(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  27247155,     834616]*)
(*NotebookOutlinePosition[  27247883,     834641]*)
(*  CellTagsIndexPosition[  27247839,     834637]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Using Text3D", "Title"],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[BoxData[
    \(Needs["\<DrawGraphics`DrawingMaster`\>"]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "Text3D is a package for writing strings of characters in Graphics3D as \
vector characters composed of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Lines. As such, they are true 3D graphical objects and will show \
perspective, rotate when the graphics is rotated and hide behind surfaces. \
Using the regular ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Text statement in Graphics3D produces only 2D characters that are \
projected to the viewing plane.  Even though they are attached to a 3D point, \
they are always visible and never show perspective."
}], "Text"],

Cell["\<\
Text3D is based on the Hershey fonts, which were designed by Dr. A. V. \
Hershey.  The present Text3D package uses only a subset of the entire Hershey \
character file. This saves a considerable amount of space and should be \
adequate for most graphical work. There are two fonts, a sans serif \
FuturaFont3D and a TimesFont3D. Each font consists of the entire keyboard set \
of characters plus upper and lower case Greek characters.\
\>", "Text"],

Cell[TextData[{
  "True 3D fonts have nice features that will often be useful or necessary. \
However, Text3D statements are intrinsically more difficult to use that \
ordinary Text statements. Whereas ordinary ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Text is simply written in the viewing plane, 3D text is oriented in 3D \
space. Therefore, the user has to supply the information for positioning and \
orienting the text. 3D text can even be warped and put on curved surfaces, \
but again the user must supply the transformations to do this. The last \
section shows cases of putting 3D text on the inner and outer surfaces of a \
cylinder, and on the surface of a sphere."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Fonts", "Section"],

Cell["\<\
This routine is used to display the fonts in the two subsections below.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay[
          s_String] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{AbsoluteThickness[
              fontThickness], 
            Black, \[IndentingNewLine]Text3D[s, {0, 0, 0}, {1, 1}, {0, 0, 0}, 
              Font3D \[Rule] font3D]}, \[IndentingNewLine]Axes \[Rule] {True, 
              True, False}, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]Boxed \[Rule] 
            False, \[IndentingNewLine]PlotRange \[Rule] {All, 
              All, {\(-0.1\), 0.1}}, \[IndentingNewLine]ImageSize \[Rule] 
            600];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(font3D\\)\\\" is similar to existing symbol \
\\\"\\!\\(Font3D\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FuturaFont3D", "Subsection"],

Cell[BoxData[{
    \(\(font3D = FuturaFont3D;\)\), "\[IndentingNewLine]", 
    \(\(fontThickness = 1;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<M\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75629 
%%ImageSize: 600 453.776 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.14817e-016 1.06245 -0.102538 1.06245 [
[.04399 .20828 -24 -8.83473 ]
[.04399 .20828 0 .16527 ]
[.16849 .16085 -23.5858 -9 ]
[.16849 .16085 .41425 0 ]
[.29814 .11146 -5.67849 -9 ]
[.29814 .11146 .32151 0 ]
[.43326 .06001 -16.3817 -9 ]
[.43326 .06001 1.61835 0 ]
[.57422 .00635 -15.7278 -9 ]
[.57422 .00635 2.27219 0 ]
[.25391 .06193 -9.46416 -12.75 ]
[.25391 .06193 .53584 0 ]
[.64815 .00741 0 -6.19658 ]
[.64815 .00741 24 2.80342 ]
[.73534 .12779 0 -6.09572 ]
[.73534 .12779 30 2.90428 ]
[.81465 .2373 0 -6.00618 ]
[.81465 .2373 6 2.99382 ]
[.8871 .33734 0 -5.92615 ]
[.8871 .33734 24 3.07385 ]
[.95355 .4291 0 -5.8542 ]
[.95355 .4291 18 3.1458 ]
[.90235 .25057 0 -8.46996 ]
[.90235 .25057 10 4.28004 ]
[ 0 0 0 0 ]
[ 1 .75629 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01606 .23172 m
.62695 0 L
s
.05356 .21749 m
.05834 .2221 L
s
[(-0.4)] .04399 .20828 1 .96327 Mshowa
.17771 .1704 m
.18233 .17518 L
s
[(-0.2)] .16849 .16085 .96548 1 Mshowa
.30698 .12137 m
.3114 .12632 L
s
[(0)] .29814 .11146 .89283 1 Mshowa
.44168 .07027 m
.4459 .07541 L
s
[(0.2)] .43326 .06001 .82018 1 Mshowa
.58217 .01699 m
.58615 .02231 L
s
[(0.4)] .57422 .00635 .74753 1 Mshowa
.125 Mabswid
.08413 .2059 m
.08698 .20868 L
s
.11502 .19418 m
.11784 .197 L
s
.14621 .18235 m
.149 .18519 L
s
.20954 .15833 m
.21228 .16122 L
s
.24169 .14613 m
.2444 .14905 L
s
.27417 .13381 m
.27685 .13676 L
s
.34014 .10879 m
.34276 .11179 L
s
.37363 .09609 m
.37622 .09911 L
s
.40748 .08325 m
.41004 .0863 L
s
.47625 .05716 m
.47874 .06027 L
s
.51118 .04391 m
.51364 .04705 L
s
.54649 .03052 m
.54891 .03369 L
s
.02328 .22898 m
.02617 .23172 L
s
.61824 .00331 m
.62059 .00652 L
s
gsave
.25391 .06193 -70.4642 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.62695 0 m
.98745 .49723 L
s
.63573 .0121 m
.62951 .01444 L
s
[(-0.5)] .64815 .00741 -1 .37702 Mshowa
.72282 .13223 m
.71656 .13445 L
s
[(-0.25)] .73534 .12779 -1 .3546 Mshowa
.80205 .24151 m
.79576 .24362 L
s
[(0)] .81465 .2373 -1 .33471 Mshowa
.87444 .34135 m
.86811 .34336 L
s
[(0.25)] .8871 .33734 -1 .31692 Mshowa
.94083 .43292 m
.93447 .43484 L
s
[(0.5)] .95355 .4291 -1 .30093 Mshowa
.125 Mabswid
.65383 .03707 m
.6501 .03846 L
s
.67158 .06156 m
.66784 .06293 L
s
.68899 .08557 m
.68525 .08693 L
s
.70607 .10912 m
.70232 .11047 L
s
.73926 .15491 m
.7355 .15622 L
s
.7554 .17716 m
.75163 .17847 L
s
.77124 .19901 m
.76747 .2003 L
s
.78679 .22045 m
.78301 .22173 L
s
.81705 .2622 m
.81327 .26345 L
s
.83178 .28251 m
.82799 .28375 L
s
.84625 .30247 m
.84246 .3037 L
s
.86047 .32208 m
.85667 .3233 L
s
.88817 .3603 m
.88437 .36149 L
s
.90167 .37891 m
.89787 .3801 L
s
.91494 .39722 m
.91114 .39839 L
s
.92799 .41522 m
.92418 .41638 L
s
.95345 .45033 m
.94963 .45147 L
s
.96587 .46746 m
.96205 .46859 L
s
.97809 .48431 m
.97426 .48543 L
s
gsave
.90235 .25057 -61 -12.47 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .75629 L
0 .75629 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.462 .69113 m
.31543 .19321 L
s
.462 .69113 m
.03461 .29644 L
s
.97284 .54628 m
.62318 .08008 L
s
.97284 .54628 m
.31543 .19321 L
s
0 g
.25 Mabswid
.01606 .23172 m
.62695 0 L
s
.05356 .21749 m
.05834 .2221 L
s
[(-0.4)] .04399 .20828 1 .96327 Mshowa
.17771 .1704 m
.18233 .17518 L
s
[(-0.2)] .16849 .16085 .96548 1 Mshowa
.30698 .12137 m
.3114 .12632 L
s
[(0)] .29814 .11146 .89283 1 Mshowa
.44168 .07027 m
.4459 .07541 L
s
[(0.2)] .43326 .06001 .82018 1 Mshowa
.58217 .01699 m
.58615 .02231 L
s
[(0.4)] .57422 .00635 .74753 1 Mshowa
.125 Mabswid
.08413 .2059 m
.08698 .20868 L
s
.11502 .19418 m
.11784 .197 L
s
.14621 .18235 m
.149 .18519 L
s
.20954 .15833 m
.21228 .16122 L
s
.24169 .14613 m
.2444 .14905 L
s
.27417 .13381 m
.27685 .13676 L
s
.34014 .10879 m
.34276 .11179 L
s
.37363 .09609 m
.37622 .09911 L
s
.40748 .08325 m
.41004 .0863 L
s
.47625 .05716 m
.47874 .06027 L
s
.51118 .04391 m
.51364 .04705 L
s
.54649 .03052 m
.54891 .03369 L
s
.02328 .22898 m
.02617 .23172 L
s
.61824 .00331 m
.62059 .00652 L
s
gsave
.25391 .06193 -70.4642 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 453.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001aB000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooodX0oooo0P0000040?ooo`8000001@3oool300000?l0oooo003o0?ooodT0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`3n0?ooo`00o`3ooom90?ooo`04
0000003oool0oooo000000P0oooo1@00003o0?ooo`00o`3ooom90?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool00000o`3oool10?ooo`00o`3ooom90?ooo`040000003oool0oooo
000000T0oooo00<000000?ooo`0000007@3oool2000001@0oooo0P0000040?ooo`800000103oool2
00000;l0oooo003o0?ooodX0oooo0P00000;0?ooo`8000006`3oool200000080oooo00<000000?oo
o`3oool0403oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000;h0oooo003o
0?ooog40oooo0`0000040?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`2l0?ooo`00o`3ooom^0?ooo`<0000000<0oooo0000003oool01@3oool0
0`000000oooo0?ooo`090?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000_`3o
ool00?l0ooooK03oool2000000D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0>
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool0_P3oool00?l0ooooJ@3oool3
000000l0oooo00<000000?ooo`3oool03P3oool2000000X0oooo0`00002n0?ooo`00o`3ooomV0?oo
o`<000004P3oool00`000000oooo0?ooo`3K0?ooo`00o`3ooomT0?ooo`8000005P3oool00`000000
oooo0?ooo`3J0?ooo`00o`3ooomQ0?ooo`<000005P3oool2000000030?ooo`000000oooo0=X0oooo
003o0?oooeh0oooo0`00000H0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0f03o
ool00?l0ooooG03oool200000200oooo00<000000?ooo`3oool0f03oool00?l0ooooF@3oool30000
0080oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`3G0?ooo`00o`3ooomG0?ooo`80
00001@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0=H0oooo003o0?oooe@0oooo
0`0000080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0eP3oool00?l0ooooD@3o
ool3000002d0oooo00<000000?ooo`3oool0e@3oool00?l0ooooC`3oool200000340oooo00<00000
0?ooo`3oool0e03oool00?l0ooooC03oool3000003@0oooo00<000000?ooo`3oool0d`3oool00?l0
ooooB@3oool3000003L0oooo00<000000?ooo`3oool0d`3oool00?l0ooooA`3oool2000003/0oooo
00<000000?ooo`3oool0dP3oool00?l0ooooA03oool3000000030?ooo`000000oooo03/0oooo00<0
00000?ooo`3oool0d@3oool00?l0oooo@@3oool3000000D0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`3A0?ooo`00o`3ooolo0?ooo`800000A@3oool00`000000oooo0?ooo`3@0?oo
o`00o`3oooll0?ooo`<00000B03oool00`000000oooo0?ooo`3?0?ooo`00o`3ooolj0?ooo`800000
B@3oool2000000030?ooo`000000oooo0<l0oooo003o0?ooocL0oooo0`00001>0?ooo`030000003o
ool0oooo0<h0oooo003o0?oooc@0oooo0`00001B0?ooo`030000003oool0oooo0<d0oooo003o0?oo
oc80oooo0P00001F0?ooo`030000003oool0oooo0<`0oooo003o0?ooobl0oooo0`0000000`3oool0
00000?ooo`1F0?ooo`030000003oool0oooo0</0oooo003e0?ooo`800000103oool2000000<0oooo
1000000W0?ooo`<000001@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0</0oooo
002B0?ooo`80000000<0oooo000000000000G@3oool010000000oooo0?ooo`0000080?ooo`030000
003oool0oooo02H0oooo0P00001P0?ooo`030000003oool0oooo0<X0oooo002C0?ooo`030000003o
ool0000005h0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0R0?ooo`<00000
H`3oool00`000000oooo0?ooo`390?ooo`00U03oool00`000000oooo0?ooo`1M0?ooo`040000003o
ool0oooo000000X0oooo00<000000?ooo`3oool07P3oool3000006H0oooo00<000000?ooo`3oool0
b@3oool00980oooo0P0000000`3oool000000000001M0?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000007@3oool2000006X0oooo00<000000?ooo`3oool0b03oool00?D0oooo
0P00000:0?ooo`8000006`3oool3000006d0oooo00<000000?ooo`3oool0a`3oool00?l0oooo7@3o
ool200000740oooo00<000000?ooo`3oool0aP3oool00?l0oooo6P3oool3000000030?ooo`000000
oooo0700oooo00<000000?ooo`3oool0aP3oool00?l0oooo5`3oool3000000D0oooo00<000000?oo
o`3oool0K`3oool200000<H0oooo003o0?oooaD0oooo0P00001h0?ooo`80000000<0oooo0000003o
ool0a@3oool00?l0oooo4P3oool3000007h0oooo00<000000?ooo`3oool0``3oool00?l0oooo3`3o
ool300000840oooo00<000000?ooo`3oool0``3oool00?l0oooo3@3oool2000008D0oooo00<00000
0?ooo`3oool0`P3oool00?l0oooo2P3oool3000008P0oooo00<000000?ooo`3oool0`@3oool00?l0
oooo203oool2000008/0oooo00<000000?ooo`3oool0`@3oool00?l0oooo1@3oool300000080oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`300?ooo`00o`3oool20?ooo`<000001P3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;l0oooo003o0?ooo`8000002P3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;h0oooo003l0?ooo`<00000V03oool00`00
0000oooo0?ooo`2n0?ooo`00n@3oool3000007P0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`2m0?ooo`00m`3oool2000007`0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`2l0?ooo`00m03oool3000007h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`2l0?ooo`00l@3oool3000000030?ooo`000000oooo07l0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`2k0?ooo`00k`3oool2000000D0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0O0?ooo`<00000_03oool00>`0oooo0`0000290?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0^@3oool00>X0oooo0P00002<0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0^@3oool00>L0oooo0`00002?0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0^03oool00>@0oooo0`00002C0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0]`3oool00>80oooo0P00002G0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0]P3oool00=l0oooo0`00002I0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool0]P3oool00;00oooo0P00000Z0?ooo`<000000P3oool00`000000oooo0?ooo`2H0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool0]@3oool00:l0oooo00@000000?ooo`3oool00000
9`3oool2000000H0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0;@0oooo002_0?ooo`040000003oool0oooo000002@0oooo0`00002T0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0]03oool00:l0oooo00@000000?ooo`3oool00000
8@3oool300000:L0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2c0?ooo`00[`3o
ool010000000oooo0?ooo`00000O0?ooo`800000Z`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0;80oooo002`0?ooo`8000007@3oool300000:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`2a0?ooo`00c03oool300000;80oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`2a0?ooo`00bP3oool400000;<0oooo00<000000?ooo`3oool07`3oool30000
0;80oooo00370?ooo`<00000103oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0[`3oool00<D0oooo0P00002l0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool0[P3oool00<80oooo0`00002o0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0[P3oool00;l0oooo0`0000320?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0[@3oool00;d0oooo0P0000360?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool0[03oool00;X0oooo0`0000390?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool04P3oool2000000@0oooo0P0000030?ooo`@000000`3oool2000008H0oooo002g0?ooo`<00000
c@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool0
0000203oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo000008D0oooo002e0?ooo`80
00000`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool03`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0P`3oool00;80oooo0`0000050?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`080?ooo`@000000P3oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo0080oooo0P0000260?ooo`00/03oool2000000T0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3o
ool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo08D0oooo002]0?oo
o`<00000fP3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo0P00000:0?oo
o`800000103oool3000008D0oooo002Z0?ooo`<00000g@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo0:L0oooo002X0?ooo`800000h@3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo0:H0oooo002U0?ooo`<00000i03oool00`000000oooo0?ooo`0N0?ooo`<00000Z03o
ool00:80oooo0`0000000`3oool000000?ooo`3U0?ooo`030000003oool0oooo01/0oooo0P000003
0?ooo`030000003oool0oooo0:D0oooo002P0?ooo`8000001@3oool00`000000oooo0?ooo`3S0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool0Y03oool009d0oooo0`00003^0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0Y03oool009X0oooo0`00003b0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0X`3oool009P0oooo0P00003f0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool0XP3oool009D0oooo0`00003h0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0X@3oool00980oooo0`00003l0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool0X@3oool005L0oooo0P0000040?ooo`8000000`3oool4000002X0
oooo1000003n0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0X03oool005H0oooo
00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0X0?ooo`<00000103oool00`000000
oooo0?ooo`3l0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0W`3oool005H0oooo
00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0U0?ooo`800000o`3oool70?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0W`3oool00500oooo100000020?ooo`040000
003oool0oooo000000X0oooo00<000000?ooo`3oool08@3oool300000?l0oooo2P3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo09h0oooo001F0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000007`3oool300000?l0oooo3P3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo09d0oooo001G0?ooo`8000002P3oool2000001h0oooo0P00003o0?oooa80
oooo00<000000?ooo`3oool07@3oool4000009h0oooo00200?ooo`<00000o`3ooolD0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool0W03oool007d0oooo0`00003o0?oooaP0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`2K0?ooo`00N`3oool2000000<0oooo0P00003o
0?oooaL0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2J0?ooo`00N03oool30000
0?l0oooo7`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo09T0oooo001f0?ooo`80
0000o`3ooolR0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0V@3oool007<0oooo
0`00003o0?ooobD0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2H0?ooo`00L03o
ool300000?l0oooo:@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo09L0oooo001^
0?ooo`800000o`3oool]0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0U`3oool0
06/0oooo0`00003o0?ooobl0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2F0?oo
o`00J03oool300000080oooo00<000000?ooo`3oool0o`3oool^0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0U@3oool006H0oooo0P0000060?ooo`030000003oool0oooo0?l0oooo
;P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo09@0oooo001S0?ooo`<000002@3o
ool00`000000oooo0?ooo`3o0?ooobh0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`2D0?ooo`00H@3oool200000?l0oooo?@3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo09<0oooo001N0?ooo`<00000o`3ooom00?ooo`030000003oool0oooo01d0oooo0P0000000`3o
ool000000?ooo`2C0?ooo`00F`3oool300000?l0ooooA03oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo0940oooo001I0?ooo`800000o`3ooom80?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool0T@3oool005H0oooo0`0000000`3oool000000?ooo`3o0?ooodL0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`2@0?ooo`00D`3oool3000000D0oooo00<00000
0?ooo`3oool0o`3ooom60?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0S`3oool0
0540oooo0P00003o0?oooe80oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`2?0?oo
o`00CP3oool300000?l0ooooE@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo08h0
oooo001;0?ooo`<00000o`3ooomH0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
S@3oool004T0oooo0P00001c0?ooo`030000003oool0oooo0>D0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`2<0?ooo`003@3oool2000000@0oooo0P0000050?ooo`<00000:@3oool3
000007D0oooo0`00003V0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0S03oool0
00`0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0V0?ooo`8000000P3oool0
0`000000oooo0?ooo`1d0?ooo`040000003oool0000000000>D0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`2;0?ooo`00303oool010000000oooo0?ooo`0000080?ooo`D00000903o
ool3000000D0oooo00<000000?ooo`3oool0L`3oool010000000oooo0?ooo`3oool200000><0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2:0?ooo`001P3oool400000080oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`00000R0?ooo`<00000OP3oool00`000000
oooo0?ooo`030?ooo`800000hP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo08X0
oooo000<0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`000000803oool200000840
oooo00<000000?ooo`3oool01@3oool200000>40oooo00<000000?ooo`3oool0703oool200000003
0?ooo`000000oooo08X0oooo000=0?ooo`8000002`3oool2000001d0oooo0`0000240?ooo`030000
003oool0oooo00H0oooo0P00003P0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
R03oool003H0oooo0`0000270?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0g@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo08L0oooo000d0?ooo`800000RP3oool0
0`000000oooo0?ooo`090?ooo`800000gP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo08L0oooo000a0?ooo`<000000P3oool2000008T0oooo00<000000?ooo`3oool02P3oool20000
0=d0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`260?ooo`00;P3oool300000900
oooo00<000000?ooo`3oool0303oool200000=`0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`250?ooo`00;03oool2000009<0oooo00<000000?ooo`3oool03P3oool200000=X0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`240?ooo`00:@3oool3000009H0oooo00<0
00000?ooo`3oool03`3oool200000=T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`240?ooo`009`3oool2000009T0oooo00<000000?ooo`3oool04@3oool200000=P0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`230?ooo`00903oool3000009/0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool0PP3oool00240oooo0`00002N0?ooo`030000003oool0oooo01@0oooo0P00003F0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool0PP3oool001l0oooo0P0000030?ooo`800000
W@3oool00`000000oooo0?ooo`0E0?ooo`800000e@3oool00`000000oooo0?ooo`0O0?ooo`800000
PP3oool001`0oooo0`0000070?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool05`3o
ool200000=@0oooo00<000000?ooo`3oool0703oool2000000030?ooo`000000oooo0840oooo000I
0?ooo`<00000Y`3oool00`000000oooo0?ooo`0I0?ooo`800000d`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo07l0oooo000G0?ooo`800000Z`3oool00`000000oooo0?ooo`0J0?oo
o`800000d@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07l0oooo000D0?ooo`<0
0000[@3oool00`000000oooo0?ooo`0L0?ooo`800000d03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo07h0oooo000A0?ooo`<00000/03oool00`000000oooo0?ooo`0N0?ooo`800000
c`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo07d0oooo000?0?ooo`80000000<0
oooo0000003oool0/03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0<d0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`800000K`3oool000d0oooo0P000004
0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool200000<d0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`040000003oool0oooo000006h0oooo0035
0?ooo`030000003oool0oooo0280oooo0P00003<0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`00001^0?ooo`00a@3oool00`000000oooo0?ooo`0T
0?ooo`800000b`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00P0oooo00@00000
0?ooo`3oool00000KP3oool00<H0oooo00<000000?ooo`3oool09@3oool200000<X0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000006h0oooo0036
0?ooo`030000003oool0oooo02L0oooo0P0000380?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0203oool2000006l0oooo00360?ooo`030000003oool0oooo02T0oooo0P0000370?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0N03oool00<L0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo01h0oooo0P00000m0?ooo`80
0000>P3oool00<L0oooo00<000000?ooo`3oool0:`3oool200000<H0oooo00<000000?ooo`3oool0
6P3oool3000000030?ooo`000000oooo03d0oooo00<000000?ooo`3oool0>03oool00<L0oooo00<0
00000?ooo`3oool0;@3oool200000<@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo03L0oooo00370?ooo`030000003oool0oooo02l0oooo0P000033
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0000000h
0?ooo`00b03oool00`000000oooo0?ooo`0`0?ooo`800000`P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo03T0oooo00@000000?ooo`3oool00000>03oool00<P0oooo00<000000?oo
o`3oool0<P3oool200000<40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0g0?oo
o`<0000000<0oooo000000000000=`3oool00<P0oooo00<000000?ooo`3oool0=03oool200000;l0
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1c0?ooo`00b@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`1b0?ooo`00b@3oool00`000000oooo0?ooo`0f0?ooo`800000_P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0780oooo00390?ooo`030000003oool0oooo03P0oooo0P00002m
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0L@3oool00<X0oooo00<000000?oo
o`3oool0>@3oool200000;/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1`0?oo
o`00bP3oool00`000000oooo0?ooo`0k0?ooo`800000^P3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo06l0oooo003:0?ooo`030000003oool0oooo03d0oooo0P00002i0?ooo`030000
003oool0oooo01h0oooo0P00001`0?ooo`00bP3oool00`000000oooo0?ooo`0o0?ooo`800000^03o
ool00`000000oooo0?ooo`0K0?ooo`80000000<0oooo0000003oool0K`3oool00</0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool0K@3oool00</0oooo00<000000?ooo`3oool0@@3oool200000;H0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`1]0?ooo`00b`3oool00`000000oooo0?ooo`130?ooo`80
0000]@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06`0oooo003<0?ooo`030000
003oool0oooo04@0oooo0P00002d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
J`3oool00<`0oooo00<000000?ooo`3oool0AP3oool200000;80oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`1Z0?ooo`00c03oool00`000000oooo0?ooo`180?ooo`800000/@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06X0oooo003<0?ooo`030000003oool0oooo
04X0oooo0P00002`0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0J@3oool00<d0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0J03oool00<d0oooo00<000000?ooo`3oool0C03oool200000:h0oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1W0?ooo`00c@3oool00`000000oooo0?oo
o`1>0?ooo`800000[@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo06L0oooo003>
0?ooo`030000003oool0oooo04l0oooo0P00002/0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0IP3oool00<h0oooo00<000000?ooo`3oool0D@3oool200000:/0oooo00<000000?oo
o`3oool06`3oool2000000030?ooo`000000oooo06H0oooo003>0?ooo`030000003oool0oooo05<0
oooo0P00002Y0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0I@3oool00<l0oooo
00<000000?ooo`3oool0E03oool200000:P0oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`1T0?ooo`00c`3oool00`000000oooo0?ooo`1F0?ooo`800000Y`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo06<0oooo003?0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0Y@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0680oooo003?0?oo
o`030000003oool0oooo05T0oooo0P00002U0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0HP3oool00=00oooo00<000000?ooo`3oool0FP3oool200000:@0oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`1Q0?ooo`00603oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo05`0oooo0P00002S0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
H03oool001T0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`1N0?ooo`800000XP3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05l0oooo000J0?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool0G`3oool200000:00oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`1O0?ooo`006`3oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo
0640oooo0P00002O0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0GP3oool001`0
oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1M0?ooo`007@3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo06@0oooo0P00002N0?ooo`030000003oool0oooo01/0oooo
0`00001O0?ooo`007P3oool200000;80oooo00<000000?ooo`3oool0I@3oool2000009`0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1L0?ooo`00803oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo06L0oooo0P00002K0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0F`3oool00240oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1Y0?oo
o`800000VP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05X0oooo000R0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool0JP3oool2000009T0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1J0?ooo`008`3oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo06`0oooo0P00002G0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
F@3oool002@0oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1H0?ooo`009@3oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo06h0oooo0P00002F0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0F03oool002H0oooo00<000000?ooo`3oool0Z`3oool00`00
0000oooo0?ooo`1`0?ooo`800000U@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
05L0oooo000W0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0LP3oool2000009<0
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00:03oool00`000000oooo
0?ooo`2Y0?ooo`030000003oool0oooo07@0oooo0P00002B0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0E@3oool002T0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`1e0?ooo`800000T@3oool00`000000oooo0?ooo`0K0?ooo`<00000E`3oool002X0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`1g0?ooo`800000T03oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo05@0oooo000[0?ooo`800000Z03oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1C0?oo
o`00;@3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo07T0oooo0P00002>0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool0DP3oool002h0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`1k0?ooo`800000S@3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo0580oooo000_0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0O@3o
ool2000008`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`800000103o
ool2000000<0oooo100000030?ooo`800000<P3oool00300oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`1o0?ooo`800000RP3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo00000340oooo000a0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0P03o
ool2000008T0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0_0?ooo`00<P3o
ool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo0880oooo0P0000280?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo0P00000b0?ooo`00<`3oool00`000000oooo0?ooo`2Q0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`03
0000003oool0oooo0340oooo000d0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0
Q03oool2000008H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`800000
2P3oool2000000@0oooo0`00000a0?ooo`00=@3oool00`000000oooo0?ooo`2P0?ooo`030000003o
ool0oooo08H0oooo0P0000250?ooo`030000003oool0oooo01d0oooo0P00001>0?ooo`00=P3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo08P0oooo0P0000240?ooo`030000003oool0
oooo01T0oooo0`0000000`3oool000000?ooo`1=0?ooo`00=`3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo08T0oooo0P0000230?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0B`3oool003P0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`2;0?ooo`80
0000P@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04X0oooo000i0?ooo`800000
WP3oool00`000000oooo0?ooo`2=0?ooo`800000P03oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04X0oooo000k0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0S`3o
ool2000007l0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`190?ooo`00?03oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04P0oooo000m0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0T@3oool2000007d0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`180?ooo`00?P3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo09<0
oooo0P00001l0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0A`3oool003l0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`2D0?ooo`800000N`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo04H0oooo00100?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool0UP3oool2000007X0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`150?ooo`00@@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo09P0oooo0P00001h
0?ooo`030000003oool0oooo01d0oooo0P0000160?ooo`00@P3oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo09X0oooo0P00001g0?ooo`030000003oool0oooo01X0oooo0P0000000`3o
ool000000?ooo`150?ooo`00@`3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo09/0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo04<0
oooo00140?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0W03oool2000007H0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`130?ooo`00A@3oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo09h0oooo0P00001d0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0@P3oool004H0oooo0P00002E0?ooo`030000003oool0oooo09l0oooo0P00001c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0@@3oool004P0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`2Q0?ooo`800000LP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo0400oooo00190?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0X`3oool200000740oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`100?ooo`00
BP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo0:@0oooo0P00001_0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0?`3oool004/0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0n0?ooo`00C03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo0:L0oooo0P00001^0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0?@3oool0
04d0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`2Y0?ooo`800000K@3oool00`00
0000oooo0?ooo`0L0?ooo`800000?P3oool004h0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`2Z0?ooo`800000J`3oool00`000000oooo0?ooo`0J0?ooo`80000000<0oooo0000003o
ool0?@3oool004l0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`2/0?ooo`800000
JP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo03/0oooo001@0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0[P3oool2000006T0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0k0?ooo`00D@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0:l0oooo0P00001X0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>P3oool0
0580oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0i0?ooo`00D`3oool2000008/0
oooo00<000000?ooo`3oool0/P3oool2000006H0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0h0?ooo`00E@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;<0oooo
0P00001U0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0>03oool005H0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`800000I03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo03L0oooo001G0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0]`3oool200000680oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0f
0?ooo`00F03oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0;T0oooo0P00001Q0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0=@3oool005T0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`2j0?ooo`800000H03oool00`000000oooo0?ooo`0L0?ooo`80
0000=P3oool005X0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`2l0?ooo`800000
G`3oool00`000000oooo0?ooo`0I0?ooo`80000000<0oooo0000003oool0=@3oool005/0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo05`0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0c0?ooo`00G03oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo0;h0oooo0P00001M0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0<`3oool005d0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`300?oo
o`800000G03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0380oooo001N0?ooo`03
0000003oool0oooo0880oooo00<000000?ooo`3oool0`P3oool2000005/0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0a0?ooo`00G`3oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0<@0oooo0P00001I0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
<03oool00600oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`350?ooo`800000F03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo0300oooo001Q0?ooo`800000P@3oool0
0`000000oooo0?ooo`370?ooo`800000E`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo02l0oooo001S0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0;P3oool006@0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`390?ooo`800000E@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo02h0oooo001U0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0b`3oool2000005@0oooo00<000000?ooo`3oool06P3oool3000002l0oooo
001V0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0c@3oool2000005<0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0/0?ooo`00I`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo0<h0oooo0P00001B0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0:`3oool006P0oooo00<000000?ooo`3oool0N`3oool00`000000oooo0?ooo`3@0?oo
o`800000D03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02/0oooo001Y0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0dP3oool2000004l0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`0;0?ooo`800000103oool2000000@0oooo0P00000A0?ooo`00
JP3oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000@0?ooo`00J`3oool00`000000oooo0?ooo`1i0?ooo`03
0000003oool0oooo0=@0oooo0P00001>0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00h0oooo001/0?ooo`03
0000003oool0oooo07P0oooo00<000000?ooo`3oool0eP3oool2000004`0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000000T0oooo0P00000A0?oo
o`00K@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0=P0oooo0P00001;0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`0000090?oo
o`030000003oool0oooo0100oooo001^0?ooo`800000N03oool00`000000oooo0?ooo`3I0?ooo`80
0000BP3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00L0oooo0P00000:0?ooo`<0
0000403oool00700oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`3K0?ooo`800000
B@3oool00`000000oooo0?ooo`0K0?ooo`8000009`3oool00740oooo00<000000?ooo`3oool0M03o
ool00`000000oooo0?ooo`3M0?ooo`800000A`3oool00`000000oooo0?ooo`0H0?ooo`<0000000<0
oooo0000003oool09P3oool00780oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`3O
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0T
0?ooo`00L`3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0=l0oooo0P0000160?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool08`3oool007@0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`3Q0?ooo`800000A@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo02<0oooo001e0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
h`3oool2000004<0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0R0?ooo`00MP3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0>@0oooo0P0000120?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool08@3oool007L0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`3V0?ooo`800000@@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo0200oooo001h0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0j03oool20000
0400oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0P0?ooo`00N@3oool00`000000
oooo0?ooo`1_0?ooo`030000003oool0oooo0>T0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo01l0oooo001j0?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0jP3oool2000003h0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0N0?ooo`00N`3oool2000006h0oooo00<000000?ooo`3oool0k03oool2000003d0oooo00<0
00000?ooo`3oool06@3oool300000200oooo001m0?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0kP3oool2000003`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0M
0?ooo`00OP3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0>l0oooo0P00000j0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0703oool007l0oooo00<000000?ooo`3o
ool0JP3oool00`000000oooo0?ooo`3a0?ooo`800000>@3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo01/0oooo00200?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
l`3oool2000003P0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`00P@3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0?@0oooo0P00000g0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool06P3oool00880oooo00<000000?ooo`3oool0J03oool0
0`000000oooo0?ooo`3f0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`0I0?ooo`00P`3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo
0?L0oooo0P00000e0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0603oool008@0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`3i0?ooo`800000=03oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01P0oooo00250?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0nP3oool2000003<0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0G0?ooo`00QP3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0?`0oooo0P00
000a0?ooo`030000003oool0oooo01T0oooo1000000H0?ooo`00Q`3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo0?h0oooo0P00000`0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool05P3oool008P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`3o0?oo
o`800000;`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00290?ooo`80
0000I03oool00`000000oooo0?ooo`3o0?ooo`80oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo01@0oooo002;0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0o`3oool30?ooo`800000;@3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo01<0oooo002<0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0o`3o
ool40?ooo`800000;03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01<0oooo002=
0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0o`3oool60?ooo`800000:`3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0180oooo002>0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0o`3oool80?ooo`800000:P3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo0140oooo002?0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0o`3oool:0?ooo`800000:03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0140
oooo002@0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0o`3oool;0?ooo`800000
9`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo002A0?ooo`030000003o
ool0oooo05d0oooo00<000000?ooo`3oool0o`3oool=0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool06@3oool300000140oooo002B0?ooo`030000003oool0oooo05`0oooo00<00000
0?ooo`3oool0o`3oool>0?ooo`8000009P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00h0oooo002C0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool0o`3oool?0?oo
o`800000903oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo002D0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0o`3ooolA0?ooo`8000008`3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00d0oooo002E0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0o`3ooolC0?ooo`8000008P3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00`0oooo002F0?ooo`800000FP3oool00`000000oooo0?ooo`3o0?oooaD0oooo0P00
000Q0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool02`3oool009P0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`3o0?oooaH0oooo0P00000O0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool02`3oool009T0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3o0?oooaP0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00X0oooo002J0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0o`3ooolI0?ooo`8000007P3oool00`000000oooo0?ooo`0W0?ooo`00V`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0?l0oooo6P3oool2000001d0oooo00<000000?ooo`3oool0
9P3oool009`0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`3o0?oooa`0oooo0P00
000K0?ooo`030000003oool0oooo02H0oooo002M0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0o`3ooolN0?ooo`8000006P3oool00`000000oooo0?ooo`0U0?ooo`00WP3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0?l0oooo7`3oool2000001T0oooo00<000000?oo
o`3oool0903oool009l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`3o0?ooob40
oooo0P00000H0?ooo`030000003oool0oooo02<0oooo002P0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0o`3ooolS0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
8`3oool00:40oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`3o0?ooob@0oooo0P00
000F0?ooo`030000003oool0oooo0280oooo002R0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool0o`3ooolU0?ooo`8000005@3oool00`000000oooo0?ooo`0Q0?ooo`00X`3oool20000
0540oooo00<000000?ooo`3oool0o`3ooolW0?ooo`800000503oool00`000000oooo0?ooo`0P0?oo
o`00Y@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0?l0oooo:@3oool200000180
oooo00<000000?ooo`3oool0803oool00:H0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`3o0?ooobX0oooo0P00000A0?ooo`030000003oool0oooo01l0oooo002W0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0o`3oool/0?ooo`800000403oool00`000000oooo0?oo
o`0N0?ooo`00Z03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0?l0oooo;P3oool2
000000l0oooo00<000000?ooo`3oool07@3oool00:T0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`3o0?ooobl0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0M0?oo
o`00ZP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0?l0oooo<03oool2000000d0
oooo00<000000?ooo`3oool0703oool00:/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`3o0?oooc80oooo0P00000<0?ooo`030000003oool0oooo01/0oooo002/0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0o`3ooold0?ooo`8000002`3oool00`000000oooo0?oo
o`0J0?ooo`00[@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0?l0oooo=@3oool2
000000T0oooo00<000000?ooo`3oool06P3oool00:h0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`3o0?ooocL0oooo0P0000080?ooo`030000003oool0oooo01T0oooo002_0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool0o`3oooli0?ooo`8000001`3oool00`000000
oooo0?ooo`0H0?ooo`00/03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0?l0oooo
>P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01L0oooo002a0?ooo`800000A`3o
ool00`000000oooo0?ooo`3o0?oooc/0oooo0P0000050?ooo`030000003oool0oooo01L0oooo002c
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`800000103oool0
0`000000oooo0?ooo`0F0?ooo`00]03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
0?l0oooo?`3oool2000000<0oooo00<000000?ooo`3oool05@3oool00;D0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`3o0?oood00oooo0P0000020?ooo`030000003oool0oooo01@0
oooo002f0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0o`3ooom20?ooo`<00000
5P3oool00;L0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3o0?oood@0oooo0P00
000E0?ooo`00^03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0?l0ooooA@3oool0
0`000000oooo0?ooo`0B0?ooo`00^@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0?l0ooooFP3oool00;X0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oooeX0
oooo002k0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooomI0?ooo`00_03o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooF@3oool00;d0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`3o0?oooeT0oooo002n0?ooo`800000?@3oool00`00
0000oooo0?ooo`3o0?oooeT0oooo00300?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0o`3ooomH0?ooo`00`@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0?l0oooo
F03oool00<80oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?oooeP0oooo0033
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00a03oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo0?l0ooooE`3oool00<D0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`3o0?oooeL0oooo00360?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0o`3ooomG0?ooo`00a`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0?l0ooooEP3oool00<P0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`3o
0?oooeH0oooo00390?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0o`3ooomF0?oo
o`00bP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0?l0ooooE@3oool00</0oooo
0P00000d0?ooo`030000003oool0oooo0?l0ooooE@3oool00<d0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`3o0?oooeD0oooo003>0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0o`3ooomD0?ooo`00c`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
0?l0ooooE03oool00=00oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`3o0?oooe@0
oooo003A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00dP3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0?l0ooooD`3oool00=<0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`3o0?oooe<0oooo003D0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0o`3ooomC0?ooo`00e@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo0?l0ooooDP3oool00=H0oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`3o0?oooe80oooo003G0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0o`3o
oomB0?ooo`00f03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0?l0ooooDP3oool0
0=T0oooo0P00000Z0?ooo`030000003oool0oooo0?l0ooooD@3oool00=/0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`3o0?oooe40oooo003L0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0o`3ooomA0?ooo`00g@3oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo0?l0ooooD03oool00=h0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`3o
0?oooe00oooo003O0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0o`3ooom@0?oo
o`00h03oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0?l0ooooC`3oool00>40oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`3o0?ooodl0oooo003R0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0o`3ooom?0?ooo`00h`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo0?l0ooooC`3oool00>@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`3o0?ooodh0oooo003U0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool0o`3ooom>0?ooo`00iP3oool200000200oooo00<000000?ooo`3oool0o`3ooom>0?ooo`00j03o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?l0ooooC@3oool00>T0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`3o0?ooodd0oooo003Z0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0o`3ooom=0?ooo`00j`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo0?l0ooooC@3oool00>`0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`3o0?oood`0oooo003]0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0o`3o
oom<0?ooo`00kP3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooC03oool0
0>l0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oood/0oooo003`0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3ooom;0?ooo`00l@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo0?l0ooooB`3oool00?80oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`3o0?ooodX0oooo003c0?ooo`8000005`3oool00`000000oooo0?ooo`3o
0?ooodX0oooo003e0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3ooom:0?oo
o`00mP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0?l0ooooBP3oool00?L0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3o0?ooodT0oooo003h0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0o`3ooom90?ooo`00n@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0?l0ooooB@3oool00?X0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`3o0?ooodP0oooo003k0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0o`3ooom80?ooo`00o03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
B03oool00?d0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooodL0oooo003n
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooom70?ooo`00o`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooA`3oool00?l0oooo0@3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo0?l0ooooA`3oool00?l0oooo0P3oool2000000d0oooo
00<000000?ooo`3oool0o`3ooom60?ooo`00o`3oool40?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool0o`3ooom60?ooo`00o`3oool50?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0o`3ooom60?ooo`00o`3oool60?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0o`3ooom50?ooo`00o`3oool70?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0o`3ooom50?ooo`00o`3oool80?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooom50?ooo`00o`3oool90?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
oom50?ooo`00o`3oool:0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooom4
0?ooo`00o`3oool;0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom40?oo
o`00o`3oool<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00
o`3oool=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00o`3o
ool>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooom30?ooo`00o`3oool?
0?ooo`8000000`3oool00`000000oooo0?ooo`3o0?oood<0oooo003o0?oooa40oooo00D000000?oo
o`3oool0oooo0000003o0?oood@0oooo003o0?oooa80oooo00@000000?ooo`3oool00000o`3ooom4
0?ooo`00o`3ooolC0?ooo`030000003oool000000?l0ooooA03oool00?l0oooo503oool200000?l0
ooooA03oool00?l0oooo5@3oool200000?l0oooo@`3oool00?l0oooo5P3oool00`000000oooo0?oo
o`3o0?oood40oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 599}, {452.75, 0}} -> {-0.00579957, 0.088168, \
0.00159068, 0.00159068}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<ABCDEFGHIJKLMNOPQRSTUVWXYZ\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34481 
%%ImageSize: 600 206.885 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0520638 1.05206 -0.343127 1.05206 [
[.14504 .25617 -8.42882 -9 ]
[.14504 .25617 9.57118 0 ]
[.46386 .15307 -2.99403 -9 ]
[.46386 .15307 3.00597 0 ]
[.80838 .04171 -6.40386 -9 ]
[.80838 .04171 5.59614 0 ]
[.4622 .08791 -4.98826 -12.75 ]
[.4622 .08791 5.01174 0 ]
[.99388 -0.001 0 -5.94933 ]
[.99388 -0.001 24 3.05067 ]
[1.00147 .01006 0 -5.94265 ]
[1.00147 .01006 6 3.05735 ]
[1.009 .02104 0 -5.93603 ]
[1.009 .02104 18 3.06397 ]
[1.0645 -0.0094 0 -8.41824 ]
[1.0645 -0.0094 10 4.33176 ]
[ 0 0 0 0 ]
[ 1 .34481 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00054 .31563 m
.97928 0 L
s
.14421 .2693 m
.14379 .27586 L
s
[(-10)] .14504 .25617 -0.06346 1 Mshowa
.46384 .16622 m
.46383 .1728 L
s
[(0)] .46386 .15307 -0.00199 1 Mshowa
.80927 .05483 m
.80971 .06139 L
s
[(10)] .80838 .04171 .06731 1 Mshowa
.125 Mabswid
.20621 .2493 m
.20601 .25324 L
s
.26915 .229 m
.269 .23295 L
s
.33306 .2084 m
.33295 .21234 L
s
.39794 .18747 m
.39789 .19142 L
s
.53076 .14464 m
.53081 .14858 L
s
.59874 .12272 m
.59884 .12666 L
s
.6678 .10045 m
.66795 .10439 L
s
.73797 .07782 m
.73817 .08176 L
s
.08313 .28899 m
.08283 .29293 L
s
.02295 .3084 m
.02261 .31233 L
s
.88172 .03146 m
.88205 .03539 L
s
.95537 .00771 m
.95575 .01164 L
s
gsave
.4622 .08791 -65.9883 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97928 0 m
.99934 .02922 L
s
.98136 .00303 m
.97511 .00505 L
s
[(-0.5)] .99388 -0.001 -1 .32207 Mshowa
.98895 .01408 m
.98269 .01609 L
s
[(0)] 1.00147 .01006 -1 .32059 Mshowa
.99647 .02504 m
.99021 .02704 L
s
[(0.5)] 1.009 .02104 -1 .31912 Mshowa
.125 Mabswid
.98289 .00525 m
.97913 .00646 L
s
.9844 .00746 m
.98065 .00867 L
s
.98592 .00967 m
.98216 .01088 L
s
.98743 .01188 m
.98368 .01308 L
s
.99046 .01628 m
.9867 .01748 L
s
.99196 .01847 m
.98821 .01967 L
s
.99347 .02066 m
.98971 .02187 L
s
.99497 .02285 m
.99121 .02405 L
s
.97984 .00081 m
.97609 .00202 L
s
.99797 .02722 m
.99421 .02842 L
s
gsave
1.0645 -0.0094 -61 -12.4182 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34481 L
0 .34481 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.06013 .33054 m
.05033 .30591 L
s
.06013 .33054 m
.02398 .31439 L
s
.07985 .32426 m
.0947 .31954 L
s
.07985 .32426 m
.05695 .30378 L
s
.03662 .31962 m
.05307 .31435 L
s
.0947 .31954 m
.09858 .31698 L
s
.09858 .31698 m
.09916 .31548 L
s
.09916 .31548 m
.09866 .313 L
s
.06899 .31455 m
.08388 .30979 L
s
.09866 .313 m
.0965 .31105 L
s
.0965 .31105 m
.09268 .30962 L
s
.12016 .31011 m
.11469 .30921 L
s
.12456 .31003 m
.12016 .31011 L
s
.13123 .30791 m
.12456 .31003 L
s
.08388 .30979 m
.08776 .30721 L
s
.08993 .30917 m
.08388 .30979 L
s
.09268 .30962 m
.08993 .30917 L
s
.11469 .30921 m
.11087 .30779 L
s
.1335 .30587 m
.13123 .30791 L
s
.11087 .30779 m
.10597 .30537 L
s
.08776 .30721 m
.08834 .3057 L
s
.1347 .30284 m
.1335 .30587 L
s
.08834 .3057 m
.08783 .3032 L
s
.10597 .30537 m
.10056 .30046 L
s
.07188 .29898 m
.05695 .30378 L
s
.08783 .3032 m
.08456 .30025 L
s
.13423 .30033 m
.1347 .30284 L
s
.14962 .30206 m
.16136 .29832 L
s
.14962 .30206 m
.12708 .28122 L
s
.10056 .30046 m
.09897 .29696 L
s
.08456 .30025 m
.08071 .29881 L
s
.07796 .29836 m
.07188 .29898 L
s
.08071 .29881 m
.07796 .29836 L
s
.16136 .29832 m
.16534 .29572 L
s
.09897 .29696 m
.09847 .29445 L
s
.16534 .29572 m
.16659 .29267 L
s
.09847 .29445 m
.09964 .29139 L
s
.16659 .29267 m
.16615 .29015 L
s
.09964 .29139 m
.10189 .28932 L
s
.18495 .29081 m
.20698 .2838 L
s
.18495 .29081 m
.1626 .26979 L
s
.16615 .29015 m
.16464 .28662 L
s
.11856 .28799 m
.1224 .28944 L
s
.10189 .28932 m
.10859 .28716 L
s
.11303 .28708 m
.11856 .28799 L
s
.10859 .28716 m
.11303 .28708 L
s
.16464 .28662 m
.1593 .28163 L
s
.1593 .28163 m
.1544 .27917 L
s
.13888 .27742 m
.12708 .28122 L
s
.17435 .28084 m
.18792 .2765 L
s
.21718 .28055 m
.23938 .27349 L
s
.21718 .28055 m
.195 .25937 L
s
.1544 .27917 m
.15056 .27771 L
s
.15056 .27771 m
.14503 .27679 L
s
.14503 .27679 m
.13888 .27742 L
s
.20666 .27051 m
.22034 .26613 L
s
.1626 .26979 m
.18474 .26267 L
s
.25378 .26756 m
.24826 .26663 L
s
.25825 .26748 m
.25378 .26756 L
s
.26514 .26529 m
.25825 .26748 L
s
.24826 .26663 m
.24446 .26516 L
s
.26755 .26318 m
.26514 .26529 L
s
.24446 .26516 m
.2396 .26267 L
s
.26893 .26005 m
.26755 .26318 L
s
.2396 .26267 m
.23436 .25759 L
s
.26858 .25746 m
.26893 .26005 L
s
.28586 .25869 m
.26405 .23715 L
s
.23436 .25759 m
.23293 .25398 L
s
.23293 .25398 m
.23254 .25138 L
s
.25161 .25206 m
.26026 .24929 L
s
.23254 .25138 m
.23389 .24822 L
s
.31017 .25095 m
.28849 .22929 L
s
.25712 .24621 m
.26026 .24929 L
s
.27552 .24848 m
.29989 .24068 L
s
.23389 .24822 m
.23629 .24608 L
s
.32412 .24651 m
.30252 .22478 L
s
.25329 .24471 m
.25712 .24621 L
s
.23629 .24608 m
.24321 .24386 L
s
.24773 .24377 m
.25329 .24471 L
s
.24321 .24386 m
.24773 .24377 L
s
.35217 .23758 m
.33586 .22095 L
s
.3645 .23366 m
.34312 .21172 L
s
.31823 .2266 m
.32029 .22868 L
s
.3169 .22291 m
.31823 .2266 L
s
.38926 .22578 m
.35028 .21907 L
s
.31763 .2213 m
.3169 .22291 L
s
.39992 .22238 m
.37874 .20026 L
s
.36423 .22147 m
.36802 .2037 L
s
.32012 .21911 m
.31763 .2213 L
s
.33586 .22095 m
.33101 .21837 L
s
.32365 .21798 m
.32012 .21911 L
s
.33101 .21837 m
.32821 .21789 L
s
.32821 .21789 m
.32365 .21798 L
s
.43385 .21159 m
.42731 .18463 L
s
.43385 .21159 m
.41286 .18928 L
s
.46263 .20242 m
.44181 .17997 L
s
.46263 .20242 m
.42731 .18463 L
s
.37874 .20026 m
.40026 .19333 L
s
.4771 .19782 m
.48194 .16706 L
s
.4771 .19782 m
.45636 .17529 L
s
.50253 .18972 m
.48194 .16706 L
s
.52165 .18226 m
.51605 .18127 L
s
.52628 .18217 m
.52165 .18226 L
s
.53361 .17983 m
.52628 .18217 L
s
.51605 .18127 m
.51228 .1797 L
s
.53632 .17758 m
.53361 .17983 L
s
.51228 .1797 m
.50753 .17704 L
s
.53807 .17425 m
.53632 .17758 L
s
.50753 .17704 m
.50264 .17163 L
s
.53798 .17149 m
.53807 .17425 L
s
.55569 .1728 m
.57232 .16751 L
s
.55569 .1728 m
.53542 .14985 L
s
.50264 .17163 m
.50154 .16778 L
s
.53693 .16765 m
.53798 .17149 L
s
.50154 .16778 m
.50141 .16501 L
s
.53209 .1622 m
.53693 .16765 L
s
.57232 .16751 m
.57693 .16465 L
s
.50141 .16501 m
.50313 .16165 L
s
.57693 .16465 m
.57783 .16297 L
s
.57783 .16297 m
.57778 .16019 L
s
.52732 .15951 m
.53209 .1622 L
s
.50313 .16165 m
.50583 .15937 L
s
.5618 .15549 m
.54511 .16083 L
s
.57778 .16019 m
.57492 .15691 L
s
.52353 .15791 m
.52732 .15951 L
s
.50583 .15937 m
.51321 .157 L
s
.51788 .15691 m
.52353 .15791 L
s
.51321 .157 m
.51788 .15691 L
s
.6011 .15695 m
.59548 .15595 L
s
.60578 .15686 m
.6011 .15695 L
s
.57492 .15691 m
.57115 .15531 L
s
.61325 .15448 m
.60578 .15686 L
s
.59548 .15595 m
.59172 .15435 L
s
.56833 .1548 m
.5618 .15549 L
s
.57115 .15531 m
.56833 .1548 L
s
.61605 .15219 m
.61325 .15448 L
s
.59172 .15435 m
.587 .15164 L
s
.61791 .1488 m
.61605 .15219 L
s
.587 .15164 m
.58223 .14613 L
s
.6179 .14599 m
.61791 .1488 L
s
.63574 .14733 m
.65268 .14193 L
s
.63574 .14733 m
.61595 .12395 L
s
.58223 .14613 m
.58123 .14221 L
s
.61695 .14207 m
.6179 .14599 L
s
.58123 .14221 m
.58118 .13939 L
s
.61222 .13652 m
.61695 .14207 L
s
.65268 .14193 m
.65741 .13902 L
s
.58118 .13939 m
.58301 .13596 L
s
.65741 .13902 m
.65837 .13731 L
s
.65837 .13731 m
.65841 .13448 L
s
.6075 .13378 m
.61222 .13652 L
s
.59527 .13629 m
.60082 .12596 L
s
.64335 .13081 m
.62635 .13624 L
s
.58301 .13596 m
.58581 .13364 L
s
.65841 .13448 m
.65654 .13225 L
s
.60371 .13215 m
.6075 .13378 L
s
.58581 .13364 m
.59332 .13122 L
s
.67824 .13239 m
.6726 .13136 L
s
.68486 .13169 m
.67824 .13239 L
s
.65654 .13225 m
.65279 .13062 L
s
.59804 .13113 m
.60371 .13215 L
s
.63956 .13202 m
.64249 .11541 L
s
.69247 .12927 m
.68486 .13169 L
s
.6726 .13136 m
.67075 .12913 L
s
.59332 .13122 m
.59804 .13113 L
s
.64996 .13011 m
.64335 .13081 L
s
.65279 .13062 m
.64996 .13011 L
s
.69726 .12633 m
.69247 .12927 L
s
.67075 .12913 m
.67079 .12628 L
s
.69924 .12287 m
.69726 .12633 L
s
.67079 .12628 m
.67176 .12455 L
s
.67176 .12455 m
.67464 .12221 L
s
.70963 .12381 m
.73646 .11527 L
s
.67464 .12221 m
.68423 .1163 L
s
.72302 .11954 m
.70378 .09569 L
s
.68423 .1163 m
.68713 .11395 L
s
.66058 .11102 m
.65864 .11451 L
s
.68713 .11395 m
.68812 .1122 L
s
.74608 .1122 m
.73247 .09512 L
s
.68812 .1122 m
.68818 .10932 L
s
.66537 .10805 m
.66058 .11102 L
s
.68818 .10932 m
.6854 .10591 L
s
.67303 .10558 m
.66537 .10805 L
s
.6854 .10591 m
.67971 .10487 L
s
.67971 .10487 m
.67303 .10558 L
s
.75965 .0864 m
.77314 .10359 L
s
.78284 .1005 m
.77964 .07129 L
s
.73247 .09512 m
.73167 .09105 L
s
.73167 .09105 m
.73372 .08751 L
s
.81403 .09057 m
.77964 .07129 L
s
.8199 .08871 m
.81114 .06115 L
s
.73372 .08751 m
.73863 .08448 L
s
.75498 .08356 m
.75965 .0864 L
s
.73863 .08448 m
.74252 .08323 L
s
.74927 .08251 m
.75498 .08356 L
s
.74252 .08323 m
.74927 .08251 L
s
.83953 .08246 m
.83095 .05478 L
s
.83953 .08246 m
.81114 .06115 L
s
.85925 .07618 m
.83095 .05478 L
s
.86915 .07303 m
.87884 .03937 L
s
.89696 .06418 m
.85084 .04838 L
s
.90494 .06164 m
.91242 .04473 L
s
.93699 .05144 m
.91242 .04473 L
s
.94504 .04887 m
.97333 .03987 L
s
.91242 .04473 m
.90297 .03161 L
s
.97333 .03987 m
.92724 .0238 L
s
.92724 .0238 m
.95572 .01464 L
s
0 g
.25 Mabswid
.00054 .31563 m
.97928 0 L
s
.14421 .2693 m
.14379 .27586 L
s
[(-10)] .14504 .25617 -0.06346 1 Mshowa
.46384 .16622 m
.46383 .1728 L
s
[(0)] .46386 .15307 -0.00199 1 Mshowa
.80927 .05483 m
.80971 .06139 L
s
[(10)] .80838 .04171 .06731 1 Mshowa
.125 Mabswid
.20621 .2493 m
.20601 .25324 L
s
.26915 .229 m
.269 .23295 L
s
.33306 .2084 m
.33295 .21234 L
s
.39794 .18747 m
.39789 .19142 L
s
.53076 .14464 m
.53081 .14858 L
s
.59874 .12272 m
.59884 .12666 L
s
.6678 .10045 m
.66795 .10439 L
s
.73797 .07782 m
.73817 .08176 L
s
.08313 .28899 m
.08283 .29293 L
s
.02295 .3084 m
.02261 .31233 L
s
.88172 .03146 m
.88205 .03539 L
s
.95537 .00771 m
.95575 .01164 L
s
gsave
.4622 .08791 -65.9883 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 206.875},
  ImageMargins->{{7, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3ooom@0?ooo`<0
000000<0oooo000000000000103oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?ooobl0oooo0P00
00040?ooo`800000103oool2000001d0oooo003o0?ooool0oooo;P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000001`0oooo003o0?ooool0oooo;P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo01X0oooo003o0?ooool0oooo:03oool400000080oooo00@0
00000?ooo`3oool000002@3oool2000001d0oooo003o0?ooool0oooo7P3oool3000000d0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0L0?ooo`00o`3ooooo0?oooa/0oooo1P00
000>0?ooo`8000002P3oool3000001`0oooo003o0?ooool0oooo603oool3000000@0oooo0P00000=
0?ooo`800000:P3oool00?l0ooooo`3ooolE0?ooo`<000001@3oool200000080oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?oooa80oooo0`00000:0?oo
o`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?oo
o`h0oooo1@00000=0?ooo`@000002@3oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?oo
o`/0oooo0`0000040?ooo`030000003oool0oooo00`0oooo0`0000090?ooo`040000003oool0oooo
000002T0oooo003o0?ooool0oooo203oool3000001L0oooo0`0000090?ooo`800000:P3oool00?l0
ooooo`3oool50?ooo`<000002@3oool200000140oooo0P00000<0?ooo`800000103oool2000000@0
oooo0P00000J0?ooo`00o`3ooooo0?ooo`80oooo0`0000090?ooo`<00000403oool3000000030?oo
o`000000000000X0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000I0?oo
o`00o`3oooon0?ooo`<000002@3oool3000001D0oooo0P0000000`3oool000000?ooo`090?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`3oool05`3oool00?l0oooon`3oool3000000T0
oooo0`00000I0?ooo`80000000<0oooo0000003oool0203oool010000000oooo0?ooo`0000090?oo
o`8000006P3oool00?l0oooon03oool3000000T0oooo0`00000M0?ooo`<000002@3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01T0oooo003o0?ooooD0oooo0`00000:0?ooo`80
00008@3oool3000000T0oooo0P00000:0?ooo`<000006@3oool00?l0oooolP3oool3000000l0oooo
0`00000P0?ooo`800000<03oool00?l0oooo^P3oool500000080oooo0P00000/0?ooo`<000005@3o
ool2000001/0oooo0`0000000`3oool000000000000_0?ooo`00o`3ooonl0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0U0?ooo`@000006P3oool3000001/0oooo0`00
000_0?ooo`00o`3ooonl0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0R0?ooo`<000002@3oool00`000000oooo0?ooo`0E0?ooo`<00000BP3oool00?l0oooo_03oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07`3oool4000000`0oooo00<0
00000?ooo`3oool05`3oool3000004L0oooo003o0?oook`0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo01`0oooo0`0000040?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool06P3oool3000004@0oooo003o0?oook/0oooo0P0000040?ooo`800000703oool3
000000L0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0L0?ooo`800000@P3oool0
0?l0oooog03oool3000001L0oooo00<000000?ooo`3oool07P3oool3000003l0oooo003o0?ooomT0
oooo0`00000;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0803oool2000003d0
oooo003o0?ooomH0oooo0`00000>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
703oool3000003l0oooo003o0?ooom<0oooo0`00000@0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool06@3oool300000480oooo003o0?ooom00oooo0`00000C0?ooo`030000003oool0
oooo0100oooo0`00000D0?ooo`@00000A@3oool00?l0ooooc@3oool3000001H0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`04000000d0oooo0`0000190?ooo`00o`3oooo90?ooo`@0
00002P3oool2000000`0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`D0
00001P3oool2000004`0oooo003o0?ooolH0oooo0`00000@0?ooo`<000002@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00X0oooo0`00001A0?ooo`00o`3oooo30?ooo`<000005P3o
ool4000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1O0?ooo`00o`3oooo0
0?ooo`<000002@3oool00`000000oooo0?ooo`0A0?ooo`<0000000<0oooo0000003oool04@3oool0
0`000000oooo0?ooo`1O0?ooo`00o`3ooonm0?ooo`@000002`3oool2000001D0oooo0`00000@0?oo
o`030000003oool0oooo0600oooo003o0?oookX0oooo0`0000030?ooo`030000003oool0oooo00X0
oooo0`00000D0?ooo`030000003oool00000008000003@3oool00`000000oooo0?ooo`1P0?ooo`00
o`3ooong0?ooo`<000001`3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool00`3oool4000000P0oooo00<000000?ooo`3oool0H@3oool00?l0oooo
]03oool3000000X0oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool000000140
oooo00<000000?ooo`3oool01`3oool3000000D0oooo00<000000?ooo`3oool0H@3oool00?l0oooo
/@3oool3000000d0oooo0P00000;0?ooo`040000003oool0oooo0?ooo`8000003`3oool00`000000
oooo0?ooo`0:0?ooo`800000I`3oool00?l0oooo[P3oool300000140oooo0`0000090?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1d0?ooo`00o`3o
oon[0?ooo`<00000503oool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1d0?ooo`00o`3ooonW0?ooo`@000005`3o
ool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool01@3oool2000000X0oooo
00<000000?ooo`3oool0M03oool00?l0ooooY03oool3000000T0oooo00<000000?ooo`3oool0403o
ool010000000oooo0?ooo`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo07D0oooo003o0?oooj40oooo0`00000<0?ooo`<00000403o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo07D0oooo003l0?ooo`80000000<0oooo
000000000000W03oool3000000l0oooo00<000000?ooo`3oool00P00000>0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`800000O@3oool0
0?d0oooo00<000000?ooo`000000VP3oool300000180oooo00<000000?ooo`3oool00P3oool20000
00d0oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`1j0?ooo`00oP3oool00`000000oooo0?ooo`2F0?ooo`<000005@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`0000280?ooo`00o03oool2000000030?ooo`000000000009<0oooo0`0000000`3oool0
00000?ooo`0F0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`000000R03oool00?l0ooooTP3oool3000000@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`060?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`<00000
Q`3oool00?l0ooooS`3oool3000000T0oooo2000000>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo08D0oooo003o
0?oooh`0oooo0`0000090?ooo`<00000203oool2000000`0oooo00<000000?ooo`3oool02@3oool2
000000H0oooo00<000000?ooo`3oool0T@3oool00?l0ooooR@3oool3000000X0oooo0P00000=0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool02`3oool2000000D0oooo00<000000?oo
o`3oool0T03oool00?l0ooooQ@3oool4000000`0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`030000003oool0oooo0900
oooo003o0?oooh80oooo0`00000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo09<0oooo003o0?ooogl0oooo0`00
000C0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`2U0?ooo`00o`3oooml0?ooo`<000005`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0Y03oool00?l0ooooN@3oool3000000X0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0Y03oool00?l0ooooMP3oool3000000h0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0Y03oool00?l0oooo
L`3oool300000180oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0Y03oool00?l0ooooL03oool3000001H0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0Y03oool00?l0ooooK@3oool300000080oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0ZP3oool0
0?l0ooooJP3oool3000000D0oooo00<000000?ooo`3oool01P00000?0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0_03oool00?l0ooooI`3oool3000000T0oooo0P0000060?ooo`80
00003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0;/0oooo003o0?ooof<0oooo
100000090?ooo`<000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0^`3oool00?l0ooooH03oool3000000/0oooo0P00000=0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`2j0?ooo`00o`3ooomM
0?ooo`<000003@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2i0?ooo`00o`3ooomJ0?ooo`<00000403oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0b03oool00?l0
ooooE`3oool3000000X0oooo00<000000?ooo`3oool0503oool200000180oooo00<000000?ooo`3o
ool01@3oool200000<00oooo003o0?oooe@0oooo0`00000=0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0400000<80oooo003o0?oooe40oooo0`00
000@0?ooo`030000003oool0oooo0140oooo0P00000E0?ooo`@00000aP3oool00?l0ooooCP3oool3
00000180oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`@00000bP3oool0
0?l0ooooB`3oool3000001D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo0P00003>0?ooo`00o`3ooom80?ooo`<0000000<0oooo0000003o
ool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo0P00000<0?ooo`03
0000003oool0oooo0=@0oooo003o0?ooodD0oooo0`0000040?ooo`800000203oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3D0?ooo`00o`3ooom10?ooo`@000001`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0=D0oooo003o0?oooch0oooo0`00000;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool01`3oool9000000T0oooo00<000000?ooo`3oool01`3oool300000=P0oooo003o0?oo
oc/0oooo0`00000:0?ooo`P000002@3oool00`000000oooo0?ooo`040?ooo`<00000203oool20000
00P0oooo2@00003K0?ooo`00o`3ooolh0?ooo`<000002P3oool3000000<0oooo00<000000?ooo`3o
ool00P3oool2000000P0oooo00<000000?ooo`3oool00`00000=0?ooo`030000003oool0oooo0>T0
oooo003o0?ooocD0oooo0`00000;0?ooo`8000001@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo0`00000@0?ooo`030000003oool0oooo0>T0oooo003o0?oooc80oooo0`00
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0>T0oooo003o0?ooo`800000;@3oool300000100oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0jP3oool00?h0oooo00@000000?ooo`3oool00000:@3oool3000001<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0j`3oool00?h0oooo00@000000?ooo`3oool000009P3oool3000001H0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo0`00003^
0?ooo`00oP3oool010000000oooo0?ooo`00000S0?ooo`<000006@3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool0oooo1@00003a0?ooo`00oP3oool0
10000000oooo0?ooo`00000P0?ooo`@00000703oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00L0oooo0`00003f0?ooo`00o`3oool2000001d0oooo100000030?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooo`40oooo003o0?oo
oa`0oooo0`00000:0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`3o0?ooo`80oooo003o0?oooaT0oooo0`00000>0?ooo`030000003oool0oooo01P0
oooo0P00000>0?ooo`030000003oool0oooo0?l0oooo0P3oool00?l0oooo5P3oool300000180oooo
00<000000?ooo`3oool06@3oool2000000/0oooo00<000000?ooo`3oool0o`3oool30?ooo`00o`3o
oolC0?ooo`<000005P3oool00`000000oooo0?ooo`070?ooo`P000002`3oool3000000H0oooo0P00
003o0?ooo`H0oooo003o0?oooa00oooo0`0000080?ooo`P000002@3oool00`000000oooo0?ooo`04
0?ooo`<00000203oool2000000`0oooo1P00003o0?ooo`P0oooo003o0?ooo`d0oooo0`0000080?oo
o`<00000203oool2000000P0oooo00<000000?ooo`3oool00`00000<0?ooo`030000003oool0oooo
0?l0oooo603oool00?l0oooo2P3oool3000000X0oooo00<000000?ooo`3oool02`3oool2000000L0
oooo0P00000@0?ooo`030000003oool0oooo0?l0oooo5`3oool00?l0oooo1`3oool3000000`0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0o`3ooolG0?ooo`00o`3oool40?ooo`<000003`3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`3o0?oooaL0oooo003o0?ooo`40oooo0`0000070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo0P00003o
0?oooaX0oooo003l0?ooo`D000002@3oool2000000T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo0P00003o0?oooa`0oooo003i0?ooo`<0
0000103oool00`000000oooo0?ooo`070?ooo`030000003oool0000000P0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo0`00003o0?oooah0
oooo003f0?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?ooo`00
0000203oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00`00003o0?ooob40oooo003c0?ooo`<000002P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00L0oooo0P00003o0?ooob@0oooo003`0?ooo`<000002@3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0?l0oooo;P3oool00>d0oooo0`00000=0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`050?ooo`8000003P3oool0
0`000000oooo0?ooo`3o0?ooobh0oooo003Z0?ooo`<000004@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool01`3oool2000000/0oooo00<000000?oo
o`3oool0o`3oool_0?ooo`00i`3oool3000000X0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool3000000H0
oooo0P00003o0?oooc80oooo003T0?ooo`<000003P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`H00000
o`3ooold0?ooo`00h@3oool3000000P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`3o0?oood<0oooo003N0?ooo`<000002`3oool3000000P0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooom2
0?ooo`00fP3oool4000000l0oooo00@000000?ooo`00000000001`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o
0?oood40oooo003G0?ooo`<000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00H0oooo00@000000?ooo`3oool0oooo0P0000060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0oooo@03oool0
0=@0oooo0`0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`030?ooo`800000103oool00`000000oooo0?ooo`080?ooo`050000003oool0oooo
0?ooo`000000o`3ooom@0?ooo`00d@3oool3000000P0oooo0P0000080?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool01@3oool2000000<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0000003o0?oooe40oooo003>0?ooo`<00000203oool3000000/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`060?ooo`8000000P3oool00`000000oooo0?ooo`080?ooo`80
0000o`3ooomA0?ooo`00b`3oool3000000P0oooo0`00000?0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0
o`3ooom?0?ooo`00b03oool3000000P0oooo0`00000C0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool02P3oool300000?l0ooooF`3oool00<D0oooo0`0000090?ooo`8000005`3oool0
1@000000oooo0?ooo`3oool0000000h0oooo0P00003o0?oooeX0oooo00320?ooo`<000003@3oool0
0`000000oooo0?ooo`0F0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`000000oooo0?oo
o`3o0?oooeL0oooo002o0?ooo`<000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo01H0oooo00@000000?ooo`3oool00000o`3ooomY0?ooo`00_03oool3000000`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool000000?l0ooooJ@3oool0
0;P0oooo1000000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05P3oool20000
0?l0ooooJ@3oool00;D0oooo1000000A0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05P3oool200000?l0ooooJ03oool00;80oooo0`0000030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0o`3ooomV0?ooo`00[`3oool3000000`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooOP3oool00:`0oooo0`00000@
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o
0?ooogd0oooo002Y0?ooo`<00000503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0o`3oooml0?ooo`00YP3oool3000000P0oooo1`0000090?ooo`<0
00001@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooN`3oool00:<0oooo
0`0000090?ooo`8000001`3oool2000000P0oooo00<000000?ooo`0000001@00000B0?ooo`030000
003oool0oooo0?l0ooooNP3oool00:00oooo0`00000<0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`030?ooo`H000003P3oool00`000000oooo0?oo
o`3o0?ooogT0oooo002M0?ooo`<000001`3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`H00000o`3ooon4
0?ooo`00VP3oool3000000/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool03@3oool300000?l0ooooP@3oool009H0
oooo1000000?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0?l0ooooT03oool009<0oooo0`0000090?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0o`3ooon?0?ooo`00T03oool3000000030?ooo`00
0000oooo00X0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00S@3oool3000000@0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooohd0oooo002:0?ooo`<000005@3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooonE0?oo
o`00Q`3oool3000000P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooonD0?ooo`00Q03oool3000000`0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
Y`3oool00840oooo0`00000@0?ooo`030000003oool0oooo00d0oooo0P00000:0?ooo`030000003o
ool0oooo0?l0ooooYP3oool004h0oooo1@0000020?ooo`8000009`3oool3000001@0oooo00<00000
0?ooo`3oool02@3oool300000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?ooojD0oooo001@0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Q
0?ooo`<000001`3oool8000000T0oooo00<000000?ooo`3oool0103oool4000000H0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooj@0oooo001@0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0N0?ooo`<000001`3oool3000000P0oooo0P000008
0?ooo`030000003oool0oooo00<000002`3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0ooooX`3oool004P0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0J0?ooo`@000002@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00H0oooo0P00000?0?ooo`030000003oool0oooo0?l0oooo[@3oool00500oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01L0oooo0`00000<0?ooo`030000003oool0
oooo00/0oooo0`0000080?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon/
0?ooo`00C`3oool2000000@0oooo0P00000G0?ooo`@000003P3oool00`000000oooo0?ooo`080?oo
o`<00000303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooZ`3oool006/0
oooo0`0000030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`3o0?oook/0oooo001X0?ooo`<000005@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo0?l0oooo^P3oool006D0oooo0`00000H0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oookT0oooo001R0?ooo`<000001P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`3o0?oookP0oooo001O0?ooo`<000002P3oool00`000000oooo0?ooo`0C0?oo
o`800000403oool00`000000oooo0?ooo`3o0?oool80oooo001L0?ooo`<000001P3oool2000000H0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0
oooo`P3oool005T0oooo0`0000060?ooo`<000002@3oool00`000000oooo0?ooo`0D0?ooo`800000
3@3oool00`000000oooo0?ooo`3o0?oool80oooo001F0?ooo`<000001@3oool4000000d0oooo00<0
00000?ooo`3oool01P3oool2000000d0oooo00<000000?ooo`3oool01`3oool300000?l0ooooa@3o
ool00580oooo100000050?ooo`<000004P3oool00`000000oooo0?ooo`030?ooo`800000403oool9
00000?l0oooob03oool004l0oooo0`0000070?ooo`8000005P3oool2000000030?ooo`0000000000
0?l0ooooh`3oool004`0oooo1000000:0?ooo`030000003oool0oooo01D0oooo0P00003o0?ooonD0
oooo00190?ooo`<000000`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0303oool200000?l0ooooe03oool004H0oooo0`0000060?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`<00000o`3o
oooF0?ooo`00@`3oool3000000H0oooo1P00000;0?ooo`030000003oool0oooo00H0oooo0P00000>
0?ooo`030000003oool0oooo00@0oooo0`00003o0?ooomT0oooo00100?ooo`<000001`3oool20000
00H0oooo100000080?ooo`040000003oool0oooo0?ooo`@000004@3oool00`000000oooo0?ooo`03
00000?l0oooog03oool003d0oooo0`0000080?ooo`800000303oool2000000L0oooo0`00000F0?oo
o`800000o`3ooooO0?ooo`00>P3oool3000000T0oooo0P00000@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0o`3ooooe0?ooo`00=`3oool3000000d0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo0P00003o0?ooonH0oooo
000d0?ooo`<000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0203oool300000?l0ooooj03oool00300oooo100000070?ooo`L000001`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0103oool3
00000?l0ooooj`3oool002d0oooo0`0000080?ooo`<000001`3oool2000000H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00<00000o`3oooo^0?oo
o`00:P3oool4000000T0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00P0oooo0P00003o0?oooo40oooo000W0?ooo`<000000`3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01<0oooo0P00000>0?ooo`030000003oool0oooo0?l0oooo
nP3oool002@0oooo0`00000?0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`3o0?oooo/0oooo000Q0?ooo`<000004P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooook0?ooo`007P3oool30000
00D0oooo1`0000090?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool30000
0?l0oooooP3oool001/0oooo0`0000060?ooo`8000001`3oool2000000P0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@00000o`3ooooo0?ooo`80
oooo000H0?ooo`<000001P3oool3000000/0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00D0oooo0P00003o0?ooool0oooo1P3oool001D0oooo0`00
00070?ooo`8000003`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`d0oooo000B0?ooo`<000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01`3oool2000000d0oooo00<00000
0?ooo`3oool0o`3ooooo0?ooo`h0oooo000>0?ooo`@000002@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool2000000X0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`l0oooo000;0?ooo`<000003P3oool00`000000oooo0?ooo`030?ooo`80
00002@3oool7000000X0oooo0`0000050?ooo`800000o`3ooooo0?oooa80oooo00080?ooo`<00000
00<0oooo0000003oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo
0P0000070?ooo`8000002`3oool500000?l0ooooo`3ooolD0?ooo`001@3oool3000000@0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<000002`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo8@3oool00080oooo0`0000080?ooo`8000003@3oool2
000000P0oooo0P00000>0?ooo`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`000P00000=0?oo
o`800000203oool300000080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0ooooo`3ooolQ0?ooo`004@3oool2000000<0oooo0`0000050?ooo`03
0000003oool0oooo00L0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooolR0?ooo`00
4`3oool3000000P0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`060?ooo`800000
o`3ooooo0?ooobD0oooo000E0?ooo`800000203oool00`000000oooo0?ooo`090?ooo`040000003o
ool0oooo0?ooo`@00000o`3ooooo0?ooobL0oooo000G0?ooo`<000001@3oool00`000000oooo0?oo
o`0:0?ooo`<00000o`3ooooo0?ooob/0oooo000J0?ooo`800000103oool00`000000oooo0?ooo`3o
0?ooool0oooo=`3oool001`0oooo0P0000020?ooo`030000003oool0oooo0?l0ooooo`3ooolg0?oo
o`007P3oool2000000030?ooo`000000oooo0?l0ooooo`3ooolg0?ooo`00803oool200000?l0oooo
o`3ooolh0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {205.875, 0}} -> {0.0494824, 0.301488, \
0.00171789, 0.00171789}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<abcdefghijklmnopqrstuvwxyz\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35436 
%%ImageSize: 600 212.616 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0498163 1.04982 -0.336555 1.04982 [
[.09072 .27166 -8.32646 -9 ]
[.09072 .27166 9.67354 0 ]
[.45766 .15262 -2.98957 -9 ]
[.45766 .15262 3.01043 0 ]
[.85951 .02232 -6.472 -9 ]
[.85951 .02232 5.528 0 ]
[.45788 .08701 -4.98262 -12.75 ]
[.45788 .08701 5.01738 0 ]
[.98988 .00679 0 -5.94908 ]
[.98988 .00679 24 3.05092 ]
[.99865 .01957 0 -5.94128 ]
[.99865 .01957 6 3.05872 ]
[1.00734 .03224 0 -5.93355 ]
[1.00734 .03224 18 3.06645 ]
[1.05969 -0.00256 0 -8.41863 ]
[1.05969 -0.00256 10 4.33137 ]
[ 0 0 0 0 ]
[ 1 .35436 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00063 .31357 m
.96997 0 L
s
.08974 .28475 m
.08925 .29129 L
s
[(-10)] .09072 .27166 -0.07484 1 Mshowa
.45761 .16574 m
.45759 .1723 L
s
[(0)] .45766 .15262 -0.00348 1 Mshowa
.86054 .0354 m
.86106 .04194 L
s
[(10)] .85951 .02232 .07867 1 Mshowa
.125 Mabswid
.16073 .26178 m
.16049 .26571 L
s
.23298 .23841 m
.23279 .24234 L
s
.30652 .21462 m
.30639 .21855 L
s
.38138 .1904 m
.38131 .19434 L
s
.53524 .14063 m
.53529 .14457 L
s
.6143 .11505 m
.61441 .11899 L
s
.69485 .089 m
.69502 .09293 L
s
.77691 .06245 m
.77715 .06638 L
s
.01997 .30732 m
.01962 .31124 L
s
.94578 .00782 m
.94616 .01174 L
s
gsave
.45788 .08701 -65.9826 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.96997 0 m
.99923 .04263 L
s
.97739 .01081 m
.97114 .01282 L
s
[(-0.5)] .98988 .00679 -1 .32202 Mshowa
.98615 .02357 m
.9799 .02557 L
s
[(0)] .99865 .01957 -1 .32028 Mshowa
.99483 .03623 m
.98858 .03822 L
s
[(0.5)] 1.00734 .03224 -1 .31857 Mshowa
.125 Mabswid
.97915 .01337 m
.9754 .01458 L
s
.9809 .01593 m
.97715 .01713 L
s
.98265 .01848 m
.97891 .01968 L
s
.9844 .02103 m
.98065 .02223 L
s
.98789 .02611 m
.98414 .02731 L
s
.98963 .02865 m
.98588 .02985 L
s
.99137 .03118 m
.98762 .03238 L
s
.9931 .03371 m
.98935 .0349 L
s
.97563 .00824 m
.97188 .00945 L
s
.97386 .00567 m
.97011 .00688 L
s
.97209 .00309 m
.96835 .0043 L
s
.97032 .00051 m
.96658 .00172 L
s
.99656 .03874 m
.99281 .03994 L
s
.99829 .04126 m
.99454 .04245 L
s
gsave
1.05969 -0.00256 -61 -12.4186 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35436 L
0 .35436 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05312 .33184 m
.04679 .33081 L
s
.05817 .33175 m
.05312 .33184 L
s
.06387 .32993 m
.05817 .33175 L
s
.09357 .33109 m
.06715 .30741 L
s
.04679 .33081 m
.04109 .32806 L
s
.06641 .3276 m
.06387 .32993 L
s
.04109 .32806 m
.03855 .32582 L
s
.06769 .32414 m
.06641 .3276 L
s
.07147 .3275 m
.05375 .31172 L
s
.03855 .32582 m
.03662 .32184 L
s
.03662 .32184 m
.03787 .31837 L
s
.08738 .3209 m
.09246 .32081 L
s
.08105 .31987 m
.08738 .3209 L
s
.09246 .32081 m
.0982 .31898 L
s
.0982 .31898 m
.10079 .31663 L
s
.03787 .31837 m
.0404 .31601 L
s
.10079 .31663 m
.10212 .31314 L
s
.0404 .31601 m
.04611 .31418 L
s
.0512 .31408 m
.05757 .31512 L
s
.04611 .31418 m
.0512 .31408 L
s
.10212 .31314 m
.10029 .30912 L
s
.07225 .30732 m
.07095 .31082 L
s
.10029 .30912 m
.09778 .30684 L
s
.1258 .30864 m
.11945 .3076 L
s
.1309 .30855 m
.1258 .30864 L
s
.1367 .3067 m
.1309 .30855 L
s
.11945 .3076 m
.11377 .3048 L
s
.07482 .30494 m
.07225 .30732 L
s
.09778 .30684 m
.09207 .30404 L
s
.13933 .30433 m
.1367 .3067 L
s
.08059 .30309 m
.07482 .30494 L
s
.11377 .3048 m
.11127 .30252 L
s
.14073 .3008 m
.13933 .30433 L
s
.09207 .30404 m
.0857 .30299 L
s
.0857 .30299 m
.08059 .30309 L
s
.11127 .30252 m
.10944 .29847 L
s
.18804 .30109 m
.16218 .27685 L
s
.10944 .29847 m
.1108 .29493 L
s
.16069 .29751 m
.15433 .29646 L
s
.16582 .29742 m
.16069 .29751 L
s
.17166 .29555 m
.16582 .29742 L
s
.15433 .29646 m
.14866 .29363 L
s
.17434 .29316 m
.17166 .29555 L
s
.1108 .29493 m
.11342 .29253 L
s
.14866 .29363 m
.14618 .29133 L
s
.17579 .2896 m
.17434 .29316 L
s
.11342 .29253 m
.11924 .29066 L
s
.12438 .29056 m
.13077 .29162 L
s
.14618 .29133 m
.1444 .28724 L
s
.11924 .29066 m
.12438 .29056 L
s
.1444 .28724 m
.14581 .28368 L
s
.19784 .28565 m
.19147 .28459 L
s
.20299 .28556 m
.19784 .28565 L
s
.2089 .28368 m
.20299 .28556 L
s
.19147 .28459 m
.18582 .28174 L
s
.21162 .28126 m
.2089 .28368 L
s
.14581 .28368 m
.14847 .28126 L
s
.24379 .28184 m
.23819 .27898 L
s
.24895 .28174 m
.24379 .28184 L
s
.25291 .28048 m
.24895 .28174 L
s
.18582 .28174 m
.18336 .27942 L
s
.18582 .28174 m
.20946 .27418 L
s
.14847 .28126 m
.15434 .27937 L
s
.21237 .27947 m
.21162 .28126 L
s
.1595 .27927 m
.16591 .28034 L
s
.2119 .27651 m
.21237 .27947 L
s
.18336 .27942 m
.18162 .27529 L
s
.15434 .27937 m
.1595 .27927 L
s
.23819 .27898 m
.2175 .25906 L
s
.22863 .27738 m
.2425 .27296 L
s
.20946 .27418 m
.2119 .27651 L
s
.18162 .27529 m
.18309 .27169 L
s
.18309 .27169 m
.1858 .26925 L
s
.1858 .26925 m
.19173 .26735 L
s
.19691 .26725 m
.20333 .26833 L
s
.19173 .26735 m
.19691 .26725 L
s
.2572 .26671 m
.2508 .26564 L
s
.26239 .26661 m
.2572 .26671 L
s
.26838 .26471 m
.26239 .26661 L
s
.2508 .26564 m
.24518 .26274 L
s
.30074 .26529 m
.2756 .24038 L
s
.27117 .26225 m
.26838 .26471 L
s
.24518 .26274 m
.24275 .26039 L
s
.27277 .25862 m
.27117 .26225 L
s
.27638 .26216 m
.25706 .24317 L
s
.24275 .26039 m
.2411 .2562 L
s
.2411 .2562 m
.24266 .25255 L
s
.34018 .25433 m
.33698 .25378 L
s
.34103 .2525 m
.34018 .25433 L
s
.29725 .25393 m
.30247 .25383 L
s
.28763 .2523 m
.29725 .25393 L
s
.30247 .25383 m
.30852 .2519 L
s
.33698 .25378 m
.33783 .25195 L
s
.24266 .25255 m
.24545 .25007 L
s
.33783 .25195 m
.34103 .2525 L
s
.30852 .2519 m
.31136 .24943 L
s
.24545 .25007 m
.25146 .24814 L
s
.31136 .24943 m
.30981 .24521 L
s
.25669 .24804 m
.26313 .24913 L
s
.25146 .24814 m
.25669 .24804 L
s
.36045 .24789 m
.35725 .24735 L
s
.36132 .24605 m
.36045 .24789 L
s
.35725 .24735 m
.35812 .24551 L
s
.35812 .24551 m
.36132 .24605 L
s
.30981 .24521 m
.29785 .23322 L
s
.33076 .24481 m
.3141 .22799 L
s
.23689 .24172 m
.23411 .24421 L
s
.25706 .24317 m
.25139 .24023 L
s
.37354 .24217 m
.34886 .21682 L
s
.24292 .23978 m
.23689 .24172 L
s
.25139 .24023 m
.24816 .23968 L
s
.24816 .23968 m
.24292 .23978 L
s
.35108 .23833 m
.33094 .21778 L
s
.41042 .23046 m
.38599 .20488 L
s
.38586 .22724 m
.3536 .22168 L
s
.36652 .22391 m
.37151 .20953 L
s
.33094 .21778 m
.3253 .21478 L
s
.41886 .21671 m
.40259 .19954 L
s
.32001 .21488 m
.31591 .21621 L
s
.3253 .21478 m
.32001 .21488 L
s
.42392 .21351 m
.42922 .21341 L
s
.41423 .21183 m
.42392 .21351 L
s
.42922 .21341 m
.43545 .21142 L
s
.43545 .21142 m
.43847 .20887 L
s
.43847 .20887 m
.4371 .20452 L
s
.4468 .20621 m
.45212 .20611 L
s
.4371 .20452 m
.4468 .20621 L
s
.45212 .20611 m
.45838 .20411 L
s
.4371 .20452 m
.42553 .19216 L
s
.45838 .20411 m
.46142 .20154 L
s
.46142 .20154 m
.46009 .19717 L
s
.46009 .19717 m
.4486 .18474 L
s
.48144 .19676 m
.46545 .17932 L
s
.48661 .1935 m
.49196 .1934 L
s
.47689 .1918 m
.48661 .1935 L
s
.49196 .1934 m
.49828 .19138 L
s
.49828 .19138 m
.50137 .18879 L
s
.50137 .18879 m
.5001 .18438 L
s
.5001 .18438 m
.48873 .17184 L
s
.52468 .18136 m
.51818 .18021 L
s
.53004 .18125 m
.52468 .18136 L
s
.53643 .17922 m
.53004 .18125 L
s
.51818 .18021 m
.51268 .17713 L
s
.53957 .1766 m
.53643 .17922 L
s
.51268 .17713 m
.51042 .17462 L
s
.5416 .17273 m
.53957 .1766 L
s
.51042 .17462 m
.50915 .17015 L
s
.54039 .16826 m
.5416 .17273 L
s
.55991 .17173 m
.53639 .145 L
s
.50915 .17015 m
.51115 .16626 L
s
.56308 .1691 m
.56848 .169 L
s
.55658 .16794 m
.56308 .1691 L
s
.56848 .169 m
.57492 .16694 L
s
.53815 .16573 m
.54039 .16826 L
s
.57492 .16694 m
.57811 .16431 L
s
.51115 .16626 m
.51428 .16362 L
s
.53264 .16262 m
.53815 .16573 L
s
.57811 .16431 m
.58021 .16039 L
s
.51428 .16362 m
.52069 .16156 L
s
.5261 .16145 m
.53264 .16262 L
s
.52069 .16156 m
.5261 .16145 L
s
.58021 .16039 m
.57905 .15589 L
s
.54971 .15386 m
.54765 .1578 L
s
.57905 .15589 m
.57684 .15333 L
s
.60616 .15535 m
.59964 .15418 L
s
.61159 .15525 m
.60616 .15535 L
s
.61809 .15317 m
.61159 .15525 L
s
.59964 .15418 m
.59418 .15104 L
s
.55289 .1512 m
.54971 .15386 L
s
.57684 .15333 m
.57135 .15019 L
s
.62135 .15051 m
.61809 .15317 L
s
.55936 .14912 m
.55289 .1512 L
s
.59418 .15104 m
.59198 .14848 L
s
.62352 .14656 m
.62135 .15051 L
s
.62678 .1504 m
.60374 .12326 L
s
.57135 .15019 m
.5648 .14902 L
s
.5648 .14902 m
.55936 .14912 L
s
.59198 .14848 m
.59083 .14393 L
s
.64203 .14554 m
.62679 .12744 L
s
.59083 .14393 m
.59296 .13996 L
s
.6475 .14216 m
.65295 .14206 L
s
.64096 .14098 m
.6475 .14216 L
s
.65295 .14206 m
.65952 .13996 L
s
.63552 .13781 m
.64096 .14098 L
s
.59296 .13996 m
.59621 .13727 L
s
.59621 .13727 m
.60274 .13517 L
s
.60821 .13506 m
.61477 .13625 L
s
.60274 .13517 m
.60821 .13506 L
s
.67161 .13447 m
.66726 .13258 L
s
.67928 .13366 m
.67161 .13447 L
s
.68588 .13155 m
.67928 .13366 L
s
.66726 .13258 m
.66731 .12928 L
s
.69144 .12814 m
.68588 .13155 L
s
.722 .1315 m
.70402 .10926 L
s
.66731 .12928 m
.67064 .12657 L
s
.69151 .12483 m
.69144 .12814 L
s
.67064 .12657 m
.68061 .12173 L
s
.70798 .12451 m
.72351 .11955 L
s
.65868 .11884 m
.65864 .12217 L
s
.68061 .12173 m
.68396 .11901 L
s
.68396 .11901 m
.68403 .11567 L
s
.66422 .1154 m
.65868 .11884 L
s
.68403 .11567 m
.68295 .11436 L
s
.67086 .11327 m
.66422 .1154 L
s
.73687 .11529 m
.72634 .1021 L
s
.68295 .11436 m
.67859 .11244 L
s
.67859 .11244 m
.67086 .11327 L
s
.70402 .10926 m
.70304 .10458 L
s
.76147 .10745 m
.74682 .08884 L
s
.70304 .10458 m
.70644 .10182 L
s
.77494 .10315 m
.77395 .08012 L
s
.72634 .1021 m
.7254 .0974 L
s
.70644 .10182 m
.71091 .10039 L
s
.7254 .0974 m
.72883 .09463 L
s
.72883 .09463 m
.73556 .09246 L
s
.80202 .09451 m
.77395 .08012 L
s
.74112 .09235 m
.75102 .09418 L
s
.73556 .09246 m
.74112 .09235 L
s
.81335 .0909 m
.80809 .06913 L
s
.83154 .0851 m
.82641 .06324 L
s
.83154 .0851 m
.80809 .06913 L
s
.84981 .07927 m
.82641 .06324 L
s
.86356 .07489 m
.87487 .04766 L
s
.88888 .06681 m
.84942 .05584 L
s
.90043 .06313 m
.90047 .03943 L
s
.92829 .05424 m
.90047 .03943 L
s
.93995 .05053 m
.9657 .04231 L
s
.9657 .04231 m
.92621 .03115 L
s
.90047 .03943 m
.8918 .03538 L
s
.8918 .03538 m
.88512 .03411 L
s
.87944 .03422 m
.87711 .03498 L
s
.88512 .03411 m
.87944 .03422 L
s
.92621 .03115 m
.9521 .02282 L
s
0 g
.25 Mabswid
.00063 .31357 m
.96997 0 L
s
.08974 .28475 m
.08925 .29129 L
s
[(-10)] .09072 .27166 -0.07484 1 Mshowa
.45761 .16574 m
.45759 .1723 L
s
[(0)] .45766 .15262 -0.00348 1 Mshowa
.86054 .0354 m
.86106 .04194 L
s
[(10)] .85951 .02232 .07867 1 Mshowa
.125 Mabswid
.16073 .26178 m
.16049 .26571 L
s
.23298 .23841 m
.23279 .24234 L
s
.30652 .21462 m
.30639 .21855 L
s
.38138 .1904 m
.38131 .19434 L
s
.53524 .14063 m
.53529 .14457 L
s
.6143 .11505 m
.61441 .11899 L
s
.69485 .089 m
.69502 .09293 L
s
.77691 .06245 m
.77715 .06638 L
s
.01997 .30732 m
.01962 .31124 L
s
.94578 .00782 m
.94616 .01174 L
s
gsave
.45788 .08701 -65.9826 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 212.563},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000e2000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3ooolL0?ooo`8000004P3oool2000000@0oooo0P0000040?oo
o`800000703oool00?l0ooooo`3ooolI0?ooo`@0000000<0oooo0000003oool03`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000001/0oooo003o0?ooool0oooo5P3oool30000
00D0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo01T0oooo003o0?ooool0oooo4`3oool3000000H0oooo0P0000000`3oool000000?ooo`080?oo
o`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000703oool00?l0ooooo`3oool@0?oo
o`<000002P3oool2000000030?ooo`000000oooo00d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0K0?ooo`00o`3ooooI0?ooo`D000000P3oool2000002T0oooo1000000>0?oo
o`<000003`3oool2000000X0oooo0`00000K0?ooo`00o`3ooooK0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0S0?ooo`<000000`3oool00`000000oooo0?ooo`0>0?oo
o`800000>03oool00?l0oooof`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0803oool3000000H0oooo00<000000?ooo`3oool02`3oool300000080oooo00<000000?oo
o`3oool02P3oool2000002T0oooo003o0?ooom/0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01d0oooo0`00000J0?ooo`<000002`3oool010000000oooo0?ooo`00000X
0?ooo`00o`3ooooK0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J
0?ooo`<00000803oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000002P0oooo003o
0?ooomX0oooo0P0000040?ooo`8000006P3oool300000240oooo0P0000000`3oool000000?ooo`08
0?ooo`040000003oool0oooo000002P0oooo003o0?ooooT0oooo0`00000U0?ooo`<000002@3oool0
10000000oooo0?ooo`00000X0?ooo`00o`3oooof0?ooo`<00000:`3oool00`000000oooo0?ooo`07
0?ooo`800000:@3oool00?l0ooool`3oool3000001/0oooo0P00000?0?ooo`@00000<`3oool00?l0
ooool03oool3000001X0oooo1000000@0?ooo`<0000000<0oooo0000003oool02`3oool2000000@0
oooo0P0000040?ooo`8000006@3oool00?l0ooook03oool4000001T0oooo1000000G0?ooo`<00000
2P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001P0oooo003o0?ooonT0
oooo0`00000I0?ooo`@000007@3oool2000000T0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0?ooo`0F0?ooo`00o`3ooooV0?ooo`<000006P3oool2000001l0oooo0P0000000`3oool0
0000000000080?ooo`040000003oool0oooo000000T0oooo0P00000I0?ooo`00o`3ooooS0?ooo`<0
00007`3oool3000001d0oooo0P0000000`3oool000000?ooo`070?ooo`040000003oool0oooo0000
00T0oooo00<000000?ooo`3oool0603oool00?l0ooooh03oool3000000H0oooo1@00000J0?ooo`<0
00007@3oool2000000P0oooo0P00000:0?ooo`<00000603oool00?l0oooog@3oool3000000P0oooo
00<000000?ooo`3oool00`3oool4000001T0oooo0`00000H0?ooo`@00000;`3oool00?l0oooofP3o
ool300000080oooo00<000000?ooo`3oool0403oool2000001X0oooo1000000D0?ooo`8000000P3o
ool00`000000oooo0?ooo`0/0?ooo`00o`3ooooG0?ooo`<000001@3oool00`000000oooo0?ooo`0B
0?ooo`800000703oool3000001<0oooo1000000]0?ooo`00o`3ooooD0?ooo`<00000203oool00`00
0000oooo0?ooo`0C0?ooo`<000007@3oool3000001<0oooo00<000000?ooo`3oool0:`3oool00?l0
ooood@3oool300000240oooo00<000000?ooo`3oool00P00000N0?ooo`8000003`3oool200000003
0?ooo`000000oooo02/0oooo003o0?ooolh0oooo0`00000T0?ooo`030000003oool0oooo0080oooo
0P00000H0?ooo`@00000@@3oool00?l0oooobP3oool4000002L0oooo00<000000?ooo`3oool0103o
ool2000001<0oooo0`0000150?ooo`00o`3oooo70?ooo`<000007@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00H0oooo0P00000=0?ooo`@00000B03oool00?l0ooooa03oool30000
0200oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`080?ooo`8000002@3oool20000
04`0oooo003o0?oool40oooo0`00000R0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool02P3oool2000005D0oooo003o0?oookh0oooo0`00000U0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1B0?ooo`00o`3ooonk0?ooo`<000006`3o
ool2000000X0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Q0?ooo`00o`3ooonh
0?ooo`<00000803oool4000000H0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1Q
0?ooo`00o`3ooone0?ooo`<000009`3oool4000000030?ooo`000000oooo00l0oooo00<000000?oo
o`3oool0H@3oool00?l0oooo/P3oool3000002h0oooo0`00000?0?ooo`030000003oool0oooo0640
oooo003o0?ooojl0oooo0`00000J0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1000000;0?ooo`030000003oool0oooo0640oooo003o0?oooj/0oooo100000000`3oool000000?oo
o`0J0?ooo`<00000503oool00`000000oooo0?ooo`040?ooo`@00000J`3oool00?l0ooooZ03oool3
000000D0oooo00<000000?ooo`3oool06@3oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo00T0oooo0P00001Y0?ooo`00o`3ooonU0?ooo`<000009@3oool00`000000oooo0?ooo`02
00000100oooo00<000000?ooo`3oool0M03oool00?l0ooooXP3oool3000001d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0M@3oool00?l0ooooW`3oool300000200oooo0`0000080?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1e0?ooo`00n`3oool2000000030?oo
o`000000000009/0oooo0`00000S0?ooo`030000003oool0oooo008000001P3oool00`000000oooo
0?ooo`040?ooo`8000002P3oool00`000000oooo0?ooo`1f0?ooo`00o03oool00`000000oooo0000
002I0?ooo`<000009`3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo07H0oooo003m0?ooo`030000003o
ool0oooo09D0oooo0`00000Z0?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003o
ool0oooo00H0oooo0P0000200?ooo`00n`3oool2000000030?ooo`00000000000980oooo0`00000]
0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`030000003o
ool0oooo07d0oooo003o0?oooi00oooo0`00000L0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool01@3oool2000000030?ooo`000000oooo08T0oooo003o0?oooh`0oooo1000000O0?oo
o`<000004P3oool00`000000oooo0?ooo`060?ooo`<00000R@3oool00?l0ooooR@3oool3000002<0
oooo00<000000?ooo`3oool00P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0Q`3oool00?l0ooooQP3oool3000002H0oooo00<000000?ooo`3oool00P3oool2000000h0oooo
00<000000?ooo`3oool0TP3oool00?l0ooooP`3oool3000002T0oooo00<000000?ooo`3oool0103o
ool2000000`0oooo00<000000?ooo`3oool0TP3oool00?l0ooooP03oool4000001`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`8000002`3oool00`000000oooo0?ooo`2A
0?ooo`00o`3ooomm0?ooo`<000000`3oool00`000000oooo0?ooo`0E0?ooo`<000000`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`030000003oool0oooo
0940oooo003o0?ooogX0oooo0`0000060?ooo`030000003oool0oooo0180oooo0`0000030?ooo`<0
000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`0:0?ooo`800000V`3oool00?l0oooo
M`3oool3000001`0oooo0P0000090?ooo`800000303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo09P0oooo003o0?ooog@0oooo0`00000M0?ooo`8000003@3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0:L0oooo003o0?ooog40oooo0`00000P0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2W0?ooo`00o`3ooom]0?oo
o`@000006P3oool2000000L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0:L0oooo003o0?ooofX0oooo0`00000L0?ooo`8000002@3oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0Y`3oool00?l0oooo
I`3oool3000001d0oooo0P00000<0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
/03oool00?l0ooooI03oool300000200oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0:l0oooo003o0?ooof40oooo0`00000T0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`2^0?ooo`00o`3ooomN0?oo
o`<000009`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0;l0oooo003o0?oooe/0
oooo0`00000[0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0_P3oool00?l0oooo
F03oool3000001T0oooo1`00000?0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
_@3oool00?l0ooooE@3oool3000001X0oooo0P0000070?ooo`<00000303oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0;`0oooo003o0?oooe80oooo0`0000000`3oool000000?ooo`0H
0?ooo`8000002`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0</0oooo003o0?oo
odl0oooo0`0000040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0<X0oooo003o0?oood/0oooo1000000P0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`3oool30000
0<D0oooo003o0?ooodP0oooo0`00000T0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03`3oool400000<P0oooo003o0?ooodD0oooo0`0000080?ooo`030000003oool0oooo02H0oooo
0P00000?0?ooo`<000000P3oool00`000000oooo0?ooo`370?ooo`00o`3ooom20?ooo`<00000303o
ool00`000000oooo0?ooo`0S0?ooo`800000203oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0<L0oooo003o0?ooocl0oooo0`00000@0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool05@3oool2000000X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`36
0?ooo`00o`3oooll0?ooo`<00000503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0180oooo0P00000:0?ooo`800000403oool00`000000oooo0?ooo`350?ooo`00o`3oooli0?ooo`<0
00005`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool01`3oool2000001<0oooo00<000000?ooo`3oool0a03oool00?l0oooo=P3oool3000001/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0A0?ooo`800000103oool400000=`0oooo
003o0?oooc<0oooo0`00000I0?ooo`L000002P3oool00`000000oooo0?ooo`0B0?ooo`@00000h03o
ool00?l0oooo<03oool3000001T0oooo0`0000060?ooo`8000002P3oool00`000000oooo0?ooo`3e
0?ooo`00o@3oool2000002`0oooo1000000K0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`3d0?ooo`00o03oool010000000oooo0?ooo`00000X0?oo
o`<000007P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00P0oooo0P0000090?oo
o`800000j@3oool00?`0oooo00@000000?ooo`3oool000009@3oool3000000030?ooo`000000oooo
01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`030000003oool00000
00P00000j`3oool00?`0oooo00@000000?ooo`3oool000008P3oool3000000@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0lP3oool00?`0oooo00@000000?ooo`3oool000007`3oool3000000L0oooo0P00000M0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3a0?oo
o`00o@3oool2000001d0oooo0`00000<0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`3k0?ooo`00o`3ooolJ0?ooo`<00000403oool00`000000oooo
0?ooo`060?ooo`H000003P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool000000?`0oooo
003o0?oooaL0oooo0`00000D0?ooo`030000003oool0oooo00<0oooo0P0000060?ooo`@000002`3o
ool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo00000?/0oooo003o0?oooa@0oooo0`00
000G0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02P3oool2000000X0oooo0P00
00090?ooo`<00000o`3oool00?l0oooo4@3oool3000001/0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0:0?ooo`8000000`3oool400000?l0oooo0`3oool00?l0oooo3@3oool4
000001l0oooo0P00000@0?ooo`030000003oool0oooo00/0oooo0`00003o0?ooo`L0oooo003o0?oo
o`X0oooo0`00000T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolE0?oo
o`00o`3oool70?ooo`<00000:03oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0
oooo503oool00?l0oooo103oool3000001X0oooo1P00000<0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0o`3ooolE0?ooo`00o`3oool10?ooo`<000006P3oool3000000H0oooo1000
00090?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00o@3oool3
000001`0oooo00<000000?ooo`3oool02`3oool2000000P0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`3o0?oooaH0oooo003j0?ooo`<0000000<0oooo0000003oool0703oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool20000
0?l0oooo6@3oool00?L0oooo0`0000040?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`060?ooo`T00000o`3ooolK0?ooo`00m03oool3000000L0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3ooolP0?ooo`00l@3oool3000000X0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`3o0?oooal0oooo003]0?ooo`@000007`3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00jP3oool30000
02@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0?l0oooo:`3oool00>L0oooo0`00000X0?ooo`030000003oool0oooo00L0oooo0P00000<0?ooo`03
0000003oool0oooo0?l0oooo;03oool00>@0oooo0`00000K0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool02@3oool4000000L0oooo0P00003o0?ooobh0oooo003Q0?ooo`<000007`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo1`00003o0?oooc00oooo003N
0?ooo`<000008`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo@P3oool0
0=/0oooo0`00000K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`3o0?oood40oooo003H0?ooo`<000007`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooom10?ooo`00e@3oool3000002<0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo
@03oool00=80oooo0`00000W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?oood40oooo003>0?ooo`@0000000<0oooo0000003oool05`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo100000070?ooo`800000o`3ooom4
0?ooo`00b`3oool3000000D0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool01`00003o0?ooodH0oooo00380?ooo`<0
00008`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0o`3ooom<0?ooo`00a@3oool3000002L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0?l0ooooB`3oool00<80oooo0`00000J0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?oooeL0oooo002o
0?ooo`<000007P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0o`3ooomF0?ooo`00_03oool300000280oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooE`3oool00;T0oooo0`00000J0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool3000000P0oooo0P00003o0?oooeX0
oooo002f0?ooo`<000007P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool02000003o0?oooe`0oooo002c0?ooo`<000008P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3ooomS0?ooo`00/03oool3
000001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`00[03oool4000001h0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`080?ooo`@00000203oool200000?l0ooooIP3oool00:T0
oooo0`00000Q0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0800000?l0ooooJ03oool00:H0oooo0`0000000`3oool000000?ooo`030?ooo`L00000
5`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooom_0?ooo`00X`3oool3000000@0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0o`3ooom^0?ooo`00X03oool3000000L0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`3o0?ooogP0oooo002M0?ooo`<000006@3oool00`000000oooo0?ooo`070?oo
o`@000001@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0?l0ooooM`3oool009X0
oooo0`00000M0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P00000C0?ooo`03
0000003oool0oooo0?l0ooooMP3oool009L0oooo0`00000Q0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool00`3oool00`000000oooo00000005000000h0oooo00<000000?ooo`3oool0
o`3ooome0?ooo`00U03oool3000002D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0:0?ooo`@000002`3oool00`000000oooo0?ooo`3o0?ooog@0oooo002A0?ooo`<000006P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`3o0?ooog<0oooo002=0?ooo`@000007P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oo
og80oooo002:0?ooo`<000008`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0o`3ooon=0?ooo`00Q`3oool3000001/0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooon<0?ooo`00Q03oool3000001l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooon;0?ooo`00P@3oool3
000002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0o`3ooon:0?ooo`00OP3oool4000000D0oooo0`00000N0?oo
o`8000002P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooon90?ooo`00N`3oool3000000<0oooo00@000000?ooo`3oool0oooo0P0000030?oo
o`<00000303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`3o0?ooohP0oooo001h0?ooo`<000001P3oool010000000
oooo0000000000080?ooo`8000002`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?ooohL0oooo001e0?ooo`<0
00002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0ooooW`3oool00780oooo
0`00000K0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0H0?ooo`800000o`3ooon@0?ooo`00KP3oool4000001P0oooo1P0000000`3oool000000?oo
o`0:0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05P3oool300000?l0ooooT03o
ool006/0oooo0`00000J0?ooo`8000001P3oool3000000/0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`3o0?ooojT0oooo001X0?ooo`<00000703oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00T0oooo0`0000080?ooo`<000003P3oool00`000000oooo0?ooo`3o0?oo
oi/0oooo001U0?ooo`<000007P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`0000001`00000A0?ooo`<00000o`3ooonK0?ooo`00HP3oool300000240oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01P0oooo
0P00003o0?oooi/0oooo000a0?ooo`D000000P3oool2000002D0oooo0`00000T0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oook@0oooo000c
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`<000006@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3o0?oook<0oooo000c0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0L0?ooo`<000007@3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`3o0?oook80oooo000[
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06@3o
ool400000200oooo00<000000?ooo`3oool02P3oool2000000d0oooo00@000000?ooo`3oool00000
2`3oool00`000000oooo0?ooo`3o0?oook40oooo000c0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0F0?ooo`<000000`3oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00/0oooo0P0000090?ooo`800000403oool00`000000oooo0?ooo`3o0?oook00oooo
000b0?ooo`800000103oool2000001D0oooo100000060?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0303oool9000001<0oooo00<000000?ooo`3oool0o`3ooon_0?ooo`00C03oool3
000001X0oooo2@00000;0?ooo`030000003oool0oooo0?l0oooof@3oool004T0oooo0`00000K0?oo
o`8000005@3oool200000?l0oooof@3oool004H0oooo0`00000L0?ooo`8000006@3oool00`000000
oooo0?ooo`3o0?ooomH0oooo00130?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`040000
003oool0oooo0?ooo`800000o`3ooooB0?ooo`00@03oool300000240oooo00<000000?ooo`3oool0
303oool2000000`0oooo1000003o0?ooom@0oooo000m0?ooo`<000006P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo00T0oooo0`0000020?ooo`030000003oool0oooo00L0oooo0P00
00020?ooo`030000003oool0oooo0?l0ooood`3oool003X0oooo0`00000G0?ooo`H0000000<0oooo
0000003oool0203oool00`000000oooo0?ooo`040?ooo`@000001P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?l0oooodP3oool003L0oooo0`00000H0?ooo`8000001P3oool30000
00T0oooo00<000000?ooo`3oool00`0000090?ooo`030000003oool0oooo00d0oooo0P0000050?oo
o`030000003oool0oooo0?l0oooobP3oool003@0oooo0`00000J0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01`3oool2000000/0oooo00<000000?ooo`3oool0403oool500000?l0
ooooc@3oool00340oooo0`00000M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
203oool3000000L0oooo0P00003o0?ooon@0oooo000]0?ooo`D000007P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00X0oooo1`00003o0?ooonH0oooo000Z0?ooo`<00000103oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3oooof
0?ooo`009`3oool3000000L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0?l0oooom@3oool002@0oooo0`00000:0?ooo`030000003oool0oooo00d0
oooo200000080?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000o`3oooof0?ooo`00
8@3oool3000001/0oooo0P00000A0?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0
0000o`3ooooe0?ooo`007P3oool3000001`0oooo0P00000D0?ooo`8000002@3oool2000000@0oooo
00<000000?ooo`3oool0o`3oooob0?ooo`006`3oool3000001h0oooo00<000000?ooo`3oool05P3o
ool2000000@0oooo0`0000070?ooo`030000003oool0oooo0?l0ooool@3oool001P0oooo0`00000Q
0?ooo`030000003oool0oooo01P0oooo1000000;0?ooo`030000003oool0oooo0?l0ooool03oool0
01D0oooo0`00000T0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`3o0?ooonl0oooo000B0?ooo`<00000:03oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0o`3oooo^0?ooo`003P3oool4000001T0oooo
2@00000:0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo
000;0?ooo`<000006`3oool2000000T0oooo0P0000090?ooo`8000002`3oool00`000000oooo0?oo
o`3o0?ooool0oooo2`3oool000P0oooo1000000I0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool0203oool3000000H0oooo0P00003o0?ooool0oooo3P3oool000D0oooo0`000002
0?ooo`030000003oool0oooo01T0oooo0P00000?0?ooo`030000003oool0oooo00X0oooo1P00003o
0?ooool0oooo403oool00080oooo0`0000050?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0ooooo`3ooolP0?oo
o`000P00000L0?ooo`030000003oool0oooo00L0oooo0P00000>0?ooo`030000003oool0oooo0?l0
ooooo`3ooolO0?ooo`00603oool9000000T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`3o0?ooool0oooo7`3oool001H0oooo0P0000080?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo7`3oool001D0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo0`00003o
0?ooool0oooo8P3oool001@0oooo00<000000?ooo`3oool02`3oool2000000T0oooo0P0000030?oo
o`<00000o`3ooooo0?ooobD0oooo000D0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool01`3oool400000?l0ooooo`3ooolX0?ooo`00503oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooooo0?ooobP0oooo000E0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`0000002@3oool200000?l0ooooo`3ooolX0?ooo`005P3oool0
0`000000oooo0?ooo`0;0?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3o
oooo0?ooobD0oooo000G0?ooo`8000002P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo0?l0ooooo`3ooolT0?ooo`006@3oool3000000H0oooo0P00000@0?ooo`030000003oool0oooo
0?l0ooooo`3ooolS0?ooo`00703oool600000?l0ooooo`3ooolh0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {211.563, 0}} -> {0.0474472, 0.299637, \
0.00171377, 0.00171377}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<`1234567890-=~!@#$%^&*()_+\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35187 
%%ImageSize: 600 211.124 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0502096 1.05021 -0.338126 1.05021 [
[.14308 .25503 -8.418 -9 ]
[.14308 .25503 9.582 0 ]
[.45933 .15251 -2.99071 -9 ]
[.45933 .15251 3.00929 0 ]
[.80111 .04176 -6.39799 -9 ]
[.80111 .04176 5.60201 0 ]
[.45864 .08717 -4.98362 -12.75 ]
[.45864 .08717 5.01638 0 ]
[.9906 .00532 0 -5.94897 ]
[.9906 .00532 24 3.05103 ]
[.99811 .01628 0 -5.94229 ]
[.99811 .01628 6 3.05771 ]
[1.00557 .02715 0 -5.93567 ]
[1.00557 .02715 18 3.06433 ]
[1.06062 -0.00376 0 -8.41824 ]
[1.06062 -0.00376 10 4.33176 ]
[ 0 0 0 0 ]
[ 1 .35187 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00054 .31394 m
.97169 0 L
s
.14223 .26813 m
.14181 .27468 L
s
[(-10)] .14308 .25503 -0.06467 1 Mshowa
.45929 .16564 m
.45927 .1722 L
s
[(0)] .45933 .15251 -0.0031 1 Mshowa
.80198 .05486 m
.80241 .06141 L
s
[(10)] .80111 .04176 .06633 1 Mshowa
.125 Mabswid
.20373 .24825 m
.20352 .25218 L
s
.26616 .22807 m
.266 .232 L
s
.32955 .20758 m
.32944 .21151 L
s
.39392 .18677 m
.39386 .19071 L
s
.52568 .14418 m
.52572 .14812 L
s
.59312 .12238 m
.59321 .12631 L
s
.66163 .10023 m
.66178 .10417 L
s
.73124 .07773 m
.73145 .08166 L
s
.08165 .28772 m
.08135 .29164 L
s
.02196 .30701 m
.02161 .31094 L
s
.87387 .03162 m
.87419 .03555 L
s
.94694 .008 m
.94732 .01192 L
s
gsave
.45864 .08717 -65.9836 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97169 0 m
.99934 .04028 L
s
.9781 .00934 m
.97185 .01135 L
s
[(-0.5)] .9906 .00532 -1 .32199 Mshowa
.98561 .02028 m
.97936 .02229 L
s
[(0)] .99811 .01628 -1 .32051 Mshowa
.99307 .03114 m
.98681 .03314 L
s
[(0.5)] 1.00557 .02715 -1 .31904 Mshowa
.125 Mabswid
.97961 .01154 m
.97586 .01274 L
s
.98111 .01373 m
.97736 .01493 L
s
.98262 .01592 m
.97887 .01712 L
s
.98412 .0181 m
.98037 .0193 L
s
.98711 .02246 m
.98336 .02366 L
s
.9886 .02464 m
.98485 .02584 L
s
.99009 .02681 m
.98634 .02801 L
s
.99158 .02898 m
.98783 .03017 L
s
.97659 .00714 m
.97285 .00835 L
s
.97508 .00494 m
.97133 .00615 L
s
.97357 .00274 m
.96982 .00395 L
s
.97205 .00053 m
.96831 .00174 L
s
.99455 .0333 m
.9908 .0345 L
s
.99603 .03546 m
.99228 .03666 L
s
.99751 .03762 m
.99376 .03881 L
s
.99899 .03977 m
.99524 .04096 L
s
gsave
1.06062 -0.00376 -61 -12.4182 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35187 L
0 .35187 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05021 .33208 m
.0448 .3312 L
s
.0448 .3312 m
.04263 .32929 L
s
.04534 .32973 m
.04263 .32929 L
s
.04588 .32825 m
.04534 .32973 L
s
.07836 .32961 m
.05565 .30935 L
s
.07025 .32829 m
.07836 .32961 L
s
.04263 .32929 m
.04317 .32781 L
s
.06592 .32837 m
.07025 .32829 L
s
.04317 .32781 m
.04588 .32825 L
s
.10181 .32085 m
.10616 .32077 L
s
.0991 .3204 m
.10181 .32085 L
s
.10616 .32077 m
.11273 .31868 L
s
.09532 .319 m
.0991 .3204 L
s
.09425 .31803 m
.09532 .319 L
s
.11273 .31868 m
.11495 .31666 L
s
.11495 .31666 m
.11553 .31517 L
s
.11553 .31517 m
.11504 .31271 L
s
.11504 .31271 m
.11291 .31077 L
s
.13414 .31186 m
.15236 .30606 L
s
.11291 .31077 m
.10912 .30935 L
s
.10912 .30935 m
.10261 .30749 L
s
.10261 .30749 m
.07535 .30301 L
s
.15236 .30606 m
.13393 .30143 L
s
.07535 .30301 m
.09845 .29558 L
s
.13393 .30143 m
.1389 .29984 L
s
.1389 .29984 m
.14116 .29779 L
s
.14116 .29779 m
.14176 .29628 L
s
.18066 .29706 m
.15847 .27628 L
s
.18066 .29706 m
.14918 .2886 L
s
.11221 .29382 m
.1127 .29632 L
s
.14176 .29628 m
.14024 .2928 L
s
.11279 .2923 m
.11221 .29382 L
s
.14024 .2928 m
.1381 .29083 L
s
.1167 .28972 m
.11279 .2923 L
s
.1381 .29083 m
.13323 .2884 L
s
.20076 .29066 m
.18966 .28229 L
s
.21758 .28531 m
.20076 .29066 L
s
.12169 .28811 m
.1167 .28972 L
s
.14918 .2886 m
.1743 .28055 L
s
.13323 .2884 m
.12776 .28749 L
s
.12776 .28749 m
.12169 .28811 L
s
.19239 .28275 m
.19849 .28213 L
s
.18966 .28229 m
.19239 .28275 L
s
.19849 .28213 m
.20354 .28051 L
s
.20354 .28051 m
.20756 .2779 L
s
.20756 .2779 m
.20885 .27482 L
s
.23683 .27786 m
.23033 .27595 L
s
.24295 .27724 m
.23683 .27786 L
s
.24635 .27616 m
.24295 .27724 L
s
.25041 .27353 m
.24635 .27616 L
s
.23033 .27595 m
.22344 .27149 L
s
.17911 .27233 m
.17954 .27487 L
s
.20885 .27482 m
.2074 .27128 L
s
.25005 .27099 m
.25041 .27353 L
s
.17974 .27078 m
.17911 .27233 L
s
.22344 .27149 m
.21822 .26648 L
s
.2074 .27128 m
.2053 .26928 L
s
.18374 .26815 m
.17974 .27078 L
s
.26506 .2702 m
.28901 .26258 L
s
.22853 .26987 m
.22305 .26895 L
s
.23467 .26924 m
.22853 .26987 L
s
.2053 .26928 m
.20045 .26681 L
s
.23637 .2687 m
.23467 .26924 L
s
.22305 .26895 m
.21822 .26648 L
s
.24043 .26606 m
.23637 .2687 L
s
.18882 .26652 m
.18374 .26815 L
s
.20045 .26681 m
.19495 .26589 L
s
.19495 .26589 m
.18882 .26652 L
s
.21822 .26648 m
.21573 .26191 L
s
.24176 .26296 m
.24043 .26606 L
s
.24035 .25938 m
.24176 .26296 L
s
.28901 .26258 m
.25019 .24678 L
s
.21573 .26191 m
.21703 .2588 L
s
.23931 .25837 m
.24035 .25938 L
s
.21703 .2588 m
.22109 .25614 L
s
.23447 .25589 m
.23931 .25837 L
s
.30173 .25719 m
.29797 .25572 L
s
.30792 .25656 m
.30173 .25719 L
s
.31482 .25437 m
.30792 .25656 L
s
.22109 .25614 m
.2228 .25559 L
s
.22897 .25496 m
.23447 .25589 L
s
.29797 .25572 m
.29593 .25369 L
s
.2228 .25559 m
.22897 .25496 L
s
.31898 .2517 m
.31482 .25437 L
s
.29593 .25369 m
.29561 .25111 L
s
.31869 .24912 m
.31898 .2517 L
s
.29561 .25111 m
.29804 .24899 L
s
.31665 .24708 m
.31869 .24912 L
s
.29804 .24899 m
.30393 .24576 L
s
.29427 .2475 m
.30047 .24687 L
s
.28876 .24657 m
.29427 .2475 L
s
.31289 .24559 m
.31665 .24708 L
s
.30047 .24687 m
.30841 .24568 L
s
.28498 .24508 m
.28876 .24657 L
s
.30393 .24576 m
.3081 .24308 L
s
.30841 .24568 m
.31289 .24559 L
s
.33804 .24563 m
.34426 .245 L
s
.33255 .2447 m
.33804 .24563 L
s
.28189 .24202 m
.28498 .24508 L
s
.34426 .245 m
.346 .24444 L
s
.32778 .24219 m
.33255 .2447 L
s
.346 .24444 m
.35021 .24176 L
s
.3081 .24308 m
.30952 .23992 L
s
.32676 .24116 m
.32778 .24219 L
s
.28155 .23941 m
.28189 .24202 L
s
.35021 .24176 m
.35169 .2386 L
s
.32545 .23753 m
.32676 .24116 L
s
.30952 .23992 m
.30921 .23732 L
s
.28225 .23783 m
.28155 .23941 L
s
.35169 .2386 m
.3494 .23393 L
s
.28641 .23513 m
.28225 .23783 L
s
.3269 .23436 m
.32545 .23753 L
s
.30921 .23732 m
.30614 .23423 L
s
.29335 .2329 m
.28641 .23513 L
s
.37292 .23453 m
.36641 .23256 L
s
.37917 .23389 m
.37292 .23453 L
s
.33111 .23166 m
.3269 .23436 L
s
.30614 .23423 m
.30235 .23273 L
s
.3494 .23393 m
.34435 .22877 L
s
.3494 .23393 m
.34463 .2314 L
s
.38268 .23277 m
.37917 .23389 L
s
.29959 .23226 m
.29335 .2329 L
s
.38695 .23006 m
.38268 .23277 L
s
.30235 .23273 m
.29959 .23226 L
s
.36641 .23256 m
.35964 .22795 L
s
.33286 .2311 m
.33111 .23166 L
s
.34463 .2314 m
.33911 .23045 L
s
.33911 .23045 m
.33286 .2311 L
s
.38747 .22584 m
.38695 .23006 L
s
.31699 .22666 m
.3173 .22929 L
s
.34435 .22877 m
.33753 .22416 L
s
.35964 .22795 m
.35661 .22485 L
s
.32121 .22394 m
.31699 .22666 L
s
.38424 .22009 m
.38747 .22584 L
s
.35661 .22485 m
.35331 .21909 L
s
.33753 .22416 m
.33097 .22217 L
s
.3247 .22282 m
.32121 .22394 L
s
.33097 .22217 m
.3247 .22282 L
s
.38124 .21696 m
.38424 .22009 L
s
.35331 .21909 m
.35379 .21483 L
s
.37445 .21231 m
.38124 .21696 L
s
.35379 .21483 m
.35806 .21209 L
s
.39361 .213 m
.42558 .20277 L
s
.36789 .2103 m
.37445 .21231 L
s
.35806 .21209 m
.36159 .21095 L
s
.36159 .21095 m
.36789 .2103 L
s
.44282 .20136 m
.47512 .19104 L
s
.4369 .19502 m
.46925 .18464 L
s
.48858 .18536 m
.49317 .18527 L
s
.48385 .18273 m
.48858 .18536 L
s
.49317 .18527 m
.49679 .18411 L
s
.48761 .18429 m
.4922 .1842 L
s
.48385 .18273 m
.48761 .18429 L
s
.4922 .1842 m
.49582 .18304 L
s
.49679 .18411 m
.49944 .18188 L
s
.49582 .18304 m
.49847 .18081 L
s
.4819 .18059 m
.48385 .18273 L
s
.49944 .18188 m
.50379 .17634 L
s
.54358 .18157 m
.53017 .1665 L
s
.49847 .18081 m
.50282 .17527 L
s
.51846 .17442 m
.52039 .17657 L
s
.50379 .17634 m
.50646 .1741 L
s
.50282 .17527 m
.50549 .17303 L
s
.51374 .17177 m
.51846 .17442 L
s
.51471 .17285 m
.51846 .17442 L
s
.50646 .1741 m
.5101 .17294 L
s
.50549 .17303 m
.50913 .17186 L
s
.5101 .17294 m
.51471 .17285 L
s
.5636 .17244 m
.55804 .17145 L
s
.56822 .17235 m
.5636 .17244 L
s
.57466 .17168 m
.56822 .17235 L
s
.50913 .17186 m
.51374 .17177 L
s
.58017 .16993 m
.57466 .17168 L
s
.55804 .17145 m
.55431 .16988 L
s
.58475 .16709 m
.58017 .16993 L
s
.55431 .16988 m
.54962 .16722 L
s
.54962 .16722 m
.54675 .16397 L
s
.58749 .16483 m
.58475 .16709 L
s
.56532 .16637 m
.56253 .16587 L
s
.56994 .16628 m
.56532 .16637 L
s
.56994 .16628 m
.56437 .16528 L
s
.57546 .16452 m
.56994 .16628 L
s
.56253 .16587 m
.55784 .16321 L
s
.56437 .16528 m
.55968 .16262 L
s
.5893 .16149 m
.58749 .16483 L
s
.57819 .16226 m
.57546 .16452 L
s
.54675 .16397 m
.54571 .16013 L
s
.55784 .16321 m
.55498 .15995 L
s
.58098 .16275 m
.57156 .15464 L
s
.55968 .16262 m
.55682 .15936 L
s
.57815 .15949 m
.57819 .16226 L
s
.58282 .16217 m
.57341 .15404 L
s
.58926 .15872 m
.5893 .16149 L
s
.52622 .1594 m
.52535 .16108 L
s
.52535 .16108 m
.52255 .16058 L
s
.62636 .16076 m
.58325 .12976 L
s
.52255 .16058 m
.52342 .15891 L
s
.54571 .16013 m
.54563 .15736 L
s
.55498 .15995 m
.55491 .15718 L
s
.52342 .15891 m
.52622 .1594 L
s
.55682 .15936 m
.55675 .15659 L
s
.58828 .15486 m
.58926 .15872 L
s
.54563 .15736 m
.54739 .154 L
s
.6375 .15723 m
.59446 .12614 L
s
.55491 .15718 m
.55763 .15491 L
s
.55675 .15659 m
.55763 .15491 L
s
.55763 .15491 m
.56317 .15313 L
s
.58639 .15268 m
.58828 .15486 L
s
.57156 .15464 m
.56966 .15245 L
s
.56781 .15304 m
.57156 .15464 L
s
.57341 .15404 m
.5715 .15186 L
s
.54739 .154 m
.55012 .15172 L
s
.56317 .15313 m
.56781 .15304 L
s
.5817 .14999 m
.58639 .15268 L
s
.56966 .15245 m
.5724 .15017 L
s
.5715 .15186 m
.5724 .15017 L
s
.55012 .15172 m
.55469 .14885 L
s
.60125 .15072 m
.6273 .14239 L
s
.5724 .15017 m
.5761 .14898 L
s
.65986 .15013 m
.63296 .11799 L
s
.5761 .14898 m
.5817 .14999 L
s
.55469 .14885 m
.56023 .14706 L
s
.66734 .14775 m
.6405 .11556 L
s
.56023 .14706 m
.56674 .14638 L
s
.5714 .14629 m
.5742 .14679 L
s
.64965 .14642 m
.64407 .14542 L
s
.65618 .14574 m
.64965 .14642 L
s
.56674 .14638 m
.5714 .14629 L
s
.66367 .14335 m
.65618 .14574 L
s
.64407 .14542 m
.64222 .14322 L
s
.59374 .14473 m
.61982 .13637 L
s
.66838 .14046 m
.66367 .14335 L
s
.64222 .14322 m
.64224 .14042 L
s
.6703 .13706 m
.66838 .14046 L
s
.64224 .14042 m
.64318 .13872 L
s
.64318 .13872 m
.646 .13641 L
s
.646 .13641 m
.65541 .13059 L
s
.6853 .13508 m
.68998 .13498 L
s
.68159 .13346 m
.6853 .13508 L
s
.68998 .13498 m
.69375 .13378 L
s
.69375 .13378 m
.69662 .13147 L
s
.69375 .13378 m
.69571 .13036 L
s
.67976 .13124 m
.68159 .13346 L
s
.69662 .13147 m
.70138 .12855 L
s
.68171 .12781 m
.67976 .13124 L
s
.65541 .13059 m
.65825 .12828 L
s
.69571 .13036 m
.69389 .12814 L
s
.632 .1254 m
.63012 .12883 L
s
.70138 .12855 m
.70706 .12675 L
s
.65825 .12828 m
.65921 .12656 L
s
.69389 .12814 m
.69018 .12651 L
s
.68548 .12661 m
.68171 .12781 L
s
.70706 .12675 m
.71365 .12605 L
s
.69018 .12651 m
.68548 .12661 L
s
.65921 .12656 m
.65924 .12373 L
s
.71365 .12605 m
.71835 .12596 L
s
.71835 .12596 m
.66503 .11336 L
s
.63671 .12247 m
.632 .1254 L
s
.65924 .12373 m
.65646 .12037 L
s
.64424 .12005 m
.63671 .12247 L
s
.74105 .12154 m
.7438 .10089 L
s
.74105 .12154 m
.71319 .11069 L
s
.65646 .12037 m
.65083 .11935 L
s
.65083 .11935 m
.64424 .12005 L
s
.69332 .1128 m
.68959 .11116 L
s
.69804 .1127 m
.69332 .1128 L
s
.70185 .11149 m
.69804 .1127 L
s
.70383 .10801 m
.70185 .11149 L
s
.68959 .11116 m
.68775 .1089 L
s
.68775 .1089 m
.68972 .10542 L
s
.702 .10575 m
.70383 .10801 L
s
.77091 .10782 m
.76721 .10617 L
s
.77563 .10773 m
.77091 .10782 L
s
.7786 .10537 m
.77563 .10773 L
s
.76721 .10617 m
.76543 .10391 L
s
.69826 .1041 m
.702 .10575 L
s
.68972 .10542 m
.69353 .10419 L
s
.77875 .10249 m
.7786 .10537 L
s
.69353 .10419 m
.69826 .1041 L
s
.76543 .10391 m
.76469 .09989 L
s
.77698 .10022 m
.77875 .10249 L
s
.77328 .09857 m
.77698 .10022 L
s
.76469 .09989 m
.76587 .09525 L
s
.77047 .09805 m
.77328 .09857 L
s
.75341 .09781 m
.77047 .09805 L
s
.75059 .09729 m
.75341 .09781 L
s
.74687 .09563 m
.75059 .09729 L
s
.74507 .09335 m
.74687 .09563 L
s
.76587 .09525 m
.76928 .08414 L
s
.78873 .09363 m
.78591 .09311 L
s
.79067 .09302 m
.78873 .09363 L
s
.74519 .09045 m
.74507 .09335 L
s
.78591 .09311 m
.78221 .09145 L
s
.79172 .09126 m
.79067 .09302 L
s
.78221 .09145 m
.77389 .08696 L
s
.79084 .09011 m
.79172 .09126 L
s
.74622 .08868 m
.74519 .09045 L
s
.74918 .0863 m
.74622 .08868 L
s
.77389 .08696 m
.76734 .08477 L
s
.81483 .08673 m
.80428 .0729 L
s
.86055 .08639 m
.85492 .08534 L
s
.80248 .08639 m
.81669 .07324 L
s
.75691 .08381 m
.74918 .0863 L
s
.85492 .08534 m
.84843 .08314 L
s
.76734 .08477 m
.76168 .08371 L
s
.76928 .08414 m
.77137 .0806 L
s
.76168 .08371 m
.75691 .08381 L
s
.84843 .08314 m
.84106 .07978 L
s
.87229 .08266 m
.87451 .07911 L
s
.77137 .0806 m
.77435 .0782 L
s
.82195 .08017 m
.79719 .0795 L
s
.84106 .07978 m
.83476 .07464 L
s
.87451 .07911 m
.87588 .0744 L
s
.78108 .07748 m
.78197 .07863 L
s
.77435 .0782 m
.77824 .07695 L
s
.77824 .07695 m
.78108 .07748 L
s
.83476 .07464 m
.83127 .07001 L
s
.87588 .0744 m
.8764 .06851 L
s
.83127 .07001 m
.82886 .06356 L
s
.8764 .06851 m
.87409 .06206 L
s
.82886 .06356 m
.82929 .05763 L
s
.87409 .06206 m
.87066 .05739 L
s
.82929 .05763 m
.83059 .05284 L
s
.87066 .05739 m
.86436 .05216 L
s
.83059 .05284 m
.83278 .04922 L
s
.86436 .05216 m
.85693 .04873 L
s
.85693 .04873 m
.85036 .04647 L
s
.94961 .04804 m
.93454 .02668 L
s
.85036 .04647 m
.84465 .04539 L
s
.92407 .04317 m
.96021 .0316 L
s
.86648 .03834 m
.90245 .02673 L
s
0 g
.25 Mabswid
.00054 .31394 m
.97169 0 L
s
.14223 .26813 m
.14181 .27468 L
s
[(-10)] .14308 .25503 -0.06467 1 Mshowa
.45929 .16564 m
.45927 .1722 L
s
[(0)] .45933 .15251 -0.0031 1 Mshowa
.80198 .05486 m
.80241 .06141 L
s
[(10)] .80111 .04176 .06633 1 Mshowa
.125 Mabswid
.20373 .24825 m
.20352 .25218 L
s
.26616 .22807 m
.266 .232 L
s
.32955 .20758 m
.32944 .21151 L
s
.39392 .18677 m
.39386 .19071 L
s
.52568 .14418 m
.52572 .14812 L
s
.59312 .12238 m
.59321 .12631 L
s
.66163 .10023 m
.66178 .10417 L
s
.73124 .07773 m
.73145 .08166 L
s
.08165 .28772 m
.08135 .29164 L
s
.02196 .30701 m
.02161 .31094 L
s
.87387 .03162 m
.87419 .03555 L
s
.94694 .008 m
.94732 .01192 L
s
gsave
.45864 .08717 -65.9836 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 211.125},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000db000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo0P00000L0?oo
o`00o`3ooooo0?oooa`0oooo0P00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000006`3oool00?l0ooooo`3ooolI0?ooo`@0000000<0oooo0000003oool03`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo01T0oooo003o0?ooool0oooo5P3oool30000
00<0oooo0`00000:0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000703oool0
0?l0ooooo`3ooolC0?ooo`<000001`3oool3000000l0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0K0?ooo`00o`3ooooo0?ooo`l0oooo1000000=0?ooo`030000003oool0oooo
00d0oooo0P00000:0?ooo`<000006`3oool00?l0ooooo`3oool<0?ooo`@000003P3oool4000000`0
oooo0P00000Z0?ooo`00o`3ooooo0?ooo`T0oooo0`0000040?ooo`030000003oool0oooo00X0oooo
0`0000000`3oool000000000000:0?ooo`040000003oool0oooo000002T0oooo003o0?ooool0oooo
1P3oool3000000L0oooo00<000000?ooo`3oool0303oool2000000030?ooo`000000oooo00T0oooo
00@000000?ooo`3oool00000:@3oool00?l0ooooo`3oool30?ooo`<000006P3oool3000000X0oooo
00@000000?ooo`3oool00000:@3oool00?l0ooooo`3oool3000001h0oooo0`0000090?ooo`040000
003oool0oooo000002T0oooo003o0?oooo`0oooo0`00000T0?ooo`030000003oool0oooo00L0oooo
0P00000Z0?ooo`00o`3ooooi0?ooo`<000009@3oool4000000`0oooo0P0000040?ooo`800000103o
ool2000001X0oooo003o0?ooooH0oooo0`00000W0?ooo`<0000000<0oooo0000000000002P3oool0
10000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001T0oooo003o0?oooo<0oooo0`00
000]0?ooo`<000002P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01L0oooo
003o0?oooo00oooo0`00000`0?ooo`@000002@3oool010000000oooo0?ooo`0000090?ooo`800000
6P3oool00?l0oooo^03oool500000080oooo0P00000[0?ooo`@000001@3oool200000100oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo
00<000000?ooo`3oool06@3oool00?l0oooo^P3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool09@3oool3000000H0oooo0`00000C0?ooo`030000003oool0oooo01T0oooo
0P0000000`3oool000000?ooo`080?ooo`8000002P3oool3000001T0oooo003o0?oookX0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0280oooo0`0000050?ooo`@00000
5P3oool00`000000oooo0?ooo`0J0?ooo`@00000<03oool00?l0oooo^P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool07`3oool4000000@0oooo0`00000K0?ooo`030000
003oool0oooo00T0oooo0P00000>0?ooo`80000000<0oooo000000000000;`3oool00?l0oooo^P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3000000<0oooo
00<000000?ooo`0000000P00000O0?ooo`030000003oool0oooo00D0oooo0`00000B0?ooo`<00000
;`3oool00?l0oooo^@3oool2000000@0oooo0P00000L0?ooo`<00000103oool4000002<0oooo00<0
00000?ooo`3oool01000000F0?ooo`<00000;P3oool00?l0oooofP3oool3000000D0oooo0P00000W
0?ooo`<00000703oool00`000000oooo0?ooo`0/0?ooo`00o`3ooooG0?ooo`<00000;P3oool30000
00030?ooo`000000oooo01X0oooo0P0000000`3oool000000?ooo`0/0?ooo`00o`3ooooD0?ooo`<0
0000;@3oool4000000D0oooo00<000000?ooo`3oool06@3oool2000002h0oooo003o0?ooom40oooo
0`00000^0?ooo`8000002P3oool00`000000oooo0?ooo`180?ooo`00o`3oooo>0?ooo`<000001@3o
ool2000003H0oooo00<000000?ooo`3oool0B03oool00?l0oooobP3oool4000000X0oooo0`00000d
0?ooo`030000003oool0oooo04L0oooo003o0?ooolL0oooo0`0000050?ooo`030000003oool0oooo
00T0oooo0`00000b0?ooo`030000003oool0oooo04H0oooo003o0?oool@0oooo0`0000070?ooo`03
0000003oool0oooo00d0oooo0P00001i0?ooo`00o`3oooo10?ooo`<000002P3oool00`000000oooo
0?ooo`0?0?ooo`800000M`3oool00?l0oooo_P3oool3000000d0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1d0?ooo`00o`3ooonk0?ooo`@000003P3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo07<0oooo003o0?oookP0oooo0`0000030?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1b0?ooo`00o`3ooone0?ooo`<0
00001P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0L@3oool00?l0oooo/P3oool3000000T0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo0700oooo003o0?ooojl0oooo0`00000K0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0L03oool00?l0ooooZ`3oool4000001h0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1`0?ooo`00o`3ooonX0?ooo`<000008P3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo06l0oooo003o0?ooojD0oooo0`00000V0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0K`3oool00?l0ooooXP3oool3000002T0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1_0?ooo`00n`3oool2000000030?ooo`00
0000000009h0oooo0`00000M0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1_0?ooo`00o03oool00`000000oooo0000002L0?ooo`<000008@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1_0?ooo`00o@3oool00`000000oooo0?ooo`2H0?ooo`<00000903oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`1_0?ooo`00n`3oool2000000030?ooo`000000000009D0oooo0`00000F0?ooo`@0
00003P3oool010000000oooo0?ooo`00000=0?ooo`8000004P3oool00`000000oooo0?ooo`1`0?oo
o`00o`3ooonC0?ooo`<0000000<0oooo0000003oool05@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00D0oooo2@00000@0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0L03oool00?l0ooooT03oool3000000@0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0A0?ooo`T000002`3oool2000000h0oooo00<000000?ooo`3oool0L@3oool00?l0ooooS03o
ool4000001L0oooo0P0000030?ooo`030000003oool0oooo0140oooo00@000000?ooo`3oool00000
4`3oool3000000/0oooo00<000000?ooo`3oool0L@3oool00?l0ooooR@3oool3000001P0oooo0`00
00020?ooo`@000004P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo0`00
001l0?ooo`00o`3ooon60?ooo`<00000603oool3000000P0oooo0`00000?0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool05@3oool2000007X0oooo003o0?oooh<0oooo0`00000I0?oo
o`8000002P3oool010000000oooo0?ooo`3oool200000:P0oooo003o0?oooh00oooo0`00000K0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool2000000D0oooo00<000000?oo
o`3oool0WP3oool00?l0ooooO@3oool3000001h0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0WP3oool00?l0oooo
NP3oool300000240oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`070?ooo`D00000
X03oool00?l0ooooM`3oool3000002D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`2/0?ooo`00o`3ooomd0?ooo`<00000:@3oool=00000:`0oooo003o0?ooog40oooo0`00000e0?oo
o`040000003oool0oooo0?ooo`800000ZP3oool00?l0ooooK@3oool4000002d0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`030?ooo`800000Z03oool00?l0ooooJP3oool3000000<0
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0Y@3oool00?l0ooooI`3oool3000000H0oooo00<000000?ooo`3oool0
3`3oool3000001T0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0:D0oooo003o0?ooof@0oooo0`00000I0?ooo`8000000`3oool2000001H0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:D0oooo003o
0?ooof40oooo0`00000J0?ooo`8000001`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00`0oooo1@00002X0?ooo`00o`3ooomN0?ooo`<000007@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo0P00000>0?ooo`030000003oool0oooo0;T0oooo003o0?oooe/0
oooo0`00000Q0?ooo`8000001@3oool00`000000oooo0?ooo`060?ooo`800000303oool00`000000
oooo0?ooo`2i0?ooo`00o`3ooomH0?ooo`<000005`3oool3000000`0oooo1@00000;0?ooo`<00000
2@3oool00`000000oooo0?ooo`2i0?ooo`00o`3ooomE0?ooo`<00000303oool00`000000oooo0?oo
o`0>0?ooo`@000006`3oool2000000L0oooo00<000000?ooo`3oool0^@3oool00?l0ooooDP3oool3
00000100oooo00<000000?ooo`3oool04@3oool4000001T0oooo0`0000030?ooo`030000003oool0
oooo0;X0oooo003o0?ooodl0oooo0`00000>0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00`00000A0?ooo`@00000603oool2000000030?ooo`000000oooo0;/0oooo003o0?oood/0
oooo1000000B0?ooo`040000003oool0oooo0?ooo`@000000`3oool2000001<0oooo1000000F0?oo
o`800000_03oool00?l0ooooB03oool3000001L0oooo0`0000020?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool400000=00oooo003o0?ooodD0oooo0`0000020?ooo`030000
003oool0oooo01<0oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool05`3oool400000<`0oooo003o0?oood80oooo0`0000050?ooo`8000004`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0;0?ooo`@000001`3oool800000<T0oooo003o0?ooocl0oooo0`00000:
0?ooo`800000403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`800000103oool2000000<0oooo0P00003A0?ooo`00o`3oooll
0?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0000000`0oooo00<00000
0?ooo`3oool01P3oool300000=<0oooo003o0?ooocT0oooo0`0000090?ooo`800000203oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0080oooo0P00000=0?ooo`030000003oool0oooo
00D0oooo0P00003E0?ooo`00o`3ooolf0?ooo`<000003P3oool00`000000oooo0?ooo`060?ooo`80
00005@3oool00`000000oooo0?ooo`03000000h0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`3D0?ooo`00o`3ooolc0?ooo`<000004P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01<0oooo0P0000030?ooo`030000003oool0oooo00`0oooo1P00003G0?ooo`00o`3o
ool`0?ooo`<000005P3oool2000000P0oooo0P0000030?ooo`8000003@3oool00`000000oooo0000
00040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0h@3oool00?h0oooo0P00000[
0?ooo`@000006`3oool00`000000oooo0?ooo`060?ooo`@000003P3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3R0?ooo`00o@3oool0
10000000oooo0?ooo`00000W0?ooo`<00000803oool200000080oooo100000020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`000000i03oool00?d0oooo00@000000?ooo`3oool00000903oool3000002<0oooo
100000070?ooo`8000000`3oool2000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0000000000>D0oooo003m0?ooo`040000003oool0oooo00000240
oooo0`00000T0?ooo`8000000`3oool00`000000oooo0?ooo`070?ooo`<000002@3oool00`000000
oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`800000i`3oool00?d0oooo00@000000?ooo`3o
ool000007P3oool3000000030?ooo`000000oooo01@0oooo1@00000A0?ooo`800000103oool30000
00030?ooo`000000000000X0oooo2P0000020?ooo`030000003oool0oooo0>@0oooo003n0?ooo`80
0000703oool3000000@0oooo00<000000?ooo`3oool0403oool3000000D0oooo00<000000?ooo`3o
ool0403oool4000000H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0><0oooo003o0?oooaX0oooo0`00000G0?ooo`<000001`3oool7000000/0oooo
1@0000080?ooo`800000403oool00`000000oooo0?ooo`3W0?ooo`00o`3ooolG0?ooo`<00000603o
ool2000000T0oooo0P0000060?ooo`030000003oool0oooo00H0oooo0P0000050?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0m`3oool00?l0oooo503oool3000001X0oooo00<00000
0?ooo`3oool0103oool7000000L0oooo00<000000?ooo`3oool03@3oool2000000P0oooo00<00000
0?ooo`3oool0mP3oool00?l0oooo4@3oool3000001`0oooo00<000000?ooo`3oool00`3oool20000
00D0oooo0`0000070?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool01P3oool20000
0?H0oooo003o0?ooo`d0oooo1000000O0?ooo`030000003oool0oooo0080oooo0P0000080?ooo`80
00001P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0l`3oool00?l0oooo2P3oool3000001H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`8000002@3oool3000000D0oooo00<000000?ooo`3oool03`3oool200000?d0oooo
003o0?ooo`L0oooo0`00000I0?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`8000002`3o
ool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3j0?ooo`00o`3oool4
0?ooo`<00000:@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000X0oooo0`000003
0?ooo`030000003oool0oooo0?l0oooo3`3oool00?l0oooo0@3oool3000002`0oooo00<000000?oo
o`3oool00`3oool4000000D0oooo0`0000050?ooo`030000003oool0oooo0?l0oooo403oool00?d0
oooo0`00000V0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool7000000P0
oooo00<000000?ooo`3oool0o`3oool@0?ooo`00nP3oool300000080oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0100oooo0P00003o0?oooa<0oooo
003g0?ooo`<000001@3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00L0oooo0P00
000=0?ooo`<00000o`3ooolE0?ooo`00m03oool3000000P0oooo00<000000?ooo`3oool0603oool4
000000X0oooo00<000000?ooo`3oool02@3oool3000000L0oooo0`00003o0?oooaP0oooo003a0?oo
o`<000002`3oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000000000000P00000:0?oo
o`030000003oool0oooo00/0oooo1`00003o0?oooa/0oooo003]0?ooo`@000009P3oool010000000
oooo0000000000030?ooo`8000002P3oool00`000000oooo0?ooo`3o0?ooob`0oooo003Z0?ooo`<0
0000:@3oool3000000L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooob/0
oooo003W0?ooo`<00000:`3oool2000001@0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00i03o
ool3000002@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0000000E0?ooo`030000003o
ool0oooo0?l0oooo:P3oool00>40oooo0`00000X0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`0000005`3oool00`000000oooo0?ooo`3o0?ooobT0oooo003N0?ooo`<00000;03oool80000
0?l0ooooA03oool00=/0oooo0`00000U0?ooo`8000002P3oool400000?l0ooooAP3oool00=P0oooo
0`00000T0?ooo`@00000o`3ooomF0?ooo`00e@3oool300000080oooo00<000000?ooo`3oool07`3o
ool300000?l0ooooFP3oool00=80oooo0`0000050?ooo`030000003oool0oooo01/0oooo1000000:
0?ooo`800000o`3ooomA0?ooo`00cP3oool400000280oooo1000000;0?ooo`<00000o`3ooomC0?oo
o`00b`3oool3000002@0oooo0P00000<0?ooo`<00000o`3ooomF0?ooo`00b03oool300000380oooo
0`00003o0?oooeT0oooo00350?ooo`<00000<P3oool300000?l0ooooG03oool00<80oooo0`00000b
0?ooo`<00000o`3ooomO0?ooo`00_`3oool3000003<0oooo0P00003o0?ooof80oooo002l0?ooo`<0
0000;03oool200000?l0ooooK03oool00;T0oooo0`00000[0?ooo`@00000o`3ooom^0?ooo`00]P3o
ool3000002/0oooo0`00003o0?ooog80oooo002c0?ooo`@00000:@3oool400000?l0ooooM@3oool0
0;00oooo0`0000030?ooo`030000003oool0oooo00l0oooo1P00000>0?ooo`@00000o`3ooomi0?oo
o`00[03oool4000001H0oooo0P0000060?ooo`8000002P3oool200000?l0ooooO@3oool00:T0oooo
0`00000H0?ooo`8000002P3oool200000?l0ooooQ`3oool00:H0oooo0`00000K0?ooo`030000003o
ool0oooo00/0oooo0P00003o0?ooohD0oooo002S0?ooo`<000007P3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0?l0ooooPP3oool00:00oooo0`00000Q0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0o`3ooon10?ooo`00W@3oool3000001H0oooo0`00000<0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooon00?ooo`00VP3oool3000001D0oooo
100000030?ooo`<000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo
P03oool009L0oooo0`00000G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0ooooO`3oool009@0oooo0`00000I
0?ooo`030000003oool0oooo00X0oooo0P0000070?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0o`3ooomo0?ooo`00T@3oool3000001`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3ooon00?oo
o`00S@3oool400000080oooo00<000000?ooo`3oool08P3oool9000000L0oooo0P00000<0?ooo`03
0000003oool0oooo0?l0ooooP03oool008X0oooo0`0000060?ooo`030000003oool0oooo00`0oooo
1`00000>0?ooo`030000003oool0oooo00H0oooo0P0000080?ooo`<000001`3oool200000?l0oooo
P`3oool008L0oooo0`00000F0?ooo`8000001`3oool2000000X0oooo0P00000;0?ooo`030000003o
ool0oooo00P0oooo1`00003o0?ooohD0oooo00240?ooo`<000005`3oool2000000X0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0?l0ooooU03oool0
0840oooo0`00000H0?ooo`8000003@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0o`3ooonC0?ooo`00OP3oool3000001/0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0o`3ooonD0?ooo`00CP3oool500000080oooo0P00000T0?ooo`<000007P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00L0oooo0P00000;0?ooo`030000003oool0oooo0?l0oooo
U03oool00500oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo
0`00000R0?ooo`030000003oool0oooo00X0oooo0P00000;0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0o`3ooonE0?ooo`00D03oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool06`3oool3000002H0oooo00<000000?ooo`3oool01`3oool6000000X0oooo
2@00003o0?oooiP0oooo00180?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0603oool3000001D0oooo0P00000C0?ooo`X000001@3oool200000?l0oooo
Z@3oool00500oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01@0oooo
1000000J0?ooo`8000005`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo
YP3oool004l0oooo0P0000040?ooo`800000503oool3000000<0oooo00<000000?ooo`3oool06P3o
ool3000001<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?ooojH0oooo001X
0?ooo`<000001P3oool00`000000oooo0?ooo`0M0?ooo`8000004@3oool00`000000oooo0?ooo`09
0?ooo`800000o`3ooonW0?ooo`00I@3oool3000002/0oooo0P00000?0?ooo`030000003oool0oooo
00H0oooo0`00003o0?ooojT0oooo001R0?ooo`<000005@3oool900000180oooo0`00000=0?ooo`03
0000003oool0oooo0080oooo0`00003o0?oooj`0oooo001O0?ooo`<000005`3oool00`000000oooo
0?ooo`070?ooo`8000004`3oool2000000`0oooo1000003o0?ooojl0oooo001L0?ooo`<000006@3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo0`00003o0?oook`0oooo001I
0?ooo`<000006`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01D0oooo0P00003o
0?oookX0oooo001F0?ooo`<000007`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01H0oooo0P00003o0?oookP0oooo001C0?ooo`<000008P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01@0oooo0`00003o0?oookX0oooo001?0?ooo`@000005@3oool8000000T0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0@0?ooo`@00000o`3ooonm0?ooo`00C03o
ool3000001H0oooo0`0000080?ooo`800000203oool3000000H0oooo0P00000@0?ooo`<00000o`3o
ooo10?ooo`00B@3oool300000080oooo00<000000?ooo`3oool04P3oool2000000d0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo00000005000000L0oooo00<000000?ooo`3oool01P3oool2
00000?l0ooooa03oool004H0oooo0`0000050?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool0o`3oooo<0?ooo`00@`3oool3000000P0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00L0oooo0P00000;0?ooo`800000o`3oooo=0?ooo`00
@03oool3000000/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool02@3oool2000000L0oooo0P00003o0?oooll0oooo
000m0?ooo`<000006@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo1`00
003o0?ooom40oooo000j0?ooo`<000007@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo0?l0ooooi03oool003L0oooo0`00000Q0?ooo`040000003oool0oooo0?ooo`8000003`3oool2
00000?l0ooooi`3oool003@0oooo0`00000T0?ooo`@000002P3oool700000?l0ooooj@3oool00340
oooo0`00000T0?ooo`<000000P3oool00`000000oooo0?ooo`0:0?ooo`8000002`3oool200000?l0
ooooh03oool002d0oooo1000000S0?ooo`@000001P3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00D0oooo0`00003o0?ooon80oooo000Z0?ooo`@00000503oool9000000L0oooo0P00
000;0?ooo`030000003oool0oooo00/0oooo0P0000020?ooo`<00000o`3ooooU0?ooo`009`3oool3
000000<0oooo00<000000?ooo`3oool0403oool2000000T0oooo0P0000070?ooo`@00000203oool0
0`000000oooo0?ooo`0<0?ooo`800000o`3ooooX0?ooo`00903oool3000000H0oooo00<000000?oo
o`3oool03P3oool2000000`0oooo00<000000?ooo`3oool02@3oool3000000H0oooo00<000000?oo
o`3oool0o`3ooooe0?ooo`008@3oool3000001X0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`0;0?ooo`@000000`3oool00`000000oooo0?ooo`3o0?oooo@0oooo000N0?ooo`<00000
503oool2000000L0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`D00000
o`3ooooe0?ooo`006`3oool3000001@0oooo0`0000090?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04P3oool200000?l0oooom03oool001P0oooo0`00000C0?ooo`@000006P3oool2
00000?l0ooooo`3oool<0?ooo`005@3oool3000001<0oooo0`00000L0?ooo`800000o`3ooooo0?oo
o`h0oooo000B0?ooo`<00000503oool300000200oooo0`00003o0?ooool0oooo2`3oool000h0oooo
1000000J0?ooo`D000007P3oool400000?l0ooooo`3oool70?ooo`002`3oool3000002<0oooo1@00
000M0?ooo`800000o`3ooooo0?ooo`D0oooo00080?ooo`<0000000<0oooo0000003oool0:03oool4
000001H0oooo0`00003o0?ooool0oooo1`3oool000D0oooo0`0000040?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool06@3oool3000000l0oooo1000003o0?ooool0oooo2P3oool00080
oooo0`0000070?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06`3oool2000000/0
oooo0P00003o0?ooool0oooo3P3oool0008000007P3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo0?l0ooooo`3ooolH0?ooo`008@3oool2000001d0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo000S0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaP0oooo000T0?ooo`030000003oool0oooo00d0oooo0P0000070?ooo`800000o`3ooooo0?oo
oa/0oooo000U0?ooo`030000003oool0oooo00h0oooo1`00003o0?ooool0oooo7@3oool002H0oooo
00<000000?ooo`3oool0o`3ooooo0?oooc40oooo000W0?ooo`800000o`3ooooo0?oooc40oooo000Y
0?ooo`030000003oool0oooo0?l0ooooo`3oool^0?ooo`005`3oool3000000X0oooo1@0000000`3o
ool000000?ooo`3o0?ooool0oooo;P3oool001L0oooo0`00000?0?ooo`<00000o`3ooooo0?ooobh0
oooo000H0?ooo`@00000o`3ooooo0?oooch0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {210.125, 0}} -> {0.0478041, 0.300333, \
0.00171464, 0.00171464}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<,./<>?;'[]:\"{}\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .39891 
%%ImageSize: 600 239.345 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0396315 1.03963 -0.305918 1.03963 [
[.05122 .27593 -5.47152 -9 ]
[.05122 .27593 6.52848 0 ]
[.24136 .2133 -11.4039 -9 ]
[.24136 .2133 12.5961 0 ]
[.44122 .14748 -2.97535 -9 ]
[.44122 .14748 3.02465 0 ]
[.65156 .07822 -9.33011 -9 ]
[.65156 .07822 8.66989 0 ]
[.87326 .00526 -3.25638 -9 ]
[.87326 .00526 2.74362 0 ]
[.43953 .08325 -4.95654 -12.75 ]
[.43953 .08325 5.04346 0 ]
[.95833 .01957 0 -5.96243 ]
[.95833 .01957 24 3.03757 ]
[.97706 .04691 0 -5.94485 ]
[.97706 .04691 6 3.05515 ]
[.99543 .07373 0 -5.92769 ]
[.99543 .07373 18 3.07231 ]
[1.03893 .02705 0 -8.42187 ]
[1.03893 .02705 10 4.32813 ]
[ 0 0 0 0 ]
[ 1 .39891 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00143 .30485 m
.92981 0 L
s
.05008 .28888 m
.04951 .29535 L
s
[(-5)] .05122 .27593 -0.08808 1 Mshowa
.24071 .22628 m
.24039 .23277 L
s
[(-2.5)] .24136 .2133 -0.04968 1 Mshowa
.44111 .16047 m
.44106 .16697 L
s
[(0)] .44122 .14748 -0.00822 1 Mshowa
.65204 .09121 m
.65228 .0977 L
s
[(2.5)] .65156 .07822 .03668 1 Mshowa
.87436 .01821 m
.87492 .02468 L
s
[(5)] .87326 .00526 .08546 1 Mshowa
.125 Mabswid
.08746 .2766 m
.08715 .28049 L
s
.12521 .26421 m
.12492 .2681 L
s
.16333 .25169 m
.16307 .25558 L
s
.20183 .23905 m
.2016 .24294 L
s
.27999 .21338 m
.27982 .21728 L
s
.31966 .20036 m
.31953 .20425 L
s
.35973 .1872 m
.35963 .19109 L
s
.40021 .1739 m
.40015 .1778 L
s
.48243 .14691 m
.48243 .15081 L
s
.52417 .1332 m
.52421 .1371 L
s
.56635 .11935 m
.56642 .12325 L
s
.60897 .10535 m
.60908 .10925 L
s
.69557 .07692 m
.69574 .08081 L
s
.73955 .06247 m
.73977 .06637 L
s
.78401 .04788 m
.78426 .05177 L
s
.82894 .03312 m
.82924 .03701 L
s
.01306 .30103 m
.01269 .30491 L
s
.92027 .00313 m
.92065 .00701 L
s
gsave
.43953 .08325 -65.9565 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.92981 0 m
.99832 .09996 L
s
.94597 .02358 m
.93979 .02559 L
s
[(-0.5)] .95833 .01957 -1 .32498 Mshowa
.96469 .05089 m
.9585 .05287 L
s
[(0)] .97706 .04691 -1 .32108 Mshowa
.98304 .07766 m
.97685 .07962 L
s
[(0.5)] .99543 .07373 -1 .31726 Mshowa
.125 Mabswid
.94975 .02909 m
.94604 .03029 L
s
.9535 .03457 m
.94979 .03577 L
s
.95725 .04003 m
.95354 .04123 L
s
.96097 .04547 m
.95726 .04666 L
s
.96839 .05628 m
.96468 .05747 L
s
.97207 .06166 m
.96836 .06285 L
s
.97574 .06701 m
.97203 .0682 L
s
.9794 .07235 m
.97568 .07353 L
s
.94218 .01806 m
.93848 .01926 L
s
.93838 .01251 m
.93467 .01372 L
s
.93456 .00694 m
.93086 .00815 L
s
.93073 .00135 m
.92702 .00256 L
s
.98667 .08295 m
.98295 .08413 L
s
.99028 .08822 m
.98656 .0894 L
s
.99388 .09347 m
.99016 .09464 L
s
.99747 .0987 m
.99375 .09987 L
s
gsave
1.03893 .02705 -61 -12.4219 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .39891 L
0 .39891 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.24291 .34184 m
.08418 .28755 L
s
.05979 .33546 m
.06111 .33175 L
s
.05303 .33436 m
.05979 .33546 L
s
.05434 .33065 m
.05303 .33436 L
s
.06111 .33175 m
.05566 .32693 L
s
.06111 .33175 m
.05434 .33065 L
s
.05566 .32693 m
.04208 .32471 L
s
.09361 .32128 m
.09223 .32502 L
s
.09223 .32502 m
.08546 .32391 L
s
.08546 .32391 m
.08683 .32017 L
s
.08683 .32017 m
.09361 .32128 L
s
.31729 .29584 m
.22683 .29501 L
s
.22683 .29501 m
.27135 .25043 L
s
.35137 .28505 m
.3983 .24011 L
s
.46461 .25587 m
.47579 .25566 L
s
.45781 .2547 m
.46461 .25587 L
s
.47579 .25566 m
.49341 .25011 L
s
.4486 .25096 m
.45781 .2547 L
s
.44618 .24839 m
.4486 .25096 L
s
.49341 .25011 m
.49988 .24474 L
s
.49988 .24474 m
.50194 .24076 L
s
.50194 .24076 m
.50163 .23416 L
s
.3983 .24011 m
.30585 .23925 L
s
.50163 .23416 m
.49685 .22895 L
s
.49685 .22895 m
.4876 .22514 L
s
.4876 .22514 m
.48074 .22393 L
s
.4581 .22437 m
.45078 .21648 L
s
.48074 .22393 m
.4581 .22437 L
s
.5827 .22197 m
.58491 .21791 L
s
.57588 .22076 m
.5827 .22197 L
s
.57807 .2167 m
.57588 .22076 L
s
.63261 .21967 m
.66456 .20965 L
s
.63261 .21967 m
.55782 .13263 L
s
.63716 .21824 m
.56248 .1311 L
s
.58491 .21791 m
.58028 .21263 L
s
.58028 .21263 m
.5711 .20877 L
s
.52315 .207 m
.52103 .21109 L
s
.52103 .21109 m
.51414 .20987 L
s
.51414 .20987 m
.51625 .20578 L
s
.5711 .20877 m
.56423 .20755 L
s
.51625 .20578 m
.52315 .207 L
s
.44046 .19911 m
.43847 .20323 L
s
.43847 .20323 m
.43152 .20201 L
s
.43152 .20201 m
.43351 .19789 L
s
.69213 .201 m
.72454 .19084 L
s
.43351 .19789 m
.44046 .19911 L
s
.50423 .19241 m
.50634 .18826 L
s
.49729 .19118 m
.50423 .19241 L
s
.7199 .1923 m
.64727 .10337 L
s
.49939 .18703 m
.49729 .19118 L
s
.72454 .19084 m
.65203 .10182 L
s
.50634 .18826 m
.50149 .18286 L
s
.50634 .18826 m
.49939 .18703 L
s
.50149 .18286 m
.48754 .18038 L
s
.79102 .15632 m
.77585 .13684 L
s
.82917 .14429 m
.81421 .12464 L
s
.73592 .13906 m
.7334 .14336 L
s
.7334 .14336 m
.72644 .14209 L
s
.72644 .14209 m
.72895 .13777 L
s
.72895 .13777 m
.73592 .13906 L
s
.88841 .13602 m
.87943 .13193 L
s
.88841 .13602 m
.8815 .13474 L
s
.90015 .13579 m
.88841 .13602 L
s
.8815 .13474 m
.8725 .13064 L
s
.55782 .13263 m
.59055 .12192 L
s
.87943 .13193 m
.87526 .12629 L
s
.8725 .13064 m
.86832 .12499 L
s
.87526 .12629 m
.87594 .11909 L
s
.86832 .12499 m
.86899 .11778 L
s
.72025 .11932 m
.71773 .1237 L
s
.71773 .1237 m
.71071 .1224 L
s
.71071 .1224 m
.71321 .11802 L
s
.9489 .12051 m
.95671 .11458 L
s
.71321 .11802 m
.72025 .11932 L
s
.87594 .11909 m
.87872 .1147 L
s
.86899 .11778 m
.87175 .11339 L
s
.87872 .1147 m
.87941 .10744 L
s
.95671 .11458 m
.95761 .10732 L
s
.95671 .11458 m
.95962 .11018 L
s
.87175 .11339 m
.87243 .10612 L
s
.61881 .11268 m
.65203 .10182 L
s
.95962 .11018 m
.96053 .10289 L
s
.87941 .10744 m
.87521 .1017 L
s
.95761 .10732 m
.95358 .10158 L
s
.87243 .10612 m
.86821 .10038 L
s
.96053 .10289 m
.9565 .09713 L
s
.87521 .1017 m
.86609 .09749 L
s
.95358 .10158 m
.94458 .09737 L
s
.86821 .10038 m
.85418 .09773 L
s
.84227 .09797 m
.85758 .0859 L
s
.86609 .09749 m
.84227 .09797 L
s
.94458 .09737 m
.9376 .09605 L
s
.9565 .09713 m
.94749 .09291 L
s
.9376 .09605 m
.92856 .09183 L
s
.94749 .09291 m
.9405 .09159 L
s
.84991 .09195 m
.85544 .08298 L
s
.92856 .09183 m
.92444 .08602 L
s
.9405 .09159 m
.93145 .08735 L
s
.93145 .08735 m
.92733 .08152 L
s
.92444 .08602 m
.92526 .0786 L
s
.85758 .0859 m
.85822 .07848 L
s
.85544 .08298 m
.85115 .07713 L
s
.92733 .08152 m
.93314 .07249 L
s
.92526 .0786 m
.94106 .06635 L
s
.85822 .07848 m
.85393 .07261 L
s
.85115 .07713 m
.84191 .07285 L
s
.84191 .07285 m
.83482 .07151 L
s
.85393 .07261 m
.84468 .06832 L
s
.83482 .07151 m
.82553 .06721 L
s
.84468 .06832 m
.83757 .06696 L
s
.82553 .06721 m
.82115 .06129 L
s
.83757 .06696 m
.82828 .06265 L
s
.91695 .06684 m
.90778 .06253 L
s
.94106 .06635 m
.91695 .06684 L
s
.929 .06659 m
.91486 .06388 L
s
.91486 .06388 m
.91067 .05795 L
s
.82828 .06265 m
.82389 .05671 L
s
.90778 .06253 m
.90357 .05659 L
s
.82115 .06129 m
.8217 .05374 L
s
.91067 .05795 m
.91146 .05038 L
s
.82389 .05671 m
.82445 .04913 L
s
.90357 .05659 m
.90434 .04901 L
s
.8217 .05374 m
.82445 .04913 L
s
.91146 .05038 m
.91437 .04577 L
s
.82445 .04913 m
.83219 .04289 L
s
.90434 .04901 m
.90724 .04439 L
s
.91437 .04577 m
.91518 .03812 L
s
.90724 .04439 m
.90803 .03674 L
s
.91518 .03812 m
.91095 .03208 L
s
.90803 .03674 m
.90378 .03069 L
s
.91095 .03208 m
.90165 .02766 L
s
.90378 .03069 m
.89447 .02626 L
s
.90165 .02766 m
.89447 .02626 L
s
.89447 .02626 m
.88224 .02652 L
s
0 g
.25 Mabswid
.00143 .30485 m
.92981 0 L
s
.05008 .28888 m
.04951 .29535 L
s
[(-5)] .05122 .27593 -0.08808 1 Mshowa
.24071 .22628 m
.24039 .23277 L
s
[(-2.5)] .24136 .2133 -0.04968 1 Mshowa
.44111 .16047 m
.44106 .16697 L
s
[(0)] .44122 .14748 -0.00822 1 Mshowa
.65204 .09121 m
.65228 .0977 L
s
[(2.5)] .65156 .07822 .03668 1 Mshowa
.87436 .01821 m
.87492 .02468 L
s
[(5)] .87326 .00526 .08546 1 Mshowa
.125 Mabswid
.08746 .2766 m
.08715 .28049 L
s
.12521 .26421 m
.12492 .2681 L
s
.16333 .25169 m
.16307 .25558 L
s
.20183 .23905 m
.2016 .24294 L
s
.27999 .21338 m
.27982 .21728 L
s
.31966 .20036 m
.31953 .20425 L
s
.35973 .1872 m
.35963 .19109 L
s
.40021 .1739 m
.40015 .1778 L
s
.48243 .14691 m
.48243 .15081 L
s
.52417 .1332 m
.52421 .1371 L
s
.56635 .11935 m
.56642 .12325 L
s
.60897 .10535 m
.60908 .10925 L
s
.69557 .07692 m
.69574 .08081 L
s
.73955 .06247 m
.73977 .06637 L
s
.78401 .04788 m
.78426 .05177 L
s
.82894 .03312 m
.82924 .03701 L
s
.01306 .30103 m
.01269 .30491 L
s
.92027 .00313 m
.92065 .00701 L
s
gsave
.43953 .08325 -65.9565 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 239.313},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000kb000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooonh0oooo0P00001Y0?ooo`00o`3oooo]0?ooo`040000003oool0oooo000006P0oooo003o
0?oooo00oooo00<000000?ooo`3oool0IP3oool00?l0ooookP3oool2000006T0oooo003o0?ooonh0
oooo00<000000?ooo`3oool0J03oool00?l0ooookP3oool3000001h0oooo0P0000180?ooo`00o`3o
oooo0?ooo`d0oooo0`0000000`3oool00000000000170?ooo`00o`3ooooo0?ooo`X0oooo0`000002
0?ooo`80000000<0oooo0000003oool0AP3oool00?l0ooooo`3oool70?ooo`<0000000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`140?ooo`00o`3ooooo0?ooo`@0oooo0`0000040?ooo`03
0000003oool0oooo00D0oooo0P0000150?ooo`00o`3ooooo0?ooo`40oooo0`00000=0?ooo`800000
00<0oooo0000003oool0A03oool00?l0ooooo@3oool3000001@0oooo00<000000?ooo`3oool0@P3o
ool00?l0oooonP3oool3000001L0oooo0P00000B0?ooo`800000103oool2000000@0oooo0P00000S
0?ooo`00o`3oooog0?ooo`<00000603oool2000000030?ooo`000000oooo0100oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000R0?ooo`00o`3ooood0?ooo`<000007`3oool0
0`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0803o
ool00?l0ooool@3oool3000002<0oooo00<000000?ooo`3oool01`3oool400000080oooo00@00000
0?ooo`3oool000002@3oool2000001X0oooo0P0000070?ooo`00o`3oooo]0?ooo`@00000903oool3
000000l0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00D0oooo003o0?ooonX0oooo0`0000030?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool03@3oool2000000X0oooo0`00000K0?ooo`030000003oool0oooo00@0oooo003o0?oo
onL0oooo0`0000070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo000000050?ooo`00o`3ooooT0?ooo`<000002P3oool00`000000oooo0?ooo`0T0?ooo`80
0000=P3oool010000000oooo0?ooo`0000050?ooo`00o`3ooooQ0?ooo`<000004@3oool9000001L0
oooo0`0000020?ooo`030000003oool0oooo0380oooo0`0000000`3oool00000000000040?ooo`00
o`3ooooN0?ooo`<00000703oool5000001T0oooo00<000000?ooo`3oool0>`3oool00?l0oooof`3o
ool300000240oooo0P0000000`3oool000000000000E0?ooo`<00000?@3oool00?l0oooof03oool3
000002H0oooo00<000000?ooo`3oool00P00000F0?ooo`030000003oool0oooo03X0oooo003o0?oo
omD0oooo0`00000Z0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool0>@3oool0
0?l0oooodP3oool3000000030?ooo`000000oooo02X0oooo00D000000?ooo`3oool0oooo0000000F
0?ooo`030000003oool0oooo03T0oooo003o0?oooll0oooo0`0000050?ooo`030000003oool0oooo
02T0oooo00@000000?ooo`3oool00000503oool2000000030?ooo`000000oooo03T0oooo003o0?oo
ol`0oooo0`00000d0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000oooo0?ooo`0g
0?ooo`00o`3oooo90?ooo`<00000=`3oool01@000000oooo0?ooo`3oool0000001L0oooo00<00000
0?ooo`3oool02P3oool2000002/0oooo003o0?ooolH0oooo0`00000j0?ooo`050000003oool0oooo
0?ooo`0000005@3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000:P3o
ool00?l0oooo``3oool300000180oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3o
ool0000001T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000Z0?ooo`00o`3o
ooo00?ooo`<00000503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000002X0oooo
003o0?oookd0oooo0`00000E0?ooo`800000:`3oool01@000000oooo0?ooo`3oool0000001P0oooo
0P0000000`3oool000000?ooo`070?ooo`040000003oool0oooo000002X0oooo003o0?oookX0oooo
1000000F0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0P00000[0?ooo`00o`3ooong0?ooo`<000000`3o
ool00`000000oooo0?ooo`0C0?ooo`800000;03oool01@000000oooo0?ooo`3oool0000001`0oooo
0P00000e0?ooo`00o`3ooond0?ooo`<000001P3oool00`000000oooo0?ooo`0C0?ooo`800000;03o
ool01@000000oooo0?ooo`3oool0000001X0oooo0P0000020?ooo`030000003oool0oooo0380oooo
003o0?oook40oooo0`00000N0?ooo`030000003oool0000002`0oooo00D000000?ooo`3oool0oooo
0000000O0?ooo`030000003oool0oooo0340oooo003o0?ooojd0oooo1000000Q0?ooo`030000003o
ool0000002`0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`800000<P3oool00?l0ooooZP3o
ool3000002D0oooo00<000000?ooo`000000;03oool01@000000oooo0?ooo`3oool0000001d0oooo
0P0000000`3oool000000?ooo`0a0?ooo`00o`3ooonW0?ooo`<00000:03oool010000000oooo0?oo
o`00000/0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000oooo0?ooo`0_0?ooo`00
o`3ooonT0?ooo`<00000:`3oool010000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?oo
o`000000803oool200000300oooo003o0?oooj40oooo1000000^0?ooo`030000003oool0oooo0080
0000:`3oool200000080oooo0P00000L0?ooo`80000000<0oooo0000003oool0;`3oool00?l0oooo
JP3oool4000000<0oooo0P0000040?ooo`8000009@3oool3000000<0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`3oool2000002/0oooo0P0000020?ooo`@00000703oool00`000000
oooo0?ooo`0]0?ooo`00o`3ooomZ0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
00008@3oool3000000H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`<0
0000:P3oool@00000180oooo0P00000<0?ooo`800000103oool2000000@0oooo0P00000D0?ooo`00
mP3oool2000000030?ooo`000000000006l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0L0?ooo`<00000>`3oool2000000D0oooo1000000d0?ooo`030000003oool0oooo0100oooo
0`00000;0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004`3oool00?L0
oooo00<000000?ooo`000000L@3oool00`000000oooo0?ooo`080?ooo`800000703oool300000400
oooo0P0000070?ooo`<00000;`3oool2000001H0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo0140oooo003h0?ooo`030000003oool0oooo06h0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0H0?ooo`<00000A@3oool20000
00P0oooo0P00000/0?ooo`030000003oool0oooo01H0oooo0P0000090?ooo`040000003oool0oooo
000000T0oooo0P00000D0?ooo`00mP3oool2000000030?ooo`000000000006l0oooo0P00000:0?oo
o`<000005@3oool3000004X0oooo100000050?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool05P3oool3000000T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooon<0?ooo`<00000D@3oool2000000@0oooo00<000000?ooo`3oool09P3oool20000
01`0oooo00<000000?ooo`3oool01`3oool2000000X0oooo0`00000C0?ooo`00o`3ooon90?ooo`<0
0000EP3oool200000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0000000L0?ooo`80
0000:P3oool00?l0ooooQP3oool300000080oooo00<000000?ooo`3oool0EP3oool010000000oooo
0?ooo`00000U0?ooo`030000003oool0000001X0oooo0`0000000`3oool000000?ooo`0Y0?ooo`00
o`3ooon30?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`040000003oool0oooo000002D0
oooo0P00000P0?ooo`030000003oool0oooo02L0oooo003o0?oooh00oooo0`00001R0?ooo`030000
003oool0000002D0oooo00<000000?ooo`0000007`3oool2000002P0oooo003o0?ooogd0oooo0`00
001T0?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`0000007P3oool3000002P0oooo
003o0?ooogX0oooo0`00001W0?ooo`040000003oool0oooo000002D0oooo00@000000?ooo`3oool0
0000803oool00`000000oooo0?ooo`0U0?ooo`00o`3ooomg0?ooo`<00000J@3oool010000000oooo
0?ooo`00000W0?ooo`030000003oool0oooo008000007P3oool2000002H0oooo003o0?ooog@0oooo
0`00001/0?ooo`<00000:03oool00`000000oooo0?ooo`020?ooo`8000006`3oool3000002H0oooo
003o0?ooog40oooo0`00001^0?ooo`800000:`3oool00`000000oooo0?ooo`030?ooo`<000006`3o
ool00`000000oooo0?ooo`0S0?ooo`00o`3ooom^0?ooo`<0000000<0oooo0000003oool0KP3oool0
0`000000oooo0?ooo`0[0?ooo`8000001P3oool4000001L0oooo0P00000T0?ooo`00o`3ooomZ0?oo
o`@00000103oool00`000000oooo0?ooo`1[0?ooo`800000<03oool2000000P0oooo0P00000D0?oo
o`<00000903oool00?l0ooooI`3oool3000000P0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`0b0?ooo`D000001@3oool2000001D0oooo00<000000?ooo`3oool08@3oool00?l0oooo
I03oool3000000/0oooo00<000000?ooo`3oool0J@3oool@000002/0oooo0P0000040?ooo`030000
003oool0oooo01<0oooo0P00000R0?ooo`00o`3ooomQ0?ooo`<00000Q@3oool7000002/0oooo0P00
00030?ooo`030000003oool0oooo0140oooo0`00000R0?ooo`00o`3ooomN0?ooo`<00000403oool2
000007/0oooo00@000000?ooo`0000000000:`3oool010000000oooo0?ooo`00000h0?ooo`00o`3o
oomK0?ooo`<00000403oool300000080oooo00<000000?ooo`3oool0N03oool01@000000oooo0?oo
o`3oool0000002/0oooo00@000000?ooo`3oool00000=`3oool00?l0ooooF03oool300000100oooo
0`0000020?ooo`050000003oool0oooo0?ooo`000000NP3oool010000000oooo0?ooo`00000[0?oo
o`040000003oool0oooo000003L0oooo003o0?oooeD0oooo0`0000020?ooo`030000003oool0oooo
00X0oooo100000060?ooo`040000003oool0oooo000007X0oooo00D000000?ooo`3oool0oooo0000
000[0?ooo`030000003oool0000003L0oooo003o0?oooe80oooo0`0000050?ooo`030000003oool0
oooo00L0oooo0`00000;0?ooo`040000003oool0oooo000007T0oooo00D000000?ooo`3oool0oooo
0000000[0?ooo`030000003oool0000003L0oooo003o0?ooodl0oooo0`00000?0?ooo`<000003P3o
ool01@000000oooo0?ooo`3oool0000007P0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`03
0000003oool0000003L0oooo003o0?oood`0oooo0`00000@0?ooo`8000004P3oool01@000000oooo
0?ooo`3oool0000007L0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`800000>03oool00?l0
ooooB@3oool3000002P0oooo00D000000?ooo`3oool0oooo0000001f0?ooo`050000003oool0oooo
0?ooo`000000:`3oool00`000000oooo0?ooo`0g0?ooo`00o`3ooom60?ooo`<00000;03oool01@00
0000oooo0?ooo`3oool0000007@0oooo00D000000?ooo`3oool0oooo0000000[0?ooo`030000003o
ool0oooo03P0oooo003o0?oood<0oooo0`00000`0?ooo`040000003oool0oooo000001/0oooo0P00
001F0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool09`3oool2000003/0oooo003o
0?oood00oooo0`00000d0?ooo`040000003oool0oooo000001T0oooo00<000000?ooo`3oool00`00
001C0?ooo`050000003oool0oooo0?ooo`000000:@3oool00`000000oooo0?ooo`0k0?ooo`00o`3o
oolm0?ooo`<000000P3oool00`000000oooo0?ooo`090?ooo`8000009`3oool01@000000oooo0?oo
o`3oool0000001P0oooo00D000000?ooo`3oool0oooo0000001D0?ooo`050000003oool0oooo0?oo
o`000000:03oool00`000000oooo0?ooo`0l0?ooo`00o`3ooolj0?ooo`<000001@3oool00`000000
oooo0?ooo`060?ooo`<00000:P3oool01@000000oooo0?ooo`3oool0000001H0oooo1@00001E0?oo
o`050000003oool0oooo0?ooo`000000I`3oool00?l0oooo=`3oool3000000h0oooo0`00000^0?oo
o`050000003oool0oooo0?ooo`000000D03oool00`000000oooo0?ooo`0L0?ooo`050000003oool0
oooo0?ooo`000000I`3oool00?l0oooo=03oool3000000h0oooo0`00000b0?ooo`040000003oool0
oooo00000540oooo00<000000?ooo`3oool0703oool010000000oooo0?ooo`00001W0?ooo`00o`3o
oola0?ooo`<000003P3oool3000003H0oooo00@000000?ooo`3oool00000D@3oool00`000000oooo
0?ooo`0K0?ooo`050000003oool0oooo0?ooo`000000IP3oool00?l0oooo;P3oool3000000h0oooo
0`00000j0?ooo`040000003oool0oooo00000500oooo00<000000?ooo`3oool0703oool010000000
oooo0?ooo`00001V0?ooo`00o`3oool[0?ooo`<000003`3oool3000003`0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`030000003oool0oooo01`0oooo0P0000000`3oool000000000001T0?oo
o`00n@3oool2000002/0oooo1000000C0?ooo`030000003oool0000003`0oooo00D000000?ooo`3o
ool0oooo0000001@0?ooo`030000003oool0oooo01d0oooo0P0000000`3oool000000000001R0?oo
o`00n03oool010000000oooo0?ooo`00000W0?ooo`<000000`3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0000003`0oooo00D000000?ooo`3oool0oooo0000001@0?ooo`030000003oool0
oooo01h0oooo3000001I0?ooo`00n03oool010000000oooo0?ooo`00000T0?ooo`<000001P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0000003`0oooo00@000000?ooo`3oool000006`3o
ool2000001P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`220?ooo`00n03oool0
10000000oooo0?ooo`00000Q0?ooo`<000007`3oool010000000oooo0?ooo`00000l0?ooo`040000
003oool0oooo000001T0oooo00<000000?ooo`3oool00`00000F0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool0P@3oool00?P0oooo00@000000?ooo`3oool000007P3oool3000002<0
oooo00<000000?ooo`000000?@3oool010000000oooo0?ooo`00000H0?ooo`050000003oool0oooo
0?ooo`000000603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0840oooo003i0?oo
o`800000703oool3000002L0oooo00<000000?ooo`000000?03oool01@000000oooo0?ooo`3oool0
000001H0oooo0P0000030?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`200?ooo`00o`3ooolE0?ooo`<00000:`3oool00`000000oooo0000000l0?oo
o`050000003oool0oooo0?ooo`0000005`3oool3000001X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`1o0?ooo`00o`3ooolB0?ooo`<00000;`3oool00`000000oooo0000000l0?oo
o`040000003oool0oooo000003D0oooo00<000000?ooo`3oool0VP3oool00?l0oooo3`3oool40000
0380oooo00<000000?ooo`000000?03oool010000000oooo0?ooo`00000e0?ooo`030000003oool0
oooo09T0oooo003o0?ooo``0oooo0`0000030?ooo`030000003oool0oooo0300oooo00@000000?oo
o`3oool00000?03oool010000000oooo0?ooo`00000e0?ooo`030000003oool0oooo09P0oooo003o
0?ooo`T0oooo0`0000060?ooo`030000003oool0oooo0340oooo00@000000?ooo`3oool00000?03o
ool010000000oooo0?ooo`00000e0?ooo`030000003oool0oooo09L0oooo003o0?ooo`H0oooo0`00
000n0?ooo`040000003oool0oooo000003`0oooo00@000000?ooo`3oool00000=03oool00`000000
oooo0?ooo`2G0?ooo`00o`3oool30?ooo`<00000@P3oool00`000000oooo0000000l0?ooo`050000
003oool0oooo0?ooo`000000=03oool00`000000oooo0?ooo`2F0?ooo`00o`3oool3000004H0oooo
00<000000?ooo`000000?03oool010000000oooo0?ooo`00000e0?ooo`030000003oool0oooo09D0
oooo003l0?ooo`<00000BP3oool00`000000oooo0000000l0?ooo`040000003oool0oooo00000<`0
oooo003i0?ooo`<00000C@3oool010000000oooo0?ooo`00000l0?ooo`040000003oool0oooo0000
0</0oooo003f0?ooo`<0000000<0oooo0000003oool0CP3oool010000000oooo0?ooo`00000l0?oo
o`040000003oool0oooo00000<X0oooo003c0?ooo`<00000103oool00`000000oooo0?ooo`1>0?oo
o`040000003oool0oooo000003`0oooo00@000000?ooo`3oool00000b@3oool00?00oooo0`000007
0?ooo`030000003oool0oooo04l0oooo00@000000?ooo`3oool00000>`3oool01@000000oooo0?oo
o`3oool000000<P0oooo003]0?ooo`<000002P3oool00`000000oooo0?ooo`1@0?ooo`040000003o
ool0oooo000003/0oooo00@000000?ooo`3oool00000b03oool00>X0oooo0`00001Q0?ooo`030000
003oool0000003`0oooo00@000000?ooo`3oool00000a`3oool00>H0oooo1000001T0?ooo`040000
003oool0oooo000003`0oooo00@000000?ooo`3oool00000aP3oool00><0oooo0`00001Y0?ooo`04
0000003oool0oooo000003`0oooo00@000000?ooo`3oool00000a@3oool00>00oooo0`00001]0?oo
o`040000003oool0oooo000003`0oooo00@000000?ooo`3oool00000a03oool00=d0oooo0`000002
0?ooo`030000003oool0oooo06`0oooo00@000000?ooo`3oool00000>`3oool010000000oooo0?oo
o`0000340?ooo`00fP3oool3000000D0oooo00<000000?ooo`3oool0K@3oool010000000oooo0?oo
o`00000k0?ooo`040000003oool0oooo00000<<0oooo003G0?ooo`<00000N@3oool010000000oooo
0?ooo`00000k0?ooo`040000003oool0oooo00000<80oooo003D0?ooo`<00000?@3oool4000003`0
oooo00@000000?ooo`3oool00000>`3oool010000000oooo0?ooo`0000310?ooo`00d@3oool30000
04@0oooo1@00000g0?ooo`040000003oool0oooo000003`0oooo00@000000?ooo`3oool00000`03o
ool00<h0oooo0`00001<0?ooo`030000003oool0oooo03D0oooo00@000000?ooo`3oool00000?03o
ool010000000oooo0?ooo`00002o0?ooo`00b`3oool3000004d0oooo0P0000000`3oool000000?oo
o`0f0?ooo`040000003oool0oooo000003/0oooo00@000000?ooo`3oool00000_`3oool00<P0oooo
1000001>0?ooo`030000003oool0oooo00<00000=`3oool010000000oooo0?ooo`00000k0?ooo`04
0000003oool0oooo00000;h0oooo00350?ooo`<000000`3oool00`000000oooo0?ooo`1<0?ooo`05
0000003oool0oooo0?ooo`000000>@3oool010000000oooo0?ooo`00000k0?ooo`040000003oool0
000000000;d0oooo00320?ooo`<000001P3oool00`000000oooo0?ooo`1;0?ooo`D00000>`3oool0
10000000oooo0?ooo`00000i0?ooo`<00000_`3oool00;l0oooo0`00002G0?ooo`050000003oool0
oooo0?ooo`000000=@3oool300000<80oooo002l0?ooo`<00000V`3oool01@000000oooo0?ooo`3o
ool000000340oooo0`0000350?ooo`00^@3oool3000003T0oooo0P00001T0?ooo`040000003oool0
oooo000002h0oooo0`0000380?ooo`00Q03oool4000000<0oooo0P0000040?ooo`8000008`3oool3
000003`0oooo00<000000?ooo`0000000P00001R0?ooo`040000003oool0oooo000002X0oooo0`00
003;0?ooo`00Q03oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000001l0oooo0`00
000n0?ooo`050000003oool0oooo0?ooo`000000I03oool010000000oooo0?ooo`00000W0?ooo`80
0000cP3oool008D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0J0?ooo`<00000
0P3oool00`000000oooo0?ooo`0l0?ooo`D00000I@3oool010000000oooo0?ooo`00003f0?ooo`00
OP3oool4000000@0oooo00<000000?ooo`3oool0203oool2000001X0oooo0`0000050?ooo`030000
003oool0oooo0:H0oooo00D000000?ooo`3oool0oooo0000003e0?ooo`00Q03oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo01H0oooo0`00001g0?ooo`800000>@3oool01@000000
oooo0?ooo`3oool000000?@0oooo00250?ooo`8000002P3oool3000001<0oooo0`00001i0?ooo`03
0000003oool0oooo00<000005P3oool2000001l0oooo00D000000?ooo`3oool0oooo0000003c0?oo
o`00X`3oool4000007`0oooo0P0000020?ooo`030000003oool0oooo01L0oooo1000000L0?ooo`05
0000003oool0oooo0?ooo`0000004@3oool200000=l0oooo002P0?ooo`<00000PP3oool3000001d0
oooo0P00000K0?ooo`040000003oool0oooo000000h0oooo0`00003Q0?ooo`00W@3oool300000:L0
oooo0P00000J0?ooo`040000003oool0oooo000000X0oooo0`00003T0?ooo`00VP3oool300000003
0?ooo`000000oooo0:T0oooo00<000000?ooo`3oool05`3oool01@000000oooo0?ooo`3oool00000
00H0oooo0`00003W0?ooo`00U`3oool3000000@0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`150?ooo`040000003oool0oooo000001T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`<00000jP3oool009@0oooo0`00001Y0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<00000k@3oool00940
oooo0`00001]0?ooo`030000003oool0oooo0480oooo0P0000020?ooo`030000003oool0oooo01T0
oooo0P00003`0?ooo`00SP3oool300000740oooo00<000000?ooo`3oool0@`3oool300000?l0oooo
3P3oool008/0oooo0`00001e0?ooo`l00000o`3ooom70?ooo`00R03oool3000008L0oooo1000003o
0?oood<0oooo00250?ooo`@00000S@3oool200000?l0oooo@@3oool00880oooo0`0000030?ooo`03
0000003oool0oooo08d0oooo0P00003o0?ooocl0oooo001o0?ooo`<000001P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0?l0oooo?03oool007`0oooo0`0000090?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00N@3oool300000:00oooo00<00000
0?ooo`3oool0o`3ooolj0?ooo`00MP3oool300000:<0oooo00<000000?ooo`3oool0o`3ooolj0?oo
o`00L`3oool300000:H0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00L03oool3000003X0oooo
=@00000j0?ooo`030000003oool0oooo0?l0oooo>P3oool006d0oooo0`0000020?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`3o0?ooocX0oooo001Z
0?ooo`<000001@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0o`3ooolk0?ooo`00I`3oool3000007@0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`3o0?oooc/0oooo001T0?ooo`<00000MP3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo0?l0oooo?03oool00600oooo1000001h0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool06@3oool200000?l0oooo?`3oool005d0oooo0`00000i0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0F0?ooo`800000o`3o
oom10?ooo`00FP3oool3000003/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0Q
0?ooo`8000004`3oool300000?l0oooo@`3oool005L0oooo0`0000020?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0T0?ooo`8000003@3oool40000
0?l0ooooAP3oool005@0oooo0`0000050?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0W0?ooo`d00000o`3ooom:0?ooo`00D@3oool300000440oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooogl0oooo001>0?ooo`<00000@`3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooP03oool004/0oooo0`000015
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooon10?ooo`007`3oool20000
02L0oooo0`0000170?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooon20?oo
o`007P3oool010000000oooo0?ooo`00000S0?ooo`<00000B@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0?l0ooooP`3oool00240oooo00<000000?ooo`3oool07P3oool300000003
0?ooo`000000oooo04P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oooh@0
oooo000H0?ooo`@000000`3oool2000001h0oooo0`0000040?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooohD0oooo000O0?ooo`030000003o
ool0oooo01X0oooo0`00001?0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3o
oon60?ooo`007`3oool3000001L0oooo0`00001A0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0o`3ooon70?ooo`00=P3oool3000005<0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`3o0?ooohP0oooo000c0?ooo`<00000EP3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo0?l0ooooR@3oool00300oooo0`00001H0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool0o`3ooon:0?ooo`00;@3oool3000000030?ooo`000000oooo05L0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oooh/0oooo000Z0?ooo`<00000103oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooon<
0?ooo`009`3oool3000005h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oo
ohd0oooo000T0?ooo`<00000H03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0
ooooSP3oool00200oooo1000001R0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
o`3ooon?0?ooo`007@3oool3000000l0oooo0P00001D0?ooo`030000003oool0oooo0?l0ooood@3o
ool001X0oooo0`00000D0?ooo`<00000D03oool00`000000oooo0?ooo`3o0?ooom80oooo000G0?oo
o`<000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000C03oool00`000000oooo0?ooo`3o0?oo
om<0oooo000D0?ooo`<000001@3oool00`000000oooo0?ooo`0H0?ooo`<00000B03oool00`000000
oooo0?ooo`3o0?ooom@0oooo000A0?ooo`<00000203oool00`000000oooo0?ooo`0K0?ooo`<00000
A03oool00`000000oooo0?ooo`3o0?ooomD0oooo000>0?ooo`<000002`3oool00`000000oooo0?oo
o`0N0?ooo`800000@@3ooold00000?l0ooooY@3oool000/0oooo0`00000a0?ooo`<00000o`3ooooo
0?oooaP0oooo00080?ooo`<00000=`3oool300000?l0ooooo`3ooolE0?ooo`001@3oool3000003d0
oooo0`00003o0?ooool0oooo4P3oool00080oooo0`0000020?ooo`030000003oool0oooo03h0oooo
0`00003o0?ooool0oooo3`3oool0008000001@3oool00`000000oooo0?ooo`110?ooo`<00000o`3o
oooo0?ooo``0oooo001>0?ooo`<00000o`3ooooo0?ooo`T0oooo001A0?ooo`<00000o`3ooooo0?oo
o`H0oooo001D0?ooo`<00000o`3ooooo0?ooo`<0oooo001G0?ooo`<00000o`3ooooo0?ooo`00FP3o
ool200000?l0ooooo@3oool005`0oooo0`00003o0?ooooX0oooo001O0?ooo`<00000o`3oooog0?oo
o`00HP3oool300000?l0oooom03oool00340oooo1@00000_0?ooo`<00000o`3ooooa0?ooo`00<03o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo0`00003o0?ooonh0oooo000G
0?ooo`8000005`3oool200000080oooo00<000000?ooo`3oool0=03oool300000?l0ooooj`3oool0
01T0oooo1000000E0?ooo`<00000>@3oool300000?l0ooooj03oool001d0oooo0`00001A0?ooo`<0
0000o`3ooooU0?ooo`00803oool200000580oooo0`00003o0?ooon80oooo000N0?ooo`D00000E03o
ool300000?l0oooog`3oool001h0oooo00@000000?ooo`3oool00000F03oool200000?l0oooog@3o
ool001h0oooo1000001J0?ooo`<00000o`3ooooJ0?ooo`00O`3oool300000?l0ooooe`3oool00880
oooo0`00003o0?ooom@0oooo00250?ooo`<00000o`3ooooA0?ooo`00R03oool200000?l0ooooc`3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oo
oeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 599}, {238.313, 0}} -> {0.0381158, 0.278835, \
0.00169667, 0.00169667}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay[FromCharacterCode[Range[945, 969]]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3531 
%%ImageSize: 600 211.859 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0504718 1.05047 -0.337689 1.05047 [
[.03103 .29164 -8.22789 -9 ]
[.03103 .29164 9.77211 0 ]
[.2399 .22391 -5.72394 -9 ]
[.2399 .22391 6.27606 0 ]
[.45991 .15259 -2.99114 -9 ]
[.45991 .15259 3.00886 0 ]
[.69196 .07738 -3.13142 -9 ]
[.69196 .07738 2.86858 0 ]
[.93707 -0.00203 -6.56857 -9 ]
[.93707 -0.00203 5.43143 0 ]
[.45912 .08726 -4.98425 -12.75 ]
[.45912 .08726 5.01575 0 ]
[.98986 .00309 0 -5.95045 ]
[.98986 .00309 24 3.04955 ]
[1.00019 .01816 0 -5.94128 ]
[1.00019 .01816 6 3.05872 ]
[1.01042 .03307 0 -5.93222 ]
[1.01042 .03307 18 3.06778 ]
[1.0609 -0.00453 0 -8.41909 ]
[1.0609 -0.00453 10 4.33091 ]
[ 0 0 0 0 ]
[ 1 .3531 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00074 .31415 m
.97247 0 L
s
.02991 .30472 m
.02935 .31126 L
s
[(-10)] .03103 .29164 -0.08579 1 Mshowa
.2393 .23703 m
.239 .24359 L
s
[(-5)] .2399 .22391 -0.04601 1 Mshowa
.45987 .16572 m
.45985 .17229 L
s
[(0)] .45991 .15259 -0.00295 1 Mshowa
.69253 .0905 m
.69282 .09706 L
s
[(5)] .69196 .07738 .04381 1 Mshowa
.93831 .01104 m
.93893 .01758 L
s
[(10)] .93707 -0.00203 .09476 1 Mshowa
.125 Mabswid
.07093 .29146 m
.07063 .29538 L
s
.11238 .27806 m
.1121 .28199 L
s
.15425 .26452 m
.15401 .26845 L
s
.19656 .25085 m
.19634 .25478 L
s
.28249 .22306 m
.28234 .227 L
s
.32614 .20895 m
.32602 .21289 L
s
.37024 .19469 m
.37016 .19863 L
s
.41482 .18028 m
.41477 .18422 L
s
.5054 .151 m
.50542 .15494 L
s
.55143 .13612 m
.55149 .14006 L
s
.59795 .12108 m
.59805 .12502 L
s
.64498 .10587 m
.64512 .10981 L
s
.7406 .07496 m
.74081 .07889 L
s
.78921 .05925 m
.78946 .06318 L
s
.83836 .04336 m
.83865 .04729 L
s
.88805 .02729 m
.88839 .03122 L
s
gsave
.45912 .08726 -65.9843 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97247 0 m
.9991 .0388 L
s
.97736 .00712 m
.97111 .00913 L
s
[(-0.5)] .98986 .00309 -1 .32232 Mshowa
.98768 .02216 m
.98143 .02417 L
s
[(0)] 1.00019 .01816 -1 .32028 Mshowa
.9979 .03706 m
.99165 .03905 L
s
[(0.5)] 1.01042 .03307 -1 .31827 Mshowa
.125 Mabswid
.97943 .01014 m
.97568 .01135 L
s
.9815 .01316 m
.97775 .01436 L
s
.98357 .01617 m
.97982 .01737 L
s
.98563 .01917 m
.98188 .02037 L
s
.98974 .02516 m
.98598 .02636 L
s
.99178 .02814 m
.98803 .02934 L
s
.99383 .03112 m
.99008 .03232 L
s
.99587 .03409 m
.99211 .03529 L
s
.97528 .00409 m
.97153 .0053 L
s
.9732 .00106 m
.96945 .00227 L
s
gsave
1.0609 -0.00453 -61 -12.4191 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .3531 L
0 .3531 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05311 .33116 m
.04716 .3302 L
s
.05788 .33108 m
.05311 .33116 L
s
.05788 .33108 m
.06146 .32994 L
s
.04716 .3302 m
.04298 .32866 L
s
.06146 .32994 m
.06206 .32831 L
s
.04298 .32866 m
.0376 .32607 L
s
.06206 .32831 m
.06147 .32563 L
s
.0376 .32607 m
.034 .32289 L
s
.06865 .32333 m
.074 .32593 L
s
.06147 .32563 m
.05552 .31599 L
s
.10446 .32483 m
.09851 .32386 L
s
.10924 .32474 m
.10446 .32483 L
s
.10924 .32474 m
.11285 .3236 L
s
.09851 .32386 m
.09019 .32077 L
s
.11285 .3236 m
.11412 .32033 L
s
.0603 .32024 m
.06865 .32333 L
s
.034 .32289 m
.03338 .3202 L
s
.09019 .32077 m
.08484 .31816 L
s
.11412 .32033 m
.11061 .31714 L
s
.05312 .3182 m
.0603 .32024 L
s
.03338 .3202 m
.03576 .31798 L
s
.04414 .31674 m
.05312 .3182 L
s
.08484 .31816 m
.0783 .31448 L
s
.03576 .31798 m
.03934 .31683 L
s
.11061 .31714 m
.10645 .31559 L
s
.09324 .31692 m
.09568 .3147 L
s
.09866 .31519 m
.09324 .31692 L
s
.03934 .31683 m
.04414 .31674 L
s
.05552 .31599 m
.05492 .31328 L
s
.10645 .31559 m
.10346 .3151 L
s
.10346 .3151 m
.09866 .31519 L
s
.09568 .3147 m
.09693 .31141 L
s
.0783 .31448 m
.06934 .30864 L
s
.05492 .31328 m
.05552 .31163 L
s
.07415 .30855 m
.07592 .31234 L
s
.05552 .31163 m
.05732 .31105 L
s
.09693 .31141 m
.09638 .30869 L
s
.11796 .31047 m
.12277 .31038 L
s
.11198 .30949 m
.11796 .31047 L
s
.12277 .31038 m
.12458 .3098 L
s
.12458 .3098 m
.12705 .30757 L
s
.09638 .30869 m
.09282 .30547 L
s
.06934 .30864 m
.05795 .30063 L
s
.07477 .3069 m
.07415 .30855 L
s
.12705 .30757 m
.1277 .30592 L
s
.07719 .30467 m
.07477 .3069 L
s
.1277 .30592 m
.126 .30211 L
s
.09282 .30547 m
.08864 .3039 L
s
.08082 .3035 m
.07719 .30467 L
s
.17287 .30453 m
.17654 .30337 L
s
.16988 .30404 m
.17287 .30453 L
s
.16757 .30189 m
.16988 .30404 L
s
.08864 .3039 m
.08563 .30341 L
s
.08563 .30341 m
.08082 .3035 L
s
.14463 .30341 m
.1393 .30076 L
s
.17654 .30337 m
.17905 .30112 L
s
.126 .30211 m
.1213 .2978 L
s
.16709 .29915 m
.16757 .30189 L
s
.17905 .30112 m
.18042 .2978 L
s
.1393 .30076 m
.13513 .29919 L
s
.13513 .29919 m
.11357 .29297 L
s
.16844 .29582 m
.16709 .29915 L
s
.1213 .2978 m
.11357 .29297 L
s
.15811 .29766 m
.15211 .29667 L
s
.16294 .29757 m
.15811 .29766 L
s
.16844 .29582 m
.16294 .29757 L
s
.15211 .29667 m
.14678 .29401 L
s
.1698 .29248 m
.16844 .29582 L
s
.14678 .29401 m
.14326 .29076 L
s
.11357 .29297 m
.10517 .28981 L
s
.16816 .28863 m
.1698 .29248 L
s
.14326 .29076 m
.14158 .28691 L
s
.10517 .28981 m
.09978 .28713 L
s
.16467 .28536 m
.16816 .28863 L
s
.1894 .28768 m
.18709 .2855 L
s
.19425 .28759 m
.1894 .28768 L
s
.1998 .28582 m
.19425 .28759 L
s
.14158 .28691 m
.14224 .28523 L
s
.20235 .28354 m
.1998 .28582 L
s
.18709 .2855 m
.18662 .28272 L
s
.15932 .28268 m
.16467 .28536 L
s
.14224 .28523 m
.14475 .28295 L
s
.23079 .28468 m
.22779 .28418 L
s
.23564 .28459 m
.23079 .28468 L
s
.22779 .28418 m
.22665 .28309 L
s
.20306 .28186 m
.20235 .28354 L
s
.22665 .28309 m
.22737 .2814 L
s
.14475 .28295 m
.14843 .28177 L
s
.18662 .28272 m
.19102 .27985 L
s
.15329 .28168 m
.15932 .28268 L
s
.14843 .28177 m
.15329 .28168 L
s
.22737 .2814 m
.23181 .27853 L
s
.18246 .28113 m
.17643 .28013 L
s
.19102 .27985 m
.18246 .28113 L
s
.17643 .28013 m
.1741 .27794 L
s
.23181 .27853 m
.23741 .27675 L
s
.1741 .27794 m
.17363 .27515 L
s
.22767 .27693 m
.21979 .27652 L
s
.23741 .27675 m
.22767 .27693 L
s
.21979 .27652 m
.21075 .27501 L
s
.17363 .27515 m
.17617 .27285 L
s
.21075 .27501 m
.20543 .2723 L
s
.17617 .27285 m
.18174 .27106 L
s
.20543 .2723 m
.20312 .2701 L
s
.18662 .27097 m
.19266 .27198 L
s
.18174 .27106 m
.18662 .27097 L
s
.24635 .27097 m
.25009 .26978 L
s
.24032 .26996 m
.24635 .27097 L
s
.20312 .2701 m
.20267 .26729 L
s
.23617 .26835 m
.24032 .26996 L
s
.25009 .26978 m
.25083 .26807 L
s
.25083 .26807 m
.24856 .26586 L
s
.20267 .26729 m
.20409 .26388 L
s
.25646 .26628 m
.26135 .26619 L
s
.25043 .26526 m
.25646 .26628 L
s
.26135 .26619 m
.26511 .26499 L
s
.24856 .26586 m
.24211 .26203 L
s
.24211 .26203 m
.25043 .26526 L
s
.26511 .26499 m
.26661 .26157 L
s
.20409 .26388 m
.20738 .25986 L
s
.30506 .26254 m
.30093 .26092 L
s
.30884 .26134 m
.30506 .26254 L
s
.24211 .26203 m
.23033 .25545 L
s
.26661 .26157 m
.26321 .25823 L
s
.31151 .25902 m
.30884 .26134 L
s
.30093 .26092 m
.29869 .2587 L
s
.20738 .25986 m
.20694 .25703 L
s
.28208 .25958 m
.28586 .25837 L
s
.27604 .25856 m
.28208 .25958 L
s
.31006 .25508 m
.31151 .25902 L
s
.29869 .2587 m
.29722 .25475 L
s
.27189 .25693 m
.27604 .25856 L
s
.28586 .25837 m
.28662 .25665 L
s
.19783 .25549 m
.19829 .25833 L
s
.26321 .25823 m
.25563 .25326 L
s
.20694 .25703 m
.20461 .2548 L
s
.28662 .25665 m
.28437 .25442 L
s
.20158 .25428 m
.19783 .25549 L
s
.3067 .25172 m
.31006 .25508 L
s
.20461 .2548 m
.20158 .25428 L
s
.29722 .25475 m
.29764 .25018 L
s
.28437 .25442 m
.27681 .24944 L
s
.25563 .25326 m
.23734 .24274 L
s
.29919 .24673 m
.3067 .25172 L
s
.29764 .25018 m
.29919 .24673 L
s
.27681 .24944 m
.27341 .24607 L
s
.29919 .24673 m
.30265 .24265 L
s
.2939 .24396 m
.29919 .24673 L
s
.27341 .24607 m
.27303 .24321 L
s
.32575 .24565 m
.31409 .23899 L
s
.28974 .24232 m
.2939 .24396 L
s
.27303 .24321 m
.27379 .24148 L
s
.28253 .24016 m
.28974 .24232 L
s
.27379 .24148 m
.27759 .24026 L
s
.27759 .24026 m
.28253 .24016 L
s
.31409 .23899 m
.30768 .23507 L
s
.34871 .23833 m
.3254 .22489 L
s
.38142 .23828 m
.38528 .23706 L
s
.38528 .23706 m
.38804 .2347 L
s
.30768 .23507 m
.30543 .23281 L
s
.38804 .2347 m
.38888 .23295 L
s
.35914 .23352 m
.347 .23144 L
s
.36409 .23342 m
.35914 .23352 L
s
.36602 .23281 m
.36409 .23342 L
s
.38888 .23295 m
.3835 .20621 L
s
.30543 .23281 m
.30621 .23106 L
s
.36684 .23106 m
.36602 .23281 L
s
.31613 .23087 m
.32029 .23252 L
s
.34012 .23215 m
.34285 .22978 L
s
.34204 .23153 m
.34012 .23215 L
s
.347 .23144 m
.34204 .23153 L
s
.30621 .23106 m
.31004 .22983 L
s
.31004 .22983 m
.31613 .23087 L
s
.34285 .22978 m
.34366 .22802 L
s
.34366 .22802 m
.34194 .22108 L
s
.38727 .22603 m
.36017 .21372 L
s
.34194 .22108 m
.34275 .21931 L
s
.34275 .21931 m
.34468 .21869 L
s
.34468 .21869 m
.34773 .21922 L
s
.41642 .21673 m
.3816 .1962 L
s
.41011 .21276 m
.40268 .20761 L
s
.43597 .2105 m
.42445 .20366 L
s
.40268 .20761 m
.39938 .20414 L
s
.44971 .20612 m
.45561 .20424 L
s
.45561 .20424 m
.44716 .1979 L
s
.39938 .20414 m
.40109 .20056 L
s
.42445 .20366 m
.41811 .19964 L
s
.41615 .20027 m
.42445 .20366 L
s
.40109 .20056 m
.40501 .1993 L
s
.41003 .1992 m
.41615 .20027 L
s
.41811 .19964 m
.41592 .19731 L
s
.40501 .1993 m
.41003 .1992 L
s
.50154 .19862 m
.49849 .19809 L
s
.50656 .19853 m
.50154 .19862 L
s
.49849 .19809 m
.49743 .19692 L
s
.47534 .19794 m
.47015 .19508 L
s
.44716 .1979 m
.43976 .19269 L
s
.41592 .19731 m
.41679 .19552 L
s
.42685 .19532 m
.431 .19702 L
s
.49743 .19692 m
.49835 .19513 L
s
.41679 .19552 m
.42072 .19425 L
s
.42072 .19425 m
.42685 .19532 L
s
.49835 .19513 m
.50325 .19206 L
s
.47015 .19508 m
.46602 .19338 L
s
.46602 .19338 m
.45882 .19113 L
s
.49119 .19289 m
.48707 .19118 L
s
.49623 .19279 m
.49119 .19289 L
s
.50325 .19206 m
.49623 .19279 L
s
.43976 .19269 m
.43452 .18982 L
s
.50325 .19206 m
.50922 .19016 L
s
.48707 .19118 m
.48493 .18884 L
s
.45882 .19113 m
.44964 .18953 L
s
.44153 .18909 m
.43452 .18982 L
s
.44964 .18953 m
.44153 .18909 L
s
.48493 .18884 m
.48677 .18522 L
s
.48677 .18522 m
.49167 .18213 L
s
.47758 .18361 m
.47344 .18189 L
s
.48263 .18351 m
.47758 .18361 L
s
.49167 .18213 m
.48263 .18351 L
s
.49167 .18213 m
.49566 .18086 L
s
.47344 .18189 m
.47128 .17953 L
s
.52201 .18154 m
.5159 .18046 L
s
.52707 .18145 m
.52201 .18154 L
s
.53108 .18017 m
.52707 .18145 L
s
.5159 .18046 m
.51071 .17756 L
s
.53403 .17771 m
.53108 .18017 L
s
.47128 .17953 m
.4731 .17589 L
s
.53499 .17589 m
.53403 .17771 L
s
.51071 .17756 m
.50751 .17401 L
s
.4731 .17589 m
.47892 .17095 L
s
.53383 .17169 m
.53499 .17589 L
s
.50751 .17401 m
.50632 .16981 L
s
.55213 .17194 m
.55922 .17119 L
s
.546 .17085 m
.55213 .17194 L
s
.53066 .16812 m
.53383 .17169 L
s
.55922 .17119 m
.58552 .16281 L
s
.47892 .17095 m
.47984 .16911 L
s
.56325 .16991 m
.54045 .15577 L
s
.50632 .16981 m
.50725 .16797 L
s
.47984 .16911 m
.47768 .16673 L
s
.4726 .16683 m
.4686 .16812 L
s
.52546 .16519 m
.53066 .16812 L
s
.50725 .16797 m
.5102 .16549 L
s
.47768 .16673 m
.4726 .16683 L
s
.57336 .16668 m
.56913 .15887 L
s
.5102 .16549 m
.51422 .1642 L
s
.51931 .1641 m
.52546 .16519 L
s
.51422 .1642 m
.51931 .1641 L
s
.56913 .15887 m
.56592 .15221 L
s
.60279 .15577 m
.59664 .15467 L
s
.6079 .15567 m
.60279 .15577 L
s
.61198 .15437 m
.6079 .15567 L
s
.59664 .15467 m
.5915 .15171 L
s
.61504 .15186 m
.61198 .15437 L
s
.56592 .15221 m
.5648 .14794 L
s
.61605 .15 m
.61504 .15186 L
s
.5915 .15171 m
.56763 .13617 L
s
.5915 .15171 m
.58838 .14809 L
s
.61501 .14573 m
.61605 .15 L
s
.58838 .14809 m
.58729 .14381 L
s
.61192 .14209 m
.61501 .14573 L
s
.63553 .14532 m
.63245 .14477 L
s
.64271 .14457 m
.63553 .14532 L
s
.63245 .14477 m
.62835 .143 L
s
.64889 .1426 m
.64271 .14457 L
s
.58729 .14381 m
.58829 .14194 L
s
.62835 .143 m
.6263 .14058 L
s
.65405 .13941 m
.64889 .1426 L
s
.60676 .13911 m
.61192 .14209 L
s
.58829 .14194 m
.59134 .13941 L
s
.6263 .14058 m
.6263 .13749 L
s
.59134 .13941 m
.59544 .1381 L
s
.6551 .13754 m
.65405 .13941 L
s
.60058 .13799 m
.60676 .13911 L
s
.59544 .1381 m
.60058 .13799 L
s
.6263 .13749 m
.62836 .13373 L
s
.62836 .13373 m
.63353 .12741 L
s
.6768 .13215 m
.67064 .13103 L
s
.68196 .13205 m
.6768 .13215 L
s
.70276 .12542 m
.68196 .13205 L
s
.67064 .13103 m
.66552 .12802 L
s
.68926 .12818 m
.68611 .13073 L
s
.69034 .12629 m
.68926 .12818 L
s
.66552 .12802 m
.66248 .12434 L
s
.63353 .12741 m
.63353 .12429 L
s
.6894 .12194 m
.69034 .12629 L
s
.66248 .12434 m
.6615 .11999 L
s
.63353 .12429 m
.63147 .12183 L
s
.62837 .12127 m
.62423 .1226 L
s
.68638 .11824 m
.6894 .12194 L
s
.63147 .12183 m
.62837 .12127 L
s
.7122 .12086 m
.71947 .12009 L
s
.70602 .11973 m
.7122 .12086 L
s
.71947 .12009 m
.74255 .11273 L
s
.6615 .11999 m
.66256 .11809 L
s
.68126 .1152 m
.68638 .11824 L
s
.66256 .11809 m
.6657 .11551 L
s
.72785 .11742 m
.70757 .10206 L
s
.6657 .11551 m
.66987 .11417 L
s
.67506 .11407 m
.68126 .1152 L
s
.66987 .11417 m
.67506 .11407 L
s
.75519 .1087 m
.75941 .10735 L
s
.749 .10756 m
.75519 .1087 L
s
.74492 .10574 m
.749 .10756 L
s
.75941 .10735 m
.76054 .10543 L
s
.76054 .10543 m
.75858 .10294 L
s
.75858 .10294 m
.74843 .09679 L
s
.77978 .09617 m
.78271 .09992 L
s
.74843 .09679 m
.74546 .09303 L
s
.77375 .09183 m
.77978 .09617 L
s
.74546 .09303 m
.74772 .08915 L
s
.76556 .08815 m
.77375 .09183 L
s
.79992 .0913 m
.79371 .09015 L
s
.80516 .0912 m
.79992 .0913 L
s
.79371 .09015 m
.78866 .08705 L
s
.74772 .08915 m
.75197 .08779 L
s
.75934 .087 m
.76556 .08815 L
s
.75197 .08779 m
.75934 .087 L
s
.82109 .08768 m
.81488 .08653 L
s
.82537 .08631 m
.82109 .08768 L
s
.78866 .08705 m
.78573 .08326 L
s
.81488 .08653 m
.80674 .08284 L
s
.82775 .08242 m
.82537 .08631 L
s
.78573 .08326 m
.78592 .08004 L
s
.80674 .08284 m
.7976 .07788 L
s
.82487 .07862 m
.82775 .08242 L
s
.84041 .08152 m
.84471 .08015 L
s
.84471 .08015 m
.84712 .07623 L
s
.78592 .08004 m
.78708 .07809 L
s
.81983 .07549 m
.82487 .07862 L
s
.78708 .07809 m
.79038 .07544 L
s
.7976 .07788 m
.78137 .0672 L
s
.84712 .07623 m
.84384 .05026 L
s
.81263 .07305 m
.81983 .07549 L
s
.79038 .07544 m
.79682 .07337 L
s
.79682 .07337 m
.80424 .07257 L
s
.80424 .07257 m
.81263 .07305 L
s
.87279 .07119 m
.86874 .06933 L
s
.86874 .06933 m
.86156 .06688 L
s
.91409 .06907 m
.87031 .0385 L
s
.88147 .06843 m
.88581 .06704 L
s
.87524 .06725 m
.88147 .06843 L
s
.87119 .06539 m
.87524 .06725 L
s
.88581 .06704 m
.88705 .06507 L
s
.86156 .06688 m
.82937 .05972 L
s
.88705 .06507 m
.88517 .0625 L
s
.88517 .0625 m
.87828 .05677 L
s
.82937 .05972 m
.82214 .05725 L
s
.82214 .05725 m
.81803 .05537 L
s
.87828 .05677 m
.87544 .0529 L
s
.91356 .05343 m
.91853 .05661 L
s
.90451 .04837 m
.91356 .05343 L
s
.87544 .0529 m
.87573 .04961 L
s
.84384 .05026 m
.84627 .04626 L
s
.93516 .04972 m
.92799 .04723 L
s
.94047 .04961 m
.93516 .04972 L
s
.87573 .04961 m
.87916 .04691 L
s
.89731 .04588 m
.90451 .04837 L
s
.92799 .04723 m
.92301 .04404 L
s
.87916 .04691 m
.88353 .0455 L
s
.84627 .04626 m
.85063 .04485 L
s
.89105 .04469 m
.89731 .04588 L
s
.88353 .0455 m
.89105 .04469 L
s
.92301 .04404 m
.92022 .04013 L
s
.96383 .04057 m
.96253 .04258 L
s
.96331 .03594 m
.96383 .04057 L
s
.92022 .04013 m
.91963 .03551 L
s
.94377 .03899 m
.93787 .03447 L
s
.96057 .03202 m
.96331 .03594 L
s
.91963 .03551 m
.9209 .03349 L
s
.93787 .03447 m
.93731 .02983 L
s
.93067 .03196 m
.93787 .03447 L
s
.9209 .03349 m
.92532 .03207 L
s
.92532 .03207 m
.93067 .03196 L
s
.9556 .02879 m
.96057 .03202 L
s
.93731 .02983 m
.9386 .0278 L
s
.94839 .02627 m
.9556 .02879 L
s
.9386 .0278 m
.94303 .02638 L
s
.94303 .02638 m
.94839 .02627 L
s
0 g
.25 Mabswid
.00074 .31415 m
.97247 0 L
s
.02991 .30472 m
.02935 .31126 L
s
[(-10)] .03103 .29164 -0.08579 1 Mshowa
.2393 .23703 m
.239 .24359 L
s
[(-5)] .2399 .22391 -0.04601 1 Mshowa
.45987 .16572 m
.45985 .17229 L
s
[(0)] .45991 .15259 -0.00295 1 Mshowa
.69253 .0905 m
.69282 .09706 L
s
[(5)] .69196 .07738 .04381 1 Mshowa
.93831 .01104 m
.93893 .01758 L
s
[(10)] .93707 -0.00203 .09476 1 Mshowa
.125 Mabswid
.07093 .29146 m
.07063 .29538 L
s
.11238 .27806 m
.1121 .28199 L
s
.15425 .26452 m
.15401 .26845 L
s
.19656 .25085 m
.19634 .25478 L
s
.28249 .22306 m
.28234 .227 L
s
.32614 .20895 m
.32602 .21289 L
s
.37024 .19469 m
.37016 .19863 L
s
.41482 .18028 m
.41477 .18422 L
s
.5054 .151 m
.50542 .15494 L
s
.55143 .13612 m
.55149 .14006 L
s
.59795 .12108 m
.59805 .12502 L
s
.64498 .10587 m
.64512 .10981 L
s
.7406 .07496 m
.74081 .07889 L
s
.78921 .05925 m
.78946 .06318 L
s
.83836 .04336 m
.83865 .04729 L
s
.88805 .02729 m
.88839 .03122 L
s
gsave
.45912 .08726 -65.9843 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 211.813},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000db000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?ooo`@0oooo
1@0000020?ooo`800000C@3oool00?l0ooooo`3oool60?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`110?ooo`8000001`3oool00?l0ooooo`3oool60?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo
003o0?ooool0oooo1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`040?ooo`00o`3ooooo0?ooo`H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0480oooo00<000000?ooo`0000001@3oool00?l0ooooo`3o
ool50?ooo`800000103oool2000004@0oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3o
oom@0?ooo`<0000000<0oooo000000000000103oool00?l0ooooo`3oool_0?ooo`800000103oool2
000000@0oooo0P00000M0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000L0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`0J0?ooo`00o`3ooooo0?oooa`0oooo0`0000090?ooo`@000000P3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00?l0ooooo`3ooolI0?ooo`H000003`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01`0oooo003o0?ooool0oooo5P3oool3
000000@0oooo0`00000?0?ooo`8000002P3oool3000001`0oooo003o0?ooool0oooo4`3oool30000
00T0oooo0P00000i0?ooo`00o`3ooooo0?oooa00oooo0`00000;0?ooo`<00000>@3oool00?l0oooo
o`3oool<0?ooo`@000003@3oool01@000000oooo0?ooo`3oool0000003P0oooo003o0?ooool0oooo
2@3oool3000001<0oooo0`00000=0?ooo`800000:@3oool00?l0ooooo`3oool60?ooo`<0000000<0
oooo0000003oool05P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000002P0oooo
003o0?ooool0oooo0`3oool3000000D0oooo00<000000?ooo`3oool04P3oool2000000030?ooo`00
0000oooo00T0oooo00@000000?ooo`3oool00000:03oool00?l0ooooo`3oool3000000P0oooo00<0
00000?ooo`3oool04`3oool4000000T0oooo00@000000?ooo`3oool00000:03oool00?l0ooooo03o
ool3000002@0oooo0P0000080?ooo`040000003oool0oooo000002P0oooo003o0?ooooT0oooo0`00
000V0?ooo`<000002@3oool2000002T0oooo003o0?ooooH0oooo0`00000[0?ooo`800000<`3oool0
0?l0ooool`3oool3000002/0oooo0`0000000`3oool000000?ooo`0b0?ooo`00o`3oooo`0?ooo`<0
00006@3oool4000001@0oooo0`00000<0?ooo`800000103oool2000000@0oooo0P00000H0?ooo`00
o`3oooo/0?ooo`@000006P3oool2000000@0oooo0P00000E0?ooo`030000003oool0oooo00P0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000G0?ooo`00o`3ooooY0?ooo`<0
00000P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo0`00000@0?ooo`<0
00002P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01D0oooo003o0?ooonH0
oooo0`0000050?ooo`030000003oool0oooo0140oooo100000030?ooo`030000003oool0oooo00T0
oooo0P00000?0?ooo`<000002@3oool010000000oooo0?ooo`0000090?ooo`800000603oool00?l0
ooooh`3oool3000001X0oooo0P0000040?ooo`80000000<0oooo0000003oool02`3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000002@3oool00`00
0000oooo0?ooo`0G0?ooo`00o`3ooooP0?ooo`<00000703oool00`000000oooo0?ooo`060?ooo`80
00003@3oool00`000000oooo0?ooo`0=0?ooo`80000000<0oooo0000003oool01`3oool2000000X0
oooo0`00000G0?ooo`00o`3ooooM0?ooo`<000007`3oool00`000000oooo0?ooo`080?ooo`800000
2`3oool00`000000oooo0?ooo`0@0?ooo`800000;@3oool00?l0oooofP3oool3000000L0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0303oool3000000030?ooo`000000oooo02`0oooo003o0?ooomL0oooo0`00000;
0?ooo`800000603oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03h0oooo003o0?oo
om@0oooo0`00000@0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0o0?ooo`00o`3ooooA0?ooo`<00000103oool2000000h0oooo00<000000?ooo`3o
ool00`3oool300000100oooo00<000000?ooo`3oool0E@3oool00?l0oooocP3oool3000000030?oo
o`000000oooo0080oooo0P00000A0?ooo`D000000`3oool4000000d0oooo0P00001E0?ooo`00o`3o
ooo:0?ooo`@00000103oool010000000oooo0?ooo`00000C0?ooo`<000002@3oool3000000`0oooo
0P00001C0?ooo`00o`3oooo70?ooo`<000002`3oool00`000000oooo0?ooo`0?0?ooo`8000000`3o
ool2000000X0oooo0P00000<0?ooo`H00000C@3oool00?l0ooooa03oool3000000h0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo0P00001M
0?ooo`00o`3oooo10?ooo`<000004@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1J0?ooo`00o`3ooonn0?ooo`<0
00001P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01P3oool2000000/0oooo00<000000?ooo`3oool0F@3oool00?l0oooo^`3oool3000000X0oooo
0P00000<0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo05P0oooo003o0?oookL0oooo1000000?0?ooo`8000002P3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00L0oooo0P00001T0?ooo`00o`3ooone
0?ooo`<00000503oool4000000H0oooo00<000000?ooo`3oool04@3oool2000000T0oooo00<00000
0?ooo`3oool0H@3oool00?l0oooo/P3oool300000080oooo00<000000?ooo`3oool05P3oool40000
0080oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`070?ooo`800000H@3oool00?l0
ooooO`3oool2000002h0oooo0`0000050?ooo`030000003oool0oooo01X0oooo1@00000C0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0GP3oool00?l0ooooOP3oool010000000oooo
0?ooo`00000Y0?ooo`@000009`3oool00`000000oooo0?ooo`04000000L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05d0oooo003o0?oooh40oooo
00<000000?ooo`3oool0903oool3000000L0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`040?ooo`@00000103oool3000000@0oooo00<000000?ooo`3oool02`3oool2000005d0oooo
003o0?ooogl0oooo0P00000T0?ooo`<000002`3oool200000240oooo00<000000?ooo`3oool0203o
ool3000000@0oooo1000000@0?ooo`030000003oool0oooo05X0oooo003o0?ooogl0oooo00<00000
0?ooo`3oool0803oool300000100oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0:
0?ooo`800000L`3oool00?/0oooo0P0000000`3oool000000000001n0?ooo`<000007@3oool30000
01@0oooo0P0000020?ooo``000004@3oool00`000000oooo0?ooo`1o0?ooo`00o03oool00`000000
oooo0000002L0?ooo`<00000603oool3000000`0oooo0`00000>0?ooo`030000003oool0oooo07l0
oooo003m0?ooo`030000003oool0oooo09P0oooo1000000I0?ooo`030000003oool0oooo00800000
3P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo07l0oooo003k0?ooo`80000000<0
oooo000000000000U@3oool3000000<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`200?ooo`00o`3ooonC0?ooo`<000007`3oool00`000000oooo0?ooo`040?ooo`8000003@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0840oooo003o0?oooi00oooo0`00000R0?oo
o`030000003oool0oooo00H0oooo0P00000<0?ooo`030000003oool0oooo00@0oooo0P0000240?oo
o`00o`3ooon<0?ooo`@000009@3oool00`000000oooo0?ooo`080?ooo`8000002@3oool00`000000
oooo0?ooo`2;0?ooo`00o`3ooon90?ooo`<00000:@3oool00`000000oooo0?ooo`0:0?ooo`800000
1P3oool2000008d0oooo003o0?ooohH0oooo0`00000I0?ooo`T000002`3oool00`000000oooo0?oo
o`0;0?ooo`H00000S`3oool00?l0ooooP`3oool3000001X0oooo0P0000090?ooo`030000003oool0
oooo00T0oooo0P00002P0?ooo`00o`3ooon00?ooo`<00000703oool00`000000oooo0?ooo`0:0?oo
o`8000002`3oool8000009P0oooo003o0?ooogd0oooo0`0000000`3oool000000?ooo`0K0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0Z03oool00?l0ooooNP3oool3000000@0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`800000Z03oool00?l0ooooM`3o
ool3000000L0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0:D0oooo003o0?ooog@0oooo0`00000Z0?ooo`8000003`3oool00`000000oooo0?ooo`2T
0?ooo`00o`3oooma0?ooo`<00000;`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0:<0oooo003o0?ooofd0oooo1000000H0?ooo`030000003oool0oooo01P0oooo0P00002c0?ooo`00
o`3ooomZ0?ooo`<000007@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0;00oooo
003o0?ooofL0oooo0`00000Q0?ooo`8000004@3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0:l0oooo003o0?ooof@0oooo1000000U0?ooo`030000003oool0oooo00l0oooo0`000004
0?ooo`030000003oool0oooo0;00oooo003o0?ooof40oooo0`0000030?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool04@3oool400000;<0oooo003o0?oooeh0oooo0`0000060?ooo`03
0000003oool0oooo02D0oooo0P0000380?ooo`00o`3ooomK0?ooo`<00000<`3oool00`000000oooo
0?ooo`080?ooo`800000^`3oool00?l0ooooF03oool3000001T0oooo2000000F0?ooo`030000003o
ool0oooo00@0oooo0`00002m0?ooo`00o`3ooomE0?ooo`<000006P3oool2000000P0oooo0P00000E
0?ooo`H00000`03oool00?l0ooooDP3oool3000001/0oooo0P00000<0?ooo`030000003oool0oooo
0140oooo100000330?ooo`00o`3ooom?0?ooo`<000007P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00L0oooo0P0000050?ooo`<00000a`3oool00?l0ooooB`3oool4000000h0oooo
0`00000@0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool500000<X0oooo
003o0?ooodP0oooo0`0000000`3oool000000?ooo`0=0?ooo`8000000P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0e`3oool00?l0ooooA@3oool3
000000D0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool200000=40oooo003o0?oood80oooo0`00000K0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030000
0=<0oooo003o0?ooocl0oooo0`00000M0?ooo`030000003oool0oooo0100oooo0P00000;0?ooo`@0
0000eP3oool00?l0oooo?03oool3000001l0oooo00<000000?ooo`3oool04`3oool3000000H0oooo
0`00003I0?ooo`00o`3oooli0?ooo`<000008P3oool00`000000oooo0?ooo`0F0?ooo`H00000g03o
ool00?l0oooo=P3oool3000002@0oooo00<000000?ooo`3oool0n@3oool00?l0oooo<`3oool30000
00H0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`3j0?ooo`00oP3oool2000002l0
oooo100000090?ooo`800000303oool5000000`0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`3Z0?ooo`00o@3oool010000000oooo0?ooo`00000Z0?ooo`@000000`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00L0oooo0P0000050?ooo`<000002@3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo0>X0oooo003m0?ooo`040000003oool0oooo000002L0
oooo0`00000D0?ooo`8000001@3oool2000000X0oooo0P0000070?ooo`030000003oool0oooo00/0
oooo0P00003]0?ooo`00o@3oool010000000oooo0?ooo`00000T0?ooo`<000006@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool2000000T0
oooo0P00003_0?ooo`00o@3oool010000000oooo0?ooo`00000Q0?ooo`<000007@3oool01@000000
oooo0?ooo`3oool0000000h0oooo00<000000?ooo`3oool01P3oool900000?40oooo003n0?ooo`80
00007`3oool300000240oooo0P0000000`3oool000000?ooo`0=0?ooo`030000003oool0oooo0?l0
oooo0@3oool00?l0oooo7@3oool3000001X0oooo00<000000?ooo`3oool02@3oool2000000l0oooo
00<000000?ooo`3oool0o`3oool00?l0oooo6@3oool4000001d0oooo00<000000?ooo`3oool02P3o
ool2000000h0oooo00<000000?ooo`3oool0o`3oool00?l0oooo5`3oool300000240oooo00<00000
0?ooo`3oool02`3oool2000000/0oooo00<000000?ooo`3oool0o`3oool10?ooo`00o`3ooolD0?oo
o`<000000P3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00d0oooo0`0000060?oo
o`800000o`3oool40?ooo`00o`3ooolA0?ooo`<000001@3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool600000?l0oooo1P3oool00?l0oooo
3@3oool4000001d0oooo0P00000<0?ooo`030000003oool0oooo0?l0oooo6`3oool00?l0oooo2P3o
ool3000002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3o0?oooa/0oooo003o
0?ooo`L0oooo0`00000W0?ooo`8000002P3oool00`000000oooo0?ooo`3o0?oooaX0oooo003o0?oo
o`@0oooo0`00000/0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool20000
0?l0oooo4`3oool00?l0oooo0@3oool3000001P0oooo2@00000?0?ooo`800000203oool010000000
oooo0?ooo`3oool300000?l0oooo5@3oool00?d0oooo0`0000060?ooo`@00000403oool00`000000
oooo0?ooo`070?ooo`8000003`3oool00`000000oooo0?ooo`060?ooo`<00000o`3ooolH0?ooo`00
nP3oool300000080oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00d0oooo0P0000030?ooo`<00000
o`3ooolK0?ooo`00m`3oool3000000D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3oool2000000L0oooo0`00
003o0?oooah0oooo003d0?ooo`<00000203oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`L00000o`3ooolQ
0?ooo`00l@3oool3000001<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0?l0oooo;P3oool00>d0oooo1000000E0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooobd0oooo003Z0?ooo`<00000
603oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
o`3oool^0?ooo`00i`3oool3000001/0oooo00<000000?ooo`3oool0503oool2000000T0oooo00<0
00000?ooo`3oool0o`3oool_0?ooo`00i03oool3000001h0oooo00<000000?ooo`3oool02P3oool2
000000X0oooo2@00003o0?oooc80oooo003Q0?ooo`<000000P3oool00`000000oooo0?ooo`0M0?oo
o``00000o`3ooom70?ooo`00gP3oool3000000D0oooo00<000000?ooo`3oool09@3oool200000?l0
ooooB@3oool00=/0oooo0`00000_0?ooo`030000003oool0oooo0?l0ooooB@3oool00=P0oooo0`00
000b0?ooo`030000003oool0oooo0?l0ooooB@3oool00=D0oooo0`00000I0?ooo`/000004@3oool0
0`000000oooo0?ooo`090?ooo`800000o`3oooln0?ooo`00dP3oool3000001d0oooo0P0000080?oo
o`@000003P3oool00`000000oooo0?ooo`050?ooo`<00000o`3ooom00?ooo`00cP3oool4000001L0
oooo0P0000090?ooo`030000003oool0oooo00T0oooo1000000;0?ooo`P00000o`3ooom20?ooo`00
b`3oool3000000D0oooo00<000000?ooo`3oool04@3oool200000080oooo0`0000070?ooo`800000
3@3oool2000000h0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00b03oool300000080oooo00<0
00000?ooo`3oool0103oool200000100oooo00<000000?ooo`3oool01@3oool2000000L0oooo0P00
000=0?ooo`800000303oool00`000000oooo0?ooo`3o0?oood80oooo00350?ooo`<000001@3oool0
0`000000oooo0?ooo`060?ooo`800000203oool500000080oooo0P00000@0?ooo`030000003oool0
oooo01P0oooo1P00003o0?ooocl0oooo00320?ooo`<000004`3oool00`000000oooo0?ooo`030?oo
o`8000001@3oool3000000030?ooo`000000oooo00l0oooo00<000000?ooo`3oool0o`3ooomL0?oo
o`00_`3oool3000001L0oooo0P0000020?ooo`030000003oool0oooo00P0oooo0`00000@0?ooo`03
0000003oool0oooo0?l0ooooF`3oool00;`0oooo0`00000L0?ooo`<00000303oool3000000h0oooo
0P00003o0?oooe`0oooo002i0?ooo`<00000603oool00`000000oooo0?ooo`060?ooo`8000003P3o
ool2000000X0oooo0P00003o0?oooeh0oooo002f0?ooo`<000006`3oool00`000000oooo0?ooo`07
0?ooo`8000003`3oool200000?l0ooooJ03oool008L0oooo0P00000Z0?ooo`<000007P3oool00`00
0000oooo0?ooo`090?ooo`8000003`3oool200000?l0ooooIP3oool008H0oooo00@000000?ooo`3o
ool000009P3oool300000080oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`090?oo
o`800000o`3ooomf0?ooo`00R@3oool00`000000oooo0?ooo`0P0?ooo`@000001@3oool00`000000
oooo0?ooo`0?0?ooo`800000303oool00`000000oooo0?ooo`0;0?ooo`800000o`3ooomd0?ooo`00
P03oool4000000<0oooo0P00000P0?ooo`<000007@3oool2000000X0oooo00<000000?ooo`3oool0
3@3oool200000?l0ooooLP3oool008L0oooo00<000000?ooo`3oool0703oool300000280oooo0P00
00080?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooom_0?ooo`00Q`3oool3
000001T0oooo0`00000H0?ooo`@000002`3oool2000000H0oooo00<000000?ooo`3oool0o`3ooon1
0?ooo`00X03oool3000001X0oooo00<000000?ooo`3oool03`3oool3000000@0oooo00<000000?oo
o`3oool0o`3ooon00?ooo`00W03oool4000001d0oooo00<000000?ooo`3oool04P3oool200000080
oooo00<000000?ooo`3oool0o`3ooon00?ooo`00VP3oool3000001L0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0D0?ooo`<00000o`3ooon20?ooo`00U`3oool300000080oooo00<0
00000?ooo`3oool05P3oool2000000L0oooo00<000000?ooo`3oool05@3oool200000?l0ooooP@3o
ool009@0oooo0`0000050?ooo`030000003oool0oooo01P0oooo0P0000050?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0o`3ooon00?ooo`00T@3oool3000001P0oooo0P00000;0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`3o0?oo
ogl0oooo002=0?ooo`@000006@3oool200000080oooo0P00000:0?ooo`X000001`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0?l0ooooO`3oool008X0oooo0`00000L0?ooo`030000
003oool0oooo00@0oooo0P00000:0?ooo`030000003oool0oooo00D0oooo2000000;0?ooo`030000
003oool0oooo0?l0ooooO`3oool008L0oooo0`00000P0?ooo`030000003oool0oooo0100oooo0P00
000H0?ooo`030000003oool0oooo0?l0ooooO`3oool008@0oooo0`00000T0?ooo`8000004P3oool2
000001@0oooo0P00003o0?oooh80oooo00210?ooo`@00000:03oool200000180oooo00<000000?oo
o`3oool03`3oool200000?l0ooooQ03oool007h0oooo0`0000030?ooo`030000003oool0oooo01<0
oooo1000000A0?ooo`800000o`3ooonX0?ooo`00N`3oool3000000D0oooo0P00000C0?ooo`800000
103oool4000000H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?ooojD0oooo
001h0?ooo`<000002@3oool200000140oooo00<000000?ooo`3oool0203oool2000000<0oooo00<0
00000?ooo`3oool0203oool200000?l0ooooY@3oool007D0oooo0`00000>0?ooo`8000003`3oool0
0`000000oooo0?ooo`0:0?ooo`80000000<0oooo0000003oool02`3oool00`000000oooo0?ooo`3o
0?oooj80oooo001b0?ooo`<000004`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0o`3ooon`0?ooo`00KP3oool4000001L0oooo0P00000>0?ooo`03
0000003oool0oooo00T0oooo00@000000?ooo`0000000000o`3ooon`0?ooo`00J`3oool3000001d0
oooo0P00000=0?ooo`030000003oool0oooo00P0oooo00@000000?ooo`3oool0oooo0P00003o0?oo
ojh0oooo001X0?ooo`<000000P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00/0
oooo0P0000080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooon[0?ooo`00
I@3oool3000000D0oooo1@00000=0?ooo`030000003oool0oooo00`0oooo0P00000=0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooojX0oooo
001R0?ooo`<00000203oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo0P00
000>0?ooo`800000103oool2000000H0oooo0P0000050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooonZ0?ooo`00G`3oool3000000`0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`<000000`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooonZ0?ooo`00G03oool3
000001@0oooo00<000000?ooo`3oool03P3oool2000000d0oooo00<000000?ooo`3oool01@3oool3
000000P0oooo0P0000030?ooo`030000003oool0oooo0?l0ooooZ`3oool005T0oooo0`00000F0?oo
o`030000003oool0oooo0140oooo0P00000<0?ooo`030000003oool0oooo0140oooo1000003o0?oo
ojd0oooo001E0?ooo`@00000603oool00`000000oooo0?ooo`0C0?ooo`<000002@3oool00`000000
oooo0?ooo`3o0?oool<0oooo001C0?ooo`<000006P3oool00`000000oooo0?ooo`0F0?ooo`/00000
o`3oooo50?ooo`00C`3oool400000080oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0?l0oooob`3oool004`0oooo0`0000060?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0403oool4000000<0oooo00<000000?ooo`3oool0o`3oooo<
0?ooo`00B@3oool3000001L0oooo1P0000080?ooo`030000003oool0oooo01<0oooo0`00003o0?oo
oll0oooo00160?ooo`<00000603oool2000000H0oooo0P0000070?ooo`800000o`3ooooU0?ooo`00
@`3oool3000001X0oooo00<000000?ooo`3oool04@3oool400000?l0ooooh@3oool000l0oooo1@00
00020?ooo`800000:03oool3000001d0oooo00<000000?ooo`3oool05@3oool<00000?l0ooooe@3o
ool00140oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0280oooo0`00
000P0?ooo`030000003oool0oooo01d0oooo0P00003o0?ooomL0oooo000A0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`<0000000<0oooo0000003oool08@3o
ool2000000D0oooo0`00000D0?ooo`030000003oool0oooo0?l0ooooe`3oool000T0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`<00000103o
ool00`000000oooo0?ooo`0A0?ooo`L000002P3oool7000000H0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`3o0?ooomP0oooo000A0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0I0?ooo`<000006@3oool2000000L0oooo0P00000<0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool02P3oool200000?l0oooofP3oool00100oooo0P000004
0?ooo`8000006@3oool3000001X0oooo0P00000;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool3000000l0oooo1000003o0?ooomH0oooo000]0?ooo`@000001P3oool20000
01D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`090?ooo`D00000o`3oooo/0?oo
o`00:P3oool3000000`0oooo0`00000B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool0o`3ooooi0?ooo`009`3oool300000180oooo0P00000A0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0o`3ooooi0?ooo`00903oool4000001H0oooo0`00000?0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooh0?ooo`008@3oool3000000<0oooo00<00000
0?ooo`3oool05P3oool4000000d0oooo0P00000:0?ooo`030000003oool0oooo0?l0oooon@3oool0
01h0oooo0`0000060?ooo`030000003oool0oooo01L0oooo0P000000103oool0000000000000000<
0?ooo`<000001P3oool200000?l0oooon`3oool001/0oooo0`00000U0?ooo`040000003oool0oooo
0?ooo`<00000303oool7000000L0oooo00<000000?ooo`3oool0o`3oooob0?ooo`00603oool30000
00D0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`030?ooo`800000403oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0?l0ooool`3oool001D0oooo0`0000090?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0103oool3000000h0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`3o0?oooo<0oooo000B0?ooo`<000003@3oool00`000000oooo
0?ooo`070?ooo`H000004`3oool00`000000oooo0?ooo`070?ooo`8000003@3oool00`000000oooo
0?ooo`0200000?l0oooomP3oool000h0oooo1000000A0?ooo`8000001@3oool2000000H0oooo0P00
000B0?ooo`030000003oool0oooo01H0oooo0P00003o0?ooooP0oooo000;0?ooo`<000000P3oool0
0`000000oooo0?ooo`0B0?ooo`050000003oool0oooo0?ooo`0000002P3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0?l0ooooo`3ooolA0?ooo`00203oool3000000D0oooo00<00000
0?ooo`3oool04`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo00H0oooo0P00
00050?ooo`030000003oool0oooo0?l0ooooo`3ooolB0?ooo`001@3oool3000000P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`050?ooo`<000002`3oool00`000000oooo0?ooo`08
0?ooo`H00000o`3ooooo0?oooa@0oooo00020?ooo`<000006@3oool00`000000oooo0?ooo`080?oo
o`8000002P3oool00`000000oooo0?ooo`3o0?ooool0oooo8P3oool000800000703oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P00003o0?ooool0
oooo803oool001D0oooo1P0000030?ooo`030000003oool0oooo00/0oooo0P0000050?ooo`D00000
0P3oool200000?l0ooooo`3ooolN0?ooo`004`3oool2000000H0oooo1@00000>0?ooo`800000303o
ool200000?l0ooooo`3ooolL0?ooo`004P3oool00`000000oooo0?ooo`0:0?ooo`@000003@3oool2
000000`0oooo0P00003o0?ooool0oooo6P3oool00180oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`02000000d0oooo0P00000:0?ooo`030000003oool0oooo0?l0ooooo`3ooolI0?oo
o`004P3oool00`000000oooo0?ooo`0<0?ooo`040000003oool0oooo0?ooo`<00000303oool40000
00H0oooo00<000000?ooo`3oool0o`3ooooo0?oooaT0oooo000C0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool2000000h0oooo1P00003o0?ooool0oooo703oool001@0oooo
0P00000<0?ooo`030000003oool0oooo0?l0ooooo`3ooole0?ooo`005P3oool3000000T0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooocD0oooo000I0?ooo`X00000o`3ooooo0?ooocL0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {210.813, 0}} -> {0.0480418, 0.299422, \
0.00171467, 0.00171467}}]
}, Open  ]],

Cell[BoxData[
    \(\(stringDisplay[FromCharacterCode[Range[913, 937]]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<Pythagoras, \[CapitalSigma]\[Omicron]\[Kappa]\[Rho]\
\[Alpha]\[Tau]\[Epsilon]\[FinalSigma], x = Sin[\[Theta]]\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35209 
%%ImageSize: 600 211.255 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0501628 1.05016 -0.337979 1.05016 [
[.14089 .2557 -8.41405 -9 ]
[.14089 .2557 9.58595 0 ]
[.45924 .15249 -2.99065 -9 ]
[.45924 .15249 3.00935 0 ]
[.80349 .04093 -6.40104 -9 ]
[.80349 .04093 5.59896 0 ]
[.45855 .08715 -4.98351 -12.75 ]
[.45855 .08715 5.01649 0 ]
[.99045 .00538 0 -5.94903 ]
[.99045 .00538 24 3.05097 ]
[.99801 .01642 0 -5.9423 ]
[.99801 .01642 6 3.0577 ]
[1.00553 .02737 0 -5.93564 ]
[1.00553 .02737 18 3.06436 ]
[1.06052 -0.00362 0 -8.41826 ]
[1.06052 -0.00362 10 4.33174 ]
[ 0 0 0 0 ]
[ 1 .35209 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00054 .31389 m
.97149 0 L
s
.14004 .2688 m
.13961 .27535 L
s
[(-10)] .14089 .2557 -0.06511 1 Mshowa
.4592 .16562 m
.45918 .17218 L
s
[(0)] .45924 .15249 -0.00312 1 Mshowa
.80437 .05403 m
.8048 .06058 L
s
[(10)] .80349 .04093 .06684 1 Mshowa
.125 Mabswid
.20193 .24879 m
.20173 .25272 L
s
.26478 .22847 m
.26461 .23241 L
s
.32859 .20784 m
.32847 .21178 L
s
.39339 .18689 m
.39332 .19083 L
s
.52606 .144 m
.5261 .14794 L
s
.59397 .12205 m
.59407 .12598 L
s
.66298 .09974 m
.66313 .10367 L
s
.7331 .07707 m
.73331 .081 L
s
.07907 .28851 m
.07877 .29243 L
s
.01901 .30792 m
.01866 .31185 L
s
.8768 .03061 m
.87712 .03454 L
s
.95044 .00681 m
.95082 .01073 L
s
gsave
.45855 .08715 -65.9835 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97149 0 m
.99934 .04056 L
s
.97795 .00941 m
.9717 .01142 L
s
[(-0.5)] .99045 .00538 -1 .32201 Mshowa
.98551 .02042 m
.97926 .02243 L
s
[(0)] .99801 .01642 -1 .32051 Mshowa
.99302 .03136 m
.98677 .03335 L
s
[(0.5)] 1.00553 .02737 -1 .31903 Mshowa
.125 Mabswid
.97947 .01162 m
.97572 .01282 L
s
.98098 .01382 m
.97723 .01503 L
s
.9825 .01603 m
.97875 .01723 L
s
.98401 .01823 m
.98026 .01943 L
s
.98702 .02262 m
.98327 .02382 L
s
.98852 .02481 m
.98477 .02601 L
s
.99002 .02699 m
.98627 .02819 L
s
.99152 .02918 m
.98777 .03037 L
s
.97643 .00719 m
.97268 .0084 L
s
.97491 .00498 m
.97116 .00619 L
s
.97339 .00276 m
.96964 .00397 L
s
.97186 .00053 m
.96811 .00175 L
s
.99451 .03353 m
.99076 .03473 L
s
.99601 .03571 m
.99225 .0369 L
s
.99749 .03788 m
.99374 .03907 L
s
.99898 .04004 m
.99523 .04124 L
s
gsave
1.06052 -0.00362 -61 -12.4183 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35209 L
0 .35209 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05259 .33805 m
.06729 .33337 L
s
.05259 .33805 m
.02959 .31778 L
s
.06729 .33337 m
.07112 .33085 L
s
.07112 .33085 m
.07167 .32936 L
s
.07167 .32936 m
.07115 .32691 L
s
.05532 .32276 m
.04059 .32747 L
s
.07115 .32691 m
.06789 .32401 L
s
.06789 .32401 m
.06407 .3226 L
s
.06134 .32215 m
.05532 .32276 L
s
.06407 .3226 m
.06134 .32215 L
s
.07775 .32086 m
.07241 .30401 L
s
.11833 .31713 m
.1 .30048 L
s
.09755 .31453 m
.07241 .30401 L
s
.10583 .31189 m
.11745 .30818 L
s
.13493 .31185 m
.11234 .29116 L
s
.07241 .30401 m
.06472 .30114 L
s
.13137 .30241 m
.13578 .30233 L
s
.12314 .30106 m
.13137 .30241 L
s
.13578 .30233 m
.14079 .30073 L
s
.06472 .30114 m
.05921 .30023 L
s
.0548 .30032 m
.05314 .30085 L
s
.14079 .30073 m
.14307 .29867 L
s
.1 .30048 m
.09841 .29698 L
s
.05921 .30023 m
.0548 .30032 L
s
.14307 .29867 m
.14153 .29517 L
s
.09841 .29698 m
.10066 .29492 L
s
.14153 .29517 m
.13078 .28524 L
s
.10066 .29492 m
.10399 .29385 L
s
.16152 .29278 m
.15603 .29187 L
s
.16595 .29269 m
.16152 .29278 L
s
.171 .29108 m
.16595 .29269 L
s
.15603 .29187 m
.15114 .28943 L
s
.1733 .28901 m
.171 .29108 L
s
.15114 .28943 m
.149 .28744 L
s
.17455 .28594 m
.1733 .28901 L
s
.17774 .28893 m
.16282 .27493 L
s
.149 .28744 m
.14746 .2839 L
s
.14746 .2839 m
.14869 .28082 L
s
.19359 .28253 m
.18808 .28161 L
s
.19803 .28245 m
.19359 .28253 L
s
.20312 .28082 m
.19803 .28245 L
s
.18808 .28161 m
.18321 .27915 L
s
.20547 .27874 m
.20312 .28082 L
s
.14869 .28082 m
.15099 .27874 L
s
.18321 .27915 m
.18108 .27715 L
s
.20676 .27564 m
.20547 .27874 L
s
.15099 .27874 m
.15605 .27711 L
s
.20992 .27865 m
.19298 .26252 L
s
.16051 .27702 m
.16603 .27794 L
s
.18108 .27715 m
.17959 .27359 L
s
.15605 .27711 m
.16051 .27702 L
s
.17959 .27359 m
.18085 .27048 L
s
.22591 .2722 m
.22039 .27128 L
s
.23037 .27212 m
.22591 .2722 L
s
.2355 .27048 m
.23037 .27212 L
s
.22039 .27128 m
.21553 .2688 L
s
.23788 .26838 m
.2355 .27048 L
s
.18085 .27048 m
.18319 .26838 L
s
.21553 .2688 m
.21342 .26678 L
s
.23922 .26526 m
.23788 .26838 L
s
.18319 .26838 m
.18829 .26674 L
s
.19277 .26665 m
.1983 .26758 L
s
.21342 .26678 m
.21196 .26319 L
s
.18829 .26674 m
.19277 .26665 L
s
.23779 .26167 m
.23922 .26526 L
s
.25436 .26446 m
.23972 .2502 L
s
.1757 .26129 m
.17337 .2634 L
s
.21196 .26319 m
.21327 .26006 L
s
.19298 .26252 m
.18808 .26002 L
s
.25848 .2618 m
.26297 .26171 L
s
.25296 .26087 m
.25848 .2618 L
s
.26297 .26171 m
.26814 .26006 L
s
.23569 .25964 m
.23779 .26167 L
s
.18082 .25964 m
.1757 .26129 L
s
.24811 .25837 m
.25296 .26087 L
s
.21327 .26006 m
.21564 .25794 L
s
.18808 .26002 m
.1853 .25955 L
s
.23082 .25713 m
.23569 .25964 L
s
.1853 .25955 m
.18082 .25964 L
s
.21564 .25794 m
.22079 .25629 L
s
.22528 .2562 m
.23082 .25713 L
s
.22079 .25629 m
.22528 .2562 L
s
.28092 .25463 m
.27539 .25369 L
s
.28542 .25454 m
.28092 .25463 L
s
.29061 .25288 m
.28542 .25454 L
s
.27539 .25369 m
.27055 .25118 L
s
.29305 .25075 m
.29061 .25288 L
s
.27055 .25118 m
.26846 .24913 L
s
.29446 .24759 m
.29305 .25075 L
s
.29756 .25067 m
.28307 .23625 L
s
.26846 .24913 m
.26707 .24549 L
s
.26707 .24549 m
.26845 .24232 L
s
.31045 .24519 m
.30665 .24369 L
s
.3167 .24455 m
.31045 .24519 L
s
.32194 .24288 m
.3167 .24455 L
s
.30665 .24369 m
.30634 .24108 L
s
.32616 .24017 m
.32194 .24288 L
s
.26845 .24232 m
.27088 .24017 L
s
.30634 .24108 m
.3088 .23893 L
s
.32587 .23755 m
.32616 .24017 L
s
.27088 .24017 m
.2761 .23849 L
s
.28062 .23841 m
.28619 .23936 L
s
.3088 .23893 m
.31651 .23509 L
s
.2761 .23849 m
.28062 .23841 L
s
.29807 .2328 m
.2984 .23543 L
s
.31651 .23509 m
.31899 .23293 L
s
.31899 .23293 m
.31869 .23029 L
s
.30229 .23007 m
.29807 .2328 L
s
.38702 .23163 m
.41185 .22373 L
s
.38702 .23163 m
.38939 .21723 L
s
.31869 .23029 m
.31766 .22925 L
s
.30754 .22838 m
.30229 .23007 L
s
.31766 .22925 m
.31384 .22773 L
s
.31384 .22773 m
.30754 .22838 L
s
.33201 .22738 m
.33275 .22578 L
s
.32923 .22691 m
.33201 .22738 L
s
.32996 .2253 m
.32923 .22691 L
s
.33275 .22578 m
.33069 .22369 L
s
.33275 .22578 m
.32996 .2253 L
s
.33069 .22369 m
.32512 .22273 L
s
.38939 .21723 m
.36581 .20964 L
s
.4152 .21063 m
.41074 .20985 L
s
.41886 .21056 m
.4152 .21063 L
s
.42172 .20964 m
.41886 .21056 L
s
.41074 .20985 m
.40691 .20777 L
s
.42379 .20788 m
.42172 .20964 L
s
.36581 .20964 m
.39078 .20161 L
s
.42443 .20658 m
.42379 .20788 L
s
.40691 .20777 m
.4045 .20523 L
s
.42347 .20357 m
.42443 .20658 L
s
.4045 .20523 m
.40352 .20223 L
s
.44038 .20368 m
.42346 .1936 L
s
.42107 .20103 m
.42347 .20357 L
s
.40352 .20223 m
.40414 .20092 L
s
.41723 .19894 m
.42107 .20103 L
s
.40414 .20092 m
.40621 .19915 L
s
.44823 .20007 m
.43929 .19851 L
s
.4519 .2 m
.44823 .20007 L
s
.45334 .19954 m
.4519 .2 L
s
.454 .19823 m
.45334 .19954 L
s
.40621 .19915 m
.40908 .19823 L
s
.43417 .19904 m
.43626 .19727 L
s
.43561 .19858 m
.43417 .19904 L
s
.41275 .19815 m
.41723 .19894 L
s
.43929 .19851 m
.43561 .19858 L
s
.40908 .19823 m
.41275 .19815 L
s
.43626 .19727 m
.4369 .19595 L
s
.4369 .19595 m
.4358 .19075 L
s
.46701 .19407 m
.46254 .19328 L
s
.47069 .194 m
.46701 .19407 L
s
.47359 .19307 m
.47069 .194 L
s
.46254 .19328 m
.45872 .19118 L
s
.4757 .19129 m
.47359 .19307 L
s
.47637 .18997 m
.4757 .19129 L
s
.45872 .19118 m
.44099 .18015 L
s
.45872 .19118 m
.45634 .18861 L
s
.4358 .19075 m
.43645 .18943 L
s
.47546 .18693 m
.47637 .18997 L
s
.43645 .18943 m
.43789 .18897 L
s
.43789 .18897 m
.44014 .18936 L
s
.45634 .18861 m
.45541 .18557 L
s
.4731 .18435 m
.47546 .18693 L
s
.49315 .18571 m
.48867 .18492 L
s
.49685 .18564 m
.49315 .18571 L
s
.49685 .18564 m
.49976 .18471 L
s
.45541 .18557 m
.45607 .18424 L
s
.48867 .18492 m
.48565 .18367 L
s
.49976 .18471 m
.50044 .18338 L
s
.46928 .18223 m
.4731 .18435 L
s
.45607 .18424 m
.45818 .18245 L
s
.48565 .18367 m
.48183 .18155 L
s
.50044 .18338 m
.50034 .18119 L
s
.45818 .18245 m
.46109 .18151 L
s
.46479 .18144 m
.46928 .18223 L
s
.48183 .18155 m
.47947 .17896 L
s
.46109 .18151 m
.46479 .18144 L
s
.50619 .17932 m
.50998 .18144 L
s
.50034 .18119 m
.49701 .17333 L
s
.50014 .1768 m
.50619 .17932 L
s
.55142 .17932 m
.53117 .15646 L
s
.47947 .17896 m
.47935 .17676 L
s
.55326 .17874 m
.5551 .17815 L
s
.53302 .15586 m
.55326 .17874 L
s
.5551 .17815 m
.53487 .15527 L
s
.55694 .17756 m
.55878 .17698 L
s
.53672 .15467 m
.55694 .17756 L
s
.51946 .1773 m
.52463 .17676 L
s
.51497 .17651 m
.51946 .1773 L
s
.55878 .17698 m
.53857 .15408 L
s
.49486 .17514 m
.50014 .1768 L
s
.47935 .17676 m
.48149 .17496 L
s
.52463 .17676 m
.5408 .1716 L
s
.56062 .17639 m
.56246 .17581 L
s
.54042 .15348 m
.56062 .17639 L
s
.56246 .17581 m
.54228 .15288 L
s
.5643 .17522 m
.56615 .17463 L
s
.54413 .15229 m
.5643 .17522 L
s
.48812 .17395 m
.49486 .17514 L
s
.48149 .17496 m
.48441 .17402 L
s
.5305 .17489 m
.51521 .16412 L
s
.56615 .17463 m
.54599 .15169 L
s
.56799 .17405 m
.56984 .17346 L
s
.54784 .15109 m
.56799 .17405 L
s
.48441 .17402 m
.48812 .17395 L
s
.56984 .17346 m
.5497 .1505 L
s
.49701 .17333 m
.4969 .17113 L
s
.57168 .17287 m
.57353 .17228 L
s
.55155 .1499 m
.57168 .17287 L
s
.57353 .17228 m
.55341 .1493 L
s
.57538 .1717 m
.57723 .17111 L
s
.55527 .1487 m
.57538 .1717 L
s
.4969 .17113 m
.49758 .16979 L
s
.57723 .17111 m
.55713 .14811 L
s
.57908 .17052 m
.58093 .16993 L
s
.55899 .14751 m
.57908 .17052 L
s
.58093 .16993 m
.56085 .14691 L
s
.49758 .16979 m
.49905 .16931 L
s
.57998 .15796 m
.57773 .15755 L
s
.58521 .15741 m
.57998 .15796 L
s
.57773 .15755 m
.57472 .15627 L
s
.58967 .15598 m
.58521 .15741 L
s
.53117 .15646 m
.53302 .15586 L
s
.57472 .15627 m
.57319 .15452 L
s
.59339 .15367 m
.58967 .15598 L
s
.53487 .15527 m
.53672 .15467 L
s
.57319 .15452 m
.57315 .15228 L
s
.53857 .15408 m
.54042 .15348 L
s
.59412 .15232 m
.59339 .15367 L
s
.54228 .15288 m
.54413 .15229 L
s
.57315 .15228 m
.5746 .14956 L
s
.54599 .15169 m
.54784 .15109 L
s
.5497 .1505 m
.55155 .1499 L
s
.5746 .14956 m
.57827 .14499 L
s
.55341 .1493 m
.55527 .1487 L
s
.55713 .14811 m
.55899 .14751 L
s
.57827 .14499 m
.57823 .14274 L
s
.57823 .14274 m
.57669 .14096 L
s
.57443 .14056 m
.57144 .14152 L
s
.60001 .14141 m
.60093 .1397 L
s
.59718 .1409 m
.60001 .14141 L
s
.57669 .14096 m
.57443 .14056 L
s
.59811 .13919 m
.59718 .1409 L
s
.60093 .1397 m
.59903 .13747 L
s
.60093 .1397 m
.59811 .13919 L
s
.65173 .13756 m
.65953 .11517 L
s
.59903 .13747 m
.59337 .13645 L
s
.67255 .13092 m
.63863 .12189 L
s
.71458 .11465 m
.74922 .10358 L
s
.70908 .10785 m
.7438 .09672 L
s
.80488 .09724 m
.79922 .09619 L
s
.81161 .09653 m
.80488 .09724 L
s
.81943 .09404 m
.81161 .09653 L
s
.79922 .09619 m
.79745 .0939 L
s
.82442 .09102 m
.81943 .09404 L
s
.79745 .0939 m
.79763 .09097 L
s
.82659 .08747 m
.82442 .09102 L
s
.79763 .09097 m
.79869 .0892 L
s
.79869 .0892 m
.80172 .0868 L
s
.84381 .08771 m
.84098 .08718 L
s
.84491 .08593 m
.84381 .08771 L
s
.84098 .08718 m
.84207 .0854 L
s
.80172 .0868 m
.8117 .08072 L
s
.84207 .0854 m
.84491 .08593 L
s
.8117 .08072 m
.81474 .07831 L
s
.788 .0753 m
.78587 .07889 L
s
.83684 .07845 m
.82453 .0621 L
s
.81474 .07831 m
.81582 .07652 L
s
.81582 .07652 m
.81602 .07356 L
s
.79299 .07225 m
.788 .0753 L
s
.89973 .07424 m
.91365 .06981 L
s
.89973 .07424 m
.87217 .03648 L
s
.90171 .07361 m
.87417 .03583 L
s
.81602 .07356 m
.81337 .07006 L
s
.85262 .07341 m
.84038 .057 L
s
.80085 .06972 m
.79299 .07225 L
s
.85769 .07035 m
.86252 .07025 L
s
.84914 .06874 m
.85769 .07035 L
s
.86252 .07025 m
.86846 .06835 L
s
.81337 .07006 m
.80765 .06899 L
s
.80765 .06899 m
.80085 .06972 L
s
.86846 .06835 m
.87157 .06592 L
s
.87157 .06592 m
.87096 .06176 L
s
.87096 .06176 m
.86227 .04996 L
s
.95932 .05531 m
.97343 .05083 L
s
.93185 .05479 m
.92889 .05341 L
s
.93506 .05377 m
.93185 .05479 L
s
.9376 .0518 m
.93506 .05377 L
s
.92889 .05341 m
.92754 .05152 L
s
.91427 .05227 m
.91748 .05125 L
s
.9097 .0514 m
.91427 .05227 L
s
.93719 .04844 m
.9376 .0518 L
s
.92754 .05152 m
.92712 .04817 L
s
.97141 .05147 m
.94459 .0131 L
s
.90673 .05002 m
.9097 .0514 L
s
.91748 .05125 m
.91841 .04979 L
s
.97343 .05083 m
.94663 .01244 L
s
.91841 .04979 m
.91705 .04789 L
s
.93517 .04559 m
.93719 .04844 L
s
.92712 .04817 m
.92831 .04429 L
s
.91705 .04789 m
.91203 .04365 L
s
.93018 .04135 m
.93517 .04559 L
s
.92831 .04429 m
.93018 .04135 L
s
.91203 .04365 m
.90998 .04079 L
s
.93018 .04135 m
.93367 .03789 L
s
.92653 .039 m
.93018 .04135 L
s
.90998 .04079 m
.91022 .03837 L
s
.92355 .03761 m
.92653 .039 L
s
.91022 .03837 m
.91114 .03689 L
s
.91828 .03578 m
.92355 .03761 L
s
.91114 .03689 m
.91437 .03586 L
s
.87217 .03648 m
.88624 .03193 L
s
.91437 .03586 m
.91828 .03578 L
s
.93237 .01704 m
.94663 .01244 L
s
0 g
.25 Mabswid
.00054 .31389 m
.97149 0 L
s
.14004 .2688 m
.13961 .27535 L
s
[(-10)] .14089 .2557 -0.06511 1 Mshowa
.4592 .16562 m
.45918 .17218 L
s
[(0)] .45924 .15249 -0.00312 1 Mshowa
.80437 .05403 m
.8048 .06058 L
s
[(10)] .80349 .04093 .06684 1 Mshowa
.125 Mabswid
.20193 .24879 m
.20173 .25272 L
s
.26478 .22847 m
.26461 .23241 L
s
.32859 .20784 m
.32847 .21178 L
s
.39339 .18689 m
.39332 .19083 L
s
.52606 .144 m
.5261 .14794 L
s
.59397 .12205 m
.59407 .12598 L
s
.66298 .09974 m
.66313 .10367 L
s
.7331 .07707 m
.73331 .081 L
s
.07907 .28851 m
.07877 .29243 L
s
.01901 .30792 m
.01866 .31185 L
s
.8768 .03061 m
.87712 .03454 L
s
.95044 .00681 m
.95082 .01073 L
s
gsave
.45855 .08715 -65.9835 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 211.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000db000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo0P00000L0?oo
o`00o`3ooooo0?oooa`0oooo0P00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000006`3oool00?l0ooooo`3ooolI0?ooo`@0000000<0oooo0000003oool03`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0oooo01T0oooo003o0?ooool0oooo5P3oool30000
00<0oooo0`00000:0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000703oool0
0?l0ooooo`3ooolC0?ooo`<000001`3oool3000000l0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0K0?ooo`00o`3ooooo0?oooa00oooo0`00000;0?ooo`<000003`3oool20000
00X0oooo0`00000K0?ooo`00o`3ooooo0?ooo``0oooo100000000`3oool000000?ooo`0=0?ooo`80
0000303oool2000002X0oooo003o0?ooool0oooo2@3oool3000000H0oooo00<000000?ooo`3oool0
203oool3000000030?ooo`000000oooo00X0oooo00@000000?ooo`3oool00000:@3oool00?l0oooo
o`3oool60?ooo`<000001@3oool2000000l0oooo0P0000000`3oool000000?ooo`090?ooo`040000
003oool0oooo000002T0oooo003o0?ooool0oooo0`3oool3000000@0oooo100000000`3oool00000
0000000?0?ooo`80000000<0oooo0000003oool0203oool010000000oooo0?ooo`00000Y0?ooo`00
o`3ooooo0?ooo`<00000103oool3000000D0oooo0P00000@0?ooo`@00000203oool010000000oooo
0?ooo`00000Y0?ooo`00o`3ooool0?ooo`<00000403oool200000180oooo00<000000?ooo`3oool0
1`3oool2000002X0oooo003o0?ooooT0oooo0`00000D0?ooo`8000003`3oool4000000`0oooo0P00
00040?ooo`800000103oool2000001X0oooo003o0?ooooH0oooo0`00000H0?ooo`8000003@3oool3
00000080oooo00<000000?ooo`3oool0203oool010000000oooo0?ooo`0000080?ooo`040000003o
ool0oooo000001T0oooo003o0?oooo<0oooo0`00000K0?ooo`800000403oool3000000X0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0?ooo`0G0?ooo`00o`3oooo`0?ooo`<000007`3o
ool2000000l0oooo100000090?ooo`040000003oool0oooo000000T0oooo0P00000J0?ooo`00o`3o
ooni0?ooo`D000000P3oool2000002X0oooo1000000S0?ooo`8000003`3oool4000000P0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0I0?ooo`00o`3ooonk0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0T0?ooo`<000009`3oool200000180oooo
0P0000080?ooo`8000002P3oool3000001T0oooo003o0?oook/0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0240oooo0`00000[0?ooo`8000003`3oool400000300oooo
003o0?oook/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo
0`0000000`3oool000000?ooo`030?ooo`8000009`3oool2000000h0oooo0P0000020?ooo`030000
003oool0oooo02d0oooo003o0?oook/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01/0oooo0`0000050?ooo`@00000:P3oool2000000l0oooo0P0000000`3oool00000
0?ooo`0]0?ooo`00o`3ooonj0?ooo`800000103oool2000001/0oooo0`0000050?ooo`<000004`3o
ool5000001H0oooo0P00000@0?ooo`@00000;@3oool00?l0oooofP3oool3000000T0oooo0P00000B
0?ooo`030000003oool0oooo00<0oooo100000030?ooo`030000003oool0oooo00d0oooo0P00000A
0?ooo`800000;@3oool00?l0ooooe`3oool3000000`0oooo0P00000B0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`0000004@3oool2000000h0oooo0P0000000`3oool000000000000/0?oo
o`00o`3ooooD0?ooo`<00000403oool200000140oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0@0?ooo`8000003`3oool2000002h0oooo003o0?ooom40oooo0`00000D0?ooo`800000
4@3oool00`000000oooo0?ooo`060?ooo`040000003oool0000000000140oooo0P00000n0?ooo`00
o`3oooo>0?ooo`<00000603oool200000140oooo0P0000060?ooo`050000003oool0oooo0?ooo`00
00004@3oool2000003d0oooo003o0?ooolX0oooo1000000K0?ooo`8000004`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0403oool2000003`0oooo
003o0?ooolL0oooo0`00000P0?ooo`8000004`3oool01@000000oooo0?ooo`3oool0000000D0oooo
00<000000?ooo`3oool03`3oool2000003`0oooo003o0?oool@0oooo0`00000H0?ooo`030000003o
ool0oooo00T0oooo0P00000;0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0403oool2000003/0oooo003o0?oool40oooo0`00000L
0?ooo`030000003oool0oooo00P0oooo0P00000>0?ooo`<000001P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00h0oooo0P00000m0?ooo`00o`3ooonn0?ooo`<00000803oool00`00
0000oooo0?ooo`080?ooo`8000005`3oool4000000h0oooo0`00000o0?ooo`00o`3ooonk0?ooo`<0
000000<0oooo0000003oool04P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0
oooo0P00000V0?ooo`800000@P3oool00?l0oooo^03oool3000000@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo0P00001Y0?ooo`00o`3o
oone0?ooo`<000001`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0203oool2000006T0oooo003o0?oook80oooo0`00000E0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`080?ooo`800000J03oool0
0?l0oooo[`3oool3000001T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00T0oooo0P00001W0?ooo`00o`3ooon[0?ooo`@000007@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool2000006L0
oooo003o0?ooojP0oooo0`00000Q0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0:0?ooo`800000IP3oool00?l0ooooY@3oool3000001P0oooo0`00
000:0?ooo`030000003oool0oooo00P0oooo0`0000070?ooo`8000003P3oool2000006D0oooo003o
0?oooj80oooo0`00000G0?ooo`@000000`3oool2000000T0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0000000600000140oooo0P0000060?ooo`800000G03oool00?/0oooo0P0000000`3o
ool000000000002N0?ooo`<000005`3oool3000000T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo0P0000020?ooo`@00000GP3oool00?`0
oooo00<000000?ooo`000000W03oool3000001P0oooo0P00000=0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`<00000HP3oool00?d0oooo
00<000000?ooo`3oool0V03oool3000001X0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo08H0oooo003k0?ooo`80000000<0oooo000000000000U@3o
ool3000001`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo08D0oooo003o0?oooi<0oooo0`0000020?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`2B0?ooo`00o`3ooon@0?ooo`<000001@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo09<0oooo003o0?oooh`0oooo1000000a0?ooo`80
0000UP3oool00?l0ooooR@3oool3000003<0oooo0P00000C0?ooo`030000003oool0oooo0880oooo
003o0?ooohH0oooo0`00000e0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool01@3o
ool300000880oooo003o0?oooh<0oooo0`00000f0?ooo`8000003@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0840oooo003o0?oooh00oooo0`00000h0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0S03oool00?l0ooooO@3oool3000003/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2=0?ooo`00o`3ooomj0?ooo`<00000?P3oool00`000000oooo
0?ooo`080?ooo`<00000T03oool00?l0ooooM`3oool300000480oooo0P0000040?ooo`@00000T`3o
ool00?l0ooooM03oool3000002H0oooo0P00000O0?ooo`@00000U`3oool00?l0ooooL@3oool30000
02H0oooo0`00002l0?ooo`00o`3ooom]0?ooo`D00000903oool400000;l0oooo003o0?ooofX0oooo
0`0000040?ooo`030000003oool0oooo01l0oooo0`00000:0?ooo`800000]`3oool00?l0ooooI`3o
ool3000002H0oooo0`00000:0?ooo`<00000^@3oool00?l0ooooI03oool3000002D0oooo10000009
0?ooo`@00000_03oool00?l0ooooH@3oool3000002H0oooo0P00000:0?ooo`<00000`03oool00?l0
ooooGP3oool300000380oooo0`0000330?ooo`00o`3ooomK0?ooo`<00000<@3oool400000<H0oooo
003o0?oooeP0oooo0`00000b0?ooo`800000bP3oool00?l0ooooE@3oool3000001L0oooo00<00000
0?ooo`3oool0i`3oool00?l0ooooDP3oool3000001X0oooo00<000000?ooo`3oool0i`3oool00?l0
ooooC`3oool3000001`0oooo00<000000?ooo`3oool0j03oool00?l0ooooB`3oool4000001l0oooo
00<000000?ooo`3oool0j03oool00?l0ooooB03oool3000001P0oooo0P0000080?ooo`030000003o
ool0oooo0>T0oooo003o0?ooodD0oooo0`0000020?ooo`030000003oool0oooo01P0oooo10000004
0?ooo`030000003oool0oooo0>T0oooo003o0?oood80oooo0`0000050?ooo`030000003oool0oooo
01`0oooo1000003/0?ooo`00o`3ooolo0?ooo`<00000:P3oool500000>P0oooo003o0?oooc`0oooo
0`00000]0?ooo`030000003oool0oooo0080oooo1000003T0?ooo`00o`3oooli0?ooo`<00000;`3o
ool00`000000oooo0?ooo`070?ooo`800000hP3oool00?l0oooo=P3oool300000380oooo00<00000
0?ooo`3oool0j`3oool00?l0oooo<`3oool3000003@0oooo00<000000?ooo`3oool0k03oool00?l0
oooo<03oool3000001L0oooo1000000L0?ooo`030000003oool0oooo0>`0oooo003n0?ooo`800000
:`3oool4000001d0oooo0P00003o0?ooo`/0oooo003m0?ooo`040000003oool0oooo000002L0oooo
0`00000B0?ooo`@000002P3oool300000?l0oooo2`3oool00?d0oooo00@000000?ooo`3oool00000
903oool3000001T0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00o@3oool010000000oooo0?oo
o`00000Q0?ooo`<00000703oool00`000000oooo0?ooo`3o0?oooaD0oooo003m0?ooo`040000003o
ool0oooo000001h0oooo0`0000020?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`3o0?oooaH0oooo003n0?ooo`800000703oool3000000D0oooo00<0
00000?ooo`3oool03@3oool3000000030?ooo`000000oooo00H0oooo00<000000?ooo`3oool0o`3o
oolF0?ooo`00o`3ooolJ0?ooo`<000005@3oool3000000060?ooo`00000000000000003oool00000
1@3oool00`000000oooo0?ooo`3o0?oooaL0oooo003o0?oooaL0oooo0`00000E0?ooo`<0000000D0
oooo00000000000000000?ooo`03000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`3o0?ooo`d0oooo003o0?oooa@0oooo0`00000E0?ooo`<0000000D0
oooo00000000000000000?ooo`03000000030?ooo`0000000000008000000`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0?l0oooo3@3oool00?l0oooo4@3oool3000001D0oooo0`00
00001@3oool00000000000000000oooo00<0000000<0oooo000000000000100000001@3oool00000
0?ooo`3oool0000000P0oooo0P00003o0?oooa00oooo003o0?ooo`d0oooo1000000G0?ooo`030000
003oool000000080000000D0oooo00000000000000000?ooo`05000000030?ooo`00000000000080
000000@0oooo0000003oool0oooo0P0000030?ooo`<00000o`3ooolB0?ooo`00o`3oool:0?ooo`<0
0000703oool00`000000oooo00000002000000030?ooo`000000000000<0000000D0oooo00000000
000000000?ooo`04000000030?ooo`000000oooo0080oooo0`00003o0?oooaD0oooo003o0?ooo`L0
oooo0`00000P0?ooo`030000003oool0000000@0000000D0oooo00000000000000000?ooo`040000
00060?ooo`00000000000000003oool00000o`3ooolJ0?ooo`00o`3oool40?ooo`<00000903oool3
000000050?ooo`00000000000000003oool0100000001@3oool00000000000000000oooo00<00000
00<0oooo0000003oool0o`3ooolH0?ooo`00o`3oool10?ooo`<000006`3oool00`000000oooo0?oo
o`0:0?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<00000
00<0oooo0000000000000P00003o0?oooaT0oooo003m0?ooo`<000007`3oool00`000000oooo0?oo
o`0:0?ooo`@0000000D0oooo00000000000000000?ooo`03000000030?ooo`000000000000@00000
00<0oooo0000003oool0o`3ooolG0?ooo`00nP3oool300000080oooo00<000000?ooo`3oool07P3o
ool2000000X0oooo00<000000?ooo`0000000P0000001@3oool00000000000000000oooo00D00000
00<0oooo0000000000000P0000000`3oool000000?ooo`3o0?oooaH0oooo003g0?ooo`<000001@3o
ool00`000000oooo0?ooo`0B0?ooo`800000303oool00`000000oooo0?ooo`080?ooo`030000003o
ool000000080000000<0oooo0000000000000`0000001@3oool00000000000000000oooo00@00000
00<0oooo0000003oool0o`3ooolE0?ooo`00m03oool3000000P0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool000000?oo
o`05000000050?ooo`00000000000000003oool00`0000000`3oool000000000000200000?l0oooo
5`3oool00?40oooo0`00000I0?ooo`@000000`3oool00`000000oooo0?ooo`0=0?ooo`8000000P3o
ool3000000@0oooo0`0000001@3oool00000000000000000oooo00<0000000@0oooo000000000000
0000o`3ooolK0?ooo`00k@3oool4000001X0oooo0P0000040?ooo`@00000403oool3000000P0oooo
0`0000001@3oool00000000000000000oooo00<00000o`3ooolN0?ooo`00jP3oool3000001d0oooo
00<000000?ooo`3oool01`3oool3000000L0oooo1`00000<0?ooo`<0000000@0oooo000000000000
0000o`3ooolQ0?ooo`00i`3oool300000200oooo00<000000?ooo`3oool0203oool00`000000oooo
00000002000001P0oooo0`00003o0?ooob@0oooo003T0?ooo`<000003@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`3o0?oooc`0oooo003Q0?ooo`<000004@3oool2000000L0oooo1`0000060?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oooc/0oooo003N0?oo
o`<000005P3oool2000000@0oooo00<000000?ooo`3oool01@3oool2000000D0oooo0P0000070?oo
o`030000003oool0oooo0?l0oooo@@3oool00=/0oooo0`00000K0?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0103oool700000?l0ooooA03oool00=P0oooo0`00000O0?ooo`<0
00002`3oool00`000000oooo0?ooo`3o0?ooodh0oooo003E0?ooo`<000000P3oool00`000000oooo
0?ooo`0E0?ooo`<000001`3oool2000000X0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`00dP3o
ool3000000D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0o`3ooom>0?ooo`00cP3oool4000001T0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0:0?ooo`<000001@3oool00`000000oooo0?ooo`3o
0?ooodl0oooo003;0?ooo`<000007P3oool2000000@0oooo00<000000?ooo`3oool03@3oool50000
0?l0ooooDP3oool00<P0oooo0`00000S0?ooo`050000003oool0oooo0?ooo`000000o`3ooomV0?oo
o`00a@3oool3000001T0oooo1`0000070?ooo`L000001P3oool00`000000oooo0?ooo`3o0?oooeX0
oooo00320?ooo`<000006`3oool00`000000oooo0?ooo`050?ooo`8000001`3oool00`000000oooo
0?ooo`020?ooo`H00000o`3ooomM0?ooo`00_`3oool3000001H0oooo0P0000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool01@3oool200000?l0ooooI@3oool00;`0oooo0`00000E
0?ooo`@00000203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0o`3ooomR0?ooo`00^@3oool3000001D0oooo0`00000<0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0o`3ooom[0?ooo`00]P3oool3000001@0oooo1000000@0?ooo`80
0000203oool00`000000oooo0?ooo`3o0?ooof/0oooo002c0?ooo`@00000503oool2000001H0oooo
0P0000050?ooo`030000003oool0oooo0?l0ooooK03oool00;00oooo0`0000030?ooo`030000003o
ool0oooo01@0oooo0`00000E0?ooo`D00000o`3ooom_0?ooo`00[03oool400000200oooo1000003o
0?ooohD0oooo002Y0?ooo`<00000:03oool300000?l0ooooPP3oool00:H0oooo0`00000^0?ooo`80
0000o`3ooon00?ooo`00X`3oool300000380oooo00<000000?ooo`3oool0o`3ooomn0?ooo`00X03o
ool3000003@0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00W@3oool3000003L0oooo00<00000
0?ooo`3oool0o`3ooomo0?ooo`00VP3oool3000001L0oooo1000000O0?ooo`030000003oool0oooo
00T0oooo0P00003o0?ooog@0oooo002G0?ooo`<000007@3oool2000001h0oooo00<000000?ooo`3o
ool01@3oool400000?l0ooooMP3oool009@0oooo0`00000F0?ooo`8000001`3oool3000001d0oooo
00<000000?ooo`3oool00`3oool300000?l0ooooNP3oool00940oooo0`00000E0?ooo`@000000P3o
ool2000002D0oooo00<000000?ooo`0000000`00003o0?ooogd0oooo002=0?ooo`@0000000<0oooo
0000003oool04`3oool2000000L0oooo00<000000?ooo`3oool08`3oool200000?l0ooooP@3oool0
08X0oooo0`0000050?ooo`030000003oool0oooo0100oooo0P00000:0?ooo`030000003oool0oooo
0?l0ooooY@3oool008L0oooo0`00000K0?ooo`030000003oool0oooo00L0oooo0P00003o0?ooojP0
oooo00240?ooo`<000005P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0o`3ooonX0?ooo`00P@3oool3000001@0oooo1@0000000`3oool000000?oo
o`0<0?ooo`8000001P3oool00`000000oooo0?ooo`3o0?oooj80oooo001n0?ooo`<000005@3oool2
000000D0oooo0`00000;0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooonQ
0?ooo`00C03oool500000080oooo0P00000V0?ooo`<000005`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3oool200000?l0ooooY03oool004h0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0200oooo0`00000I0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`800000o`3ooonV0?ooo`00CP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool07@3oool3000001`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`060?oo
o`H00000o`3ooonX0?ooo`00AP3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01X0oooo0`00000O0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0o`3ooonc0?ooo`00CP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool05P3oool4000002<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0000003o0?oo
ok@0oooo001=0?ooo`800000103oool2000001H0oooo0`0000020?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
0?l0oooo/`3oool006P0oooo0`0000050?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`060?ooo`800000o`3ooong0?ooo`00I@3oool3000001l0oooo
00<000000?ooo`3oool03P3oool800000?l0oooo^@3oool00680oooo0`00000D0?ooo`H000002@3o
ool00`000000oooo0?ooo`3o0?ooolh0oooo001O0?ooo`<000005@3oool2000000H0oooo0P000008
0?ooo`030000003oool0oooo0?l0ooooc@3oool005`0oooo0`0000040?ooo`H000003@3oool00`00
0000oooo0?ooo`080?ooo`8000001`3oool2000000P0oooo00<000000?ooo`3oool0o`3oooo20?oo
o`00F@3oool3000000D0oooo0P0000060?ooo`8000002P3oool00`000000oooo0?ooo`0;0?ooo`80
00001P3oool900000?l0ooooa@3oool005H0oooo0`0000070?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0o`3oooo:0?ooo`00D`3oool3000001H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0o`3o
ooo90?ooo`00C`3oool4000001@0oooo200000070?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool0o`3ooooB0?ooo`00C03oool3000001H0oooo0P0000070?ooo`030000003oool0oooo
00H0oooo0P00000;0?ooo`030000003oool0oooo0?l0oooodP3oool004T0oooo0`0000000`3oool0
00000?ooo`0E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool3000000D0
oooo0`00003o0?ooomD0oooo00160?ooo`<00000103oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool500000?l0oooof03oool004<0oooo0`00
00070?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`3o0?ooonD0oooo00100?ooo`<000002P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooon@0oooo000m0?oo
o`<000005@3oool8000000L0oooo00<000000?ooo`3oool02`3oool200000?l0ooooi@3oool003X0
oooo0`00000F0?ooo`8000001`3oool00`000000oooo0?ooo`060?ooo`8000002`3oool00`000000
oooo0000003o0?ooon@0oooo000g0?ooo`<00000603oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00L0oooo0`0000050?ooo`<00000o`3ooooW0?ooo`00=03oool3000001X0oooo00<0
00000?ooo`3oool02P3oool2000000X0oooo1@00003o0?ooonX0oooo000a0?ooo`<00000503oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0o`3oooof
0?ooo`00;@3oool4000001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?oo
o`800000o`3oooog0?ooo`00:P3oool3000001d0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool000000?l0oooomP3oool002L0oooo0`0000000`3oool00000
0?ooo`0N0?ooo`030000003oool0oooo00D0oooo0P0000090?ooo`800000o`3ooooi0?ooo`00903o
ool3000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00H0oooo2@00003o0?oooo/0oooo000Q0?ooo`<000005@3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`X0oooo000N0?oo
o`<000005P3oool2000000L0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3o0?oo
ool0oooo2@3oool001/0oooo0`00000H0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo2@3oool001P0oooo0`00000K0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3o0?ooool0oooo
203oool001D0oooo0`0000050?ooo`P000004P3oool00`000000oooo0?ooo`090?ooo`<000001`3o
ool200000?l0ooooo`3oool;0?ooo`004P3oool300000100oooo0P00000A0?ooo`030000003oool0
oooo00T0oooo2@00003o0?ooool0oooo3@3oool000h0oooo1000000E0?ooo`<000003`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0ooooo`3ooolA0?ooo`002`3oool3000001X0
oooo00<000000?ooo`0000000P00000=0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooa00oooo00080?ooo`<000007P3oool010000000oooo0?ooo`3oool2000000`0
oooo00<000000?ooo`3oool00P3oool2000000H0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`l0
oooo00050?ooo`<000000P3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo
0`00000:0?ooo`@000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo3P3oool00080oooo0`00
00050?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool3000000D0oooo0P00
00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`d0oooo0002
000002P0oooo00<000000?ooo`3oool0203oool2000000P0oooo00<000000?ooo`3oool0o`3ooooo
0?oooaP0oooo000Z0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oaL0oooo000@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`3o0?ooool0oooo5P3oool00140oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`3o0?ooool0oooo;03oool00180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`3o0?ooool0oooo;03oool001<0oooo00<000000?ooo`3oool01`3oool700000?l0ooooo`3ooolf
0?ooo`00503oool00`000000oooo0?ooo`040?ooo`8000001`3oool200000?l0ooooo`3ooold0?oo
o`005@3oool00`000000oooo0?ooo`03000000/0oooo0P00003o0?ooool0oooo<P3oool001H0oooo
0P00000?0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`00603oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`006@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`006P3oool00`000000oooo0?ooo`070?oo
o`<00000o`3ooooo0?oooc<0oooo000K0?ooo`030000003oool0oooo00@0oooo0P00003o0?ooool0
oooo=P3oool001`0oooo00<000000?ooo`3oool00`00003o0?ooool0oooo>03oool001d0oooo0P00
003o0?ooool0oooo>`3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {210.25, 0}} -> {0.0477618, 0.300289, \
0.00171456, 0.00171456}}]
}, Open  ]],

Cell["A bolder font is obtained by increasing the line thickness", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fontThickness = 2;\)\), "\n", 
    \(\(stringDisplay["\<ABCDEFGHIJKLMNOPQRSTUVWXYZ\>"];\)\), "\n", 
    \(\(stringDisplay["\<abcdefghijklmnopqrstuvwxyz\>"];\)\), "\n", 
    \(\(stringDisplay[FromCharacterCode[Range[945, 969]]];\)\), "\n", 
    \(\(stringDisplay[
        FromCharacterCode[Range[913, 937]]];\)\), "\[IndentingNewLine]", 
    \(\(fontThickness = 1;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34481 
%%ImageSize: 600 206.885 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0520638 1.05206 -0.343127 1.05206 [
[.14504 .25617 -8.42882 -9 ]
[.14504 .25617 9.57118 0 ]
[.46386 .15307 -2.99403 -9 ]
[.46386 .15307 3.00597 0 ]
[.80838 .04171 -6.40386 -9 ]
[.80838 .04171 5.59614 0 ]
[.4622 .08791 -4.98826 -12.75 ]
[.4622 .08791 5.01174 0 ]
[.99388 -0.001 0 -5.94933 ]
[.99388 -0.001 24 3.05067 ]
[1.00147 .01006 0 -5.94265 ]
[1.00147 .01006 6 3.05735 ]
[1.009 .02104 0 -5.93603 ]
[1.009 .02104 18 3.06397 ]
[1.0645 -0.0094 0 -8.41824 ]
[1.0645 -0.0094 10 4.33176 ]
[ 0 0 0 0 ]
[ 1 .34481 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00054 .31563 m
.97928 0 L
s
.14421 .2693 m
.14379 .27586 L
s
[(-10)] .14504 .25617 -0.06346 1 Mshowa
.46384 .16622 m
.46383 .1728 L
s
[(0)] .46386 .15307 -0.00199 1 Mshowa
.80927 .05483 m
.80971 .06139 L
s
[(10)] .80838 .04171 .06731 1 Mshowa
.125 Mabswid
.20621 .2493 m
.20601 .25324 L
s
.26915 .229 m
.269 .23295 L
s
.33306 .2084 m
.33295 .21234 L
s
.39794 .18747 m
.39789 .19142 L
s
.53076 .14464 m
.53081 .14858 L
s
.59874 .12272 m
.59884 .12666 L
s
.6678 .10045 m
.66795 .10439 L
s
.73797 .07782 m
.73817 .08176 L
s
.08313 .28899 m
.08283 .29293 L
s
.02295 .3084 m
.02261 .31233 L
s
.88172 .03146 m
.88205 .03539 L
s
.95537 .00771 m
.95575 .01164 L
s
gsave
.4622 .08791 -65.9883 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97928 0 m
.99934 .02922 L
s
.98136 .00303 m
.97511 .00505 L
s
[(-0.5)] .99388 -0.001 -1 .32207 Mshowa
.98895 .01408 m
.98269 .01609 L
s
[(0)] 1.00147 .01006 -1 .32059 Mshowa
.99647 .02504 m
.99021 .02704 L
s
[(0.5)] 1.009 .02104 -1 .31912 Mshowa
.125 Mabswid
.98289 .00525 m
.97913 .00646 L
s
.9844 .00746 m
.98065 .00867 L
s
.98592 .00967 m
.98216 .01088 L
s
.98743 .01188 m
.98368 .01308 L
s
.99046 .01628 m
.9867 .01748 L
s
.99196 .01847 m
.98821 .01967 L
s
.99347 .02066 m
.98971 .02187 L
s
.99497 .02285 m
.99121 .02405 L
s
.97984 .00081 m
.97609 .00202 L
s
.99797 .02722 m
.99421 .02842 L
s
gsave
1.0645 -0.0094 -61 -12.4182 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34481 L
0 .34481 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.06013 .33054 m
.05033 .30591 L
s
.06013 .33054 m
.02398 .31439 L
s
.07985 .32426 m
.0947 .31954 L
s
.07985 .32426 m
.05695 .30378 L
s
.03662 .31962 m
.05307 .31435 L
s
.0947 .31954 m
.09858 .31698 L
s
.09858 .31698 m
.09916 .31548 L
s
.09916 .31548 m
.09866 .313 L
s
.06899 .31455 m
.08388 .30979 L
s
.09866 .313 m
.0965 .31105 L
s
.0965 .31105 m
.09268 .30962 L
s
.12016 .31011 m
.11469 .30921 L
s
.12456 .31003 m
.12016 .31011 L
s
.13123 .30791 m
.12456 .31003 L
s
.08388 .30979 m
.08776 .30721 L
s
.08993 .30917 m
.08388 .30979 L
s
.09268 .30962 m
.08993 .30917 L
s
.11469 .30921 m
.11087 .30779 L
s
.1335 .30587 m
.13123 .30791 L
s
.11087 .30779 m
.10597 .30537 L
s
.08776 .30721 m
.08834 .3057 L
s
.1347 .30284 m
.1335 .30587 L
s
.08834 .3057 m
.08783 .3032 L
s
.10597 .30537 m
.10056 .30046 L
s
.07188 .29898 m
.05695 .30378 L
s
.08783 .3032 m
.08456 .30025 L
s
.13423 .30033 m
.1347 .30284 L
s
.14962 .30206 m
.16136 .29832 L
s
.14962 .30206 m
.12708 .28122 L
s
.10056 .30046 m
.09897 .29696 L
s
.08456 .30025 m
.08071 .29881 L
s
.07796 .29836 m
.07188 .29898 L
s
.08071 .29881 m
.07796 .29836 L
s
.16136 .29832 m
.16534 .29572 L
s
.09897 .29696 m
.09847 .29445 L
s
.16534 .29572 m
.16659 .29267 L
s
.09847 .29445 m
.09964 .29139 L
s
.16659 .29267 m
.16615 .29015 L
s
.09964 .29139 m
.10189 .28932 L
s
.18495 .29081 m
.20698 .2838 L
s
.18495 .29081 m
.1626 .26979 L
s
.16615 .29015 m
.16464 .28662 L
s
.11856 .28799 m
.1224 .28944 L
s
.10189 .28932 m
.10859 .28716 L
s
.11303 .28708 m
.11856 .28799 L
s
.10859 .28716 m
.11303 .28708 L
s
.16464 .28662 m
.1593 .28163 L
s
.1593 .28163 m
.1544 .27917 L
s
.13888 .27742 m
.12708 .28122 L
s
.17435 .28084 m
.18792 .2765 L
s
.21718 .28055 m
.23938 .27349 L
s
.21718 .28055 m
.195 .25937 L
s
.1544 .27917 m
.15056 .27771 L
s
.15056 .27771 m
.14503 .27679 L
s
.14503 .27679 m
.13888 .27742 L
s
.20666 .27051 m
.22034 .26613 L
s
.1626 .26979 m
.18474 .26267 L
s
.25378 .26756 m
.24826 .26663 L
s
.25825 .26748 m
.25378 .26756 L
s
.26514 .26529 m
.25825 .26748 L
s
.24826 .26663 m
.24446 .26516 L
s
.26755 .26318 m
.26514 .26529 L
s
.24446 .26516 m
.2396 .26267 L
s
.26893 .26005 m
.26755 .26318 L
s
.2396 .26267 m
.23436 .25759 L
s
.26858 .25746 m
.26893 .26005 L
s
.28586 .25869 m
.26405 .23715 L
s
.23436 .25759 m
.23293 .25398 L
s
.23293 .25398 m
.23254 .25138 L
s
.25161 .25206 m
.26026 .24929 L
s
.23254 .25138 m
.23389 .24822 L
s
.31017 .25095 m
.28849 .22929 L
s
.25712 .24621 m
.26026 .24929 L
s
.27552 .24848 m
.29989 .24068 L
s
.23389 .24822 m
.23629 .24608 L
s
.32412 .24651 m
.30252 .22478 L
s
.25329 .24471 m
.25712 .24621 L
s
.23629 .24608 m
.24321 .24386 L
s
.24773 .24377 m
.25329 .24471 L
s
.24321 .24386 m
.24773 .24377 L
s
.35217 .23758 m
.33586 .22095 L
s
.3645 .23366 m
.34312 .21172 L
s
.31823 .2266 m
.32029 .22868 L
s
.3169 .22291 m
.31823 .2266 L
s
.38926 .22578 m
.35028 .21907 L
s
.31763 .2213 m
.3169 .22291 L
s
.39992 .22238 m
.37874 .20026 L
s
.36423 .22147 m
.36802 .2037 L
s
.32012 .21911 m
.31763 .2213 L
s
.33586 .22095 m
.33101 .21837 L
s
.32365 .21798 m
.32012 .21911 L
s
.33101 .21837 m
.32821 .21789 L
s
.32821 .21789 m
.32365 .21798 L
s
.43385 .21159 m
.42731 .18463 L
s
.43385 .21159 m
.41286 .18928 L
s
.46263 .20242 m
.44181 .17997 L
s
.46263 .20242 m
.42731 .18463 L
s
.37874 .20026 m
.40026 .19333 L
s
.4771 .19782 m
.48194 .16706 L
s
.4771 .19782 m
.45636 .17529 L
s
.50253 .18972 m
.48194 .16706 L
s
.52165 .18226 m
.51605 .18127 L
s
.52628 .18217 m
.52165 .18226 L
s
.53361 .17983 m
.52628 .18217 L
s
.51605 .18127 m
.51228 .1797 L
s
.53632 .17758 m
.53361 .17983 L
s
.51228 .1797 m
.50753 .17704 L
s
.53807 .17425 m
.53632 .17758 L
s
.50753 .17704 m
.50264 .17163 L
s
.53798 .17149 m
.53807 .17425 L
s
.55569 .1728 m
.57232 .16751 L
s
.55569 .1728 m
.53542 .14985 L
s
.50264 .17163 m
.50154 .16778 L
s
.53693 .16765 m
.53798 .17149 L
s
.50154 .16778 m
.50141 .16501 L
s
.53209 .1622 m
.53693 .16765 L
s
.57232 .16751 m
.57693 .16465 L
s
.50141 .16501 m
.50313 .16165 L
s
.57693 .16465 m
.57783 .16297 L
s
.57783 .16297 m
.57778 .16019 L
s
.52732 .15951 m
.53209 .1622 L
s
.50313 .16165 m
.50583 .15937 L
s
.5618 .15549 m
.54511 .16083 L
s
.57778 .16019 m
.57492 .15691 L
s
.52353 .15791 m
.52732 .15951 L
s
.50583 .15937 m
.51321 .157 L
s
.51788 .15691 m
.52353 .15791 L
s
.51321 .157 m
.51788 .15691 L
s
.6011 .15695 m
.59548 .15595 L
s
.60578 .15686 m
.6011 .15695 L
s
.57492 .15691 m
.57115 .15531 L
s
.61325 .15448 m
.60578 .15686 L
s
.59548 .15595 m
.59172 .15435 L
s
.56833 .1548 m
.5618 .15549 L
s
.57115 .15531 m
.56833 .1548 L
s
.61605 .15219 m
.61325 .15448 L
s
.59172 .15435 m
.587 .15164 L
s
.61791 .1488 m
.61605 .15219 L
s
.587 .15164 m
.58223 .14613 L
s
.6179 .14599 m
.61791 .1488 L
s
.63574 .14733 m
.65268 .14193 L
s
.63574 .14733 m
.61595 .12395 L
s
.58223 .14613 m
.58123 .14221 L
s
.61695 .14207 m
.6179 .14599 L
s
.58123 .14221 m
.58118 .13939 L
s
.61222 .13652 m
.61695 .14207 L
s
.65268 .14193 m
.65741 .13902 L
s
.58118 .13939 m
.58301 .13596 L
s
.65741 .13902 m
.65837 .13731 L
s
.65837 .13731 m
.65841 .13448 L
s
.6075 .13378 m
.61222 .13652 L
s
.59527 .13629 m
.60082 .12596 L
s
.64335 .13081 m
.62635 .13624 L
s
.58301 .13596 m
.58581 .13364 L
s
.65841 .13448 m
.65654 .13225 L
s
.60371 .13215 m
.6075 .13378 L
s
.58581 .13364 m
.59332 .13122 L
s
.67824 .13239 m
.6726 .13136 L
s
.68486 .13169 m
.67824 .13239 L
s
.65654 .13225 m
.65279 .13062 L
s
.59804 .13113 m
.60371 .13215 L
s
.63956 .13202 m
.64249 .11541 L
s
.69247 .12927 m
.68486 .13169 L
s
.6726 .13136 m
.67075 .12913 L
s
.59332 .13122 m
.59804 .13113 L
s
.64996 .13011 m
.64335 .13081 L
s
.65279 .13062 m
.64996 .13011 L
s
.69726 .12633 m
.69247 .12927 L
s
.67075 .12913 m
.67079 .12628 L
s
.69924 .12287 m
.69726 .12633 L
s
.67079 .12628 m
.67176 .12455 L
s
.67176 .12455 m
.67464 .12221 L
s
.70963 .12381 m
.73646 .11527 L
s
.67464 .12221 m
.68423 .1163 L
s
.72302 .11954 m
.70378 .09569 L
s
.68423 .1163 m
.68713 .11395 L
s
.66058 .11102 m
.65864 .11451 L
s
.68713 .11395 m
.68812 .1122 L
s
.74608 .1122 m
.73247 .09512 L
s
.68812 .1122 m
.68818 .10932 L
s
.66537 .10805 m
.66058 .11102 L
s
.68818 .10932 m
.6854 .10591 L
s
.67303 .10558 m
.66537 .10805 L
s
.6854 .10591 m
.67971 .10487 L
s
.67971 .10487 m
.67303 .10558 L
s
.75965 .0864 m
.77314 .10359 L
s
.78284 .1005 m
.77964 .07129 L
s
.73247 .09512 m
.73167 .09105 L
s
.73167 .09105 m
.73372 .08751 L
s
.81403 .09057 m
.77964 .07129 L
s
.8199 .08871 m
.81114 .06115 L
s
.73372 .08751 m
.73863 .08448 L
s
.75498 .08356 m
.75965 .0864 L
s
.73863 .08448 m
.74252 .08323 L
s
.74927 .08251 m
.75498 .08356 L
s
.74252 .08323 m
.74927 .08251 L
s
.83953 .08246 m
.83095 .05478 L
s
.83953 .08246 m
.81114 .06115 L
s
.85925 .07618 m
.83095 .05478 L
s
.86915 .07303 m
.87884 .03937 L
s
.89696 .06418 m
.85084 .04838 L
s
.90494 .06164 m
.91242 .04473 L
s
.93699 .05144 m
.91242 .04473 L
s
.94504 .04887 m
.97333 .03987 L
s
.91242 .04473 m
.90297 .03161 L
s
.97333 .03987 m
.92724 .0238 L
s
.92724 .0238 m
.95572 .01464 L
s
0 g
.25 Mabswid
.00054 .31563 m
.97928 0 L
s
.14421 .2693 m
.14379 .27586 L
s
[(-10)] .14504 .25617 -0.06346 1 Mshowa
.46384 .16622 m
.46383 .1728 L
s
[(0)] .46386 .15307 -0.00199 1 Mshowa
.80927 .05483 m
.80971 .06139 L
s
[(10)] .80838 .04171 .06731 1 Mshowa
.125 Mabswid
.20621 .2493 m
.20601 .25324 L
s
.26915 .229 m
.269 .23295 L
s
.33306 .2084 m
.33295 .21234 L
s
.39794 .18747 m
.39789 .19142 L
s
.53076 .14464 m
.53081 .14858 L
s
.59874 .12272 m
.59884 .12666 L
s
.6678 .10045 m
.66795 .10439 L
s
.73797 .07782 m
.73817 .08176 L
s
.08313 .28899 m
.08283 .29293 L
s
.02295 .3084 m
.02261 .31233 L
s
.88172 .03146 m
.88205 .03539 L
s
.95537 .00771 m
.95575 .01164 L
s
gsave
.4622 .08791 -65.9883 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 206.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3ooom@0?ooo`<0
000000<0oooo000000000000103oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?ooobl0oooo0P00
00040?ooo`800000103oool2000001d0oooo003o0?ooool0oooo;P3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo000001`0oooo003o0?ooool0oooo;P3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo01X0oooo003o0?ooool0oooo:03oool400000080oooo00@0
00000?ooo`3oool000002@3oool2000001d0oooo003o0?ooool0oooo7P3oool3000000d0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`0L0?ooo`00o`3ooooo0?oooa/0oooo1P00
000>0?ooo`8000002P3oool3000001`0oooo003o0?ooool0oooo603oool3000000@0oooo0P00000=
0?ooo`800000:P3oool00?l0ooooo`3ooolE0?ooo`<000001@3oool200000080oooo00<000000?oo
o`3oool02@3oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?oooa80oooo0`00000:0?oo
o`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?oo
o`h0oooo1@00000=0?ooo`@000002@3oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?oo
o`/0oooo0`0000040?ooo`030000003oool0oooo00`0oooo0`0000090?ooo`040000003oool0oooo
000002T0oooo003o0?ooool0oooo203oool3000000L0oooo00<000000?ooo`3oool03@3oool30000
00T0oooo0P00000Z0?ooo`00o`3ooooo0?ooo`D0oooo0`0000070?ooo`D00000403oool2000000`0
oooo0P0000040?ooo`800000103oool2000001X0oooo003o0?ooool0oooo0P3oool3000000L0oooo
1`00000>0?ooo`<0000000<0oooo0000000000002P3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000001T0oooo003o0?ooooh0oooo0`0000070?ooo`L000004`3oool200000003
0?ooo`000000oooo00T0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0G0?oo
o`00o`3ooook0?ooo`<000001`3oool7000001L0oooo0P0000000`3oool000000?ooo`080?ooo`04
0000003oool0oooo000000T0oooo0P00000J0?ooo`00o`3ooooh0?ooo`<000001`3oool7000001/0
oooo0`0000090?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool06@3oool00?l0
oooom@3oool3000000T0oooo1@00000O0?ooo`<000002@3oool2000000X0oooo0`00000I0?ooo`00
o`3oooob0?ooo`<000003@3oool7000001h0oooo0P00000`0?ooo`00o`3ooonj0?ooo`D000000P3o
ool2000002`0oooo0`00000C0?ooo`H000006@3oool3000000030?ooo`000000000002l0oooo003o
0?oook`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02D0oooo1000
00050?ooo`030000003oool0oooo0140oooo1P00000I0?ooo`<00000;`3oool00?l0oooo_03oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool08P3oool3000000T0oooo00<0
00000?ooo`3oool04`3oool7000004P0oooo003o0?oook`0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo01l0oooo1000000;0?ooo`8000005`3oool7000004D0oooo003o
0?oook`0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo0`00
00040?ooo`030000003oool0oooo00T0oooo0P00000I0?ooo`H00000@`3oool00?l0oooo^`3oool2
000000@0oooo0P00000L0?ooo`<000001`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01X0oooo1P0000100?ooo`00o`3ooooL0?ooo`<00000203oool00`000000oooo0?ooo`0<0?oo
o`8000007@3oool7000003d0oooo003o0?ooomT0oooo0`00000:0?ooo`<000003P3oool00`000000
oooo0?ooo`0N0?ooo`D00000?03oool00?l0ooooeP3oool3000000d0oooo0P00000?0?ooo`800000
703oool7000003d0oooo003o0?ooom<0oooo0`00000@0?ooo`800000403oool2000001P0oooo1P00
00110?ooo`00o`3oooo@0?ooo`<000004P3oool300000100oooo1P00000A0?ooo`H00000A03oool0
0?l0ooooc@3oool3000000L0oooo00<000000?ooo`3oool02`3oool200000140oooo2`0000090?oo
o`H00000A`3oool00?l0oooob@3oool4000000X0oooo1000000:0?ooo`8000004@3oool00`000000
oooo0?ooo`030?ooo`X000000`3oool4000004X0oooo003o0?ooolH0oooo0`00000?0?ooo`H00000
1P3oool300000100oooo0P00000:0?ooo`D000000`3oool00`000000oooo0?ooo`1;0?ooo`00o`3o
ooo30?ooo`<000001P3oool00`000000oooo0?ooo`0<0?ooo`H000000`3oool200000140oooo00<0
00000?ooo`3oool0G`3oool00?l0oooo`03oool3000000P0oooo0`00000@0?ooo`P000004@3oool0
0`000000oooo0?ooo`1O0?ooo`00o`3ooonm0?ooo`@000002`3oool400000140oooo1`00000>0?oo
o`800000H@3oool00?l0oooo^P3oool3000000<0oooo00<000000?ooo`3oool02@3oool500000180
oooo2000000;0?ooo`030000003oool0oooo0600oooo003o0?oookL0oooo0`0000070?ooo`030000
003oool0oooo00P0oooo1P00000A0?ooo`8000000`3oool6000000L0oooo0P00001R0?ooo`00o`3o
oond0?ooo`<000002@3oool3000000X0oooo0P0000000`3oool0000000000002000000h0oooo0`00
00060?ooo`H00000103oool00`000000oooo0?ooo`1Q0?ooo`00o`3ooona0?ooo`<000003@3oool4
000000P0oooo0P0000020?ooo`@000003@3oool2000000X0oooo100000030?ooo`030000003oool0
oooo0640oooo003o0?ooojh0oooo0`00000@0?ooo`D000001`3oool3000000<0oooo0`00000<0?oo
o`8000003@3oool00`000000oooo0?ooo`1U0?ooo`00o`3ooon[0?ooo`<000004`3oool6000000L0
oooo0P0000040?ooo`@000002@3oool3000007D0oooo003o0?ooojL0oooo100000050?ooo`030000
003oool0oooo00l0oooo0P0000000`3oool0000000000002000000D0oooo0P0000050?ooo`@00000
203oool2000007H0oooo003o0?oooj@0oooo0`0000080?ooo`@000003`3oool200000080oooo1000
00040?ooo`8000001`3oool3000000L0oooo0P00001f0?ooo`00o`3ooonQ0?ooo`<00000303oool4
000000h0oooo0`0000030?ooo`<000000`3oool3000000L0oooo100000040?ooo`<00000MP3oool0
0?`0oooo0P0000000`3oool000000000002L0?ooo`<000003`3oool6000000d0oooo0P0000040?oo
o`@000000P3oool2000000P0oooo100000040?ooo`030000003oool0oooo07D0oooo003m0?ooo`03
0000003oool0000009X0oooo0`00000B0?ooo`80000000<0oooo0000000000000`00000;0?ooo`80
00001@3oool4000000030?ooo`000000000000X0oooo0`00001k0?ooo`00oP3oool00`000000oooo
0?ooo`2F0?ooo`<000005@3oool2000000<0oooo1@0000090?ooo`<000001P3oool6000000X0oooo
00<000000?ooo`3oool0NP3oool00?`0oooo0P0000000`3oool000000000002C0?ooo`<0000000<0
oooo0000003oool05@3oool2000000D0oooo100000090?ooo`8000001`3oool5000008L0oooo003o
0?oooi80oooo0`0000040?ooo`030000003oool0000000H0oooo00<000000?ooo`3oool02`3oool2
000000L0oooo100000070?ooo`800000203oool4000008L0oooo003o0?ooohl0oooo0`0000070?oo
o`/00000303oool2000000P0oooo1@0000050?ooo`<000002@3oool3000008H0oooo003o0?oooh`0
oooo0`0000070?oooa0000002P3oool2000000X0oooo1@0000040?ooo`8000002P3oool00`000000
oooo0?ooo`250?ooo`00o`3ooon90?ooo`<000002@3oool5000000T0oooo1000000:0?ooo`800000
2`3oool4000000<0oooo0P00002B0?ooo`00o`3ooon50?ooo`@00000303oool2000000h0oooo0P00
000:0?ooo`8000003@3oool4000000040?ooo`000000000000000940oooo003o0?oooh80oooo0`00
000?0?ooo`<000003`3oool2000000T0oooo0P00000>0?ooo`@0000000<0oooo0000003oool0T@3o
ool00?l0ooooO`3oool3000001<0oooo0P00000@0?ooo`800000203oool200000100oooo00<00000
0?ooo`3oool0T`3oool00?l0ooooO03oool3000000L0oooo00<000000?ooo`3oool0303oool20000
0140oooo00<000000?ooo`3oool01P3oool200000:H0oooo003o0?ooogT0oooo0`0000090?ooo`<0
00003@3oool300000100oooo0P0000070?ooo`800000YP3oool00?l0ooooMP3oool3000000d0oooo
0`00000=0?ooo`8000004@3oool2000000H0oooo0P00002V0?ooo`00o`3ooomc0?ooo`<000004@3o
ool3000000d0oooo0P00000A0?ooo`8000001@3oool200000:H0oooo003o0?ooog00oooo0`00000E
0?ooo`8000003P3oool200000140oooo0P0000050?ooo`800000Y@3oool00?l0ooooK@3oool30000
0080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0=0?ooo`8000003P3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo0P00002U0?ooo`00o`3ooomZ0?oo
o`<000001@3oool;000000`0oooo0`00000=0?ooo`8000004@3oool00`000000oooo0?ooo`2Z0?oo
o`00o`3ooomW0?ooo`<000001`3oool=000000`0oooo0`00000=0?ooo`800000_@3oool00?l0oooo
H`3oool4000000L0oooo1P0000080?ooo`<00000303oool3000000d0oooo0P00002l0?ooo`00o`3o
oomP0?ooo`<000002P3oool5000000X0oooo0P00000>0?ooo`<000003@3oool200000;/0oooo003o
0?oooed0oooo0`00000=0?ooo`8000003@3oool2000000l0oooo0P00000>0?ooo`030000003oool0
oooo0;T0oooo003o0?oooeX0oooo0`0000070?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool02`3oool4000000l0oooo0P0000080?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0^@3oool00?l0ooooE`3oool3000000T0oooo0`0000070?ooo`030000003oool0oooo00X0
oooo1000000@0?ooo`<00000103oool400000<00oooo003o0?oooe@0oooo0`00000<0?ooo`800000
4`3oool4000001<0oooo2@0000310?ooo`00o`3ooomA0?ooo`<000003`3oool200000180oooo1000
000B0?ooo`P00000a03oool00?l0ooooCP3oool300000180oooo0P00000A0?ooo`<000002P3oool0
0`000000oooo0?ooo`030?ooo`T00000a`3oool00?l0ooooB`3oool3000000L0oooo00<000000?oo
o`3oool02P3oool3000000l0oooo1000000;0?ooo`030000003oool0oooo00<0oooo1000003<0?oo
o`00o`3ooom80?ooo`<0000000<0oooo0000000000001P3oool3000000/0oooo0P00000?0?ooo`@0
00002`3oool200000=D0oooo003o0?ooodD0oooo0`0000040?ooo`8000001`3oool3000000X0oooo
0P00000?0?ooo`800000303oool300000=D0oooo003o0?oood40oooo100000070?ooo`800000203o
ool3000000T0oooo0`0000050?ooo`030000003oool0oooo00H0oooo0P00000;0?ooo`<00000eP3o
ool00?l0oooo?P3oool3000000P0oooo00@000000?ooo`00000000000P3oool00`000000oooo0?oo
o`050?ooo`<000001`3oool<000000H0oooo0`0000050?ooo`L00000e`3oool00?l0oooo>`3oool3
000000L0oooo3@0000060?ooo`<000000`3oool@000000H0oooo3@00003H0?ooo`00o`3ooolh0?oo
o`<00000203oool@000000H0oooo2P0000090?ooo`<000001@3oool800000=d0oooo003o0?ooocD0
oooo0`00000:0?ooo`@00000103oool00`000000oooo0?ooo`040?ooo`<000001P3oool5000000d0
oooo0P00003[0?ooo`00o`3ooolb0?ooo`<000003@3oool2000000H0oooo00<000000?ooo`3oool0
1@3oool3000000D0oooo0`00000?0?ooo`<00000jP3oool00?l0oooo0P00000]0?ooo`<000003`3o
ool200000100oooo0`0000050?ooo`<000003@3oool300000>/0oooo003n0?ooo`040000003oool0
oooo000002T0oooo0`00000B0?ooo`8000004@3oool3000000D0oooo0`00000;0?ooo`<00000k03o
ool00?h0oooo00@000000?ooo`3oool000009P3oool3000001D0oooo0P00000B0?ooo`<000001@3o
ool3000000D0oooo1`00003]0?ooo`00oP3oool010000000oooo0?ooo`00000S0?ooo`<00000603o
ool300000140oooo0P0000070?ooo`d00000kP3oool00?h0oooo00@000000?ooo`3oool00000803o
ool4000001`0oooo00<000000?ooo`3oool03`3oool2000000P0oooo1P00003d0?ooo`00o`3oool2
000001d0oooo100000030?ooo`040000003oool0oooo000001T0oooo0P00000@0?ooo`800000203o
ool200000?P0oooo003o0?oooa`0oooo0`0000090?ooo`<000006@3oool2000000l0oooo0P00003o
0?ooo`<0oooo003o0?oooaT0oooo0`00000=0?ooo`<00000603oool5000000/0oooo0`00003o0?oo
o`<0oooo003o0?oooaH0oooo0`00000A0?ooo`<000002P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00D0oooo1P0000070?ooo`@00000o`3oool40?ooo`00o`3ooolC0?ooo`<00000
1P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo0P0000070?ooo``00000
203oool600000080oooo1@00003o0?ooo`D0oooo003o0?oooa00oooo0`0000050?ooo`d000001`3o
ool2000000<0oooo400000090?ooo`T00000o`3oool70?ooo`00o`3oool=0?ooo`<000001`3oool?
000000H0oooo2@00000:0?ooo`8000002`3oool500000?l0oooo2@3oool00?l0oooo2P3oool30000
00T0oooo0`00000;0?ooo`@000001@3oool5000000d0oooo0P00003o0?oooaT0oooo003o0?ooo`L0
oooo0`00000<0?ooo`8000003@3oool4000000D0oooo0`00000>0?ooo`800000o`3ooolI0?ooo`00
o`3oool40?ooo`<00000103oool00`000000oooo0?ooo`070?ooo`800000403oool3000000D0oooo
0`00000<0?ooo`@00000o`3ooolH0?ooo`00o`3oool10?ooo`<000001P3oool3000000P0oooo0P00
000A0?ooo`<000001@3oool2000000/0oooo1000003o0?oooaT0oooo003l0?ooo`D00000203oool4
000000L0oooo0P00000B0?ooo`<000001@3oool2000000L0oooo1@00003o0?oooa/0oooo003i0?oo
o`<00000103oool00`000000oooo0?ooo`060?ooo`D000001P3oool300000140oooo0P0000060?oo
o`<000000`3oool700000?l0oooo703oool00?H0oooo0`0000070?ooo`030000003oool0oooo00H0
oooo0P000000103oool000000000000000070?ooo`030000003oool0oooo00l0oooo0P0000070?oo
o`T00000o`3ooolO0?ooo`00l`3oool3000000H0oooo00D000000?ooo`3oool0oooo000000080?oo
o`8000000P3oool3000000H0oooo0P00000@0?ooo`800000203oool500000?l0oooo8P3oool00?00
oooo0`0000080?ooo`<000002`3oool2000000<0oooo0`0000060?ooo`8000003`3oool2000000T0
oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00k@3oool3000000`0oooo0`0000090?ooo`800000
1@3oool2000000H0oooo1@00000;0?ooo`<00000o`3oool_0?ooo`00jP3oool3000000L0oooo00<0
00000?ooo`3oool01P3oool3000000P0oooo0P0000060?ooo`8000001P3oool6000000L0oooo1000
003o0?oooc00oooo003W0?ooo`<000002@3oool3000000P0oooo0`0000070?ooo`8000001P3oool3
000000P0oooo1P0000020?ooo`D00000o`3ooola0?ooo`00i03oool3000000D0oooo00<000000?oo
o`3oool01@3oool3000000P0oooo0`0000060?ooo`8000001`3oool3000000T0oooo2@00003o0?oo
oc<0oooo003Q0?ooo`<000001`3oool4000000H0oooo0`0000080?ooo`8000001P3oool2000000P0
oooo0`00000:0?ooo`D00000o`3ooole0?ooo`00gP3oool3000000/0oooo1@0000050?ooo`<00000
203oool2000000D0oooo0P0000090?ooo`<00000o`3ooom30?ooo`00fP3oool4000000H0oooo00<0
00000?ooo`3oool01@3oool7000000@0oooo0`0000070?ooo`<000000`3oool2000000/0oooo0`00
003o0?oood80oooo003G0?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`<000001P3oool2
00000080oooo1@0000030?ooo`800000203oool300000080oooo0P00000<0?ooo`<00000o`3ooom1
0?ooo`00e03oool3000000D0oooo0P0000060?ooo`<000001@3oool3000000<0oooo100000030?oo
o`800000203oool3000000030?ooo`000000000000d0oooo00<000000?ooo`3oool0o`3ooom00?oo
o`00d@3oool3000000H0oooo1@0000060?ooo`<000001@3oool2000000D0oooo10000000103oool0
00000000000000080?ooo`D00000o`3ooom@0?ooo`00cP3oool3000000H0oooo1`0000080?ooo`<0
0000103oool2000000H0oooo200000080?ooo`@00000o`3ooom@0?ooo`00b`3oool3000000H0oooo
1`00000<0?ooo`<000000`3oool2000000P0oooo1`0000080?ooo`<00000o`3ooom@0?ooo`00b03o
ool3000000H0oooo1`00000@0?ooo`<000000P3oool3000000T0oooo1P0000070?ooo`800000o`3o
oomA0?ooo`00a@3oool3000000P0oooo1@00000D0?ooo`<000000P3oool2000000/0oooo1@00003o
0?oooeT0oooo00320?ooo`<00000303oool3000001H0oooo0`0000000`3oool000000000000=0?oo
o`@00000o`3ooomH0?ooo`00_`3oool3000000P0oooo0P0000060?ooo`<000005P3oool6000000h0
oooo00<000000?ooo`3oool0o`3ooomG0?ooo`00_03oool3000000/0oooo0P0000070?ooo`<00000
5P3oool500000?l0ooooJ03oool00;P0oooo1000000>0?ooo`800000203oool3000001H0oooo1000
003o0?ooofP0oooo002e0?ooo`@00000103oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool3
000001H0oooo0`00003o0?ooofP0oooo002b0?ooo`<000000`3oool010000000oooo0?ooo`3oool3
000000/0oooo0P00000:0?ooo`<000005P3oool300000?l0ooooI`3oool00:l0oooo0`00000;0?oo
o`<000002@3oool2000000`0oooo0`00000F0?ooo`030000003oool0oooo0?l0ooooIP3oool00:`0
oooo0`00000?0?ooo`<00000203oool2000000d0oooo0`00003o0?ooogh0oooo002Y0?ooo`<00000
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000070?ooo`800000
3P3oool300000?l0ooooO@3oool00:H0oooo0`0000060?ooo`/000001P3oool700000080oooo0P00
000?0?ooo`<00000o`3oooml0?ooo`00X`3oool3000000P0oooo3@0000060?ooo`/000003`3oool3
00000?l0ooooN`3oool00:00oooo0`0000040?ooo`030000003oool0oooo00@0oooo0P0000090?oo
o`<000001P3oool300000080oooo2`00000:0?ooo`<00000o`3ooomj0?ooo`00W@3oool3000000H0
oooo0`0000050?ooo`<000002@3oool3000000H0oooo0`0000020?ooo`8000000P3oool;000000H0
oooo00<000000?ooo`3oool0o`3ooomi0?ooo`00VP3oool3000000X0oooo0`0000060?ooo`030000
003oool0oooo00P0oooo0`0000060?ooo`<000002`3oool600000?l0ooooP@3oool009H0oooo1000
00050?ooo`030000003oool0oooo00H0oooo0`0000050?ooo`8000002P3oool3000000H0oooo0`00
000?0?ooo`030000003oool0oooo0?l0ooooO`3oool009<0oooo0`0000080?ooo`<00000203oool3
000000D0oooo00<000000?ooo`3oool02@3oool3000000H0oooo0`00003o0?oooi00oooo002@0?oo
o`<0000000<0oooo0000003oool02@3oool3000000P0oooo0`0000040?ooo`030000003oool0oooo
00X0oooo0`0000060?ooo`<00000o`3ooon?0?ooo`00S@3oool3000000@0oooo00<000000?ooo`3o
ool02@3oool3000000P0oooo0`00000A0?ooo`<000001P3oool300000?l0ooooSP3oool008X0oooo
0`0000050?ooo`030000003oool0oooo00`0oooo0`0000080?ooo`<000004@3oool3000000H0oooo
00<000000?ooo`3oool0o`3ooon=0?ooo`00Q`3oool3000000L0oooo0`00000>0?ooo`<00000203o
ool300000140oooo0`00003o0?oooiD0oooo00240?ooo`<000002`3oool3000000h0oooo0`000008
0?ooo`<000004@3oool00`000000oooo0?ooo`3o0?oooi@0oooo00210?ooo`<000003`3oool30000
00`0oooo1@0000080?ooo`<00000o`3ooonW0?ooo`00CP3oool500000080oooo0P00000W0?ooo`<0
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo0`0000080?ooo`T0
0000203oool300000?l0ooooYP3oool00500oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0240oooo0`0000040?ooo`d000001P3oool3000000@0oooo1P0000040?ooo`<0
0000203oool300000?l0ooooY@3oool00500oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01h0oooo0`0000060?ooo`l000001P3oool9000000P0oooo0`0000080?ooo`<0
0000o`3ooonT0?ooo`00B03oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01X0oooo100000080?ooo`<000002`3oool3000000H0oooo1@00000<0?ooo`<0
0000203oool00`000000oooo0?ooo`3o0?oooj<0oooo001@0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0G0?ooo`<00000303oool2000000T0oooo1`0000060?ooo`<0
00003P3oool300000?l0oooo[@3oool004l0oooo0P0000040?ooo`8000005`3oool4000000d0oooo
0P0000090?ooo`L00000203oool3000000h0oooo0`00003o0?oooj`0oooo001[0?ooo`<000000`3o
ool00`000000oooo0?ooo`0;0?ooo`8000002@3oool00`000000oooo0?ooo`0=0?ooo`<000003P3o
ool00`000000oooo0?ooo`3o0?oooj/0oooo001X0?ooo`<00000503oool2000001X0oooo0`00003o
0?oook/0oooo001U0?ooo`<000000`3oool00`000000oooo0?ooo`0A0?ooo`<000004@3oool20000
00L0oooo0`00003o0?oookX0oooo001R0?ooo`<000001@3oool3000001<0oooo0`00000@0?ooo`80
0000203oool300000?l0oooo^@3oool005l0oooo0`0000040?ooo`030000003oool0oooo0080oooo
0`00000C0?ooo`@000003P3oool2000000T0oooo00<000000?ooo`3oool0o`3ooonh0?ooo`00G03o
ool3000000@0oooo100000050?ooo`<000004`3oool4000000d0oooo0P00003o0?oool@0oooo001I
0?ooo`<00000103oool6000000L0oooo0`0000090?ooo`030000003oool0oooo00P0oooo1000000:
0?ooo`@00000o`3oooo30?ooo`00EP3oool3000000@0oooo1P00000;0?ooo`<000001P3oool40000
00X0oooo1@0000040?ooo`L00000o`3oooo40?ooo`00DP3oool4000000<0oooo1`00000?0?ooo`<0
00000P3oool6000000d0oooo3000003o0?ooolH0oooo001?0?ooo`<000001P3oool5000001<0oooo
2000000@0?ooo`L00000o`3oooo:0?ooo`00C03oool4000000T0oooo0`00000E0?ooo`@000003`3o
ool00`000000oooo0?ooo`3o0?ooom80oooo00190?ooo`<000000`3oool00`000000oooo0?ooo`08
0?ooo`<000005@3oool4000000/0oooo1@00003o0?ooom<0oooo00160?ooo`<000000`3oool00`00
0000oooo0?ooo`02000000X0oooo0`00000F0?ooo`<000001`3oool700000?l0ooooe03oool004<0
oooo0`0000040?ooo`X0000000<0oooo0000003oool01@3oool3000000D0oooo1000000=0?ooo`<0
00000`3oool700000?l0ooooe`3oool00400oooo0`0000050?ooo`l000001P3oool;000000h0oooo
2@00003o0?ooomX0oooo000m0?ooo`<000001P3oool5000000L0oooo1`0000050?ooo`H000004`3o
ool500000?l0oooog@3oool003X0oooo0`0000080?ooo`@000003@3oool4000000D0oooo1000000?
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooooN0?ooo`00=`3oool30000
00`0oooo0`00000?0?ooo`<000001P3oool3000000/0oooo1@00003o0?ooonD0oooo000d0?ooo`<0
00001@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo0`00000?0?ooo`<0
00001P3oool3000000L0oooo1`00003o0?ooonH0oooo000`0?ooo`@00000103oool<000000@0oooo
0`00000?0?ooo`<000001P3oool3000000<0oooo1`00003o0?ooonT0oooo000]0?ooo`<000001`3o
ool>000000@0oooo0`00000>0?ooo`800000203oool900000?l0ooook03oool002X0oooo10000008
0?ooo`<000002P3oool00`000000oooo0?ooo`040?ooo`@00000303oool3000000P0oooo1@00003o
0?ooonl0oooo000W0?ooo`<000000`3oool00`000000oooo0?ooo`060?ooo`8000004`3oool40000
00/0oooo100000080?ooo`030000003oool0oooo0?l0ooool03oool002@0oooo0`00000>0?ooo`80
00005P3oool3000000/0oooo0P00003o0?oooo`0oooo000Q0?ooo`<000000`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00H0oooo0P00000G0?ooo`<00000203oool400000?l0oooo
o03oool001h0oooo0`0000030?ooo`/000001P3oool3000001L0oooo0`0000040?ooo`H00000o`3o
ooom0?ooo`006`3oool3000000@0oooo3P0000060?ooo`<00000403oool2000000D0oooo2P00003o
0?ooool0oooo000H0?ooo`<00000103oool6000000T0oooo0`0000060?ooo`<000003`3oool20000
00H0oooo1@00003o0?ooool0oooo103oool001D0oooo0`0000030?ooo`030000003oool0oooo00D0
0000303oool3000000H0oooo0`00000>0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooool0
oooo1@3oool00180oooo0`0000050?ooo`<000000P3oool3000000d0oooo0P0000080?ooo`D00000
2P3oool300000?l0ooooo`3oool?0?ooo`003P3oool4000000T0oooo0P0000030?ooo`@000002P3o
ool4000000030?ooo`000000oooo00D0oooo1P0000060?ooo`@00000o`3ooooo0?oooa00oooo000;
0?ooo`<000003@3oool3000000<0oooo100000060?ooo`/000001`3oool6000000030?ooo`000000
000000<00000o`3ooooo0?oooa40oooo00080?ooo`<0000000<0oooo0000003oool03P3oool20000
00D0oooo0`0000030?ooo`h00000203oool800000?l0ooooo`3ooolC0?ooo`001@3oool3000000@0
oooo0P00000>0?ooo`8000001P3oool8000000T0oooo0`0000090?ooo`@00000o`3ooooo0?oooaD0
oooo00020?ooo`<000001`3oool4000000X0oooo1@0000060?ooo`D000002`3oool200000?l0oooo
o`3ooolS0?ooo`000P00000;0?ooo`D000001@3oool8000000L0oooo0`00000;0?ooo`@00000o`3o
oooo0?ooob80oooo000?0?ooo``000000P3oool3000000L0oooo100000090?ooo`<00000o`3ooooo
0?ooob<0oooo000A0?ooo`L000001P3oool2000000P0oooo100000040?ooo`H00000o`3ooooo0?oo
ob@0oooo000D0?ooo`D000001@3oool3000000T0oooo2`00003o0?ooool0oooo9@3oool001H0oooo
1@0000040?ooo`8000002P3oool500000?l0ooooo`3ooolZ0?ooo`00603oool6000000030?ooo`00
0000000000X0oooo0P00003o0?ooool0oooo;@3oool001X0oooo2000003o0?ooool0oooo>03oool0
01d0oooo1@00003o0?ooool0oooo>03oool001l0oooo1000003o0?ooool0oooo=`3oool00240oooo
00<000000?ooo`3oool0o`3ooooo0?ooocH0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {205.875, 0}} -> {0.0494824, 0.301488, \
0.00171789, 0.00171789}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35436 
%%ImageSize: 600 212.616 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0498163 1.04982 -0.336555 1.04982 [
[.09072 .27166 -8.32646 -9 ]
[.09072 .27166 9.67354 0 ]
[.45766 .15262 -2.98957 -9 ]
[.45766 .15262 3.01043 0 ]
[.85951 .02232 -6.472 -9 ]
[.85951 .02232 5.528 0 ]
[.45788 .08701 -4.98262 -12.75 ]
[.45788 .08701 5.01738 0 ]
[.98988 .00679 0 -5.94908 ]
[.98988 .00679 24 3.05092 ]
[.99865 .01957 0 -5.94128 ]
[.99865 .01957 6 3.05872 ]
[1.00734 .03224 0 -5.93355 ]
[1.00734 .03224 18 3.06645 ]
[1.05969 -0.00256 0 -8.41863 ]
[1.05969 -0.00256 10 4.33137 ]
[ 0 0 0 0 ]
[ 1 .35436 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00063 .31357 m
.96997 0 L
s
.08974 .28475 m
.08925 .29129 L
s
[(-10)] .09072 .27166 -0.07484 1 Mshowa
.45761 .16574 m
.45759 .1723 L
s
[(0)] .45766 .15262 -0.00348 1 Mshowa
.86054 .0354 m
.86106 .04194 L
s
[(10)] .85951 .02232 .07867 1 Mshowa
.125 Mabswid
.16073 .26178 m
.16049 .26571 L
s
.23298 .23841 m
.23279 .24234 L
s
.30652 .21462 m
.30639 .21855 L
s
.38138 .1904 m
.38131 .19434 L
s
.53524 .14063 m
.53529 .14457 L
s
.6143 .11505 m
.61441 .11899 L
s
.69485 .089 m
.69502 .09293 L
s
.77691 .06245 m
.77715 .06638 L
s
.01997 .30732 m
.01962 .31124 L
s
.94578 .00782 m
.94616 .01174 L
s
gsave
.45788 .08701 -65.9826 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.96997 0 m
.99923 .04263 L
s
.97739 .01081 m
.97114 .01282 L
s
[(-0.5)] .98988 .00679 -1 .32202 Mshowa
.98615 .02357 m
.9799 .02557 L
s
[(0)] .99865 .01957 -1 .32028 Mshowa
.99483 .03623 m
.98858 .03822 L
s
[(0.5)] 1.00734 .03224 -1 .31857 Mshowa
.125 Mabswid
.97915 .01337 m
.9754 .01458 L
s
.9809 .01593 m
.97715 .01713 L
s
.98265 .01848 m
.97891 .01968 L
s
.9844 .02103 m
.98065 .02223 L
s
.98789 .02611 m
.98414 .02731 L
s
.98963 .02865 m
.98588 .02985 L
s
.99137 .03118 m
.98762 .03238 L
s
.9931 .03371 m
.98935 .0349 L
s
.97563 .00824 m
.97188 .00945 L
s
.97386 .00567 m
.97011 .00688 L
s
.97209 .00309 m
.96835 .0043 L
s
.97032 .00051 m
.96658 .00172 L
s
.99656 .03874 m
.99281 .03994 L
s
.99829 .04126 m
.99454 .04245 L
s
gsave
1.05969 -0.00256 -61 -12.4186 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35436 L
0 .35436 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.05312 .33184 m
.04679 .33081 L
s
.05817 .33175 m
.05312 .33184 L
s
.06387 .32993 m
.05817 .33175 L
s
.09357 .33109 m
.06715 .30741 L
s
.04679 .33081 m
.04109 .32806 L
s
.06641 .3276 m
.06387 .32993 L
s
.04109 .32806 m
.03855 .32582 L
s
.06769 .32414 m
.06641 .3276 L
s
.07147 .3275 m
.05375 .31172 L
s
.03855 .32582 m
.03662 .32184 L
s
.03662 .32184 m
.03787 .31837 L
s
.08738 .3209 m
.09246 .32081 L
s
.08105 .31987 m
.08738 .3209 L
s
.09246 .32081 m
.0982 .31898 L
s
.0982 .31898 m
.10079 .31663 L
s
.03787 .31837 m
.0404 .31601 L
s
.10079 .31663 m
.10212 .31314 L
s
.0404 .31601 m
.04611 .31418 L
s
.0512 .31408 m
.05757 .31512 L
s
.04611 .31418 m
.0512 .31408 L
s
.10212 .31314 m
.10029 .30912 L
s
.07225 .30732 m
.07095 .31082 L
s
.10029 .30912 m
.09778 .30684 L
s
.1258 .30864 m
.11945 .3076 L
s
.1309 .30855 m
.1258 .30864 L
s
.1367 .3067 m
.1309 .30855 L
s
.11945 .3076 m
.11377 .3048 L
s
.07482 .30494 m
.07225 .30732 L
s
.09778 .30684 m
.09207 .30404 L
s
.13933 .30433 m
.1367 .3067 L
s
.08059 .30309 m
.07482 .30494 L
s
.11377 .3048 m
.11127 .30252 L
s
.14073 .3008 m
.13933 .30433 L
s
.09207 .30404 m
.0857 .30299 L
s
.0857 .30299 m
.08059 .30309 L
s
.11127 .30252 m
.10944 .29847 L
s
.18804 .30109 m
.16218 .27685 L
s
.10944 .29847 m
.1108 .29493 L
s
.16069 .29751 m
.15433 .29646 L
s
.16582 .29742 m
.16069 .29751 L
s
.17166 .29555 m
.16582 .29742 L
s
.15433 .29646 m
.14866 .29363 L
s
.17434 .29316 m
.17166 .29555 L
s
.1108 .29493 m
.11342 .29253 L
s
.14866 .29363 m
.14618 .29133 L
s
.17579 .2896 m
.17434 .29316 L
s
.11342 .29253 m
.11924 .29066 L
s
.12438 .29056 m
.13077 .29162 L
s
.14618 .29133 m
.1444 .28724 L
s
.11924 .29066 m
.12438 .29056 L
s
.1444 .28724 m
.14581 .28368 L
s
.19784 .28565 m
.19147 .28459 L
s
.20299 .28556 m
.19784 .28565 L
s
.2089 .28368 m
.20299 .28556 L
s
.19147 .28459 m
.18582 .28174 L
s
.21162 .28126 m
.2089 .28368 L
s
.14581 .28368 m
.14847 .28126 L
s
.24379 .28184 m
.23819 .27898 L
s
.24895 .28174 m
.24379 .28184 L
s
.25291 .28048 m
.24895 .28174 L
s
.18582 .28174 m
.18336 .27942 L
s
.18582 .28174 m
.20946 .27418 L
s
.14847 .28126 m
.15434 .27937 L
s
.21237 .27947 m
.21162 .28126 L
s
.1595 .27927 m
.16591 .28034 L
s
.2119 .27651 m
.21237 .27947 L
s
.18336 .27942 m
.18162 .27529 L
s
.15434 .27937 m
.1595 .27927 L
s
.23819 .27898 m
.2175 .25906 L
s
.22863 .27738 m
.2425 .27296 L
s
.20946 .27418 m
.2119 .27651 L
s
.18162 .27529 m
.18309 .27169 L
s
.18309 .27169 m
.1858 .26925 L
s
.1858 .26925 m
.19173 .26735 L
s
.19691 .26725 m
.20333 .26833 L
s
.19173 .26735 m
.19691 .26725 L
s
.2572 .26671 m
.2508 .26564 L
s
.26239 .26661 m
.2572 .26671 L
s
.26838 .26471 m
.26239 .26661 L
s
.2508 .26564 m
.24518 .26274 L
s
.30074 .26529 m
.2756 .24038 L
s
.27117 .26225 m
.26838 .26471 L
s
.24518 .26274 m
.24275 .26039 L
s
.27277 .25862 m
.27117 .26225 L
s
.27638 .26216 m
.25706 .24317 L
s
.24275 .26039 m
.2411 .2562 L
s
.2411 .2562 m
.24266 .25255 L
s
.34018 .25433 m
.33698 .25378 L
s
.34103 .2525 m
.34018 .25433 L
s
.29725 .25393 m
.30247 .25383 L
s
.28763 .2523 m
.29725 .25393 L
s
.30247 .25383 m
.30852 .2519 L
s
.33698 .25378 m
.33783 .25195 L
s
.24266 .25255 m
.24545 .25007 L
s
.33783 .25195 m
.34103 .2525 L
s
.30852 .2519 m
.31136 .24943 L
s
.24545 .25007 m
.25146 .24814 L
s
.31136 .24943 m
.30981 .24521 L
s
.25669 .24804 m
.26313 .24913 L
s
.25146 .24814 m
.25669 .24804 L
s
.36045 .24789 m
.35725 .24735 L
s
.36132 .24605 m
.36045 .24789 L
s
.35725 .24735 m
.35812 .24551 L
s
.35812 .24551 m
.36132 .24605 L
s
.30981 .24521 m
.29785 .23322 L
s
.33076 .24481 m
.3141 .22799 L
s
.23689 .24172 m
.23411 .24421 L
s
.25706 .24317 m
.25139 .24023 L
s
.37354 .24217 m
.34886 .21682 L
s
.24292 .23978 m
.23689 .24172 L
s
.25139 .24023 m
.24816 .23968 L
s
.24816 .23968 m
.24292 .23978 L
s
.35108 .23833 m
.33094 .21778 L
s
.41042 .23046 m
.38599 .20488 L
s
.38586 .22724 m
.3536 .22168 L
s
.36652 .22391 m
.37151 .20953 L
s
.33094 .21778 m
.3253 .21478 L
s
.41886 .21671 m
.40259 .19954 L
s
.32001 .21488 m
.31591 .21621 L
s
.3253 .21478 m
.32001 .21488 L
s
.42392 .21351 m
.42922 .21341 L
s
.41423 .21183 m
.42392 .21351 L
s
.42922 .21341 m
.43545 .21142 L
s
.43545 .21142 m
.43847 .20887 L
s
.43847 .20887 m
.4371 .20452 L
s
.4468 .20621 m
.45212 .20611 L
s
.4371 .20452 m
.4468 .20621 L
s
.45212 .20611 m
.45838 .20411 L
s
.4371 .20452 m
.42553 .19216 L
s
.45838 .20411 m
.46142 .20154 L
s
.46142 .20154 m
.46009 .19717 L
s
.46009 .19717 m
.4486 .18474 L
s
.48144 .19676 m
.46545 .17932 L
s
.48661 .1935 m
.49196 .1934 L
s
.47689 .1918 m
.48661 .1935 L
s
.49196 .1934 m
.49828 .19138 L
s
.49828 .19138 m
.50137 .18879 L
s
.50137 .18879 m
.5001 .18438 L
s
.5001 .18438 m
.48873 .17184 L
s
.52468 .18136 m
.51818 .18021 L
s
.53004 .18125 m
.52468 .18136 L
s
.53643 .17922 m
.53004 .18125 L
s
.51818 .18021 m
.51268 .17713 L
s
.53957 .1766 m
.53643 .17922 L
s
.51268 .17713 m
.51042 .17462 L
s
.5416 .17273 m
.53957 .1766 L
s
.51042 .17462 m
.50915 .17015 L
s
.54039 .16826 m
.5416 .17273 L
s
.55991 .17173 m
.53639 .145 L
s
.50915 .17015 m
.51115 .16626 L
s
.56308 .1691 m
.56848 .169 L
s
.55658 .16794 m
.56308 .1691 L
s
.56848 .169 m
.57492 .16694 L
s
.53815 .16573 m
.54039 .16826 L
s
.57492 .16694 m
.57811 .16431 L
s
.51115 .16626 m
.51428 .16362 L
s
.53264 .16262 m
.53815 .16573 L
s
.57811 .16431 m
.58021 .16039 L
s
.51428 .16362 m
.52069 .16156 L
s
.5261 .16145 m
.53264 .16262 L
s
.52069 .16156 m
.5261 .16145 L
s
.58021 .16039 m
.57905 .15589 L
s
.54971 .15386 m
.54765 .1578 L
s
.57905 .15589 m
.57684 .15333 L
s
.60616 .15535 m
.59964 .15418 L
s
.61159 .15525 m
.60616 .15535 L
s
.61809 .15317 m
.61159 .15525 L
s
.59964 .15418 m
.59418 .15104 L
s
.55289 .1512 m
.54971 .15386 L
s
.57684 .15333 m
.57135 .15019 L
s
.62135 .15051 m
.61809 .15317 L
s
.55936 .14912 m
.55289 .1512 L
s
.59418 .15104 m
.59198 .14848 L
s
.62352 .14656 m
.62135 .15051 L
s
.62678 .1504 m
.60374 .12326 L
s
.57135 .15019 m
.5648 .14902 L
s
.5648 .14902 m
.55936 .14912 L
s
.59198 .14848 m
.59083 .14393 L
s
.64203 .14554 m
.62679 .12744 L
s
.59083 .14393 m
.59296 .13996 L
s
.6475 .14216 m
.65295 .14206 L
s
.64096 .14098 m
.6475 .14216 L
s
.65295 .14206 m
.65952 .13996 L
s
.63552 .13781 m
.64096 .14098 L
s
.59296 .13996 m
.59621 .13727 L
s
.59621 .13727 m
.60274 .13517 L
s
.60821 .13506 m
.61477 .13625 L
s
.60274 .13517 m
.60821 .13506 L
s
.67161 .13447 m
.66726 .13258 L
s
.67928 .13366 m
.67161 .13447 L
s
.68588 .13155 m
.67928 .13366 L
s
.66726 .13258 m
.66731 .12928 L
s
.69144 .12814 m
.68588 .13155 L
s
.722 .1315 m
.70402 .10926 L
s
.66731 .12928 m
.67064 .12657 L
s
.69151 .12483 m
.69144 .12814 L
s
.67064 .12657 m
.68061 .12173 L
s
.70798 .12451 m
.72351 .11955 L
s
.65868 .11884 m
.65864 .12217 L
s
.68061 .12173 m
.68396 .11901 L
s
.68396 .11901 m
.68403 .11567 L
s
.66422 .1154 m
.65868 .11884 L
s
.68403 .11567 m
.68295 .11436 L
s
.67086 .11327 m
.66422 .1154 L
s
.73687 .11529 m
.72634 .1021 L
s
.68295 .11436 m
.67859 .11244 L
s
.67859 .11244 m
.67086 .11327 L
s
.70402 .10926 m
.70304 .10458 L
s
.76147 .10745 m
.74682 .08884 L
s
.70304 .10458 m
.70644 .10182 L
s
.77494 .10315 m
.77395 .08012 L
s
.72634 .1021 m
.7254 .0974 L
s
.70644 .10182 m
.71091 .10039 L
s
.7254 .0974 m
.72883 .09463 L
s
.72883 .09463 m
.73556 .09246 L
s
.80202 .09451 m
.77395 .08012 L
s
.74112 .09235 m
.75102 .09418 L
s
.73556 .09246 m
.74112 .09235 L
s
.81335 .0909 m
.80809 .06913 L
s
.83154 .0851 m
.82641 .06324 L
s
.83154 .0851 m
.80809 .06913 L
s
.84981 .07927 m
.82641 .06324 L
s
.86356 .07489 m
.87487 .04766 L
s
.88888 .06681 m
.84942 .05584 L
s
.90043 .06313 m
.90047 .03943 L
s
.92829 .05424 m
.90047 .03943 L
s
.93995 .05053 m
.9657 .04231 L
s
.9657 .04231 m
.92621 .03115 L
s
.90047 .03943 m
.8918 .03538 L
s
.8918 .03538 m
.88512 .03411 L
s
.87944 .03422 m
.87711 .03498 L
s
.88512 .03411 m
.87944 .03422 L
s
.92621 .03115 m
.9521 .02282 L
s
0 g
.25 Mabswid
.00063 .31357 m
.96997 0 L
s
.08974 .28475 m
.08925 .29129 L
s
[(-10)] .09072 .27166 -0.07484 1 Mshowa
.45761 .16574 m
.45759 .1723 L
s
[(0)] .45766 .15262 -0.00348 1 Mshowa
.86054 .0354 m
.86106 .04194 L
s
[(10)] .85951 .02232 .07867 1 Mshowa
.125 Mabswid
.16073 .26178 m
.16049 .26571 L
s
.23298 .23841 m
.23279 .24234 L
s
.30652 .21462 m
.30639 .21855 L
s
.38138 .1904 m
.38131 .19434 L
s
.53524 .14063 m
.53529 .14457 L
s
.6143 .11505 m
.61441 .11899 L
s
.69485 .089 m
.69502 .09293 L
s
.77691 .06245 m
.77715 .06638 L
s
.01997 .30732 m
.01962 .31124 L
s
.94578 .00782 m
.94616 .01174 L
s
gsave
.45788 .08701 -65.9826 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 212.563},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000e2000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3ooolL0?ooo`8000004P3oool2000000@0oooo0P0000040?oo
o`800000703oool00?l0ooooo`3ooolI0?ooo`@0000000<0oooo0000003oool03`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo000001/0oooo003o0?ooool0oooo5P3oool30000
00D0oooo00<000000?ooo`3oool03P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo01T0oooo003o0?ooool0oooo4`3oool3000000H0oooo0P0000000`3oool000000?ooo`080?oo
o`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000703oool00?l0ooooo`3oool@0?oo
o`<000002P3oool2000000030?ooo`000000oooo00d0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`0K0?ooo`00o`3ooooI0?ooo`D000000P3oool2000002T0oooo1000000>0?oo
o`<000003`3oool2000000X0oooo0`00000K0?ooo`00o`3ooooK0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0S0?ooo`<000000`3oool00`000000oooo0?ooo`0>0?oo
o`800000>03oool00?l0oooof`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0803oool3000000H0oooo00<000000?ooo`3oool02`3oool300000080oooo00<000000?oo
o`3oool02P3oool2000002T0oooo003o0?ooom/0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01d0oooo0`00000J0?ooo`<000002`3oool010000000oooo0?ooo`00000X
0?ooo`00o`3ooooK0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0J
0?ooo`<00000803oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo000002P0oooo003o
0?ooomX0oooo0P0000040?ooo`8000006P3oool300000240oooo0P0000000`3oool000000?ooo`08
0?ooo`040000003oool0oooo000002P0oooo003o0?ooooT0oooo0`00000U0?ooo`<000002@3oool0
10000000oooo0?ooo`00000X0?ooo`00o`3oooof0?ooo`<000006@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00L0oooo0P00000Y0?ooo`00o`3ooooc0?ooo`<000006@3oool40000
00l0oooo1000000c0?ooo`00o`3oooo`0?ooo`<00000603oool7000000l0oooo0`0000000`3oool0
00000?ooo`0;0?ooo`800000103oool2000000@0oooo0P00000I0?ooo`00o`3oooo/0?ooo`@00000
5`3oool8000001D0oooo0`00000:0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool00000603oool00?l0ooooj@3oool3000001L0oooo2000000K0?ooo`8000002@3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo01H0oooo003o0?ooonH0oooo0`00000J0?ooo`@0
00007@3oool2000000030?ooo`000000000000P0oooo00@000000?ooo`3oool000002@3oool20000
01T0oooo003o0?ooon<0oooo0`0000030?ooo`030000003oool0000001P0oooo1P00000K0?ooo`80
000000<0oooo0000003oool01`3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
01P0oooo003o0?ooon00oooo0`0000050?ooo`T000005P3oool6000001/0oooo0P0000080?ooo`80
00002P3oool3000001P0oooo003o0?ooomd0oooo0`0000070?ooo``000005`3oool6000001H0oooo
1000000_0?ooo`00o`3ooooJ0?ooo`<000000P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00D0oooo1P00000G0?ooo`H000004`3oool200000080oooo00<000000?ooo`3oool0;03o
ool00?l0ooooe`3oool3000000D0oooo00<000000?ooo`3oool0403oool6000001P0oooo1P00000B
0?ooo`@00000;@3oool00?l0ooooe03oool3000000P0oooo00<000000?ooo`3oool04P3oool60000
01T0oooo1P00000B0?ooo`030000003oool0oooo02/0oooo003o0?ooom40oooo0`00000P0?ooo`80
000000<0oooo0000000000000`00000J0?ooo`@000003`3oool2000000030?ooo`000000oooo02/0
oooo003o0?ooolh0oooo0`00000S0?ooo`8000000`3oool4000001D0oooo2000000o0?ooo`00o`3o
ooo:0?ooo`@000006@3oool00`000000oooo0?ooo`0:0?ooo`8000001@3oool400000100oooo1`00
00130?ooo`00o`3oooo70?ooo`<000007@3oool00`000000oooo0?ooo`0:0?ooo`8000001P3oool5
000000X0oooo1`0000170?ooo`00o`3oooo40?ooo`<000007`3oool2000000`0oooo0P0000080?oo
o`D00000203oool4000004X0oooo003o0?oool40oooo0`00000R0?ooo`030000003oool0oooo00/0
oooo0P00000:0?ooo`D00000E03oool00?l0oooo_P3oool3000002@0oooo0P00000=0?ooo`800000
303oool4000005<0oooo003o0?oook/0oooo0`00000K0?ooo`@00000203oool00`000000oooo0?oo
o`0<0?ooo`8000003P3oool00`000000oooo0?ooo`1B0?ooo`00o`3ooonh0?ooo`<000007P3oool8
000000<0oooo0P00000>0?ooo`800000H`3oool00?l0oooo]@3oool3000002D0oooo2000000?0?oo
o`800000H`3oool00?l0oooo/P3oool3000001L0oooo00<000000?ooo`3oool04P3oool7000000`0
oooo0P00001S0?ooo`00o`3ooon_0?ooo`<000006@3oool3000001D0oooo2@0000080?ooo`800000
H`3oool00?l0ooooZ`3oool4000000030?ooo`000000oooo01X0oooo1000000C0?ooo`030000003o
ool0oooo0080oooo200000040?ooo`800000H`3oool00?l0ooooZ03oool3000000D0oooo00<00000
0?ooo`3oool06@3oool500000140oooo0P0000080?ooo`@00000J@3oool00?l0ooooY@3oool30000
01X0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`0000000000008000003`3oool00`00
0000oooo0?ooo`1d0?ooo`00o`3ooonR0?ooo`<00000703oool4000000L0oooo0`0000000`3oool0
000000000002000000d0oooo0P00001f0?ooo`00o`3ooonO0?ooo`<00000803oool4000000L0oooo
0P0000030?ooo`@000002`3oool00`000000oooo0?ooo`1e0?ooo`00n`3oool2000000030?ooo`00
0000000009/0oooo0`00000S0?ooo`H000001@3oool2000000@0oooo100000090?ooo`800000M`3o
ool00?`0oooo00<000000?ooo`000000V@3oool3000002H0oooo0P0000000`3oool0000000000002
000000@0oooo0P0000060?ooo`@000001`3oool00`000000oooo0?ooo`1f0?ooo`00o@3oool00`00
0000oooo0?ooo`2E0?ooo`<00000:@3oool300000080oooo100000020?ooo`<000001P3oool40000
00H0oooo00<000000?ooo`3oool0MP3oool00?/0oooo0P0000000`3oool000000000002B0?ooo`<0
00006@3oool00`000000oooo0?ooo`0A0?ooo`8000000`3oool5000000030?ooo`000000000000P0
oooo0`00001n0?ooo`00o`3ooon@0?ooo`<000006`3oool400000140oooo0P0000050?ooo`H00000
2@3oool00`000000oooo0?ooo`1m0?ooo`00o`3ooon<0?ooo`@000007P3oool6000000l0oooo0P00
00070?ooo`@00000R@3oool00?l0ooooR@3oool300000280oooo0P0000000`3oool0000000000003
000000d0oooo0`0000070?ooo`@00000R03oool00?l0ooooQP3oool3000002D0oooo0P0000030?oo
o`@000003@3oool2000000T0oooo00<000000?ooo`3oool0Q`3oool00?l0ooooP`3oool3000001X0
oooo00<000000?ooo`3oool02`3oool2000000D0oooo1000000;0?ooo`800000T`3oool00?l0oooo
P03oool4000001P0oooo00<000000?ooo`3oool00`00000<0?ooo`8000001P3oool5000000T0oooo
0P00002C0?ooo`00o`3ooomm0?ooo`<000000`3oool00`000000oooo0?ooo`0C0?ooo`X000002`3o
ool2000000P0oooo1@0000070?ooo`<00000TP3oool00?l0ooooNP3oool3000000H0oooo00<00000
0?ooo`3oool0403oool=000000/0oooo0P00000:0?ooo`D000001P3oool00`000000oooo0?ooo`2A
0?ooo`00o`3ooomg0?ooo`<000006P3oool6000000D0oooo1@00000:0?ooo`800000303oool40000
09T0oooo003o0?ooog@0oooo0`00000L0?ooo`@000002`3oool3000000T0oooo0P00000>0?ooo`03
0000003oool0oooo09P0oooo003o0?ooog40oooo0`00000H0?ooo`030000003oool0oooo00@0oooo
0P00000>0?ooo`<00000203oool200000:T0oooo003o0?ooofd0oooo1000000H0?ooo`D000001@3o
ool2000000l0oooo0`0000070?ooo`800000Z@3oool00?l0ooooJP3oool3000001X0oooo1P000006
0?ooo`<000003`3oool2000000L0oooo0P00002Y0?ooo`00o`3ooomW0?ooo`<00000703oool40000
00T0oooo1000000?0?ooo`8000001P3oool200000:T0oooo003o0?ooof@0oooo0`00000P0?ooo`80
0000303oool3000000h0oooo0`00002`0?ooo`00o`3ooomQ0?ooo`<000008`3oool2000000d0oooo
0P00000?0?ooo`800000/03oool00?l0ooooGP3oool3000002H0oooo0`00000=0?ooo`8000003`3o
ool00`000000oooo0?ooo`2^0?ooo`00o`3ooomK0?ooo`<000005`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00/0oooo0`00000<0?ooo`<00000_`3oool00?l0ooooF03oool30000
01L0oooo2`00000<0?ooo`8000003@3oool300000;h0oooo003o0?oooeD0oooo0`00000H0?ooo`h0
0000303oool2000000d0oooo0P00002n0?ooo`00o`3ooomB0?ooo`<0000000<0oooo0000003oool0
5`3oool4000000P0oooo0`00000<0?ooo`<000003@3oool00`000000oooo0?ooo`2l0?ooo`00o`3o
oom?0?ooo`<00000103oool00`000000oooo0?ooo`0E0?ooo`<000002`3oool3000000`0oooo0`00
003;0?ooo`00o`3ooom;0?ooo`@000007`3oool2000000/0oooo0`00000>0?ooo`P00000a@3oool0
0?l0ooooB03oool3000000D0oooo00<000000?ooo`3oool06`3oool2000000T0oooo1000000=0?oo
o`X00000a@3oool00?l0ooooA@3oool3000000L0oooo0`00000L0?ooo`8000001`3oool5000000d0
oooo1`0000390?ooo`00o`3ooom20?ooo`<000002`3oool3000000X0oooo00<000000?ooo`3oool0
5@3oool5000000H0oooo0P0000070?ooo`030000003oool0oooo00<0oooo0P0000380?ooo`00o`3o
oolo0?ooo`<000003`3oool3000000P0oooo0`00000D0?ooo`D000001`3oool4000000`0oooo0`00
00370?ooo`00o`3oooll0?ooo`<000004`3oool2000000T0oooo0`00000B0?ooo`@00000203oool4
000000h0oooo0`0000360?ooo`00o`3oooli0?ooo`<000005`3oool2000000T0oooo0P00000B0?oo
o`8000001P3oool600000140oooo0P0000360?ooo`00o`3ooolf0?ooo`<000005`3oool00`000000
oooo0?ooo`03000000T0oooo0P00000A0?ooo`d000004`3oool00`000000oooo0?ooo`340?ooo`00
o`3ooolc0?ooo`<000005P3oool;000000P0oooo0`00000@0?ooo`P00000g`3oool00?l0oooo<03o
ool3000001P0oooo3@0000080?ooo`<000004P3oool200000>80oooo003m0?ooo`800000;03oool4
000001X0oooo0`0000090?ooo`<00000203oool3000000/0oooo00<000000?ooo`3oool0i`3oool0
0?`0oooo00@000000?ooo`3oool00000:03oool3000001d0oooo0`00000;0?ooo`<00000203oool4
000000D0oooo1@00003Y0?ooo`00o03oool010000000oooo0?ooo`00000U0?ooo`<0000000<0oooo
0000003oool07@3oool2000000d0oooo0`0000080?ooo``00000jP3oool00?`0oooo00@000000?oo
o`3oool000008P3oool3000000@0oooo0P00000L0?ooo`<000003P3oool2000000P0oooo2@00003]
0?ooo`00o03oool010000000oooo0?ooo`00000O0?ooo`<000001`3oool3000001`0oooo0P00000?
0?ooo`800000203oool200000?<0oooo003m0?ooo`8000007@3oool3000000/0oooo0`0000090?oo
o`030000003oool0000000l0oooo0P00000?0?ooo`<00000203oool00`000000oooo0?ooo`3a0?oo
o`00o`3ooolJ0?ooo`<000003`3oool3000000D0oooo2`00000:0?ooo`<000003P3oool400000?/0
oooo003o0?oooaL0oooo0`00000C0?ooo`800000103oool?000000P0oooo0`00000;0?ooo`H00000
n`3oool00?l0oooo503oool3000001L0oooo0P0000020?ooo`<000002@3oool5000000P0oooo1000
00050?ooo`L000000P3oool00`000000oooo0?ooo`3i0?ooo`00o`3ooolA0?ooo`<000006P3oool6
000000d0oooo0P0000090?ooo`d00000o`3oool10?ooo`00o`3oool=0?ooo`@000007P3oool40000
00l0oooo00<000000?ooo`3oool02@3oool700000?l0oooo1@3oool00?l0oooo2P3oool3000002<0
oooo0`00000?0?ooo`8000003@3oool00`000000oooo0?ooo`3o0?ooo`H0oooo003o0?ooo`L0oooo
0`00000H0?ooo`030000003oool0000000`0oooo0`00000?0?ooo`030000003oool0oooo0?l0oooo
503oool00?l0oooo103oool3000001L0oooo300000080?ooo`<000003@3oool200000?l0oooo5P3o
ool00?l0oooo0@3oool3000001T0oooo400000060?ooo`<000002`3oool300000?l0oooo5P3oool0
0?d0oooo0`00000L0?ooo`8000002P3oool5000000H0oooo0P00000:0?ooo`<00000o`3ooolG0?oo
o`00nP3oool3000000030?ooo`000000oooo01/0oooo0`00000=0?ooo`8000001`3oool2000000D0
oooo1P00003o0?oooaP0oooo003g0?ooo`<00000103oool00`000000oooo0?ooo`0I0?ooo`<00000
3`3oool00`000000oooo0?ooo`050?ooo``00000o`3ooolI0?ooo`00m03oool3000000L0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`<00000403oool2000000H0oooo2000
003o0?oooad0oooo003a0?ooo`<000002P3oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool2
00000100oooo0`0000070?ooo`800000o`3ooolQ0?ooo`00k@3oool4000001h0oooo0`0000090?oo
o`030000003oool0oooo00d0oooo0`0000090?ooo`030000003oool0oooo0?l0oooo7`3oool00>X0
oooo0`00000S0?ooo`<00000203oool2000000d0oooo0`00003o0?ooob`0oooo003W0?ooo`<00000
603oool00`000000oooo0?ooo`0<0?ooo`800000203oool6000000T0oooo0P00003o0?ooobd0oooo
003T0?ooo`<000006P3oool3000000h0oooo0P0000080?ooo`P000000P3oool500000?l0oooo;P3o
ool00>40oooo0`00000N0?ooo`<000003@3oool3000000/0oooo2`00003o0?ooobh0oooo003N0?oo
o`<00000603oool00`000000oooo0?ooo`070?ooo`<000003@3oool3000000`0oooo1@00003o0?oo
oc80oooo003K0?ooo`<000006P3oool3000000T0oooo0`00000=0?ooo`800000o`3ooom30?ooo`00
f03oool3000001h0oooo0`0000090?ooo`8000003P3oool200000?l0oooo@P3oool00=D0oooo0`00
000R0?ooo`<000002@3oool2000000d0oooo0`00003o0?oood40oooo003B0?ooo`<000005`3oool0
0`000000oooo0?ooo`0<0?ooo`8000002@3oool3000000/0oooo0`00003o0?oood80oooo003>0?oo
o`@0000000<0oooo0000003oool05P3oool3000000h0oooo0P0000090?ooo`P000000P3oool50000
0?l0oooo@`3oool00</0oooo0`0000050?ooo`030000003oool0oooo01H0oooo0`00000=0?ooo`<0
00002@3oool=00000?l0ooooA03oool00<P0oooo0`00000R0?ooo`<000003@3oool3000000T0oooo
0`0000000`3oool000000000000300000?l0ooooA`3oool00<D0oooo0`00000G0?ooo`030000003o
ool0oooo00`0oooo0P00000>0?ooo`8000002P3oool300000?l0ooooC03oool00<80oooo0`00000I
0?ooo`<000003P3oool2000000h0oooo0P00000:0?ooo`030000003oool0oooo0?l0ooooB`3oool0
0;l0oooo0`00000M0?ooo`<000003@3oool3000000d0oooo0`00003o0?oooeL0oooo002l0?ooo`<0
00005`3oool00`000000oooo0?ooo`070?ooo`<000003@3oool3000000/0oooo0`00003o0?oooeP0
oooo002i0?ooo`<000006@3oool3000000T0oooo0`00000=0?ooo`L000000`3oool500000?l0oooo
F@3oool00;H0oooo0`00000M0?ooo`<000002@3oool2000000h0oooo3@00003o0?oooeX0oooo002c
0?ooo`<00000603oool00`000000oooo0?ooo`060?ooo`<000002@3oool2000000h0oooo00@00000
0?ooo`3oool0oooo1@00003o0?oooed0oooo002`0?ooo`<000006P3oool3000000P0oooo0`000008
0?ooo`<00000303oool200000?l0ooooI@3oool00:`0oooo1000000M0?ooo`8000002P3oool30000
00P0oooo200000020?ooo`D00000o`3ooomV0?ooo`00Z@3oool3000000P0oooo00<000000?ooo`3o
ool05P3oool2000000/0oooo0`0000080?ooo`h00000o`3ooomV0?ooo`00YP3oool3000000030?oo
o`000000oooo0080oooo2P0000090?ooo`030000003oool0oooo00P0oooo0`00000<0?ooo`<00000
203oool3000000030?ooo`000000000000<00000o`3ooomZ0?ooo`00X`3oool3000000@0oooo00@0
00000?ooo`3oool0oooo2`0000070?ooo`<000002@3oool2000000h0oooo0`0000080?ooo`<00000
o`3ooom_0?ooo`00X03oool3000000L0oooo00<000000?ooo`3oool02P3oool3000000L0oooo1000
00060?ooo`<000003`3oool3000000P0oooo00<000000?ooo`3oool0o`3ooom^0?ooo`00W@3oool3
000001P0oooo0`0000070?ooo`/000004@3oool300000?l0ooooN03oool009X0oooo0`00000L0?oo
o`<000001`3oool=000000l0oooo0`00003o0?ooogL0oooo002G0?ooo`<00000803oool3000000L0
oooo0`0000030?ooo``000002P3oool300000?l0ooooMP3oool009@0oooo0`00000G0?ooo`030000
003oool0oooo00X0oooo0`0000070?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`L00000
2P3oool300000?l0ooooM@3oool00940oooo0`00000I0?ooo`<00000303oool3000000L0oooo0`00
000=0?ooo`030000003oool0oooo00T0oooo0`00003o0?ooog@0oooo002=0?ooo`@000007@3oool3
000000`0oooo0`0000070?ooo`<000006@3oool300000?l0ooooL`3oool008X0oooo0`00000H0?oo
o`030000003oool0oooo00L0oooo0`00000<0?ooo`<000001`3oool3000001T0oooo00<000000?oo
o`3oool0o`3ooomb0?ooo`00Q`3oool3000001X0oooo0`0000090?ooo`<00000303oool3000000L0
oooo0`00003o0?ooohd0oooo00240?ooo`<000007P3oool3000000T0oooo0`00000<0?ooo`<00000
1`3oool300000?l0ooooS03oool00840oooo0`0000030?ooo`030000003oool0000001`0oooo0`00
00090?ooo`<00000303oool3000000L0oooo0`00003o0?oooh/0oooo001n0?ooo`@000000`3oool7
000000d0oooo00<000000?ooo`3oool02`3oool4000000P0oooo0`00000<0?ooo`<000001`3oool3
00000?l0ooooRP3oool007/0oooo0`0000030?ooo`030000003oool0000000/000002@3oool30000
00d0oooo100000080?ooo`<00000303oool00`000000oooo0?ooo`070?ooo`<00000o`3ooon90?oo
o`00N03oool3000000H0oooo1@0000050?ooo`D000002@3oool3000000h0oooo0`0000080?ooo`<0
00005P3oool300000?l0ooooR03oool007D0oooo0`0000090?ooo`<000002P3oool3000000T0oooo
0`00000>0?ooo`<00000203oool3000000h0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`3o0?ooohL0oooo001b0?ooo`<000003@3oool00`000000oooo0?ooo`060?ooo`040000003o
ool000000?ooo`<000002@3oool3000000h0oooo0P0000090?ooo`030000003oool0oooo00`0oooo
0`00003o0?oooi00oooo001^0?ooo`@000005P3oool;000000T0oooo0`00000=0?ooo`8000005`3o
ool400000?l0ooooT03oool006/0oooo0`00000I0?ooo`d000002@3oool3000000/0oooo1000000<
0?ooo`030000003oool0oooo00L0oooo1000003o0?oooi00oooo001X0?ooo`<000006`3oool30000
00T0oooo0`0000090?ooo`L000000`3oool6000000`0oooo1000003o0?oooi/0oooo001U0?ooo`<0
00007@3oool3000000/0oooo0`0000090?ooo`d000003P3oool500000?l0ooooVP3oool00680oooo
0`00000P0?ooo`8000003@3oool3000000T0oooo0`0000000`3oool000000000000300000140oooo
1@00003o0?oooiX0oooo000a0?ooo`D000000P3oool2000002D0oooo0`00000F0?ooo`030000003o
ool0oooo00X0oooo0P00000>0?ooo`<000002@3oool3000001P0oooo0P00003o0?oooi/0oooo000c
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0O0?ooo`<00000603o
ool3000000/0oooo0P00000?0?ooo`<000002@3oool300000?l0oooo]03oool003<0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01`0oooo0`00000L0?ooo`<000002P3o
ool4000000d0oooo100000090?ooo`<00000o`3ooonc0?ooo`00:`3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01T0oooo1000000O0?ooo`<000002@3o
ool5000000/0oooo1P0000090?ooo`<00000o`3ooonb0?ooo`00<`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool05P3oool3000000<0oooo00<000000?ooo`3oool07P3o
ool3000000/0oooo100000050?ooo`H000000P3oool00`000000oooo0?ooo`090?ooo`<00000o`3o
oona0?ooo`00<P3oool2000000@0oooo0P00000E0?ooo`@000001P3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00h0oooo0`00000;0?ooo`d00000403oool300000?l0oooo/03oool0
04`0oooo0`00000H0?ooo`/000002P3oool4000000X0oooo2000000E0?ooo`030000003oool0oooo
0?l0oooo[`3oool004T0oooo0`00000I0?ooo`d000002`3oool400000?l0oooof03oool004H0oooo
0`00000K0?ooo`@000005`3oool300000?l0ooooe`3oool004<0oooo0`00000N0?ooo`8000003P3o
ool00`000000oooo0?ooo`090?ooo`L00000o`3ooooB0?ooo`00@03oool3000001L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0:0?ooo`D000002@3oool800000?l0oooodP3oool0
03d0oooo0`00000E0?ooo`040000003oool000000?ooo`<00000203oool2000000P0oooo2@000008
0?ooo`H00000o`3ooooD0?ooo`00>P3oool3000001D0oooo2`0000070?ooo`<00000103oool60000
00@0oooo0`00000;0?ooo`<000001P3oool00`000000oooo0?ooo`3o0?ooolX0oooo000g0?ooo`<0
00005`3oool=000000L0oooo2@0000060?ooo`<000003@3oool400000080oooo1000003o0?oool/0
oooo000d0?ooo`<000006P3oool2000000T0oooo0`0000070?ooo`D000002@3oool2000000l0oooo
2000003o0?oool`0oooo000a0?ooo`<000007@3oool00`000000oooo0?ooo`090?ooo`<000001`3o
ool700000080oooo1@00000A0?ooo`D00000o`3oooo>0?ooo`00;@3oool5000001h0oooo0P00000<
0?ooo`<000002@3oool;00000?l0ooooi03oool002X0oooo0`0000040?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0303oool3000000X0oooo1@00003o0?ooonP0oooo000W0?ooo`<0
00001`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00/0oooo0P00000>0?ooo`<0
0000o`3oooof0?ooo`00903oool3000000X0oooo00<000000?ooo`3oool02`3oool:000000L0oooo
0`00000=0?ooo`@00000o`3ooooe0?ooo`008@3oool3000001T0oooo300000080?ooo`<000002`3o
ool600000?l0oooom03oool001h0oooo0`00000K0?ooo`@000004P3oool4000000H0oooo1@000002
0?ooo`<00000o`3ooooc0?ooo`006`3oool3000001h0oooo0P00000E0?ooo`d00000103oool30000
0?l0oooolP3oool001P0oooo0`00000Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool8000000P0oooo0`00003o0?oooo40oooo000E0?ooo`<00000903oool200000100oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0:0?ooo`<00000o`3oooo`0?ooo`004P3o
ool3000001L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`<000003P3o
ool2000001P0oooo0`00003o0?ooonl0oooo000>0?ooo`@000005`3oool<000000P0oooo0`00000<
0?ooo`<000006@3oool00`000000oooo0?ooo`3o0?ooonh0oooo000;0?ooo`<000005`3oool00`00
0000oooo0?ooo`0?000000L0oooo1@0000080?ooo`<00000o`3ooooo0?ooo``0oooo00080?ooo`@0
0000603oool6000000X0oooo100000070?ooo`L000000P3oool500000?l0ooooo`3oool=0?ooo`00
1@3oool300000080oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`050?ooo`@00000
3@3oool3000000T0oooo2P00003o0?ooool0oooo3P3oool00080oooo0`0000050?ooo`030000003o
ool0oooo00l0oooo0`0000070?ooo`<000003P3oool2000000/0oooo1@00003o0?ooool0oooo4@3o
ool0008000005`3oool010000000oooo0?ooo`3oool3000000L0oooo1000000<0?ooo`800000o`3o
oooo0?ooob40oooo000F0?ooo`/000001`3oool4000000/0oooo0P00003o0?ooool0oooo8@3oool0
01D0oooo3@0000080?ooo`<000002@3oool400000?l0ooooo`3ooolP0?ooo`00503oool3000000T0
oooo100000070?ooo`<000001@3oool600000?l0ooooo`3ooolQ0?ooo`00503oool2000000/0oooo
100000070?ooo`/00000o`3ooooo0?ooob<0oooo000D0?ooo`030000003oool0oooo00`0oooo0`00
00070?ooo`L00000o`3ooooo0?ooobH0oooo000D0?ooo`8000003P3oool3000000L0oooo1000003o
0?ooool0oooo:03oool001@0oooo0`00000=0?ooo`@000001`3oool400000?l0ooooo`3ooolW0?oo
o`005@3oool4000000/0oooo00<000000?ooo`0000000P0000080?ooo`<00000o`3ooooo0?ooobH0
oooo000F0?ooo`D00000203oool200000080oooo00<000000?ooo`3oool0203oool300000?l0oooo
o`3ooolU0?ooo`00603oool600000080oooo1@00000>0?ooo`<00000o`3ooooo0?ooob@0oooo000J
0?ooo`X00000403oool00`000000oooo0?ooo`3o0?ooool0oooo8`3oool001`0oooo1@00003o0?oo
ool0oooo>@3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {211.563, 0}} -> {0.0474472, 0.299637, \
0.00171377, 0.00171377}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .3531 
%%ImageSize: 600 211.859 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0504718 1.05047 -0.337689 1.05047 [
[.03103 .29164 -8.22789 -9 ]
[.03103 .29164 9.77211 0 ]
[.2399 .22391 -5.72394 -9 ]
[.2399 .22391 6.27606 0 ]
[.45991 .15259 -2.99114 -9 ]
[.45991 .15259 3.00886 0 ]
[.69196 .07738 -3.13142 -9 ]
[.69196 .07738 2.86858 0 ]
[.93707 -0.00203 -6.56857 -9 ]
[.93707 -0.00203 5.43143 0 ]
[.45912 .08726 -4.98425 -12.75 ]
[.45912 .08726 5.01575 0 ]
[.98986 .00309 0 -5.95045 ]
[.98986 .00309 24 3.04955 ]
[1.00019 .01816 0 -5.94128 ]
[1.00019 .01816 6 3.05872 ]
[1.01042 .03307 0 -5.93222 ]
[1.01042 .03307 18 3.06778 ]
[1.0609 -0.00453 0 -8.41909 ]
[1.0609 -0.00453 10 4.33091 ]
[ 0 0 0 0 ]
[ 1 .3531 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00074 .31415 m
.97247 0 L
s
.02991 .30472 m
.02935 .31126 L
s
[(-10)] .03103 .29164 -0.08579 1 Mshowa
.2393 .23703 m
.239 .24359 L
s
[(-5)] .2399 .22391 -0.04601 1 Mshowa
.45987 .16572 m
.45985 .17229 L
s
[(0)] .45991 .15259 -0.00295 1 Mshowa
.69253 .0905 m
.69282 .09706 L
s
[(5)] .69196 .07738 .04381 1 Mshowa
.93831 .01104 m
.93893 .01758 L
s
[(10)] .93707 -0.00203 .09476 1 Mshowa
.125 Mabswid
.07093 .29146 m
.07063 .29538 L
s
.11238 .27806 m
.1121 .28199 L
s
.15425 .26452 m
.15401 .26845 L
s
.19656 .25085 m
.19634 .25478 L
s
.28249 .22306 m
.28234 .227 L
s
.32614 .20895 m
.32602 .21289 L
s
.37024 .19469 m
.37016 .19863 L
s
.41482 .18028 m
.41477 .18422 L
s
.5054 .151 m
.50542 .15494 L
s
.55143 .13612 m
.55149 .14006 L
s
.59795 .12108 m
.59805 .12502 L
s
.64498 .10587 m
.64512 .10981 L
s
.7406 .07496 m
.74081 .07889 L
s
.78921 .05925 m
.78946 .06318 L
s
.83836 .04336 m
.83865 .04729 L
s
.88805 .02729 m
.88839 .03122 L
s
gsave
.45912 .08726 -65.9843 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97247 0 m
.9991 .0388 L
s
.97736 .00712 m
.97111 .00913 L
s
[(-0.5)] .98986 .00309 -1 .32232 Mshowa
.98768 .02216 m
.98143 .02417 L
s
[(0)] 1.00019 .01816 -1 .32028 Mshowa
.9979 .03706 m
.99165 .03905 L
s
[(0.5)] 1.01042 .03307 -1 .31827 Mshowa
.125 Mabswid
.97943 .01014 m
.97568 .01135 L
s
.9815 .01316 m
.97775 .01436 L
s
.98357 .01617 m
.97982 .01737 L
s
.98563 .01917 m
.98188 .02037 L
s
.98974 .02516 m
.98598 .02636 L
s
.99178 .02814 m
.98803 .02934 L
s
.99383 .03112 m
.99008 .03232 L
s
.99587 .03409 m
.99211 .03529 L
s
.97528 .00409 m
.97153 .0053 L
s
.9732 .00106 m
.96945 .00227 L
s
gsave
1.0609 -0.00453 -61 -12.4191 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .3531 L
0 .3531 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.05311 .33116 m
.04716 .3302 L
s
.05788 .33108 m
.05311 .33116 L
s
.05788 .33108 m
.06146 .32994 L
s
.04716 .3302 m
.04298 .32866 L
s
.06146 .32994 m
.06206 .32831 L
s
.04298 .32866 m
.0376 .32607 L
s
.06206 .32831 m
.06147 .32563 L
s
.0376 .32607 m
.034 .32289 L
s
.06865 .32333 m
.074 .32593 L
s
.06147 .32563 m
.05552 .31599 L
s
.10446 .32483 m
.09851 .32386 L
s
.10924 .32474 m
.10446 .32483 L
s
.10924 .32474 m
.11285 .3236 L
s
.09851 .32386 m
.09019 .32077 L
s
.11285 .3236 m
.11412 .32033 L
s
.0603 .32024 m
.06865 .32333 L
s
.034 .32289 m
.03338 .3202 L
s
.09019 .32077 m
.08484 .31816 L
s
.11412 .32033 m
.11061 .31714 L
s
.05312 .3182 m
.0603 .32024 L
s
.03338 .3202 m
.03576 .31798 L
s
.04414 .31674 m
.05312 .3182 L
s
.08484 .31816 m
.0783 .31448 L
s
.03576 .31798 m
.03934 .31683 L
s
.11061 .31714 m
.10645 .31559 L
s
.09324 .31692 m
.09568 .3147 L
s
.09866 .31519 m
.09324 .31692 L
s
.03934 .31683 m
.04414 .31674 L
s
.05552 .31599 m
.05492 .31328 L
s
.10645 .31559 m
.10346 .3151 L
s
.10346 .3151 m
.09866 .31519 L
s
.09568 .3147 m
.09693 .31141 L
s
.0783 .31448 m
.06934 .30864 L
s
.05492 .31328 m
.05552 .31163 L
s
.07415 .30855 m
.07592 .31234 L
s
.05552 .31163 m
.05732 .31105 L
s
.09693 .31141 m
.09638 .30869 L
s
.11796 .31047 m
.12277 .31038 L
s
.11198 .30949 m
.11796 .31047 L
s
.12277 .31038 m
.12458 .3098 L
s
.12458 .3098 m
.12705 .30757 L
s
.09638 .30869 m
.09282 .30547 L
s
.06934 .30864 m
.05795 .30063 L
s
.07477 .3069 m
.07415 .30855 L
s
.12705 .30757 m
.1277 .30592 L
s
.07719 .30467 m
.07477 .3069 L
s
.1277 .30592 m
.126 .30211 L
s
.09282 .30547 m
.08864 .3039 L
s
.08082 .3035 m
.07719 .30467 L
s
.17287 .30453 m
.17654 .30337 L
s
.16988 .30404 m
.17287 .30453 L
s
.16757 .30189 m
.16988 .30404 L
s
.08864 .3039 m
.08563 .30341 L
s
.08563 .30341 m
.08082 .3035 L
s
.14463 .30341 m
.1393 .30076 L
s
.17654 .30337 m
.17905 .30112 L
s
.126 .30211 m
.1213 .2978 L
s
.16709 .29915 m
.16757 .30189 L
s
.17905 .30112 m
.18042 .2978 L
s
.1393 .30076 m
.13513 .29919 L
s
.13513 .29919 m
.11357 .29297 L
s
.16844 .29582 m
.16709 .29915 L
s
.1213 .2978 m
.11357 .29297 L
s
.15811 .29766 m
.15211 .29667 L
s
.16294 .29757 m
.15811 .29766 L
s
.16844 .29582 m
.16294 .29757 L
s
.15211 .29667 m
.14678 .29401 L
s
.1698 .29248 m
.16844 .29582 L
s
.14678 .29401 m
.14326 .29076 L
s
.11357 .29297 m
.10517 .28981 L
s
.16816 .28863 m
.1698 .29248 L
s
.14326 .29076 m
.14158 .28691 L
s
.10517 .28981 m
.09978 .28713 L
s
.16467 .28536 m
.16816 .28863 L
s
.1894 .28768 m
.18709 .2855 L
s
.19425 .28759 m
.1894 .28768 L
s
.1998 .28582 m
.19425 .28759 L
s
.14158 .28691 m
.14224 .28523 L
s
.20235 .28354 m
.1998 .28582 L
s
.18709 .2855 m
.18662 .28272 L
s
.15932 .28268 m
.16467 .28536 L
s
.14224 .28523 m
.14475 .28295 L
s
.23079 .28468 m
.22779 .28418 L
s
.23564 .28459 m
.23079 .28468 L
s
.22779 .28418 m
.22665 .28309 L
s
.20306 .28186 m
.20235 .28354 L
s
.22665 .28309 m
.22737 .2814 L
s
.14475 .28295 m
.14843 .28177 L
s
.18662 .28272 m
.19102 .27985 L
s
.15329 .28168 m
.15932 .28268 L
s
.14843 .28177 m
.15329 .28168 L
s
.22737 .2814 m
.23181 .27853 L
s
.18246 .28113 m
.17643 .28013 L
s
.19102 .27985 m
.18246 .28113 L
s
.17643 .28013 m
.1741 .27794 L
s
.23181 .27853 m
.23741 .27675 L
s
.1741 .27794 m
.17363 .27515 L
s
.22767 .27693 m
.21979 .27652 L
s
.23741 .27675 m
.22767 .27693 L
s
.21979 .27652 m
.21075 .27501 L
s
.17363 .27515 m
.17617 .27285 L
s
.21075 .27501 m
.20543 .2723 L
s
.17617 .27285 m
.18174 .27106 L
s
.20543 .2723 m
.20312 .2701 L
s
.18662 .27097 m
.19266 .27198 L
s
.18174 .27106 m
.18662 .27097 L
s
.24635 .27097 m
.25009 .26978 L
s
.24032 .26996 m
.24635 .27097 L
s
.20312 .2701 m
.20267 .26729 L
s
.23617 .26835 m
.24032 .26996 L
s
.25009 .26978 m
.25083 .26807 L
s
.25083 .26807 m
.24856 .26586 L
s
.20267 .26729 m
.20409 .26388 L
s
.25646 .26628 m
.26135 .26619 L
s
.25043 .26526 m
.25646 .26628 L
s
.26135 .26619 m
.26511 .26499 L
s
.24856 .26586 m
.24211 .26203 L
s
.24211 .26203 m
.25043 .26526 L
s
.26511 .26499 m
.26661 .26157 L
s
.20409 .26388 m
.20738 .25986 L
s
.30506 .26254 m
.30093 .26092 L
s
.30884 .26134 m
.30506 .26254 L
s
.24211 .26203 m
.23033 .25545 L
s
.26661 .26157 m
.26321 .25823 L
s
.31151 .25902 m
.30884 .26134 L
s
.30093 .26092 m
.29869 .2587 L
s
.20738 .25986 m
.20694 .25703 L
s
.28208 .25958 m
.28586 .25837 L
s
.27604 .25856 m
.28208 .25958 L
s
.31006 .25508 m
.31151 .25902 L
s
.29869 .2587 m
.29722 .25475 L
s
.27189 .25693 m
.27604 .25856 L
s
.28586 .25837 m
.28662 .25665 L
s
.19783 .25549 m
.19829 .25833 L
s
.26321 .25823 m
.25563 .25326 L
s
.20694 .25703 m
.20461 .2548 L
s
.28662 .25665 m
.28437 .25442 L
s
.20158 .25428 m
.19783 .25549 L
s
.3067 .25172 m
.31006 .25508 L
s
.20461 .2548 m
.20158 .25428 L
s
.29722 .25475 m
.29764 .25018 L
s
.28437 .25442 m
.27681 .24944 L
s
.25563 .25326 m
.23734 .24274 L
s
.29919 .24673 m
.3067 .25172 L
s
.29764 .25018 m
.29919 .24673 L
s
.27681 .24944 m
.27341 .24607 L
s
.29919 .24673 m
.30265 .24265 L
s
.2939 .24396 m
.29919 .24673 L
s
.27341 .24607 m
.27303 .24321 L
s
.32575 .24565 m
.31409 .23899 L
s
.28974 .24232 m
.2939 .24396 L
s
.27303 .24321 m
.27379 .24148 L
s
.28253 .24016 m
.28974 .24232 L
s
.27379 .24148 m
.27759 .24026 L
s
.27759 .24026 m
.28253 .24016 L
s
.31409 .23899 m
.30768 .23507 L
s
.34871 .23833 m
.3254 .22489 L
s
.38142 .23828 m
.38528 .23706 L
s
.38528 .23706 m
.38804 .2347 L
s
.30768 .23507 m
.30543 .23281 L
s
.38804 .2347 m
.38888 .23295 L
s
.35914 .23352 m
.347 .23144 L
s
.36409 .23342 m
.35914 .23352 L
s
.36602 .23281 m
.36409 .23342 L
s
.38888 .23295 m
.3835 .20621 L
s
.30543 .23281 m
.30621 .23106 L
s
.36684 .23106 m
.36602 .23281 L
s
.31613 .23087 m
.32029 .23252 L
s
.34012 .23215 m
.34285 .22978 L
s
.34204 .23153 m
.34012 .23215 L
s
.347 .23144 m
.34204 .23153 L
s
.30621 .23106 m
.31004 .22983 L
s
.31004 .22983 m
.31613 .23087 L
s
.34285 .22978 m
.34366 .22802 L
s
.34366 .22802 m
.34194 .22108 L
s
.38727 .22603 m
.36017 .21372 L
s
.34194 .22108 m
.34275 .21931 L
s
.34275 .21931 m
.34468 .21869 L
s
.34468 .21869 m
.34773 .21922 L
s
.41642 .21673 m
.3816 .1962 L
s
.41011 .21276 m
.40268 .20761 L
s
.43597 .2105 m
.42445 .20366 L
s
.40268 .20761 m
.39938 .20414 L
s
.44971 .20612 m
.45561 .20424 L
s
.45561 .20424 m
.44716 .1979 L
s
.39938 .20414 m
.40109 .20056 L
s
.42445 .20366 m
.41811 .19964 L
s
.41615 .20027 m
.42445 .20366 L
s
.40109 .20056 m
.40501 .1993 L
s
.41003 .1992 m
.41615 .20027 L
s
.41811 .19964 m
.41592 .19731 L
s
.40501 .1993 m
.41003 .1992 L
s
.50154 .19862 m
.49849 .19809 L
s
.50656 .19853 m
.50154 .19862 L
s
.49849 .19809 m
.49743 .19692 L
s
.47534 .19794 m
.47015 .19508 L
s
.44716 .1979 m
.43976 .19269 L
s
.41592 .19731 m
.41679 .19552 L
s
.42685 .19532 m
.431 .19702 L
s
.49743 .19692 m
.49835 .19513 L
s
.41679 .19552 m
.42072 .19425 L
s
.42072 .19425 m
.42685 .19532 L
s
.49835 .19513 m
.50325 .19206 L
s
.47015 .19508 m
.46602 .19338 L
s
.46602 .19338 m
.45882 .19113 L
s
.49119 .19289 m
.48707 .19118 L
s
.49623 .19279 m
.49119 .19289 L
s
.50325 .19206 m
.49623 .19279 L
s
.43976 .19269 m
.43452 .18982 L
s
.50325 .19206 m
.50922 .19016 L
s
.48707 .19118 m
.48493 .18884 L
s
.45882 .19113 m
.44964 .18953 L
s
.44153 .18909 m
.43452 .18982 L
s
.44964 .18953 m
.44153 .18909 L
s
.48493 .18884 m
.48677 .18522 L
s
.48677 .18522 m
.49167 .18213 L
s
.47758 .18361 m
.47344 .18189 L
s
.48263 .18351 m
.47758 .18361 L
s
.49167 .18213 m
.48263 .18351 L
s
.49167 .18213 m
.49566 .18086 L
s
.47344 .18189 m
.47128 .17953 L
s
.52201 .18154 m
.5159 .18046 L
s
.52707 .18145 m
.52201 .18154 L
s
.53108 .18017 m
.52707 .18145 L
s
.5159 .18046 m
.51071 .17756 L
s
.53403 .17771 m
.53108 .18017 L
s
.47128 .17953 m
.4731 .17589 L
s
.53499 .17589 m
.53403 .17771 L
s
.51071 .17756 m
.50751 .17401 L
s
.4731 .17589 m
.47892 .17095 L
s
.53383 .17169 m
.53499 .17589 L
s
.50751 .17401 m
.50632 .16981 L
s
.55213 .17194 m
.55922 .17119 L
s
.546 .17085 m
.55213 .17194 L
s
.53066 .16812 m
.53383 .17169 L
s
.55922 .17119 m
.58552 .16281 L
s
.47892 .17095 m
.47984 .16911 L
s
.56325 .16991 m
.54045 .15577 L
s
.50632 .16981 m
.50725 .16797 L
s
.47984 .16911 m
.47768 .16673 L
s
.4726 .16683 m
.4686 .16812 L
s
.52546 .16519 m
.53066 .16812 L
s
.50725 .16797 m
.5102 .16549 L
s
.47768 .16673 m
.4726 .16683 L
s
.57336 .16668 m
.56913 .15887 L
s
.5102 .16549 m
.51422 .1642 L
s
.51931 .1641 m
.52546 .16519 L
s
.51422 .1642 m
.51931 .1641 L
s
.56913 .15887 m
.56592 .15221 L
s
.60279 .15577 m
.59664 .15467 L
s
.6079 .15567 m
.60279 .15577 L
s
.61198 .15437 m
.6079 .15567 L
s
.59664 .15467 m
.5915 .15171 L
s
.61504 .15186 m
.61198 .15437 L
s
.56592 .15221 m
.5648 .14794 L
s
.61605 .15 m
.61504 .15186 L
s
.5915 .15171 m
.56763 .13617 L
s
.5915 .15171 m
.58838 .14809 L
s
.61501 .14573 m
.61605 .15 L
s
.58838 .14809 m
.58729 .14381 L
s
.61192 .14209 m
.61501 .14573 L
s
.63553 .14532 m
.63245 .14477 L
s
.64271 .14457 m
.63553 .14532 L
s
.63245 .14477 m
.62835 .143 L
s
.64889 .1426 m
.64271 .14457 L
s
.58729 .14381 m
.58829 .14194 L
s
.62835 .143 m
.6263 .14058 L
s
.65405 .13941 m
.64889 .1426 L
s
.60676 .13911 m
.61192 .14209 L
s
.58829 .14194 m
.59134 .13941 L
s
.6263 .14058 m
.6263 .13749 L
s
.59134 .13941 m
.59544 .1381 L
s
.6551 .13754 m
.65405 .13941 L
s
.60058 .13799 m
.60676 .13911 L
s
.59544 .1381 m
.60058 .13799 L
s
.6263 .13749 m
.62836 .13373 L
s
.62836 .13373 m
.63353 .12741 L
s
.6768 .13215 m
.67064 .13103 L
s
.68196 .13205 m
.6768 .13215 L
s
.70276 .12542 m
.68196 .13205 L
s
.67064 .13103 m
.66552 .12802 L
s
.68926 .12818 m
.68611 .13073 L
s
.69034 .12629 m
.68926 .12818 L
s
.66552 .12802 m
.66248 .12434 L
s
.63353 .12741 m
.63353 .12429 L
s
.6894 .12194 m
.69034 .12629 L
s
.66248 .12434 m
.6615 .11999 L
s
.63353 .12429 m
.63147 .12183 L
s
.62837 .12127 m
.62423 .1226 L
s
.68638 .11824 m
.6894 .12194 L
s
.63147 .12183 m
.62837 .12127 L
s
.7122 .12086 m
.71947 .12009 L
s
.70602 .11973 m
.7122 .12086 L
s
.71947 .12009 m
.74255 .11273 L
s
.6615 .11999 m
.66256 .11809 L
s
.68126 .1152 m
.68638 .11824 L
s
.66256 .11809 m
.6657 .11551 L
s
.72785 .11742 m
.70757 .10206 L
s
.6657 .11551 m
.66987 .11417 L
s
.67506 .11407 m
.68126 .1152 L
s
.66987 .11417 m
.67506 .11407 L
s
.75519 .1087 m
.75941 .10735 L
s
.749 .10756 m
.75519 .1087 L
s
.74492 .10574 m
.749 .10756 L
s
.75941 .10735 m
.76054 .10543 L
s
.76054 .10543 m
.75858 .10294 L
s
.75858 .10294 m
.74843 .09679 L
s
.77978 .09617 m
.78271 .09992 L
s
.74843 .09679 m
.74546 .09303 L
s
.77375 .09183 m
.77978 .09617 L
s
.74546 .09303 m
.74772 .08915 L
s
.76556 .08815 m
.77375 .09183 L
s
.79992 .0913 m
.79371 .09015 L
s
.80516 .0912 m
.79992 .0913 L
s
.79371 .09015 m
.78866 .08705 L
s
.74772 .08915 m
.75197 .08779 L
s
.75934 .087 m
.76556 .08815 L
s
.75197 .08779 m
.75934 .087 L
s
.82109 .08768 m
.81488 .08653 L
s
.82537 .08631 m
.82109 .08768 L
s
.78866 .08705 m
.78573 .08326 L
s
.81488 .08653 m
.80674 .08284 L
s
.82775 .08242 m
.82537 .08631 L
s
.78573 .08326 m
.78592 .08004 L
s
.80674 .08284 m
.7976 .07788 L
s
.82487 .07862 m
.82775 .08242 L
s
.84041 .08152 m
.84471 .08015 L
s
.84471 .08015 m
.84712 .07623 L
s
.78592 .08004 m
.78708 .07809 L
s
.81983 .07549 m
.82487 .07862 L
s
.78708 .07809 m
.79038 .07544 L
s
.7976 .07788 m
.78137 .0672 L
s
.84712 .07623 m
.84384 .05026 L
s
.81263 .07305 m
.81983 .07549 L
s
.79038 .07544 m
.79682 .07337 L
s
.79682 .07337 m
.80424 .07257 L
s
.80424 .07257 m
.81263 .07305 L
s
.87279 .07119 m
.86874 .06933 L
s
.86874 .06933 m
.86156 .06688 L
s
.91409 .06907 m
.87031 .0385 L
s
.88147 .06843 m
.88581 .06704 L
s
.87524 .06725 m
.88147 .06843 L
s
.87119 .06539 m
.87524 .06725 L
s
.88581 .06704 m
.88705 .06507 L
s
.86156 .06688 m
.82937 .05972 L
s
.88705 .06507 m
.88517 .0625 L
s
.88517 .0625 m
.87828 .05677 L
s
.82937 .05972 m
.82214 .05725 L
s
.82214 .05725 m
.81803 .05537 L
s
.87828 .05677 m
.87544 .0529 L
s
.91356 .05343 m
.91853 .05661 L
s
.90451 .04837 m
.91356 .05343 L
s
.87544 .0529 m
.87573 .04961 L
s
.84384 .05026 m
.84627 .04626 L
s
.93516 .04972 m
.92799 .04723 L
s
.94047 .04961 m
.93516 .04972 L
s
.87573 .04961 m
.87916 .04691 L
s
.89731 .04588 m
.90451 .04837 L
s
.92799 .04723 m
.92301 .04404 L
s
.87916 .04691 m
.88353 .0455 L
s
.84627 .04626 m
.85063 .04485 L
s
.89105 .04469 m
.89731 .04588 L
s
.88353 .0455 m
.89105 .04469 L
s
.92301 .04404 m
.92022 .04013 L
s
.96383 .04057 m
.96253 .04258 L
s
.96331 .03594 m
.96383 .04057 L
s
.92022 .04013 m
.91963 .03551 L
s
.94377 .03899 m
.93787 .03447 L
s
.96057 .03202 m
.96331 .03594 L
s
.91963 .03551 m
.9209 .03349 L
s
.93787 .03447 m
.93731 .02983 L
s
.93067 .03196 m
.93787 .03447 L
s
.9209 .03349 m
.92532 .03207 L
s
.92532 .03207 m
.93067 .03196 L
s
.9556 .02879 m
.96057 .03202 L
s
.93731 .02983 m
.9386 .0278 L
s
.94839 .02627 m
.9556 .02879 L
s
.9386 .0278 m
.94303 .02638 L
s
.94303 .02638 m
.94839 .02627 L
s
0 g
.25 Mabswid
.00074 .31415 m
.97247 0 L
s
.02991 .30472 m
.02935 .31126 L
s
[(-10)] .03103 .29164 -0.08579 1 Mshowa
.2393 .23703 m
.239 .24359 L
s
[(-5)] .2399 .22391 -0.04601 1 Mshowa
.45987 .16572 m
.45985 .17229 L
s
[(0)] .45991 .15259 -0.00295 1 Mshowa
.69253 .0905 m
.69282 .09706 L
s
[(5)] .69196 .07738 .04381 1 Mshowa
.93831 .01104 m
.93893 .01758 L
s
[(10)] .93707 -0.00203 .09476 1 Mshowa
.125 Mabswid
.07093 .29146 m
.07063 .29538 L
s
.11238 .27806 m
.1121 .28199 L
s
.15425 .26452 m
.15401 .26845 L
s
.19656 .25085 m
.19634 .25478 L
s
.28249 .22306 m
.28234 .227 L
s
.32614 .20895 m
.32602 .21289 L
s
.37024 .19469 m
.37016 .19863 L
s
.41482 .18028 m
.41477 .18422 L
s
.5054 .151 m
.50542 .15494 L
s
.55143 .13612 m
.55149 .14006 L
s
.59795 .12108 m
.59805 .12502 L
s
.64498 .10587 m
.64512 .10981 L
s
.7406 .07496 m
.74081 .07889 L
s
.78921 .05925 m
.78946 .06318 L
s
.83836 .04336 m
.83865 .04729 L
s
.88805 .02729 m
.88839 .03122 L
s
gsave
.45912 .08726 -65.9843 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 211.813},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000db000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?ooo`@0oooo
1@0000020?ooo`800000C@3oool00?l0ooooo`3oool60?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`110?ooo`8000001`3oool00?l0ooooo`3oool60?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00D0oooo
003o0?ooool0oooo1P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`040?ooo`00o`3ooooo0?ooo`H0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0480oooo00<000000?ooo`0000001@3oool00?l0ooooo`3o
ool50?ooo`800000103oool2000004@0oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3o
oom@0?ooo`<0000000<0oooo000000000000103oool00?l0ooooo`3oool_0?ooo`800000103oool2
000000@0oooo0P00000M0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool00000203oool0
10000000oooo0?ooo`00000L0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`0J0?ooo`00o`3ooooo0?oooa`0oooo0`0000090?ooo`@000000P3oool0
10000000oooo0?ooo`0000090?ooo`8000007@3oool00?l0ooooo`3ooolI0?ooo`H000003`3oool0
10000000oooo0?ooo`0000090?ooo`030000003oool0oooo01`0oooo003o0?ooool0oooo5P3oool3
000000@0oooo0`00000?0?ooo`8000002P3oool3000001`0oooo003o0?ooool0oooo4`3oool30000
00T0oooo0P00000i0?ooo`00o`3ooooo0?oooa00oooo0`00000;0?ooo`<00000>@3oool00?l0oooo
o`3oool<0?ooo`@000003@3oool01@000000oooo0?ooo`3oool0000003P0oooo003o0?ooool0oooo
2@3oool3000001<0oooo0`00000=0?ooo`800000:@3oool00?l0ooooo`3oool60?ooo`<0000000<0
oooo0000003oool05P3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo000002P0oooo
003o0?ooool0oooo0`3oool3000000D0oooo00<000000?ooo`3oool04P3oool2000000030?ooo`00
0000oooo00T0oooo00@000000?ooo`3oool00000:03oool00?l0ooooo`3oool3000000P0oooo00<0
00000?ooo`3oool04`3oool4000000T0oooo00@000000?ooo`3oool00000:03oool00?l0ooooo03o
ool3000002@0oooo0P0000080?ooo`040000003oool0oooo000002P0oooo003o0?ooooT0oooo0`00
000V0?ooo`<000002@3oool2000002T0oooo003o0?ooooH0oooo0`00000[0?ooo`800000<`3oool0
0?l0ooool`3oool3000001H0oooo00@000000?ooo`3oool000004@3oool3000000030?ooo`000000
oooo0380oooo003o0?oooo00oooo0`00000G0?ooo`P000004P3oool3000000`0oooo0P0000040?oo
o`800000103oool2000001P0oooo003o0?ooon`0oooo1000000I0?ooo`/000004`3oool00`000000
oooo0?ooo`080?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000005`3oool0
0?l0ooooj@3oool300000080oooo00<000000?ooo`3oool04@3oool010000000oooo0?ooo`000002
0?ooo`<000001P3oool6000000h0oooo0`00000:0?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`3oool05@3oool00?l0ooooiP3oool3000000D0oooo00<000000?ooo`3oool03`3oool:
000000T0oooo1@00000>0?ooo`<000002@3oool010000000oooo0?ooo`0000090?ooo`800000603o
ool00?l0ooooh`3oool3000001T0oooo2`00000<0?ooo`8000004@3oool00`000000oooo0?ooo`06
0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool05`3oool00?l0ooooh03oool3
000001/0oooo0`0000060?ooo`@000002`3oool3000000h0oooo0P0000000`3oool000000?ooo`07
0?ooo`8000002P3oool3000001L0oooo003o0?ooomd0oooo0`0000040?ooo`030000003oool0oooo
01L0oooo0P0000080?ooo`D000002P3oool200000140oooo0P00000]0?ooo`00o`3ooooJ0?ooo`<0
00001P3oool3000001P0oooo0P00000:0?ooo`@000002@3oool2000000h0oooo0`0000000`3oool0
00000?ooo`0/0?ooo`00o`3ooooG0?ooo`<000002P3oool4000001H0oooo0`00000;0?ooo`030000
003oool0oooo00P0oooo0`00000o0?ooo`00o`3ooooD0?ooo`<000000P3oool00`000000oooo0?oo
o`090?ooo`@000001@3oool2000000h0oooo1000000D0?ooo`<00000@03oool00?l0ooood@3oool3
00000080oooo1@00000<0?ooo``000003@3oool3000001@0oooo00<000000?ooo`3oool0?`3oool0
0?l0oooocP3oool3000000040?ooo`000000oooo0?ooo`D000003P3oool@000000T0oooo1000001D
0?ooo`00o`3oooo:0?ooo`@00000103oool00`000000oooo0?ooo`0200000100oooo1P0000060?oo
o`L00000203oool600000540oooo003o0?ooolL0oooo0`00000;0?ooo`8000003`3oool400000003
0?ooo`000000000000800000203oool4000000T0oooo2000001=0?ooo`00o`3oooo40?ooo`<00000
3P3oool2000000l0oooo0P0000040?ooo`@000002@3oool4000000X0oooo1@00001=0?ooo`00o`3o
ooo10?ooo`<000000`3oool00`000000oooo0?ooo`0;0?ooo`8000003`3oool2000000H0oooo1000
00080?ooo`@00000F`3oool00?l0oooo_P3oool3000000D0oooo1000000;0?ooo`8000003`3oool3
000000H0oooo100000090?ooo`<00000FP3oool00?l0oooo^`3oool3000000T0oooo1@0000090?oo
o`800000403oool3000000L0oooo100000080?ooo`<00000F@3oool00?l0oooo]`3oool4000000h0
oooo1@0000070?ooo`8000004@3oool4000000H0oooo100000080?ooo`030000003oool0oooo05P0
oooo003o0?oookD0oooo0`00000C0?ooo`L000000`3oool200000180oooo100000070?ooo`<00000
HP3oool00?l0oooo/P3oool300000080oooo00<000000?ooo`3oool04`3oool:000001@0oooo0`00
00070?ooo`@00000H03oool00?l0ooooO`3oool2000002h0oooo0`0000050?ooo`030000003oool0
oooo01P0oooo2@0000090?ooo`030000003oool0oooo00D0oooo0P0000080?ooo`@00000G`3oool0
0?l0ooooOP3oool010000000oooo0?ooo`00000Y0?ooo`@000000`3oool00`000000oooo0?ooo`0Q
0?ooo`X000000`3oool4000000D0oooo0`0000090?ooo`@00000G@3oool00?l0ooooP@3oool00`00
0000oooo0?ooo`0T0?ooo`<000001P3oool400000240oooo0P0000030?oooa<000002`3oool40000
05`0oooo003o0?ooogl0oooo0P00000T0?ooo`<000002P3oool400000200oooo0P0000070?ooo`h0
00003P3oool3000005/0oooo003o0?ooogl0oooo00<000000?ooo`3oool0803oool3000000l0oooo
0`0000040?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0403oool2000000/0oooo
100000030?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0FP3oool00?/0oooo0P00
00000`3oool000000000001n0?ooo`<000007@3oool3000001<0oooo5000000=0?ooo`8000003@3o
ool00`000000oooo0?ooo`1a0?ooo`00o03oool00`000000oooo0000002L0?ooo`<000005`3ooolD
000000`0oooo0P0000210?ooo`00o@3oool00`000000oooo0?ooo`2H0?ooo`@00000603oool70000
00`0oooo0`00000;0?ooo`<00000P03oool00?/0oooo0P0000000`3oool000000000002E0?ooo`<0
00000`3oool00`000000oooo0?ooo`0E0?ooo`<000000P3oool5000000/0oooo0`0000090?ooo`@0
0000P03oool00?l0ooooT`3oool3000001h0oooo0P0000050?ooo`@000002`3oool3000000H0oooo
100000220?ooo`00o`3ooon@0?ooo`<000008@3oool2000000L0oooo1000000:0?ooo`<00000103o
ool4000008<0oooo003o0?oooh`0oooo1000000T0?ooo`800000203oool5000000P0oooo0P000006
0?ooo`030000003oool0oooo08<0oooo003o0?ooohT0oooo0`00000F0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01`3oool3000000T0oooo1P0000020?ooo`D00000S03oool00?l0
ooooQP3oool3000001L0oooo300000090?ooo`<000002P3oool:000008d0oooo003o0?oooh<0oooo
0`00000I0?ooo`l00000203oool4000000X0oooo1@00002@0?ooo`00o`3ooon00?ooo`<000006`3o
ool3000000X0oooo100000080?ooo`X00000V03oool00?l0ooooO@3oool3000000030?ooo`000000
oooo01X0oooo0`00000=0?ooo`<00000203oool9000009P0oooo003o0?ooogX0oooo0`0000040?oo
o`030000003oool0oooo01X0oooo0`00000=0?ooo`@00000Y`3oool00?l0ooooM`3oool3000000L0
oooo00<000000?ooo`3oool06`3oool4000000`0oooo1000002V0?ooo`00o`3ooomd0?ooo`<00000
:@3oool4000000d0oooo0`00002U0?ooo`00o`3oooma0?ooo`<000005@3oool00`000000oooo0?oo
o`0F0?ooo`<000003@3oool300000:@0oooo003o0?ooofd0oooo1000000G0?ooo`<00000603oool4
000000`0oooo00<000000?ooo`3oool0X`3oool00?l0ooooJP3oool3000001`0oooo1000000A0?oo
o`030000003oool0oooo00<0oooo1000002a0?ooo`00o`3ooomW0?ooo`<00000803oool4000000l0
oooo100000050?ooo`<00000/03oool00?l0ooooI03oool4000002@0oooo0`00000?0?ooo`X00000
/@3oool00?l0ooooH@3oool3000000<0oooo00<000000?ooo`3oool08`3oool4000000l0oooo1`00
002b0?ooo`00o`3ooomN0?ooo`<000001P3oool00`000000oooo0?ooo`0T0?ooo`@000002`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0;80oooo003o0?oooe/0oooo0`00000F0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool04P3oool3000000L0oooo1000002k0?oo
o`00o`3ooomH0?ooo`<000005`3oool;000001@0oooo100000020?ooo`H00000_03oool00?l0oooo
E@3oool3000001P0oooo3`00000C0?ooo`P00000_`3oool00?l0ooooDP3oool3000001X0oooo1000
00090?ooo`@000001`3oool00`000000oooo0?ooo`060?ooo`L00000`P3oool00?l0ooooC`3oool3
000000/0oooo00<000000?ooo`0000003`3oool2000000d0oooo0P0000070?ooo`d0000000<0oooo
0000003oool0`P3oool00?l0ooooB`3oool4000000`0oooo1@00000?0?ooo`8000003@3oool30000
00L0oooo2@0000380?ooo`00o`3ooom80?ooo`<0000000<0oooo0000003oool0303oool7000000h0
oooo0P00000>0?ooo`8000001P3oool010000000oooo0?ooo`3oool200000<`0oooo003o0?ooodD0
oooo0`0000050?ooo`030000003oool0oooo00/0oooo00@000000?ooo`3oool0oooo0P00000>0?oo
o`<000003@3oool2000000<0oooo1@00003@0?ooo`00o`3ooom20?ooo`<000006P3oool2000000h0
oooo1000000<0?ooo`T00000d@3oool00?l0oooo?`3oool3000001d0oooo0P00000@0?ooo`D00000
1`3oool800000=@0oooo003o0?oooc`0oooo0`00000O0?ooo`8000004P3oool700000080oooo1`00
003G0?ooo`00o`3oooli0?ooo`<000008@3oool2000001H0oooo2P00003J0?ooo`00o`3ooolf0?oo
o`<000000`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01L0oooo1@00003M0?oo
o`00o`3ooolc0?ooo`<000001@3oool3000000d0oooo00@000000?ooo`3oool000003@3oool20000
0?/0oooo003n0?ooo`800000;`3oool4000000P0oooo100000090?ooo`T000002@3oool2000000h0
oooo0P00003/0?ooo`00o@3oool010000000oooo0?ooo`00000Z0?ooo`@000000`3oool00`000000
oooo0?ooo`070?ooo`@000001P3oool>000000H0oooo0P00000=0?ooo`@00000j`3oool00?d0oooo
00@000000?ooo`3oool000009`3oool3000001<0oooo100000030?ooo`@000001`3oool5000000D0
oooo0`00000;0?ooo`@00000k03oool00?d0oooo00@000000?ooo`3oool00000903oool3000001L0
oooo100000020?ooo`800000303oool3000000@0oooo1P0000040?ooo`H00000kP3oool00?d0oooo
00@000000?ooo`3oool000008@3oool3000001`0oooo1P00000=0?ooo`<000001@3oool=00000>l0
oooo003n0?ooo`8000007`3oool3000001L0oooo00<000000?ooo`3oool01P3oool5000000h0oooo
0P0000070?ooo`L00000l`3oool00?l0oooo7@3oool3000001X0oooo00<000000?ooo`3oool0203o
ool4000000d0oooo0P00003o0?ooo`80oooo003o0?oooaT0oooo1000000M0?ooo`8000002P3oool4
000000`0oooo0`00003o0?ooo`40oooo003o0?oooaL0oooo0`00000P0?ooo`<000002`3oool50000
00L0oooo1000003o0?ooo`80oooo003o0?oooa@0oooo0`0000020?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02`3oool2000000`0oooo1`0000020?ooo`D00000o`3oool30?ooo`00
o`3ooolA0?ooo`<000001@3oool00`000000oooo0?ooo`0@0?ooo`@000002`3oool2000000l0oooo
2@00003o0?ooo`D0oooo003o0?ooo`d0oooo1000000L0?ooo`@000002P3oool200000140oooo1@00
003o0?ooo`L0oooo003o0?ooo`X0oooo0`00000R0?ooo`@00000203oool300000?l0oooo703oool0
0?l0oooo1`3oool3000002H0oooo100000080?ooo`800000203oool00`000000oooo0?ooo`3o0?oo
oa40oooo003o0?ooo`@0oooo0`00000E0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool02`3oool3000000P0oooo0P0000040?ooo`D00000o`3ooolB0?ooo`00o`3oool10?ooo`<00000
0`3oool010000000oooo0?ooo`00000@0?ooo`/000003@3oool4000000L0oooo2@00003o0?oooa<0
oooo003m0?ooo`<00000103oool7000000h0oooo3P00000<0?ooo`@000001@3oool700000?l0oooo
5P3oool00?X0oooo0`0000020?ooo`040000003oool0oooo0?ooo`T00000303oool3000000T0oooo
100000070?ooo`030000003oool0oooo00<0oooo2`00003o0?oooaT0oooo003g0?ooo`<000001@3o
ool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0?ooo`<000003@3oool2000000`0oooo
0`0000050?ooo`D000000`3oool700000?l0oooo703oool00?@0oooo0`0000080?ooo`030000003o
ool0oooo00D0oooo0`00000>0?ooo`8000003@3oool3000000D0oooo2`00003o0?oooal0oooo003a
0?ooo`<000004P3oool3000000l0oooo0`00000=0?ooo`8000001`3oool600000?l0oooo8P3oool0
0>d0oooo1000000D0?ooo`<00000403oool4000000`0oooo0`00003o0?ooobh0oooo003Z0?ooo`<0
0000603oool2000001<0oooo0`00000:0?ooo`<00000o`3oool_0?ooo`00i`3oool3000001/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`050?ooo`@000001`3oool300000?l0oooo
<03oool00>@0oooo0`00000N0?ooo`8000002@3oool5000000L0oooo3000003o0?oooc40oooo003Q
0?ooo`<000000P3oool00`000000oooo0?ooo`0L0?ooo`l000002@3oool:00000?l0oooo<P3oool0
0=h0oooo0`0000050?ooo`030000003oool0oooo01`0oooo3000003o0?ooodP0oooo003K0?ooo`<0
0000;`3oool200000?l0ooooBP3oool00=P0oooo0`00000F0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0?l0oooo
?03oool00=D0oooo0`00000H0?ooo`l000003P3oool2000000P0oooo1@00003o0?ooocd0oooo003B
0?ooo`<00000503oool00`000000oooo0?ooo`040?oooa<000002P3oool400000080oooo2000003o
0?oooch0oooo003>0?ooo`@0000000<0oooo0000003oool04P3oool6000000D0oooo1@0000070?oo
o`P00000203oool:00000?l0oooo@@3oool00</0oooo0`0000040?ooo`@00000403oool:000000@0
oooo1@0000090?ooo`H000001`3oool700000?l0oooo@`3oool00<P0oooo0`0000020?ooo`030000
003oool0oooo00<0oooo100000090?ooo`030000003oool000000080oooo100000030?ooo`D00000
1@3oool4000000/0oooo1000000:0?ooo`800000o`3ooom40?ooo`00a@3oool3000000D0oooo00<0
00000?ooo`3oool01@3oool4000000D0oooo300000050?ooo`030000003oool0oooo00H0oooo0`00
000<0?ooo`030000003oool0oooo00T0oooo1`00003o0?ooocl0oooo00320?ooo`<000004@3oool5
00000080oooo3P00000>0?ooo`<000005`3oool700000?l0oooo?`3oool00;l0oooo0`00000F0?oo
o`@0000000<0oooo000000000000203oool5000000h0oooo0`00003o0?oooe`0oooo002l0?ooo`<0
00006`3oool5000000X0oooo1@00000;0?ooo`D00000o`3ooomK0?ooo`00^@3oool3000001P0oooo
0P0000050?ooo`D000002`3oool6000000L0oooo1@00003o0?oooe`0oooo002f0?ooo`<000006`3o
ool2000000L0oooo1000000<0?ooo`H000001P3oool00`000000oooo0?ooo`3o0?oooed0oooo0027
0?ooo`800000:P3oool3000001h0oooo0P0000090?ooo`@000003@3oool400000?l0ooooI@3oool0
08H0oooo00@000000?ooo`3oool000009P3oool300000080oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0:0?ooo`8000002P3oool5000000d0oooo00<000000?ooo`3oool0o`3ooomT
0?ooo`00R@3oool00`000000oooo0?ooo`0P0?ooo`@000001@3oool00`000000oooo0?ooo`0>0?oo
o`@000002P3oool2000000`0oooo1000003o0?ooog<0oooo00200?ooo`@000000`3oool200000200
oooo0`00000K0?ooo`H00000203oool2000000`0oooo1@00003o0?ooog40oooo00270?ooo`030000
003oool0oooo01`0oooo0`00000E0?ooo`030000003oool0oooo00P0oooo1P0000060?ooo`800000
3P3oool400000?l0ooooL03oool008L0oooo0`00000I0?ooo`<000005`3oool5000000X0oooo1@00
00040?ooo`800000403oool00`000000oooo0?ooo`3o0?ooofl0oooo002P0?ooo`<000006@3oool6
000000`0oooo1@0000020?ooo`800000o`3ooon20?ooo`00W03oool4000001@0oooo00<000000?oo
o`3oool01P3oool200000140oooo1`00003o0?oooh80oooo002J0?ooo`<000005P3oool4000000H0
oooo0P00000C0?ooo`H00000o`3ooon10?ooo`00U`3oool300000080oooo00<000000?ooo`3oool0
5@3oool4000000D0oooo0P00000F0?ooo`@00000o`3ooon00?ooo`00U03oool3000000D0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`070?ooo`@000000`3oool3000001H0oooo0P00
003o0?oooh40oooo002A0?ooo`<000005P3oool6000000L0oooo100000000`3oool0000000000002
000001H0oooo0P00003o0?oooh40oooo002=0?ooo`@00000603oool9000000L0oooo3`0000020?oo
o`8000002P3oool200000?l0ooooP@3oool008X0oooo0`00000K0?ooo`<00000103oool4000000L0
oooo4P00000:0?ooo`800000o`3ooon10?ooo`00Q`3oool3000001l0oooo100000040?ooo`030000
003oool0oooo00P0oooo100000060?ooo`H000002@3oool400000?l0ooooP03oool008@0oooo0`00
000S0?ooo`D000003`3oool400000140oooo1@00003o0?oooh40oooo00210?ooo`@000005@3oool2
00000100oooo1@00000>0?ooo`@000003`3oool400000?l0ooooP`3oool007h0oooo0`0000020?oo
o`8000004`3oool9000000L0oooo00<000000?ooo`3oool00`3oool4000000l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`3o0?oooh<0oooo001k0?ooo`<00000103oool400000140
oooo3@0000040?ooo`030000003oool0oooo00D0oooo0`00003o0?ooojH0oooo001h0?ooo`<00000
203oool4000000l0oooo0`0000070?ooo`D000000P3oool2000000P0oooo1000003o0?oooj@0oooo
001e0?ooo`<000003@3oool4000000d0oooo0`00000:0?ooo`D000002P3oool400000?l0ooooX`3o
ool00780oooo0`00000A0?ooo`D000002`3oool4000000X0oooo1@00000;0?ooo`030000003oool0
oooo0?l0ooooXP3oool006h0oooo1000000F0?ooo`@00000303oool3000000T0oooo1`00003o0?oo
ojh0oooo001[0?ooo`<00000703oool4000000/0oooo100000070?ooo`8000000P3oool400000?l0
oooo[@3oool006P0oooo0`0000020?ooo`050000003oool0oooo0?ooo`0000003@3oool00`000000
oooo0?ooo`090?ooo`D000002P3oool4000000H0oooo0P0000040?ooo`<00000o`3ooon/0?ooo`00
I@3oool3000000@0oooo1`00000;0?ooo`@000002`3oool4000000D0oooo00<000000?ooo`3oool0
0`3oool4000000@0oooo0P0000050?ooo`<00000o`3ooon[0?ooo`00HP3oool3000000L0oooo2000
000;0?ooo`@00000303oool400000080oooo1@0000030?ooo`@000000`3oool2000000D0oooo0P00
003o0?oooj`0oooo001O0?ooo`<00000303oool010000000oooo0?ooo`3oool2000000d0oooo1000
000;0?ooo`@000000P3oool:000000@0oooo100000030?ooo`800000o`3ooon/0?ooo`00G03oool3
000000l0oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`D000002`3oool3000000@0oooo1P00
00050?ooo`H0000000<0oooo000000000000o`3ooon/0?ooo`00F@3oool3000001D0oooo0`00000@
0?ooo`D000002P3oool3000000H0oooo00<000000?ooo`3oool0203oool500000?l0oooo[@3oool0
05D0oooo1000000G0?ooo`<000004`3oool6000000L0oooo0P00000C0?ooo`@00000o`3ooon]0?oo
o`00D`3oool3000001X0oooo0P00000F0?ooo``00000o`3oooo50?ooo`00C`3oool400000080oooo
00<000000?ooo`3oool05`3oool2000001@0oooo00<000000?ooo`3oool00P3oool:00000?l0oooo
a@3oool004`0oooo0`0000060?ooo`030000003oool0oooo00`0oooo00@000000?ooo`3oool00000
1`3oool300000100oooo2P00003o0?ooold0oooo00190?ooo`<000005@3oool:000000@0oooo1000
000?0?ooo`T00000o`3oooo>0?ooo`00AP3oool3000001L0oooo300000050?ooo`D000004P3oool0
0`000000oooo0?ooo`3o0?ooolh0oooo00130?ooo`<000006@3oool3000000P0oooo00<000000?oo
o`3oool01@3oool9000000P0oooo00<000000?ooo`3oool0o`3ooooC0?ooo`003`3oool500000080
oooo0P00000X0?ooo`<00000703oool2000001@0oooo4000003o0?ooom@0oooo000A0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0R0?ooo`<000007`3oool3000000P0
oooo00<000000?ooo`3oool0303oool;00000?l0ooooe@3oool00140oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo01l0oooo0`0000000`3oool000000?ooo`0B0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool=00000180oooo0`00003o0?ooomP0
oooo00090?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0703oool3000000@0oooo00<000000?ooo`3oool03`3oool:000000L0oooo2P0000040?ooo`80
0000303oool300000?l0oooof@3oool00140oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01T0oooo0`00000G0?ooo`h00000203oool5000000D0oooo1000000:0?ooo`D0
0000o`3ooooH0?ooo`00403oool2000000@0oooo0P00000I0?ooo`<000000`3oool00`000000oooo
0?ooo`0C0?ooo`@00000203oool4000000T0oooo100000000`3oool0000000000004000000/0oooo
1`00003o0?ooomH0oooo000]0?ooo`@000001@3oool500000180oooo0P00000<0?ooo`<00000203o
ool900000100oooo1000003o0?ooomH0oooo000Z0?ooo`<000002P3oool600000100oooo0`00000<
0?ooo`<000002@3oool400000?l0ooook@3oool002L0oooo0`00000@0?ooo`H000003P3oool30000
00`0oooo0P00003o0?ooooX0oooo000T0?ooo`@00000503oool7000000`0oooo0`00000<0?ooo`03
0000003oool0oooo0?l0oooon03oool00240oooo0`0000030?ooo`030000003oool0oooo01D0oooo
1`00000:0?ooo`D00000203oool200000?l0oooonP3oool001h0oooo0`0000060?ooo`030000003o
ool0oooo01H0oooo2@0000080?ooo`L000000P3oool5000000D0oooo00<000000?ooo`3oool0o`3o
ooob0?ooo`006`3oool300000080oooo00<000000?ooo`3oool07`3oool:000000P0oooo2P000006
0?ooo`030000003oool0oooo0?l0oooolP3oool001P0oooo0`0000040?ooo`<000008@3oool30000
0080oooo1P0000080?ooo`P000001@3oool200000?l0oooom03oool001D0oooo0`0000080?ooo`<0
00002@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo0`0000040?ooo`H0
00002`3oool3000000<0oooo0`00003o0?oooo@0oooo000B0?ooo`<00000303oool4000000D0oooo
2P00000A0?ooo`8000001P3oool5000000/0oooo1`00003o0?ooooD0oooo000>0?ooo`@00000403o
ool4000000<0oooo3000000@0?ooo`8000002@3oool00`000000oooo0?ooo`0;0?ooo`D00000o`3o
ooof0?ooo`002`3oool300000080oooo00<000000?ooo`3oool04@3oool3000000040?ooo`000000
0000000000P0oooo0`0000080?ooo`030000003oool0oooo00@0oooo0P00000H0?ooo`030000003o
ool0oooo0?l0oooom`3oool000P0oooo0`0000050?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00`3oool5000000X0oooo0`0000060?ooo`D000000`3oool200000?l0ooooo`3ooolC
0?ooo`001@3oool3000000P0oooo00<000000?ooo`3oool02`3oool3000000D0oooo1@0000090?oo
o`800000203oool800000?l0ooooo`3ooolD0?ooo`000P3oool3000001L0oooo100000080?ooo`@0
0000203oool2000000<0oooo00<000000?ooo`3oool0103oool600000?l0ooooo`3ooolD0?ooo`00
0P00000C0?ooo`030000003oool0000000@0oooo0`00000:0?ooo`D000001@3oool900000?l0oooo
o`3ooolN0?ooo`004`3oool=000000/0oooo1@0000020?ooo``00000o`3ooooo0?oooa`0oooo000B
0?oooa0000002`3oool4000000030?ooo`000000000000<00000103oool500000?l0ooooo`3ooolJ
0?ooo`004@3oool3000000T0oooo1`00000;0?ooo`@000002P3oool400000?l0ooooo`3ooolI0?oo
o`004@3oool2000000d0oooo1`0000090?ooo`L000001`3oool200000?l0ooooo`3ooolJ0?ooo`00
4@3oool3000000`0oooo2P0000080?ooo`P000000P3oool400000?l0ooooo`3ooolJ0?ooo`004@3o
ool4000000`0oooo0P0000030?ooo`D000002`3oool900000?l0ooooo`3ooolK0?ooo`004`3oool5
000000T0oooo0P0000060?ooo`030000003oool0oooo00`0oooo1@00003o0?ooool0oooo7@3oool0
01@0oooo1`0000060?ooo`800000o`3ooooo0?ooocL0oooo000G0?ooo``00000o`3ooooo0?ooocL0
oooo000I0?ooo`X00000o`3ooooo0?ooocL0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {210.813, 0}} -> {0.0480418, 0.299422, \
0.00171467, 0.00171467}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34463 
%%ImageSize: 600 206.78 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0522068 1.05221 -0.343322 1.05221 [
[.12607 .26245 -8.39713 -9 ]
[.12607 .26245 9.60287 0 ]
[.46426 .1531 -2.99431 -9 ]
[.46426 .1531 3.00569 0 ]
[.83148 .03441 -6.43217 -9 ]
[.83148 .03441 5.56783 0 ]
[.46247 .08796 -4.98862 -12.75 ]
[.46247 .08796 5.01138 0 ]
[.99273 -0.00347 0 -5.95066 ]
[.99273 -0.00347 24 3.04934 ]
[.99678 .00243 0 -5.9471 ]
[.99678 .00243 30 3.0529 ]
[1.00081 .0083 0 -5.94355 ]
[1.00081 .0083 6 3.05645 ]
[1.00482 .01416 0 -5.94003 ]
[1.00482 .01416 24 3.05997 ]
[1.00882 .01999 0 -5.93651 ]
[1.00882 .01999 18 3.06349 ]
[1.06476 -0.00983 0 -8.41838 ]
[1.06476 -0.00983 10 4.33162 ]
[ 0 0 0 0 ]
[ 1 .34463 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00057 .31576 m
.97983 0 L
s
.12519 .27557 m
.12475 .28213 L
s
[(-10)] .12607 .26245 -0.06699 1 Mshowa
.46423 .16625 m
.46422 .17283 L
s
[(0)] .46426 .1531 -0.0019 1 Mshowa
.83242 .04753 m
.8329 .05409 L
s
[(10)] .83148 .03441 .07203 1 Mshowa
.125 Mabswid
.19084 .25441 m
.19062 .25835 L
s
.25753 .2329 m
.25737 .23684 L
s
.32532 .21104 m
.3252 .21499 L
s
.39421 .18883 m
.39415 .19278 L
s
.53542 .1433 m
.53547 .14724 L
s
.60781 .11996 m
.60791 .1239 L
s
.68141 .09622 m
.68158 .10016 L
s
.75627 .07208 m
.7565 .07602 L
s
.06058 .29641 m
.06027 .30034 L
s
.90989 .02255 m
.91024 .02648 L
s
gsave
.46247 .08796 -65.9886 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97983 0 m
.9993 .02837 L
s
.98021 .00056 m
.97395 .00258 L
s
[(-0.5)] .99273 -0.00347 -1 .32237 Mshowa
.98426 .00645 m
.978 .00847 L
s
[(-0.25)] .99678 .00243 -1 .32158 Mshowa
.98828 .01232 m
.98202 .01433 L
s
[(0)] 1.00081 .0083 -1 .32079 Mshowa
.9923 .01817 m
.98603 .02017 L
s
[(0.25)] 1.00482 .01416 -1 .32001 Mshowa
.99629 .02399 m
.99003 .02599 L
s
[(0.5)] 1.00882 .01999 -1 .31923 Mshowa
.125 Mabswid
.98102 .00174 m
.97727 .00295 L
s
.98183 .00292 m
.97808 .00413 L
s
.98264 .0041 m
.97889 .00531 L
s
.98345 .00528 m
.97969 .00649 L
s
.98506 .00763 m
.98131 .00884 L
s
.98587 .0088 m
.98211 .01001 L
s
.98668 .00998 m
.98292 .01118 L
s
.98748 .01115 m
.98372 .01236 L
s
.98909 .01349 m
.98533 .0147 L
s
.98989 .01466 m
.98613 .01587 L
s
.99069 .01583 m
.98694 .01703 L
s
.9915 .017 m
.98774 .0182 L
s
.9931 .01933 m
.98934 .02053 L
s
.9939 .0205 m
.99014 .0217 L
s
.9947 .02166 m
.99094 .02286 L
s
.99549 .02282 m
.99174 .02402 L
s
.99709 .02515 m
.99333 .02635 L
s
.99789 .02631 m
.99413 .02751 L
s
.99868 .02747 m
.99492 .02867 L
s
gsave
1.06476 -0.00983 -61 -12.4184 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34463 L
0 .34463 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.06023 .32992 m
.04981 .3037 L
s
.06023 .32992 m
.02177 .31273 L
s
.08121 .32324 m
.09701 .31821 L
s
.08121 .32324 m
.05686 .30143 L
s
.03523 .3183 m
.05273 .31269 L
s
.09701 .31821 m
.10115 .3155 L
s
.10115 .3155 m
.10177 .3139 L
s
.10177 .3139 m
.10124 .31126 L
s
.06966 .3129 m
.08551 .30783 L
s
.11641 .31204 m
.13768 .30527 L
s
.11641 .31204 m
.09225 .29004 L
s
.10124 .31126 m
.09894 .30918 L
s
.09894 .30918 m
.09487 .30766 L
s
.08551 .30783 m
.08965 .30509 L
s
.09196 .30718 m
.08551 .30783 L
s
.09487 .30766 m
.09196 .30718 L
s
.08965 .30509 m
.09026 .30348 L
s
.09026 .30348 m
.08972 .30082 L
s
.07274 .29632 m
.05686 .30143 L
s
.08972 .30082 m
.08624 .29768 L
s
.15905 .29846 m
.14952 .2716 L
s
.15905 .29846 m
.12078 .28085 L
s
.08624 .29768 m
.08215 .29614 L
s
.07922 .29566 m
.07274 .29632 L
s
.08215 .29614 m
.07922 .29566 L
s
.18054 .29162 m
.20395 .28417 L
s
.18054 .29162 m
.15673 .26928 L
s
.16925 .28103 m
.18368 .27641 L
s
.12078 .28085 m
.14952 .2716 L
s
.21479 .28072 m
.24021 .27263 L
s
.24021 .27263 m
.19117 .25819 L
s
.15673 .26928 m
.18027 .2617 L
s
.25298 .26856 m
.22958 .24582 L
s
.27863 .26039 m
.25538 .23751 L
s
.19117 .25819 m
.21674 .24996 L
s
.24189 .25778 m
.26761 .24955 L
s
.29781 .25286 m
.29193 .25186 L
s
.3026 .25276 m
.29781 .25286 L
s
.31 .25041 m
.3026 .25276 L
s
.29193 .25186 m
.28788 .25027 L
s
.31262 .24814 m
.31 .25041 L
s
.28788 .25027 m
.28274 .24759 L
s
.31415 .24477 m
.31262 .24814 L
s
.28274 .24759 m
.27722 .24213 L
s
.31382 .24199 m
.31415 .24477 L
s
.33414 .24272 m
.31121 .21954 L
s
.28979 .24245 m
.30092 .23889 L
s
.27722 .24213 m
.27575 .23825 L
s
.31241 .23811 m
.31382 .24199 L
s
.3472 .23857 m
.32435 .21531 L
s
.27575 .23825 m
.27539 .23545 L
s
.30693 .2326 m
.31241 .23811 L
s
.27539 .23545 m
.27688 .23205 L
s
.30177 .22989 m
.30693 .2326 L
s
.27688 .23205 m
.27948 .22975 L
s
.37344 .23021 m
.33201 .2231 L
s
.2977 .22828 m
.30177 .22989 L
s
.27948 .22975 m
.28693 .22736 L
s
.29176 .22726 m
.2977 .22828 L
s
.28693 .22736 m
.29176 .22726 L
s
.34683 .22565 m
.35074 .20681 L
s
.39795 .22241 m
.39064 .19396 L
s
.39795 .22241 m
.36021 .20376 L
s
.4226 .21456 m
.41553 .18595 L
s
.4226 .21456 m
.4002 .19089 L
s
.45314 .20484 m
.43092 .18099 L
s
.45314 .20484 m
.41553 .18595 L
s
.46849 .19995 m
.47353 .16727 L
s
.46849 .19995 m
.44637 .17602 L
s
.49548 .19136 m
.47353 .16727 L
s
.50711 .18766 m
.53435 .17899 L
s
.50452 .17372 m
.51623 .16997 L
s
.55093 .17223 m
.54497 .17117 L
s
.55587 .17213 m
.55093 .17223 L
s
.56373 .16963 m
.55587 .17213 L
s
.54497 .17117 m
.54096 .16949 L
s
.56664 .16723 m
.56373 .16963 L
s
.54096 .16949 m
.53592 .16665 L
s
.56855 .16365 m
.56664 .16723 L
s
.53592 .16665 m
.53076 .16085 L
s
.56849 .1607 m
.56855 .16365 L
s
.48523 .16351 m
.51264 .15468 L
s
.58935 .16148 m
.61712 .15264 L
s
.58935 .16148 m
.56799 .13686 L
s
.53076 .16085 m
.52963 .15672 L
s
.56741 .15658 m
.56849 .1607 L
s
.52963 .15672 m
.52952 .15376 L
s
.5623 .15074 m
.56741 .15658 L
s
.52952 .15376 m
.53139 .15015 L
s
.61712 .15264 m
.59594 .12786 L
s
.55725 .14785 m
.5623 .15074 L
s
.53139 .15015 m
.5343 .14771 L
s
.63107 .1482 m
.64907 .14247 L
s
.63107 .1482 m
.60998 .12334 L
s
.55321 .14614 m
.55725 .14785 L
s
.5343 .14771 m
.5422 .14516 L
s
.54719 .14506 m
.55321 .14614 L
s
.5422 .14516 m
.54719 .14506 L
s
.64907 .14247 m
.65409 .13937 L
s
.65409 .13937 m
.65511 .13755 L
s
.65511 .13755 m
.65515 .13454 L
s
.66714 .13671 m
.64629 .11165 L
s
.66915 .13607 m
.67117 .13543 L
s
.64831 .111 m
.66915 .13607 L
s
.67117 .13543 m
.65034 .11035 L
s
.63813 .12945 m
.62007 .13523 L
s
.67318 .13479 m
.6752 .13415 L
s
.65237 .10969 m
.67318 .13479 L
s
.65515 .13454 m
.65217 .13098 L
s
.6752 .13415 m
.6544 .10904 L
s
.67721 .1335 m
.67923 .13286 L
s
.65643 .10839 m
.67721 .1335 L
s
.67923 .13286 m
.65846 .10773 L
s
.68125 .13222 m
.68327 .13158 L
s
.66049 .10708 m
.68125 .13222 L
s
.68327 .13158 m
.66252 .10642 L
s
.65217 .13098 m
.64817 .12925 L
s
.68529 .13093 m
.68731 .13029 L
s
.66456 .10577 m
.68529 .13093 L
s
.68731 .13029 m
.66659 .10511 L
s
.68933 .12965 m
.69136 .129 L
s
.66863 .10446 m
.68933 .12965 L
s
.64516 .1287 m
.63813 .12945 L
s
.64817 .12925 m
.64516 .1287 L
s
.69136 .129 m
.67066 .1038 L
s
.69338 .12836 m
.69541 .12771 L
s
.6727 .10315 m
.69338 .12836 L
s
.69541 .12771 m
.67474 .10249 L
s
.69743 .12707 m
.69946 .12642 L
s
.67678 .10183 m
.69743 .12707 L
s
.69946 .12642 m
.67882 .10118 L
s
.70352 .12513 m
.73202 .11606 L
s
.70352 .12513 m
.70802 .10859 L
s
.73815 .11411 m
.76687 .10496 L
s
.64629 .11165 m
.64831 .111 L
s
.65034 .11035 m
.65237 .10969 L
s
.75249 .10954 m
.7322 .08399 L
s
.6544 .10904 m
.65643 .10839 L
s
.70802 .10859 m
.6829 .09986 L
s
.65846 .10773 m
.66049 .10708 L
s
.66252 .10642 m
.66456 .10577 L
s
.66659 .10511 m
.66863 .10446 L
s
.67066 .1038 m
.6727 .10315 L
s
.67474 .10249 m
.67678 .10183 L
s
.77718 .10168 m
.78131 .10037 L
s
.77417 .10113 m
.77718 .10168 L
s
.7702 .09935 m
.77417 .10113 L
s
.78131 .10037 m
.78242 .09849 L
s
.6829 .09986 m
.71159 .09062 L
s
.76829 .09692 m
.7702 .09935 L
s
.78242 .09849 m
.7826 .0954 L
s
.79372 .09642 m
.7907 .09586 L
s
.79786 .0951 m
.79372 .09642 L
s
.7907 .09586 m
.78674 .09408 L
s
.7826 .0954 m
.78087 .08986 L
s
.79899 .09322 m
.79786 .0951 L
s
.78674 .09408 m
.78087 .08986 L
s
.79918 .09011 m
.79899 .09322 L
s
.79729 .08767 m
.79918 .09011 L
s
.78087 .08986 m
.76746 .07264 L
s
.82698 .08583 m
.8072 .05984 L
s
.81092 .08179 m
.80789 .08122 L
s
.81812 .08102 m
.81092 .08179 L
s
.80789 .08122 m
.80392 .07943 L
s
.82648 .07835 m
.81812 .08102 L
s
.80392 .07943 m
.80108 .07573 L
s
.83183 .07511 m
.82648 .07835 L
s
.85418 .07717 m
.86429 .04146 L
s
.80108 .07573 m
.80127 .07258 L
s
.83299 .0732 m
.83183 .07511 L
s
.83322 .07005 m
.83299 .0732 L
s
.80127 .07258 m
.80242 .07067 L
s
.80242 .07067 m
.80775 .06742 L
s
.83041 .06633 m
.83322 .07005 L
s
.8346 .05102 m
.88367 .06778 L
s
.80775 .06742 m
.81614 .06472 L
s
.82643 .06452 m
.83041 .06633 L
s
.81614 .06472 m
.82338 .06395 L
s
.82338 .06395 m
.82643 .06452 L
s
.91335 .05833 m
.89418 .03183 L
s
.88877 .05692 m
.89089 .05625 L
s
.89089 .05625 m
.8921 .05431 L
s
.8921 .05431 m
.89056 .04861 L
s
.89056 .04861 m
.89085 .04541 L
s
.94876 .04551 m
.95609 .04472 L
s
.94268 .04435 m
.94876 .04551 L
s
.89085 .04541 m
.89207 .04346 L
s
.92499 .04535 m
.92713 .04467 L
s
.92195 .04478 m
.92499 .04535 L
s
.91618 .0404 m
.92195 .04478 L
s
.95609 .04472 m
.96039 .04336 L
s
.93785 .04125 m
.94268 .04435 L
s
.89207 .04346 m
.89756 .04014 L
s
.96039 .04336 m
.96596 .04004 L
s
.93424 .03618 m
.93785 .04125 L
s
.91222 .03856 m
.91618 .0404 L
s
.89756 .04014 m
.90183 .03877 L
s
.96596 .04004 m
.96849 .03613 L
s
.90183 .03877 m
.90917 .03798 L
s
.90917 .03798 m
.91222 .03856 L
s
.93278 .0304 m
.93424 .03618 L
s
.96849 .03613 m
.96798 .03162 L
s
.96798 .03162 m
.96442 .02652 L
s
.9329 .01937 m
.93278 .0304 L
s
.96442 .02652 m
.95868 .02209 L
s
.92427 .02215 m
.9329 .01937 L
s
.95868 .02209 m
.94589 .01519 L
s
.94589 .01519 m
.95456 .01239 L
s
0 g
.25 Mabswid
.00057 .31576 m
.97983 0 L
s
.12519 .27557 m
.12475 .28213 L
s
[(-10)] .12607 .26245 -0.06699 1 Mshowa
.46423 .16625 m
.46422 .17283 L
s
[(0)] .46426 .1531 -0.0019 1 Mshowa
.83242 .04753 m
.8329 .05409 L
s
[(10)] .83148 .03441 .07203 1 Mshowa
.125 Mabswid
.19084 .25441 m
.19062 .25835 L
s
.25753 .2329 m
.25737 .23684 L
s
.32532 .21104 m
.3252 .21499 L
s
.39421 .18883 m
.39415 .19278 L
s
.53542 .1433 m
.53547 .14724 L
s
.60781 .11996 m
.60791 .1239 L
s
.68141 .09622 m
.68158 .10016 L
s
.75627 .07208 m
.7565 .07602 L
s
.06058 .29641 m
.06027 .30034 L
s
.90989 .02255 m
.91024 .02648 L
s
gsave
.46247 .08796 -65.9886 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 206.75},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3oool_0?ooo`80
0000103oool2000000@0oooo0P00000C0?ooo`<0000000<0oooo000000000000103oool00?l0oooo
o`3oool^0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000703oool00?l0
ooooo`3oool^0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06P3oool00?l0
ooooo`3ooolX0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`8000007@3oool00?l0
ooooo`3oool^0?ooo`030000003oool0oooo00800000103oool200000080oooo1@0000030?ooo`80
00005@3oool00?l0ooooo`3oool_0?ooo`8000000P3oool00`000000oooo0?ooo`050?ooo`<00000
103oool010000000oooo0?ooo`00000D0?ooo`00o`3ooooo0?oooal0oooo0P00000?0?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0B0?ooo`00
o`3ooooo0?oooa`0oooo1P0000080?ooo`D0000000D0oooo0000003oool0oooo0000000:0?ooo`03
0000003oool0oooo0080oooo0P00000E0?ooo`00o`3ooooo0?oooaT0oooo1`0000000`3oool00000
0?ooo`090?ooo`030000003oool0oooo008000000P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool0503oool00?l0ooooo`3ooolF0?ooo`<00000
1P3oool4000000T0oooo00D000000?ooo`3oool000000?ooo`02000000X0oooo0P0000040?ooo`<0
0000503oool00?l0ooooo`3ooolC0?ooo`<000002@3oool4000000T0oooo00<000000?ooo`3oool0
0P0000040?ooo`8000000`3oool4000000<0oooo0P00000G0?ooo`00o`3ooooo0?ooo`l0oooo1000
000<0?ooo`<0000000<0oooo0000003oool01`3oool01P000000oooo000000000000oooo000000P0
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000F0?ooo`00o`3ooooo0?ooo``0
oooo0`0000030?ooo`030000003oool0oooo00`0oooo100000080?ooo`8000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00?l0oooo
o`3oool90?ooo`<000000`3oool5000000h0oooo0`0000090?ooo`030000003oool0oooo00<00000
103oool200000080oooo00D000000?ooo`00000000000?ooo`02000001L0oooo003o0?ooool0oooo
1P3oool3000000@0oooo1P00000>0?ooo`D00000203oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool000000P3oool2000001P0oooo003o0?ooool0
oooo0`3oool3000000H0oooo1000000C0?ooo`@00000203oool300000080oooo00<000000?ooo`3o
ool0103oool2000000<0oooo1000000F0?ooo`00o`3ooooo0?ooo`<000002P3oool600000100oooo
1000000:0?ooo`040000003oool0oooo000000T0oooo0P00000J0?ooo`00o`3oooo70?ooo`D00000
0P3oool2000002`0oooo0`0000000`3oool0000000000005000000L0oooo1P00000>0?ooo`800000
0P3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3o
ool06@3oool00?l0oooob@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool09P3oool3000000<0oooo1`00000;0?ooo`@000003`3oool4000000T0oooo0P00000:0?ooo`<0
00006@3oool00?l0oooob@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool08`3oool3000000H0oooo00<000000?ooo`3oool00P3oool2000000d0oooo0`00000?0?ooo`<0
0000<@3oool00?l0oooob@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0803oool300000080oooo00<000000?ooo`3oool02@3oool2000000h0oooo0`00000>0?ooo`@0
0000<03oool00?l0oooob@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0703oool4000000D0oooo00<000000?ooo`3oool02@3oool2000000l0oooo0`00000<0?ooo`H0
0000;`3oool00?l0oooob03oool2000000@0oooo0P00000L0?ooo`<000005@3oool200000100oooo
0P00000?0?ooo`<00000;`3oool00?l0ooooj@3oool3000000<0oooo00<000000?ooo`3oool04@3o
ool300000140oooo0P0000100?ooo`00o`3ooooV0?ooo`<000001@3oool300000180oooo0`00000A
0?ooo`800000@03oool00?l0ooooh`3oool3000000T0oooo0`00000B0?ooo`8000004@3oool20000
0400oooo003o0?ooon00oooo0`00000=0?ooo`8000001@3oool00`000000oooo0?ooo`0:0?ooo`<0
0000403oool200000400oooo003o0?ooomd0oooo0`00000A0?ooo`T000002`3oool200000100oooo
0P0000100?ooo`00o`3ooooJ0?ooo`<000000P3oool00`000000oooo0?ooo`0=0?ooo`d000002P3o
ool2000000d0oooo100000100?ooo`00o`3ooooG0?ooo`<00000103oool3000000d0oooo1`000004
0?ooo`D00000203oool3000000/0oooo100000110?ooo`00o`3ooooD0?ooo`<000001`3oool20000
00d0oooo0`0000030?ooo`8000001P3oool5000000L0oooo100000060?ooo`D00000@`3oool00?l0
ooood@3oool3000000X0oooo0P00000<0?ooo`<000001@3oool2000000L0oooo1@0000060?ooo`d0
0000A03oool00?l0ooooc@3oool4000000`0oooo0`00000<0?ooo`8000001P3oool3000000L0oooo
100000070?ooo`T00000A`3oool00?l0oooobP3oool5000000h0oooo0P00000=0?ooo`<000001P3o
ool300000640oooo003o0?ooolL0oooo0`0000030?ooo`D000002`3oool2000000d0oooo0`000007
0?ooo`<00000H03oool00?l0ooooa03oool3000000H0oooo1`0000090?ooo`8000003P3oool20000
00P0oooo0P00001P0?ooo`00o`3oooo10?ooo`<000002@3oool010000000oooo0?ooo`3oool60000
00D0oooo0`00000>0?ooo`<00000203oool2000005l0oooo003o0?oookh0oooo0`00000B0?ooo`L0
00000P3oool2000000h0oooo0`0000090?ooo`<00000GP3oool00?l0oooo^`3oool3000000030?oo
o`000000oooo01D0oooo2000000=0?ooo`<000002`3oool3000005d0oooo003o0?oookP0oooo0`00
00040?ooo`030000003oool0oooo01L0oooo1P00000=0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0G03oool00?l0oooo]@3oool3000000L0oooo0P00000J0?ooo`L00000M`3oool0
0?l0oooo/P3oool3000000/0oooo0P0000020?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool03P3oool2000000030?ooo`000000000000D00000M03oool00?l0oooo[P3oool4000000l0
oooo3000000=0?ooo`<00000103oool600000780oooo003o0?oooj/0oooo0`00000A0?ooo`l00000
303oool2000000P0oooo1P00001_0?ooo`00o`3ooonX0?ooo`<000004@3oool8000000P0oooo0P00
000<0?ooo`8000002P3oool5000006h0oooo003o0?ooojD0oooo0`0000000`3oool000000?ooo`0@
0?ooo`D000000`3oool2000000L0oooo0P00000<0?ooo`8000003@3oool00`000000oooo0?ooo`1]
0?ooo`00o`3ooonR0?ooo`<00000103oool00`000000oooo0?ooo`0?0?ooo`8000001`3oool00`00
0000oooo0?ooo`050?ooo`8000002`3oool3000007d0oooo003l0?ooo`80000000<0oooo00000000
0000W@3oool3000000030?ooo`000000oooo00@0oooo0P00000@0?ooo`8000001`3oool2000000H0
oooo0P00000;0?ooo`800000OP3oool00?d0oooo00<000000?ooo`000000V`3oool3000000@0oooo
00<000000?ooo`3oool0103oool2000000l0oooo0P0000080?ooo`800000103oool4000000X0oooo
0P00001n0?ooo`00oP3oool00`000000oooo0?ooo`2G0?ooo`<000003`3oool00`000000oooo0?oo
o`0=0?ooo`<00000203oool200000080oooo1000000:0?ooo`<00000OP3oool00?`0oooo0P000000
0`3oool000000000002D0?ooo`<000004P3oool2000000l0oooo100000050?ooo`L000003@3oool0
0`000000oooo0?ooo`1m0?ooo`00o`3ooonC0?ooo`<000005P3oool2000000l0oooo3P00002>0?oo
o`00o`3ooon?0?ooo`@000000`3oool00`000000oooo0?ooo`0D0?ooo`8000003`3oool800000080
oooo0P00002?0?ooo`00o`3ooon<0?ooo`<000001P3oool3000001H0oooo00<000000?ooo`3oool0
603oool2000008h0oooo003o0?ooohT0oooo0`00000:0?ooo`<000005@3oool2000000X0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`2<0?ooo`00o`3ooon60?ooo`<0000000<0oooo
0000003oool02`3oool2000001H0oooo0P0000080?ooo`<000003P3oool00`000000oooo0?ooo`2<
0?ooo`00o`3ooon30?ooo`<0000000<0oooo0000000000000P00000=0?ooo`8000005@3oool40000
00L0oooo0`00002L0?ooo`00o`3ooon00?ooo`<0000000<0oooo0000000000001000000>0?ooo`<0
00005@3oool5000000D0oooo0P00002M0?ooo`00o`3ooomm0?ooo`<0000000<0oooo000000000000
1000000B0?ooo`<00000503oool700000080oooo0P00002N0?ooo`00o`3ooomi0?ooo`@0000000<0
oooo0000000000001000000F0?ooo`8000003P3oool00`000000oooo0?ooo`030?ooo`<0000000<0
oooo0000000000001P00002M0?ooo`00o`3ooomg0?ooo`X000006P3oool2000000`0oooo0`000004
0?ooo`800000103oool5000009h0oooo003o0?ooog@0oooo0`0000000`3oool00000000000040000
01d0oooo0`00000<0?ooo`@000000P3oool2000000H0oooo00<000000?ooo`3oool0WP3oool00?l0
ooooL@3oool3000000030?ooo`000000000000X000006`3oool3000000`0oooo1`00002W0?ooo`00
o`3ooom]0?ooo`h000000P3oool6000001X0oooo0`0000090?ooo`030000003oool0oooo00H00000
Y`3oool00?l0ooooJP3oool3000000030?ooo`000000000000/000001@3oool6000001P0oooo0P00
00060?ooo`@00000[`3oool00?l0ooooI`3oool300000080oooo400000060?ooo`L000005P3oool2
00000080oooo1P00002`0?ooo`00o`3ooomT0?ooo`<0000000<0oooo0000000000004`0000080?oo
o`D000005@3oool700000;<0oooo003o0?ooof40oooo0`0000020?oooaP000002@3oool2000001@0
oooo1P00002f0?ooo`00o`3ooomN0?ooo`<00000103ooolI000000T0oooo0P00000A0?ooo`H00000
00<0oooo0000003oool0]P3oool00?l0ooooF`3oool3000000L0oooo6P0000080?ooo`800000303o
ool010000000oooo0?ooo`3oool400000;`0oooo003o0?oooeP0oooo0`00000<0?oooaT000001P3o
ool3000000T0oooo1@0000020?ooo`030000003oool0oooo0;d0oooo003o0?oooeD0oooo0`00000@
0?oooaT000001@3oool2000000L0oooo1`0000330?ooo`00o`3ooomB0?ooo`<00000503ooolI0000
00@0oooo0P0000040?ooo`L00000aP3oool00?l0ooooCP3oool5000001H0oooo6@0000040?ooo`80
000000<0oooo0000000000001@0000390?ooo`00o`3ooom;0?ooo`<000000`3oool3000001H0oooo
6@0000030?ooo`L00000c03oool00?l0ooooB03oool3000000H0oooo1000000F0?oooaT0000000<0
oooo0000000000000`00003?0?ooo`00o`3ooom50?ooo`<000000P3oool00`000000oooo0?ooo`06
0?ooo`<000003`3oool00`000000oooo0?ooo`040?oooaT0000000<0oooo0000003oool0d@3oool0
0?l0oooo@P3oool3000000@0oooo0`0000080?ooo`8000002`3oool7000000D0oooo5`00003E0?oo
o`00o`3ooolo0?ooo`<00000203oool3000000P0oooo0P0000070?ooo``00000103ooolE00000=H0
oooo003o0?oooc`0oooo0`00000<0?ooo`<000001`3oool3000000<0oooo1`0000050?ooo`@00000
103ooolA00000=T0oooo003o0?ooocT0oooo0`00000@0?ooo`800000203oool9000000X0oooo0`00
00030?ooo``0000000<0oooo0000003oool0f`3oool00?l0oooo=P3oool300000080oooo00<00000
0?ooo`3oool03`3oool2000000P0oooo1@00000>0?ooo`<000000`3oool900000>00oooo003o0?oo
oc<0oooo0`0000040?ooo`<00000403oool3000000P0oooo0`00000?0?ooo`<00000103oool50000
0><0oooo003o0?ooo`800000;@3oool4000000P0oooo0`00000@0?ooo`<00000203oool3000000d0
oooo0`0000060?ooo`800000i@3oool00?h0oooo00@000000?ooo`3oool00000:@3oool3000000d0
oooo0`00000@0?ooo`<00000203oool2000000`0oooo0`00003^0?ooo`00oP3oool010000000oooo
0?ooo`00000V0?ooo`<000000P3oool2000000d0oooo0P00000A0?ooo`<00000203oool2000000P0
oooo1@00003_0?ooo`00oP3oool010000000oooo0?ooo`00000S0?ooo`@000000P3oool8000000X0
oooo0P00000A0?ooo`<000001`3oool3000000@0oooo1`00003`0?ooo`00oP3oool010000000oooo
0?ooo`00000P0?ooo`<000000P3oool>000000P0oooo0`00000A0?ooo`800000203oool900000?@0
oooo003o0?ooo`8000007P3oool3000000<0oooo1`0000060?ooo`@00000203oool300000140oooo
0P0000080?ooo`D00000m`3oool00?l0oooo7@3oool3000000D0oooo1000000<0?ooo`@000001`3o
ool300000100oooo0`0000080?ooo`030000003oool0oooo0?P0oooo003o0?oooaX0oooo0`000008
0?ooo`8000003`3oool4000000L0oooo0`00000@0?ooo`<00000o`3oool30?ooo`00o`3ooolG0?oo
o`<000000P3oool00`000000oooo0?ooo`050?ooo`8000004P3oool2000000P0oooo0`00000>0?oo
o`D00000o`3oool20?ooo`00o`3ooolD0?ooo`<000000P3oool5000000H0oooo0P00000C0?ooo`80
0000203oool2000000/0oooo1`00003o0?ooo`<0oooo003o0?oooa40oooo0`0000020?ooo`L00000
1`3oool2000001@0oooo00<000000?ooo`3oool01`3oool2000000L0oooo1`00003o0?ooo`H0oooo
003o0?ooo`d0oooo100000020?ooo`L000002P3oool3000001<0oooo0P0000080?ooo`<000000`3o
ool700000?l0oooo2@3oool00?l0oooo2P3oool3000000<0oooo1`00000>0?ooo`<000004P3oool2
000000T0oooo2@00003o0?ooo``0oooo003o0?ooo`L0oooo0`0000030?ooo`L000004P3oool30000
0140oooo0P00000:0?ooo`D00000o`3oool?0?ooo`00o`3oool40?ooo`<000001@3oool5000001H0
oooo0`00000@0?ooo`8000002`3oool00`000000oooo0?ooo`3o0?oooa00oooo003o0?ooo`40oooo
0`0000020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0603oool3000000l0oooo
0P00003o0?oooah0oooo003m0?ooo`@000000`3oool3000001H0oooo00<000000?ooo`3oool0203o
ool4000000/0oooo1000003o0?oooah0oooo003j0?ooo`<000000`3oool010000000oooo0?ooo`3o
ool400000180oooo1@00000:0?ooo`D000001@3oool700000?l0oooo7`3oool00?L0oooo0`000006
0?ooo`040000003oool0oooo0?ooo`D000003P3oool7000000d0oooo3@00003o0?ooob40oooo003d
0?ooo`<000002@3oool010000000oooo0?ooo`3oool2000000040?ooo`0000000000000000`0oooo
1@00000B0?ooo`L00000o`3ooolU0?ooo`00l@3oool300000080oooo00<000000?ooo`3oool02`3o
ool200000080oooo0`00000<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`00k@3oool4000000@0oooo0`00000<0?ooo`8000000`3oool3000001/0oooo00<00000
0?ooo`3oool0o`3oool_0?ooo`00jP3oool3000000030?ooo`000000oooo00H0oooo0`00000;0?oo
o`800000103oool3000001L0oooo1@00003o0?oooc00oooo003W0?ooo`<000000`3oool3000000L0
oooo0`00000:0?ooo`8000001@3oool3000001<0oooo1`00003o0?oooc40oooo003T0?ooo`<00000
1`3oool3000000L0oooo0`0000090?ooo`8000001P3oool3000000l0oooo1`00003o0?oooc@0oooo
003Q0?ooo`<0000000<0oooo0000003oool0203oool3000000L0oooo0`0000070?ooo`800000203o
ool3000000/0oooo1`00003o0?ooocL0oooo003N0?ooo`<000000`3oool4000000P0oooo0P000008
0?ooo`<000001P3oool2000000T0oooo0`0000070?ooo`L00000o`3ooolj0?ooo`00f`3oool30000
00L0oooo1@0000070?ooo`800000203oool3000000D0oooo0P00000:0?ooo`<000001@3oool50000
0?l0oooo?@3oool00=P0oooo0`0000020?ooo`030000003oool0oooo00D0oooo1`0000050?ooo`<0
0000203oool3000000@0oooo0P00000;0?ooo`<000001@3oool00`000000oooo0?ooo`3o0?oooch0
oooo003E0?ooo`<000000P3oool00`000000oooo00000002000000H0oooo0P0000020?ooo`D00000
103oool3000000P0oooo0`0000030?ooo`800000303oool300000?l0ooooA@3oool00=80oooo0`00
00030?ooo`030000003oool000000080oooo0`0000050?ooo`<000000`3oool5000000<0oooo0`00
00080?ooo`<000000P3oool2000000d0oooo00<000000?ooo`3oool0o`3ooom40?ooo`00cP3oool4
000000D0oooo0`0000040?ooo`<000001@3oool2000000D0oooo100000030?ooo`<00000203oool3
000000030?ooo`00000000000?l0ooooE03oool00</0oooo0`00000:0?ooo`8000001@3oool30000
00@0oooo0P0000070?ooo`@000000P3oool3000000P0oooo1@00003o0?oooe@0oooo00380?ooo`<0
00003@3oool2000000H0oooo0`0000030?ooo`800000203oool5000000030?ooo`000000000000T0
oooo1000003o0?oooe@0oooo00350?ooo`<00000403oool2000000L0oooo0`0000020?ooo`<00000
2@3oool7000000T0oooo0`00003o0?oooe@0oooo00320?ooo`<000000P3oool00`000000oooo0?oo
o`0>0?ooo`<000001`3oool2000000<0oooo0P00000;0?ooo`H00000203oool200000?l0ooooE@3o
ool00;l0oooo0`0000040?ooo`@000003`3oool2000000P0oooo0P0000020?ooo`8000003@3oool5
00000?l0ooooGP3oool00;`0oooo0`0000030?ooo`030000003oool0oooo0080oooo1@00000=0?oo
o`800000203oool3000000030?ooo`000000000000l0oooo1000003o0?oooed0oooo002i0?ooo`<0
00001@3oool3000000D0oooo1@00000;0?ooo`8000002@3oool600000100oooo00<000000?ooo`3o
ool0o`3ooomL0?ooo`00]P3oool3000000P0oooo0P0000080?ooo`D000002@3oool3000000T0oooo
1@00003o0?ooofl0oooo002c0?ooo`<000002`3oool2000000X0oooo1@0000080?ooo`8000002P3o
ool400000?l0ooooK`3oool00:l0oooo1@00000<0?ooo`<00000303oool6000000D0oooo0P00000;
0?ooo`<00000o`3ooom_0?ooo`00[03oool3000000<0oooo0`00000;0?ooo`8000003`3oool60000
00<0oooo0`00000;0?ooo`<00000o`3ooom^0?ooo`00Z@3oool3000000L0oooo0`00000:0?ooo`80
00004P3oool500000080oooo0P00000<0?ooo`030000003oool0oooo0?l0ooooK@3oool00:H0oooo
0`0000030?ooo`030000003oool0oooo00D0oooo0`0000090?ooo`800000503oool700000?l0oooo
O03oool00:<0oooo0`0000050?ooo`<000001`3oool3000000L0oooo0`00000F0?ooo`D00000o`3o
ooml0?ooo`00X03oool3000000T0oooo0`0000070?ooo`<000001P3oool2000001T0oooo1000003o
0?ooog/0oooo002M0?ooo`<000003@3oool3000000H0oooo1`0000020?ooo`8000006`3oool00`00
0000oooo0?ooo`3o0?ooogX0oooo002J0?ooo`<0000000D0oooo0000003oool0oooo0000000<0?oo
o`<000001`3oool;00000?l0ooooUP3oool009L0oooo3P0000000`3oool000000?ooo`070?ooo`<0
00001`3oool3000000030?ooo`000000000000X00000o`3ooon@0?ooo`00U03oool300000080oooo
3`0000080?ooo`<000001`3oool3000000H0oooo2`00003o0?oooh/0oooo002A0?ooo`<000001@3o
ool2000000P0oooo1`0000070?ooo`<000001`3oool3000000/0oooo1P00003o0?ooohX0oooo002=
0?ooo`@000001`3oool3000000`0oooo100000070?ooo`<000001`3oool3000000l0oooo00<00000
0?ooo`3oool0o`3ooon80?ooo`00RP3oool3000000030?ooo`000000oooo00L0oooo0`00000?0?oo
o`<000001`3oool3000000L0oooo0`00003o0?oooiT0oooo00270?ooo`<000000`3oool2000000P0
oooo0P00000=0?ooo`040000003oool0oooo0?ooo`<000001`3oool3000000L0oooo0`00003o0?oo
oiP0oooo00240?ooo`<000001@3oool3000000P0oooo0P00000:0?ooo`D000000`3oool3000000L0
oooo0`0000070?ooo`<00000o`3ooonG0?ooo`00P@3oool3000000T0oooo0`0000070?ooo`<00000
1P3oool7000000D0oooo0P0000080?ooo`<000001`3oool00`000000oooo0?ooo`3o0?oooiH0oooo
001n0?ooo`<000003@3oool3000000L0oooo0`0000040?ooo`D00000203oool2000000T0oooo0`00
003o0?oooil0oooo001k0?ooo`<0000000<0oooo0000003oool03P3oool3000000L0oooo0`000004
0?ooo`030000003oool0oooo00T0oooo0P00000:0?ooo`030000003oool0oooo0?l0ooooWP3oool0
07P0oooo0`0000030?ooo`<000003`3oool3000000L0oooo0`00000?0?ooo`<00000o`3ooonZ0?oo
o`00A03oool500000080oooo0P00000X0?ooo`<000001`3oool3000000l0oooo100000060?ooo`<0
00003@3oool300000?l0ooooZ`3oool004H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0280oooo0`00000;0?ooo`<000003P3oool5000000H0oooo1000000;0?ooo`80
0000o`3ooon/0?ooo`00AP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool07P3oool400000080oooo100000090?ooo`<000002P3oool9000000H0oooo1@0000050?ooo`D0
0000o`3ooon]0?ooo`00?P3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01/0oooo0`0000020?ooo`P000002P3oool3000000H0oooo1`0000030?ooo`<0
00001`3oool=00000?l0oooo[@3oool004H0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo01P0oooo0`0000020?ooo`L000003`3oool300000080oooo1`0000070?ooo`<0
00001`3oool800000?l0oooo/@3oool004D0oooo0P0000040?ooo`800000603oool3000000030?oo
o`000000000000D00000503oool8000000/0oooo0`00003o0?oookl0oooo001R0?ooo`<00000103o
ool4000001L0oooo1@00000?0?ooo`<00000o`3ooonn0?ooo`00G`3oool3000000030?ooo`000000
oooo00D0oooo1P00000E0?ooo`<000004@3oool300000?l0oooo_@3oool005`0oooo0`0000000`3o
ool0000000000002000000T0oooo1`00000B0?ooo`<000004@3oool00`000000oooo0?ooo`3o0?oo
ok`0oooo001I0?ooo`<0000000<0oooo0000000000001000000=0?ooo`L00000403oool300000?l0
ooooc`3oool005H0oooo0`0000000`3oool0000000000004000001@0oooo1P00000>0?ooo`<00000
o`3oooo>0?ooo`00D`3oool:000001X0oooo1`00000;0?ooo`<00000o`3oooo=0?ooo`00C`3oool4
00000080oooo1@00000P0?ooo`L000002@3oool300000?l0ooooc03oool004`0oooo200000020?oo
o`<000009@3oool7000000H0oooo00<000000?ooo`3oool0o`3oooo;0?ooo`00B@3oool300000003
0?ooo`000000000000D000000`3oool3000002L0oooo1@00003o0?ooom<0oooo00160?ooo`<00000
00<0oooo000000000000100000020?ooo`800000103oool3000000X0oooo00<000000?ooo`3oool0
5P3oool700000?l0ooooe03oool004<0oooo0`0000000`3oool0000000000005000000@0oooo0`00
00040?ooo`<000001P3oool5000001D0oooo1P00003o0?ooomL0oooo00100?ooo`<000000P3oool6
000000P0oooo0P0000050?ooo`<000000`3oool6000001<0oooo1P00003o0?ooomX0oooo000m0?oo
o`<000000P3oool6000000/0oooo0P0000060?ooo`P000004`3oool700000?l0oooog03oool003X0
oooo0`0000040?ooo`D000003@3oool3000000H0oooo1@00000?0?ooo`030000003oool0oooo0080
oooo1@00003o0?oooml0oooo000g0?ooo`<00000203oool6000000`0oooo0P0000070?ooo`<00000
3@3oool5000000@0oooo00<000000?ooo`3oool0o`3ooooP0?ooo`00=03oool3000000d0oooo1P00
000:0?ooo`800000203oool3000000X0oooo1P00003o0?ooonP0oooo000a0?ooo`<000004`3oool5
000000P0oooo0`0000080?ooo`<000001P3oool600000?l0ooooj`3oool002d0oooo100000020?oo
o`030000003oool0oooo01<0oooo1P0000060?ooo`8000002@3oool3000000<0oooo1P00003o0?oo
ond0oooo000Z0?ooo`<000001@3oool3000001H0oooo1P0000040?ooo`8000002P3oool800000?l0
ooool03oool002L0oooo0`0000090?ooo`<00000603oool500000080oooo0`00000:0?ooo`D00000
o`3oooob0?ooo`00903oool3000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool0103o
ool3000001T0oooo2000000;0?ooo`030000003oool0oooo0?l0ooool`3oool00240oooo0`000000
0`3oool0000000000009000000D0oooo0`00000J0?ooo`H00000o`3ooooo0?ooo`80oooo000N0?oo
oa<000001@3oool3000001`0oooo1000003o0?ooool0oooo0@3oool001/0oooo0`0000000`3oool0
000000000005000000T0oooo0`0000050?ooo`<000007@3oool00`000000oooo0?ooo`3o0?ooool0
oooo000H0?ooo`@000000P3oool5000000d0oooo0`0000050?ooo`@00000o`3ooooo0?oooah0oooo
000E0?ooo`<000000P3oool300000080oooo0`00000>0?ooo`8000001`3oool4000000l0oooo00<0
00000?ooo`3oool0o`3ooooo0?ooo`/0oooo000B0?ooo`<000001P3oool2000000<0oooo0`00000=
0?ooo`<0000000<0oooo0000003oool01@3oool3000000/0oooo1@00003o0?ooool0oooo303oool0
00h0oooo100000090?ooo`800000103oool3000000/0oooo200000050?ooo`<000001`3oool70000
0?l0ooooo`3oool=0?ooo`002`3oool3000000d0oooo0`0000040?ooo`<000001P3oool>000000@0
oooo0`0000030?ooo`L00000o`3ooooo0?oooa00oooo00080?ooo`<0000000<0oooo0000003oool0
3P3oool2000000D0oooo3@0000060?ooo`@00000103oool900000?l0ooooo`3ooolC0?ooo`001@3o
ool3000000<0oooo1000000;0?ooo`D000001@3oool7000000`0oooo0P0000060?ooo`D00000o`3o
oooo0?oooaH0oooo00020?ooo`<000001`3oool5000000H0oooo200000060?ooo`@000003P3oool3
000000H0oooo00<000000?ooo`3oool0o`3ooooo0?oooaL0oooo0002000000`0oooo1@0000000`3o
ool0000000000004000000<0oooo0P0000080?ooo`<000002`3oool400000?l0ooooo`3ooolQ0?oo
o`00403oool7000000H0oooo0`0000080?ooo`<000001`3oool600000?l0ooooo`3ooolR0?ooo`00
4P3oool5000000L0oooo0P0000090?ooo`<000000`3oool700000?l0ooooo`3ooolT0?ooo`00503o
ool6000000@0oooo0`0000090?ooo`T00000o`3ooooo0?ooobL0oooo000F0?ooo`H000000`3oool2
000000X0oooo1@00003o0?ooool0oooo:P3oool001T0oooo1@0000000`3oool000000000000;0?oo
o`030000003oool0oooo0?l0ooooo`3oool[0?ooo`006`3oool700000?l0ooooo`3ooolh0?ooo`00
7@3oool500000?l0ooooo`3ooolh0?ooo`007`3oool400000?l0ooooo`3ooolg0?ooo`008@3oool0
0`000000oooo0?ooo`3o0?ooool0oooo=P3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {205.75, 0}} -> {0.0496113, 0.301403, \
0.00171806, 0.00171806}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["TimesFont3D", "Subsection"],

Cell[BoxData[{
    \(\(font3D = TimesFont3D;\)\), "\[IndentingNewLine]", 
    \(\(fontThickness = 1;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<M\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .69265 
%%ImageSize: 600 415.589 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.59413e-017 1.04874 -0.127076 1.04874 [
[.05923 .22887 -24 -8.68818 ]
[.05923 .22887 0 .31182 ]
[.18912 .17934 -29.7546 -9 ]
[.18912 .17934 .24538 0 ]
[.32574 .12726 -5.67849 -9 ]
[.32574 .12726 .32151 0 ]
[.46961 .07244 -21.6243 -9 ]
[.46961 .07244 2.37575 0 ]
[.62133 .01466 -15.4009 -9 ]
[.62133 .01466 2.59911 0 ]
[.28208 .07836 -9.46416 -12.75 ]
[.28208 .07836 .53584 0 ]
[.71513 .00595 0 -6.19658 ]
[.71513 .00595 24 2.80342 ]
[.78576 .11108 0 -6.09572 ]
[.78576 .11108 30 2.90428 ]
[.84992 .20658 0 -6.00618 ]
[.84992 .20658 6 2.99382 ]
[.90846 .29372 0 -5.92615 ]
[.90846 .29372 24 3.07385 ]
[.96208 .37354 0 -5.8542 ]
[.96208 .37354 18 3.1458 ]
[.93209 .21575 0 -8.46996 ]
[.93209 .21575 10 4.28004 ]
[ 0 0 0 0 ]
[ 1 .69265 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.01563 .25797 m
.69575 0 L
s
.06883 .2378 m
.07362 .24226 L
s
[(-0.5)] .05923 .22887 1 .93071 Mshowa
.19831 .18868 m
.20291 .19335 L
s
[(-0.25)] .18912 .17934 .98364 1 Mshowa
.33447 .13704 m
.33883 .14193 L
s
[(0)] .32574 .12726 .89283 1 Mshowa
.47781 .08267 m
.48191 .08778 L
s
[(0.25)] .46961 .07244 .80202 1 Mshowa
.62893 .02534 m
.63273 .03069 L
s
[(0.5)] .62133 .01466 .71121 1 Mshowa
.125 Mabswid
.09421 .22817 m
.09707 .23087 L
s
.11985 .21844 m
.12269 .22117 L
s
.14575 .20862 m
.14856 .21137 L
s
.1719 .1987 m
.17468 .20148 L
s
.225 .17856 m
.22773 .18139 L
s
.25195 .16834 m
.25465 .17119 L
s
.27917 .15801 m
.28185 .16089 L
s
.30668 .14758 m
.30933 .15048 L
s
.36254 .12639 m
.36513 .12935 L
s
.39091 .11563 m
.39347 .11861 L
s
.41957 .10476 m
.4221 .10777 L
s
.44854 .09377 m
.45103 .09681 L
s
.50739 .07144 m
.50982 .07454 L
s
.53729 .0601 m
.53968 .06323 L
s
.56751 .04864 m
.56987 .05179 L
s
.59806 .03706 m
.60037 .04023 L
s
.04368 .24733 m
.04659 .24999 L
s
.01879 .25678 m
.02171 .25941 L
s
.66015 .0135 m
.66239 .01674 L
s
.6917 .00154 m
.6939 .0048 L
s
gsave
.28208 .07836 -70.4642 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.69575 0 m
.9871 .43319 L
s
.70286 .01057 m
.69673 .01289 L
s
[(-0.5)] .71513 .00595 -1 .37702 Mshowa
.77341 .11546 m
.76723 .11765 L
s
[(-0.25)] .78576 .11108 -1 .3546 Mshowa
.83749 .21075 m
.83128 .21283 L
s
[(0)] .84992 .20658 -1 .33471 Mshowa
.89596 .29768 m
.88971 .29966 L
s
[(0.25)] .90846 .29372 -1 .31692 Mshowa
.94953 .37732 m
.94325 .37921 L
s
[(0.5)] .96208 .37354 -1 .30093 Mshowa
.125 Mabswid
.71753 .03239 m
.71385 .03376 L
s
.73192 .05377 m
.72823 .05513 L
s
.74602 .07474 m
.74232 .07608 L
s
.75985 .0953 m
.75614 .09663 L
s
.78671 .13524 m
.783 .13655 L
s
.79977 .15465 m
.79605 .15594 L
s
.81258 .1737 m
.80885 .17497 L
s
.82515 .19239 m
.82142 .19365 L
s
.84961 .22876 m
.84588 .23 L
s
.86151 .24646 m
.85777 .24768 L
s
.8732 .26384 m
.86946 .26505 L
s
.88468 .28091 m
.88094 .28211 L
s
.90705 .31416 m
.90329 .31534 L
s
.91794 .33036 m
.91418 .33153 L
s
.92865 .34628 m
.92489 .34744 L
s
.93918 .36193 m
.93541 .36308 L
s
.9597 .39245 m
.95593 .39358 L
s
.96971 .40734 m
.96594 .40845 L
s
.97956 .42198 m
.97578 .42308 L
s
gsave
.93209 .21575 -61 -12.47 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .69265 L
0 .69265 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.40373 .63713 m
.50363 .6088 L
s
.47832 .61598 m
.32612 .20358 L
s
.47832 .61598 m
.11806 .28006 L
s
.50363 .6088 m
.38266 .26458 L
s
.85495 .50918 m
.9721 .47597 L
s
.85495 .50918 m
.55148 .12073 L
s
.85495 .50918 m
.32612 .20358 L
s
.88382 .501 m
.58522 .10833 L
s
.0337 .31107 m
.20524 .24801 L
s
.45264 .15707 m
.68888 .07022 L
s
0 g
.25 Mabswid
.01563 .25797 m
.69575 0 L
s
.06883 .2378 m
.07362 .24226 L
s
[(-0.5)] .05923 .22887 1 .93071 Mshowa
.19831 .18868 m
.20291 .19335 L
s
[(-0.25)] .18912 .17934 .98364 1 Mshowa
.33447 .13704 m
.33883 .14193 L
s
[(0)] .32574 .12726 .89283 1 Mshowa
.47781 .08267 m
.48191 .08778 L
s
[(0.25)] .46961 .07244 .80202 1 Mshowa
.62893 .02534 m
.63273 .03069 L
s
[(0.5)] .62133 .01466 .71121 1 Mshowa
.125 Mabswid
.09421 .22817 m
.09707 .23087 L
s
.11985 .21844 m
.12269 .22117 L
s
.14575 .20862 m
.14856 .21137 L
s
.1719 .1987 m
.17468 .20148 L
s
.225 .17856 m
.22773 .18139 L
s
.25195 .16834 m
.25465 .17119 L
s
.27917 .15801 m
.28185 .16089 L
s
.30668 .14758 m
.30933 .15048 L
s
.36254 .12639 m
.36513 .12935 L
s
.39091 .11563 m
.39347 .11861 L
s
.41957 .10476 m
.4221 .10777 L
s
.44854 .09377 m
.45103 .09681 L
s
.50739 .07144 m
.50982 .07454 L
s
.53729 .0601 m
.53968 .06323 L
s
.56751 .04864 m
.56987 .05179 L
s
.59806 .03706 m
.60037 .04023 L
s
.04368 .24733 m
.04659 .24999 L
s
.01879 .25678 m
.02171 .25941 L
s
.66015 .0135 m
.66239 .01674 L
s
.6917 .00154 m
.6939 .0048 L
s
gsave
.28208 .07836 -70.4642 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 415.563},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0001Wb000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo]03oool2000000@0oooo0P0000040?ooo`80
0000U`3oool00?l0ooooI`3oool2000000@0oooo0P0000040?ooo`800000:P3oool200000180oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00002F0?ooo`00o`3ooomV0?ooo`04
0000003oool0oooo000000P0oooo00@000000?ooo`3oool000009`3oool200000080oooo00<00000
0?ooo`3oool03`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo09@0oooo003o
0?ooofH0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0R0?ooo`<000000P3o
ool00`000000oooo0000000;0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000
U`3oool00?l0ooooIP3oool010000000oooo0?ooo`0000090?ooo`8000008P3oool3000000P0oooo
00<000000?ooo`3oool03P3oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo09H0
oooo003o0?ooofH0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0O0?ooo`80
0000303oool00`000000oooo0?ooo`0>0?ooo`8000002P3oool3000009H0oooo003o0?ooofL0oooo
0P00000:0?ooo`<00000703oool3000000h0oooo00<000000?ooo`3oool0/`3oool00?l0ooooS`3o
ool300000180oooo0P00002c0?ooo`00o`3ooon=0?ooo`8000004P3oool3000000030?ooo`000000
oooo0;80oooo003o0?ooohX0oooo0`00000H0?ooo`030000003oool0oooo0;40oooo003o0?ooohL0
oooo0`0000020?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0/03oool00?l0oooo
Q@3oool2000000H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`2_0?ooo`00o`3o
oon20?ooo`<000008P3oool00`000000oooo0?ooo`2_0?ooo`00o`3ooomo0?ooo`<000009P3oool0
0`000000oooo0?ooo`2^0?ooo`00o`3ooomm0?ooo`800000:P3oool00`000000oooo0?ooo`2]0?oo
o`00o`3ooomj0?ooo`<00000;03oool00`000000oooo0?ooo`2]0?ooo`00o`3ooomh0?ooo`800000
<03oool00`000000oooo0?ooo`2/0?ooo`00o`3ooome0?ooo`<000000P3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0:/0oooo003o0?ooog80oooo0`0000050?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool0ZP3oool00?l0ooooL03oool2000000T0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`2Z0?ooo`00o`3ooom]0?ooo`<00000?@3oool00`000000
oooo0?ooo`2Y0?ooo`00o`3ooomZ0?ooo`<00000?P3oool2000000030?ooo`000000oooo0:T0oooo
003o0?ooofP0oooo0P0000140?ooo`030000003oool0oooo0:P0oooo003o0?ooofD0oooo0`000017
0?ooo`030000003oool0oooo0:L0oooo003o0?ooof80oooo0`0000020?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool0YP3oool00?l0ooooH03oool2000000H0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`2V0?ooo`00o`3ooomM0?ooo`<00000D@3oool00`000000oooo
0?ooo`2U0?ooo`00o`3ooomK0?ooo`800000E@3oool00`000000oooo0?ooo`2T0?ooo`00o`3ooomH
0?ooo`<00000E`3oool00`000000oooo0?ooo`2T0?ooo`00o`3ooomE0?ooo`<00000F`3oool00`00
0000oooo0?ooo`2S0?ooo`00o`3ooomC0?ooo`800000G`3oool00`000000oooo0?ooo`2R0?ooo`00
o`3ooom@0?ooo`<000000P3oool2000005d0oooo00<000000?ooo`3oool0XP3oool00?l0ooooC@3o
ool3000006D0oooo00<000000?ooo`3oool0X@3oool00?l0ooooB`3oool2000006L0oooo0`00002R
0?ooo`00o`3ooom80?ooo`<00000J`3oool00`000000oooo0?ooo`2P0?ooo`00o`3ooom50?ooo`<0
0000K`3oool00`000000oooo0?ooo`2O0?ooo`00o`3oool60?ooo`800000103oool2000000<0oooo
100000030?ooo`800000:03oool3000007<0oooo00<000000?ooo`3oool0WP3oool00?l0oooo1@3o
ool010000000oooo0?ooo`0000080?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool0
00009@3oool4000007@0oooo00<000000?ooo`3oool0WP3oool00?l0oooo1@3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool3000000@0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`2M0?ooo`00XP3oool2000000030?oo
o`000000000005d0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`80
00008@3oool2000007d0oooo00<000000?ooo`3oool0W03oool00:<0oooo00<000000?ooo`000000
GP3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool07@3oool3000007l0oooo00<000000?ooo`3oool0W03oool00:@0oooo00<000000?ooo`3o
ool0GP3oool2000000X0oooo0P0000040?ooo`<000006`3oool2000008<0oooo00<000000?ooo`3o
ool0V`3oool00:80oooo0P0000000`3oool000000000002;0?ooo`<00000I@3oool2000001l0oooo
00<000000?ooo`3oool0VP3oool00?l0oooo<03oool3000006D0oooo0`00000Q0?ooo`030000003o
ool0oooo09X0oooo003o0?ooobh0oooo0P0000000`3oool000000?ooo`1S0?ooo`8000009@3oool0
0`000000oooo0?ooo`2I0?ooo`00o`3oool[0?ooo`<00000103oool00`000000oooo0?ooo`1N0?oo
o`<00000:03oool00`000000oooo0?ooo`2H0?ooo`00o`3ooolX0?ooo`<00000I@3oool3000002T0
oooo0`00002J0?ooo`00o`3ooolV0?ooo`800000IP3oool2000002l0oooo00<000000?ooo`3oool0
U`3oool00?l0oooo8`3oool3000006D0oooo0`00000b0?ooo`030000003oool0oooo09H0oooo003o
0?ooob00oooo0`00001U0?ooo`<00000=@3oool00`000000oooo0?ooo`2F0?ooo`00o`3ooolN0?oo
o`800000IP3oool2000003T0oooo00<000000?ooo`3oool0U@3oool00?l0oooo6`3oool300000080
oooo00<000000?ooo`3oool0H03oool3000003`0oooo00<000000?ooo`3oool0U03oool00?l0oooo
6@3oool2000000D0oooo00<000000?ooo`3oool0G@3oool300000400oooo00<000000?ooo`3oool0
T`3oool00?l0oooo5P3oool3000000P0oooo00<000000?ooo`3oool0FP3oool2000004<0oooo00<0
00000?ooo`3oool0T`3oool00?l0oooo4`3oool3000006D0oooo0`0000160?ooo`030000003oool0
oooo0980oooo003o0?oooa40oooo0P00001U0?ooo`<00000BP3oool00`000000oooo0?ooo`2A0?oo
o`00o`3oool=0?ooo`@00000I03oool3000004d0oooo00<000000?ooo`3oool0T@3oool00?l0oooo
2`3oool4000006@0oooo0P00001A0?ooo`800000T@3oool00?l0oooo2@3oool2000000@0oooo00<0
00000?ooo`3oool0GP3oool300000540oooo0P0000000`3oool000000?ooo`2@0?ooo`00o`3oool6
0?ooo`<00000I03oool3000005L0oooo00<000000?ooo`3oool0S`3oool00?l0oooo0`3oool30000
06D0oooo0P00001K0?ooo`030000003oool0oooo08h0oooo003o0?ooo`40oooo0P00001U0?ooo`<0
0000GP3oool00`000000oooo0?ooo`2=0?ooo`00o@3oool3000006@0oooo0`00001Q0?ooo`030000
003oool0oooo08d0oooo003j0?ooo`<00000I@3oool2000006D0oooo00<000000?ooo`3oool04@3o
ool2000000@0oooo0P0000030?ooo`@000000`3oool2000006L0oooo003h0?ooo`8000000P3oool0
0`000000oooo0?ooo`1P0?ooo`<00000J03oool00`000000oooo0?ooo`0?0?ooo`040000003oool0
oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00001V0?ooo`00m@3o
ool3000000D0oooo00<000000?ooo`3oool0G03oool3000006/0oooo00<000000?ooo`3oool03`3o
ool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
I03oool00?<0oooo0P00001U0?ooo`8000000`3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo00P0oooo100000020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0
0P3oool2000006L0oooo003`0?ooo`<00000I03oool3000000H0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`0=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`1V0?ooo`00`03oool2000002/0oooo0`00001T0?ooo`<00000
2@3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo00h0oooo0P00000:0?ooo`800000
103oool3000006H0oooo002o0?ooo`040000003oool0oooo000002L0oooo0`00001T0?ooo`<00000
3@3oool00`000000oooo0?ooo`1Y0?ooo`800000R@3oool00;l0oooo00@000000?ooo`3oool00000
9@3oool4000006<0oooo0P00000A0?ooo`030000003oool0oooo06L0oooo0`0000290?ooo`00_`3o
ool010000000oooo0?ooo`00000R0?ooo`<00000103oool00`000000oooo0?ooo`1M0?ooo`<00000
503oool00`000000oooo0?ooo`1T0?ooo`8000000P3oool00`000000oooo0?ooo`270?ooo`00_`3o
ool010000000oooo0?ooo`00000P0?ooo`800000I03oool3000001L0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`260?ooo`00`03oool2000001h0oooo0`00001T0?ooo`8000000P3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0Q@3o
ool00=d0oooo0`00001T0?ooo`<000001@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo06P0oooo00<000000?ooo`3oool0Q@3oool00=/0oooo0P00001T0?ooo`<00000203oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0Q03oool00=P0
oooo0`00001T0?ooo`800000303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0P`3oool00=H0oooo0P0000020?ooo`030000003oool0oooo05l0oooo
0`00000?0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`230?ooo`00d`3oool3000000D0oooo00<000000?ooo`3oool0F`3oool3000001<0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0880oooo003@
0?ooo`<00000I03oool2000001H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo0840oooo003>0?ooo`800000I03oool3000001T0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo0840oooo003;0?ooo`<0
0000H`3oool3000001d0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1X0?ooo`80
0000P@3oool00<P0oooo0`00001S0?ooo`<000008@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo06D0oooo0P0000000`3oool000000?ooo`200?ooo`00aP3oool200000080oooo00<0
00000?ooo`3oool0G`3oool2000002D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1X0?ooo`030000003oool0oooo07h0oooo00330?ooo`<00000103oool00`000000oooo0?ooo`1L
0?ooo`<000009`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06P0oooo00<00000
0?ooo`3oool0OP3oool00<00oooo0`0000080?ooo`030000003oool0oooo05P0oooo0`00000[0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1m0?oo
o`00_P3oool2000006@0oooo0P00000_0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0J03oool00`000000oooo0?ooo`1l0?ooo`00^`3oool3000006<0oooo0`00000b0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1l0?ooo`00^03o
ool3000006<0oooo0`00000e0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0J03o
ool00`000000oooo0?ooo`1k0?ooo`00]P3oool2000000030?ooo`000000oooo0640oooo0P00000i
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`1j
0?ooo`00/`3oool3000000@0oooo00<000000?ooo`3oool0G03oool3000003`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo07X0oooo002a0?ooo`80
0000H`3oool300000400oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo07T0oooo002^0?ooo`<00000H`3oool2000004@0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1X0?ooo`030000003oool0oooo07P0oooo002[0?ooo`<00000H`3o
ool3000004H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1U0?ooo`<00000NP3o
ool00:T0oooo0P00001T0?ooo`800000BP3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0M`3oool00:H0oooo0`00002c0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1f0?ooo`00X`3oool3000000<0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0MP3oool00:40oooo0P00002j0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1e0?ooo`00WP3oool300000;d0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo07@0oooo001L
0?ooo`800000103oool2000000<0oooo100000030?ooo`800000:`3oool300000<40oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo07@0oooo001K0?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00
000X0?ooo`800000a@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0L`3oool005/0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02<0oooo0`0000380?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`1b0?ooo`00E@3oool400000080oooo00@00000
0?ooo`3oool000002P3oool00`000000oooo0?ooo`020?ooo`8000008`3oool300000080oooo0P00
00370?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`1b0?ooo`00F`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0803oool200000<l0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0740oooo001L0?ooo`8000002P3oool2000000@0oooo0`00
000M0?ooo`<00000dP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo00<0
00000?ooo`3oool0L03oool008`0oooo0P00003F0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0I03oool300000780oooo00290?ooo`<00000f03oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0K`3oool008H0oooo0`00003L0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1^0?ooo`00
Q03oool200000080oooo0P00003L0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`1^0?ooo`00P@3oool300000><0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06d0oooo001n0?ooo`<00000i`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0K03oool0
07`0oooo0P00003Z0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`1/0?ooo`00N@3oool300000>d0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo06/0oooo001f0?ooo`<00000l@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0JP3oool007@0oooo0P00
00030?ooo`030000003oool0oooo0>l0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo06T0oooo001a0?ooo`<000001@3oool00`000000oooo0?ooo`3`
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1Y
0?ooo`00K`3oool2000000T0oooo00<000000?ooo`3oool0k`3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0680oooo0P0000000`3oool000000?ooo`1Y0?ooo`00K03oool300000?h0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06L0
oooo001Y0?ooo`<00000o`3oool30?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`1W0?ooo`00I`3oool200000?l0oooo1`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool02`3oool2000005T0oooo001T
0?ooo`<000000P3oool200000?l0oooo1@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool02@3oool010000000oooo0?ooo`00001H0?ooo`00H@3oool3
00000?l0oooo3@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool02@3oool010000000oooo0?ooo`00001H0?ooo`00G`3oool2000006<0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`00001H0?ooo`00G03oool3000006D0oooo0`00002[
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`07
0?ooo`040000003oool0oooo000002l0oooo0P00000W0?ooo`00F@3oool3000006T0oooo00@00000
0?ooo`0000000000ZP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0203oool200000340oooo00<000000?ooo`3oool09@3oool005L0oooo0P00001/
0?ooo`040000003oool0oooo0?ooo`800000Z03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0T0?ooo`00E03oool3
00000080oooo0P00001Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06@0oooo0P00000k0?ooo`030000003oool0
000002D0oooo001A0?ooo`<00000LP3oool00`000000oooo0?ooo`030?ooo`800000Y`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo0600oooo0`0000000`3oool000000?ooo`0i0?oo
o`040000003oool0oooo000002D0oooo001?0?ooo`800000M@3oool00`000000oooo0?ooo`050?oo
o`800000YP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0=P3oool3000000030?ooo`000000000002@0oooo000E0?ooo`800000103oool2000000@0
oooo0P00000Y0?ooo`<00000N03oool00`000000oooo0?ooo`060?ooo`800000Y03oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0G`3oool001@0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000U0?ooo`<00000N`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo05l0oooo000D0?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`3oool08@3oool4000007`0oooo00<000000?ooo`3oool02@3oool20000
0:<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
05h0oooo000>0?ooo`@000000P3oool010000000oooo0?ooo`0000090?ooo`8000008@3oool30000
00@0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0:0?ooo`800000XP3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0G@3oool001@0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0N0?ooo`800000Q03oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0:00oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo05d0oooo000E0?ooo`8000002P3oool3000001/0
oooo0`0000260?ooo`030000003oool0oooo00d0oooo0P00002P0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1L0?ooo`00?03oool3000008X0oooo
00<000000?ooo`3oool03P3oool2000009l0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo05/0oooo000j0?ooo`800000S@3oool00`000000oooo0?oo
o`0@0?ooo`800000WP3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0F`3oool003L0oooo1000002?0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo0`00001L
0?ooo`00=03oool3000000@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0B0?oo
o`800000W03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0F@3oool00380oooo0P00002F0?ooo`030000003oool0oooo01@0oooo0P00002K0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1I0?ooo`00
;`3oool3000009T0oooo00<000000?ooo`3oool05@3oool2000009X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo05P0oooo000]0?ooo`800000W03o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo05L0oooo000Z0?ooo`<00000WP3oool0
0`000000oooo0?ooo`0H0?ooo`800000V@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool0E`3oool002L0oooo0`0000020?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool06@3oool2000009L0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo05H0oooo000U0?ooo`8000001@3oool00`000000
oooo0?ooo`2M0?ooo`030000003oool0oooo01/0oooo0P00002F0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1E0?ooo`008P3oool3000000P0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo09@0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo05D0oooo
000O0?ooo`<00000Z`3oool00`000000oooo0?ooo`0M0?ooo`800000U@3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0E03oool001d0oooo0P00002^
0?ooo`030000003oool0oooo01l0oooo0P00002C0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`1C0?ooo`006P3oool3000005h0oooo0P00001A0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo0600oooo0P0000000`3oool000000?ooo`1C0?ooo`005`3oool3000000<0
oooo00<000000?ooo`3oool0F03oool3000005<0oooo00<000000?ooo`3oool08@3oool200000980
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0580
oooo000E0?ooo`800000G`3oool2000005H0oooo00<000000?ooo`3oool08`3oool200000940oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0540oooo
000B0?ooo`<00000GP3oool3000005T0oooo00<000000?ooo`3oool0903oool200000900oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0500oooo000?
0?ooo`<00000GP3oool3000005`0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1@
0?ooo`003@3oool2000005l0oooo0P00001O0?ooo`030000003oool0oooo02L0oooo0P00002>0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1?0?oo
o`002`3oool2000000030?ooo`000000oooo05/0oooo0`00001R0?ooo`030000003oool0oooo02P0
oooo0P00002=0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H`3oool00`000000
oooo0?ooo`1>0?ooo`003`3oool00`000000oooo0?ooo`1F0?ooo`<00000I@3oool00`000000oooo
0?ooo`0Z0?ooo`800000S03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool0CP3oool006H0oooo0P00001X0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0C@3oool006<0oooo0`00001[0?ooo`030000003oool0oooo02`0oooo0P00002:
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1<
0?ooo`00H03oool3000006h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0J0?oo
o`800000R@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0600oooo0`00001>0?oo
o`00GP3oool200000780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0L0?ooo`80
0000R03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0B`3oool005/0oooo0`00001d0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`1:0?ooo`00F03oool3000007L0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0N0?ooo`800000QP3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool0BP3oool005H0oooo0P00001k0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0803oool2000008D0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04T0oooo001C0?ooo`<00000O@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0B03oool00500
oooo0`0000200?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool08P3oool2000008@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo04P0
oooo001>0?ooo`800000Q03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02@0oooo
0P0000220?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`170?ooo`00B`3oool3000008H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0U0?ooo`800000P@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0AP3oool004P0oooo0`00002:0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`160?ooo`00A@3oool3000000030?ooo`000000oooo
08X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0W0?ooo`800000P03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo05l0oooo0`0000170?ooo`00@`3oool2000000D0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02T0
oooo0P00001o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`140?ooo`00@03oool3000000P0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo02/0oooo0P00001m0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`140?ooo`00?@3oool3000000`0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool0N`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool02`3oool2000000@0oooo0P0000030?ooo`@000000`3oool2000002@0oooo000k
0?ooo`800000403oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0;@3oool2000007`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q
0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000002<0oooo000h0?ooo`<000004`3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0;`3oool2000007/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo00T0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0240oooo
000e0?ooo`<000005`3oool2000008H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0`0?ooo`800000N@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0640oooo00<0
00000?ooo`3oool0203oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0080oooo
0P00000T0?ooo`00<`3oool2000001`0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool01`3oool010000000oooo0?oo
o`0000080?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool08`3oool00300oooo
0`00000O0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0c0?ooo`800000N03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0203oool2000000X0oooo0P0000040?ooo`<000008`3oool002d0oooo0`00
000S0?ooo`030000003oool0oooo0880oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0d0?ooo`800000M`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0?`3oool002/0oooo0P00000W0?ooo`030000003oool0oooo0880oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0f0?ooo`800000MP3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo05l0oooo0`0000100?ooo`00:03oool3000002X0oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03P0oooo00<000000?oo
o`3oool0L`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05`0oooo0P0000030?oo
o`030000003oool0oooo03d0oooo000U0?ooo`<00000;P3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0>03oool2000007@0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03d0oooo000S0?ooo`800000
<P3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
>P3oool2000007<0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1P0?ooo`030000
003oool0oooo03`0oooo000P0?ooo`<00000=@3oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0k0?ooo`007@3oool3
000003T0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo03`0oooo0P00001a0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0k0?ooo`006`3oool2000003d0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo03h0oooo0P00001`0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0j0?ooo`00603oool300000400
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0400
oooo0P00001_0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0i0?ooo`005P3oool2000004@0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0K@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0>@3oool005d0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0480oooo0P00
001^0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?oo
o`0h0?ooo`00GP3oool2000007`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`13
0?ooo`800000K03oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo05d0oooo0P000000
0`3oool000000?ooo`0h0?ooo`00H03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0A@3oool2000006/0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`1O0?ooo`030000003oool0oooo03L0oooo001Q0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo06T0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03H0
oooo001R0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`170?ooo`800000JP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0600oooo
00<000000?ooo`3oool0=@3oool006<0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo04T0oooo0P00001Y0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0G`3oool00`000000oooo0?ooo`0e0?ooo`00I03oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0B`3oool2000006L0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo03@0oooo001U0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1O0?oo
o`030000003oool0oooo03<0oooo001V0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`1=0?ooo`800000IP3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo05l0oooo00<000000?ooo`3oool0<`3oool006L0oooo00<000000?ooo`3oool0
M@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04l0oooo0P00001U0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0b0?ooo`00J03o
ool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0GP3o
ool2000003<0oooo001Y0?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1A0?ooo`800000H`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo05/0oooo0P0000000`3oool000000?ooo`0b0?ooo`00JP3oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0D`3oool200000680oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0300oooo001[0?ooo`03
0000003oool0oooo07<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1D0?ooo`80
0000H@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3o
ool0;`3oool006`0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0;`3oool006d0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo05L0oooo0P00001O0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0^0?ooo`00KP3oool2
00000780oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1H0?ooo`800000GP3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0;@3oool0
0700oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
05X0oooo0P00001M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0]0?ooo`00L@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0/0?ooo`00LP3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0G03oool2000005/0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02/0oooo
001c0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`1N0?ooo`800000FP3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05`0oooo0`00
000]0?ooo`00M03oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0G`3oool2000005T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo02X0oooo001e0?ooo`030000003oool0oooo06`0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02T0oooo001f0?ooo`03
0000003oool0oooo06/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1R0?ooo`80
0000F03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0:03oool007L0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo06<0oooo0P00001F0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`0X0?ooo`00N03oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0W0?ooo`00N@3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0IP3oool2
000005D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo02H0oooo001j0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1W0?ooo`800000E03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
05d0oooo00<000000?ooo`3oool09P3oool007/0oooo00<000000?ooo`3oool0J03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo06T0oooo0P00001B0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0U0?ooo`00O03oool00`000000oooo
0?ooo`1X0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0G@3oool2000002H0oooo
001m0?ooo`800000J03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06/0oooo0P00
001A0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0FP3oool2000000030?ooo`00
0000oooo02D0oooo001o0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`1]0?ooo`800000D03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo05d0oooo00<000000?ooo`3oool08`3oool00800oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo06l0oooo0P00001?0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0:0?ooo`800000103oool20000
00@0oooo0P00000:0?ooo`00P@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`090?ooo`040000003oool0oooo0000
00P0oooo00@000000?ooo`3oool000002@3oool00880oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0740oooo0P00001=0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`080?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`3oool01`3oool008<0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo07<0oooo0P00001<0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo
000000T0oooo0P00000:0?ooo`00Q03oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0M03oool2000004/0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`1L0?ooo`030000003oool0oooo00L0oooo00@000000?ooo`3oool000002@3oool0
0`000000oooo0?ooo`090?ooo`00Q@3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`070?ooo`8000002P3oool30000
00T0oooo00260?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`1f0?ooo`800000B@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05/0
oooo0`00000P0?ooo`00Q`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0N03oool2000004P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`1H0?ooo`8000000P3oool00`000000oooo0?ooo`0N0?ooo`00R03oool00`000000oooo0?oo
o`1P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0NP3oool2000004L0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01d0oooo0029
0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1k
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1M
0?ooo`030000003oool0oooo01`0oooo002:0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1l0?ooo`800000A@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo05`0oooo00<000000?ooo`3oool0703oool008/0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07h0oooo0P0000140?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0K0?ooo`00
S03oool2000005h0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1L0?ooo`030000
003oool0oooo01X0oooo002>0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`200?ooo`800000@`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo05`0oooo00<000000?ooo`3oool06P3oool008l0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0880oooo0P0000110?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0I0?ooo`00T03oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0P`3oool20000
0400oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1K0?ooo`8000006P3oool00940
oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05P0
oooo0P0000000`3oool000000?ooo`0I0?ooo`00TP3oool00`000000oooo0?ooo`1I0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0QP3oool2000003l0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01L0oooo002C0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`270?ooo`800000?P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool05P3o
ool009@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo08T0oooo0P00000l0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0F0?ooo`00U@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0E0?ooo`00UP3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0R`3oool2000003/0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01@0
oooo002G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`2=0?ooo`800000>P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0503oool009P0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo08h0oooo0P00000h0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`0C0?ooo`00V@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0F03oool4000001@0oooo002J0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2A0?oo
o`800000=`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05`0oooo00<000000?oo
o`3oool04@3oool009/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo0980oooo0P00000f0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0A0?ooo`00W03oool2000005@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0100oooo002N0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2E0?ooo`800000=03o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool03`3o
ool009l0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo09H0oooo0P00000c0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0?0?ooo`00X03oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0V03oool200000380oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo00h0oooo002Q0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00d0
oooo002R0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`2J0?ooo`800000<03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool03@3oool00:<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo09`0oooo0P00000_0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0F03oool4000000h0oooo002T0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`2N0?ooo`800000;P3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool02`3oool00:D0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool02`3oool00:H0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0:00oooo0P00000]0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0:0?ooo`00Y`3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0XP3oool2000002/0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00T0oooo002X0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`2S0?ooo`800000:P3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool02@3o
ool00:T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0203oool00:X0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo0:H0oooo0P00000Y0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0I03oool00:/0oooo0P00001:0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0Y`3oool2000002L0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1T0?ooo`00[@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0Z@3oool2000002H0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1S0?ooo`00[P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0HP3oool00:l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0:/0oooo0P00000U0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0H@3oool00;00oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0:d0oooo0P00000T0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0H03oool00;40oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0600oooo002b0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`2_0?ooo`8000008P3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo05l0oooo002c0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`2a0?ooo`8000008@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo05h0oooo002d0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`2b0?ooo`800000803oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo05d0oooo002e0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`1M0?ooo`00]P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0]@3oool2000001h0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`1L0?ooo`00]`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0]P3oool2000001d0oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1K0?ooo`00^03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0^03oool2000001`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`1J0?ooo`00^@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0^P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool0FP3oool00;X0oooo0P0000100?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0^P3oool2000001X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1I0?oo
o`00_03oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0_03oool2000001T0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1H0?ooo`00
_@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
_P3oool2000001P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1G0?ooo`00_P3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E`3o
ool00;l0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0<00oooo0P00000G0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0EP3oool0
0<00oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0<80oooo0P00000E0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0E@3oool00<40
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo05@0
oooo00320?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`340?ooo`800000503oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05@0oooo
00330?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`350?ooo`8000004`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo05<0oooo0034
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`37
0?ooo`8000004@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0580oooo00350?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0l0?oo
o`8000004`3oool00<H0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0<T0oooo0P00000@0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0>03oool4000001D0oooo00370?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3;0?ooo`8000003`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo03<0oooo1000000I0?ooo`00b03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0c@3oool2000000h0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0_0?ooo`<000007@3oool00<T0oooo0P00000f0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0:P3oool400000200oooo003;0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3?0?ooo`800000303oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0oooo1000000T0?ooo`00c03oool00`000000
oooo0?ooo`0c0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0d@3oool2000000/0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0R0?ooo`<00000:03oool00<d0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0=80oooo
0P00000:0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07@3oool4000002/0oooo
003>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0H0?ooo`@00000;`3oool00<l0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0=D0oooo0P0000080?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool05@3oool3000003<0oooo003@0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`3F0?ooo`8000001`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo0100oooo1000000f0?ooo`00d@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0f03oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool4000003X0oooo003B0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3I0?ooo`800000
1P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00H0oooo1000000n0?ooo`00d`3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0fP3o
ool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`<00000@P3o
ool00=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0=`0oooo0P0000030?ooo`030000003oool0oooo0140oooo1@0000150?ooo`00e@3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0g@3oool01@00
0000oooo0?ooo`3oool0000000l0oooo1@0000180?ooo`00eP3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0gP3oool200000080oooo00<000000?oo
o`3oool02@3oool3000004d0oooo003G0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`3P0?ooo`<000001`3oool400000500oooo003H0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3Q0?ooo`800000
0P3oool4000005@0oooo003I0?ooo`800000:`3oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo0><0oooo0P00001H0?ooo`00f`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3oooln0?ooo`00g03oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00g@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolm0?ooo`00
gP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
o`3ooolm0?ooo`00g`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0o`3oooll0?ooo`00h03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00h@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oooll0?ooo`00hP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`00
h`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
o`3ooolk0?ooo`00i03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0o`3ooolk0?ooo`00i@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00iP3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00i`3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolj0?ooo`00
j03oool200000280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooocT0oooo
003Z0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3o0?ooocT0oooo003[0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`3o0?ooocP0oooo003/0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?ooocP0oooo003]0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooocP0oooo003^0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooocL0oooo
003_0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3o0?ooocL0oooo003`0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3o0?ooocL0oooo003a0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?ooocH0oooo003b0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooocH0oooo003c0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooocH0oooo
003d0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`3o0?ooocD0oooo003e0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3o0?ooocD0oooo003f0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?ooocD0oooo003g0?ooo`800000603oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo=03oool00?T0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo=03oool00?X0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo=03o
ool00?/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0?l0oooo<`3oool00?`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0?l0oooo<`3oool00?d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo<P3oool00?h0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo<P3oool00?l0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo<P3o
ool00?l0oooo0@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0o`3ooola0?ooo`00o`3oool20?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?oooc40oooo003o0?ooo`<0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo<@3oool00?l0oooo
103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
o`3oool`0?ooo`00o`3oool50?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`3o0?oooc00oooo003o0?ooo`H0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo<03oool00?l0oooo1`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oool_0?oo
o`00o`3oool80?ooo`8000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0
oooo;`3oool00?l0oooo2P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0o`3oool_0?ooo`00o`3oool;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?ooobh0oooo003o0?ooo``0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo;P3oool0
0?l0oooo3@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0o`3oool^0?ooo`00o`3oool>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`3o0?ooobd0oooo003o0?ooo`l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo;@3oool00?l0oooo403o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0o`3o
ool]0?ooo`00o`3ooolA0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3o0?ooob`0oooo003o0?oooa80oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0?l0oooo;03oool00?l0oooo4`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00
o`3ooolD0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`3o0?ooob/0oooo003o0?oooaD0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0?l0oooo:`3oool00?l0oooo5P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolZ0?ooo`00o`3ooolG0?oo
o`8000000`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo:P3oool00?l0
oooo6@3oool01@000000oooo0?ooo`3oool0000000l0oooo00<000000?ooo`3oool0o`3ooolZ0?oo
o`00o`3ooolJ0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0o`3ooolY0?oo
o`00o`3ooolK0?ooo`040000003oool0oooo000000h0oooo0P00003o0?ooob/0oooo003o0?oooa`0
oooo00<000000?ooo`0000002P3oool400000?l0oooo;@3oool00?l0oooo7@3oool2000000H0oooo
1000003o0?oooc40oooo003o0?oooah0oooo0P0000020?ooo`<00000o`3ooole0?ooo`00o`3ooolN
0?ooo`@00000o`3ooolh0?ooo`00o`3ooolJ0?ooo`@00000o`3oooll0?ooo`00o`3ooolG0?ooo`<0
0000o`3ooom00?ooo`00o`3ooolC0?ooo`@00000o`3ooom30?ooo`00o`3oool?0?ooo`@00000o`3o
oom70?ooo`00o`3oool;0?ooo`@00000o`3ooom;0?ooo`00o`3oool80?ooo`<00000o`3ooom?0?oo
o`00o`3oool40?ooo`@00000o`3ooomB0?ooo`00o`3oool400000?l0ooooEP3oool00?`0oooo0`00
003o0?oooeX0oooo003h0?ooo`@00000o`3ooomM0?ooo`00m03oool400000?l0ooooH@3oool00?80
oooo0P00003o0?ooofD0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0
ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oo
oeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0oooo
FP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {414.563, 0}} -> {-0.00346918, 0.116904, \
0.00160345, 0.00160345}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<ABCDEFGHIJKLMNOPQRSTUVWXYZ\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34571 
%%ImageSize: 600 207.426 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0517421 1.05174 -0.342426 1.05174 [
[.16183 .25043 -8.4562 -9 ]
[.16183 .25043 9.5438 0 ]
[.46313 .15296 -2.99349 -9 ]
[.46313 .15296 3.00651 0 ]
[.78732 .04812 -6.37838 -9 ]
[.78732 .04812 5.62162 0 ]
[.46158 .08778 -4.98746 -12.75 ]
[.46158 .08778 5.01254 0 ]
[.9949 .00237 0 -5.94781 ]
[.9949 .00237 24 3.05219 ]
[1.00205 .01278 0 -5.94151 ]
[1.00205 .01278 6 3.05849 ]
[1.00914 .02313 0 -5.93527 ]
[1.00914 .02313 18 3.06473 ]
[1.06386 -0.00842 0 -8.41812 ]
[1.06386 -0.00842 10 4.33188 ]
[ 0 0 0 0 ]
[ 1 .34571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00051 .31534 m
.978 0 L
s
.16104 .26355 m
.16064 .27011 L
s
[(-10)] .16183 .25043 -0.06042 1 Mshowa
.4631 .1661 m
.46309 .17268 L
s
[(0)] .46313 .15296 -0.00217 1 Mshowa
.78815 .06124 m
.78857 .0678 L
s
[(10)] .78732 .04812 .06306 1 Mshowa
.125 Mabswid
.21973 .24462 m
.21954 .24855 L
s
.27926 .22541 m
.27911 .22935 L
s
.33966 .20593 m
.33955 .20987 L
s
.40093 .18616 m
.40088 .1901 L
s
.52619 .14575 m
.52623 .14969 L
s
.59022 .1251 m
.59031 .12904 L
s
.65521 .10413 m
.65535 .10807 L
s
.72118 .08285 m
.72137 .08679 L
s
.10317 .28222 m
.10289 .28615 L
s
.04611 .30063 m
.04578 .30456 L
s
.85615 .03931 m
.85645 .04324 L
s
.9252 .01703 m
.92556 .02096 L
s
gsave
.46158 .08778 -65.9875 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.978 0 m
.99938 .03114 L
s
.98239 .0064 m
.97613 .00841 L
s
[(-0.5)] .9949 .00237 -1 .32174 Mshowa
.98953 .0168 m
.98327 .0188 L
s
[(0)] 1.00205 .01278 -1 .32034 Mshowa
.99662 .02712 m
.99035 .02912 L
s
[(0.5)] 1.00914 .02313 -1 .31895 Mshowa
.125 Mabswid
.98382 .00848 m
.98007 .00969 L
s
.98525 .01056 m
.9815 .01177 L
s
.98668 .01264 m
.98292 .01385 L
s
.9881 .01472 m
.98435 .01593 L
s
.99095 .01887 m
.98719 .02007 L
s
.99237 .02093 m
.98861 .02214 L
s
.99379 .023 m
.99003 .0242 L
s
.9952 .02506 m
.99145 .02626 L
s
.98095 .00431 m
.9772 .00552 L
s
.97952 .00222 m
.97577 .00343 L
s
.97808 .00012 m
.97433 .00133 L
s
.99803 .02918 m
.99427 .03037 L
s
gsave
1.06386 -0.00842 -61 -12.4181 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34571 L
0 .34571 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.06259 .33134 m
.05182 .30863 L
s
.06259 .33134 m
.03008 .31562 L
s
.05951 .32861 m
.05026 .30913 L
s
.08118 .32542 m
.09985 .31948 L
s
.08584 .32394 m
.06429 .30462 L
s
.08739 .32345 m
.06585 .30412 L
s
.0394 .32013 m
.05336 .31566 L
s
.09985 .31948 m
.10196 .31757 L
s
.09985 .31948 m
.10352 .31707 L
s
.10196 .31757 m
.1025 .31616 L
s
.10352 .31707 m
.10407 .31566 L
s
.02698 .31662 m
.03627 .31363 L
s
.1025 .31616 m
.10203 .31382 L
s
.10407 .31566 m
.1036 .31332 L
s
.07718 .31428 m
.08966 .31029 L
s
.10203 .31382 m
.1 .31198 L
s
.1036 .31332 m
.10156 .31148 L
s
.1 .31198 m
.0964 .31063 L
s
.12074 .31159 m
.11558 .31075 L
s
.12645 .31102 m
.12074 .31159 L
s
.10156 .31148 m
.09796 .31013 L
s
.12231 .31109 m
.11714 .31025 L
s
.12645 .31102 m
.12231 .31109 L
s
.1296 .31002 m
.12645 .31102 L
s
.11558 .31075 m
.11198 .3094 L
s
.0964 .31063 m
.09381 .31021 L
s
.04559 .31063 m
.05493 .30763 L
s
.08966 .31029 m
.09177 .30836 L
s
.08966 .31029 m
.09333 .30786 L
s
.09381 .31021 m
.08966 .31029 L
s
.09538 .30971 m
.08966 .31029 L
s
.11714 .31025 m
.11355 .3089 L
s
.09796 .31013 m
.09538 .30971 L
s
.1333 .30759 m
.1296 .31002 L
s
.11198 .3094 m
.10736 .30713 L
s
.11355 .3089 m
.10893 .30663 L
s
.09177 .30836 m
.09231 .30694 L
s
.09333 .30786 m
.09388 .30644 L
s
.13444 .30474 m
.1333 .30759 L
s
.10736 .30713 m
.10227 .3025 L
s
.13903 .30702 m
.13444 .30474 L
s
.13298 .30145 m
.13903 .30702 L
s
.09231 .30694 m
.09183 .30458 L
s
.10893 .30663 m
.10384 .302 L
s
.09388 .30644 m
.0934 .30408 L
s
.07837 .3001 m
.05961 .30613 L
s
.13444 .30474 m
.13298 .30145 L
s
.09183 .30458 m
.08876 .3018 L
s
.0934 .30408 m
.09033 .3013 L
s
.14849 .30401 m
.16431 .29897 L
s
.15323 .3025 m
.13201 .28286 L
s
.10227 .3025 m
.10077 .29921 L
s
.15481 .302 m
.1336 .28235 L
s
.10384 .302 m
.10234 .2987 L
s
.08876 .3018 m
.08513 .30045 L
s
.09033 .3013 m
.0867 .29994 L
s
.08513 .30045 m
.08254 .30002 L
s
.08254 .30002 m
.07837 .3001 L
s
.08411 .29952 m
.07837 .3001 L
s
.0867 .29994 m
.08411 .29952 L
s
.10077 .29921 m
.1003 .29684 L
s
.16431 .29897 m
.16648 .29703 L
s
.16431 .29897 m
.16806 .29653 L
s
.10234 .2987 m
.10187 .29633 L
s
.16648 .29703 m
.16765 .29416 L
s
.1003 .29684 m
.1014 .29396 L
s
.16806 .29653 m
.16924 .29365 L
s
.10187 .29633 m
.10297 .29346 L
s
.16765 .29416 m
.16724 .29178 L
s
.1014 .29396 m
.1051 .29151 L
s
.16924 .29365 m
.16882 .29127 L
s
.10297 .29346 m
.1051 .29151 L
s
.18177 .29342 m
.20731 .28529 L
s
.11922 .29077 m
.12284 .29213 L
s
.18655 .2919 m
.16549 .2721 L
s
.16724 .29178 m
.16582 .28846 L
s
.1051 .29151 m
.10826 .29049 L
s
.18814 .29139 m
.16709 .27158 L
s
.16882 .29127 m
.16741 .28795 L
s
.11402 .28991 m
.11922 .29077 L
s
.10826 .29049 m
.11402 .28991 L
s
.16582 .28846 m
.16079 .28376 L
s
.16741 .28795 m
.16238 .28325 L
s
.20136 .27964 m
.20571 .2858 L
s
.20731 .28529 m
.20136 .27964 L
s
.14314 .27928 m
.12725 .28439 L
s
.16079 .28376 m
.15617 .28145 L
s
.16238 .28325 m
.15776 .28093 L
s
.21532 .28274 m
.24107 .27455 L
s
.19175 .2827 m
.18375 .27514 L
s
.17816 .282 m
.18775 .27893 L
s
.15617 .28145 m
.15255 .28007 L
s
.22014 .28121 m
.19925 .26125 L
s
.15776 .28093 m
.15415 .27956 L
s
.22174 .2807 m
.20086 .26073 L
s
.15255 .28007 m
.14734 .2792 L
s
.15415 .27956 m
.14893 .27869 L
s
.14734 .2792 m
.14314 .27928 L
s
.14893 .27869 m
.14314 .27928 L
s
.23516 .26885 m
.23945 .27506 L
s
.24107 .27455 m
.23516 .26885 L
s
.16069 .27364 m
.18636 .26539 L
s
.22548 .27194 m
.21754 .26432 L
s
.21184 .27123 m
.22151 .26814 L
s
.19238 .27111 m
.18475 .26591 L
s
.18636 .26539 m
.19238 .27111 L
s
.25626 .26845 m
.25106 .26758 L
s
.2621 .26786 m
.25626 .26845 L
s
.25788 .26794 m
.25268 .26706 L
s
.2621 .26786 m
.25788 .26794 L
s
.26535 .26682 m
.2621 .26786 L
s
.25106 .26758 m
.24748 .26619 L
s
.25268 .26706 m
.2491 .26567 L
s
.26925 .26432 m
.26535 .26682 L
s
.24748 .26619 m
.2429 .26384 L
s
.2491 .26567 m
.24452 .26332 L
s
.27055 .26137 m
.26925 .26432 L
s
.2429 .26384 m
.23797 .25905 L
s
.2751 .26372 m
.27055 .26137 L
s
.26925 .25797 m
.2751 .26372 L
s
.24452 .26332 m
.23959 .25853 L
s
.19441 .26281 m
.20571 .25917 L
s
.27055 .26137 m
.26925 .25797 L
s
.28651 .26009 m
.29795 .25645 L
s
.23797 .25905 m
.23662 .25565 L
s
.29141 .25853 m
.27088 .23823 L
s
.23959 .25853 m
.23824 .25513 L
s
.29304 .25801 m
.27252 .2377 L
s
.23662 .25565 m
.23626 .25321 L
s
.23824 .25513 m
.23789 .25268 L
s
.25586 .25333 m
.26728 .24967 L
s
.30778 .25333 m
.31927 .24967 L
s
.23626 .25321 m
.23753 .25023 L
s
.23789 .25268 m
.23916 .24971 L
s
.26075 .25176 m
.25286 .24402 L
s
.3127 .25176 m
.29228 .23135 L
s
.26238 .25124 m
.25449 .2435 L
s
.31434 .25124 m
.29393 .23082 L
s
.23753 .25023 m
.24143 .24769 L
s
.23916 .24971 m
.24143 .24769 L
s
.28331 .24838 m
.30302 .24208 L
s
.24143 .24769 m
.24469 .24665 L
s
.32586 .24757 m
.3374 .2439 L
s
.25058 .24604 m
.25582 .24693 L
s
.24469 .24665 m
.25058 .24604 L
s
.3308 .246 m
.31048 .2255 L
s
.33245 .24548 m
.31214 .22497 L
s
.26596 .23981 m
.27746 .23612 L
s
.35064 .23969 m
.36225 .23599 L
s
.35561 .23811 m
.33929 .22144 L
s
.35727 .23758 m
.34095 .2209 L
s
.36724 .23441 m
.3789 .2307 L
s
.28733 .23294 m
.29889 .22923 L
s
.37223 .23282 m
.35213 .21212 L
s
.3739 .23229 m
.3538 .21158 L
s
.38892 .22751 m
.39896 .22431 L
s
.30551 .2271 m
.31711 .22337 L
s
.33124 .22661 m
.33193 .22509 L
s
.32861 .22616 m
.33124 .22661 L
s
.32667 .22419 m
.32861 .22616 L
s
.39561 .22538 m
.36149 .21951 L
s
.33193 .22509 m
.3293 .22464 L
s
.3264 .22169 m
.32667 .22419 L
s
.40567 .22218 m
.41744 .21844 L
s
.32875 .21963 m
.3264 .22169 L
s
.33929 .22144 m
.33472 .21901 L
s
.37201 .22132 m
.37395 .2051 L
s
.34095 .2209 m
.33639 .21848 L
s
.37368 .22078 m
.37563 .20456 L
s
.41071 .22058 m
.39081 .19969 L
s
.41239 .22004 m
.3925 .19914 L
s
.33208 .21856 m
.32875 .21963 L
s
.33472 .21901 m
.33208 .21856 L
s
.33639 .21848 m
.33208 .21856 L
s
.34711 .21373 m
.35883 .20996 L
s
.43599 .21253 m
.44276 .21038 L
s
.44107 .21092 m
.43326 .18604 L
s
.44107 .21092 m
.42133 .18988 L
s
.44276 .21038 m
.43609 .18908 L
s
.3689 .20673 m
.379 .20348 L
s
.46483 .20336 m
.47164 .20119 L
s
.46483 .20336 m
.44522 .1822 L
s
.46483 .20336 m
.43326 .18604 L
s
.46653 .20281 m
.44694 .18165 L
s
.38574 .20131 m
.41113 .19315 L
s
.41682 .19918 m
.40944 .1937 L
s
.41113 .19315 m
.41682 .19918 L
s
.47847 .19902 m
.4853 .19684 L
s
.48359 .19739 m
.46409 .17613 L
s
.4853 .19684 m
.48835 .17098 L
s
.48346 .19483 m
.48649 .16893 L
s
.50072 .19194 m
.51103 .18866 L
s
.41623 .19152 m
.42644 .18823 L
s
.50587 .1903 m
.48649 .16893 L
s
.44009 .18385 m
.45207 .18 L
s
.52563 .1827 m
.52036 .18177 L
s
.53173 .18207 m
.52563 .1827 L
s
.52736 .18215 m
.52208 .18122 L
s
.53173 .18207 m
.52736 .18215 L
s
.53519 .18097 m
.53173 .18207 L
s
.52036 .18177 m
.5168 .18029 L
s
.52208 .18122 m
.51853 .17974 L
s
.53774 .17885 m
.53519 .18097 L
s
.53947 .1783 m
.53519 .18097 L
s
.5168 .18029 m
.51141 .17677 L
s
.51853 .17974 m
.51314 .17622 L
s
.53939 .17571 m
.53774 .17885 L
s
.54113 .17516 m
.53947 .1783 L
s
.45894 .17779 m
.46925 .17448 L
s
.51141 .17677 m
.50865 .17371 L
s
.51314 .17622 m
.51038 .17316 L
s
.53931 .17311 m
.53939 .17571 L
s
.54105 .17256 m
.54113 .17516 L
s
.556 .17435 m
.57691 .16769 L
s
.50865 .17371 m
.5067 .16906 L
s
.51038 .17316 m
.50843 .16851 L
s
.53741 .16846 m
.53931 .17311 L
s
.56122 .17269 m
.54215 .15105 L
s
.53915 .16791 m
.54105 .17256 L
s
.56296 .17213 m
.5439 .15048 L
s
.5067 .16906 m
.50658 .16645 L
s
.50843 .16851 m
.50832 .1659 L
s
.53467 .16538 m
.53741 .16846 L
s
.53641 .16483 m
.53915 .16791 L
s
.57691 .16769 m
.57951 .16555 L
s
.57691 .16769 m
.58126 .165 L
s
.50658 .16645 m
.5082 .16328 L
s
.50832 .1659 m
.50994 .16273 L
s
.57951 .16555 m
.58036 .16397 L
s
.52927 .16182 m
.53467 .16538 L
s
.58126 .165 m
.58211 .16341 L
s
.53101 .16127 m
.53641 .16483 L
s
.58036 .16397 m
.58032 .16135 L
s
.58211 .16341 m
.58207 .16079 L
s
.5082 .16328 m
.51249 .16058 L
s
.50994 .16273 m
.51249 .16058 L
s
.52569 .16032 m
.52927 .16182 L
s
.58032 .16135 m
.57763 .15826 L
s
.52744 .15976 m
.53101 .16127 L
s
.56701 .15636 m
.55301 .16084 L
s
.58207 .16079 m
.57938 .1577 L
s
.51249 .16058 m
.51597 .15946 L
s
.52037 .15937 m
.52569 .16032 L
s
.52211 .15881 m
.52744 .15976 L
s
.51597 .15946 m
.52037 .15937 L
s
.51597 .15946 m
.52211 .15881 L
s
.60231 .1583 m
.59701 .15735 L
s
.60847 .15765 m
.60231 .1583 L
s
.57763 .15826 m
.57407 .15675 L
s
.60407 .15774 m
.59877 .15679 L
s
.60847 .15765 m
.60407 .15774 L
s
.57938 .1577 m
.57582 .15619 L
s
.61199 .15653 m
.60847 .15765 L
s
.59701 .15735 m
.59346 .15584 L
s
.59877 .15679 m
.59522 .15528 L
s
.57407 .15675 m
.57142 .15627 L
s
.61463 .15438 m
.61199 .15653 L
s
.61639 .15381 m
.61199 .15653 L
s
.57142 .15627 m
.56701 .15636 L
s
.57317 .15571 m
.56701 .15636 L
s
.57582 .15619 m
.57317 .15571 L
s
.59346 .15584 m
.58812 .15226 L
s
.59522 .15528 m
.58988 .1517 L
s
.61638 .15118 m
.61463 .15438 L
s
.61815 .15061 m
.61639 .15381 L
s
.5369 .15273 m
.54916 .14879 L
s
.58812 .15226 m
.58542 .14914 L
s
.58988 .1517 m
.58719 .14858 L
s
.61638 .14853 m
.61638 .15118 L
s
.61814 .14797 m
.61815 .15061 L
s
.63318 .14979 m
.65447 .14302 L
s
.58542 .14914 m
.58358 .14441 L
s
.58719 .14858 m
.58535 .14384 L
s
.61459 .1438 m
.61638 .14853 L
s
.63849 .1481 m
.61986 .12607 L
s
.61636 .14324 m
.61814 .14797 L
s
.64026 .14754 m
.62165 .1255 L
s
.58358 .14441 m
.58354 .14175 L
s
.58535 .14384 m
.58531 .14119 L
s
.61191 .14067 m
.61459 .1438 L
s
.61368 .1401 m
.61636 .14324 L
s
.65447 .14302 m
.65715 .14084 L
s
.65447 .14302 m
.65893 .14027 L
s
.59064 .14215 m
.59507 .14206 L
s
.58707 .14062 m
.59064 .14215 L
s
.59507 .14206 m
.59684 .14149 L
s
.58354 .14175 m
.58527 .13853 L
s
.59684 .14149 m
.59948 .13931 L
s
.58531 .14119 m
.58704 .13796 L
s
.65715 .14084 m
.65806 .13923 L
s
.60657 .13704 m
.61191 .14067 L
s
.58617 .13957 m
.58707 .14062 L
s
.65893 .14027 m
.65984 .13866 L
s
.60834 .13647 m
.61368 .1401 L
s
.59948 .13931 m
.59946 .13665 L
s
.65806 .13923 m
.65809 .13656 L
s
.65984 .13866 m
.65987 .13599 L
s
.58527 .13853 m
.58967 .13577 L
s
.58704 .13796 m
.58967 .13577 L
s
.64568 .13253 m
.63144 .13709 L
s
.603 .13551 m
.60657 .13704 L
s
.59946 .13665 m
.59763 .13187 L
s
.59946 .13665 m
.59493 .12871 L
s
.65809 .13656 m
.65633 .13446 L
s
.60477 .13494 m
.60834 .13647 L
s
.65987 .13599 m
.65812 .13389 L
s
.58967 .13577 m
.59321 .13464 L
s
.59766 .13455 m
.603 .13551 L
s
.59943 .13398 m
.60477 .13494 L
s
.59321 .13464 m
.59766 .13455 L
s
.59321 .13464 m
.59943 .13398 L
s
.67678 .13459 m
.67146 .13363 L
s
.68302 .13393 m
.67678 .13459 L
s
.65633 .13446 m
.65279 .13293 L
s
.64033 .13424 m
.64301 .13205 L
s
.68839 .13222 m
.68302 .13393 L
s
.65812 .13389 m
.65458 .13236 L
s
.67146 .13363 m
.66972 .13152 L
s
.65279 .13293 m
.65013 .13244 L
s
.65013 .13244 m
.64568 .13253 L
s
.65191 .13187 m
.64568 .13253 L
s
.65458 .13236 m
.65191 .13187 L
s
.6929 .12946 m
.68839 .13222 L
s
.64301 .13205 m
.64303 .12937 L
s
.64301 .13205 m
.64391 .13043 L
s
.59763 .13187 m
.5976 .12919 L
s
.66972 .13152 m
.67155 .12827 L
s
.66972 .13152 m
.66976 .12884 L
s
.64391 .13043 m
.64308 .1213 L
s
.69477 .1262 m
.6929 .12946 L
s
.64303 .12937 m
.6404 .12082 L
s
.5976 .12919 m
.59848 .12757 L
s
.66976 .12884 m
.67067 .12722 L
s
.69916 .1288 m
.69396 .12245 L
s
.69477 .1262 m
.69916 .1288 L
s
.59493 .12871 m
.5958 .12708 L
s
.60293 .12748 m
.60383 .12854 L
s
.67155 .12827 m
.67426 .12607 L
s
.61452 .12779 m
.627 .12378 L
s
.59848 .12757 m
.60025 .127 L
s
.60025 .127 m
.60293 .12748 L
s
.59935 .12594 m
.60293 .12748 L
s
.67067 .12722 m
.67339 .12501 L
s
.5958 .12708 m
.59935 .12594 L
s
.69396 .12245 m
.69477 .1262 L
s
.67426 .12607 m
.68329 .12051 L
s
.70815 .12594 m
.73524 .11732 L
s
.70297 .11958 m
.70815 .12594 L
s
.70995 .12537 m
.70297 .11958 L
s
.67339 .12501 m
.68242 .11945 L
s
.72077 .12192 m
.70262 .09947 L
s
.72257 .12135 m
.70444 .09889 L
s
.64308 .1213 m
.64398 .11967 L
s
.66095 .12095 m
.65565 .11457 L
s
.6601 .11719 m
.66095 .12095 L
s
.6404 .12082 m
.6413 .11918 L
s
.64845 .11958 m
.64934 .12064 L
s
.68329 .12051 m
.68602 .11829 L
s
.64398 .11967 m
.64577 .11909 L
s
.64489 .11803 m
.64845 .11958 L
s
.64577 .11909 m
.64845 .11958 L
s
.68242 .11945 m
.68515 .11723 L
s
.6413 .11918 m
.64489 .11803 L
s
.68602 .11829 m
.68695 .11665 L
s
.73011 .11092 m
.73343 .1179 L
s
.73524 .11732 m
.73011 .11092 L
s
.68515 .11723 m
.68701 .11395 L
s
.65565 .11457 m
.6601 .11719 L
s
.66193 .1139 m
.6601 .11719 L
s
.68695 .11665 m
.68701 .11395 L
s
.74249 .11501 m
.75521 .11096 L
s
.68701 .11395 m
.68351 .10967 L
s
.66645 .1111 m
.66193 .1139 L
s
.74794 .11328 m
.73512 .09718 L
s
.74975 .1127 m
.73694 .0966 L
s
.67186 .10936 m
.66645 .1111 L
s
.68351 .10967 m
.67815 .10869 L
s
.67815 .10869 m
.67186 .10936 L
s
.76796 .10691 m
.77893 .10342 L
s
.76074 .08897 m
.77344 .10516 L
s
.78442 .10167 m
.79542 .09817 L
s
.69718 .10122 m
.70989 .09714 L
s
.78808 .1005 m
.78327 .07355 L
s
.78992 .09992 m
.78581 .07684 L
s
.73512 .09718 m
.73437 .09335 L
s
.73694 .0966 m
.73619 .09277 L
s
.80645 .09466 m
.81751 .09114 L
s
.73437 .09335 m
.7363 .09001 L
s
.73619 .09277 m
.73813 .08942 L
s
.81382 .09232 m
.78327 .07355 L
s
.7363 .09001 m
.74093 .08716 L
s
.82121 .08997 m
.83415 .08585 L
s
.73813 .08942 m
.74093 .08716 L
s
.75634 .0863 m
.76074 .08897 L
s
.82675 .0882 m
.81669 .06281 L
s
.8286 .08761 m
.82088 .06833 L
s
.74093 .08716 m
.7446 .08598 L
s
.75096 .0853 m
.75634 .0863 L
s
.7446 .08598 m
.75096 .0853 L
s
.84157 .08349 m
.83163 .05801 L
s
.84157 .08349 m
.81669 .06281 L
s
.84342 .0829 m
.83579 .06355 L
s
.85086 .08053 m
.86202 .07698 L
s
.85644 .07876 m
.83163 .05801 L
s
.86575 .07579 m
.87696 .07223 L
s
.86949 .0746 m
.87673 .04352 L
s
.87135 .07401 m
.87862 .04291 L
s
.8882 .06865 m
.89946 .06507 L
s
.8957 .06626 m
.85224 .05139 L
s
.90322 .06387 m
.91452 .06028 L
s
.90698 .06267 m
.91135 .04622 L
s
.90887 .06207 m
.91325 .04562 L
s
.92774 .05607 m
.9391 .05245 L
s
.93531 .05366 m
.91325 .04562 L
s
.84849 .05259 m
.85977 .04897 L
s
.9467 .05004 m
.97337 .04155 L
s
.94194 .04333 m
.9467 .05004 L
s
.9486 .04943 m
.94194 .04333 L
s
.91135 .04622 m
.90326 .03499 L
s
.91325 .04562 m
.90516 .03438 L
s
.87107 .04534 m
.8824 .04169 L
s
.97146 .04216 m
.92994 .02642 L
s
.97337 .04155 m
.93185 .0258 L
s
.89756 .03682 m
.91086 .03255 L
s
.92994 .02642 m
.95678 .01779 L
s
.96155 .02462 m
.95486 .01841 L
s
.95678 .01779 m
.96155 .02462 L
s
0 g
.25 Mabswid
.00051 .31534 m
.978 0 L
s
.16104 .26355 m
.16064 .27011 L
s
[(-10)] .16183 .25043 -0.06042 1 Mshowa
.4631 .1661 m
.46309 .17268 L
s
[(0)] .46313 .15296 -0.00217 1 Mshowa
.78815 .06124 m
.78857 .0678 L
s
[(10)] .78732 .04812 .06306 1 Mshowa
.125 Mabswid
.21973 .24462 m
.21954 .24855 L
s
.27926 .22541 m
.27911 .22935 L
s
.33966 .20593 m
.33955 .20987 L
s
.40093 .18616 m
.40088 .1901 L
s
.52619 .14575 m
.52623 .14969 L
s
.59022 .1251 m
.59031 .12904 L
s
.65521 .10413 m
.65535 .10807 L
s
.72118 .08285 m
.72137 .08679 L
s
.10317 .28222 m
.10289 .28615 L
s
.04611 .30063 m
.04578 .30456 L
s
.85615 .03931 m
.85645 .04324 L
s
.9252 .01703 m
.92556 .02096 L
s
gsave
.46158 .08778 -65.9875 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 207.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cb000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooD@3oool2000000L0oooo003o0?ooool0ooooDP3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooooo0?oooe<0oooo00<000000?ooo`3oool0103oool00?l0ooooo`3ooomB0?ooo`03
0000003oool0000000D0oooo003o0?ooool0ooooD@3oool010000000oooo0?ooo`0000050?ooo`00
o`3ooooo0?oooe00oooo0`0000000`3oool00000000000040?ooo`00o`3ooooo0?oooeX0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo0P00000L0?oo
o`00o`3ooooo0?ooobl0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000K
0?ooo`00o`3ooooo0?oooah0oooo0P00000?0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool06@3oool00?l0ooooo`3ooolK0?ooo`@0000000<0oooo0000003oool01`3oool40000
0080oooo00@000000?ooo`3oool000002@3oool2000001`0oooo003o0?ooool0oooo603oool30000
00<0oooo0`00000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool06`3oool0
0?l0ooooo`3ooolE0?ooo`<000001`3oool3000000`0oooo1000000:0?ooo`<000006`3oool00?l0
ooooo`3ooolB0?ooo`<000002`3oool3000000X0oooo00@000000?ooo`3oool00000:@3oool00?l0
ooooo`3oool>0?ooo`@00000303oool200000080oooo0P0000090?ooo`040000003oool0oooo0000
02T0oooo003o0?ooool0oooo2`3oool300000180oooo0P0000000`3oool000000?ooo`080?ooo`04
0000003oool0oooo000002T0oooo003o0?ooool0oooo203oool3000001H0oooo0P0000000`3oool0
00000?ooo`070?ooo`040000003oool0oooo000002T0oooo003o0?ooool0oooo1@3oool3000001X0
oooo100000080?ooo`800000:P3oool00?l0ooooo`3oool20?ooo`<000007@3oool2000000030?oo
o`000000oooo00/0oooo0P0000040?ooo`800000103oool2000001X0oooo003o0?ooooh0oooo1000
000?0?ooo`8000003`3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000
203oool010000000oooo0?ooo`00000I0?ooo`00o`3ooook0?ooo`<000000`3oool00`000000oooo
0?ooo`0:0?ooo`<0000000<0oooo0000000000003@3oool00`000000oooo00000003000000T0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`0G0?ooo`00o`3ooooh0?ooo`<00000
1P3oool00`000000oooo0?ooo`070?ooo`<000001@3oool00`000000oooo0?ooo`0>0?ooo`<00000
2@3oool010000000oooo0?ooo`0000090?ooo`8000006P3oool00?l0oooom@3oool300000100oooo
0`0000090?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool01P3oool010000000oooo
0?ooo`0000090?ooo`030000003oool0oooo01T0oooo003o0?oooo80oooo0`00000?0?ooo`@00000
3@3oool00`000000oooo0?ooo`0=0?ooo`@00000203oool2000000X0oooo0`00000I0?ooo`00o`3o
ooo_0?ooo`<000004@3oool2000000030?ooo`000000000001d0oooo1@00000_0?ooo`00o`3oooo[
0?ooo`@000005P3oool6000001X0oooo0P0000020?ooo`030000003oool0oooo02d0oooo003o0?oo
onP0oooo0`00000M0?ooo`D000006P3oool2000000030?ooo`000000oooo02d0oooo003o0?ooonD0
oooo0`00000@0?ooo`8000004@3oool5000004T0oooo003o0?ooojl0oooo1@0000020?ooo`800000
:P3oool300000140oooo0P00000F0?ooo`D00000AP3oool00?l0oooo/@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0903oool300000140oooo0`0000000`3oool00000
0?ooo`0G0?ooo`D00000A03oool00?l0oooo/@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool08@3oool300000180oooo0P0000030?ooo`8000006`3oool500000440oooo
003o0?oook40oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo
0`00000J0?ooo`030000003oool0000001d0oooo1000000o0?ooo`00o`3ooona0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0K0?ooo`<000000P3oool00`000000oooo
0?ooo`0:0?ooo`8000003@3oool00`000000oooo0000000O0?ooo`<00000?@3oool00?l0oooo/03o
ool2000000@0oooo0P00000K0?ooo`<000001@3oool00`000000oooo0?ooo`070?ooo`<00000403o
ool200000100oooo00<000000?ooo`3oool02P3oool3000003l0oooo003o0?ooom00oooo0`00000@
0?ooo`80000000<0oooo000000000000403oool010000000oooo00000000000?0?ooo`030000003o
ool0oooo00L0oooo0P0000120?ooo`00o`3oooo=0?ooo`<000005P3oool200000140oooo0P000000
0`3oool000000000000=0?ooo`8000001@3oool3000004@0oooo003o0?ooolT0oooo1000000?0?oo
o`8000001`3oool200000180oooo0P0000030?ooo`800000303oool2000000040?ooo`0000000000
000004L0oooo003o0?ooolH0oooo0`00000?0?ooo`@000002@3oool200000180oooo00<000000?oo
o`3oool0103oool3000000X0oooo0P00001:0?ooo`00o`3oooo30?ooo`<00000403oool4000000/0
oooo0P00000A0?ooo`8000002@3oool200000080oooo0P00001@0?ooo`00o`3oooo00?ooo`<00000
5`3oool3000000P0oooo0P00000A0?ooo`8000002P3oool300000580oooo003o0?oookd0oooo0`00
000M0?ooo`<00000103oool200000180oooo0P0000080?ooo`800000E@3oool00?l0oooo^P3oool3
00000100oooo00<000000?ooo`3oool0403oool3000000030?ooo`00000000000180oooo0P00001O
0?ooo`00o`3ooong0?ooo`<000004`3oool2000001@0oooo0`00000A0?ooo`800000H03oool00?l0
oooo]03oool3000001L0oooo0P00000D0?ooo`D000003P3oool2000000030?ooo`000000000005d0
oooo003o0?oook40oooo0`0000000`3oool000000?ooo`0>0?ooo`030000003oool0oooo00H0oooo
1000000A0?ooo`800000103oool3000000/0oooo0`00001O0?ooo`00o`3ooon^0?ooo`<00000103o
ool00`000000oooo0?ooo`0=0?ooo`8000001`3oool200000080oooo00<000000?ooo`3oool03P3o
ool2000000L0oooo0`0000020?ooo`8000000P3oool200000680oooo003o0?oooj/0oooo0`000007
0?ooo`030000003oool0oooo00h0oooo0P0000070?ooo`8000000P3oool00`000000oooo0?ooo`0=
0?ooo`8000002@3oool3000006P0oooo003o0?ooojL0oooo1000000:0?ooo`030000003oool0oooo
00h0oooo100000050?ooo`8000000`3oool00`000000oooo0?ooo`0<0?ooo`8000001`3oool20000
06/0oooo003o0?oooj@0oooo0`00000O0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`80
0000103oool00`000000oooo0?ooo`0:0?ooo`800000M@3oool00?l0ooooX@3oool3000002<0oooo
0P0000020?ooo`030000003oool0oooo0080oooo0P0000040?ooo`030000003oool0oooo00T0oooo
0P0000000`3oool000000000001b0?ooo`00o03oool2000000030?ooo`000000000009`0oooo0`00
000A0?ooo`030000003oool0oooo0180oooo0P0000030?ooo`040000003oool0oooo0?ooo`800000
1@3oool2000000T0oooo0`00001d0?ooo`00o@3oool00`000000oooo0000002J0?ooo`<00000503o
ool300000180oooo0P0000040?ooo`040000003oool0oooo0?ooo`8000001P3oool00`000000oooo
0?ooo`040?ooo`800000M`3oool00?h0oooo00<000000?ooo`3oool0UP3oool3000001L0oooo00<0
00000?ooo`0000000P00000A0?ooo`800000103oool2000000030?ooo`000000000000L0oooo00<0
00000?ooo`3oool00P00001j0?ooo`00o03oool2000000030?ooo`000000000009<0oooo0`00000K
0?ooo`8000000P3oool00`000000oooo0?ooo`0>0?ooo`8000001P3oool3000000L0oooo0`00001l
0?ooo`00o`3ooonB0?ooo`<000007P3oool2000000<0oooo0P00000?0?ooo`8000001P3oool30000
00@0oooo0P00001o0?ooo`00o`3ooon?0?ooo`<000008@3oool2000000D0oooo0P00000=0?ooo`80
00001`3oool2000008D0oooo003o0?oooh`0oooo0`0000000`3oool000000?ooo`0=0?ooo`<00000
4@3oool00`000000oooo000000060?ooo`8000002`3oool2000008h0oooo003o0?ooohT0oooo0`00
00040?ooo`030000003oool0oooo00P0oooo100000030?ooo`<000003P3oool00`000000oooo0000
00080?ooo`030000003oool0oooo00T0oooo0P0000000`3oool000000000002:0?ooo`00o`3ooon5
0?ooo`@00000403oool2000000X0oooo0P00000=0?ooo`8000002@3oool2000000P0oooo1000002<
0?ooo`00o`3ooon20?ooo`<000004`3oool2000000d0oooo00<000000?ooo`3oool02P3oool20000
00/0oooo0P0000040?ooo`800000T03oool00?l0ooooO`3oool3000001D0oooo0P00000?0?ooo`03
0000003oool0oooo00T0oooo0P00000=0?ooo`<00000T`3oool00?l0ooooO03oool3000001P0oooo
0P00000?0?ooo`030000003oool0oooo00T0oooo0P00000;0?ooo`<00000U@3oool00?l0ooooN@3o
ool3000001/0oooo0P00000@0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`000000203o
ool2000009P0oooo003o0?ooogH0oooo0`00000@0?ooo`800000303oool00`000000oooo0000000@
0?ooo`030000003oool0oooo00P0oooo0P00002R0?ooo`00o`3ooomc0?ooo`<000003`3oool40000
00l0oooo00<000000?ooo`000000403oool00`000000oooo0?ooo`070?ooo`D00000W`3oool00?l0
ooooL03oool3000000l0oooo0`0000020?ooo`800000403oool00`000000oooo0000000?0?ooo`03
0000003oool0oooo00D0oooo1000002R0?ooo`00o`3ooom]0?ooo`<00000603oool200000100oooo
0P00000@0?ooo`030000003oool0oooo00800000Z03oool00?l0ooooJP3oool3000001/0oooo0P00
000A0?ooo`8000003`3oool300000:X0oooo003o0?ooofL0oooo0`0000000`3oool000000?ooo`0L
0?ooo`800000403oool00`000000oooo0000000<0?ooo`800000[@3oool00?l0ooooH`3oool40000
00@0oooo00<000000?ooo`3oool02@3oool300000100oooo0P00000@0?ooo`030000003oool00000
0;X0oooo003o0?ooof00oooo0`00000@0?ooo`@000000`3oool2000000l0oooo0P00000@0?ooo`80
0000^P3oool00?l0ooooG@3oool300000140oooo0P0000090?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`8000000P3oool200000;D0oooo
003o0?oooeX0oooo0`00000B0?ooo`800000303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000L0oooo00<000000?ooo`3oool01@3oool400000;L0oooo003o0?oooeL0oooo0`00000A
0?ooo`80000000<0oooo0000003oool0303oool2000000l0oooo0P0000070?ooo`800000103oool2
00000;/0oooo003o0?oooe@0oooo0`00000?0?ooo`030000003oool0oooo00<0oooo0`00000=0?oo
o`800000403oool2000000L0oooo0P0000300?ooo`00o`3ooomA0?ooo`<00000403oool5000000@0
oooo0P00000;0?ooo`<000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<0
oooo0`0000320?ooo`00o`3ooom>0?ooo`<000004P3oool00`000000oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool2000000030?ooo`000000oooo00X0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0000000200000<D0oooo003o0?oood/0oooo0`00
000E0?ooo`030000003oool000000100oooo0P0000000`3oool00000000000060?ooo`030000003o
ool0oooo00<0oooo0P0000050?ooo`<00000b03oool00?l0ooooA`3oool400000100oooo0P000007
0?ooo`8000003`3oool010000000oooo0000000000080?ooo`8000001@3oool2000000040?ooo`00
0000000000000</0oooo003o0?ooodD0oooo0`0000040?ooo`8000002@3oool4000000T0oooo0P00
000>0?ooo`030000003oool0000000X0oooo0`0000050?ooo`800000cP3oool00?l0oooo@@3oool4
00000080oooo00<000000?ooo`3oool01P0000050?ooo`8000000P3oool2000000X0oooo00<00000
0?ooo`3oool02`3oool3000000X0oooo00<000000?ooo`3oool00P00003D0?ooo`00o`3oooln0?oo
o`<000001P3oool00`000000oooo0?ooo`02000000h0oooo0P0000090?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3F0?ooo`00o`3ooolk0?ooo`<0
00003@3oool00`000000oooo0?ooo`0<0?ooo`8000002@3oool00`000000oooo0?ooo`04000000L0
oooo00<000000?ooo`3oool01`3oool300000=T0oooo003o0?ooocP0oooo0`00000@0?ooo`<00000
3@3oool2000000H0oooo1@000000103oool000000000003oool2000000H0oooo0P0000040?ooo`<0
0000g03oool00?l0oooo=@3oool3000000l0oooo2@00000<0?ooo`8000000`3oool4000000H0oooo
0P0000000`3oool000000?ooo`060?ooo`@00000g`3oool00?l0oooo<P3oool300000140oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`03000000/0oooo1000000<0?ooo`800000jP3o
ool00?l0oooo0P00000]0?ooo`<000004`3oool2000000D0oooo00<000000?ooo`3oool00P3oool3
000000X0oooo0P00000=0?ooo`800000jP3oool00?h0oooo00@000000?ooo`3oool00000:@3oool3
000001D0oooo0`0000040?ooo`030000003oool0oooo00D0oooo0P00000:0?ooo`8000002`3oool2
00000>/0oooo003n0?ooo`040000003oool0oooo000002H0oooo0`00000H0?ooo`80000000<0oooo
0000000000000P0000090?ooo`<00000203oool2000000T0oooo0`00003/0?ooo`00oP3oool01000
0000oooo0?ooo`00000S0?ooo`<000006`3oool2000000l0oooo0P0000090?ooo`8000001@3oool3
00000>l0oooo003n0?ooo`040000003oool0oooo00000200oooo0`00000N0?ooo`8000003`3oool0
0`000000oooo000000090?ooo`80000000@0oooo0000000000000000lP3oool00?l0oooo0P00000M
0?ooo`@0000000<0oooo0000003oool07`3oool2000000l0oooo0P0000090?ooo`<00000m@3oool0
0?l0oooo703oool3000000D0oooo00<000000?ooo`3oool01`3oool010000000oooo00000000000C
0?ooo`8000003`3oool2000000L0oooo0P00003h0?ooo`00o`3ooolI0?ooo`<00000403oool40000
01H0oooo0P00000>0?ooo`800000o`3oool20?ooo`00o`3ooolF0?ooo`<000004@3oool200000080
oooo00<000000?ooo`0000005P3oool3000000/0oooo0P00003o0?ooo`<0oooo003o0?oooa<0oooo
0`00000I0?ooo`800000303oool2000000X0oooo0P0000090?ooo`800000o`3oool40?ooo`00o`3o
ool@0?ooo`<00000703oool00`000000oooo000000070?ooo`T00000203oool;00000?l0oooo1@3o
ool00?l0oooo3@3oool3000000h0oooo1P00000<0?ooo`030000003oool000000080oooo10000006
0?ooo`80000000<0oooo0000003oool02@3oool300000?l0oooo2P3oool00?l0oooo2P3oool30000
00l0oooo0P0000050?ooo`@000002P3oool010000000oooo00000000000<0?ooo`<00000o`3ooolF
0?ooo`00o`3oool70?ooo`<000004@3oool00`000000oooo0?ooo`070?ooo`@000002@3oool00`00
0000oooo0000000=0?ooo`800000o`3ooolF0?ooo`00o`3oool40?ooo`<000004`3oool00`000000
oooo0?ooo`0:0?ooo`<000002@3oool00`000000oooo0000000<0?ooo`800000o`3ooolF0?ooo`00
o`3oool10?ooo`<000005@3oool2000000h0oooo0P0000090?ooo`8000002`3oool200000?l0oooo
5`3oool00?`0oooo1@00000G0?ooo`8000003`3oool2000000P0oooo00<000000?ooo`000000203o
ool300000?l0oooo603oool00?T0oooo0`0000040?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool0203oool2000000l0oooo0P0000090?ooo`030000003oool0000000@0oooo0`00003o
0?oooa/0oooo003f0?ooo`<000001`3oool00`000000oooo0?ooo`0:0?ooo`8000002@3oool00`00
0000oooo0000000?0?ooo`8000002@3oool00`000000oooo0000000300000?l0oooo7P3oool00?<0
oooo0`00000:0?ooo`030000003oool0oooo00X0oooo0`0000090?ooo`8000003`3oool2000000T0
oooo0`00003o0?ooob40oooo003`0?ooo`<000003`3oool2000000T0oooo0P0000000`3oool00000
0?ooo`080?ooo`8000003P3oool2000000L0oooo0P00003o0?ooob@0oooo003]0?ooo`<00000403o
ool2000000X0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`800000303o
ool200000?l0oooo;P3oool00>X0oooo0`00000A0?ooo`80000000<0oooo0000003oool02@3oool2
000000@0oooo00<000000?ooo`3oool01`3oool3000000X0oooo0P00003o0?ooobh0oooo003W0?oo
o`<000003`3oool2000000L0oooo00<000000?ooo`3oool01`3oool2000000@0oooo00<000000?oo
o`3oool02@3oool4000000H0oooo0P00003o0?ooobl0oooo003T0?ooo`<000003P3oool4000000X0
oooo00<000000?ooo`3oool01P3oool2000000D0oooo00<000000?ooo`3oool02@3oool900000?l0
oooo<@3oool00>40oooo0`00000?0?ooo`8000000P3oool2000000/0oooo00<000000?ooo`3oool0
1@3oool2000000H0oooo00<000000?ooo`3oool0o`3ooom20?ooo`00g@3oool4000000h0oooo00<0
00000?ooo`3oool01P3oool2000000/0oooo00<000000?ooo`3oool0103oool2000000L0oooo00<0
00000?ooo`3oool0o`3ooom10?ooo`00fP3oool4000000d0oooo0P0000020?ooo`<000001`3oool2
000000/0oooo00<000000?ooo`3oool00`3oool2000000P0oooo00<000000?ooo`3oool0o`3ooom0
0?ooo`00e`3oool3000000<0oooo00<000000?ooo`3oool0203oool3000000D0oooo100000060?oo
o`8000002`3oool01`000000oooo0?ooo`3oool000000?ooo`0000002@3oool400000?l0oooo?P3o
ool00=@0oooo0`00000?0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`8000000P3oool2
000000D0oooo0P00000;0?ooo`030000003oool0oooo00800000203oool400000?l0oooo@03oool0
0=40oooo0`00000>0?ooo`8000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool00000
00<0oooo0P0000030?ooo`030000003oool0000000/0oooo00@000000?ooo`0000000000o`3ooom<
0?ooo`00cP3oool3000000h0oooo0`0000000`3oool00000000000070?ooo`030000003oool0oooo
0080oooo0P0000050?ooo`070000003oool0oooo0?ooo`000000oooo0000000;0?ooo`<00000o`3o
oom<0?ooo`00b`3oool3000000l0oooo0P0000050?ooo`8000001`3oool010000000oooo0?ooo`3o
ool2000000H0oooo0P0000020?ooo`030000003oool0000000/0oooo0P00003o0?oood`0oooo0038
0?ooo`<000003P3oool4000000T0oooo00<000000?ooo`3oool01@3oool01P000000oooo0?ooo`00
0000oooo000000L0oooo0P000000103oool000000?ooo`0000070?ooo`<00000o`3ooom>0?ooo`00
a@3oool3000000l0oooo1000000C0?ooo`040000003oool0oooo0?ooo`8000002@3oool300000003
0?ooo`000000oooo0?l0ooooEP3oool00<80oooo0`00000@0?ooo`8000000P3oool00`000000oooo
0000000C0?ooo`030000003oool0oooo008000002`3oool2000000030?ooo`000000oooo00800000
o`3ooomC0?ooo`00_`3oool3000000d0oooo0`0000080?ooo`030000003oool0000001<0oooo00<0
00000?ooo`3oool00P00000<0?ooo`<00000o`3ooomE0?ooo`00_03oool3000000l0oooo0P00000;
0?ooo`030000003oool0000001<0oooo00@000000?ooo`0000000000o`3ooomT0?ooo`00^03oool4
00000100oooo0P0000000`3oool000000?ooo`0;0?ooo`030000003oool0000001<0oooo0`00003o
0?ooof@0oooo002e0?ooo`<000000`3oool00`000000oooo0?ooo`070?ooo`800000203oool00`00
0000oooo0?ooo`0;0?ooo`800000503oool300000?l0ooooH`3oool00;80oooo0`00000=0?ooo`<0
00002@3oool2000000h0oooo0P00000D0?ooo`800000o`3ooomS0?ooo`00[`3oool3000000h0oooo
0`0000000`3oool000000?ooo`080?ooo`030000003oool0oooo00h0oooo0P00000@0?ooo`<00000
o`3ooomU0?ooo`00[03oool3000001@0oooo00<000000?ooo`000000203oool00`000000oooo0?oo
o`0?0?ooo`800000o`3ooomg0?ooo`00Z@3oool3000001P0oooo00<000000?ooo`0000001`3oool0
0`000000oooo0?ooo`0@0?ooo`800000o`3ooomf0?ooo`00YP3oool3000000h0oooo1000000:0?oo
o`030000003oool0000000D0oooo0P00000C0?ooo`8000000P3oool200000?l0ooooL@3oool00:<0
oooo0`00000@0?ooo`040000003oool0oooo0?ooo`<000002@3oool00`000000oooo000000030000
00030?ooo`000000000001<0oooo1000003o0?ooog<0oooo002P0?ooo`<000004@3oool2000000D0
oooo00<000000?ooo`0000002@3oool00`000000oooo000000020?ooo`H000003P3oool200000?l0
ooooM`3oool009d0oooo0`00000>0?ooo`800000103oool00`000000oooo0?ooo`050?ooo`030000
003oool0000000T0oooo0`0000070?ooo`H000000`3oool200000?l0ooooO03oool009X0oooo0`00
000>0?ooo`<000001`3oool3000000D0oooo00<000000?ooo`0000002P3oool2000000`0oooo1000
003o0?ooogd0oooo002F0?ooo`D000003P3oool2000000030?ooo`000000000000P0oooo0P000006
0?ooo`030000003oool0000000X0oooo0P00000:0?ooo`800000o`3ooon00?ooo`00T`3oool30000
00@0oooo00<000000?ooo`3oool01`3oool2000000L0oooo0P00000@0?ooo`8000002`3oool20000
0?l0ooooR`3oool00900oooo0`00000>0?ooo`<000002P3oool200000100oooo0P00000;0?ooo`80
000000<0oooo000000000000o`3ooon70?ooo`00S@3oool3000000l0oooo0P0000000`3oool00000
0000000;0?ooo`800000403oool2000000X0oooo0`00003o0?ooohT0oooo002:0?ooo`<000005P3o
ool2000000/0oooo0P00000@0?ooo`8000001`3oool200000?l0ooooS03oool005P0oooo1@000002
0?ooo`8000009P3oool3000000h0oooo0P00000:0?ooo`8000002`3oool3000000l0oooo0P000002
0?ooo`800000o`3ooon@0?ooo`00FP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0803oool3000000h0oooo0`00000=0?ooo`800000303oool2000000l0oooo0`00003o
0?oooi80oooo001J0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0M
0?ooo`<000003`3oool2000000030?ooo`000000000000h0oooo0P00000<0?ooo`800000303oool2
00000?l0ooooU@3oool00580oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0J0?ooo`<000005P3oool2000000d0oooo1000000;0?ooo`800000o`3ooonR
0?ooo`00FP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool05`3oool3
000000d0oooo0P00000;0?ooo`8000002@3oool300000080oooo00<000000?ooo`0000002`3oool2
000000030?ooo`00000000000?l0ooooWP3oool005T0oooo0P0000040?ooo`8000005`3oool30000
00h0oooo1@00000;0?ooo`8000001P3oool2000000H0oooo00<000000?ooo`0000002P3oool30000
0?l0ooooX03oool007@0oooo100000000`3oool000000?ooo`0:0?ooo`@000000`3oool4000000X0
oooo0P0000020?ooo`<000002@3oool00`000000oooo000000070?ooo`800000o`3ooonS0?ooo`00
L@3oool3000000D0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`040000
003oool000000?ooo`8000001`3oool3000000d0oooo00@000000?ooo`000000oooo0P00003o0?oo
ojP0oooo001^0?ooo`<000004P3oool00`000000oooo0?ooo`090?ooo`<000002`3oool2000000d0
oooo0`00003o0?ooojX0oooo001[0?ooo`<00000503oool2000000T0oooo0P0000000`3oool00000
0?ooo`0<0?ooo`8000002P3oool2000000030?ooo`000000oooo0?l0ooooZP3oool006P0oooo0`00
000G0?ooo`8000006`3oool200000?l0oooo^03oool006D0oooo0`00000K0?ooo`030000003oool0
oooo01X0oooo0P0000000`3oool000000000003o0?oook@0oooo001R0?ooo`<000007P3oool20000
0100oooo00<000000?ooo`3oool0203oool300000?l0oooo]P3oool005l0oooo0`00000>0?ooo`80
00004@3oool00`000000oooo0000000?0?ooo`8000001`3oool200000?l0oooo^@3oool005`0oooo
0`00000>0?ooo`<00000503oool3000000h0oooo0`00003o0?oool40oooo001I0?ooo`<000003`3o
ool200000080oooo0P0000070?ooo`030000003oool0oooo00/0oooo0P00000=0?ooo`040000003o
ool0000000000?l0oooo`03oool005H0oooo1000000<0?ooo`800000203oool2000000L0oooo00<0
00000?ooo`3oool02`3oool3000000T0oooo0P00003o0?oool@0oooo001B0?ooo`@000000P3oool0
0`000000oooo0?ooo`080?ooo`<0000000<0oooo000000000000203oool2000000L0oooo00<00000
0?ooo`3oool0303oool:00000?l0ooooaP3oool004l0oooo0`0000060?ooo`030000003oool0oooo
00D0oooo0`0000050?ooo`800000203oool2000000@0oooo0`0000070?ooo`030000003oool0oooo
00L0oooo1000003o0?ooolT0oooo001<0?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`<0
00002P3oool00`000000oooo0?ooo`060?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooood`3oool004T0oooo0`00000>0?ooo`<000005`3oool2000000H0oooo
00<000000?ooo`3oool0103oool200000?l0ooooe03oool004H0oooo0`00000?0?ooo`8000000P3o
ool2000000L0oooo00<000000?ooo`3oool03@3oool2000000d0oooo0P00003o0?ooom<0oooo0013
0?ooo`<000005`3oool2000000L0oooo00<000000?ooo`3oool03@3oool2000000T0oooo0`00003o
0?ooomD0oooo00100?ooo`<000003P3oool3000000X0oooo0`0000060?ooo`030000003oool0oooo
00d0oooo0P0000060?ooo`800000o`3ooooH0?ooo`00?@3oool3000000h0oooo200000090?ooo`03
0000003oool0000000<0oooo100000060?ooo`030000003oool0oooo00H0oooo0P0000020?ooo`<0
0000o`3ooooJ0?ooo`00>@3oool4000000`0oooo00<000000?ooo`0000000P0000070?ooo`<00000
203oool00`000000oooo00000002000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`060?ooo`<00000o`3ooooM0?ooo`00=`3oool3000000h0oooo0`00000=0?ooo`8000001`3o
ool3000000H0oooo00<000000?ooo`3oool00`3oool2000000D0oooo0P00003o0?ooon00oooo000d
0?ooo`<0000000<0oooo0000003oool0303oool200000080oooo0P00000>0?ooo`030000003oool0
oooo00H0oooo0P00000<0?ooo`800000o`3ooooV0?ooo`00<03oool4000000@0oooo00<000000?oo
o`3oool0403oool2000000d0oooo0P0000080?ooo`<000001`3oool300000?l0ooooj03oool002d0
oooo0`00000L0?ooo`8000003@3oool2000000P0oooo00<000000?ooo`000000103oool200000?l0
ooooj`3oool002X0oooo0`00000>0?ooo`P000002P3oool2000000`0oooo00<000000?ooo`000000
203oool00`000000oooo0000000300000?l0ooook@3oool002L0oooo0`00000@0?ooo`030000003o
ool0oooo00H0oooo0P0000090?ooo`<000002`3oool2000000P0oooo0`00003o0?oooo00oooo000T
0?ooo`<000004@3oool2000001D0oooo00<000000?ooo`0000002P3oool2000000H0oooo0P00003o
0?oooo<0oooo000Q0?ooo`<000004`3oool2000001L0oooo00<000000?ooo`0000002@3oool20000
0?l0oooon`3oool001h0oooo0`00000F0?ooo`800000603oool00`000000oooo000000070?ooo`80
0000o`3ooool0?ooo`006`3oool3000000`0oooo1`0000060?ooo`8000006@3oool00`000000oooo
000000040?ooo`<00000o`3oooom0?ooo`00603oool3000000d0oooo0P0000060?ooo`<00000103o
ool00`000000oooo0000000?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`0000000`00
003o0?ooool0oooo0@3oool001D0oooo0`0000000`3oool000000?ooo`0:0?ooo`<000002@3oool2
000000D0oooo00<000000?ooo`0000003P3oool2000000L0oooo0`00003o0?ooool0oooo1@3oool0
0180oooo0`0000040?ooo`030000003oool0oooo00L0oooo0P00000=0?ooo`8000001@3oool30000
00h0oooo0P00003o0?ooool0oooo3P3oool000h0oooo1000000;0?ooo`8000000P3oool200000003
0?ooo`000000000000d0oooo00<000000?ooo`3oool01@3oool2000000`0oooo00@000000?ooo`00
00000000o`3ooooo0?ooo`d0oooo000;0?ooo`<000003@3oool2000000P0oooo0P00000;0?ooo`80
00002@3oool2000000T0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`l0oooo00080?ooo`<00000
3P3oool4000000T0oooo0`0000070?ooo`L00000203oool900000?l0ooooo`3ooolB0?ooo`001@3o
ool3000001@0oooo0P00000:0?ooo`8000000P3oool4000000H0oooo0`0000080?ooo`@00000o`3o
oooo0?oooaD0oooo00020?ooo`<000003@3oool3000000L0oooo0P00000;0?ooo`<00000303oool2
00000?l0ooooo`3ooolP0?ooo`000P00000<0?ooo`@000002P3oool3000000/0oooo0P00000<0?oo
o`800000o`3ooooo0?ooob00oooo000A0?ooo`8000001@3oool4000000030?ooo`000000000000`0
oooo0P00000;0?ooo`800000o`3ooooo0?ooob00oooo000C0?ooo`D000001P3oool2000000`0oooo
0`0000070?ooo`<00000o`3ooooo0?ooob40oooo000E0?ooo`8000001`3oool2000000h0oooo0P00
00020?ooo`@00000o`3ooooo0?ooob@0oooo000G0?ooo`8000001P3oool2000000d0oooo1000003o
0?ooool0oooo:03oool001T0oooo0P0000040?ooo`8000002`3oool200000?l0ooooo`3oool/0?oo
o`006`3oool2000000<0oooo0P00003o0?ooool0oooo>03oool001d0oooo0P0000000`3oool00000
0000003o0?ooool0oooo>03oool001l0oooo0P0000000`3oool000000?ooo`3o0?ooool0oooo=P3o
ool00240oooo0P00003o0?ooool0oooo=`3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {206.375, 0}} -> {0.0491916, 0.301489, \
0.00171738, 0.00171738}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<abcdefghijklmnopqrstuvwxyz\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35 
%%ImageSize: 600 210.001 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0507744 1.05077 -0.339506 1.05077 [
[.12796 .26047 -8.39439 -9 ]
[.12796 .26047 9.60561 0 ]
[.45857 .15337 -2.99046 -9 ]
[.45857 .15337 3.00954 0 ]
[.81711 .03727 -6.41697 -9 ]
[.81711 .03727 5.58303 0 ]
[.45971 .08739 -4.98504 -12.75 ]
[.45971 .08739 5.01496 0 ]
[.99308 .00563 0 -5.9478 ]
[.99308 .00563 24 3.0522 ]
[1.00095 .01709 0 -5.94083 ]
[1.00095 .01709 6 3.05917 ]
[1.00875 .02847 0 -5.93393 ]
[1.00875 .02847 18 3.06607 ]
[1.06176 -0.00547 0 -8.41834 ]
[1.06176 -0.00547 10 4.33166 ]
[ 0 0 0 0 ]
[ 1 .35 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00056 .31445 m
.97395 0 L
s
.12708 .27357 m
.12664 .28013 L
s
[(-10)] .12796 .26047 -0.06729 1 Mshowa
.45853 .1665 m
.45851 .17307 L
s
[(0)] .45857 .15337 -0.00318 1 Mshowa
.81802 .05037 m
.81847 .05692 L
s
[(10)] .81711 .03727 .06949 1 Mshowa
.125 Mabswid
.19129 .25283 m
.19107 .25677 L
s
.25651 .23176 m
.25634 .2357 L
s
.32277 .21036 m
.32266 .2143 L
s
.3901 .18861 m
.39004 .19255 L
s
.52807 .14404 m
.52812 .14798 L
s
.59877 .1212 m
.59886 .12514 L
s
.67063 .09798 m
.67079 .10192 L
s
.74371 .07438 m
.74392 .07831 L
s
.06387 .29399 m
.06356 .29792 L
s
.00163 .3141 m
.00127 .31802 L
s
.8936 .02596 m
.89393 .02988 L
s
.97048 .00112 m
.97087 .00504 L
s
gsave
.45971 .08739 -65.985 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97395 0 m
.99931 .03694 L
s
.98058 .00965 m
.97433 .01166 L
s
[(-0.5)] .99308 .00563 -1 .32173 Mshowa
.98844 .0211 m
.98218 .0231 L
s
[(0)] 1.00095 .01709 -1 .32019 Mshowa
.99623 .03246 m
.98998 .03445 L
s
[(0.5)] 1.00875 .02847 -1 .31865 Mshowa
.125 Mabswid
.98216 .01195 m
.9784 .01315 L
s
.98373 .01424 m
.97998 .01545 L
s
.9853 .01653 m
.98155 .01774 L
s
.98687 .01882 m
.98312 .02002 L
s
.99 .02338 m
.98625 .02458 L
s
.99156 .02565 m
.98781 .02685 L
s
.99312 .02793 m
.98937 .02912 L
s
.99468 .03019 m
.99093 .03139 L
s
.979 .00735 m
.97525 .00856 L
s
.97742 .00505 m
.97367 .00626 L
s
.97583 .00274 m
.97208 .00395 L
s
.97425 .00043 m
.9705 .00164 L
s
.99779 .03472 m
.99403 .03591 L
s
gsave
1.06176 -0.00547 -61 -12.4183 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35 L
0 .35 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.04812 .33063 m
.05266 .33055 L
s
.04529 .33018 m
.04812 .33063 L
s
.05266 .33055 m
.05947 .32838 L
s
.08271 .33051 m
.08955 .32834 L
s
.04415 .32917 m
.04529 .33018 L
s
.04699 .32963 m
.04585 .32863 L
s
.04585 .32863 m
.04415 .32917 L
s
.08784 .32888 m
.06412 .30764 L
s
.05947 .32838 m
.06175 .32629 L
s
.08955 .32834 m
.06583 .30709 L
s
.06175 .32629 m
.06232 .32474 L
s
.03959 .32515 m
.03561 .32369 L
s
.04584 .32453 m
.03959 .32515 L
s
.06232 .32474 m
.0521 .31565 L
s
.06232 .32474 m
.06177 .32217 L
s
.0413 .32461 m
.03731 .32314 L
s
.04584 .32453 m
.0413 .32461 L
s
.05722 .32226 m
.04584 .32453 L
s
.03561 .32369 m
.03332 .32167 L
s
.03731 .32314 m
.03502 .32112 L
s
.06006 .32272 m
.05722 .32226 L
s
.06177 .32217 m
.05381 .3151 L
s
.03332 .32167 m
.03273 .3191 L
s
.03502 .32112 m
.03444 .31856 L
s
.08399 .31919 m
.08855 .3191 L
s
.07831 .31826 m
.08399 .31919 L
s
.03273 .3191 m
.03671 .31645 L
s
.08855 .3191 m
.09198 .31801 L
s
.03444 .31856 m
.03671 .31645 L
s
.09198 .31801 m
.0943 .3159 L
s
.09198 .31801 m
.09602 .31535 L
s
.03671 .31645 m
.04183 .3148 L
s
.0943 .3159 m
.09549 .31277 L
s
.04639 .31472 m
.0521 .31565 L
s
.0521 .31565 m
.05153 .31307 L
s
.09602 .31535 m
.09721 .31222 L
s
.05381 .3151 m
.05324 .31252 L
s
.04183 .3148 m
.04639 .31472 L
s
.05153 .31307 m
.05381 .31095 L
s
.09549 .31277 m
.09384 .30917 L
s
.05324 .31252 m
.05381 .31095 L
s
.09721 .31222 m
.09556 .30862 L
s
.05381 .31095 m
.05553 .3104 L
s
.07041 .307 m
.06925 .31014 L
s
.09384 .30917 m
.09158 .30713 L
s
.11672 .30874 m
.11102 .30781 L
s
.12303 .30811 m
.11672 .30874 L
s
.09556 .30862 m
.09331 .30658 L
s
.11845 .30819 m
.11275 .30726 L
s
.12303 .30811 m
.11845 .30819 L
s
.12822 .30645 m
.12303 .30811 L
s
.11102 .30781 m
.10593 .3053 L
s
.11275 .30726 m
.10766 .30475 L
s
.09158 .30713 m
.08647 .30462 L
s
.07272 .30487 m
.07041 .307 L
s
.09331 .30658 m
.08819 .30407 L
s
.13058 .30432 m
.12822 .30645 L
s
.10593 .3053 m
.10368 .30326 L
s
.07617 .30377 m
.07272 .30487 L
s
.10766 .30475 m
.10541 .3027 L
s
.08647 .30462 m
.08075 .30368 L
s
.13182 .30116 m
.13058 .30432 L
s
.08819 .30407 m
.08248 .30313 L
s
.08075 .30368 m
.07617 .30377 L
s
.08248 .30313 m
.07617 .30377 L
s
.10368 .30326 m
.10203 .29963 L
s
.10541 .3027 m
.10376 .29907 L
s
.17075 .30253 m
.17774 .30031 L
s
.13008 .30172 m
.12723 .30125 L
s
.12723 .30125 m
.12785 .29967 L
s
.1307 .30014 m
.13182 .30116 L
s
.17599 .30087 m
.15274 .27916 L
s
.17774 .30031 m
.1545 .2786 L
s
.12785 .29967 m
.1307 .30014 L
s
.10203 .29963 m
.10324 .29646 L
s
.10376 .29907 m
.10497 .2959 L
s
.15145 .29766 m
.14574 .29672 L
s
.1578 .29702 m
.15145 .29766 L
s
.1532 .2971 m
.14749 .29616 L
s
.1578 .29702 m
.1532 .2971 L
s
.16129 .2959 m
.1578 .29702 L
s
.14574 .29672 m
.14066 .29419 L
s
.10324 .29646 m
.10732 .29376 L
s
.14749 .29616 m
.14241 .29363 L
s
.16368 .29376 m
.16129 .2959 L
s
.10497 .2959 m
.10732 .29376 L
s
.14066 .29419 m
.13843 .29212 L
s
.10732 .29376 m
.11079 .29264 L
s
.16497 .29057 m
.16368 .29376 L
s
.14241 .29363 m
.14017 .29156 L
s
.11714 .29199 m
.12287 .29294 L
s
.11079 .29264 m
.11714 .29199 L
s
.13843 .29212 m
.13682 .28846 L
s
.14017 .29156 m
.13857 .2879 L
s
.13682 .28846 m
.13808 .28527 L
s
.13857 .2879 m
.13983 .28471 L
s
.18648 .28648 m
.18076 .28553 L
s
.19286 .28583 m
.18648 .28648 L
s
.18824 .28592 m
.18252 .28497 L
s
.19286 .28583 m
.18824 .28592 L
s
.19815 .28414 m
.19286 .28583 L
s
.18076 .28553 m
.17569 .28298 L
s
.13808 .28527 m
.14221 .28254 L
s
.18252 .28497 m
.17745 .28241 L
s
.13983 .28471 m
.14221 .28254 L
s
.20058 .28198 m
.19815 .28414 L
s
.22766 .28306 m
.22372 .28155 L
s
.23229 .28298 m
.22766 .28306 L
s
.23229 .28298 m
.22943 .2825 L
s
.23583 .28185 m
.23229 .28298 L
s
.17569 .28298 m
.17348 .2809 L
s
.14221 .28254 m
.14572 .28142 L
s
.22943 .2825 m
.22549 .28098 L
s
.17745 .28241 m
.17524 .28033 L
s
.17745 .28241 m
.19863 .27564 L
s
.15035 .28133 m
.15609 .28228 L
s
.20015 .27933 m
.20058 .28198 L
s
.20125 .28038 m
.20058 .28198 L
s
.23652 .28024 m
.23583 .28185 L
s
.22372 .28155 m
.20401 .26269 L
s
.14572 .28142 m
.15035 .28133 L
s
.22549 .28098 m
.20579 .26211 L
s
.17348 .2809 m
.17192 .2772 L
s
.23475 .28081 m
.23189 .28033 L
s
.20082 .27773 m
.20125 .28038 L
s
.17524 .28033 m
.17368 .27664 L
s
.23189 .28033 m
.23258 .27873 L
s
.23544 .2792 m
.23652 .28024 L
s
.19686 .2762 m
.20015 .27933 L
s
.23258 .27873 m
.23544 .2792 L
s
.15274 .27916 m
.15977 .2769 L
s
.21405 .27907 m
.22823 .27455 L
s
.19863 .27564 m
.20082 .27773 L
s
.17192 .2772 m
.17322 .27398 L
s
.17368 .27664 m
.17499 .27341 L
s
.17322 .27398 m
.17741 .27123 L
s
.17499 .27341 m
.17741 .27123 L
s
.17741 .27123 m
.18095 .2701 L
s
.18736 .26944 m
.19312 .2704 L
s
.18095 .2701 m
.18736 .26944 L
s
.24495 .26782 m
.24099 .26629 L
s
.24495 .26782 m
.24208 .26734 L
s
.2496 .26773 m
.24495 .26782 L
s
.25317 .26659 m
.2496 .26773 L
s
.28039 .26769 m
.28756 .26541 L
s
.24208 .26734 m
.23812 .2658 L
s
.25567 .2644 m
.25317 .26659 L
s
.24099 .26629 m
.23664 .26207 L
s
.28577 .26598 m
.26313 .24369 L
s
.23812 .2658 m
.23594 .2637 L
s
.28756 .26541 m
.26493 .24311 L
s
.25529 .26172 m
.25567 .2644 L
s
.25637 .26277 m
.25567 .2644 L
s
.19867 .2644 m
.21113 .2604 L
s
.23594 .2637 m
.23555 .26101 L
s
.26283 .26211 m
.25925 .26326 L
s
.25925 .26326 m
.26391 .26317 L
s
.25637 .26277 m
.25925 .26326 L
s
.26391 .26317 m
.26283 .26211 L
s
.256 .26009 m
.25637 .26277 L
s
.23664 .26207 m
.23624 .25938 L
s
.25095 .25749 m
.25529 .26172 L
s
.23555 .26101 m
.23267 .26053 L
s
.23555 .26101 m
.23624 .25938 L
s
.23267 .26053 m
.2287 .25899 L
s
.25383 .25797 m
.256 .26009 L
s
.23624 .25938 m
.23873 .25718 L
s
.2287 .25899 m
.2276 .25793 L
s
.24987 .25643 m
.25383 .25797 L
s
.2276 .25793 m
.22829 .25629 L
s
.2276 .25793 m
.2272 .25523 L
s
.24699 .25594 m
.25095 .25749 L
s
.23873 .25718 m
.24231 .25603 L
s
.24699 .25594 m
.24987 .25643 L
s
.22829 .25629 m
.23257 .25351 L
s
.24231 .25603 m
.24699 .25594 L
s
.28259 .25581 m
.28906 .25515 L
s
.27683 .25484 m
.28259 .25581 L
s
.2272 .25523 m
.23147 .25245 L
s
.28906 .25515 m
.29267 .254 L
s
.22431 .25475 m
.23078 .25408 L
s
.22032 .2532 m
.22431 .25475 L
s
.29267 .254 m
.29521 .25178 L
s
.29267 .254 m
.29701 .2512 L
s
.23257 .25351 m
.24153 .25063 L
s
.32618 .25174 m
.32543 .25338 L
s
.32543 .25338 m
.32256 .25289 L
s
.21922 .25213 m
.22032 .2532 L
s
.32256 .25289 m
.32331 .25125 L
s
.23147 .25245 m
.24044 .24956 L
s
.21881 .24943 m
.21922 .25213 L
s
.29521 .25178 m
.29487 .24907 L
s
.32331 .25125 m
.32618 .25174 L
s
.29701 .2512 m
.29668 .2485 L
s
.24153 .25063 m
.24583 .24783 L
s
.24044 .24956 m
.24474 .24676 L
s
.22308 .24663 m
.21881 .24943 L
s
.29487 .24907 m
.28302 .23729 L
s
.29668 .2485 m
.28484 .23671 L
s
.24583 .24783 m
.24544 .24511 L
s
.31256 .24765 m
.31982 .24534 L
s
.24474 .24676 m
.24544 .24511 L
s
.23386 .24315 m
.22308 .24663 L
s
.34799 .2448 m
.34722 .24645 L
s
.34722 .24645 m
.34435 .24596 L
s
.34435 .24596 m
.34512 .24431 L
s
.318 .24592 m
.30302 .23087 L
s
.25772 .24543 m
.27035 .24137 L
s
.31982 .24534 m
.30484 .23028 L
s
.24544 .24511 m
.24435 .24404 L
s
.34512 .24431 m
.34799 .2448 L
s
.24435 .24404 m
.24036 .24248 L
s
.24036 .24248 m
.23386 .24315 L
s
.35816 .24297 m
.36547 .24065 L
s
.36364 .24123 m
.34145 .21852 L
s
.33437 .2407 m
.34166 .23837 L
s
.36547 .24065 m
.34329 .21793 L
s
.27759 .23904 m
.29028 .23496 L
s
.33984 .23895 m
.32065 .21947 L
s
.34166 .23837 m
.32248 .21888 L
s
.29755 .23262 m
.31031 .22853 L
s
.39852 .23015 m
.4059 .2278 L
s
.37096 .22902 m
.38201 .2255 L
s
.40405 .22839 m
.3821 .20546 L
s
.4059 .2278 m
.38395 .20486 L
s
.37648 .22726 m
.34754 .22229 L
s
.35913 .22428 m
.36172 .212 L
s
.36097 .22369 m
.36357 .21141 L
s
.31332 .22183 m
.31408 .22015 L
s
.31041 .22133 m
.31332 .22183 L
s
.30934 .22024 m
.31041 .22133 L
s
.33594 .22029 m
.34881 .21615 L
s
.31009 .21856 m
.30934 .22024 L
s
.31408 .22015 m
.31117 .21965 L
s
.32065 .21947 m
.31666 .21788 L
s
.32248 .21888 m
.3185 .21729 L
s
.31375 .21738 m
.31009 .21856 L
s
.31666 .21788 m
.31375 .21738 L
s
.3185 .21729 m
.31375 .21738 L
s
.41159 .21606 m
.41902 .21369 L
s
.41716 .21429 m
.40257 .19888 L
s
.35619 .21378 m
.36727 .21022 L
s
.41902 .21369 m
.40443 .19828 L
s
.42171 .21141 m
.42833 .21072 L
s
.41591 .2104 m
.42171 .21141 L
s
.42833 .21072 m
.43206 .20954 L
s
.43206 .20954 m
.43475 .20725 L
s
.43206 .20954 m
.43662 .20665 L
s
.37653 .20725 m
.38953 .20307 L
s
.43475 .20725 m
.43456 .20445 L
s
.43662 .20665 m
.43643 .20385 L
s
.44223 .20486 m
.44887 .20417 L
s
.43643 .20385 m
.44223 .20486 L
s
.43456 .20445 m
.42314 .19227 L
s
.44887 .20417 m
.45262 .20298 L
s
.43643 .20385 m
.42501 .19167 L
s
.45262 .20298 m
.45534 .20068 L
s
.45262 .20298 m
.45722 .20008 L
s
.39698 .20068 m
.41004 .19648 L
s
.45534 .20068 m
.45516 .19786 L
s
.45722 .20008 m
.45704 .19726 L
s
.45516 .19786 m
.44381 .18563 L
s
.45704 .19726 m
.4457 .18502 L
s
.47328 .19639 m
.48082 .19398 L
s
.47893 .19458 m
.46458 .17895 L
s
.41752 .19407 m
.43064 .18986 L
s
.48082 .19398 m
.46648 .17834 L
s
.48357 .19167 m
.49026 .19097 L
s
.47776 .19065 m
.48357 .19167 L
s
.49026 .19097 m
.49404 .18976 L
s
.49404 .18976 m
.49681 .18744 L
s
.49404 .18976 m
.49871 .18684 L
s
.43816 .18744 m
.45135 .1832 L
s
.49681 .18744 m
.49668 .1846 L
s
.49871 .18684 m
.49858 .18399 L
s
.49668 .1846 m
.48546 .17224 L
s
.49858 .18399 m
.48736 .17163 L
s
.45891 .18077 m
.47216 .17651 L
s
.52151 .17956 m
.51568 .17853 L
s
.52824 .17886 m
.52151 .17956 L
s
.52342 .17895 m
.51759 .17792 L
s
.52824 .17886 m
.52342 .17895 L
s
.53205 .17764 m
.52824 .17886 L
s
.51568 .17853 m
.51074 .17576 L
s
.51759 .17792 m
.51265 .17515 L
s
.53487 .1753 m
.53205 .17764 L
s
.53678 .17469 m
.53205 .17764 L
s
.51074 .17576 m
.50872 .17351 L
s
.53669 .17182 m
.53487 .1753 L
s
.51265 .17515 m
.51062 .1729 L
s
.5386 .17121 m
.53678 .17469 L
s
.47976 .17407 m
.49307 .16979 L
s
.50872 .17351 m
.50758 .16951 L
s
.51062 .1729 m
.50949 .1689 L
s
.53559 .16781 m
.53669 .17182 L
s
.55118 .17154 m
.55886 .16909 L
s
.53751 .1672 m
.5386 .17121 L
s
.55694 .1697 m
.53584 .14575 L
s
.50758 .16951 m
.50937 .16602 L
s
.55886 .16909 m
.53777 .14513 L
s
.50949 .1689 m
.51128 .16541 L
s
.53358 .16555 m
.53559 .16781 L
s
.53549 .16493 m
.53751 .1672 L
s
.56171 .16673 m
.56655 .16663 L
s
.55587 .16569 m
.56171 .16673 L
s
.56655 .16663 m
.5704 .16541 L
s
.50937 .16602 m
.51409 .16304 L
s
.52863 .16276 m
.53358 .16555 L
s
.51128 .16541 m
.51409 .16304 L
s
.5704 .16541 m
.57326 .16304 L
s
.5704 .16541 m
.57519 .16243 L
s
.53055 .16214 m
.53549 .16493 L
s
.51409 .16304 m
.51792 .16181 L
s
.57326 .16304 m
.57514 .15953 L
s
.52277 .16172 m
.52863 .16276 L
s
.57519 .16243 m
.57707 .15892 L
s
.52469 .1611 m
.53055 .16214 L
s
.51792 .16181 m
.52277 .16172 L
s
.51792 .16181 m
.52469 .1611 L
s
.57514 .15953 m
.57409 .15549 L
s
.57707 .15892 m
.57603 .15487 L
s
.54971 .15306 m
.54786 .15659 L
s
.57409 .15549 m
.5721 .15321 L
s
.57603 .15487 m
.57404 .15259 L
s
.60035 .1544 m
.5945 .15335 L
s
.60715 .15368 m
.60035 .1544 L
s
.60229 .15378 m
.59644 .15273 L
s
.60715 .15368 m
.60229 .15378 L
s
.61104 .15244 m
.60715 .15368 L
s
.5945 .15335 m
.58959 .15053 L
s
.5721 .15321 m
.56718 .15039 L
s
.55256 .15068 m
.54971 .15306 L
s
.59644 .15273 m
.59153 .14991 L
s
.57404 .15259 m
.56911 .14977 L
s
.61395 .15006 m
.61104 .15244 L
s
.55643 .14944 m
.55256 .15068 L
s
.58959 .15053 m
.58761 .14824 L
s
.56718 .15039 m
.5613 .14934 L
s
.61589 .14652 m
.61395 .15006 L
s
.61883 .14996 m
.59812 .12566 L
s
.59153 .14991 m
.58955 .14762 L
s
.56911 .14977 m
.56324 .14872 L
s
.5613 .14934 m
.55643 .14944 L
s
.56324 .14872 m
.55643 .14944 L
s
.62077 .14934 m
.60008 .12503 L
s
.58761 .14824 m
.58658 .14417 L
s
.53005 .14762 m
.54357 .14325 L
s
.58955 .14762 m
.58852 .14354 L
s
.63053 .14623 m
.63835 .14373 L
s
.63639 .14436 m
.6227 .12814 L
s
.58658 .14417 m
.58848 .14061 L
s
.63835 .14373 m
.62466 .12751 L
s
.58852 .14354 m
.59043 .13998 L
s
.64325 .14071 m
.64814 .14061 L
s
.63739 .13965 m
.64325 .14071 L
s
.58848 .14061 m
.59334 .13758 L
s
.64814 .14061 m
.65403 .13873 L
s
.59043 .13998 m
.59334 .13758 L
s
.6325 .1368 m
.63739 .13965 L
s
.65403 .13873 m
.65503 .13695 L
s
.59334 .13758 m
.59724 .13632 L
s
.65013 .13704 m
.65306 .13758 L
s
.60214 .13622 m
.60802 .13729 L
s
.65112 .13526 m
.65013 .13704 L
s
.65503 .13695 m
.65406 .13579 L
s
.59724 .13632 m
.60214 .13622 L
s
.65406 .13579 m
.65112 .13526 L
s
.6688 .13255 m
.66587 .13202 L
s
.67371 .13245 m
.6688 .13255 L
s
.68161 .12994 m
.67371 .13245 L
s
.66587 .13202 m
.66394 .12969 L
s
.66491 .13086 m
.66591 .12906 L
s
.71203 .13052 m
.69584 .1106 L
s
.61681 .13003 m
.63056 .12561 L
s
.6846 .12751 m
.68161 .12994 L
s
.71401 .12989 m
.69783 .10996 L
s
.66394 .12969 m
.66495 .1279 L
s
.66591 .12906 m
.6689 .12663 L
s
.66495 .1279 m
.66793 .12547 L
s
.59224 .12756 m
.60596 .12313 L
s
.68563 .12571 m
.6846 .12751 L
s
.68952 .12741 m
.68569 .12274 L
s
.68563 .12571 m
.68952 .12741 L
s
.6689 .12663 m
.67686 .12113 L
s
.68569 .12274 m
.68563 .12571 L
s
.66793 .12547 m
.6759 .11996 L
s
.69943 .12425 m
.71533 .11918 L
s
.65813 .12269 m
.65424 .118 L
s
.65816 .11972 m
.65813 .12269 L
s
.67686 .12113 m
.67986 .11869 L
s
.6759 .11996 m
.6789 .11752 L
s
.65424 .118 m
.65816 .11972 L
s
.65917 .11791 m
.65816 .11972 L
s
.67986 .11869 m
.68088 .11688 L
s
.66216 .11546 m
.65917 .11791 L
s
.6789 .11752 m
.67992 .1157 L
s
.68088 .11688 m
.67799 .11335 L
s
.6701 .11291 m
.66216 .11546 L
s
.7293 .11472 m
.73729 .11217 L
s
.67799 .11335 m
.67504 .11281 L
s
.67504 .11281 m
.6701 .11291 L
s
.73529 .11281 m
.72489 .09979 L
s
.73729 .11217 m
.72689 .09915 L
s
.69584 .1106 m
.69495 .10642 L
s
.69783 .10996 m
.69695 .10577 L
s
.75133 .1077 m
.75937 .10513 L
s
.69495 .10642 m
.69798 .10395 L
s
.75736 .10577 m
.74419 .0891 L
s
.69695 .10577 m
.69798 .10395 L
s
.75937 .10513 m
.74621 .08845 L
s
.70694 .10256 m
.71086 .10429 L
s
.69798 .10395 m
.70198 .10266 L
s
.70198 .10266 m
.70694 .10256 L
s
.77145 .10128 m
.78357 .09741 L
s
.77549 .09999 m
.77459 .07933 L
s
.72489 .09979 m
.72499 .09677 L
s
.77751 .09935 m
.77646 .08174 L
s
.72689 .09915 m
.727 .09612 L
s
.72499 .09677 m
.73008 .09363 L
s
.727 .09612 m
.73008 .09363 L
s
.79167 .09483 m
.80385 .09095 L
s
.73008 .09363 m
.7341 .09234 L
s
.7411 .09159 m
.74702 .09269 L
s
.7341 .09234 m
.7411 .09159 L
s
.79978 .09224 m
.77459 .07933 L
s
.80791 .08965 m
.82217 .0851 L
s
.74419 .0891 m
.75228 .0865 L
s
.81402 .0877 m
.8093 .06818 L
s
.81605 .08705 m
.81207 .07182 L
s
.83034 .08249 m
.82572 .0629 L
s
.83034 .08249 m
.8093 .06818 L
s
.83238 .08184 m
.82848 .06656 L
s
.84057 .07923 m
.85288 .0753 L
s
.84672 .07727 m
.82572 .0629 L
s
.85905 .07334 m
.87141 .06939 L
s
.86317 .07202 m
.87329 .04761 L
s
.86523 .07137 m
.87537 .04694 L
s
.87967 .06676 m
.89209 .0628 L
s
.88795 .06412 m
.85048 .05494 L
s
.89831 .06081 m
.91079 .05683 L
s
.90247 .05949 m
.9025 .03823 L
s
.90455 .05882 m
.90429 .04071 L
s
.84634 .05627 m
.85876 .05228 L
s
.91912 .05418 m
.93165 .05018 L
s
.92747 .05151 m
.9025 .03823 L
s
.86706 .04962 m
.87954 .04561 L
s
.94212 .04684 m
.96734 .0388 L
s
.93861 .0419 m
.94212 .04684 L
s
.94421 .04617 m
.93861 .0419 L
s
.96523 .03947 m
.92979 .02946 L
s
.96734 .0388 m
.9319 .02878 L
s
.9025 .03823 m
.89473 .0346 L
s
.88337 .03673 m
.88455 .03481 L
s
.88037 .03616 m
.88337 .03673 L
s
.88156 .03424 m
.88037 .03616 L
s
.89473 .0346 m
.88874 .03346 L
s
.88365 .03356 m
.88156 .03424 L
s
.88874 .03346 m
.88365 .03356 L
s
.92979 .02946 m
.95513 .02131 L
s
.95864 .02633 m
.95302 .02199 L
s
.95513 .02131 m
.95864 .02633 L
s
0 g
.25 Mabswid
.00056 .31445 m
.97395 0 L
s
.12708 .27357 m
.12664 .28013 L
s
[(-10)] .12796 .26047 -0.06729 1 Mshowa
.45853 .1665 m
.45851 .17307 L
s
[(0)] .45857 .15337 -0.00318 1 Mshowa
.81802 .05037 m
.81847 .05692 L
s
[(10)] .81711 .03727 .06949 1 Mshowa
.125 Mabswid
.19129 .25283 m
.19107 .25677 L
s
.25651 .23176 m
.25634 .2357 L
s
.32277 .21036 m
.32266 .2143 L
s
.3901 .18861 m
.39004 .19255 L
s
.52807 .14404 m
.52812 .14798 L
s
.59877 .1212 m
.59886 .12514 L
s
.67063 .09798 m
.67079 .10192 L
s
.74371 .07438 m
.74392 .07831 L
s
.06387 .29399 m
.06356 .29792 L
s
.00163 .3141 m
.00127 .31802 L
s
.8936 .02596 m
.89393 .02988 L
s
.97048 .00112 m
.97087 .00504 L
s
gsave
.45971 .08739 -65.985 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 210},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000dR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooc00oooo0P0000040?ooo`80
0000103oool2000001`0oooo003o0?ooool0oooo703oool300000100oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000K0?ooo`00o`3ooooo0?oooaX0oooo100000000`3oool0
00000?ooo`0>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06@3oool00?l0
ooooo`3ooolG0?ooo`<000000P3oool5000000P0oooo100000020?ooo`040000003oool0oooo0000
00T0oooo0P00000L0?ooo`00o`3ooooo0?oooa@0oooo0`0000070?ooo`<000003P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01/0oooo003o0?ooool0oooo4@3oool3000000/0
oooo0`00000>0?ooo`8000002P3oool3000001/0oooo003o0?ooool0oooo3@3oool4000000l0oooo
0P00000=0?ooo`800000:@3oool00?l0ooooo`3oool:0?ooo`<000004@3oool200000080oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`00000X0?ooo`00o`3ooooo0?ooo`L0oooo0`00
000F0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000X0?ooo`00o`3o
oooo0?ooo`@0oooo0`00000J0?ooo`@000002@3oool010000000oooo0?ooo`00000X0?ooo`00o`3o
oooo0?ooo`40oooo0`00000N0?ooo`<000002@3oool010000000oooo0?ooo`00000X0?ooo`00o`3o
ooom0?ooo`<00000903oool00`000000oooo0?ooo`070?ooo`800000:@3oool00?l0oooonP3oool3
000001@0oooo0P00000?0?ooo`@00000<`3oool00?l0oooo`03oool500000080oooo0P00000^0?oo
o`<00000503oool4000000030?ooo`000000oooo00`0oooo0`0000000`3oool000000?ooo`0;0?oo
o`800000103oool2000000@0oooo0P00000I0?ooo`00o`3oooo20?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0X0?ooo`<000005@3oool2000000@0oooo0P00000@0?oo
o`<000002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo000001P0oooo003o
0?oool80oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo02@0oooo1000
000E0?ooo`<00000203oool00`000000oooo0?ooo`0?0?ooo`8000002@3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0oooo01H0oooo003o0?oool80oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0240oooo1000000E0?ooo`<000006`3oool2000000030?oo
o`000000oooo00P0oooo00@000000?ooo`3oool000002@3oool2000001T0oooo003o0?oool80oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01h0oooo0`0000030?ooo`03
0000003oool0oooo0140oooo0`00000N0?ooo`80000000<0oooo0000003oool01`3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01P0oooo003o0?oool40oooo0P0000040?ooo`80
00007P3oool3000001`0oooo1@00000K0?ooo`80000000<0oooo0000003oool01`3oool2000000X0
oooo0`00000H0?ooo`00o`3ooooT0?ooo`<00000103oool5000001T0oooo1P00000I0?ooo`<00000
;P3oool00?l0ooooh@3oool3000000H0oooo0P0000040?ooo`8000006`3oool6000001<0oooo0P00
00020?ooo`030000003oool0oooo02`0oooo003o0?ooomh0oooo0`0000080?ooo`<000001P3oool2
000001`0oooo1`00000A0?ooo`80000000<0oooo0000003oool0;03oool00?l0oooof`3oool30000
01H0oooo0P00000M0?ooo`L00000?`3oool00?l0oooof03oool3000001X0oooo0`00000M0?ooo`@0
0000@03oool00?l0ooooe@3oool3000001d0oooo0P0000000`3oool000000000000?0?ooo`030000
003oool0oooo00L0oooo0P0000140?ooo`00o`3ooooA0?ooo`@00000803oool2000000<0oooo0P00
000>0?ooo`800000103oool3000004H0oooo003o0?ooolh0oooo0`00000F0?ooo`800000303oool2
000000D0oooo0P00000<0?ooo`030000003oool0000000<00000B@3oool00?l0oooob`3oool30000
01D0oooo1000000>0?ooo`8000001`3oool2000000/0oooo0P00001<0?ooo`00o`3oooo80?ooo`<0
00005P3oool200000080oooo0P00000>0?ooo`8000002@3oool200000080oooo0P00001C0?ooo`00
o`3oooo50?ooo`<00000703oool2000000l0oooo0P00000;0?ooo`800000E@3oool00?l0oooo`P3o
ool3000000030?ooo`000000oooo01@0oooo0P0000060?ooo`8000003`3oool2000000T0oooo0P00
001G0?ooo`00o`3ooono0?ooo`<000001@3oool00`000000oooo0?ooo`0>0?ooo`@000001`3oool2
00000100oooo0P0000070?ooo`800000F@3oool00?l0oooo_03oool3000000P0oooo00<000000?oo
o`3oool0303oool2000000<0oooo100000040?ooo`800000403oool200000080oooo0P00001N0?oo
o`00o`3oooni0?ooo`<000008`3oool500000140oooo1000001P0?ooo`00o`3ooonf0?ooo`<00000
:@3oool5000000`0oooo0`00001S0?ooo`00o`3ooonb0?ooo`@00000;03oool00`000000oooo0?oo
o`020?ooo`@000000`3oool2000006T0oooo003o0?ooojl0oooo0`00000I0?ooo`030000003oool0
oooo01<0oooo0P0000080?ooo`<00000J`3oool00?l0oooo[03oool3000001`0oooo0`00000C0?oo
o`030000003oool0oooo00H0oooo0P00001]0?ooo`00o`3ooonY0?ooo`<000005@3oool00`000000
oooo0?ooo`070?ooo`80000000<0oooo0000003oool0403oool2000000H0oooo0P00001_0?ooo`00
o`3ooonV0?ooo`<00000603oool3000000P0oooo00@000000?ooo`3oool00000403oool00`000000
oooo0?ooo`02000007@0oooo003o0?oooj<0oooo0`00000L0?ooo`<000001`3oool010000000oooo
0?ooo`3oool2000000d0oooo1000001f0?ooo`00o03oool2000000030?ooo`000000000009h0oooo
0`00000O0?ooo`80000000<0oooo0000000000001@3oool2000000@0oooo00<000000?ooo`3oool0
203oool3000007T0oooo003m0?ooo`030000003oool0000009`0oooo0`00000R0?ooo`8000000`3o
ool00`000000oooo0?ooo`020?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`800000OP3o
ool00?h0oooo00<000000?ooo`3oool0V03oool4000002@0oooo00<000000?ooo`0000000`3oool2
00000080oooo0P0000060?ooo`80000000<0oooo000000000000P03oool00?`0oooo0P0000000`3o
ool000000000002E0?ooo`<000000`3oool00`000000oooo0?ooo`0S0?ooo`8000001@3oool01000
0000oooo0?ooo`0000070?ooo`800000PP3oool00?l0ooooT`3oool4000001L0oooo00<000000?oo
o`3oool04P3oool2000000H0oooo100000040?ooo`800000Q03oool00?l0ooooT03oool3000001/0
oooo0`00000B0?ooo`800000203oool2000008X0oooo003o0?ooohd0oooo0`00000N0?ooo`800000
00<0oooo000000000000403oool00`000000oooo0000002C0?ooo`00o`3ooon:0?ooo`<000008@3o
ool2000000<0oooo0P00000?0?ooo`8000000P3oool2000008l0oooo003o0?ooohL0oooo0`00000F
0?ooo`<000002`3oool2000000D0oooo0P00000=0?ooo`@00000T@3oool00?l0ooooQ03oool30000
01H0oooo0`00000>0?ooo`8000001`3oool2000000P0oooo0`00002E0?ooo`00o`3ooon10?ooo`<0
00005`3oool5000000l0oooo00<000000?ooo`3oool01`3oool200000080oooo0P00002J0?ooo`00
o`3ooomn0?ooo`<000005`3oool3000000<0oooo0`00000>0?ooo`8000002@3oool3000009`0oooo
003o0?ooog/0oooo0`00000G0?ooo`<00000203oool2000000d0oooo0P0000070?ooo`800000W`3o
ool00?l0ooooM`3oool4000001P0oooo0`00000;0?ooo`800000303oool200000:P0oooo003o0?oo
og@0oooo0`00000L0?ooo`800000303oool2000000`0oooo0P0000000`3oool000000000002U0?oo
o`00o`3oooma0?ooo`<0000000<0oooo0000003oool0703oool2000000d0oooo0P00000:0?ooo`@0
0000Y`3oool00?l0ooooKP3oool3000000@0oooo00<000000?ooo`3oool0703oool2000000d0oooo
0P0000070?ooo`800000Z`3oool00?l0ooooJ`3oool3000001H0oooo200000080?ooo`030000003o
ool0000000d0oooo0P00002c0?ooo`00o`3ooomX0?ooo`<00000603oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0000000`0oooo0`00002b0?ooo`00o`3ooomU0?ooo`<000006P3oool20000
0180oooo0P0000090?ooo`<00000]@3oool00?l0ooooHP3oool3000001d0oooo00<000000?ooo`00
00004P3oool200000<00oooo003o0?oooel0oooo0`00000Q0?ooo`8000004P3oool00`000000oooo
0000002o0?ooo`00o`3ooomL0?ooo`<000005@3oool4000000`0oooo0P00000B0?ooo`<00000_P3o
ool00?l0ooooF03oool4000001H0oooo0P0000040?ooo`8000002P3oool00`000000oooo0000000>
0?ooo`<00000`@3oool00?l0ooooE@3oool3000001P0oooo0P0000080?ooo`030000003oool0oooo
00P0oooo0P00003B0?ooo`00o`3ooomB0?ooo`<000005P3oool2000000030?ooo`000000000000T0
oooo0P00000;0?ooo`800000d@3oool00?l0ooooC`3oool3000001X0oooo0`0000080?ooo`<00000
3@3oool2000000<0oooo0P00003;0?ooo`00o`3ooom<0?ooo`<000007P3oool2000000L0oooo00<0
00000?ooo`0000003P3oool00`000000oooo0000000200000<d0oooo003o0?ooodT0oooo0`000000
103oool000000?ooo`3oool2000001`0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool01`3oool400000<h0oooo003o0?ooodH0oooo0`000003
0?ooo`@000003@3oool2000001@0oooo00@000000?ooo`00000000001P3oool2000000H0oooo0P00
00020?ooo`030000003oool000000<d0oooo003o0?oood<0oooo0`0000030?ooo`<0000000<0oooo
000000000000303oool2000001D0oooo00<000000?ooo`0000001`3oool010000000oooo00000000
000:0?ooo`800000c@3oool00?l0oooo@03oool3000000/0oooo0P0000090?ooo`80000000<0oooo
0000003oool04`3oool3000000L0oooo00<000000?ooo`3oool0303oool00`000000oooo0000003<
0?ooo`00o`3ooolm0?ooo`<000003`3oool2000000H0oooo0P0000020?ooo`030000003oool00000
01<0oooo00<000000?ooo`3oool01@3oool3000000l0oooo00<000000?ooo`000000b`3oool00?l0
oooo>@3oool400000180oooo00<000000?ooo`0000002P3oool00`000000oooo0000000C0?ooo`L0
0000h03oool00?l0oooo=P3oool3000001L0oooo00<000000?ooo`0000002P3oool00`000000oooo
0000003i0?ooo`00o`3ooolc0?ooo`<000005P3oool6000000030?ooo`000000oooo00T0oooo0P00
000:0?ooo`800000k@3oool00?l0oooo<03oool3000001L0oooo0P0000050?ooo`<000002P3oool3
000000P0oooo1000003/0?ooo`00o@3oool2000002d0oooo0`00000H0?ooo`8000002@3oool20000
00X0oooo00<000000?ooo`0000000P0000060?ooo`800000k@3oool00?`0oooo00@000000?ooo`3o
ool00000:@3oool3000001X0oooo00<000000?ooo`3oool02P3oool2000000X0oooo00@000000?oo
o`000000oooo1P00003_0?ooo`00o03oool010000000oooo0?ooo`00000V0?ooo`<000000`3oool2
000001L0oooo0P00000=0?ooo`8000002P3oool300000?D0oooo003l0?ooo`040000003oool0oooo
000002<0oooo0`0000030?ooo`<000006@3oool2000000d0oooo00<000000?ooo`000000203oool3
00000?H0oooo003l0?ooo`040000003oool0oooo00000200oooo0`0000000`3oool000000?ooo`02
0?ooo`@000006@3oool00`000000oooo0000000=0?ooo`030000003oool0000000D0oooo0P00003i
0?ooo`00o@3oool2000001d0oooo100000040?ooo`040000003oool00000000000<0oooo0P000009
0?ooo`@000002`3oool00`000000oooo0000000<0?ooo`050000003oool000000?ooo`000000o`3o
ool00?l0oooo6P3oool3000000l0oooo00<000000?ooo`000000103oool500000080oooo10000009
0?ooo`<000002`3oool010000000oooo0?ooo`00003o0?ooo`40oooo003o0?oooaL0oooo0`00000C
0?ooo`030000003oool000000080oooo00<000000?ooo`3oool01`3oool4000000T0oooo10000006
0?ooo`800000o`3oool50?ooo`00o`3ooolD0?ooo`<000005`3oool010000000oooo00000000000<
0?ooo`8000002P3oool900000?l0oooo1`3oool00?l0oooo4@3oool3000001/0oooo0`00000=0?oo
o`800000o`3ooolI0?ooo`00o`3oool>0?ooo`<000007P3oool3000000d0oooo0P00003o0?oooaT0
oooo003o0?ooo`/0oooo0`00000R0?ooo`030000003oool0000000d0oooo0P00003o0?oooaP0oooo
003o0?ooo`P0oooo0`00000E0?ooo`H000002`3oool00`000000oooo0000000;0?ooo`800000o`3o
oolI0?ooo`00o`3oool50?ooo`<000005P3oool2000000D0oooo100000090?ooo`030000003oool0
000000X0oooo0P00003o0?oooaT0oooo003o0?ooo`80oooo0`00000G0?ooo`8000002@3oool40000
00P0oooo00<000000?ooo`0000001`3oool200000?l0oooo6`3oool00?d0oooo1000000I0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`0000001`3oool00`000000oooo0000000700000?l0
oooo7@3oool00?X0oooo0`0000000`3oool000000?ooo`0I0?ooo`8000003P3oool2000000P0oooo
00@000000?ooo`0000000000o`3ooolR0?ooo`00m`3oool3000000@0oooo00<000000?ooo`3oool0
3`3oool2000000L0oooo0P00000>0?ooo`800000203oool200000?l0oooo903oool00?@0oooo0`00
00070?ooo`030000003oool0oooo00/0oooo100000090?ooo`030000003oool0000000d0oooo0P00
00060?ooo`800000o`3ooolV0?ooo`00l@3oool3000000X0oooo00<000000?ooo`3oool02@3oool2
00000080oooo0P00000:0?ooo`800000303oool200000?l0oooo;`3oool00>h0oooo0`00000N0?oo
o`8000002P3oool3000000X0oooo0P00003o0?ooobl0oooo003[0?ooo`<000005P3oool2000000X0
oooo0P00000:0?ooo`D000001P3oool200000?l0oooo<03oool00>P0oooo0`00000E0?ooo`@00000
303oool2000000`0oooo2@00003o0?oooc80oooo003U0?ooo`<000005P3oool200000080oooo0P00
000=0?ooo`800000o`3ooom60?ooo`00hP3oool3000001@0oooo0P0000080?ooo`8000003@3oool2
00000?l0ooooA@3oool00=h0oooo1000000E0?ooo`8000002`3oool2000000d0oooo0P00003o0?oo
od@0oooo003K0?ooo`<000005`3oool2000000030?ooo`000000oooo00/0oooo0P00000<0?ooo`80
0000o`3ooom40?ooo`00f03oool3000001P0oooo0P0000020?ooo`030000003oool0000000/0oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`3o0?oood<0oooo003E0?ooo`@00000503o
ool2000000T0oooo00<000000?ooo`0000002`3oool00`000000oooo00000002000000H0oooo0P00
003o0?ooodH0oooo003B0?ooo`<000000`3oool00`000000oooo0?ooo`0>0?ooo`@00000303oool2
000000`0oooo00@000000?ooo`000000oooo1P00003o0?ooodP0oooo003?0?ooo`<000005@3oool2
00000080oooo0P00000=0?ooo`800000303oool00`000000oooo0000003o0?ooodh0oooo003<0?oo
o`<000007@3oool2000000d0oooo0P00000;0?ooo`800000o`3ooom?0?ooo`00b@3oool3000001H0
oooo0P0000090?ooo`8000003@3oool2000000P0oooo0P00003o0?oooe40oooo00360?ooo`<00000
5@3oool4000000`0oooo0P00000<0?ooo`800000o`3ooomK0?ooo`00`P3oool4000001H0oooo0P00
00020?ooo`8000003@3oool2000000/0oooo0P00003o0?oooe/0oooo002o0?ooo`<000005@3oool2
000000P0oooo0P00000=0?ooo`8000002@3oool200000?l0ooooG03oool00;`0oooo0`00000E0?oo
o`<000002`3oool2000000d0oooo2P00003o0?oooeh0oooo002i0?ooo`<000005P3oool4000000d0
oooo0P00000<0?ooo`800000o`3ooomV0?ooo`00]P3oool3000001L0oooo0P0000020?ooo`030000
003oool0000000`0oooo00<000000?ooo`0000002P3oool200000?l0ooooI`3oool00;<0oooo0`00
000D0?ooo`8000002@3oool00`000000oooo0000000<0?ooo`040000003oool00000000000L0oooo
0P00003o0?ooofP0oooo002`0?ooo`@000004`3oool3000000`0oooo00<000000?ooo`000000303o
ool00`000000oooo0000000700000?l0ooooJP3oool00:d0oooo0`0000020?ooo`030000003oool0
oooo0100oooo0P0000000`3oool000000000000=0?ooo`030000003oool0000000`0oooo00<00000
0?ooo`000000o`3ooom`0?ooo`00ZP3oool3000000D0oooo00<000000?ooo`3oool04`3oool20000
00h0oooo00<000000?ooo`0000002`3oool200000?l0ooooL@3oool00:L0oooo0`0000040?ooo`<0
00003`3oool2000000H0oooo0P00000?0?ooo`<00000203oool200000?l0ooooL`3oool00:<0oooo
100000050?ooo`80000000<0oooo0000000000000P0000090?ooo`@000001`3oool200000180oooo
0P00003o0?ooog`0oooo002P0?ooo`<00000203oool4000000<0oooo0P0000060?ooo`8000000P3o
ool2000000L0oooo0P00000C0?ooo`800000o`3ooomk0?ooo`00W@3oool3000000d0oooo00<00000
0?ooo`3oool00`3oool2000000X0oooo100000040?ooo`800000503oool200000?l0ooooNP3oool0
09X0oooo0`00000G0?ooo`8000002P3oool2000000030?ooo`000000000000@000005@3oool20000
0?l0ooooN@3oool009L0oooo0`00000K0?ooo`8000002P3oool2000000D0oooo1P0000040?ooo`80
00002`3oool200000?l0ooooN03oool009@0oooo0`00000D0?ooo`8000002@3oool2000000X0oooo
0P00000:0?ooo`@000003P3oool200000?l0ooooM`3oool00940oooo0`00000E0?ooo`800000303o
ool2000000X0oooo0P0000080?ooo`8000003P3oool300000?l0ooooN@3oool008h0oooo0`00000F
0?ooo`80000000<0oooo0000003oool0303oool2000000X0oooo0P00003o0?oooi<0oooo002;0?oo
o`@000005P3oool200000080oooo00<000000?ooo`0000003@3oool2000000X0oooo0P00003o0?oo
oi80oooo00280?ooo`<000000`3oool00`000000oooo0?ooo`0?0?ooo`800000203oool00`000000
oooo0000000=0?ooo`8000002P3oool200000?l0ooooT@3oool008@0oooo1000000D0?ooo`@00000
2`3oool00`000000oooo0000000=0?ooo`8000002P3oool200000?l0ooooT03oool00840oooo0`00
000E0?ooo`<000000P3oool2000000`0oooo0P00000>0?ooo`8000002P3oool200000?l0ooooS`3o
ool007h0oooo0`00000N0?ooo`800000303oool2000000X0oooo0`00000=0?ooo`800000o`3ooon>
0?ooo`00N`3oool3000000H0oooo0P00000>0?ooo`8000002P3oool2000000`0oooo0P00000F0?oo
o`<00000o`3ooon@0?ooo`00N03oool3000000@0oooo1@0000020?ooo`800000203oool4000000`0
oooo00<000000?ooo`000000303oool2000000h0oooo0`00003o0?oooiL0oooo00150?ooo`D00000
0P3oool2000002L0oooo0`0000030?ooo`@000002@3oool00`000000oooo0?ooo`030?ooo`800000
0P3oool2000000d0oooo00<000000?ooo`000000303oool2000000d0oooo0P00003o0?oooiP0oooo
00170?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`<00000
1@3oool00`000000oooo0?ooo`0:0?ooo`8000002P3oool2000000d0oooo00<000000?ooo`000000
203oool300000?l0ooooZ@3oool004L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01h0oooo0`0000070?ooo`030000003oool0oooo00P0oooo1000000<0?ooo`800000
3@3oool200000?l0oooo]03oool003l0oooo100000040?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0K0?ooo`<000002P3oool00`000000oooo0?ooo`060?ooo`@00000
3`3oool2000000`0oooo0P00000>0?ooo`800000o`3ooonT0?ooo`00A`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool05`3oool4000000d0oooo0P0000050?ooo`@00000
4P3oool2000000X0oooo0P00000>0?ooo`<00000o`3ooonT0?ooo`00AP3oool2000000@0oooo0P00
000G0?ooo`<0000000<0oooo0000003oool0403oool6000001H0oooo100000040?ooo`@00000o`3o
oonf0?ooo`00HP3oool3000000@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`03
0?ooo`P000003@3oool600000?l0oooo^P3oool005l0oooo0`00000L0?ooo`8000000`3oool00`00
0000oooo0?ooo`050?ooo`8000003@3oool200000?l0oooo_@3oool005`0oooo0`00000E0?ooo`80
00002P3oool4000000P0oooo0`00000<0?ooo`800000o`3ooonl0?ooo`00F@3oool3000001@0oooo
1000000>0?ooo`8000002@3oool200000080oooo00<000000?ooo`3oool0203oool200000?l0oooo
^`3oool005H0oooo0`00000E0?ooo`8000000P3oool2000000h0oooo00<000000?ooo`000000203o
ool00`000000oooo00000003000000X0oooo0P00003o0?oookX0oooo001C0?ooo`<000007@3oool2
000000h0oooo0`0000060?ooo`030000003oool0oooo00l0oooo0P00003o0?oookT0oooo001@0?oo
o`<000008@3oool2000000l0oooo2000000>0?ooo`<00000o`3ooonk0?ooo`00C@3oool3000001@0
oooo1@00000<0?ooo`800000o`3ooooR0?ooo`00B@3oool4000001D0oooo0P0000050?ooo`<00000
2P3oool200000?l0ooooh@3oool004H0oooo0`00000H0?ooo`030000003oool0oooo01<0oooo0P00
003o0?ooon00oooo00130?ooo`@000006@3oool00`000000oooo0?ooo`0E0?ooo`8000000`3oool2
00000?l0oooofP3oool00400oooo0`0000030?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0103oool2000000`0oooo0P00000:0?ooo`@00000o`3ooooL0?ooo`00?@3oool3000000H0
oooo00<000000?ooo`3oool0303oool3000000L0oooo0P0000080?ooo`@0000000<0oooo00000000
00001P3oool3000000030?ooo`000000000000D0oooo00<000000?ooo`3oool0o`3ooooE0?ooo`00
>P3oool3000000T0oooo00<000000?ooo`3oool02`3oool3000000T0oooo0P0000030?ooo`@00000
1P3oool00`000000oooo0?ooo`090?ooo`8000000`3oool400000?l0ooooe@3oool003L0oooo0`00
000D0?ooo`X00000203oool00`000000oooo00000002000000X0oooo00<000000?ooo`3oool02P3o
ool400000080oooo00<000000?ooo`3oool0o`3ooooD0?ooo`00=03oool3000001H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo000000080?ooo`@000001`3oool3000000h0oooo1@00003o
0?ooomL0oooo000a0?ooo`<00000603oool2000000T0oooo00<000000?ooo`0000002@3oool90000
0?l0ooook@3oool002h0oooo0`00000J0?ooo`8000002`3oool00`000000oooo0000000;0?ooo`<0
0000o`3oooo`0?ooo`00:P3oool4000001d0oooo0P00000<0?ooo`040000003oool0000000000?l0
ooooo03oool002L0oooo0`00000Q0?ooo`030000003oool0000000`0oooo0P0000000`3oool00000
0?ooo`3o0?ooooX0oooo000T0?ooo`<000005P3oool8000000L0oooo00<000000?ooo`0000002`3o
ool01@000000oooo0000003oool000000?l0oooonP3oool00240oooo0`00000G0?ooo`800000403o
ool3000000X0oooo00H000000?ooo`3oool000000?ooo`00003o0?ooooT0oooo000N0?ooo`<00000
0P3oool00`000000oooo0?ooo`0C0?ooo`800000503oool;000000@0oooo00<000000?ooo`000000
o`3ooooh0?ooo`006`3oool3000000D0oooo00<000000?ooo`3oool04P3oool2000001P0oooo1000
00090?ooo`030000003oool000000?l0oooom`3oool001P0oooo0`00000M0?ooo`800000303oool3
000001L0oooo0`00003o0?ooooH0oooo000E0?ooo`<00000803oool2000000`0oooo1000000D0?oo
o`@00000o`3oooog0?ooo`004P3oool3000001D0oooo1`0000080?ooo`8000003@3oool00`000000
oooo0?ooo`3o0?ooool0oooo3`3oool000h0oooo1000000F0?ooo`800000103oool5000000L0oooo
0`00000:0?ooo`030000003oool0oooo0?l0ooooo`3oool@0?ooo`002`3oool3000001D0oooo0P00
00020?ooo`030000003oool0oooo00L0oooo0`0000080?ooo`@000001P3oool200000?l0ooooo`3o
oolB0?ooo`00203oool3000001T0oooo0`00000<0?ooo`<000002@3oool700000?l0ooooo`3ooolD
0?ooo`001@3oool3000001D0oooo0P0000060?ooo`8000003@3oool200000?l0ooooo`3ooolT0?oo
o`000P3oool3000001L0oooo0P0000080?ooo`800000303oool200000?l0ooooo`3ooolT0?ooo`00
0P00000D0?ooo`D0000000<0oooo0000000000002@3oool2000000/0oooo0P00003o0?ooool0oooo
903oool000030000003oool0oooo0140oooo0P0000050?ooo`80000000<0oooo0000003oool0203o
ool2000000X0oooo0P00003o0?ooool0oooo903oool000030000003oool0oooo0100oooo00<00000
0?ooo`3oool01`3oool010000000oooo0000000000080?ooo`@000001P3oool200000?l0ooooo`3o
oolU0?ooo`004P3oool2000000X0oooo00@000000?ooo`3oool000002@3oool800000?l0ooooo`3o
oolW0?ooo`004P3oool2000000X0oooo0`0000000`3oool000000?ooo`080?ooo`800000o`3ooooo
0?ooob`0oooo000C0?ooo`8000001P3oool300000080oooo0`00000:0?ooo`800000o`3ooooo0?oo
ob/0oooo000D0?ooo`L000001`3oool00`000000oooo0?ooo`090?ooo`800000o`3ooooo0?ooobX0
oooo000R0?ooo`030000003oool0oooo00X0oooo0P00003o0?ooool0oooo:@3oool001P0oooo0P00
00050?ooo`<000003P3oool200000?l0ooooo`3ooolX0?ooo`006@3oool6000000h0oooo0`00003o
0?ooool0oooo:P3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0oooo
FP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0
ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {209, 0}} -> {0.0483161, 0.300546, 0.00171557, \
0.00171557}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<`1234567890-=~!@#$%^&*()_+\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35122 
%%ImageSize: 600 210.734 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0503484 1.05035 -0.338563 1.05035 [
[.14959 .25305 -8.42975 -9 ]
[.14959 .25305 9.57025 0 ]
[.45958 .15258 -2.99091 -9 ]
[.45958 .15258 3.00909 0 ]
[.79405 .04422 -6.38896 -9 ]
[.79405 .04422 5.61104 0 ]
[.4589 .08722 -4.98397 -12.75 ]
[.4589 .08722 5.01603 0 ]
[.99105 .00513 0 -5.94879 ]
[.99105 .00513 24 3.05121 ]
[.99841 .01586 0 -5.94225 ]
[.99841 .01586 6 3.05775 ]
[1.00572 .02651 0 -5.93578 ]
[1.00572 .02651 18 3.06422 ]
[1.06092 -0.00418 0 -8.41819 ]
[1.06092 -0.00418 10 4.33181 ]
[ 0 0 0 0 ]
[ 1 .35122 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00053 .31406 m
.97227 0 L
s
.14876 .26616 m
.14834 .27271 L
s
[(-10)] .14959 .25305 -0.06336 1 Mshowa
.45954 .16571 m
.45952 .17228 L
s
[(0)] .45958 .15258 -0.00303 1 Mshowa
.7949 .05733 m
.79532 .06388 L
s
[(10)] .79405 .04422 .06483 1 Mshowa
.125 Mabswid
.20908 .24666 m
.20887 .25059 L
s
.2703 .22687 m
.27014 .23081 L
s
.33243 .20679 m
.33232 .21073 L
s
.39551 .18641 m
.39544 .19035 L
s
.52455 .1447 m
.52459 .14864 L
s
.59057 .12336 m
.59067 .1273 L
s
.65762 .10169 m
.65777 .10563 L
s
.72572 .07968 m
.72592 .08362 L
s
.08931 .28537 m
.08902 .28929 L
s
.03073 .3043 m
.03039 .30823 L
s
.86518 .03461 m
.86549 .03854 L
s
.93659 .01153 m
.93696 .01545 L
s
gsave
.4589 .08722 -65.984 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97227 0 m
.99936 .03946 L
s
.97855 .00915 m
.9723 .01116 L
s
[(-0.5)] .99105 .00513 -1 .32195 Mshowa
.98591 .01986 m
.97965 .02187 L
s
[(0)] .99841 .01586 -1 .3205 Mshowa
.99321 .0305 m
.98695 .0325 L
s
[(0.5)] 1.00572 .02651 -1 .31906 Mshowa
.125 Mabswid
.98003 .0113 m
.97628 .0125 L
s
.9815 .01344 m
.97775 .01465 L
s
.98297 .01559 m
.97922 .01679 L
s
.98444 .01773 m
.98069 .01893 L
s
.98737 .022 m
.98362 .0232 L
s
.98883 .02413 m
.98508 .02533 L
s
.99029 .02626 m
.98654 .02745 L
s
.99175 .02838 m
.988 .02958 L
s
.97707 .007 m
.97332 .0082 L
s
.97559 .00484 m
.97184 .00605 L
s
.97411 .00268 m
.97036 .00389 L
s
.97263 .00052 m
.96888 .00173 L
s
.99466 .03262 m
.99091 .03382 L
s
.99611 .03473 m
.99236 .03593 L
s
.99756 .03685 m
.99381 .03804 L
s
.99901 .03895 m
.99526 .04015 L
s
gsave
1.06092 -0.00418 -61 -12.4182 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35122 L
0 .35122 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05333 .33687 m
.05068 .33644 L
s
.05333 .33687 m
.05492 .32873 L
s
.05068 .33644 m
.05492 .32873 L
s
.08358 .32724 m
.06136 .30737 L
s
.07563 .32595 m
.08358 .32724 L
s
.08093 .32681 m
.05976 .30788 L
s
.07138 .32603 m
.07563 .32595 L
s
.10498 .31915 m
.11085 .31856 L
s
.10232 .31872 m
.10498 .31915 L
s
.09862 .31734 m
.10232 .31872 L
s
.11085 .31856 m
.11729 .31651 L
s
.09757 .31639 m
.09862 .31734 L
s
.10023 .31683 m
.10079 .31537 L
s
.11729 .31651 m
.11947 .31454 L
s
.11729 .31651 m
.12109 .31403 L
s
.09813 .31493 m
.09757 .31639 L
s
.10079 .31537 m
.09813 .31493 L
s
.11947 .31454 m
.12004 .31308 L
s
.12109 .31403 m
.12166 .31256 L
s
.12004 .31308 m
.11957 .31066 L
s
.12166 .31256 m
.12119 .31015 L
s
.11957 .31066 m
.11748 .30876 L
s
.12119 .31015 m
.1191 .30824 L
s
.05334 .30995 m
.06779 .3053 L
s
.13726 .30888 m
.14316 .30828 L
s
.1346 .30844 m
.13726 .30888 L
s
.11748 .30876 m
.11378 .30737 L
s
.1309 .30705 m
.1346 .30844 L
s
.14316 .30828 m
.14965 .30621 L
s
.1191 .30824 m
.11539 .30685 L
s
.11378 .30737 m
.10683 .30701 L
s
.09399 .30725 m
.08865 .30637 L
s
.09827 .30717 m
.09399 .30725 L
s
.10683 .30701 m
.09827 .30717 L
s
.10845 .30649 m
.09827 .30717 L
s
.12986 .30609 m
.1309 .30705 L
s
.11539 .30685 m
.10845 .30649 L
s
.13252 .30653 m
.1331 .30506 L
s
.08865 .30637 m
.08387 .30402 L
s
.14965 .30621 m
.15187 .30422 L
s
.14965 .30621 m
.15349 .30371 L
s
.13044 .30462 m
.12986 .30609 L
s
.1331 .30506 m
.13044 .30462 L
s
.15187 .30422 m
.15143 .30179 L
s
.08387 .30402 m
.08068 .30115 L
s
.15349 .30371 m
.15305 .30127 L
s
.08548 .30351 m
.08871 .30247 L
s
.08281 .30307 m
.08548 .30351 L
s
.08871 .30247 m
.09362 .29699 L
s
.08871 .30247 m
.09467 .29795 L
s
.15143 .30179 m
.14832 .29891 L
s
.15305 .30127 m
.14994 .29839 L
s
.14031 .29759 m
.13543 .29915 L
s
.14832 .29891 m
.14461 .29751 L
s
.10651 .29675 m
.10861 .29867 L
s
.14994 .29839 m
.14624 .29699 L
s
.09467 .29795 m
.09953 .29639 L
s
.14031 .29759 m
.14253 .29559 L
s
.14461 .29751 m
.14031 .29759 L
s
.14624 .29699 m
.14031 .29759 L
s
.09362 .29699 m
.1001 .29491 L
s
.10278 .29535 m
.10651 .29675 L
s
.10383 .29631 m
.10651 .29675 L
s
.09953 .29639 m
.10383 .29631 L
s
.12103 .29599 m
.1216 .29451 L
s
.11835 .29555 m
.12103 .29599 L
s
.14253 .29559 m
.14371 .29262 L
s
.1173 .29459 m
.11835 .29555 L
s
.1001 .29491 m
.10278 .29535 L
s
.18391 .29531 m
.15039 .28658 L
s
.18391 .29531 m
.1622 .27494 L
s
.11683 .29214 m
.1173 .29459 L
s
.1216 .29451 m
.11893 .29407 L
s
.14312 .29411 m
.14162 .29069 L
s
.18022 .29391 m
.16055 .27547 L
s
.14371 .29262 m
.14325 .29017 L
s
.1174 .29065 m
.11683 .29214 L
s
.14162 .29069 m
.13849 .28779 L
s
.12124 .28811 m
.1174 .29065 L
s
.14325 .29017 m
.14012 .28726 L
s
.20362 .28904 m
.22011 .28379 L
s
.20362 .28904 m
.19007 .28039 L
s
.12776 .28601 m
.12124 .28811 L
s
.20259 .28807 m
.21084 .28545 L
s
.13849 .28779 m
.13476 .28638 L
s
.14012 .28726 m
.13639 .28585 L
s
.15039 .28658 m
.17666 .27815 L
s
.13476 .28638 m
.13208 .28593 L
s
.13208 .28593 m
.12776 .28601 L
s
.13371 .28541 m
.12776 .28601 L
s
.13639 .28585 m
.13371 .28541 L
s
.21084 .28545 m
.22011 .28379 L
s
.19542 .28128 m
.2014 .28067 L
s
.19007 .28039 m
.19542 .28128 L
s
.2014 .28067 m
.20635 .27909 L
s
.20635 .27909 m
.20864 .27706 L
s
.20635 .27909 m
.21029 .27653 L
s
.20864 .27706 m
.2099 .27404 L
s
.15561 .27706 m
.16714 .27335 L
s
.21029 .27653 m
.21156 .27351 L
s
.23898 .27649 m
.23363 .27559 L
s
.24498 .27588 m
.23898 .27649 L
s
.24064 .27596 m
.23529 .27506 L
s
.24498 .27588 m
.24064 .27596 L
s
.24997 .27429 m
.24498 .27588 L
s
.23363 .27559 m
.22993 .27417 L
s
.23529 .27506 m
.2316 .27364 L
s
.18656 .27498 m
.18718 .27347 L
s
.18388 .27453 m
.18656 .27498 L
s
.18284 .27355 m
.18388 .27453 L
s
.25229 .27225 m
.24997 .27429 L
s
.22993 .27417 m
.2242 .27078 L
s
.2099 .27404 m
.20848 .27057 L
s
.2316 .27364 m
.22586 .27025 L
s
.18242 .27106 m
.18284 .27355 L
s
.21156 .27351 m
.21014 .27004 L
s
.18718 .27347 m
.18449 .27302 L
s
.25194 .26976 m
.25229 .27225 L
s
.18304 .26955 m
.18242 .27106 L
s
.2242 .27078 m
.21806 .26488 L
s
.20848 .27057 m
.20643 .26861 L
s
.25027 .27029 m
.24759 .26984 L
s
.22586 .27025 m
.21972 .26435 L
s
.21014 .27004 m
.20809 .26808 L
s
.24759 .26984 m
.24824 .26832 L
s
.25092 .26877 m
.25194 .26976 L
s
.18697 .26697 m
.18304 .26955 L
s
.26665 .26898 m
.2606 .26307 L
s
.24824 .26832 m
.25092 .26877 L
s
.23085 .26865 m
.22548 .26775 L
s
.23686 .26804 m
.23085 .26865 L
s
.20643 .26861 m
.20168 .26619 L
s
.20809 .26808 m
.20334 .26566 L
s
.23853 .2675 m
.23686 .26804 L
s
.22548 .26775 m
.22075 .26533 L
s
.24085 .26545 m
.23853 .2675 L
s
.24252 .26492 m
.23853 .2675 L
s
.27166 .26738 m
.27501 .26632 L
s
.26631 .26648 m
.27166 .26738 L
s
.19194 .26537 m
.18697 .26697 L
s
.26631 .26648 m
.27066 .2664 L
s
.26262 .26504 m
.26631 .26648 L
s
.27066 .2664 m
.27401 .26533 L
s
.27501 .26632 m
.28039 .26069 L
s
.20168 .26619 m
.19629 .26529 L
s
.20334 .26566 m
.19795 .26476 L
s
.24215 .26242 m
.24085 .26545 L
s
.19629 .26529 m
.19194 .26537 L
s
.19795 .26476 m
.19194 .26537 L
s
.27401 .26533 m
.28039 .26069 L
s
.24382 .26188 m
.24252 .26492 L
s
.21806 .26488 m
.21665 .26139 L
s
.21972 .26435 m
.21831 .26085 L
s
.24077 .25892 m
.24215 .26242 L
s
.24244 .25838 m
.24382 .26188 L
s
.29011 .26151 m
.28711 .25854 L
s
.28643 .26007 m
.29011 .26151 L
s
.21665 .26139 m
.21793 .25834 L
s
.21831 .26085 m
.21959 .2578 L
s
.28039 .26069 m
.28375 .25962 L
s
.28375 .25962 m
.28643 .26007 L
s
.23975 .25793 m
.24077 .25892 L
s
.28711 .25854 m
.28242 .25611 L
s
.24142 .25739 m
.24244 .25838 L
s
.21793 .25834 m
.22191 .25574 L
s
.23501 .25549 m
.23975 .25793 L
s
.21959 .2578 m
.22191 .25574 L
s
.23669 .25495 m
.24142 .25739 L
s
.30259 .25623 m
.2989 .25479 L
s
.30864 .25561 m
.30259 .25623 L
s
.28242 .25611 m
.26897 .25383 L
s
.28242 .25611 m
.27065 .2533 L
s
.22191 .25574 m
.22525 .25466 L
s
.30427 .2557 m
.30059 .25425 L
s
.30864 .25561 m
.30427 .2557 L
s
.3154 .25346 m
.30864 .25561 L
s
.22962 .25458 m
.23501 .25549 L
s
.23129 .25404 m
.23669 .25495 L
s
.2989 .25479 m
.2959 .2518 L
s
.22525 .25466 m
.22962 .25458 L
s
.22525 .25466 m
.23129 .25404 L
s
.30059 .25425 m
.29759 .25127 L
s
.26897 .25383 m
.26527 .25238 L
s
.31779 .25139 m
.3154 .25346 L
s
.31949 .25085 m
.3154 .25346 L
s
.27065 .2533 m
.26695 .25185 L
s
.26527 .25238 m
.26054 .24994 L
s
.26695 .25185 m
.26223 .2494 L
s
.2959 .2518 m
.29559 .24927 L
s
.3175 .24886 m
.31779 .25139 L
s
.29759 .25127 m
.29728 .24873 L
s
.3192 .24832 m
.31949 .25085 L
s
.26054 .24994 m
.25546 .24495 L
s
.26223 .2494 m
.25714 .24441 L
s
.29559 .24927 m
.29966 .24665 L
s
.31452 .24586 m
.3175 .24886 L
s
.29728 .24873 m
.29966 .24665 L
s
.31621 .24532 m
.3192 .24832 L
s
.29358 .24728 m
.29089 .24682 L
s
.29966 .24665 m
.29358 .24728 L
s
.29089 .24682 m
.28719 .24536 L
s
.29527 .24674 m
.29258 .24628 L
s
.29966 .24665 m
.29527 .24674 L
s
.29966 .24665 m
.30643 .24449 L
s
.29258 .24628 m
.28888 .24482 L
s
.31082 .24441 m
.31452 .24586 L
s
.28719 .24536 m
.28315 .24136 L
s
.31252 .24386 m
.31621 .24532 L
s
.33816 .24491 m
.34425 .24428 L
s
.33278 .24399 m
.33816 .24491 L
s
.28888 .24482 m
.28484 .24082 L
s
.30883 .2424 m
.30643 .24449 L
s
.31052 .24186 m
.30643 .24449 L
s
.30643 .24449 m
.31082 .24441 L
s
.30643 .24449 m
.31252 .24386 L
s
.33986 .24436 m
.34425 .24428 L
s
.33448 .24345 m
.33986 .24436 L
s
.34425 .24428 m
.34766 .2432 L
s
.3281 .24153 m
.33278 .24399 L
s
.32981 .24098 m
.33448 .24345 L
s
.34766 .2432 m
.35009 .24111 L
s
.34766 .2432 m
.35179 .24056 L
s
.30952 .24086 m
.30883 .2424 L
s
.31122 .24031 m
.31052 .24186 L
s
.32711 .24052 m
.3281 .24153 L
s
.28315 .24136 m
.28282 .23881 L
s
.35009 .24111 m
.35153 .23801 L
s
.32881 .23998 m
.32981 .24098 L
s
.30922 .23831 m
.30952 .24086 L
s
.28484 .24082 m
.28452 .23826 L
s
.35179 .24056 m
.35324 .23747 L
s
.32583 .23696 m
.32711 .24052 L
s
.31092 .23776 m
.31122 .24031 L
s
.32753 .23642 m
.32881 .23998 L
s
.28282 .23881 m
.28351 .23726 L
s
.30521 .23428 m
.30922 .23831 L
s
.28452 .23826 m
.2852 .23671 L
s
.35153 .23801 m
.35028 .23445 L
s
.30691 .23373 m
.31092 .23776 L
s
.35324 .23747 m
.35199 .2339 L
s
.28351 .23726 m
.28758 .23462 L
s
.32725 .23386 m
.32583 .23696 L
s
.2852 .23671 m
.28758 .23462 L
s
.32895 .23331 m
.32753 .23642 L
s
.28758 .23462 m
.29438 .23243 L
s
.35028 .23445 m
.34434 .22839 L
s
.3015 .23281 m
.30521 .23428 L
s
.37232 .23403 m
.36595 .23209 L
s
.37845 .2334 m
.37232 .23403 L
s
.35199 .2339 m
.34606 .22784 L
s
.33137 .23121 m
.32725 .23386 L
s
.3032 .23226 m
.30691 .23373 L
s
.37404 .23348 m
.37134 .23302 L
s
.37845 .2334 m
.37404 .23348 L
s
.34929 .23344 m
.34461 .23096 L
s
.38188 .2323 m
.37845 .2334 L
s
.33137 .23121 m
.32895 .23331 L
s
.37134 .23302 m
.36767 .23155 L
s
.29879 .23235 m
.3015 .23281 L
s
.29438 .23243 m
.29879 .23235 L
s
.29438 .23243 m
.30049 .2318 L
s
.38435 .2302 m
.38188 .2323 L
s
.38607 .22965 m
.38188 .2323 L
s
.30049 .2318 m
.3032 .23226 L
s
.36595 .23209 m
.35931 .22758 L
s
.36767 .23155 m
.36103 .22704 L
s
.33308 .23066 m
.33137 .23121 L
s
.34461 .23096 m
.33921 .23003 L
s
.33921 .23003 m
.33308 .23066 L
s
.32155 .23037 m
.32226 .22881 L
s
.31884 .2299 m
.32155 .23037 L
s
.38509 .22864 m
.38435 .2302 L
s
.31784 .22889 m
.31884 .2299 L
s
.38658 .22551 m
.38607 .22965 L
s
.31755 .22632 m
.31784 .22889 L
s
.32226 .22881 m
.31955 .22834 L
s
.38486 .22606 m
.38509 .22864 L
s
.34434 .22839 m
.33866 .22488 L
s
.34606 .22784 m
.34037 .22433 L
s
.35931 .22758 m
.35635 .22454 L
s
.36103 .22704 m
.35807 .22399 L
s
.31996 .2242 m
.31755 .22632 L
s
.38169 .22043 m
.38486 .22606 L
s
.38342 .21988 m
.38658 .22551 L
s
.33866 .22488 m
.33495 .2234 L
s
.35635 .22454 m
.35312 .2189 L
s
.34037 .22433 m
.33666 .22285 L
s
.3251 .22255 m
.31996 .2242 L
s
.35807 .22399 m
.35484 .21835 L
s
.33495 .2234 m
.32952 .22247 L
s
.33666 .22285 m
.33124 .22192 L
s
.32952 .22247 m
.3251 .22255 L
s
.33124 .22192 m
.3251 .22255 L
s
.37875 .21737 m
.38169 .22043 L
s
.38047 .21682 m
.38342 .21988 L
s
.35312 .2189 m
.35359 .21473 L
s
.35484 .21835 m
.35458 .21575 L
s
.37209 .21281 m
.37875 .21737 L
s
.37382 .21226 m
.38047 .21682 L
s
.35458 .21575 m
.35531 .21418 L
s
.35359 .21473 m
.35777 .21204 L
s
.35531 .21418 m
.35777 .21204 L
s
.39259 .21294 m
.42389 .20292 L
s
.36839 .21132 m
.37209 .21281 L
s
.3674 .21029 m
.37382 .21226 L
s
.35777 .21204 m
.36122 .21093 L
s
.36567 .21085 m
.36839 .21132 L
s
.36122 .21093 m
.36567 .21085 L
s
.36122 .21093 m
.3674 .21029 L
s
.44078 .20154 m
.4724 .19143 L
s
.43498 .19533 m
.46665 .18517 L
s
.48558 .18587 m
.49007 .18578 L
s
.48094 .1833 m
.48558 .18587 L
s
.49007 .18578 m
.49361 .18465 L
s
.48462 .18483 m
.48912 .18474 L
s
.48094 .1833 m
.48462 .18483 L
s
.48912 .18474 m
.49266 .18361 L
s
.49361 .18465 m
.49621 .18247 L
s
.49266 .18361 m
.49526 .18142 L
s
.47903 .1812 m
.48094 .1833 L
s
.49621 .18247 m
.50046 .17705 L
s
.53934 .1795 m
.53942 .18217 L
s
.53942 .18217 m
.53577 .18064 L
s
.49526 .18142 m
.49951 .176 L
s
.53577 .18064 m
.52628 .16742 L
s
.53755 .18007 m
.53193 .17376 L
s
.52628 .16742 m
.53934 .1795 L
s
.51482 .17516 m
.51671 .17727 L
s
.50046 .17705 m
.50307 .17486 L
s
.49951 .176 m
.50212 .1738 L
s
.5102 .17257 m
.51482 .17516 L
s
.51115 .17363 m
.51482 .17516 L
s
.50307 .17486 m
.50663 .17371 L
s
.50212 .1738 m
.50568 .17266 L
s
.50663 .17371 m
.51115 .17363 L
s
.55902 .17323 m
.55357 .17226 L
s
.56353 .17314 m
.55902 .17323 L
s
.56985 .17248 m
.56353 .17314 L
s
.50568 .17266 m
.5102 .17257 L
s
.57524 .17077 m
.56985 .17248 L
s
.55357 .17226 m
.54991 .17072 L
s
.57971 .16799 m
.57524 .17077 L
s
.54991 .17072 m
.54532 .16812 L
s
.54532 .16812 m
.5425 .16494 L
s
.58239 .16578 m
.57971 .16799 L
s
.56068 .16729 m
.55796 .1668 L
s
.56521 .1672 m
.56068 .16729 L
s
.56521 .1672 m
.55975 .16623 L
s
.57061 .16547 m
.56521 .1672 L
s
.55796 .1668 m
.55336 .16419 L
s
.55975 .16623 m
.55516 .16362 L
s
.58416 .16251 m
.58239 .16578 L
s
.57328 .16326 m
.57061 .16547 L
s
.5425 .16494 m
.54148 .16118 L
s
.55336 .16419 m
.55055 .161 L
s
.57601 .16375 m
.56678 .15581 L
s
.55516 .16362 m
.55235 .16043 L
s
.57323 .16056 m
.57328 .16326 L
s
.57782 .16317 m
.56858 .15523 L
s
.58411 .15981 m
.58416 .16251 L
s
.5224 .16047 m
.52155 .16211 L
s
.52155 .16211 m
.51881 .16162 L
s
.62044 .1618 m
.57818 .13147 L
s
.51881 .16162 m
.51965 .15998 L
s
.54148 .16118 m
.5414 .15847 L
s
.55055 .161 m
.55048 .1583 L
s
.51965 .15998 m
.5224 .16047 L
s
.55235 .16043 m
.55228 .15772 L
s
.58315 .15603 m
.58411 .15981 L
s
.5414 .15847 m
.54312 .15518 L
s
.63133 .15834 m
.58914 .12793 L
s
.55048 .1583 m
.55314 .15607 L
s
.55228 .15772 m
.55314 .15607 L
s
.55314 .15607 m
.55856 .15434 L
s
.5813 .15389 m
.58315 .15603 L
s
.56678 .15581 m
.56491 .15367 L
s
.5631 .15425 m
.56678 .15581 L
s
.56858 .15523 m
.56672 .15309 L
s
.54312 .15518 m
.54578 .15296 L
s
.55856 .15434 m
.5631 .15425 L
s
.5767 .15126 m
.5813 .15389 L
s
.56491 .15367 m
.56759 .15144 L
s
.56672 .15309 m
.56759 .15144 L
s
.54578 .15296 m
.55025 .15014 L
s
.59583 .15197 m
.62132 .14383 L
s
.56759 .15144 m
.57121 .15028 L
s
.65321 .15139 m
.62681 .11996 L
s
.57121 .15028 m
.5767 .15126 L
s
.55025 .15014 m
.55568 .1484 L
s
.66052 .14907 m
.63418 .11759 L
s
.55568 .1484 m
.56204 .14773 L
s
.5666 .14764 m
.56935 .14813 L
s
.64321 .14777 m
.63774 .14679 L
s
.6496 .1471 m
.64321 .14777 L
s
.56204 .14773 m
.5666 .14764 L
s
.65692 .14477 m
.6496 .1471 L
s
.63774 .14679 m
.63593 .14464 L
s
.58847 .14612 m
.61399 .13793 L
s
.66153 .14194 m
.65692 .14477 L
s
.63593 .14464 m
.63777 .14131 L
s
.63593 .14464 m
.63594 .1419 L
s
.6634 .13861 m
.66153 .14194 L
s
.63594 .1419 m
.63686 .14023 L
s
.63777 .14131 m
.64052 .13906 L
s
.63686 .14023 m
.63961 .13798 L
s
.66156 .1392 m
.65882 .1387 L
s
.64052 .13906 m
.64972 .13337 L
s
.65882 .1387 m
.65976 .13703 L
s
.6625 .13753 m
.6634 .13861 L
s
.63961 .13798 m
.64881 .13229 L
s
.65976 .13703 m
.6625 .13753 L
s
.67808 .13667 m
.68266 .13658 L
s
.67444 .13509 m
.67808 .13667 L
s
.68266 .13658 m
.68634 .13541 L
s
.68634 .13541 m
.68914 .13315 L
s
.68634 .13541 m
.68825 .13206 L
s
.67265 .13292 m
.67444 .13509 L
s
.64972 .13337 m
.65249 .13111 L
s
.68914 .13315 m
.6938 .13029 L
s
.67454 .12957 m
.67265 .13292 L
s
.64881 .13229 m
.65158 .13002 L
s
.62772 .13215 m
.62864 .13047 L
s
.62497 .13165 m
.62772 .13215 L
s
.68825 .13206 m
.68647 .12989 L
s
.62405 .13057 m
.62497 .13165 L
s
.65249 .13111 m
.65343 .12943 L
s
.62588 .12721 m
.62405 .13057 L
s
.62864 .13047 m
.62588 .12998 L
s
.6938 .13029 m
.69935 .12852 L
s
.65158 .13002 m
.65345 .12666 L
s
.68647 .12989 m
.68283 .1283 L
s
.67823 .12839 m
.67454 .12957 L
s
.65343 .12943 m
.65345 .12666 L
s
.69935 .12852 m
.7058 .12784 L
s
.68283 .1283 m
.67823 .12839 L
s
.7058 .12784 m
.7104 .12775 L
s
.7104 .12775 m
.65818 .11544 L
s
.63048 .12434 m
.62588 .12721 L
s
.65345 .12666 m
.64982 .12229 L
s
.63785 .12197 m
.63048 .12434 L
s
.64982 .12229 m
.6443 .12129 L
s
.6443 .12129 m
.63785 .12197 L
s
.68587 .11489 m
.68221 .11328 L
s
.69049 .11479 m
.68587 .11489 L
s
.69421 .1136 m
.69049 .11479 L
s
.69614 .1102 m
.69421 .1136 L
s
.68221 .11328 m
.68041 .11108 L
s
.68041 .11108 m
.68232 .10767 L
s
.69434 .10799 m
.69614 .1102 L
s
.72852 .10956 m
.73911 .09921 L
s
.70912 .10882 m
.72852 .10956 L
s
.70912 .10882 m
.72763 .10845 L
s
.72763 .10845 m
.73911 .09921 L
s
.69068 .10638 m
.69434 .10799 L
s
.68232 .10767 m
.68605 .10647 L
s
.77118 .10702 m
.76756 .10541 L
s
.77581 .10693 m
.77118 .10702 L
s
.77872 .10463 m
.77581 .10693 L
s
.68605 .10647 m
.69068 .10638 L
s
.76756 .10541 m
.76582 .10319 L
s
.77887 .10181 m
.77872 .10463 L
s
.76582 .10319 m
.76596 .10037 L
s
.76582 .10319 m
.76509 .09926 L
s
.77713 .09958 m
.77887 .10181 L
s
.76596 .10037 m
.77148 .08322 L
s
.77351 .09796 m
.77713 .09958 L
s
.76509 .09926 m
.76624 .09471 L
s
.76799 .09694 m
.77351 .09796 L
s
.75317 .0961 m
.76799 .09694 L
s
.75505 .0955 m
.76058 .09652 L
s
.74952 .09448 m
.75317 .0961 L
s
.75141 .09387 m
.75505 .0955 L
s
.76624 .09471 m
.76959 .08383 L
s
.74688 .09112 m
.74952 .09448 L
s
.74877 .09052 m
.75141 .09387 L
s
.78864 .09313 m
.78588 .09261 L
s
.79054 .09252 m
.78864 .09313 L
s
.78588 .09261 m
.78225 .09098 L
s
.79157 .0908 m
.79054 .09252 L
s
.78967 .0914 m
.78691 .09089 L
s
.747 .08828 m
.74688 .09112 L
s
.78225 .09098 m
.77411 .08659 L
s
.78691 .09089 m
.78794 .08916 L
s
.79071 .08968 m
.79157 .0908 L
s
.74889 .08767 m
.74877 .09052 L
s
.78794 .08916 m
.79071 .08968 L
s
.75179 .08533 m
.747 .08828 L
s
.75179 .08533 m
.74889 .08767 L
s
.77411 .08659 m
.76769 .08444 L
s
.81421 .08636 m
.80387 .07282 L
s
.85898 .08603 m
.85347 .085 L
s
.80211 .08603 m
.81603 .07315 L
s
.75747 .0835 m
.75179 .08533 L
s
.85347 .085 m
.84627 .08172 L
s
.85347 .085 m
.84711 .08285 L
s
.76769 .08444 m
.76214 .08341 L
s
.76959 .08383 m
.77163 .08036 L
s
.76214 .08341 m
.75747 .0835 L
s
.77148 .08322 m
.77353 .07975 L
s
.84711 .08285 m
.83989 .07956 L
s
.87049 .08238 m
.87266 .0789 L
s
.84627 .08172 m
.84181 .07895 L
s
.77163 .08036 m
.77646 .0774 L
s
.82118 .07994 m
.79692 .07928 L
s
.77353 .07975 m
.77646 .0774 L
s
.83989 .07956 m
.83372 .07452 L
s
.84181 .07895 m
.83564 .07391 L
s
.87266 .0789 m
.87316 .07315 L
s
.87266 .0789 m
.874 .07429 L
s
.78114 .0773 m
.78201 .07843 L
s
.77646 .0774 m
.77836 .07678 L
s
.77836 .07678 m
.78114 .0773 L
s
.83372 .07452 m
.8303 .06999 L
s
.874 .07429 m
.8745 .06852 L
s
.83564 .07391 m
.83222 .06937 L
s
.87316 .07315 m
.87257 .06913 L
s
.8303 .06999 m
.82794 .06368 L
s
.83222 .06937 m
.82986 .06306 L
s
.87257 .06913 m
.8703 .06282 L
s
.8745 .06852 m
.87224 .0622 L
s
.82794 .06368 m
.82835 .05787 L
s
.82986 .06306 m
.82921 .05901 L
s
.8703 .06282 m
.86693 .05825 L
s
.87224 .0622 m
.86887 .05763 L
s
.82921 .05901 m
.82963 .05318 L
s
.86693 .05825 m
.86076 .05313 L
s
.82835 .05787 m
.82963 .05318 L
s
.86887 .05763 m
.8627 .05251 L
s
.82963 .05318 m
.83177 .04963 L
s
.86076 .05313 m
.85627 .05031 L
s
.8627 .05251 m
.85542 .04915 L
s
.85627 .05031 m
.84898 .04694 L
s
.85542 .04915 m
.84898 .04694 L
s
.9501 .04723 m
.93533 .02631 L
s
.84898 .04694 m
.84339 .04588 L
s
.92507 .04246 m
.96048 .03113 L
s
.86477 .03898 m
.90391 .02635 L
s
0 g
.25 Mabswid
.00053 .31406 m
.97227 0 L
s
.14876 .26616 m
.14834 .27271 L
s
[(-10)] .14959 .25305 -0.06336 1 Mshowa
.45954 .16571 m
.45952 .17228 L
s
[(0)] .45958 .15258 -0.00303 1 Mshowa
.7949 .05733 m
.79532 .06388 L
s
[(10)] .79405 .04422 .06483 1 Mshowa
.125 Mabswid
.20908 .24666 m
.20887 .25059 L
s
.2703 .22687 m
.27014 .23081 L
s
.33243 .20679 m
.33232 .21073 L
s
.39551 .18641 m
.39544 .19035 L
s
.52455 .1447 m
.52459 .14864 L
s
.59057 .12336 m
.59067 .1273 L
s
.65762 .10169 m
.65777 .10563 L
s
.72572 .07968 m
.72592 .08362 L
s
.08931 .28537 m
.08902 .28929 L
s
.03073 .3043 m
.03039 .30823 L
s
.86518 .03461 m
.86549 .03854 L
s
.93659 .01153 m
.93696 .01545 L
s
gsave
.4589 .08722 -65.984 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 210.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000dR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo0P00000L0?oo
o`00o`3ooooo0?oooa/0oooo0`00000A0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000006`3oool00?l0ooooo`3ooolI0?ooo`<000000P3oool00`000000oooo0?ooo`0>0?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06@3oool00?l0ooooo`3ooolF0?oo
o`<000000`3oool4000000T0oooo100000020?ooo`040000003oool0oooo000000T0oooo0P00000L
0?ooo`00o`3ooooo0?oooa<0oooo0`0000070?ooo`@000003P3oool010000000oooo0?ooo`000009
0?ooo`030000003oool0oooo01/0oooo003o0?ooool0oooo403oool3000000/0oooo0`00000=0?oo
o`@000002P3oool3000001/0oooo003o0?ooool0oooo303oool400000100oooo0P00000;0?ooo`04
0000003oool0oooo000002T0oooo003o0?ooool0oooo2@3oool300000140oooo1P00000:0?ooo`04
0000003oool0oooo000002T0oooo003o0?ooool0oooo1P3oool4000001P0oooo00<000000?ooo`3o
ool0203oool010000000oooo0?ooo`00000Y0?ooo`00o`3ooooo0?ooo`<0oooo0`0000040?ooo`03
0000003oool0oooo01<0oooo0P0000000`3oool000000?ooo`080?ooo`040000003oool0oooo0000
02T0oooo003o0?ooool0oooo0`00000N0?ooo`@000002@3oool2000002X0oooo003o0?oooo`0oooo
0`00000R0?ooo`<000003@3oool2000000@0oooo0P0000040?ooo`8000006P3oool00?l0oooon@3o
ool3000002L0oooo0P00000;0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00006@3oool00?l0oooomP3oool3000002L0oooo1P00000:0?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool05`3oool00?l0ooool`3oool3000002l0oooo00<000000?ooo`3oool0
203oool010000000oooo0?ooo`0000090?ooo`8000006P3oool00?l0ooool03oool300000080oooo
0P00000A0?ooo`030000003oool0oooo01P0oooo0P0000000`3oool000000?ooo`080?ooo`040000
003oool0oooo000000T0oooo00<000000?ooo`3oool06@3oool00?l0ooook03oool400000080oooo
0`00000D0?ooo`030000003oool0oooo01P0oooo0P0000000`3oool000000?ooo`080?ooo`800000
2P3oool3000001T0oooo003o0?oook@0oooo1@0000020?ooo`800000;03oool3000000<0oooo0`00
000G0?ooo`030000003oool0oooo01T0oooo1000000`0?ooo`00o`3ooonf0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0V0?ooo`<000000`3oool3000001/0oooo00<0
00000?ooo`3oool0203oool2000000l0oooo0`00000`0?ooo`00o`3ooonf0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0S0?ooo`<000000`3oool3000001l0oooo00<0
00000?ooo`3oool0103oool3000000l0oooo0P000000103oool0000000000000000_0?ooo`00o`3o
oonf0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0P0?ooo`<00000
0`3oool300000280oooo00<000000?ooo`3oool01000000E0?ooo`@00000;P3oool00?l0oooo]P3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool07@3oool3000000030?oo
o`000000oooo00<000009@3oool3000001`0oooo00<000000?ooo`3oool0;03oool00?l0oooo]@3o
ool2000000@0oooo0P00000M0?ooo`<00000103oool2000002D0oooo0`0000020?ooo`030000003o
ool0oooo01P0oooo0P0000000`3oool000000?ooo`0/0?ooo`00o`3ooooG0?ooo`<00000:P3oool4
000000D0oooo00<000000?ooo`3oool06@3oool2000002h0oooo003o0?ooom@0oooo0`00000[0?oo
o`8000002P3oool00`000000oooo0?ooo`180?ooo`00o`3ooooA0?ooo`<00000>`3oool00`000000
oooo0?ooo`170?ooo`00o`3oooo>0?ooo`<00000103oool2000003P0oooo00<000000?ooo`3oool0
A`3oool00?l0oooobP3oool4000000T0oooo0`00000f0?ooo`030000003oool0oooo04H0oooo003o
0?ooolL0oooo0`0000040?ooo`030000003oool0oooo00T0oooo0`00001l0?ooo`00o`3oooo40?oo
o`<000001P3oool00`000000oooo0?ooo`0<0?ooo`800000N`3oool00?l0oooo`@3oool3000000T0
oooo00<000000?ooo`3oool03P3oool2000007T0oooo003o0?oookh0oooo0`00000<0?ooo`030000
003oool0oooo00l0oooo0P00001h0?ooo`00o`3ooonj0?ooo`@000003P3oool200000180oooo0`00
001f0?ooo`00o`3ooonh0?ooo`<000004@3oool2000001@0oooo0P00001e0?ooo`00o`3ooone0?oo
o`<000000P3oool00`000000oooo0?ooo`0?0?ooo`8000005@3oool2000007@0oooo003o0?oook80
oooo0`0000050?ooo`030000003oool0oooo00l0oooo0P00000F0?ooo`800000L`3oool00?l0oooo
[`3oool3000000P0oooo00<000000?ooo`3oool03`3oool2000001H0oooo0P00001c0?ooo`00o`3o
oon[0?ooo`@000007@3oool00`000000oooo0000000E0?ooo`800000L`3oool00?l0ooooZ03oool3
00000280oooo0P00000F0?ooo`800000LP3oool00?l0ooooY@3oool3000002D0oooo00<000000?oo
o`0000005@3oool200000780oooo003o0?oooj80oooo0`00000Y0?ooo`8000005@3oool200000780
oooo003k0?ooo`80000000<0oooo000000000000WP3oool3000001d0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0000001@0oooo0P00001b0?ooo`00o03o
ool00`000000oooo0000002L0?ooo`<000008@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00L0oooo0P00000D0?ooo`800000LP3oool00?d0oooo00<000000?ooo`3oool0V03oool3
000001D0oooo0P00000>0?ooo`040000003oool0oooo000000/0oooo0`00000B0?ooo`030000003o
ool0oooo0740oooo003k0?ooo`80000000<0oooo000000000000U@3oool3000001H0oooo0P000002
0?ooo`030000003oool0oooo00`0oooo0P00000=0?ooo`@00000403oool00`000000oooo0?ooo`1a
0?ooo`00o`3ooonC0?ooo`<000005`3oool3000000/0oooo3P00000:0?ooo`030000003oool00000
00h0oooo00<000000?ooo`3oool0LP3oool00?l0ooooT03oool4000001P0oooo0P00000B0?ooo`04
0000003oool0oooo00000100oooo0`00000=0?ooo`030000003oool0oooo0780oooo003o0?oooh`0
oooo100000040?ooo`030000003oool0oooo00d0oooo2P00000A0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool03`3oool300000800oooo003o0?ooohT0oooo0`00000F0?ooo`800000
203oool200000100oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0A0?ooo`D00000
N`3oool00?l0ooooQP3oool3000001L0oooo0P0000090?ooo`80000000<0oooo000000000000Z@3o
ool00?l0ooooP`3oool3000001T0oooo0P00000:0?ooo`8000000`3oool2000000@0oooo0P00002Q
0?ooo`00o`3ooon00?ooo`<00000703oool2000000X0oooo0P0000050?ooo`80000000<0oooo0000
000000000P00002P0?ooo`00o`3ooomm0?ooo`<00000803oool2000000P0oooo0P0000080?ooo`@0
0000X@3oool00?l0ooooNP3oool3000002@0oooo0P0000070?ooo`800000[@3oool00?l0ooooM`3o
ool3000002P0oooo2`00002/0?ooo`00o`3ooomd0?ooo`<00000<P3oool200000080oooo0P00002Z
0?ooo`00o`3oooma0?ooo`<000009`3oool00`000000oooo0?ooo`0;0?ooo`800000103oool20000
0:P0oooo003o0?ooofd0oooo1000000X0?ooo`8000003P3oool2000000H0oooo00<000000?ooo`3o
ool0Y@3oool00?l0ooooJP3oool3000000030?ooo`000000oooo02P0oooo0P00000@0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0Y@3oool00?l0ooooI`3oool3000000@0oooo00<0
00000?ooo`3oool09P3oool200000180oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`2U0?ooo`00o`3ooomT0?ooo`<00000503oool800000180oooo0P00000E0?ooo`D00000Z03oool0
0?l0ooooH@3oool3000001H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?oo
o``00000``3oool00?l0ooooGP3oool3000001T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3C0?ooo`00o`3ooomK0?ooo`<000007@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0=@0oooo003o0?oooeP0oooo0`00000Q0?ooo`L00000eP3oool00?l0ooooE@3oool3
000001H0oooo0`00003X0?ooo`00o`3ooomB0?ooo`<00000303oool00`000000oooo0?ooo`0=0?oo
o`D00000h`3oool00?l0ooooC`3oool3000000X0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0A0?ooo`D00000gP3oool00?l0ooooB`3oool4000000h0oooo00<000000?ooo`3oool0
0`3oool700000140oooo1000003J0?ooo`00o`3ooom80?ooo`<000004`3oool00`000000oooo0?oo
o`03000000H0oooo00<000000?ooo`3oool04P3oool500000=D0oooo003o0?ooodD0oooo1000000E
0?ooo`<000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo1@00003@
0?ooo`00o`3ooom20?ooo`<000000`3oool00`000000oooo0?ooo`0A0?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01/0oooo0`00003=0?oo
o`00o`3ooolo0?ooo`<000001P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`3oool2000000/0oooo1P0000070?oo
o`H00000c`3oool00?l0oooo?03oool3000000X0oooo0P00000@0?ooo`@000000P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo008000002P3oool00`000000oooo0?ooo`040?ooo`80
00000P3oool300000=D0oooo003o0?ooocT0oooo0`0000050?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool03@3oool3000000@0oooo00<000000?ooo`3oool00`3oool3000000/0oooo
00<000000?ooo`3oool01P3oool200000=P0oooo003o0?ooocH0oooo0`0000090?ooo`800000203o
ool2000001D0oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0f03oool00?l0oooo<`3oool3000000h0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0000000@000003@3oool800000=X0oooo003n
0?ooo`800000;`3oool300000180oooo0P0000080?ooo`030000003oool0oooo0080oooo0P00000>
0?ooo`<000000`3oool00`000000oooo0?ooo`020?ooo`<00000i`3oool00?d0oooo00@000000?oo
o`3oool00000:P3oool4000001L0oooo00<000000?ooo`3oool01P3oool4000000h0oooo10000005
0?ooo`030000003oool0oooo00<00000j03oool00?d0oooo00@000000?ooo`3oool000009`3oool3
000001`0oooo0P0000050?ooo`80000000<0oooo0000003oool03P3oool200000080oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool000000>P0oooo003m0?ooo`040000003oool0
oooo000002@0oooo0`00000Q0?ooo`030000003oool0000000800000103oool2000000<0oooo0P00
00080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool300000>T0oooo003m
0?ooo`040000003oool0oooo00000240oooo0`00000S0?ooo`@00000203oool3000000X0oooo00<0
00000?ooo`3oool00`3oool010000000oooo0?ooo`3oool200000>/0oooo003n0?ooo`8000007`3o
ool3000000030?ooo`000000oooo01D0oooo00<000000?ooo`3oool02@3oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000030?ooo`000000000000/0oooo0P0000030?ooo`@000000P3o
ool00`000000oooo0?ooo`3X0?ooo`00o`3ooolM0?ooo`<00000103oool00`000000oooo0?ooo`0=
0?ooo`L0000000<0oooo000000000000403oool5000000D0oooo00<000000?ooo`3oool02P3oool3
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0i`3oool00?l0oooo6P3oool30000
01D0oooo0P00000:0?ooo`8000003@3oool4000000P0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`3/0?ooo`00o`3ooolG0?ooo`<000005P3oool2000000X0oooo0P0000020?ooo`80
00002@3oool2000000@0oooo0P0000070?ooo`8000003`3oool00`000000oooo0?ooo`3[0?ooo`00
o`3ooolD0?ooo`<00000603oool00`000000oooo0?ooo`040?ooo`H000001P3oool2000000l0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`3j0?ooo`00o`3ooolA0?ooo`<000006P3o
ool00`000000oooo0?ooo`030?ooo`800000103oool3000000L0oooo00<000000?ooo`3oool03@3o
ool2000000L0oooo0P00003j0?ooo`00o`3oool=0?ooo`@00000703oool00`000000oooo0?ooo`02
0?ooo`800000203oool2000000H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0?L0oooo003o0?ooo`X0oooo0`00000D0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool2000000T0oooo0`0000050?ooo`030000003oool0oooo
00l0oooo0P00003o0?ooo`40oooo003o0?ooo`L0oooo0`00000G0?ooo`<000002@3oool00`000000
oooo0?ooo`020?ooo`8000002`3oool2000000@0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`3m0?ooo`00o`3oool40?ooo`<000006`3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo00<0oooo0`0000090?ooo`<000000`3oool00`000000oooo0?ooo`3o0?oooa80oooo
003o0?ooo`40oooo0`00000Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`0000001@3o
ool3000000D0oooo00<000000?ooo`3oool0o`3ooolC0?ooo`00o@3oool3000002@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`040?ooo`L00000203oool00`000000oooo0?ooo`3o
0?oooa<0oooo003j0?ooo`<000000P3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00H0oooo0P00000A0?ooo`800000o`3ooolF0?ooo`00m`3oool3000000D0oooo00<000000?ooo`3o
ool08`3oool2000000T0oooo0P00000<0?ooo`<00000o`3ooolH0?ooo`00m03oool3000000P0oooo
00<000000?ooo`3oool05P3oool4000000X0oooo0P00000:0?ooo`<000001P3oool300000?l0oooo
6`3oool00?40oooo0`00000R0?ooo`80000000<0oooo0000000000000P0000090?ooo`<00000303o
ool600000?l0oooo7P3oool00>d0oooo1000000T0?ooo`040000003oool00000000000<0oooo0P00
00090?ooo`<00000o`3oool_0?ooo`00jP3oool3000002L0oooo0`0000070?ooo`030000003oool0
oooo00L0oooo0`00003o0?ooobh0oooo003W0?ooo`<00000:@3oool2000001<0oooo00@000000?oo
o`0000000000o`3oool]0?ooo`00i03oool300000280oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0000000D0?ooo`030000003oool000000?l0oooo;@3oool00>40oooo0`00000V0?ooo`80
00001@3oool00`000000oooo0000000F0?ooo`800000o`3oool]0?ooo`00gP3oool300000240oooo
0P0000080?ooo`D0000000<0oooo0000003oool0o`3ooom50?ooo`00f`3oool300000240oooo0`00
000;0?ooo`D00000o`3ooom70?ooo`00f03oool400000200oooo0`00003o0?oooeX0oooo003E0?oo
o`<000000`3oool00`000000oooo0?ooo`0K0?ooo`<00000o`3ooomM0?ooo`00dP3oool300000240
oooo0`00000<0?ooo`800000o`3ooomB0?ooo`00cP3oool400000240oooo0`00000;0?ooo`@00000
o`3ooomD0?ooo`00b`3oool3000002<0oooo0P00000;0?ooo`<00000o`3ooomH0?ooo`00b03oool3
000002l0oooo1000003o0?oooe/0oooo00350?ooo`<00000;P3oool400000?l0ooooG`3oool00<80
oooo0`00000_0?ooo`800000o`3ooomS0?ooo`00_`3oool3000002P0oooo0P00003o0?ooofd0oooo
002l0?ooo`<00000:03oool300000?l0ooooK`3oool00;P0oooo1000000X0?ooo`<00000o`3ooomb
0?ooo`00]P3oool3000002P0oooo0`00003o0?ooogD0oooo002c0?ooo`<000000P3oool00`000000
oooo0?ooo`0?0?ooo`<000004@3oool300000?l0ooooN03oool00;00oooo0`0000050?ooo`030000
003oool0oooo00/0oooo2P00000;0?ooo`<00000o`3ooomk0?ooo`00[03oool4000001D0oooo00<0
00000?ooo`3oool01@3oool2000000030?ooo`000000oooo00L0oooo0P00003o0?ooogh0oooo002Y
0?ooo`<00000603oool00`000000oooo0?ooo`080?ooo`@00000o`3ooon60?ooo`00YP3oool30000
01/0oooo00<000000?ooo`3oool02P3oool300000?l0ooooQ@3oool00:<0oooo0`00000N0?ooo`80
0000303oool200000?l0ooooQ@3oool00:00oooo0`00000Q0?ooo`8000003@3oool200000?l0oooo
Q03oool009d0oooo0`00000C0?ooo`P000002P3oool2000000d0oooo0P00003o0?oooh<0oooo002J
0?ooo`<00000503oool2000000D0oooo1@0000080?ooo`8000003@3oool200000?l0ooooP`3oool0
09H0oooo1000000F0?ooo`030000003oool0oooo00X0oooo0P0000070?ooo`8000003@3oool20000
0?l0ooooPP3oool009@0oooo0`00000I0?ooo`8000003@3oool2000000H0oooo0P00000<0?ooo`80
0000o`3ooon20?ooo`00T@3oool3000000030?ooo`000000oooo01T0oooo0`0000080?ooo`<00000
0P3oool2000000H0oooo0`00000:0?ooo`800000o`3ooon20?ooo`00S@3oool4000000@0oooo00<0
00000?ooo`3oool03@3oool4000000h0oooo100000030?ooo`<0000000<0oooo0000003oool01P3o
ool3000000L0oooo0P00003o0?oooh<0oooo002:0?ooo`<000005@3oool6000000030?ooo`000000
000000X0oooo0P0000090?ooo`80000000<0oooo0000003oool0203oool700000?l0ooooQ@3oool0
08L0oooo0`00000E0?ooo`<000001P3oool2000000030?ooo`000000oooo00L0oooo0P00000<0?oo
o`800000o`3ooonE0?ooo`00Q03oool3000001H0oooo0P00000;0?ooo`800000203oool2000000`0
oooo00<000000?ooo`000000o`3ooonD0?ooo`00D@3oool500000080oooo0P00000W0?ooo`<00000
6@3oool00`000000oooo0?ooo`0;0?ooo`8000001`3oool2000000d0oooo00<000000?ooo`3oool0
o`3ooonC0?ooo`00D`3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
8@3oool3000001`0oooo0P00000<0?ooo`800000203oool3000000X0oooo0P00003o0?oooiD0oooo
001C0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0N0?ooo`<00000
7`3oool00`000000oooo0000000;0?ooo`8000002@3oool00`000000oooo000000080?ooo`800000
o`3ooonF0?ooo`00B`3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01/0oooo0`00000C0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`000000
203oool5000000T0oooo2`00003o0?oooiL0oooo001C0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0G0?ooo`@000005@3oool00`000000oooo0000000?0?ooo`040000
003oool0000000000080oooo100000040?ooo`<00000o`3ooonY0?ooo`00DP3oool2000000@0oooo
0P00000H0?ooo`<000006@3oool3000000l0oooo1P0000090?ooo`<00000o`3ooonW0?ooo`00KP3o
ool4000000030?ooo`000000oooo01/0oooo0`00000A0?ooo`8000002P3oool200000?l0ooooY`3o
ool006/0oooo0`0000050?ooo`030000003oool0oooo01/0oooo1000000?0?ooo`8000002P3oool2
00000?l0ooooY`3oool006P0oooo0`00000X0?ooo`D00000303oool2000000P0oooo0`00003o0?oo
ojP0oooo001U0?ooo`<000005@3oool800000180oooo1000000:0?ooo`T00000o`3ooon[0?ooo`00
HP3oool3000001D0oooo0`0000060?ooo`@00000503oool3000000P0oooo1000003o0?ooojl0oooo
001O0?ooo`<000005P3oool3000000X0oooo0P00000G0?ooo`800000o`3oooni0?ooo`00G03oool3
000001T0oooo0P00000;0?ooo`800000503oool600000?l0oooo^03oool005T0oooo0`00000L0?oo
o`800000303oool200000180oooo00<000000?ooo`3oool00`3oool200000?l0oooo]`3oool005H0
oooo0`00000O0?ooo`8000002`3oool2000000T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`3o0?oookd0oooo001B0?ooo`@000004`3oool9000000L0oooo0`0000090?ooo`800000
2P3oool800000?l0oooo`03oool004l0oooo1000000D0?ooo`8000001`3oool4000000H0oooo1@00
00030?ooo`@000000`3oool00`000000oooo0?ooo`060?ooo`80000000@0oooo0000000000000000
o`3oooo10?ooo`00C03oool3000000<0oooo00<000000?ooo`3oool0403oool2000000/0oooo00<0
00000?ooo`0000001P3oool200000080oooo0`0000070?ooo`<00000203oool00`000000oooo0?oo
o`3o0?oool80oooo00190?ooo`<000001P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00/0oooo0P0000070?ooo`<000002`3oool200000?l0ooooc@3oool004H0oooo0`0000090?oo
o`030000003oool0oooo00H0oooo0P0000080?ooo`<000002`3oool00`000000oooo000000070?oo
o`@000002`3oool00`000000oooo0?ooo`3o0?ooolX0oooo00130?ooo`<000004P3oool3000000/0
oooo0P00000<0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`0000000P0000060?ooo`80
0000o`3oooo=0?ooo`00@03oool3000001<0oooo0P0000020?ooo`8000005`3oool2000000/0oooo
2P00003o0?oooll0oooo000m0?ooo`<000006`3oool2000000@0oooo0P00000>0?ooo`<00000o`3o
oooU0?ooo`00>P3oool3000001l0oooo1@0000080?ooo`8000000`3oool300000?l0ooooj03oool0
03L0oooo0`00000Q0?ooo`@000002`3oool400000?l0ooooj`3oool003@0oooo0`00000Q0?ooo`<0
00000`3oool2000000`0oooo00<000000?ooo`3oool02@3oool300000?l0oooogP3oool00340oooo
0`00000A0?ooo`L000002@3oool3000000L0oooo0`00000;0?ooo`800000103oool600000?l0oooo
h03oool002d0oooo1@00000A0?ooo`8000001@3oool4000000D0oooo0`00000:0?ooo`030000003o
ool0000000`0oooo1`00003o0?ooon<0oooo000Z0?ooo`<00000103oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00P0oooo0P0000070?ooo`D000001P3oool00`000000oooo0000000=
0?ooo`800000o`3ooooV0?ooo`009`3oool3000001L0oooo00<000000?ooo`3oool02P3oool20000
00/0oooo100000030?ooo`030000003oool000000?l0oooom03oool002@0oooo0`00000I0?ooo`03
0000003oool0oooo00/0oooo0P00000?0?ooo`D0000000<0oooo0000003oool0o`3oooob0?ooo`00
8@3oool300000180oooo0P0000090?ooo`<000002`3oool00`000000oooo0?ooo`0B0?ooo`<00000
o`3oooob0?ooo`007P3oool300000180oooo2@0000050?ooo`<000002`3oool300000?l0ooooo`3o
ool80?ooo`006`3oool3000001@0oooo00@000000?ooo`00000000001P3oool00`000000oooo0?oo
o`0>0?ooo`L00000o`3ooooo0?ooo`H0oooo000H0?ooo`<000005`3oool2000001L0oooo0P000006
0?ooo`030000003oool0oooo0?l0ooooo`3oool40?ooo`005@3oool3000001@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0?l0ooooo`3oool30?oo
o`004@3oool4000001P0oooo1000000S0?ooo`800000o`3ooooo0?ooo`@0oooo000>0?ooo`@00000
4P3oool2000000T0oooo0P00000G0?ooo`8000002@3oool200000?l0ooooo`3oool50?ooo`002`3o
ool300000080oooo00<000000?ooo`3oool03P3oool3000000d0oooo400000070?ooo`800000203o
ool200000?l0ooooo`3oool60?ooo`00203oool3000000D0oooo00<000000?ooo`3oool0303oool5
000001`0oooo0`0000060?ooo`T00000o`3ooooo0?ooo`P0oooo00050?ooo`<000005@3oool20000
00@0oooo0P00000M0?ooo`800000o`3ooooo0?oooaH0oooo00020?ooo`<000007`3oool2000001`0
oooo0P00003o0?ooool0oooo5P3oool0008000008`3oool2000000l0oooo00<000000?ooo`3oool0
2@3oool200000?l0ooooo`3ooolF0?ooo`009P3oool2000000h0oooo0P0000080?ooo`<00000o`3o
oooo0?oooaL0oooo000W0?ooo`<00000303oool3000000<0oooo1000003o0?ooool0oooo6P3oool0
02P0oooo00<000000?ooo`0000003P3oool300000?l0ooooo`3ooolN0?ooo`00:@3oool00`000000
oooo0000003o0?ooool0oooo;P3oool002X0oooo00<000000?ooo`000000o`3ooooo0?ooobd0oooo
000Y0?ooo`<0000000<0oooo0000003oool0o`3ooooo0?ooob/0oooo000W0?ooo`8000000`3oool3
00000?l0ooooo`3oool[0?ooo`007P3oool00`000000oooo0?ooo`3o0?ooool0oooo>@3oool001d0
oooo0P00003o0?ooool0oooo>`3oool001d0oooo0P00003o0?ooool0oooo>`3oool001`0oooo0P00
003o0?ooool0oooo?03oool001`0oooo0P00003o0?ooool0oooo?03oool001d0oooo00<000000?oo
o`3oool0o`3ooooo0?ooocX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {209.688, 0}} -> {0.0479298, 0.300521, \
0.0017149, 0.0017149}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<,./<>?;'[]:\"{}\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .39891 
%%ImageSize: 600 239.345 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0396315 1.03963 -0.305918 1.03963 [
[.05122 .27593 -5.47152 -9 ]
[.05122 .27593 6.52848 0 ]
[.24136 .2133 -11.4039 -9 ]
[.24136 .2133 12.5961 0 ]
[.44122 .14748 -2.97535 -9 ]
[.44122 .14748 3.02465 0 ]
[.65156 .07822 -9.33011 -9 ]
[.65156 .07822 8.66989 0 ]
[.87326 .00526 -3.25638 -9 ]
[.87326 .00526 2.74362 0 ]
[.43953 .08325 -4.95654 -12.75 ]
[.43953 .08325 5.04346 0 ]
[.95833 .01957 0 -5.96243 ]
[.95833 .01957 24 3.03757 ]
[.97706 .04691 0 -5.94485 ]
[.97706 .04691 6 3.05515 ]
[.99543 .07373 0 -5.92769 ]
[.99543 .07373 18 3.07231 ]
[1.03893 .02705 0 -8.42187 ]
[1.03893 .02705 10 4.32813 ]
[ 0 0 0 0 ]
[ 1 .39891 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00143 .30485 m
.92981 0 L
s
.05008 .28888 m
.04951 .29535 L
s
[(-5)] .05122 .27593 -0.08808 1 Mshowa
.24071 .22628 m
.24039 .23277 L
s
[(-2.5)] .24136 .2133 -0.04968 1 Mshowa
.44111 .16047 m
.44106 .16697 L
s
[(0)] .44122 .14748 -0.00822 1 Mshowa
.65204 .09121 m
.65228 .0977 L
s
[(2.5)] .65156 .07822 .03668 1 Mshowa
.87436 .01821 m
.87492 .02468 L
s
[(5)] .87326 .00526 .08546 1 Mshowa
.125 Mabswid
.08746 .2766 m
.08715 .28049 L
s
.12521 .26421 m
.12492 .2681 L
s
.16333 .25169 m
.16307 .25558 L
s
.20183 .23905 m
.2016 .24294 L
s
.27999 .21338 m
.27982 .21728 L
s
.31966 .20036 m
.31953 .20425 L
s
.35973 .1872 m
.35963 .19109 L
s
.40021 .1739 m
.40015 .1778 L
s
.48243 .14691 m
.48243 .15081 L
s
.52417 .1332 m
.52421 .1371 L
s
.56635 .11935 m
.56642 .12325 L
s
.60897 .10535 m
.60908 .10925 L
s
.69557 .07692 m
.69574 .08081 L
s
.73955 .06247 m
.73977 .06637 L
s
.78401 .04788 m
.78426 .05177 L
s
.82894 .03312 m
.82924 .03701 L
s
.01306 .30103 m
.01269 .30491 L
s
.92027 .00313 m
.92065 .00701 L
s
gsave
.43953 .08325 -65.9565 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.92981 0 m
.99832 .09996 L
s
.94597 .02358 m
.93979 .02559 L
s
[(-0.5)] .95833 .01957 -1 .32498 Mshowa
.96469 .05089 m
.9585 .05287 L
s
[(0)] .97706 .04691 -1 .32108 Mshowa
.98304 .07766 m
.97685 .07962 L
s
[(0.5)] .99543 .07373 -1 .31726 Mshowa
.125 Mabswid
.94975 .02909 m
.94604 .03029 L
s
.9535 .03457 m
.94979 .03577 L
s
.95725 .04003 m
.95354 .04123 L
s
.96097 .04547 m
.95726 .04666 L
s
.96839 .05628 m
.96468 .05747 L
s
.97207 .06166 m
.96836 .06285 L
s
.97574 .06701 m
.97203 .0682 L
s
.9794 .07235 m
.97568 .07353 L
s
.94218 .01806 m
.93848 .01926 L
s
.93838 .01251 m
.93467 .01372 L
s
.93456 .00694 m
.93086 .00815 L
s
.93073 .00135 m
.92702 .00256 L
s
.98667 .08295 m
.98295 .08413 L
s
.99028 .08822 m
.98656 .0894 L
s
.99388 .09347 m
.99016 .09464 L
s
.99747 .0987 m
.99375 .09987 L
s
gsave
1.03893 .02705 -61 -12.4219 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .39891 L
0 .39891 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.24291 .34184 m
.08418 .28755 L
s
.05979 .33546 m
.06111 .33175 L
s
.05303 .33436 m
.05979 .33546 L
s
.05434 .33065 m
.05303 .33436 L
s
.06111 .33175 m
.05566 .32693 L
s
.06111 .33175 m
.05434 .33065 L
s
.05566 .32693 m
.04208 .32471 L
s
.09361 .32128 m
.09223 .32502 L
s
.09223 .32502 m
.08546 .32391 L
s
.08546 .32391 m
.08683 .32017 L
s
.08683 .32017 m
.09361 .32128 L
s
.31729 .29584 m
.22683 .29501 L
s
.22683 .29501 m
.27135 .25043 L
s
.35137 .28505 m
.3983 .24011 L
s
.46461 .25587 m
.47579 .25566 L
s
.45781 .2547 m
.46461 .25587 L
s
.47579 .25566 m
.489 .2515 L
s
.4486 .25096 m
.45781 .2547 L
s
.489 .2515 m
.49545 .24614 L
s
.489 .2515 m
.49988 .24474 L
s
.44618 .24839 m
.4486 .25096 L
s
.45299 .24957 m
.45497 .2456 L
s
.44815 .24442 m
.44618 .24839 L
s
.49545 .24614 m
.49751 .24216 L
s
.45497 .2456 m
.44815 .24442 L
s
.49988 .24474 m
.50194 .24076 L
s
.49751 .24216 m
.49718 .23557 L
s
.50194 .24076 m
.50163 .23416 L
s
.3983 .24011 m
.30585 .23925 L
s
.49718 .23557 m
.4924 .23036 L
s
.50163 .23416 m
.49685 .22895 L
s
.4924 .23036 m
.48315 .22655 L
s
.49685 .22895 m
.4876 .22514 L
s
.48315 .22655 m
.46942 .22415 L
s
.4876 .22514 m
.48074 .22393 L
s
.4581 .22437 m
.45078 .21648 L
s
.48074 .22393 m
.4581 .22437 L
s
.57819 .22339 m
.55735 .20633 L
s
.62353 .22251 m
.6554 .21252 L
s
.62353 .22251 m
.54852 .13567 L
s
.5827 .22197 m
.55735 .20633 L
s
.62807 .22109 m
.55317 .13415 L
s
.52315 .207 m
.52103 .21109 L
s
.52103 .21109 m
.51414 .20987 L
s
.51414 .20987 m
.51625 .20578 L
s
.51625 .20578 m
.52315 .207 L
s
.68292 .20389 m
.71526 .19376 L
s
.44046 .19911 m
.43847 .20323 L
s
.43847 .20323 m
.43152 .20201 L
s
.43152 .20201 m
.43351 .19789 L
s
.43351 .19789 m
.44046 .19911 L
s
.71062 .19521 m
.63776 .10648 L
s
.71526 .19376 m
.64251 .10493 L
s
.50423 .19241 m
.50634 .18826 L
s
.49729 .19118 m
.50423 .19241 L
s
.49939 .18703 m
.49729 .19118 L
s
.50634 .18826 m
.50149 .18286 L
s
.50634 .18826 m
.49939 .18703 L
s
.50149 .18286 m
.48754 .18038 L
s
.78627 .15781 m
.78886 .15355 L
s
.78627 .15781 m
.77937 .15655 L
s
.77937 .15655 m
.76631 .13987 L
s
.78411 .15505 m
.76631 .13987 L
s
.78886 .15355 m
.76631 .13987 L
s
.72644 .14209 m
.72394 .14638 L
s
.72394 .14638 m
.71698 .14511 L
s
.71698 .14511 m
.71947 .1408 L
s
.82917 .14429 m
.83184 .13999 L
s
.82917 .14429 m
.82225 .14302 L
s
.82225 .14302 m
.8094 .12617 L
s
.71947 .1408 m
.72644 .14209 L
s
.82704 .1415 m
.8094 .12617 L
s
.83184 .13999 m
.8094 .12617 L
s
.88841 .13602 m
.87943 .13193 L
s
.88841 .13602 m
.8815 .13474 L
s
.90015 .13579 m
.88841 .13602 L
s
.54852 .13567 m
.58117 .12499 L
s
.8815 .13474 m
.8725 .13064 L
s
.87943 .13193 m
.87526 .12629 L
s
.8725 .13064 m
.86832 .12499 L
s
.71071 .1224 m
.70822 .12676 L
s
.70822 .12676 m
.7012 .12546 L
s
.87526 .12629 m
.87594 .11909 L
s
.7012 .12546 m
.70368 .1211 L
s
.86832 .12499 m
.86899 .11778 L
s
.70368 .1211 m
.71071 .1224 L
s
.9489 .12051 m
.95671 .11458 L
s
.87594 .11909 m
.87872 .1147 L
s
.86899 .11778 m
.87175 .11339 L
s
.60937 .11577 m
.64251 .10493 L
s
.87872 .1147 m
.87941 .10744 L
s
.95671 .11458 m
.95761 .10732 L
s
.95671 .11458 m
.95962 .11018 L
s
.87175 .11339 m
.87243 .10612 L
s
.95962 .11018 m
.96053 .10289 L
s
.87941 .10744 m
.87521 .1017 L
s
.95761 .10732 m
.95358 .10158 L
s
.87243 .10612 m
.86821 .10038 L
s
.96053 .10289 m
.9565 .09713 L
s
.87521 .1017 m
.86609 .09749 L
s
.95358 .10158 m
.94458 .09737 L
s
.86821 .10038 m
.85418 .09773 L
s
.84227 .09797 m
.85758 .0859 L
s
.86609 .09749 m
.84227 .09797 L
s
.94458 .09737 m
.9376 .09605 L
s
.9565 .09713 m
.94749 .09291 L
s
.9376 .09605 m
.92856 .09183 L
s
.94749 .09291 m
.9405 .09159 L
s
.84991 .09195 m
.85544 .08298 L
s
.92856 .09183 m
.92444 .08602 L
s
.9405 .09159 m
.93145 .08735 L
s
.93145 .08735 m
.92733 .08152 L
s
.92444 .08602 m
.92526 .0786 L
s
.85758 .0859 m
.85822 .07848 L
s
.85544 .08298 m
.85115 .07713 L
s
.92733 .08152 m
.93314 .07249 L
s
.92526 .0786 m
.94106 .06635 L
s
.85822 .07848 m
.85393 .07261 L
s
.85115 .07713 m
.84191 .07285 L
s
.84191 .07285 m
.83482 .07151 L
s
.85393 .07261 m
.84468 .06832 L
s
.83482 .07151 m
.82553 .06721 L
s
.84468 .06832 m
.83757 .06696 L
s
.82553 .06721 m
.82115 .06129 L
s
.83757 .06696 m
.82828 .06265 L
s
.91695 .06684 m
.90778 .06253 L
s
.94106 .06635 m
.91695 .06684 L
s
.929 .06659 m
.91486 .06388 L
s
.91486 .06388 m
.91067 .05795 L
s
.82828 .06265 m
.82389 .05671 L
s
.90778 .06253 m
.90357 .05659 L
s
.82115 .06129 m
.8217 .05374 L
s
.91067 .05795 m
.91146 .05038 L
s
.82389 .05671 m
.82445 .04913 L
s
.90357 .05659 m
.90434 .04901 L
s
.8217 .05374 m
.82445 .04913 L
s
.91146 .05038 m
.91437 .04577 L
s
.82445 .04913 m
.83219 .04289 L
s
.90434 .04901 m
.90724 .04439 L
s
.91437 .04577 m
.91518 .03812 L
s
.90724 .04439 m
.90803 .03674 L
s
.91518 .03812 m
.91095 .03208 L
s
.90803 .03674 m
.90378 .03069 L
s
.91095 .03208 m
.90165 .02766 L
s
.90378 .03069 m
.89447 .02626 L
s
.90165 .02766 m
.89447 .02626 L
s
.89447 .02626 m
.88224 .02652 L
s
0 g
.25 Mabswid
.00143 .30485 m
.92981 0 L
s
.05008 .28888 m
.04951 .29535 L
s
[(-5)] .05122 .27593 -0.08808 1 Mshowa
.24071 .22628 m
.24039 .23277 L
s
[(-2.5)] .24136 .2133 -0.04968 1 Mshowa
.44111 .16047 m
.44106 .16697 L
s
[(0)] .44122 .14748 -0.00822 1 Mshowa
.65204 .09121 m
.65228 .0977 L
s
[(2.5)] .65156 .07822 .03668 1 Mshowa
.87436 .01821 m
.87492 .02468 L
s
[(5)] .87326 .00526 .08546 1 Mshowa
.125 Mabswid
.08746 .2766 m
.08715 .28049 L
s
.12521 .26421 m
.12492 .2681 L
s
.16333 .25169 m
.16307 .25558 L
s
.20183 .23905 m
.2016 .24294 L
s
.27999 .21338 m
.27982 .21728 L
s
.31966 .20036 m
.31953 .20425 L
s
.35973 .1872 m
.35963 .19109 L
s
.40021 .1739 m
.40015 .1778 L
s
.48243 .14691 m
.48243 .15081 L
s
.52417 .1332 m
.52421 .1371 L
s
.56635 .11935 m
.56642 .12325 L
s
.60897 .10535 m
.60908 .10925 L
s
.69557 .07692 m
.69574 .08081 L
s
.73955 .06247 m
.73977 .06637 L
s
.78401 .04788 m
.78426 .05177 L
s
.82894 .03312 m
.82924 .03701 L
s
.01306 .30103 m
.01269 .30491 L
s
.92027 .00313 m
.92065 .00701 L
s
gsave
.43953 .08325 -65.9565 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 239.313},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000kb000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooonh0oooo0P00001Y0?ooo`00o`3oooo]0?ooo`040000003oool0oooo000006P0oooo003o
0?oooo00oooo00<000000?ooo`3oool0IP3oool00?l0ooookP3oool2000006T0oooo003o0?ooonh0
oooo00<000000?ooo`3oool0J03oool00?l0ooookP3oool3000001h0oooo0P0000180?ooo`00o`3o
oooo0?ooo`d0oooo0`0000000`3oool00000000000170?ooo`00o`3ooooo0?ooo`X0oooo0`000002
0?ooo`80000000<0oooo0000003oool0AP3oool00?l0ooooo`3oool70?ooo`<0000000<0oooo0000
003oool01P3oool00`000000oooo0?ooo`140?ooo`00o`3ooooo0?ooo`@0oooo0`0000040?ooo`03
0000003oool0oooo00D0oooo0P0000150?ooo`00o`3ooooo0?ooo`40oooo0`00000=0?ooo`800000
00<0oooo0000003oool0A03oool00?l0ooooo@3oool3000001@0oooo00<000000?ooo`3oool0@P3o
ool00?l0oooonP3oool3000001L0oooo0P00000B0?ooo`800000103oool2000000@0oooo0P00000S
0?ooo`00o`3oooog0?ooo`<00000603oool2000000030?ooo`000000oooo0100oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`00000R0?ooo`00o`3ooood0?ooo`<000007`3oool0
0`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool0803o
ool00?l0ooool@3oool3000002<0oooo00<000000?ooo`3oool01`3oool400000080oooo00@00000
0?ooo`3oool000002@3oool2000001X0oooo0P0000070?ooo`00o`3oooo]0?ooo`@00000903oool3
000000l0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00D0oooo003o0?ooonX0oooo0`0000030?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool03@3oool2000000X0oooo0`00000K0?ooo`030000003oool0oooo00@0oooo003o0?oo
onL0oooo0`0000070?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0=@3oool00`00
0000oooo000000050?ooo`00o`3ooooT0?ooo`<000002P3oool00`000000oooo0?ooo`0T0?ooo`80
0000=P3oool010000000oooo0?ooo`0000050?ooo`00o`3ooooQ0?ooo`<000004@3oool9000001L0
oooo0`0000020?ooo`030000003oool0oooo0380oooo0`0000000`3oool00000000000040?ooo`00
o`3ooooN0?ooo`<00000703oool5000001T0oooo00<000000?ooo`3oool0>`3oool00?l0oooof`3o
ool300000240oooo0P0000000`3oool000000000000E0?ooo`<00000?@3oool00?l0oooof03oool3
000002H0oooo00<000000?ooo`3oool00P00000F0?ooo`030000003oool0oooo03X0oooo003o0?oo
omD0oooo0`00000Z0?ooo`040000003oool0oooo000001L0oooo00<000000?ooo`3oool0>@3oool0
0?l0oooodP3oool3000000030?ooo`000000oooo02X0oooo00D000000?ooo`3oool0oooo0000000F
0?ooo`030000003oool0oooo03T0oooo003o0?oooll0oooo0`0000050?ooo`030000003oool0oooo
02T0oooo00@000000?ooo`3oool00000503oool2000000030?ooo`000000oooo03T0oooo003o0?oo
ol`0oooo0`00000d0?ooo`050000003oool0oooo0?ooo`0000005`3oool00`000000oooo0?ooo`0g
0?ooo`00o`3oooo90?ooo`<00000=`3oool01@000000oooo0?ooo`3oool0000001L0oooo00<00000
0?ooo`3oool02P3oool2000002/0oooo003o0?ooolH0oooo0`00000j0?ooo`050000003oool0oooo
0?ooo`0000005@3oool2000000030?ooo`000000oooo00T0oooo00@000000?ooo`3oool00000:P3o
ool00?l0oooo``3oool300000180oooo00<000000?ooo`3oool0:03oool01@000000oooo0?ooo`3o
ool0000001T0oooo00<000000?ooo`3oool01`3oool010000000oooo0?ooo`00000Z0?ooo`00o`3o
ooo00?ooo`<00000503oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`040000003oool0oooo000002X0oooo
003o0?oookd0oooo0`00000E0?ooo`800000:`3oool01@000000oooo0?ooo`3oool0000001P0oooo
0P0000000`3oool000000?ooo`070?ooo`040000003oool0oooo000002X0oooo003o0?oookX0oooo
1000000F0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00H0oooo0P00000[0?ooo`00o`3ooong0?ooo`<000000`3o
ool00`000000oooo0?ooo`0C0?ooo`800000;03oool01@000000oooo0?ooo`3oool0000001`0oooo
0P00000e0?ooo`00o`3ooond0?ooo`<000001P3oool00`000000oooo0?ooo`0C0?ooo`800000;03o
ool01@000000oooo0?ooo`3oool0000001X0oooo0P0000020?ooo`030000003oool0oooo0380oooo
003o0?oook40oooo0`00000N0?ooo`030000003oool0000002`0oooo00D000000?ooo`3oool0oooo
0000000O0?ooo`030000003oool0oooo0340oooo003o0?ooojd0oooo1000000Q0?ooo`030000003o
ool0000002`0oooo00D000000?ooo`3oool0oooo0000000O0?ooo`800000<P3oool00?l0ooooZP3o
ool3000002D0oooo00<000000?ooo`000000;03oool01@000000oooo0?ooo`3oool0000001d0oooo
0P0000000`3oool000000?ooo`0a0?ooo`00o`3ooonW0?ooo`<00000:03oool010000000oooo0?oo
o`00000/0?ooo`050000003oool0oooo0?ooo`000000803oool00`000000oooo0?ooo`0_0?ooo`00
o`3ooonT0?ooo`<00000:`3oool010000000oooo0?ooo`00000/0?ooo`050000003oool0oooo0?oo
o`000000803oool200000300oooo003o0?oooj40oooo1000000^0?ooo`030000003oool0oooo0080
0000:`3oool200000080oooo0P00000L0?ooo`80000000<0oooo0000003oool0;`3oool00?l0oooo
JP3oool4000000<0oooo0P0000040?ooo`8000009@3oool3000000<0oooo00<000000?ooo`3oool0
;@3oool010000000oooo0?ooo`3oool2000002/0oooo0P0000020?ooo`@00000703oool00`000000
oooo0?ooo`0]0?ooo`00o`3ooomZ0?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool0
00008@3oool3000000H0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`<0
0000:P3oool@00000180oooo0P00000<0?ooo`800000103oool2000000@0oooo0P00000D0?ooo`00
mP3oool2000000030?ooo`000000000006l0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0L0?ooo`<00000>`3oool2000000D0oooo1000000d0?ooo`030000003oool0oooo0100oooo
0`00000;0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000004`3oool00?L0
oooo00<000000?ooo`000000L@3oool00`000000oooo0?ooo`080?ooo`800000703oool300000400
oooo0P0000070?ooo`<00000;`3oool2000001H0oooo00<000000?ooo`3oool0203oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0oooo0140oooo003h0?ooo`030000003oool0oooo06h0
oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0H0?ooo`<00000A@3oool20000
00P0oooo0P00000/0?ooo`030000003oool0oooo01H0oooo0P0000090?ooo`040000003oool0oooo
000000T0oooo0P00000D0?ooo`00mP3oool2000000030?ooo`000000000006l0oooo0P00000:0?oo
o`<000005@3oool3000004X0oooo100000050?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool05P3oool3000000T0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0C
0?ooo`00o`3ooon<0?ooo`<00000D@3oool2000000@0oooo00<000000?ooo`3oool09P3oool20000
01`0oooo00<000000?ooo`3oool01`3oool2000000X0oooo0`00000C0?ooo`00o`3ooon90?ooo`<0
0000EP3oool200000080oooo00<000000?ooo`3oool09@3oool00`000000oooo0000000L0?ooo`80
0000:P3oool00?l0ooooQP3oool300000080oooo00<000000?ooo`3oool0EP3oool010000000oooo
0?ooo`00000U0?ooo`030000003oool0000001X0oooo0`0000000`3oool000000?ooo`0Y0?ooo`00
o`3ooon30?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`040000003oool0oooo000002D0
oooo0P00000P0?ooo`030000003oool0oooo02L0oooo003o0?oooh00oooo0`00001R0?ooo`030000
003oool0000002D0oooo00<000000?ooo`0000007`3oool2000002P0oooo003o0?ooogd0oooo0`00
001T0?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`0000007P3oool3000002P0oooo
003o0?ooogX0oooo0`00001W0?ooo`040000003oool0oooo000002D0oooo00@000000?ooo`3oool0
0000803oool00`000000oooo0?ooo`0U0?ooo`00o`3ooomg0?ooo`<00000J@3oool010000000oooo
0?ooo`00000W0?ooo`030000003oool0oooo008000007P3oool2000002H0oooo003o0?ooog@0oooo
0`00001/0?ooo`<00000:03oool00`000000oooo0?ooo`020?ooo`8000006`3oool3000002H0oooo
003o0?ooog40oooo0`00001^0?ooo`800000:`3oool00`000000oooo0?ooo`030?ooo`<000006`3o
ool00`000000oooo0?ooo`0S0?ooo`00o`3ooom^0?ooo`<0000000<0oooo0000003oool0KP3oool0
0`000000oooo0?ooo`0[0?ooo`8000001P3oool4000001L0oooo0P00000T0?ooo`00o`3ooomZ0?oo
o`@00000103oool00`000000oooo0?ooo`1[0?ooo`800000<03oool2000000P0oooo0P00000D0?oo
o`<00000903oool00?l0ooooI`3oool3000000P0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`0b0?ooo`D000001@3oool2000001D0oooo00<000000?ooo`3oool08@3oool00?l0oooo
I03oool3000000/0oooo00<000000?ooo`3oool0J@3oool@000002/0oooo0P0000040?ooo`030000
003oool0oooo01<0oooo0P00000R0?ooo`00o`3ooomQ0?ooo`<00000Q@3oool7000002/0oooo0P00
00030?ooo`030000003oool0oooo0140oooo0`00000R0?ooo`00o`3ooomN0?ooo`<00000S@3oool0
10000000oooo00000000000[0?ooo`040000003oool0oooo000003P0oooo003o0?oooe/0oooo0`00
002@0?ooo`050000003oool0oooo0?ooo`000000:`3oool010000000oooo0?ooo`00000g0?ooo`00
o`3ooomH0?ooo`<000004@3oool200000840oooo00@000000?ooo`3oool00000:`3oool010000000
oooo0?ooo`00000g0?ooo`00o`3ooomE0?ooo`<000000P3oool00`000000oooo0?ooo`0<0?ooo`<0
00000P3oool00`000000oooo0?ooo`1n0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`00
0000oooo0000000g0?ooo`00o`3ooomB0?ooo`<000001@3oool00`000000oooo0?ooo`090?ooo`<0
00000P3oool01@000000oooo0?ooo`3oool0000007l0oooo00D000000?ooo`3oool0oooo0000000[
0?ooo`030000003oool0000003L0oooo003o0?ooodl0oooo0`00000@0?ooo`@000001P3oool01000
0000oooo0?ooo`00001o0?ooo`050000003oool0oooo0?ooo`000000:`3oool00`000000oooo0000
000g0?ooo`00o`3ooom<0?ooo`<00000403oool3000000X0oooo00D000000?ooo`3oool0oooo0000
001n0?ooo`050000003oool0oooo0?ooo`000000:`3oool2000003P0oooo003o0?ooodT0oooo0`00
000@0?ooo`<000003P3oool01@000000oooo0?ooo`3oool0000007d0oooo00D000000?ooo`3oool0
oooo0000000[0?ooo`030000003oool0oooo03L0oooo003o0?ooodH0oooo0`00000A0?ooo`800000
4P3oool01@000000oooo0?ooo`3oool0000007/0oooo00D000000?ooo`3oool0oooo0000000[0?oo
o`030000003oool0oooo03P0oooo003o0?oood<0oooo0`00000Y0?ooo`050000003oool0oooo0?oo
o`000000N@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02L0oooo0P00000k0?oo
o`00o`3ooom00?ooo`<00000;@3oool01@000000oooo0?ooo`3oool0000007P0oooo00D000000?oo
o`3oool0oooo0000000Y0?ooo`030000003oool0oooo03/0oooo003o0?ooocd0oooo0`0000020?oo
o`030000003oool0oooo02`0oooo00@000000?ooo`3oool000006P3oool2000005`0oooo00D00000
0?ooo`3oool0oooo0000000X0?ooo`030000003oool0oooo03`0oooo003o0?ooocX0oooo0`000005
0?ooo`030000003oool0oooo02`0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`030000003o
ool0oooo00<00000F@3oool01@000000oooo0?ooo`3oool0000006L0oooo003o0?ooocL0oooo0`00
000?0?ooo`8000009`3oool01@000000oooo0?ooo`3oool0000001L0oooo0P0000020?ooo`030000
003oool0oooo05P0oooo00D000000?ooo`3oool0oooo0000001W0?ooo`00o`3ooold0?ooo`<00000
3`3oool3000002X0oooo00D000000?ooo`3oool0oooo0000000H0?ooo`<00000>03oool00`000000
oooo0?ooo`0P0?ooo`040000003oool0oooo000006L0oooo003o0?oooc40oooo0`00000?0?ooo`<0
0000;P3oool01@000000oooo0?ooo`3oool0000005<0oooo0P00000P0?ooo`050000003oool0oooo
0?ooo`000000IP3oool00?l0oooo;P3oool3000000h0oooo1000000b0?ooo`040000003oool0oooo
000005@0oooo0`00000O0?ooo`040000003oool0oooo000006H0oooo003o0?ooob/0oooo0`00000>
0?ooo`<00000=P3oool01@000000oooo0?ooo`3oool0000005@0oooo0`00000O0?ooo`80000000<0
oooo000000000000I03oool00?T0oooo0P00000[0?ooo`@000003P3oool3000003X0oooo00D00000
0?ooo`3oool0oooo0000001D0?ooo`@000007`3oool2000000030?ooo`00000000000680oooo003h
0?ooo`040000003oool0oooo000002L0oooo0`0000030?ooo`030000003oool0oooo00X0oooo0P00
00020?ooo`030000003oool0oooo03T0oooo00D000000?ooo`3oool0oooo0000001C0?ooo`050000
003oool000000?ooo`000000803oool<000005T0oooo003h0?ooo`040000003oool0oooo000002@0
oooo0`0000060?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000k0?oo
o`050000003oool0oooo0?ooo`000000D`3oool00`000000oooo00000003000008<0oooo003h0?oo
o`040000003oool0oooo00000240oooo0`00000H0?ooo`050000003oool0oooo0?ooo`000000>`3o
ool01@000000oooo0?ooo`3oool0000005<0oooo00D000000?ooo`3oool000000?ooo`0200000840
oooo003h0?ooo`040000003oool0oooo000001h0oooo0`00000L0?ooo`040000003oool0oooo0000
03`0oooo00@000000?ooo`3oool000006P3oool2000001T0oooo00<000000?ooo`3oool0703oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo07h0oooo003i0?ooo`800000703oool3
00000200oooo00@000000?ooo`3oool00000>`3oool01@000000oooo0?ooo`3oool0000001T0oooo
00<000000?ooo`0000000P00000G0?ooo`8000007@3oool200000080oooo00<000000?ooo`3oool0
O`3oool00?l0oooo5@3oool3000002<0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`050000
003oool0oooo0?ooo`0000005`3oool01@000000oooo0?ooo`3oool0000001T0oooo0`00000M0?oo
o`<00000P@3oool00?l0oooo4P3oool3000002L0oooo00D000000?ooo`3oool0oooo0000000k0?oo
o`050000003oool0oooo0?ooo`0000005P3oool5000001T0oooo00<000000?ooo`0000000P00002O
0?ooo`00o`3oool?0?ooo`@00000:P3oool01@000000oooo0?ooo`3oool0000003/0oooo00D00000
0?ooo`3oool0oooo0000000d0?ooo`040000003oool000000?ooo`800000W@3oool00?l0oooo303o
ool3000000<0oooo00<000000?ooo`3oool0:@3oool01@000000oooo0?ooo`3oool0000003/0oooo
00@000000?ooo`3oool00000=@3oool00`000000oooo000000020?ooo`800000V`3oool00?l0oooo
2@3oool3000000H0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0000003X0
oooo00D000000?ooo`3oool0oooo0000000e0?ooo`040000003oool0000000000080oooo0P00002I
0?ooo`00o`3oool60?ooo`<00000=`3oool010000000oooo0?ooo`00000k0?ooo`050000003oool0
oooo0?ooo`000000=03oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
UP3oool00?l0oooo0`3oool3000003/0oooo00@000000?ooo`3oool00000>`3oool01@000000oooo
0?ooo`3oool0000003@0oooo00L000000?ooo`3oool0oooo0000003oool0000009T0oooo003o0?oo
o`<00000?`3oool010000000oooo0?ooo`00000k0?ooo`050000003oool0oooo0?ooo`000000=03o
ool2000000<0oooo00<000000?ooo`3oool0U`3oool00?`0oooo0`0000120?ooo`050000003oool0
oooo0?ooo`000000>`3oool01@000000oooo0?ooo`3oool0000003D0oooo0`00002J0?ooo`00n@3o
ool3000004H0oooo00D000000?ooo`3oool0oooo0000000k0?ooo`040000003oool0oooo00000=80
oooo003f0?ooo`<0000000<0oooo0000003oool0A`3oool01@000000oooo0?ooo`3oool0000003X0
oooo00D000000?ooo`3oool0oooo0000003A0?ooo`00l`3oool3000000@0oooo00<000000?ooo`3o
ool0A`3oool01@000000oooo0?ooo`3oool0000003X0oooo00D000000?ooo`3oool0oooo0000003@
0?ooo`00l03oool3000000L0oooo00<000000?ooo`3oool0B03oool010000000oooo0?ooo`00000k
0?ooo`050000003oool0oooo0?ooo`000000c`3oool00>d0oooo0`00000:0?ooo`030000003oool0
oooo04T0oooo00@000000?ooo`3oool00000>`3oool01@000000oooo0?ooo`3oool000000<h0oooo
003Z0?ooo`<00000FP3oool010000000oooo0?ooo`00000k0?ooo`050000003oool0oooo0?ooo`00
0000c@3oool00>H0oooo1000001N0?ooo`040000003oool0oooo000003/0oooo00@000000?ooo`3o
ool00000c@3oool00><0oooo0`00001R0?ooo`050000003oool0oooo0?ooo`000000>P3oool01@00
0000oooo0?ooo`3oool000000<`0oooo003P0?ooo`<00000IP3oool01@000000oooo0?ooo`3oool0
000003X0oooo00D000000?ooo`3oool0oooo0000003;0?ooo`00g@3oool300000080oooo00<00000
0?ooo`3oool0I@3oool01@000000oooo0?ooo`3oool0000003X0oooo00D000000?ooo`3oool0oooo
0000003:0?ooo`00fP3oool3000000D0oooo00<000000?ooo`3oool0IP3oool010000000oooo0?oo
o`00000k0?ooo`050000003oool0oooo0?ooo`000000b@3oool00=L0oooo0`00001b0?ooo`040000
003oool0oooo000003/0oooo00@000000?ooo`3oool00000b@3oool00=@0oooo0`00000m0?ooo`@0
0000=@3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`000000b03oool0
0=40oooo0`0000140?ooo`D00000<@3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0
oooo0?ooo`000000a`3oool00<h0oooo0`00001<0?ooo`030000003oool0oooo02l0oooo00@00000
0?ooo`3oool00000>P3oool01@000000oooo0?ooo`3oool000000<H0oooo003;0?ooo`<00000C@3o
ool2000000030?ooo`000000oooo02l0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`050000
003oool0oooo0?ooo`000000a@3oool00<P0oooo1000001>0?ooo`030000003oool0oooo00<00000
<03oool01@000000oooo0?ooo`3oool0000003X0oooo00D000000?ooo`3oool0oooo000000340?oo
o`00a@3oool3000000<0oooo00<000000?ooo`3oool0C03oool01@000000oooo0?ooo`3oool00000
0380oooo00D000000?ooo`3oool0oooo0000000j0?ooo`040000003oool0oooo00000<@0oooo0032
0?ooo`<000001P3oool00`000000oooo0?ooo`1;0?ooo`D00000=03oool010000000oooo0?ooo`00
000j0?ooo`050000003oool0oooo0?ooo`000000``3oool00;l0oooo0`00002A0?ooo`040000003o
ool0oooo000003X0oooo00<000000?ooo`3oool00P0000320?ooo`00_03oool3000009D0oooo00@0
00000?ooo`3oool00000>@3oool300000<@0oooo002i0?ooo`<00000>@3oool2000005h0oooo00@0
00000?ooo`3oool00000=@3oool300000<L0oooo00240?ooo`@000000`3oool2000000@0oooo0P00
000S0?ooo`<00000?03oool00`000000oooo00000002000005`0oooo00@000000?ooo`3oool00000
<@3oool300000<X0oooo00240?ooo`030000003oool0oooo00T0oooo00@000000?ooo`3oool00000
7`3oool3000003h0oooo00D000000?ooo`3oool0oooo0000001M0?ooo`050000003oool0oooo0?oo
o`000000;@3oool300000<d0oooo00250?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool06P3oool300000080oooo00<000000?ooo`3oool0?03oool5000005h0oooo00D000000?ooo`3o
ool0oooo0000000Y0?ooo`<00000d03oool007h0oooo100000040?ooo`030000003oool0oooo00P0
oooo0P00000J0?ooo`<000001@3oool00`000000oooo0?ooo`2P0?ooo`040000003oool0oooo0000
02L0oooo0P00003C0?ooo`00Q03oool010000000oooo0?ooo`0000090?ooo`030000003oool0oooo
01H0oooo0`00001g0?ooo`8000005@3oool00`000000oooo0?ooo`0K0?ooo`040000003oool0oooo
00000?/0oooo00250?ooo`8000002P3oool3000001<0oooo0`00001i0?ooo`030000003oool0oooo
00<000004`3oool2000001`0oooo00@000000?ooo`3oool00000nP3oool00:<0oooo1000001l0?oo
o`8000000P3oool00`000000oooo0?ooo`0C0?ooo`<000006`3oool010000000oooo0?ooo`00003i
0?ooo`00X03oool300000880oooo0`00000F0?ooo`<000006`3oool010000000oooo0?ooo`00003h
0?ooo`00W@3oool300000:00oooo0`00000J0?ooo`040000003oool0oooo00000140oooo0P00003T
0?ooo`00VP3oool3000000030?ooo`000000oooo0:40oooo00@000000?ooo`0000000000603oool0
1@000000oooo0?ooo`3oool0000000`0oooo1000003V0?ooo`00U`3oool3000000@0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`100?ooo`040000003oool0oooo000001P0oooo00@0
00000?ooo`3oool000002@3oool300000>X0oooo002D0?ooo`<00000J@3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo008000005`3oool010000000oooo0?ooo`0000040?ooo`@00000
k@3oool00940oooo0`00001]0?ooo`030000003oool0oooo0400oooo0P0000020?ooo`8000005P3o
ool00`000000oooo0?ooo`0400000?40oooo002>0?ooo`<00000L@3oool00`000000oooo0?ooo`11
0?ooo`050000003oool0oooo0?ooo`0000005P3oool2000000030?ooo`000000oooo0?80oooo002;
0?ooo`<00000M@3oool?000003D0oooo00<000000?ooo`3oool0o`3oool?0?ooo`00R03oool30000
0840oooo100000020?ooo`@00000o`3ooom30?ooo`00Q@3oool4000008L0oooo0`0000030?ooo`80
0000o`3ooom10?ooo`00PP3oool3000000<0oooo00<000000?ooo`3oool0R03oool300000080oooo
0P00003o0?ooocl0oooo001o0?ooo`<000001P3oool00`000000oooo0?ooo`2;0?ooo`8000000P3o
ool00`000000oooo0?ooo`3o0?oooc`0oooo001l0?ooo`<000002@3oool00`000000oooo0?ooo`2=
0?ooo`040000003oool0oooo00000?l0oooo?@3oool007T0oooo0`00002L0?ooo`050000003oool0
oooo0?ooo`000000o`3oooll0?ooo`00MP3oool300000:00oooo00@000000?ooo`3oool00000o`3o
ooll0?ooo`00L`3oool300000:<0oooo00@000000?ooo`3oool00000o`3oooll0?ooo`00L03oool3
000003X0oooo=@00000g0?ooo`040000003oool0oooo00000?l0oooo?03oool006d0oooo0`000002
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0000003o
0?oooc`0oooo001Z0?ooo`<000001@3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo
03P0oooo0P00003o0?ooocd0oooo001W0?ooo`<00000M03oool00`000000oooo0?ooo`0M0?ooo`80
00006@3oool00`000000oooo0000003o0?ooocd0oooo001T0?ooo`<00000MP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo008000005P3oool300000?l0oooo?P3oool00600oooo1000
001h0?ooo`030000003oool0oooo01d0oooo00D000000?ooo`3oool0oooo0000000F0?ooo`800000
o`3ooom00?ooo`00G@3oool3000003T0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0O0?ooo`040000003oool0oooo000001D0oooo0P00003o0?oood40oooo001J0?ooo`<00000>`3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo0P00000D0?ooo`800000o`3o
oom30?ooo`00E`3oool300000080oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo02@0oooo0P00000>0?ooo`@00000o`3ooom50?ooo`00E03oool30000
00D0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
02L0oooo3P00003o0?ooodT0oooo001A0?ooo`<00000@@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0?l0ooooO`3oool004h0oooo0`0000130?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0o`3ooon00?ooo`00B`3oool3000004D0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`3o0?oooh40oooo000O0?ooo`8000009`3oool3000004L0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?oooh80oooo000N0?ooo`040000003oool0oooo
000002<0oooo0`0000190?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0o`3ooon3
0?ooo`008@3oool00`000000oooo0?ooo`0N0?ooo`<0000000<0oooo0000003oool0B03oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooQ03oool001P0oooo100000030?ooo`80
00007P3oool3000000@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0?l0ooooQ@3oool001l0oooo00<000000?ooo`3oool06P3oool3000004l0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooohH0oooo000O0?ooo`<000005`3o
ool300000540oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`3o0?ooohL0oooo000f
0?ooo`<00000D`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0?l0ooooR03oool0
03<0oooo0`00001F0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooon90?oo
o`00<03oool3000005P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooohX0
oooo000]0?ooo`<0000000<0oooo0000003oool0E`3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0?l0ooooR`3oool002X0oooo0`0000040?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?oooh`0oooo000W0?ooo`<00000GP3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo0?l0ooooS@3oool002@0oooo0`00001P0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0o`3ooon>0?ooo`00803oool400000680
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`3o0?ooohl0oooo000M0?ooo`<00000
3`3oool2000005@0oooo00<000000?ooo`3oool0o`3ooooA0?ooo`006P3oool3000001@0oooo0`00
001@0?ooo`030000003oool0oooo0?l0oooodP3oool001L0oooo0`0000020?ooo`030000003oool0
oooo01D0oooo0`00001<0?ooo`030000003oool0oooo0?l0ooood`3oool001@0oooo0`0000050?oo
o`030000003oool0oooo01P0oooo0`0000180?ooo`030000003oool0oooo0?l0ooooe03oool00140
oooo0`0000080?ooo`030000003oool0oooo01/0oooo0`0000140?ooo`030000003oool0oooo0?l0
ooooe@3oool000h0oooo0`00000;0?ooo`030000003oool0oooo01h0oooo0P0000110?oooc@00000
o`3ooonU0?ooo`002`3oool300000340oooo0`00003o0?ooool0oooo603oool000P0oooo0`00000g
0?ooo`<00000o`3ooooo0?oooaD0oooo00050?ooo`<00000?@3oool300000?l0ooooo`3ooolB0?oo
o`000P3oool300000080oooo00<000000?ooo`3oool0?P3oool300000?l0ooooo`3oool?0?ooo`00
0P0000050?ooo`030000003oool0oooo0440oooo0`00003o0?ooool0oooo303oool004h0oooo0`00
003o0?ooool0oooo2@3oool00540oooo0`00003o0?ooool0oooo1P3oool005@0oooo0`00003o0?oo
ool0oooo0`3oool005L0oooo0`00003o0?ooool0oooo001J0?ooo`800000o`3oooom0?ooo`00G03o
ool300000?l0oooonP3oool005l0oooo0`00003o0?ooooL0oooo001R0?ooo`<00000o`3ooood0?oo
o`00<@3oool5000002l0oooo0`00003o0?oooo40oooo000`0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0<03oool300000?l0ooookP3oool001L0oooo0P00000G0?ooo`8000000P3o
ool00`000000oooo0?ooo`0d0?ooo`<00000o`3oooo[0?ooo`006@3oool4000001D0oooo0`00000i
0?ooo`<00000o`3ooooX0?ooo`007@3oool300000540oooo0`00003o0?ooonD0oooo000P0?ooo`80
0000DP3oool300000?l0oooohP3oool001h0oooo1@00001D0?ooo`<00000o`3ooooO0?ooo`007P3o
ool010000000oooo0?ooo`00001H0?ooo`800000o`3ooooM0?ooo`007P3oool4000005X0oooo0`00
003o0?ooomX0oooo001o0?ooo`<00000o`3ooooG0?ooo`00PP3oool300000?l0ooooe03oool008D0
oooo0`00003o0?ooom40oooo00280?ooo`800000o`3oooo?0?ooo`00o`3ooooo0?oooeX0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0oooo
FP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0
ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3o
oooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {238.313, 0}} -> {0.0381158, 0.278835, \
0.00169667, 0.00169667}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay[FromCharacterCode[Range[945, 969]]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35319 
%%ImageSize: 600 211.916 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0505595 1.05056 -0.337706 1.05056 [
[.00778 .29926 -8.189 -9 ]
[.00778 .29926 9.811 0 ]
[.22664 .2283 -5.70876 -9 ]
[.22664 .2283 6.29124 0 ]
[.45777 .15337 -2.9899 -9 ]
[.45777 .15337 3.0101 0 ]
[.70223 .07415 -3.1377 -9 ]
[.70223 .07415 2.8623 0 ]
[.96122 -0.00975 -6.59904 -9 ]
[.96122 -0.00975 5.40096 0 ]
[.45928 .08729 -4.98447 -12.75 ]
[.45928 .08729 5.01553 0 ]
[.99062 .00375 0 -5.95 ]
[.99062 .00375 24 3.05 ]
[.99606 .0117 0 -5.94516 ]
[.99606 .0117 30 3.05484 ]
[1.00148 .0196 0 -5.94036 ]
[1.00148 .0196 6 3.05964 ]
[1.00687 .02746 0 -5.93559 ]
[1.00687 .02746 24 3.06441 ]
[1.06103 -0.00479 0 -8.41925 ]
[1.06103 -0.00479 10 4.33075 ]
[ 0 0 0 0 ]
[ 1 .35319 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00078 .31423 m
.97278 0 L
s
.0066 .31234 m
.00601 .31888 L
s
[(-10)] .00778 .29926 -0.09011 1 Mshowa
.22601 .24142 m
.22569 .24797 L
s
[(-5)] .22664 .2283 -0.04854 1 Mshowa
.45773 .1665 m
.4577 .17307 L
s
[(0)] .45777 .15337 -0.00337 1 Mshowa
.70283 .08727 m
.70314 .09383 L
s
[(5)] .70223 .07415 .0459 1 Mshowa
.96252 .00331 m
.96318 .00985 L
s
[(10)] .96122 -0.00975 .09984 1 Mshowa
.125 Mabswid
.04954 .29846 m
.04922 .30239 L
s
.09295 .28443 m
.09266 .28836 L
s
.13682 .27025 m
.13656 .27418 L
s
.18117 .25591 m
.18095 .25984 L
s
.27133 .22676 m
.27117 .2307 L
s
.31716 .21195 m
.31704 .21588 L
s
.36349 .19697 m
.36341 .20091 L
s
.41035 .18182 m
.4103 .18576 L
s
.50564 .15101 m
.50567 .15495 L
s
.5541 .13535 m
.55416 .13929 L
s
.60311 .1195 m
.60321 .12344 L
s
.65269 .10348 m
.65283 .10742 L
s
.75357 .07087 m
.75379 .0748 L
s
.80489 .05427 m
.80515 .05821 L
s
.85682 .03749 m
.85712 .04142 L
s
.90936 .0205 m
.9097 .02443 L
s
gsave
.45928 .08729 -65.9845 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97278 0 m
.99905 .03829 L
s
.97812 .00778 m
.97187 .0098 L
s
[(-0.5)] .99062 .00375 -1 .32222 Mshowa
.98356 .01571 m
.97731 .01772 L
s
[(-0.25)] .99606 .0117 -1 .32115 Mshowa
.98897 .02361 m
.98272 .02561 L
s
[(0)] 1.00148 .0196 -1 .32008 Mshowa
.99436 .03145 m
.9881 .03345 L
s
[(0.25)] 1.00687 .02746 -1 .31902 Mshowa
.125 Mabswid
.97374 .0014 m
.96999 .00261 L
s
.97484 .003 m
.97109 .00421 L
s
.97593 .0046 m
.97218 .00581 L
s
.97702 .00619 m
.97327 .0074 L
s
.97921 .00937 m
.97546 .01058 L
s
.9803 .01096 m
.97655 .01217 L
s
.98139 .01255 m
.97764 .01375 L
s
.98247 .01413 m
.97872 .01534 L
s
.98465 .0173 m
.98089 .0185 L
s
.98573 .01888 m
.98198 .02008 L
s
.98681 .02045 m
.98306 .02166 L
s
.98789 .02203 m
.98414 .02323 L
s
.99005 .02518 m
.9863 .02638 L
s
.99113 .02675 m
.98738 .02795 L
s
.99221 .02832 m
.98846 .02952 L
s
.99328 .02989 m
.98953 .03108 L
s
.99543 .03302 m
.99168 .03421 L
s
.99651 .03458 m
.99275 .03578 L
s
.99758 .03614 m
.99382 .03734 L
s
.99865 .0377 m
.99489 .03889 L
s
gsave
1.06103 -0.00479 -61 -12.4193 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35319 L
0 .35319 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05037 .33194 m
.04645 .33131 L
s
.05663 .33183 m
.05037 .33194 L
s
.05663 .33183 m
.06134 .33033 L
s
.05663 .33183 m
.0488 .33056 L
s
.04645 .33131 m
.04095 .32929 L
s
.0488 .33056 m
.0433 .32853 L
s
.06134 .33033 m
.06213 .32819 L
s
.06134 .33033 m
.06449 .32743 L
s
.04095 .32929 m
.0378 .32651 L
s
.0433 .32853 m
.04015 .32575 L
s
.06213 .32819 m
.05587 .31691 L
s
.06449 .32743 m
.05824 .31616 L
s
.06608 .32314 m
.07313 .32657 L
s
.0378 .32651 m
.037 .32297 L
s
.09826 .3261 m
.103 .32459 L
s
.09826 .3261 m
.09043 .32483 L
s
.04015 .32575 m
.03935 .32221 L
s
.09435 .32546 m
.08888 .32343 L
s
.09043 .32483 m
.08496 .3228 L
s
.103 .32459 m
.10383 .32245 L
s
.103 .32459 m
.10621 .32169 L
s
.08888 .32343 m
.07479 .31656 L
s
.05666 .32047 m
.06608 .32314 L
s
.037 .32297 m
.04013 .32006 L
s
.08496 .3228 m
.07085 .31592 L
s
.10383 .32245 m
.10074 .31965 L
s
.03935 .32221 m
.04013 .32006 L
s
.10621 .32169 m
.10312 .3189 L
s
.04879 .31919 m
.05666 .32047 L
s
.04013 .32006 m
.04249 .3193 L
s
.10074 .31965 m
.09527 .31761 L
s
.04249 .3193 m
.04879 .31919 L
s
.10312 .3189 m
.09764 .31686 L
s
.08896 .31773 m
.08978 .31557 L
s
.08896 .31773 m
.09216 .31481 L
s
.09527 .31761 m
.08896 .31773 L
s
.09764 .31686 m
.08896 .31773 L
s
.05587 .31691 m
.05904 .31399 L
s
.07247 .31159 m
.07479 .31656 L
s
.07479 .31656 m
.05747 .30684 L
s
.05824 .31616 m
.05904 .31399 L
s
.07085 .31592 m
.0551 .3076 L
s
.08978 .31557 m
.08904 .312 L
s
.09216 .31481 m
.09142 .31124 L
s
.05904 .31399 m
.0614 .31323 L
s
.11586 .31294 m
.12064 .31142 L
s
.108 .31165 m
.11586 .31294 L
s
.08904 .312 m
.08592 .30919 L
s
.108 .31165 m
.11432 .31153 L
s
.07565 .30866 m
.07247 .31159 L
s
.11432 .31153 m
.1191 .31001 L
s
.12064 .31142 m
.12388 .30848 L
s
.09142 .31124 m
.0883 .30842 L
s
.1191 .31001 m
.12234 .30707 L
s
.08592 .30919 m
.07803 .3079 L
s
.07803 .3079 m
.07565 .30866 L
s
.12388 .30848 m
.12164 .30348 L
s
.0883 .30842 m
.08436 .30778 L
s
.08436 .30778 m
.07803 .3079 L
s
.12234 .30707 m
.12164 .30348 L
s
.16667 .30625 m
.17149 .30472 L
s
.16274 .3056 m
.16667 .30625 L
s
.1374 .30607 m
.13038 .3026 L
s
.16122 .30419 m
.16274 .3056 L
s
.16515 .30484 m
.16997 .3033 L
s
.16122 .30419 m
.16515 .30484 L
s
.17149 .30472 m
.17238 .30254 L
s
.16058 .30059 m
.16122 .30419 L
s
.12164 .30348 m
.11389 .29639 L
s
.16997 .3033 m
.17176 .29893 L
s
.13038 .3026 m
.11389 .29639 L
s
.17238 .30254 m
.17176 .29893 L
s
.16476 .29544 m
.16058 .30059 L
s
.15029 .30006 m
.14635 .29941 L
s
.15664 .29994 m
.15029 .30006 L
s
.15664 .29994 m
.14875 .29864 L
s
.16146 .2984 m
.15664 .29994 L
s
.14635 .29941 m
.14086 .29733 L
s
.14875 .29864 m
.14327 .29656 L
s
.16324 .29401 m
.16146 .2984 L
s
.14086 .29733 m
.13778 .29449 L
s
.14327 .29656 m
.13865 .29229 L
s
.11389 .29639 m
.10285 .29223 L
s
.11389 .29639 m
.10525 .29146 L
s
.16413 .29181 m
.16476 .29544 L
s
.13778 .29449 m
.1371 .29086 L
s
.15864 .28973 m
.16324 .29401 L
s
.13865 .29229 m
.14039 .28788 L
s
.16106 .28895 m
.16413 .29181 L
s
.1371 .29086 m
.14039 .28788 L
s
.18172 .29003 m
.1802 .2886 L
s
.1881 .28991 m
.18172 .29003 L
s
.1881 .28991 m
.18415 .28925 L
s
.19539 .28758 m
.1881 .28991 L
s
.15315 .28764 m
.15864 .28973 L
s
.18415 .28925 m
.18263 .28782 L
s
.15557 .28687 m
.16106 .28895 L
s
.1802 .2886 m
.1811 .28639 L
s
.14039 .28788 m
.14523 .28633 L
s
.18263 .28782 m
.18444 .2834 L
s
.14523 .28633 m
.15315 .28764 L
s
.19874 .28459 m
.19539 .28758 L
s
.15161 .28621 m
.15557 .28687 L
s
.1811 .28639 m
.18444 .2834 L
s
.22336 .28633 m
.21942 .28567 L
s
.14523 .28633 m
.15161 .28621 L
s
.21942 .28567 m
.21792 .28424 L
s
.17562 .2843 m
.17166 .28364 L
s
.18444 .2834 m
.17562 .2843 L
s
.21792 .28424 m
.2213 .28124 L
s
.17166 .28364 m
.1686 .28076 L
s
.17805 .28352 m
.17409 .28286 L
s
.18444 .2834 m
.17805 .28352 L
s
.17409 .28286 m
.17103 .27998 L
s
.21246 .28214 m
.2085 .28148 L
s
.2213 .28124 m
.21246 .28214 L
s
.2085 .28148 m
.20303 .27938 L
s
.2149 .28136 m
.21095 .2807 L
s
.2213 .28124 m
.2149 .28136 L
s
.23015 .28034 m
.2213 .28124 L
s
.2213 .28124 m
.22865 .2789 L
s
.1686 .28076 m
.17193 .27776 L
s
.21095 .2807 m
.20548 .2786 L
s
.22865 .2789 m
.23015 .28034 L
s
.17103 .27998 m
.17193 .27776 L
s
.20303 .27938 m
.2 .27649 L
s
.20548 .2786 m
.20244 .27571 L
s
.17193 .27776 m
.17924 .27541 L
s
.2 .27649 m
.1994 .27282 L
s
.20244 .27571 m
.20185 .27203 L
s
.17924 .27541 m
.18565 .27529 L
s
.23697 .27432 m
.24188 .27276 L
s
.23301 .27366 m
.23697 .27432 L
s
.22754 .27155 m
.23301 .27366 L
s
.23942 .27354 m
.24038 .27131 L
s
.1994 .27282 m
.20033 .27058 L
s
.24188 .27276 m
.24285 .27052 L
s
.20185 .27203 m
.20371 .26755 L
s
.24038 .27131 m
.23888 .26986 L
s
.20033 .27058 m
.20371 .26755 L
s
.24285 .27052 m
.24135 .26907 L
s
.23888 .26986 m
.2234 .26124 L
s
.24531 .26973 m
.25174 .26961 L
s
.24135 .26907 m
.24531 .26973 L
s
.25174 .26961 m
.25668 .26804 L
s
.24135 .26907 m
.22586 .26045 L
s
.25668 .26804 m
.25765 .2658 L
s
.25668 .26804 m
.26013 .26501 L
s
.20371 .26755 m
.20465 .26531 L
s
.25765 .2658 m
.25466 .26288 L
s
.1927 .26331 m
.19177 .26555 L
s
.20465 .26531 m
.2016 .26239 L
s
.26013 .26501 m
.25714 .26209 L
s
.19761 .26172 m
.1927 .26331 L
s
.25466 .26288 m
.23217 .2506 L
s
.29731 .26282 m
.29334 .26215 L
s
.30228 .26124 m
.29731 .26282 L
s
.2016 .26239 m
.19761 .26172 L
s
.29334 .26215 m
.29039 .25923 L
s
.25714 .26209 m
.23465 .2498 L
s
.30035 .25605 m
.30228 .26124 L
s
.3033 .25898 m
.30228 .26124 L
s
.275 .26026 m
.27996 .25868 L
s
.27102 .25959 m
.275 .26026 L
s
.26556 .25746 m
.27102 .25959 L
s
.27748 .25947 m
.27848 .25721 L
s
.29039 .25923 m
.28992 .2555 L
s
.30285 .25526 m
.3033 .25898 L
s
.27996 .25868 m
.28096 .25642 L
s
.27848 .25721 m
.27252 .25134 L
s
.28096 .25642 m
.27351 .24906 L
s
.29592 .25164 m
.30035 .25605 L
s
.28992 .2555 m
.29444 .25017 L
s
.29842 .25084 m
.30285 .25526 L
s
.28897 .24802 m
.29592 .25164 L
s
.27252 .25134 m
.27202 .24759 L
s
.29147 .24722 m
.29842 .25084 L
s
.29444 .25017 m
.29795 .2471 L
s
.27351 .24906 m
.27302 .24531 L
s
.2835 .24586 m
.28897 .24802 L
s
.27202 .24759 m
.27302 .24531 L
s
.32139 .2474 m
.30604 .23864 L
s
.28599 .24506 m
.29147 .24722 L
s
.3239 .2466 m
.30856 .23783 L
s
.27551 .24451 m
.2835 .24586 L
s
.27302 .24531 m
.27551 .24451 L
s
.282 .24439 m
.28599 .24506 L
s
.27551 .24451 m
.282 .24439 L
s
.34403 .24019 m
.32324 .22919 L
s
.34655 .23938 m
.32576 .22838 L
s
.30604 .23864 m
.30456 .23715 L
s
.37512 .23808 m
.38019 .23647 L
s
.30856 .23783 m
.30707 .23634 L
s
.30456 .23715 m
.30559 .23485 L
s
.38019 .23647 m
.38128 .23417 L
s
.38019 .23647 m
.38382 .23336 L
s
.30707 .23634 m
.30811 .23405 L
s
.35666 .23616 m
.34869 .23479 L
s
.36172 .23454 m
.35666 .23616 L
s
.33964 .23572 m
.34323 .23262 L
s
.33964 .23572 m
.3407 .23342 L
s
.34869 .23479 m
.33964 .23572 L
s
.35919 .23535 m
.36027 .23305 L
s
.31714 .23311 m
.32262 .23529 L
s
.30559 .23485 m
.31062 .23324 L
s
.3628 .23224 m
.36172 .23454 L
s
.38128 .23417 m
.38175 .21041 L
s
.3407 .23342 m
.33989 .22582 L
s
.38382 .23336 m
.38431 .20959 L
s
.31062 .23324 m
.31714 .23311 L
s
.36027 .23305 m
.3628 .23224 L
s
.34323 .23262 m
.34243 .225 L
s
.33989 .22582 m
.3435 .22269 L
s
.38313 .22576 m
.3613 .21697 L
s
.38313 .22576 m
.35875 .21779 L
s
.34243 .225 m
.3435 .22269 L
s
.35004 .22256 m
.35551 .22475 L
s
.3435 .22269 m
.35004 .22256 L
s
.41012 .21911 m
.38105 .20267 L
s
.41269 .21829 m
.38362 .20184 L
s
.4281 .21338 m
.41291 .20439 L
s
.43067 .21256 m
.41548 .20356 L
s
.39892 .21085 m
.39603 .20781 L
s
.44098 .20927 m
.44873 .2068 L
s
.39603 .20781 m
.39715 .20547 L
s
.44615 .20762 m
.4307 .1947 L
s
.44873 .2068 m
.43759 .19847 L
s
.39715 .20547 m
.40229 .20382 L
s
.41291 .20439 m
.41146 .20286 L
s
.40889 .20369 m
.41291 .20439 L
s
.40229 .20382 m
.40889 .20369 L
s
.41548 .20356 m
.41404 .20203 L
s
.41146 .20286 m
.4126 .20051 L
s
.41404 .20203 m
.41518 .19968 L
s
.42179 .19955 m
.42725 .20178 L
s
.46687 .20102 m
.46947 .20019 L
s
.46262 .19642 m
.46687 .20102 L
s
.4126 .20051 m
.41777 .19885 L
s
.46947 .20019 m
.46262 .19642 L
s
.4959 .19968 m
.4919 .19898 L
s
.41777 .19885 m
.42179 .19955 L
s
.4919 .19898 m
.4905 .19744 L
s
.43759 .19847 m
.4307 .1947 L
s
.4905 .19744 m
.49432 .19425 L
s
.46262 .19642 m
.45316 .19348 L
s
.4333 .19386 m
.4307 .1947 L
s
.48769 .19438 m
.48368 .19367 L
s
.49693 .19342 m
.48769 .19438 L
s
.49432 .19425 m
.50216 .19175 L
s
.44251 .1929 m
.4333 .19386 L
s
.48368 .19367 m
.48086 .19059 L
s
.4903 .19354 m
.48629 .19284 L
s
.49693 .19342 m
.4903 .19354 L
s
.45316 .19348 m
.44251 .1929 L
s
.48629 .19284 m
.48347 .18976 L
s
.48086 .19059 m
.48468 .18738 L
s
.48347 .18976 m
.48468 .18738 L
s
.47804 .18751 m
.47401 .1868 L
s
.4873 .18654 m
.47804 .18751 L
s
.48468 .18738 m
.49253 .18487 L
s
.47401 .1868 m
.47118 .18371 L
s
.48065 .18667 m
.47663 .18596 L
s
.4873 .18654 m
.48065 .18667 L
s
.47663 .18596 m
.47379 .18287 L
s
.51247 .18448 m
.50845 .18377 L
s
.51912 .18435 m
.51247 .18448 L
s
.51912 .18435 m
.51108 .18293 L
s
.52438 .18268 m
.51912 .18435 L
s
.50845 .18377 m
.50303 .18151 L
s
.47118 .18371 m
.47499 .18048 L
s
.51108 .18293 m
.50565 .18067 L
s
.47379 .18287 m
.47499 .18048 L
s
.52687 .17789 m
.52438 .18268 L
s
.52826 .17944 m
.52438 .18268 L
s
.50303 .18151 m
.50022 .17841 L
s
.50565 .18067 m
.50144 .17601 L
s
.47499 .18048 m
.47882 .17724 L
s
.52812 .17549 m
.52826 .17944 L
s
.50022 .17841 m
.50004 .17445 L
s
.5227 .17322 m
.52687 .17789 L
s
.47882 .17724 m
.48002 .17484 L
s
.50144 .17601 m
.5039 .1712 L
s
.52534 .17237 m
.52812 .17549 L
s
.54814 .1751 m
.57735 .16579 L
s
.54008 .17367 m
.54814 .1751 L
s
.48002 .17484 m
.4786 .17328 L
s
.50004 .17445 m
.5039 .1712 L
s
.47456 .17257 m
.46931 .17426 L
s
.54008 .17367 m
.54676 .17354 L
s
.54676 .17354 m
.57598 .16422 L
s
.4786 .17328 m
.47456 .17257 L
s
.51726 .17094 m
.5227 .17322 L
s
.5199 .17009 m
.52534 .17237 L
s
.5039 .1712 m
.50918 .16951 L
s
.55471 .17101 m
.53831 .16016 L
s
.55471 .17101 m
.53566 .16101 L
s
.50918 .16951 m
.51726 .17094 L
s
.51586 .16938 m
.5199 .17009 L
s
.50918 .16951 m
.51586 .16938 L
s
.56533 .16762 m
.55429 .15503 L
s
.56533 .16762 m
.55162 .15588 L
s
.59468 .15825 m
.59064 .15753 L
s
.6014 .15812 m
.59468 .15825 L
s
.6014 .15812 m
.59332 .15667 L
s
.60676 .15641 m
.6014 .15812 L
s
.59064 .15753 m
.58523 .15522 L
s
.59332 .15667 m
.58791 .15437 L
s
.60676 .15641 m
.60942 .15153 L
s
.60676 .15641 m
.61077 .15311 L
s
.58523 .15522 m
.5648 .14352 L
s
.58791 .15437 m
.56748 .14265 L
s
.61077 .15311 m
.61075 .14909 L
s
.58243 .14803 m
.58249 .15206 L
s
.60942 .15153 m
.60534 .14677 L
s
.61075 .14909 m
.60804 .14591 L
s
.63771 .14856 m
.63367 .14783 L
s
.64716 .14756 m
.63771 .14856 L
s
.58643 .14471 m
.58243 .14803 L
s
.63367 .14783 m
.62828 .14551 L
s
.65528 .14498 m
.64716 .14756 L
s
.60534 .14677 m
.59993 .14445 L
s
.60804 .14591 m
.60262 .14358 L
s
.62828 .14551 m
.62558 .14232 L
s
.66209 .14079 m
.65528 .14498 L
s
.59181 .14299 m
.58643 .14471 L
s
.59993 .14445 m
.59181 .14299 L
s
.60262 .14358 m
.59856 .14285 L
s
.59856 .14285 m
.59181 .14299 L
s
.62558 .14232 m
.62558 .13826 L
s
.66347 .13833 m
.66209 .14079 L
s
.62558 .13826 m
.62829 .13332 L
s
.62829 .13332 m
.6351 .12499 L
s
.68395 .12977 m
.67989 .12903 L
s
.69074 .12963 m
.68395 .12977 L
s
.69074 .12963 m
.68262 .12815 L
s
.71268 .12264 m
.69074 .12963 L
s
.67989 .12903 m
.6745 .12668 L
s
.68262 .12815 m
.67723 .1258 L
s
.69906 .12291 m
.69621 .12789 L
s
.6745 .12668 m
.67184 .12344 L
s
.67723 .1258 m
.67324 .12095 L
s
.6351 .12499 m
.63511 .12088 L
s
.70038 .12452 m
.71137 .12102 L
s
.70049 .12041 m
.70038 .12452 L
s
.67184 .12344 m
.6719 .11933 L
s
.6951 .11804 m
.69906 .12291 L
s
.67324 .12095 m
.67605 .11594 L
s
.63511 .12088 m
.6324 .11764 L
s
.69785 .11716 m
.70049 .12041 L
s
.6719 .11933 m
.67605 .11594 L
s
.62831 .11689 m
.62285 .11865 L
s
.72644 .11825 m
.75133 .11031 L
s
.71832 .11676 m
.72644 .11825 L
s
.6897 .11567 m
.6951 .11804 L
s
.6324 .11764 m
.62831 .11689 L
s
.69245 .11479 m
.69785 .11716 L
s
.71832 .11676 m
.72514 .11662 L
s
.72514 .11662 m
.75004 .10868 L
s
.67605 .11594 m
.68154 .11418 L
s
.68154 .11418 m
.6897 .11567 L
s
.68837 .11405 m
.69245 .11479 L
s
.68154 .11418 m
.68837 .11405 L
s
.73619 .1131 m
.72296 .10089 L
s
.73619 .1131 m
.72018 .10178 L
s
.76244 .10677 m
.76801 .10499 L
s
.75837 .10602 m
.76244 .10677 L
s
.753 .10363 m
.75837 .10602 L
s
.76522 .10588 m
.76672 .10335 L
s
.76801 .10499 m
.76951 .10246 L
s
.76672 .10335 m
.76414 .10007 L
s
.76951 .10246 m
.76693 .09918 L
s
.76414 .10007 m
.75747 .09602 L
s
.78474 .09966 m
.78626 .09712 L
s
.78754 .09876 m
.78474 .09966 L
s
.76693 .09918 m
.76026 .09512 L
s
.7837 .09382 m
.78754 .09876 L
s
.75747 .09602 m
.75488 .09272 L
s
.76026 .09512 m
.75767 .09182 L
s
.77704 .08975 m
.7837 .09382 L
s
.75488 .09272 m
.75916 .08927 L
s
.75767 .09182 m
.75916 .08927 L
s
.80589 .09085 m
.80181 .0901 L
s
.80181 .0901 m
.79645 .08768 L
s
.76886 .08823 m
.77704 .08975 L
s
.75916 .08927 m
.76196 .08837 L
s
.76196 .08837 m
.76886 .08823 L
s
.79645 .08768 m
.79389 .08436 L
s
.82404 .08712 m
.81996 .08636 L
s
.82969 .08533 m
.82404 .08712 L
s
.81996 .08636 m
.81461 .08394 L
s
.82278 .08546 m
.81461 .08394 L
s
.82843 .08366 m
.82278 .08546 L
s
.83125 .08276 m
.82969 .08533 L
s
.79389 .08436 m
.79542 .08179 L
s
.79389 .08436 m
.79414 .08012 L
s
.81461 .08394 m
.80797 .07984 L
s
.82999 .08109 m
.82843 .08366 L
s
.82873 .07943 m
.83125 .08276 L
s
.79542 .08179 m
.79978 .07831 L
s
.84099 .08172 m
.84382 .08082 L
s
.84382 .08082 m
.84541 .07824 L
s
.84382 .08082 m
.84824 .07734 L
s
.79414 .08012 m
.7985 .07664 L
s
.80797 .07984 m
.80132 .07574 L
s
.80797 .07984 m
.79053 .07085 L
s
.82337 .07699 m
.82873 .07943 L
s
.8221 .07532 m
.82873 .07943 L
s
.79978 .07831 m
.80542 .0765 L
s
.84541 .07824 m
.84009 .057 L
s
.84824 .07734 m
.84295 .05608 L
s
.81518 .07546 m
.82337 .07699 L
s
.7985 .07664 m
.80414 .07483 L
s
.80542 .0765 m
.81518 .07546 L
s
.80132 .07574 m
.79336 .06994 L
s
.8139 .07378 m
.8221 .07532 L
s
.80414 .07483 m
.8139 .07378 L
s
.86654 .07357 m
.85711 .07036 L
s
.85711 .07036 m
.83122 .06404 L
s
.88365 .06812 m
.88937 .06629 L
s
.87956 .06735 m
.88365 .06812 L
s
.91146 .06756 m
.88187 .04144 L
s
.87422 .06489 m
.87956 .06735 L
s
.88651 .0672 m
.88814 .06461 L
s
.91433 .06664 m
.87899 .04237 L
s
.88937 .06629 m
.891 .06369 L
s
.88814 .06461 m
.88319 .05785 L
s
.83122 .06404 m
.82172 .06081 L
s
.891 .06369 m
.88358 .05353 L
s
.88319 .05785 m
.88234 .05183 L
s
.84009 .057 m
.84454 .05346 L
s
.91442 .05204 m
.92096 .05622 L
s
.84295 .05608 m
.84454 .05346 L
s
.88358 .05353 m
.88522 .05091 L
s
.84454 .05346 m
.8474 .05254 L
s
.90908 .04956 m
.91442 .05204 L
s
.88234 .05183 m
.88397 .04921 L
s
.88522 .05091 m
.89385 .04814 L
s
.89962 .04629 m
.90908 .04956 L
s
.90085 .048 m
.90908 .04956 L
s
.88397 .04921 m
.89261 .04643 L
s
.93707 .04899 m
.93297 .04821 L
s
.94407 .04885 m
.93707 .04899 L
s
.93707 .04899 m
.94287 .04714 L
s
.94287 .04714 m
.94407 .04885 L
s
.93297 .04821 m
.92764 .04572 L
s
.89385 .04814 m
.90085 .048 L
s
.89261 .04643 m
.89962 .04629 L
s
.92764 .04572 m
.9252 .0423 L
s
.96149 .0433 m
.96029 .04159 L
s
.9632 .04066 m
.96149 .0433 L
s
.9252 .0423 m
.92856 .03701 L
s
.9252 .0423 m
.92566 .03794 L
s
.94625 .04187 m
.94019 .03328 L
s
.96029 .04159 m
.9632 .04066 L
s
.94262 .03672 m
.94916 .04094 L
s
.96371 .03629 m
.9632 .04066 L
s
.92566 .03794 m
.92734 .03529 L
s
.92856 .03701 m
.93437 .03514 L
s
.94262 .03672 m
.9431 .03234 L
s
.93437 .03514 m
.94262 .03672 L
s
.93728 .03421 m
.94262 .03672 L
s
.96131 .03285 m
.96371 .03629 L
s
.92734 .03529 m
.93315 .03342 L
s
.93315 .03342 m
.93728 .03421 L
s
.94019 .03328 m
.94188 .03062 L
s
.95598 .03033 m
.96131 .03285 L
s
.9431 .03234 m
.94893 .03047 L
s
.94188 .03062 m
.94772 .02875 L
s
.94893 .03047 m
.95598 .03033 L
s
.94772 .02875 m
.95598 .03033 L
s
0 g
.25 Mabswid
.00078 .31423 m
.97278 0 L
s
.0066 .31234 m
.00601 .31888 L
s
[(-10)] .00778 .29926 -0.09011 1 Mshowa
.22601 .24142 m
.22569 .24797 L
s
[(-5)] .22664 .2283 -0.04854 1 Mshowa
.45773 .1665 m
.4577 .17307 L
s
[(0)] .45777 .15337 -0.00337 1 Mshowa
.70283 .08727 m
.70314 .09383 L
s
[(5)] .70223 .07415 .0459 1 Mshowa
.96252 .00331 m
.96318 .00985 L
s
[(10)] .96122 -0.00975 .09984 1 Mshowa
.125 Mabswid
.04954 .29846 m
.04922 .30239 L
s
.09295 .28443 m
.09266 .28836 L
s
.13682 .27025 m
.13656 .27418 L
s
.18117 .25591 m
.18095 .25984 L
s
.27133 .22676 m
.27117 .2307 L
s
.31716 .21195 m
.31704 .21588 L
s
.36349 .19697 m
.36341 .20091 L
s
.41035 .18182 m
.4103 .18576 L
s
.50564 .15101 m
.50567 .15495 L
s
.5541 .13535 m
.55416 .13929 L
s
.60311 .1195 m
.60321 .12344 L
s
.65269 .10348 m
.65283 .10742 L
s
.75357 .07087 m
.75379 .0748 L
s
.80489 .05427 m
.80515 .05821 L
s
.85682 .03749 m
.85712 .04142 L
s
.90936 .0205 m
.9097 .02443 L
s
gsave
.45928 .08729 -65.9845 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 211.875},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000db000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0oooo4P3oool500000080oooo0P00000o0?ooo`00o`3ooooo0?oooa@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03`0oooo003o0?ooool0
oooo503oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0?03oool00?l0
ooooo`3ooolD0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0l0?oo
o`00o`3ooooo0?oooa@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
03`0oooo003o0?ooool0oooo4`3oool2000000@0oooo0P00000o0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3ooom@0?ooo`<0
000000<0oooo000000000000103oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo
0P00000L0?ooo`00o`3ooooo0?ooobl0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`00o`3ooooo0?oooad0oooo0P00000@0?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool06@3oool00?l0ooooo`3ooolJ0?ooo`H000002@3oool400000080oooo
00@000000?ooo`3oool000002@3oool2000001`0oooo003o0?ooool0oooo5`3oool3000000<0oooo
1000000>0?ooo`030000003oool0oooo00<00000103oool2000000030?ooo`000000oooo00@00000
0`3oool2000001<0oooo003o0?ooool0oooo503oool3000000030?ooo`000000oooo00@0oooo0`00
000?0?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`<000001@3oool010000000oooo0?oo
o`00000B0?ooo`00o`3ooooo0?oooa40oooo0`0000050?ooo`030000003oool0oooo0080oooo1000
000@0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0@0?ooo`00o`3ooooo0?ooo`d0oooo100000080?ooo`040000003oool0oooo0?ooo`<00000
00<0oooo0000003oool02@3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`020?ooo`8000004`3oool00?l0ooooo`3oool:0?ooo`<000004P3oool2000000030?oo
o`000000oooo00h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0180oooo003o0?ooool0oooo1`3oool3000001H0oooo1000000<0?ooo`80
000000<0oooo0000000000002P3oool2000000@0oooo0`00000B0?ooo`00o`3ooooo0?ooo`@0oooo
0`00000J0?ooo`<000002`3oool010000000oooo0?ooo`00000W0?ooo`00o`3ooooo0?ooo`40oooo
0`00000O0?ooo`8000002P3oool010000000oooo0?ooo`00000W0?ooo`00o`3oooom0?ooo`<00000
7`3oool4000000030?ooo`000000oooo00P0oooo00@000000?ooo`3oool000009`3oool00?l0oooo
nP3oool3000002D0oooo100000080?ooo`030000003oool0oooo00<00000103oool2000000<0oooo
100000030?ooo`8000004`3oool00?l0oooom`3oool4000002P0oooo0`0000090?ooo`<000000P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
4P3oool00?l0oooom03oool3000000<0oooo00<000000?ooo`3oool09P3oool4000000X0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo
003o0?oooo40oooo0`00000^0?ooo`D000002P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo0P00000C0?ooo`00o`3oooo]0?ooo`@00000=03oool4000000P0oooo00@0
00000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo0180
oooo003o0?ooonX0oooo0`00000Q0?ooo`@000004`3oool2000000030?ooo`000000oooo00P0oooo
0P00000:0?ooo`800000103oool300000180oooo003o0?ooonL0oooo0`00000R0?ooo`80000000<0
oooo0000000000001@00000@0?ooo`@00000;`3oool00?l0ooooi03oool3000001l0oooo0P000003
0?ooo`@000001`3oool2000000d0oooo0`0000000`3oool000000?ooo`0^0?ooo`00o`3ooooQ0?oo
o`<00000803oool2000000030?ooo`00000000000080000000<0oooo0000003oool02@3oool00`00
0000oooo0?ooo`0=0?ooo`80000000<0oooo0000003oool0;@3oool00?l0oooogP3oool300000280
oooo100000030?ooo`<000002`3oool00`000000oooo0?ooo`0=0?ooo`@00000;@3oool00?l0oooo
f`3oool3000002D0oooo0P0000080?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`<00000
;@3oool00?l0oooof03oool300000080oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`070?ooo`040000003oool00000000000L0oooo00<000000?ooo`3oool0?P3oool00?l0ooooe@3o
ool3000000D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000G0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool01@3oool200000440oooo003o0?ooom80oooo0`00000E
0?ooo`<000005P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo03l0oooo003o0?oo
olh0oooo1000000J0?ooo`8000000P3oool6000000h0oooo0P00001C0?ooo`00o`3oooo;0?ooo`<0
00007`3oool3000000030?ooo`000000000000H000003@3oool2000000<0oooo0P00001<0?ooo`00
o`3oooo80?ooo`<000008@3oool5000000L0oooo0`00000=0?ooo`H00000B`3oool00?l0ooooa@3o
ool3000002<0oooo00D000000?ooo`00000000000?ooo`02000000T0oooo0P00001L0?ooo`00o`3o
ooo20?ooo`<000004@3oool300000180oooo0P0000040?ooo`8000002P3oool00`000000oooo0?oo
o`1I0?ooo`00o`3ooono0?ooo`<000004`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
000000D0oooo00<000000?ooo`3oool0203oool2000005T0oooo003o0?oook`0oooo0`0000000`3o
ool000000?ooo`0B0?ooo`8000005@3oool00`000000oooo000000060?ooo`8000002P3oool00`00
0000oooo0?ooo`1F0?ooo`00o`3oooni0?ooo`<00000103oool00`000000oooo0?ooo`0A0?ooo`80
00005@3oool010000000oooo0?ooo`0000060?ooo`800000HP3oool00?l0ooooQP3oool2000002h0
oooo0`00000A0?ooo`800000203oool2000001H0oooo00@000000?ooo`3oool000001P3oool20000
0640oooo003o0?ooohD0oooo00@000000?ooo`3oool00000:P3oool3000001H0oooo0P0000070?oo
o`8000005P3oool00`000000oooo000000070?ooo`<00000G`3oool00?l0ooooR03oool00`000000
oooo0?ooo`0U0?ooo`<000006`3oool3000000@0oooo0P00000G0?ooo`030000003oool0000000P0
oooo0P00001N0?ooo`00o`3ooon60?ooo`800000903oool400000240oooo1P00000?0?ooo`800000
1@3oool3000000X0oooo0`00001L0?ooo`00o`3ooon60?ooo`030000003oool0oooo0200oooo0`00
000Y0?ooo`<00000403oool6000000d0oooo00<000000?ooo`000000F`3oool00?l0ooooQP3oool3
000001d0oooo0`00000A0?ooo`030000003oool0oooo01T0oooo1P00001m0?ooo`00o`3ooonS0?oo
o`<000004P3oool010000000oooo0?ooo`00000J0?ooo`800000103oool4000007T0oooo003n0?oo
o`80000000<0oooo000000000000W03oool3000000030?ooo`000000oooo01<0oooo0P0000000`3o
ool000000?ooo`0H0?ooo`800000203oool3000007H0oooo003o0?ooo`030000003oool0000009X0
oooo0`0000040?ooo`030000003oool0oooo01@0oooo0`0000000`3oool000000000000:000000/0
oooo0P0000210?ooo`00o`3oool10?ooo`030000003oool0oooo09H0oooo0`00000P0?ooo`800000
00<0oooo0000000000000P0000040?ooo`@000002`3oool200000800oooo003n0?ooo`80000000<0
oooo000000000000T`3oool300000240oooo1P00000:0?ooo`8000002P3oool200000800oooo003o
0?oooi@0oooo0`00000S0?ooo`030000003oool0000000@0oooo0P00000:0?ooo`030000003oool0
oooo00H0oooo0P0000210?ooo`00o`3ooonA0?ooo`<000009P3oool2000000L0oooo0P0000090?oo
o`030000003oool0oooo00<0oooo0P0000230?ooo`00o`3ooon=0?ooo`@00000:@3oool00`000000
oooo0?ooo`080?ooo`<00000103oool2000000030?ooo`000000oooo08P0oooo003o0?ooohX0oooo
0`00000^0?ooo`030000003oool0oooo00X0oooo100000000`3oool000000000002:0?ooo`00o`3o
oon70?ooo`<00000<P3oool00`000000oooo0?ooo`0;0?ooo`<00000S03oool00?l0ooooQ03oool3
000000030?ooo`000000oooo01d0oooo2`00000;0?ooo`800000VP3oool00?l0ooooP@3oool30000
00@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00X0oooo0`00002G0?ooo`00o`3ooomn0?ooo`<000001`3oool00`000000oooo0?ooo`0J0?ooo`80
0000303oool200000:@0oooo003o0?ooog/0oooo0`00000:0?ooo`030000003oool0oooo01X0oooo
00@000000?ooo`0000000000303oool00`000000oooo0?ooo`2Q0?ooo`00o`3ooomh0?ooo`<00000
:`3oool010000000oooo0?ooo`00000<0?ooo`030000003oool0oooo0:00oooo003o0?ooogD0oooo
0`00000_0?ooo`80000000<0oooo0000003oool02@3oool00`000000oooo0000002Q0?ooo`00o`3o
oomb0?ooo`<00000=03oool3000000T0oooo0P00002R0?ooo`00o`3ooom^0?ooo`@00000803oool2
000001H0oooo00@000000?ooo`0000000000Z`3oool00?l0ooooJ`3oool3000002D0oooo0P00000?
0?ooo`8000001@3oool200000:`0oooo003o0?ooofP0oooo0`0000000`3oool000000?ooo`0V0?oo
o`800000403oool200000080oooo0`00002/0?ooo`00o`3ooomU0?ooo`<00000103oool00`000000
oooo0?ooo`0W0?ooo`800000403oool300000:h0oooo003o0?ooof80oooo0`00000b0?ooo`800000
203oool200000;H0oooo003o0?oooel0oooo0`00000f0?ooo`8000000`3oool4000000030?ooo`00
000000000;D0oooo003o0?oooe`0oooo0`00000k0?ooo`<0000000<0oooo0000000000000P00002g
0?ooo`00o`3ooomI0?ooo`<000007`3oool900000180oooo10000000103oool0000000000000002k
0?ooo`00o`3ooomF0?ooo`<000001@3oool2000001T0oooo0P0000040?ooo`@0000000<0oooo0000
000000002`3oool5000000030?ooo`000000000000800000_P3oool00?l0ooooD`3oool3000000H0
oooo0P0000020?ooo`8000005P3oool2000000T0oooo0P0000000`3oool000000?ooo`0;0?ooo`@0
0000`P3oool00?l0ooooC`3oool4000000l0oooo00<000000?ooo`3oool04P3oool2000000`0oooo
00<000000?ooo`000000d@3oool00?l0ooooC03oool300000080oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`0A0?ooo`800000303oool00`000000oooo000000040?ooo`800000b`3o
ool00?l0ooooB@3oool3000000D0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0000000`0oooo0P000000103oool0000000000000003=0?ooo`00o`3ooom6
0?ooo`<000006P3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000000X0oooo1000
003@0?ooo`00o`3ooom30?ooo`<00000703oool00`000000oooo0?ooo`0C0?ooo`80000000<0oooo
0000000000001P3oool300000=<0oooo003o0?oood00oooo0`00000N0?ooo`030000003oool0oooo
01H0oooo2@00003F0?ooo`00o`3ooolm0?ooo`<00000803oool00`000000oooo0?ooo`3f0?ooo`00
o`3ooolj0?ooo`<000008P3oool00`000000oooo0?ooo`3g0?ooo`00o`3ooolg0?ooo`<00000903o
ool00`000000oooo0?ooo`3h0?ooo`00o`3ooold0?ooo`<000009`3oool00`000000oooo0?ooo`3h
0?ooo`00o`3oool2000002h0oooo100000020?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3T0?ooo`00oP3oool010000000oooo0?ooo`00000Z0?oo
o`<000001P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0i03oool00?h0oooo00@000000?ooo`3oool000009`3oool300000300oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`3T0?ooo`00oP3oool010000000oooo0?ooo`00000T0?oo
o`<000004P3oool2000000`0oooo2@00000;0?ooo`030000003oool0oooo00l0oooo0P00003W0?oo
o`00oP3oool010000000oooo0?ooo`00000Q0?ooo`<000005P3oool3000000P0oooo0P0000030?oo
o`@000000P3oool2000000X0oooo0P00000;0?ooo`@00000j@3oool00?l0oooo0P00000O0?ooo`<0
00006`3oool3000000@0oooo0P0000090?ooo`80000000<0oooo0000003oool02`3oool2000000@0
oooo1@00003]0?ooo`00o`3ooolN0?ooo`<00000803oool300000080oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0000000=0?ooo`@00000lP3oool00?l0oooo6`3oool3000002D0oooo1000
000=0?ooo`800000o`3oool40?ooo`00o`3ooolH0?ooo`@00000:@3oool3000000`0oooo0P00003o
0?ooo`@0oooo003o0?oooaD0oooo0`0000030?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool03P3oool4000000P0oooo0P00003o0?ooo`D0oooo003o0?oooa80oooo0`00000P0?ooo`03
0000003oool000000100oooo0P000000103oool000000000000000040?ooo`800000o`3oool60?oo
o`00o`3oool>0?ooo`@00000903oool00`000000oooo0000000A0?ooo`P00000o`3oool80?ooo`00
o`3oool;0?ooo`<000007`3oool00`000000oooo0?ooo`070?ooo`030000003oool000000?l0oooo
803oool00?l0oooo203oool300000240oooo00@000000?ooo`0000000000203oool200000?l0oooo
803oool00?l0oooo1@3oool3000002D0oooo0P0000000`3oool000000?ooo`080?ooo`030000003o
ool0oooo00@0oooo0P00003o0?oooaL0oooo003o0?ooo`80oooo0`00000Z0?ooo`@00000203oool0
10000000oooo0?ooo`3oool2000000030?ooo`00000000000?l0oooo5P3oool00?h0oooo0`00000_
0?ooo`<00000203oool600000?l0oooo603oool00?/0oooo0`0000020?ooo`030000003oool0oooo
01P0oooo1P00000A0?ooo`<000000`3oool600000?l0oooo6`3oool00?P0oooo0`0000050?ooo`03
0000003oool0oooo01H0oooo0P0000040?ooo`D00000403oool700000?l0oooo7P3oool00?D0oooo
0`0000080?ooo`030000003oool0oooo00D0oooo1000000<0?ooo`8000002@3oool3000000d0oooo
1000003o0?ooob80oooo003b0?ooo`<000004@3oool2000000@0oooo00<000000?ooo`3oool0203o
ool2000000`0oooo0P0000060?ooo`L00000o`3ooolU0?ooo`00kP3oool4000001T0oooo00<00000
0?ooo`3oool02@3oool2000000`0oooo00<000000?ooo`000000o`3ooola0?ooo`00j`3oool30000
01d0oooo00<000000?ooo`3oool02@3oool00`000000oooo0000000<0?ooo`800000o`3ooola0?oo
o`00j03oool3000001h0oooo0P00000=0?ooo`030000003oool0000000/0oooo0P00003o0?oooc40
oooo003U0?ooo`<00000803oool2000000l0oooo100000080?ooo`800000o`3ooolb0?ooo`00hP3o
ool3000000030?ooo`000000oooo01l0oooo00<000000?ooo`0000004@3oool5000000@0oooo0P00
003o0?oooc<0oooo003O0?ooo`<00000103oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
000000L0oooo0P0000090?ooo`L00000o`3ooole0?ooo`00g03oool3000002X0oooo2@00003o0?oo
odL0oooo003I0?ooo`<00000<P3oool00`000000oooo0?ooo`3o0?ooodP0oooo003F0?ooo`<00000
=03oool200000?l0ooooBP3oool00=<0oooo0`00000O0?ooo`D000004`3oool010000000oooo0000
000000060?ooo`800000o`3ooom00?ooo`00c`3oool4000001h0oooo100000050?ooo`H000003P3o
ool900000?l0oooo@P3oool00<`0oooo0`00000S0?ooo`800000303oool4000000l0oooo00<00000
0?ooo`3oool0o`3ooom30?ooo`00b@3oool4000002H0oooo0`00000>0?ooo`800000303oool00`00
0000oooo0?ooo`3o0?oood@0oooo00360?ooo`<000000`3oool00`000000oooo0?ooo`0H0?ooo`L0
00001P3oool00`000000oooo0000000=0?ooo`030000003oool0000000`0oooo0`00003o0?oood<0
oooo00330?ooo`<000001P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`0000001@3oool2000000D0oooo0`00000=0?ooo`030000003oool0oooo0?l0oooo
D@3oool00<00oooo0`00000C0?ooo`040000003oool00000000000H0oooo1`0000020?ooo`030000
003oool0oooo00/0oooo0`00003o0?oooel0oooo002m0?ooo`<000005`3oool2000000030?ooo`00
000000000080oooo0P0000060?ooo`8000000P3oool2000000`0oooo00<000000?ooo`000000o`3o
oomN0?ooo`00^P3oool3000001`0oooo0P000000103oool000000000000000090?ooo`8000000P3o
ool00`000000oooo0?ooo`0:0?ooo`<00000o`3ooomM0?ooo`00]`3oool3000001d0oooo00@00000
0?ooo`3oool0oooo0P0000000`3oool000000?ooo`0:0?ooo`030000003oool0oooo00800000203o
ool300000?l0ooooG`3oool00;@0oooo0`00000O0?ooo`8000001@3oool010000000oooo00000000
000:0?ooo`8000000P3oool200000?l0ooooJ03oool00;00oooo1000000R0?ooo`8000001P3oool2
000000030?ooo`000000000000X0oooo0P0000020?ooo`030000003oool0oooo0?l0ooooI@3oool0
08<0oooo0P00000X0?ooo`<000000P3oool00`000000oooo0?ooo`0Q0?ooo`800000203oool20000
00030?ooo`000000000000X0oooo00<000000?ooo`3oool0o`3ooomW0?ooo`00PP3oool010000000
oooo0?ooo`00000T0?ooo`<000001@3oool00`000000oooo0?ooo`0Q0?ooo`8000002P3oool20000
00030?ooo`00000000000?l0ooooLP3oool008D0oooo00<000000?ooo`3oool07`3oool3000001l0
oooo100000090?ooo`800000303oool2000000030?ooo`000000oooo0?l0ooooL03oool007`0oooo
100000030?ooo`8000007`3oool3000002@0oooo1@0000060?ooo`8000003P3oool00`000000oooo
0?ooo`3o0?ooog00oooo00230?ooo`030000003oool0oooo01/0oooo0`00000[0?ooo`@000000`3o
ool200000?l0ooooP@3oool008<0oooo0`00000H0?ooo`<00000803oool5000000`0oooo1P00003o
0?oooh40oooo002K0?ooo`<000008@3oool2000000D0oooo0P00000>0?ooo`800000o`3ooon10?oo
o`00V03oool3000002@0oooo0P00000E0?ooo`800000o`3ooon10?ooo`00U@3oool3000000030?oo
o`000000oooo01/0oooo0P0000070?ooo`8000005@3oool200000?l0ooooP@3oool00940oooo1000
00040?ooo`030000003oool0oooo01/0oooo0`0000050?ooo`030000003oool0000001@0oooo0P00
003o0?oooh40oooo002>0?ooo`<000007@3oool5000000H0oooo0`0000030?ooo`030000003oool0
000000P0oooo0P00000:0?ooo`800000o`3ooon10?ooo`00R`3oool3000001h0oooo0P0000050?oo
o`8000001P3oool3000000040?ooo`00000000000?ooo`@000000`3oool3000000X0oooo0P00003o
0?oooh40oooo00280?ooo`<00000803oool00`000000oooo000000070?ooo`030000003oool0oooo
00D0oooo1@0000040?ooo`@000002P3oool300000?l0ooooPP3oool008D0oooo0`00000S0?ooo`80
000000<0oooo0000003oool03`3oool300000100oooo0P00003o0?ooohD0oooo00220?ooo`<00000
:03oool400000100oooo0`00003o0?oooiD0oooo001o0?ooo`<00000;@3oool300000?l0ooooY`3o
ool007`0oooo0`0000000`3oool000000?ooo`0_0?ooo`<00000o`3ooonU0?ooo`00N@3oool30000
00@0oooo00<000000?ooo`3oool05`3oool900000100oooo0`00003o0?oooj<0oooo001f0?ooo`<0
00001`3oool00`000000oooo0?ooo`0F0?ooo`8000001P3oool4000000<0oooo00<000000?ooo`3o
ool02P3oool200000?l0ooooXP3oool00780oooo1000000:0?ooo`030000003oool0oooo01H0oooo
0P0000080?ooo`030000003oool0000000800000o`3ooona0?ooo`00K`3oool300000140oooo00<0
00000?ooo`000000503oool2000000P0oooo1@00003o0?oook00oooo001/0?ooo`<000005@3oool4
000001<0oooo0P0000080?ooo`<0000000<0oooo0000003oool0o`3ooon^0?ooo`00J@3oool30000
01X0oooo1000000A0?ooo`030000003oool0000000H0oooo00@000000?ooo`3oool0oooo0P00003o
0?ooojl0oooo001V0?ooo`<000007`3oool400000100oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`030?ooo`800000o`3ooon^0?ooo`00H`3oool3000000030?ooo`000000oooo0240
oooo100000080?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool00`3oool200000?l0
oooo[P3oool00600oooo0`0000040?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
2@3oool4000000P0oooo1`0000050?ooo`030000003oool0oooo00<0oooo0P00003o0?ooojd0oooo
001M0?ooo`<00000403oool2000000d0oooo00@000000?ooo`00000000002`3oool4000001<0oooo
00@000000?ooo`3oool0oooo0P00003o0?ooojh0oooo001J0?ooo`<000004@3oool200000080oooo
0P00000<0?ooo`80000000<0oooo0000003oool02`3oool00`000000oooo0000000C0?ooo`<00000
o`3ooon`0?ooo`00E`3oool3000001<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0;0?ooo`040000003oool00000000000/0oooo00<000000?ooo`000000o`3oooo50?ooo`00E03o
ool3000001d0oooo00<000000?ooo`3oool0303oool2000000030?ooo`000000000000T0oooo0P00
003o0?ooolH0oooo001@0?ooo`@000007`3oool200000100oooo0P0000000`3oool0000000000006
0?ooo`800000o`3oooo70?ooo`00C@3oool300000280oooo0P00000C0?ooo`T00000o`3oooo90?oo
o`00BP3oool300000080oooo00<000000?ooo`3oool07`3oool00`000000oooo0000000=0?ooo`80
0000103oool300000?l0ooooc`3oool004L0oooo0`0000050?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`0000003`3oool500000?l0ooood@3oool004@0oooo0`00000N0?ooo`H000001`3o
ool200000?l0ooooi@3oool00440oooo0`00000N0?ooo`<000003@3oool010000000oooo00000000
003o0?ooon<0oooo000n0?ooo`<00000803oool200000100oooo0P0000000`3oool0000000000008
0?ooo`<00000o`3ooooF0?ooo`00>`3oool300000280oooo00<000000?ooo`0000004P3oool;0000
0?l0oooof@3oool003P0oooo0`00000V0?ooo`T000004P3oool00`000000oooo0?ooo`3o0?ooomX0
oooo00070?ooo`D000000P3oool2000002D0oooo0`00000[0?ooo`@0000000<0oooo000000000000
1`3oool00`000000oooo0?ooo`080?ooo`800000o`3ooooK0?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool07P3oool400000080oooo00<000000?ooo`3oool0
6@3oool8000000`0oooo0P0000060?ooo`8000003@3oool200000?l0oooof@3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01/0oooo0`0000060?ooo`030000
003oool0oooo01L0oooo0P0000060?ooo`@000002P3oool3000000<0oooo0P00003o0?ooonX0oooo
00000`3oool0000000000002000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01P0oooo0`00000Q0?ooo`8000002P3oool00`000000oooo0000000:0?ooo`D00000
o`3oooo/0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
5@3oool300000140oooo0`00000@0?ooo`8000002`3oool00`000000oooo0000003o0?ooooX0oooo
00080?ooo`800000103oool2000001D0oooo0`00000F0?ooo`<000003P3oool00`000000oooo0000
000;0?ooo`800000o`3ooooj0?ooo`008P3oool3000001`0oooo0`00000<0?ooo`030000003oool0
000000T0oooo00<000000?ooo`000000o`3ooooj0?ooo`007`3oool300000240oooo0`00000;0?oo
o`@000001`3oool200000?l0oooon`3oool001`0oooo1000000T0?ooo`040000003oool000000000
00/0oooo2@0000000`3oool000000?ooo`030?ooo`030000003oool0oooo0?l0oooom03oool001T0
oooo0`0000030?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool00P00000B0?ooo`03
0000003oool0oooo0080oooo0P00003o0?ooooH0oooo000F0?ooo`<000001P3oool00`000000oooo
0?ooo`0T0?ooo`040000003oool0oooo0?ooo`800000403oool010000000oooo0?ooo`3oool30000
0?l0oooomP3oool00180oooo1000000`0?ooo`800000103oool2000000h0oooo100000000`3oool0
00000000003o0?ooooH0oooo000?0?ooo`<00000403oool2000002<0oooo00<000000?ooo`3oool0
103oool2000000h0oooo0`00003o0?ooooP0oooo000<0?ooo`<00000503oool3000000L0oooo2000
000A0?ooo`030000003oool000000?l0ooooo`3ooolA0?ooo`002@3oool3000001T0oooo0`000004
0?ooo`030000003oool0oooo00D0oooo0`00000=0?ooo`80000000<0oooo0000003oool0o`3ooooo
0?oooa40oooo00060?ooo`<000007@3oool4000000030?ooo`000000oooo00P0oooo0P0000080?oo
o`P00000o`3ooooo0?oooa<0oooo00040?ooo`80000000<0oooo0000003oool06`3oool200000080
oooo1@0000080?ooo`800000o`3ooooo0?ooob<0oooo00070?ooo`030000003oool0oooo01T0oooo
0P0000050?ooo`040000003oool00000000000L0oooo00<000000?ooo`3oool0o`3ooooo0?ooob80
oooo00070?ooo`030000003oool0oooo01P0oooo00<000000?ooo`0000001P3oool2000000030?oo
o`000000000000@0oooo1`00003o0?ooool0oooo7`3oool000L0oooo00<000000?ooo`3oool0403o
ool700000080oooo00<000000?ooo`0000001`3oool2000000030?ooo`000000000000P0oooo0`00
003o0?ooool0oooo7@3oool001T0oooo00<000000?ooo`3oool01@3oool5000000T0oooo0P000000
0`3oool00000000000080?ooo`<00000o`3ooooo0?oooa/0oooo000H0?ooo`8000002P3oool00`00
0000oooo00000002000000P0oooo1@0000070?ooo`030000003oool0oooo0?l0ooooo`3ooolJ0?oo
o`00603oool00`000000oooo0000000:0?ooo`8000000P3oool2000000T0oooo100000040?ooo`03
0000003oool0oooo0?l0ooooo`3ooolK0?ooo`00603oool00`000000oooo0000000:0?ooo`030000
003oool0000000<0oooo0P00000;0?ooo`@00000o`3ooooo0?oooah0oooo000I0?ooo`@000002@3o
ool00`000000oooo0?ooo`3o0?ooool0oooo<@3oool001/0oooo1P0000040?ooo`030000003oool0
oooo0?l0ooooo`3ooolb0?ooo`007@3oool800000?l0ooooo`3ooole0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {210.875, 0}} -> {0.0413913, 0.29514, \
0.00172616, 0.00172616}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay[FromCharacterCode[Range[913, 937]]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34453 
%%ImageSize: 600 206.717 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0521186 1.05212 -0.343311 1.05212 [
[.14863 .25506 -8.43515 -9 ]
[.14863 .25506 9.56485 0 ]
[.46395 .1531 -2.9941 -9 ]
[.46395 .1531 3.0059 0 ]
[.80438 .04307 -6.39882 -9 ]
[.80438 .04307 5.60118 0 ]
[.4623 .08793 -4.9884 -12.75 ]
[.4623 .08793 5.0116 0 ]
[.99327 -0.00224 0 -5.94996 ]
[.99327 -0.00224 24 3.05004 ]
[1.00077 .0087 0 -5.94335 ]
[1.00077 .0087 6 3.05665 ]
[1.00822 .01957 0 -5.9368 ]
[1.00822 .01957 18 3.0632 ]
[1.06463 -0.00957 0 -8.41822 ]
[1.06463 -0.00957 10 4.33178 ]
[ 0 0 0 0 ]
[ 1 .34453 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00053 .31568 m
.97952 0 L
s
.14781 .26819 m
.1474 .27475 L
s
[(-10)] .14863 .25506 -0.06276 1 Mshowa
.46393 .16626 m
.46391 .17283 L
s
[(0)] .46395 .1531 -0.00197 1 Mshowa
.80525 .05619 m
.80569 .06275 L
s
[(10)] .80438 .04307 .06647 1 Mshowa
.125 Mabswid
.20915 .24841 m
.20895 .25235 L
s
.27141 .22833 m
.27126 .23227 L
s
.33461 .20795 m
.33451 .2119 L
s
.39878 .18726 m
.39872 .19121 L
s
.53008 .14492 m
.53012 .14887 L
s
.59727 .12326 m
.59736 .1272 L
s
.66551 .10125 m
.66566 .1052 L
s
.73483 .0789 m
.73503 .08284 L
s
.08737 .28768 m
.08707 .29161 L
s
.0278 .30689 m
.02747 .31082 L
s
.87681 .03312 m
.87713 .03705 L
s
.94952 .00967 m
.9499 .0136 L
s
gsave
.4623 .08793 -65.9884 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97952 0 m
.99935 .02889 L
s
.98075 .00179 m
.97449 .00381 L
s
[(-0.5)] .99327 -0.00224 -1 .32221 Mshowa
.98825 .01272 m
.98199 .01473 L
s
[(0)] 1.00077 .0087 -1 .32075 Mshowa
.9957 .02357 m
.98943 .02557 L
s
[(0.5)] 1.00822 .01957 -1 .31929 Mshowa
.125 Mabswid
.98225 .00398 m
.9785 .00519 L
s
.98376 .00617 m
.98 .00738 L
s
.98526 .00836 m
.9815 .00957 L
s
.98675 .01054 m
.983 .01175 L
s
.98974 .0149 m
.98599 .0161 L
s
.99124 .01707 m
.98748 .01827 L
s
.99272 .01924 m
.98897 .02044 L
s
.99421 .0214 m
.99045 .0226 L
s
.99718 .02573 m
.99342 .02692 L
s
.99866 .02788 m
.9949 .02908 L
s
gsave
1.06463 -0.00957 -61 -12.4182 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34453 L
0 .34453 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.06023 .32887 m
.04891 .30502 L
s
.06023 .32887 m
.0261 .31236 L
s
.05701 .32601 m
.04728 .30555 L
s
.07974 .32266 m
.09934 .31642 L
s
.08463 .3211 m
.06201 .30081 L
s
.08626 .32059 m
.06365 .30028 L
s
.0359 .3171 m
.05054 .3124 L
s
.09934 .31642 m
.10155 .31441 L
s
.09934 .31642 m
.10319 .31389 L
s
.10155 .31441 m
.10212 .31293 L
s
.10319 .31389 m
.10376 .3124 L
s
.02285 .31341 m
.0326 .31027 L
s
.10212 .31293 m
.10163 .31047 L
s
.10376 .3124 m
.10327 .30995 L
s
.11574 .3112 m
.14047 .30332 L
s
.07554 .31095 m
.08864 .30676 L
s
.10163 .31047 m
.0995 .30854 L
s
.10327 .30995 m
.10114 .30801 L
s
.12068 .30962 m
.09824 .28915 L
s
.12232 .3091 m
.09989 .28861 L
s
.0995 .30854 m
.09571 .30712 L
s
.10114 .30801 m
.09736 .3066 L
s
.09571 .30712 m
.093 .30668 L
s
.04238 .30712 m
.05218 .30397 L
s
.08864 .30676 m
.09086 .30474 L
s
.08864 .30676 m
.0925 .30421 L
s
.093 .30668 m
.08864 .30676 L
s
.09464 .30615 m
.08864 .30676 L
s
.09736 .3066 m
.09464 .30615 L
s
.09086 .30474 m
.09142 .30324 L
s
.0925 .30421 m
.09307 .30271 L
s
.13413 .29747 m
.13882 .30385 L
s
.14047 .30332 m
.13413 .29747 L
s
.09142 .30324 m
.09092 .30077 L
s
.09307 .30271 m
.09257 .30024 L
s
.07679 .29605 m
.05709 .30239 L
s
.09092 .30077 m
.08769 .29784 L
s
.09257 .30024 m
.08934 .29731 L
s
.08769 .29784 m
.08389 .29642 L
s
.1587 .29751 m
.14983 .27254 L
s
.1587 .29751 m
.12312 .28114 L
s
.08934 .29731 m
.08554 .29589 L
s
.08389 .29642 m
.08116 .29597 L
s
.08116 .29597 m
.07679 .29605 L
s
.08281 .29544 m
.07679 .29605 L
s
.08554 .29589 m
.08281 .29544 L
s
.15555 .29458 m
.14816 .27308 L
s
.17701 .29168 m
.20379 .28315 L
s
.09328 .29074 m
.10486 .28702 L
s
.18202 .29009 m
.1599 .2693 L
s
.18369 .28956 m
.16158 .26876 L
s
.19754 .27722 m
.20212 .28369 L
s
.20379 .28315 m
.19754 .27722 L
s
.12586 .28159 m
.14922 .27407 L
s
.12312 .28114 m
.14983 .27254 L
s
.18746 .28044 m
.17906 .2725 L
s
.1732 .27969 m
.18327 .27647 L
s
.21556 .27941 m
.23921 .27188 L
s
.20933 .27345 m
.21556 .27941 L
s
.21725 .27887 m
.20933 .27345 L
s
.23751 .27242 m
.19361 .25845 L
s
.23921 .27188 m
.19531 .2579 L
s
.15486 .27092 m
.18178 .26226 L
s
.24768 .26918 m
.25958 .26539 L
s
.18811 .26826 m
.18009 .2628 L
s
.18178 .26226 m
.18811 .26826 L
s
.25278 .26755 m
.23102 .24641 L
s
.25448 .26701 m
.23273 .24586 L
s
.2698 .26213 m
.28176 .25832 L
s
.27492 .2605 m
.25329 .23924 L
s
.27663 .25996 m
.255 .23869 L
s
.19361 .25845 m
.21738 .2508 L
s
.24416 .25698 m
.26466 .25042 L
s
.22365 .25686 m
.21568 .25135 L
s
.21738 .2508 m
.22365 .25686 L
s
.29617 .2524 m
.2907 .25147 L
s
.30234 .25177 m
.29617 .2524 L
s
.29789 .25185 m
.29242 .25093 L
s
.30234 .25177 m
.29789 .25185 L
s
.30578 .25067 m
.30234 .25177 L
s
.2907 .25147 m
.28694 .25 L
s
.29242 .25093 m
.28866 .24945 L
s
.30821 .24856 m
.30578 .25067 L
s
.30993 .24802 m
.30578 .25067 L
s
.28694 .25 m
.28113 .24649 L
s
.28866 .24945 m
.28285 .24594 L
s
.30963 .24544 m
.30821 .24856 L
s
.2259 .24806 m
.23786 .24421 L
s
.31135 .24489 m
.30993 .24802 L
s
.28113 .24649 m
.27805 .24345 L
s
.28285 .24594 m
.27977 .24289 L
s
.29177 .24577 m
.2846 .23865 L
s
.30932 .24285 m
.30963 .24544 L
s
.31105 .2423 m
.31135 .24489 L
s
.32648 .24408 m
.3386 .24022 L
s
.27805 .24345 m
.27565 .23882 L
s
.27977 .24289 m
.27738 .23827 L
s
.30698 .23822 m
.30932 .24285 L
s
.2887 .24273 m
.29905 .23941 L
s
.30211 .24247 m
.29496 .23533 L
s
.33167 .24243 m
.31034 .22088 L
s
.30871 .23767 m
.31105 .2423 L
s
.3334 .24188 m
.31208 .22032 L
s
.28768 .24171 m
.29803 .23839 L
s
.24814 .2409 m
.26016 .23703 L
s
.27565 .23882 m
.27532 .23622 L
s
.34381 .23856 m
.35598 .23469 L
s
.27738 .23827 m
.27704 .23567 L
s
.30392 .23516 m
.30698 .23822 L
s
.30565 .2346 m
.30871 .23767 L
s
.34902 .2369 m
.32779 .21527 L
s
.35076 .23635 m
.32953 .2147 L
s
.27532 .23622 m
.2767 .23306 L
s
.27704 .23567 m
.27843 .23251 L
s
.2981 .23161 m
.30392 .23516 L
s
.29983 .23106 m
.30565 .2346 L
s
.2767 .23306 m
.28085 .23037 L
s
.27843 .23251 m
.28085 .23037 L
s
.29432 .23011 m
.2981 .23161 L
s
.36644 .23136 m
.37693 .22802 L
s
.29605 .22956 m
.29983 .23106 L
s
.28085 .23037 m
.28431 .22926 L
s
.2888 .22917 m
.29432 .23011 L
s
.29053 .22862 m
.29605 .22956 L
s
.28431 .22926 m
.2888 .22917 L
s
.28431 .22926 m
.29053 .22862 L
s
.37343 .22913 m
.33766 .22299 L
s
.34868 .22488 m
.35057 .20793 L
s
.35043 .22432 m
.35233 .20737 L
s
.30512 .22256 m
.31731 .21864 L
s
.39798 .22131 m
.38941 .19543 L
s
.39798 .22131 m
.36465 .2034 L
s
.395 .21821 m
.38764 .196 L
s
.32254 .21695 m
.33478 .21301 L
s
.41913 .21457 m
.42621 .21232 L
s
.42444 .21288 m
.4161 .18684 L
s
.42444 .21288 m
.40363 .19086 L
s
.42621 .21232 m
.41908 .19002 L
s
.3453 .20963 m
.35585 .20623 L
s
.44928 .20497 m
.45641 .2027 L
s
.44928 .20497 m
.42861 .18281 L
s
.44928 .20497 m
.4161 .18684 L
s
.36113 .20453 m
.37171 .20113 L
s
.45106 .2044 m
.4304 .18224 L
s
.46355 .20043 m
.4707 .19815 L
s
.46891 .19872 m
.44835 .17646 L
s
.4707 .19815 m
.47375 .17106 L
s
.38232 .19771 m
.39296 .19429 L
s
.46875 .19605 m
.47179 .16892 L
s
.48683 .19301 m
.49761 .18958 L
s
.39829 .19257 m
.40897 .18914 L
s
.49222 .1913 m
.47179 .16892 L
s
.50939 .1872 m
.50278 .18246 L
s
.50747 .18507 m
.53281 .177 L
s
.42325 .18454 m
.43578 .18051 L
s
.50651 .18401 m
.53186 .17593 L
s
.53654 .17855 m
.52995 .17379 L
s
.44296 .1782 m
.45375 .17472 L
s
.50796 .1753 m
.50132 .17053 L
s
.50603 .17316 m
.51692 .16968 L
s
.50507 .17209 m
.51596 .1686 L
s
.52066 .17124 m
.51403 .16645 L
s
.55283 .17062 m
.54729 .16963 L
s
.55926 .16995 m
.55283 .17062 L
s
.55466 .17004 m
.54911 .16905 L
s
.55926 .16995 m
.55466 .17004 L
s
.56291 .16878 m
.55926 .16995 L
s
.54729 .16963 m
.54356 .16807 L
s
.54911 .16905 m
.54538 .16748 L
s
.56562 .16654 m
.56291 .16878 L
s
.56745 .16596 m
.56291 .16878 L
s
.54356 .16807 m
.53792 .16434 L
s
.492 .16798 m
.48531 .16318 L
s
.54538 .16748 m
.53974 .16376 L
s
.5674 .16322 m
.56562 .16654 L
s
.56923 .16264 m
.56745 .16596 L
s
.49005 .16582 m
.51552 .15763 L
s
.48907 .16475 m
.51455 .15655 L
s
.53792 .16434 m
.53504 .16111 L
s
.53974 .16376 m
.53687 .16052 L
s
.56734 .16048 m
.5674 .16322 L
s
.56917 .15989 m
.56923 .16264 L
s
.5849 .16178 m
.62179 .15003 L
s
.53504 .16111 m
.53303 .15619 L
s
.53687 .16052 m
.53486 .1556 L
s
.56538 .15556 m
.56734 .16048 L
s
.59041 .16002 m
.57056 .13713 L
s
.56722 .15497 m
.56917 .15989 L
s
.59225 .15944 m
.57241 .13653 L
s
.51928 .15921 m
.51262 .15438 L
s
.53303 .15619 m
.53294 .15343 L
s
.53486 .1556 m
.53477 .15284 L
s
.56253 .1523 m
.56538 .15556 L
s
.56437 .15171 m
.56722 .15497 L
s
.53294 .15343 m
.53468 .15008 L
s
.53477 .15284 m
.53652 .14949 L
s
.61439 .15239 m
.59468 .12937 L
s
.55688 .14853 m
.56253 .1523 L
s
.61624 .1518 m
.59654 .12877 L
s
.55872 .14794 m
.56437 .15171 L
s
.53468 .15008 m
.53922 .14721 L
s
.53652 .14949 m
.53922 .14721 L
s
.55313 .14694 m
.55688 .14853 L
s
.55497 .14635 m
.55872 .14794 L
s
.62921 .14767 m
.65153 .14056 L
s
.53922 .14721 m
.5429 .14603 L
s
.54754 .14594 m
.55313 .14694 L
s
.54938 .14535 m
.55497 .14635 L
s
.5429 .14603 m
.54754 .14594 L
s
.5429 .14603 m
.54938 .14535 L
s
.63478 .1459 m
.6152 .12276 L
s
.63664 .1453 m
.61707 .12216 L
s
.65153 .14056 m
.65435 .13827 L
s
.65153 .14056 m
.65621 .13768 L
s
.56502 .13891 m
.57797 .13474 L
s
.65435 .13827 m
.65529 .13658 L
s
.65621 .13768 m
.65716 .13598 L
s
.65529 .13658 m
.65532 .13378 L
s
.65716 .13598 m
.65719 .13318 L
s
.66648 .1358 m
.64709 .1125 L
s
.66835 .1352 m
.67022 .13461 L
s
.64898 .11189 m
.66835 .1352 L
s
.67022 .13461 m
.65086 .11129 L
s
.6721 .13401 m
.67397 .13341 L
s
.65274 .11068 m
.6721 .13401 L
s
.65532 .13378 m
.65256 .13047 L
s
.67397 .13341 m
.65463 .11007 L
s
.64137 .12844 m
.62643 .13323 L
s
.65719 .13318 m
.65443 .12987 L
s
.67585 .13282 m
.67772 .13222 L
s
.65652 .10946 m
.67585 .13282 L
s
.67772 .13222 m
.6584 .10886 L
s
.6796 .13162 m
.68148 .13102 L
s
.66029 .10825 m
.6796 .13162 L
s
.58911 .13116 m
.60213 .12697 L
s
.68148 .13102 m
.66218 .10764 L
s
.65256 .13047 m
.64884 .12886 L
s
.68336 .13042 m
.68523 .12983 L
s
.66407 .10703 m
.68336 .13042 L
s
.65443 .12987 m
.65071 .12826 L
s
.68523 .12983 m
.66596 .10642 L
s
.68711 .12923 m
.689 .12863 L
s
.66785 .10582 m
.68711 .12923 L
s
.64884 .12886 m
.64604 .12835 L
s
.689 .12863 m
.66975 .10521 L
s
.64604 .12835 m
.64137 .12844 L
s
.64791 .12775 m
.64137 .12844 L
s
.65071 .12826 m
.64791 .12775 L
s
.69088 .12803 m
.69276 .12743 L
s
.67164 .1046 m
.69088 .12803 L
s
.69276 .12743 m
.67353 .10399 L
s
.69464 .12683 m
.69653 .12623 L
s
.67543 .10338 m
.69464 .12683 L
s
.69653 .12623 m
.67732 .10277 L
s
.7003 .12503 m
.72868 .11599 L
s
.7003 .12503 m
.70446 .10965 L
s
.60959 .12457 m
.62268 .12035 L
s
.70218 .12443 m
.70636 .10904 L
s
.72518 .10867 m
.72678 .11659 L
s
.72868 .11599 m
.72518 .10867 L
s
.64709 .1125 m
.64898 .11189 L
s
.74008 .11236 m
.76872 .10324 L
s
.73471 .10563 m
.74008 .11236 L
s
.74199 .11175 m
.73471 .10563 L
s
.65086 .11129 m
.65274 .11068 L
s
.65463 .11007 m
.65652 .10946 L
s
.70636 .10904 m
.68112 .10155 L
s
.6584 .10886 m
.66029 .10825 L
s
.75342 .10811 m
.73458 .08434 L
s
.66218 .10764 m
.66407 .10703 L
s
.75533 .1075 m
.7365 .08372 L
s
.66596 .10642 m
.66785 .10582 L
s
.66975 .10521 m
.67164 .1046 L
s
.67353 .10399 m
.67543 .10338 L
s
.7634 .09646 m
.76681 .10385 L
s
.76872 .10324 m
.7634 .09646 L
s
.68394 .10206 m
.70868 .0941 L
s
.68112 .10155 m
.70968 .09236 L
s
.78023 .09957 m
.78407 .09835 L
s
.77743 .09905 m
.78023 .09957 L
s
.77374 .09741 m
.77743 .09905 L
s
.71704 .09854 m
.70777 .09297 L
s
.70968 .09236 m
.71704 .09854 L
s
.77935 .09844 m
.78319 .09722 L
s
.77374 .09741 m
.77935 .09844 L
s
.78407 .09835 m
.78511 .0966 L
s
.77197 .09514 m
.77374 .09741 L
s
.78319 .09722 m
.78528 .09373 L
s
.78511 .0966 m
.78528 .09373 L
s
.79755 .09406 m
.79474 .09354 L
s
.80141 .09283 m
.79755 .09406 L
s
.78528 .09373 m
.78367 .08857 L
s
.79474 .09354 m
.79106 .09188 L
s
.79667 .09292 m
.79106 .09188 L
s
.80053 .09169 m
.79667 .09292 L
s
.80246 .09108 m
.80141 .09283 L
s
.79106 .09188 m
.7856 .08795 L
s
.80264 .08819 m
.80053 .09169 L
s
.80264 .08819 m
.80246 .09108 L
s
.78367 .08857 m
.77122 .07255 L
s
.80088 .08591 m
.80264 .08819 L
s
.7856 .08795 m
.77316 .07192 L
s
.72882 .08619 m
.74227 .08187 L
s
.82268 .08605 m
.83627 .08172 L
s
.8285 .0842 m
.81013 .06002 L
s
.83044 .08358 m
.81209 .05939 L
s
.81357 .08044 m
.81075 .07991 L
s
.82027 .07972 m
.81357 .08044 L
s
.81075 .07991 m
.80706 .07824 L
s
.81551 .07982 m
.8127 .07929 L
s
.82027 .07972 m
.81551 .07982 L
s
.82999 .07662 m
.82027 .07972 L
s
.8127 .07929 m
.809 .07762 L
s
.80706 .07824 m
.80442 .0748 L
s
.809 .07762 m
.80637 .07418 L
s
.85186 .07676 m
.86358 .07303 L
s
.83302 .07422 m
.82999 .07662 L
s
.83497 .0736 m
.82999 .07662 L
s
.85576 .07552 m
.8632 .04294 L
s
.85772 .07489 m
.86518 .04231 L
s
.80442 .0748 m
.80461 .07187 L
s
.76542 .07441 m
.77898 .07005 L
s
.8341 .07245 m
.83302 .07422 L
s
.80637 .07418 m
.80655 .07125 L
s
.83605 .07183 m
.83497 .0736 L
s
.83431 .06952 m
.8341 .07245 L
s
.80461 .07187 m
.80567 .0701 L
s
.83627 .0689 m
.83605 .07183 L
s
.80655 .07125 m
.80762 .06947 L
s
.80567 .0701 m
.81063 .06707 L
s
.8317 .06606 m
.83431 .06952 L
s
.80762 .06947 m
.81063 .06707 L
s
.87534 .06928 m
.88713 .06553 L
s
.83366 .06543 m
.83627 .0689 L
s
.81063 .06707 m
.82039 .06394 L
s
.88319 .06678 m
.83757 .05119 L
s
.828 .06437 m
.8317 .06606 L
s
.82996 .06374 m
.83366 .06543 L
s
.82517 .06384 m
.828 .06437 L
s
.82039 .06394 m
.82517 .06384 L
s
.82039 .06394 m
.82713 .06321 L
s
.82713 .06321 m
.82996 .06374 L
s
.80427 .06191 m
.81795 .05751 L
s
.90486 .05988 m
.91871 .05547 L
s
.91079 .05799 m
.89296 .03337 L
s
.91277 .05736 m
.89495 .03273 L
s
.88991 .05605 m
.89103 .05426 L
s
.88991 .05605 m
.89301 .05362 L
s
.88708 .05552 m
.88991 .05605 L
s
.89103 .05426 m
.8896 .04895 L
s
.89301 .05362 m
.89158 .04832 L
s
.83364 .05246 m
.84544 .04866 L
s
.8896 .04895 m
.88987 .04598 L
s
.89158 .04832 m
.89185 .04534 L
s
.88987 .04598 m
.891 .04417 L
s
.94569 .04544 m
.95251 .0447 L
s
.94004 .04436 m
.94569 .04544 L
s
.91877 .04539 m
.92359 .04529 L
s
.91341 .04133 m
.91877 .04539 L
s
.89185 .04534 m
.89298 .04353 L
s
.92359 .04529 m
.92474 .04348 L
s
.92076 .04475 m
.92359 .04529 L
s
.85727 .04485 m
.86914 .04103 L
s
.94769 .0448 m
.95251 .0447 L
s
.94204 .04373 m
.94769 .0448 L
s
.9154 .04069 m
.92076 .04475 L
s
.95251 .0447 m
.9605 .04216 L
s
.93554 .04147 m
.94004 .04436 L
s
.891 .04417 m
.8961 .04108 L
s
.93754 .04084 m
.94204 .04373 L
s
.89298 .04353 m
.8961 .04108 L
s
.9605 .04216 m
.96367 .03971 L
s
.9605 .04216 m
.96568 .03907 L
s
.93219 .03676 m
.93554 .04147 L
s
.90972 .03961 m
.91341 .04133 L
s
.8961 .04108 m
.90206 .03917 L
s
.93419 .03612 m
.93754 .04084 L
s
.91172 .03897 m
.9154 .04069 L
s
.96367 .03971 m
.96603 .03607 L
s
.90689 .03907 m
.90972 .03961 L
s
.90206 .03917 m
.90689 .03907 L
s
.90206 .03917 m
.90888 .03843 L
s
.96568 .03907 m
.96803 .03543 L
s
.90888 .03843 m
.91172 .03897 L
s
.93167 .03258 m
.93219 .03676 L
s
.93283 .03075 m
.93419 .03612 L
s
.96603 .03607 m
.96555 .03189 L
s
.96803 .03543 m
.96756 .03125 L
s
.88699 .03529 m
.90092 .0308 L
s
.9323 .02655 m
.93167 .03258 L
s
.96555 .03189 m
.96224 .02714 L
s
.96756 .03125 m
.96425 .0265 L
s
.9323 .02655 m
.93283 .03075 L
s
.92545 .02729 m
.92492 .02308 L
s
.96224 .02714 m
.9569 .02303 L
s
.93294 .0205 m
.9323 .02655 L
s
.96425 .0265 m
.95975 .02358 L
s
.92576 .02427 m
.93178 .02234 L
s
.95975 .02358 m
.95238 .0201 L
s
.92492 .02308 m
.93294 .0205 L
s
.9569 .02303 m
.95238 .0201 L
s
.95238 .0201 m
.94501 .01661 L
s
.94786 .01716 m
.9539 .01522 L
s
.95307 .01402 m
.95759 .01696 L
s
.94501 .01661 m
.95307 .01402 L
s
0 g
.25 Mabswid
.00053 .31568 m
.97952 0 L
s
.14781 .26819 m
.1474 .27475 L
s
[(-10)] .14863 .25506 -0.06276 1 Mshowa
.46393 .16626 m
.46391 .17283 L
s
[(0)] .46395 .1531 -0.00197 1 Mshowa
.80525 .05619 m
.80569 .06275 L
s
[(10)] .80438 .04307 .06647 1 Mshowa
.125 Mabswid
.20915 .24841 m
.20895 .25235 L
s
.27141 .22833 m
.27126 .23227 L
s
.33461 .20795 m
.33451 .2119 L
s
.39878 .18726 m
.39872 .19121 L
s
.53008 .14492 m
.53012 .14887 L
s
.59727 .12326 m
.59736 .1272 L
s
.66551 .10125 m
.66566 .1052 L
s
.73483 .0789 m
.73503 .08284 L
s
.08737 .28768 m
.08707 .29161 L
s
.0278 .30689 m
.02747 .31082 L
s
.87681 .03312 m
.87713 .03705 L
s
.94952 .00967 m
.9499 .0136 L
s
gsave
.4623 .08793 -65.9884 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 206.688},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3ooom@0?ooo`<0
000000<0oooo000000000000103oool00?l0ooooo`3oool_0?ooo`800000103oool2000000@0oooo
0P00000M0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000L0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0J0?ooo`00o`3ooooo0?ooobP0oooo100000020?ooo`040000003oool0oooo000000T0
oooo0P00000M0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0L0?ooo`00o`3ooooo0?oooah0oooo0P00000?0?ooo`8000002P3oool3000001`0oooo
003o0?ooool0oooo6`3oool3000000030?ooo`000000000000`0oooo0P00000[0?ooo`00o`3ooooo
0?oooaP0oooo0`0000020?ooo`80000000<0oooo0000000000002P3oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?oooaD0oooo0`0000070?ooo`<000002P3oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?oooa80oooo0`00000;0?ooo`<000002@3oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?ooo`h0oooo1000000@0?ooo`800000203oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?ooo`/0oooo0`0000000`3oool000000?ooo`0@0?ooo`<000002@3oool2
000002/0oooo003o0?ooool0oooo203oool3000000@0oooo00<000000?ooo`3oool03`3oool40000
00`0oooo0P0000040?ooo`800000103oool2000001/0oooo003o0?ooool0oooo1@3oool3000000L0
oooo0`00000?0?ooo`80000000<0oooo0000000000002P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001X0oooo003o0?ooool0oooo0P3oool3000000L0oooo0`000000103o
ool0000000000000000@0?ooo`<000002P3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo01P0oooo003o0?ooooh0oooo0`00000;0?ooo`<000000`3oool00`000000oooo0?ooo`0>
0?ooo`<000002@3oool010000000oooo0?ooo`0000090?ooo`8000006`3oool00?l0oooon`3oool3
00000100oooo0P00000F0?ooo`030000003oool0oooo00H0oooo00@000000?ooo`3oool000002@3o
ool00`000000oooo0?ooo`0J0?ooo`00o`3ooooh0?ooo`<00000203oool3000000X0oooo0P00000B
0?ooo`@00000203oool2000000X0oooo0`00000J0?ooo`00o`3ooooe0?ooo`<00000203oool60000
00`0oooo0P00000@0?ooo`@00000<@3oool00?l0oooolP3oool3000000/0oooo0`0000000`3oool0
00000?ooo`0=0?ooo`<000003P3oool200000080oooo00<000000?ooo`3oool0;P3oool00?l0oooo
k`3oool3000000h0oooo00D000000?ooo`3oool0oooo0000000@0?ooo`8000003`3oool300000300
oooo003o0?oookP0oooo1@0000020?ooo`800000:P3oool4000001D0oooo00<000000?ooo`3oool0
3`3oool2000000l0oooo0`00000_0?ooo`00o`3ooonj0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0T0?ooo`<000001`3oool200000100oooo0P00000@0?ooo`030000
003oool000000400oooo003o0?oookX0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0240oooo0`0000080?ooo`8000004P3oool200000140oooo0P0000100?ooo`00o`3o
oonj0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0N0?ooo`<00000
00<0oooo0000003oool01@3oool3000000030?ooo`000000oooo0140oooo0P00000A0?ooo`800000
@03oool00?l0oooo^P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
6`3oool3000000@0oooo00<000000?ooo`3oool00P3oool2000000<0oooo0P00000B0?ooo`800000
4@3oool200000400oooo003o0?oookT0oooo0P0000040?ooo`8000006`3oool3000000L0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo000000030?ooo`800000303oool00`000000oooo0000
000?0?ooo`800000@@3oool00?l0oooof@3oool3000001D0oooo00<000000?ooo`0000001P00000;
0?ooo`8000003`3oool200000440oooo003o0?ooomH0oooo0`0000070?ooo`8000003P3oool40000
00D0oooo0`00000:0?ooo`<00000303oool200000480oooo003o0?ooom<0oooo0`0000070?ooo`<0
00003P3oool200000080oooo00<000000?ooo`0000001P3oool300000080oooo00<000000?ooo`3o
ool0103oool5000000H0oooo0`0000140?ooo`00o`3oooo@0?ooo`<00000203oool2000000030?oo
o`000000000000d0oooo0P0000040?ooo`800000203oool3000000T0oooo2@0000170?ooo`00o`3o
ooo=0?ooo`<000003P3oool2000000d0oooo0P0000050?ooo`800000H`3oool00?l0oooob@3oool4
000000H0oooo0P0000080?ooo`8000003P3oool2000000H0oooo0P00001R0?ooo`00o`3oooo60?oo
o`<000001`3oool3000000X0oooo0P00000>0?ooo`8000001P3oool200000680oooo003o0?oool<0
oooo0`0000080?ooo`@000002`3oool2000000h0oooo00<000000?ooo`0000001P3oool200000640
oooo003o0?oool00oooo0`00000?0?ooo`<00000203oool2000000h0oooo00<000000?ooo`000000
1`3oool200000600oooo003o0?oookd0oooo0`00000E0?ooo`<00000103oool2000000d0oooo1000
00080?ooo`8000000`3oool2000005/0oooo003o0?oookX0oooo0`0000000`3oool000000?ooo`04
0?ooo`8000004P3oool3000000030?ooo`000000000001X0oooo1000001M0?ooo`00o`3ooong0?oo
o`<00000103oool00`000000oooo00000003000001L0oooo1000000F0?ooo`<00000H@3oool00?l0
oooo]03oool3000000H0oooo0`0000020?ooo`800000603oool2000000040?ooo`00000000000000
07L0oooo003o0?oook40oooo0`00000:0?ooo`070000003oool0oooo0?ooo`000000oooo00000004
0?ooo`@000003`3oool2000000@0oooo0`00001d0?ooo`00o`3ooon^0?ooo`<000004P3oool90000
00030?ooo`000000000000`0oooo0P0000080?ooo`<000000`3oool00`000000oooo0?ooo`1[0?oo
o`00o`3ooon[0?ooo`<000004`3oool5000000H0oooo0`00000<0?ooo`8000002`3oool3000006h0
oooo003o0?ooojL0oooo1000000D0?ooo`800000103oool2000000H0oooo00<000000?ooo`000000
2`3oool2000000X0oooo0P00001`0?ooo`00o`3ooonT0?ooo`<000001`3oool2000000h0oooo0P00
00050?ooo`030000003oool0000000H0oooo0P00000;0?ooo`800000203oool200000780oooo003o
0?oooj40oooo0`0000060?ooo`@00000403oool2000000H0oooo0P0000060?ooo`8000002P3oool2
000007d0oooo003l0?ooo`80000000<0oooo000000000000W03oool3000000L0oooo0P0000020?oo
o`800000403oool2000000L0oooo0P0000040?ooo`8000002`3oool2000000030?ooo`0000000000
07X0oooo003m0?ooo`030000003oool0000009X0oooo0`00000?0?ooo`8000003`3oool2000000L0
oooo00<000000?ooo`0000000P3oool2000000`0oooo0`00001l0?ooo`00oP3oool00`000000oooo
0?ooo`2F0?ooo`<000004P3oool200000100oooo0P0000070?ooo`030000003oool0000000800000
2`3oool2000007l0oooo003l0?ooo`80000000<0oooo000000000000T`3oool3000001H0oooo0P00
000@0?ooo`/00000SP3oool00?l0ooooTP3oool300000080oooo00<000000?ooo`3oool05@3oool2
00000140oooo0`0000050?ooo`8000000P3oool2000008T0oooo003o0?ooohl0oooo0`0000050?oo
o`030000003oool0oooo00800000503oool2000001P0oooo00@000000?ooo`0000000000R`3oool0
0?l0ooooS03oool3000000L0oooo1000000F0?ooo`800000603oool2000008d0oooo003o0?ooohT0
oooo0`0000080?ooo`8000000P3oool2000001L0oooo0P0000090?ooo`030000003oool0oooo00T0
oooo0P00002?0?ooo`00o`3ooon50?ooo`@00000403oool2000001L0oooo0P0000090?ooo`030000
003oool0oooo09T0oooo003o0?oooh80oooo0`00000D0?ooo`8000005`3oool010000000oooo0000
000000060?ooo`030000003oool0oooo09X0oooo003o0?ooogl0oooo0`0000060?ooo`800000403o
ool2000001L0oooo00<000000?ooo`3oool00P0000030?ooo`800000W03oool00?l0ooooO03oool3
000000H0oooo1P00000@0?ooo`8000005P3oool010000000oooo0?ooo`3oool6000009`0oooo003o
0?ooogT0oooo0`0000060?ooo`H0000000@0oooo0000000000000000403oool2000000h0oooo00<0
00000?ooo`3oool00`3oool200000:D0oooo003o0?ooogH0oooo0`0000050?ooo`@0000000<0oooo
0000000000001P3oool2000000l0oooo0P0000090?ooo`030000003oool0oooo00<0oooo0P000003
0?ooo`800000Y@3oool00?l0ooooL`3oool3000000D0oooo0`0000020?ooo`<000002P3oool00`00
0000oooo0?ooo`0=0?ooo`800000203oool2000000D0oooo1@00002V0?ooo`00o`3ooom`0?ooo`<0
00001P3oool200000080oooo0`00000N0?ooo`800000203oool200000:l0oooo003o0?ooofd0oooo
0`0000000`3oool000000?ooo`030?ooo`8000000`3oool300000240oooo0P0000070?ooo`<00000
[P3oool00?l0ooooJP3oool3000000@0oooo00<000000?ooo`0000000P0000000`3oool000000000
00050?ooo`8000007`3oool2000000D0oooo1000002_0?ooo`00o`3ooomW0?ooo`<000001P3oool3
000000050?ooo`00000000000000003oool00P0000060?ooo`<00000503oool00`000000oooo0?oo
o`060?ooo`80000000@0oooo0000000000000000/`3oool00?l0ooooH`3oool4000000H0oooo0`00
00001@3oool00000000000000000oooo00<0000000<0oooo000000000000203oool3000000`0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`@00000]P3oool00?l0ooooH03o
ool3000000L0oooo0`0000001@3oool00000000000000000oooo00<0000000<0oooo000000000000
0`00000;0?ooo`8000002P3oool00`000000oooo0?ooo`040?ooo`80000000@0oooo000000000000
0000^P3oool00?l0ooooG@3oool3000000H0oooo100000001@3oool00000000000000000oooo00<0
000000<0oooo000000000000100000000`3oool000000000000:0?ooo`8000002P3oool2000000H0
oooo0P00002m0?ooo`00o`3ooomJ0?ooo`<000002P3oool01@000000oooo000000000000oooo00D0
000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00800000203oool20000
00`0oooo00<000000?ooo`3oool0``3oool00?l0ooooE`3oool3000000h0oooo00<000000?ooo`00
0000100000001@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`02
000000L0oooo0P00000<0?ooo`800000a03oool00?l0ooooE03oool300000180oooo0`0000001@3o
ool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000030?ooo`00
0000000000H0oooo0P0000090?ooo`@00000a@3oool00?l0ooooD@3oool3000001D0oooo00D00000
0?ooo`00000000000?ooo`03000000050?ooo`00000000000000003oool00`0000001@3oool00000
000000000000oooo008000001@3oool2000000H0oooo0`0000390?ooo`00o`3ooom>0?ooo`<00000
1`3oool200000100oooo00D000000?ooo`00000000000?ooo`05000000030?ooo`000000oooo00<0
000000<0oooo0000000000000`0000040?ooo`8000000`3oool400000<`0oooo003o0?oood/0oooo
0`0000060?ooo`@000004`3oool00`000000oooo00000004000000060?ooo`00000000000?ooo`00
0000oooo1P0000000`3oool00000000000030?ooo`D00000d03oool00?l0ooooB03oool4000000H0
oooo0P0000020?ooo`800000503oool3000000050?ooo`00000000000000003oool00P0000000`3o
ool0000000000002000000050?ooo`00000000000000003oool00P0000020?ooo`800000d`3oool0
0?l0ooooA@3oool3000000<0oooo00@000000?ooo`0000000000203oool2000001@0oooo0`000000
1@3oool00000000000000000oooo00<0000000D0oooo00000000000000000?ooo`03000000030?oo
o`00000000000=H0oooo003o0?oood40oooo100000060?ooo`8000002`3oool2000000P0oooo2000
00040?ooo`<0000000<0oooo0000000000000`0000000`3oool000000?ooo`03000000040?ooo`00
0000000000000=P0oooo003o0?oooch0oooo0`0000070?ooo`<0000000<0oooo0000003oool02P3o
ool2000000H0oooo0P0000070?ooo`<000000P3oool00`000000oooo00000004000000060?ooo`00
000000000?ooo`000000oooo0`00003K0?ooo`00o`3ooolk0?ooo`<00000203oool2000000<0oooo
00<000000?ooo`0000002`3oool200000080oooo0`00000:0?ooo`8000000`3oool3000000050?oo
o`00000000000000003oool01000003N0?ooo`00o`3ooolh0?ooo`<000004@3oool2000000`0oooo
0`00000>0?ooo`8000000`3oool3000000040?ooo`000000000000000>80oooo003o0?ooocD0oooo
0`0000070?ooo`8000002`3oool00`000000oooo0000000<0?ooo`8000003P3oool2000000@0oooo
0`00003U0?ooo`00o`3ooolb0?ooo`<000001P3oool4000000h0oooo00<000000?ooo`000000303o
ool2000000d0oooo0P00003/0?ooo`00o`3oool2000002d0oooo0`0000070?ooo`8000000P3oool2
000000l0oooo00<000000?ooo`000000303oool2000000/0oooo0P00003]0?ooo`00oP3oool01000
0000oooo0?ooo`00000Y0?ooo`<000003`3oool2000000l0oooo0P00000<0?ooo`8000002@3oool3
00000>h0oooo003n0?ooo`040000003oool0oooo000002H0oooo0`00000C0?ooo`8000003P3oool0
0`000000oooo0000000<0?ooo`8000001@3oool300000?40oooo003n0?ooo`040000003oool0oooo
000002<0oooo0`00000F0?ooo`030000003oool0000000h0oooo00<000000?ooo`000000303oool2
000000040?ooo`000000000000000?@0oooo003n0?ooo`040000003oool0oooo00000200oooo1000
00060?ooo`P000002`3oool00`000000oooo0000000>0?ooo`030000003oool0000000/0oooo0`00
003g0?ooo`00o`3oool2000001d0oooo100000030?ooo`040000003oool0oooo0?ooo`<000001`3o
ool3000000X0oooo0P00000?0?ooo`8000002@3oool200000?X0oooo003o0?oooa`0oooo0`000007
0?ooo`030000003oool00000008000002`3oool3000000T0oooo0P00000>0?ooo`030000003oool0
000000<0oooo0P00003o0?ooo`00o`3ooolI0?ooo`<000002`3oool2000000l0oooo0P0000090?oo
o`8000003P3oool00`000000oooo0000000200000?l0oooo0P3oool00?l0oooo5P3oool3000000h0
oooo0P00000?0?ooo`8000002P3oool2000000`0oooo0`00003o0?ooo`D0oooo003o0?oooa<0oooo
0`0000060?ooo`030000003oool0oooo00P0oooo0P00000@0?ooo`8000002@3oool00`000000oooo
000000080?ooo`<00000o`3oool80?ooo`00o`3oool@0?ooo`<000002@3oool3000000P0oooo00<0
00000?ooo`0000003`3oool2000000X0oooo00<000000?ooo`000000103oool300000?l0oooo2`3o
ool00?l0oooo3@3oool3000000P0oooo1@0000020?ooo`8000001`3oool200000100oooo0P00000:
0?ooo`030000003oool0000000<00000o`3oool>0?ooo`00o`3oool:0?ooo`<00000203oool50000
00l0oooo0P00000?0?ooo`8000002P3oool300000?l0oooo4@3oool00?l0oooo1`3oool3000000<0
oooo00@000000?ooo`3oool0oooo1`00000A0?ooo`8000003`3oool2000000P0oooo0P00003o0?oo
oa@0oooo003o0?ooo`@0oooo0`0000070?ooo`<0000000@0oooo00000000000000005@3oool20000
00h0oooo00<000000?ooo`3oool0o`3ooolM0?ooo`00o`3oool10?ooo`<000002`3oool3000000/0
oooo00<000000?ooo`3oool02`3oool3000000/0oooo0P00003o0?oooal0oooo003l0?ooo`D00000
3`3oool00`000000oooo0?ooo`090?ooo`8000003P3oool2000000T0oooo0P00003o0?ooob00oooo
003i0?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0140oooo1`00
000=0?ooo`/00000o`3ooolQ0?ooo`00mP3oool3000000L0oooo00<000000?ooo`3oool00P3oool2
000000h0oooo00<000000?ooo`000000100000040?ooo`030000003oool0oooo00d0oooo1000003o
0?ooobD0oooo003c0?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`<000003P3oool30000
00`0oooo00<000000?ooo`3oool0o`3ooola0?ooo`00l03oool3000000L0oooo0P0000090?ooo`80
000000<0oooo0000003oool03P3oool2000000`0oooo00<000000?ooo`3oool0o`3oool`0?ooo`00
k@3oool3000000L0oooo0`00000:0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
6@3oool300000?l0oooo<@3oool00>X0oooo0`0000080?ooo`8000000P3oool00`000000oooo0?oo
o`080?ooo`800000103oool00`000000oooo0?ooo`0D0?ooo`@000000`3oool00`000000oooo0?oo
o`3o0?ooobh0oooo003W0?ooo`<000001P3oool2000000P0oooo00<000000?ooo`3oool01`3oool2
000000@0oooo00<000000?ooo`3oool04@3oool400000?l0oooo=`3oool00>@0oooo0`0000050?oo
o`@000002`3oool00`000000oooo0?ooo`060?ooo`8000001@3oool00`000000oooo0?ooo`080?oo
o`040000003oool0oooo0?ooo`H00000o`3oooli0?ooo`00h@3oool3000000H0oooo0P0000020?oo
o`800000303oool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`080?oo
o`H00000o`3oooll0?ooo`00gP3oool3000000h0oooo0P00000<0?ooo`030000003oool0oooo00@0
oooo0P0000070?ooo`030000003oool0oooo00P0oooo0P00003o0?ooocl0oooo003J0?ooo`@00000
203oool00`000000oooo0?ooo`070?ooo`8000002`3oool00`000000oooo0?ooo`040?ooo`800000
203oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo?@3oool00=L0oooo0`00
00020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`<000001`3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo00<0oooo0P0000090?ooo`030000003oool0oooo00800000o`3o
oom50?ooo`00e03oool3000000D0oooo00<000000?ooo`0000000P0000060?ooo`040000003oool0
0000000000H0oooo00<000000?ooo`0000002`3oool01`000000oooo0?ooo`3oool000000?ooo`00
00002@3oool300000?l0ooooA`3oool00=40oooo0`0000080?ooo`8000000P3oool00`000000oooo
0?ooo`040?ooo`8000000P3oool2000000D0oooo0P00000<0?ooo`030000003oool0oooo00800000
203oool200000?l0ooooBP3oool00<h0oooo0`0000060?ooo`<000001`3oool00`000000oooo0?oo
o`030?ooo`800000103oool2000000@0oooo0P00000<0?ooo`040000003oool0000000000?l0oooo
E03oool00</0oooo0`0000070?ooo`<000002P3oool00`000000oooo0?ooo`020?ooo`8000001P3o
ool00`000000oooo0?ooo`020?ooo`800000303oool300000?l0ooooE03oool00<P0oooo0`000008
0?ooo`80000000@0oooo0000003oool000002P3oool00`000000oooo0?ooo`020?ooo`8000001P3o
ool2000000<0oooo0P00000<0?ooo`800000o`3ooomD0?ooo`00a@3oool3000000@0oooo0P000009
0?ooo`8000002`3oool010000000oooo0?ooo`3oool2000000P0oooo0P000000103oool000000?oo
o`0000080?ooo`<00000o`3ooomF0?ooo`00`P3oool3000000@0oooo0`00000;0?ooo`8000002`3o
ool010000000oooo0?ooo`3oool2000000X0oooo0`0000000`3oool000000?ooo`020?ooo`030000
003oool0oooo0?l0ooooFP3oool00;l0oooo0`0000050?ooo`<000003@3oool00`000000oooo0000
000;0?ooo`050000003oool0oooo0?ooo`000000303oool2000000040?ooo`000000000000000?l0
ooooG@3oool00;`0oooo0`0000040?ooo`8000001@3oool2000000`0oooo0P00000<0?ooo`030000
003oool0oooo008000003@3oool200000?l0ooooG`3oool00;P0oooo100000050?ooo`8000002@3o
ool2000000X0oooo0P00000=0?ooo`040000003oool0000000000?l0ooooKP3oool00;D0oooo0`00
00000`3oool000000?ooo`040?ooo`@000002`3oool2000000P0oooo00<000000?ooo`0000003@3o
ool300000?l0ooooKP3oool00;80oooo0`0000040?ooo`030000003oool0oooo00D0oooo0P00000=
0?ooo`8000001`3oool2000000h0oooo0`00003o0?ooofd0oooo002_0?ooo`<000001P3oool20000
00L0oooo0P00000?0?ooo`8000001@3oool2000000l0oooo0P00003o0?ooofd0oooo002/0?ooo`<0
00001@3oool4000000T0oooo0P00000A0?ooo`8000000`3oool00`000000oooo0000000;0?ooo`<0
0000o`3ooom_0?ooo`00Z@3oool3000000H0oooo0P0000020?ooo`800000203oool2000001@0oooo
0P0000020?ooo`800000o`3ooomm0?ooo`00YP3oool3000000D0oooo0P0000070?ooo`8000001`3o
ool2000001H0oooo1000003o0?ooogd0oooo002S0?ooo`<00000103oool4000000X0oooo0P000006
0?ooo`800000603oool300000?l0ooooO03oool00:00oooo0`0000050?ooo`8000000P3oool20000
00/0oooo0P0000050?ooo`8000006P3oool00`000000oooo0?ooo`3o0?ooogX0oooo002M0?ooo`<0
00003@3oool2000000/0oooo100000020?ooo`800000o`3ooonG0?ooo`00VP3oool300000140oooo
0P00000;0?ooo`80000000<0oooo0000000000001000003o0?oooiD0oooo002F0?ooo`@000005@3o
ool2000000/0oooo0P0000060?ooo`L00000103oool200000?l0ooooR03oool009<0oooo10000006
0?ooo`L00000303oool2000000/0oooo0P00000<0?ooo`@00000o`3ooon:0?ooo`00T03oool30000
00<0oooo00<000000?ooo`3oool00P3oool2000000@0oooo1@00000;0?ooo`8000002`3oool20000
00X0oooo0P00003o0?ooohd0oooo002=0?ooo`<000001P3oool00`000000oooo0?ooo`02000000X0
oooo0`00000:0?ooo`8000002`3oool200000?l0ooooV03oool008X0oooo0`00000;0?ooo`800000
2@3oool010000000oooo0?ooo`3oool3000000T0oooo0P00000;0?ooo`80000000<0oooo00000000
0000o`3ooonD0?ooo`00Q`3oool3000000@0oooo0P0000080?ooo`8000002P3oool010000000oooo
0?ooo`3oool2000000X0oooo0P00000:0?ooo`<00000o`3ooonF0?ooo`00Q03oool3000000@0oooo
0`00000:0?ooo`8000000`3oool00`000000oooo0?ooo`030?ooo`<000000`3oool2000000X0oooo
0P0000070?ooo`800000o`3ooonI0?ooo`00D03oool500000080oooo0P00000X0?ooo`<000001@3o
ool2000000040?ooo`000000oooo000000T0oooo0P0000040?ooo`030000003oool0oooo00H00000
0`3oool2000000X0oooo0P0000020?ooo`800000o`3ooonM0?ooo`00DP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool08P3oool3000000`0oooo00<000000?ooo`000000
2@3oool2000000@0oooo100000040?ooo`060000003oool0oooo0000003oool000002@3oool40000
0?l0ooooW`3oool00580oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
01l0oooo0`0000040?ooo`8000002P3oool00`000000oooo000000080?ooo`8000001@3oool00`00
0000oooo0?ooo`080?ooo`8000001`3oool200000?l0ooooX`3oool004X0oooo100000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0L0?ooo`<000000`3oool40000
00d0oooo00<000000?ooo`000000203oool3000000@0oooo00<000000?ooo`3oool01`3oool20000
0?l0oooo[03oool00580oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
01P0oooo100000040?ooo`80000000@0oooo0000003oool000003P3oool00`000000oooo00000008
0?ooo`040000003oool00000000000/0oooo0P00003o0?ooojd0oooo001A0?ooo`800000103oool2
000001P0oooo0`00000<0?ooo`030000003oool0000000h0oooo00<000000?ooo`000000203oool2
000000030?ooo`000000oooo00T0oooo00<000000?ooo`3oool0o`3ooon/0?ooo`00KP3oool30000
0080oooo00@000000?ooo`3oool0oooo0P0000080?ooo`030000003oool0000000d0oooo10000009
0?ooo`D000000`3oool400000?l0oooo[`3oool006/0oooo0`0000050?ooo`@0000000<0oooo0000
00000000203oool00`000000oooo000000080?ooo`@000000`3oool2000000`0oooo1000003o0?oo
ok<0oooo001X0?ooo`<000001@3oool4000000D0oooo0P0000080?ooo`030000003oool0000000<0
oooo100000080?ooo`800000o`3oooo20?ooo`00I@3oool3000000D0oooo0`00000;0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`0000000P00000=0?ooo`800000o`3oooo10?ooo`00HP3o
ool3000000H0oooo0`00000G0?ooo`<000003`3oool2000000030?ooo`00000000000?l0oooo_@3o
ool005l0oooo0`00000;0?ooo`@000005P3oool2000000h0oooo0`00003o0?oookl0oooo001L0?oo
o`<00000103oool2000000/0oooo1000000D0?ooo`8000002`3oool200000?l0oooo`P3oool005T0
oooo0`0000040?ooo`@0000000<0oooo0000003oool0303oool400000180oooo0P00003o0?ooolh0
oooo001F0?ooo`<00000103oool3000000@0oooo0`00000?0?ooo`@00000403oool200000080oooo
0P00003o0?ooolT0oooo001B0?ooo`@00000103oool3000000T0oooo0P00000A0?ooo`@000003P3o
ool300000?l0oooob`3oool004l0oooo0`0000050?ooo`<000003P3oool00`000000oooo0?ooo`0A
0?ooo`@000002@3oool200000?l0oooocP3oool004`0oooo0`0000020?ooo`040000003oool0oooo
0?ooo`8000000P3oool2000002@0oooo1000003o0?ooomH0oooo00190?ooo`<000001@3oool20000
00L0oooo0P0000070?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool30000
0?l0ooooe03oool004H0oooo0`0000050?ooo`D00000203oool2000000L0oooo00<000000?ooo`3o
ool03@3oool2000000X0oooo0`00003o0?ooomH0oooo00130?ooo`<000001P3oool5000000030?oo
o`000000000000P0oooo0P0000060?ooo`8000003`3oool3000000@0oooo1000003o0?ooomT0oooo
00100?ooo`<000001P3oool5000000@0oooo0P0000090?ooo`8000000P3oool300000080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`060?ooo`030000003oool0000000<00000o`3o
oooM0?ooo`00?@3oool3000000H0oooo100000090?ooo`030000003oool0oooo00P0oooo0`000006
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool01P3oool200000?l0ooooh03oool0
03X0oooo0`0000070?ooo`<00000303oool2000000X0oooo00<000000?ooo`000000303oool20000
0?l0ooooj@3oool003L0oooo0`00000<0?ooo`8000002`3oool2000000/0oooo00<000000?ooo`00
0000303oool200000?l0ooooj03oool003@0oooo0`00000A0?ooo`8000002P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0000000P0oooo0`00003o0?ooonX0oooo000`0?ooo`@000001@3o
ool2000000l0oooo0P0000080?ooo`800000303oool00`000000oooo000000040?ooo`<00000o`3o
ooo]0?ooo`00;@3oool4000000@0oooo1000000C0?ooo`8000001`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0000000<00000o`3oooo`0?ooo`00:P3oool3000000<0oooo00<000000?oo
o`3oool00P0000020?ooo`8000005@3oool2000000D0oooo0P00000<0?ooo`<00000o`3ooooc0?oo
o`009`3oool3000000H0oooo00<000000?ooo`3oool01@3oool2000001H0oooo0P0000040?ooo`03
0000003oool0oooo00P0oooo0P00003o0?ooooH0oooo000T0?ooo`<000004P3oool2000001L0oooo
0P0000020?ooo`030000003oool0oooo0?l0ooooo`3oool10?ooo`008@3oool3000000D0oooo1`00
000:0?ooo`800000603oool2000000030?ooo`000000oooo0?l0ooooo`3oool10?ooo`007P3oool3
000000D0oooo0`0000060?ooo`<000002@3oool2000000d0oooo00<000000?ooo`3oool02@3oool2
00000?l0ooooo`3oool20?ooo`006`3oool3000000D0oooo0`00000;0?ooo`<00000203oool30000
00`0oooo00<000000?ooo`3oool0o`3ooooo0?ooo``0oooo000H0?ooo`<000001P3oool4000000d0
oooo0P0000090?ooo`030000003oool0000000/0oooo0P00003o0?ooool0oooo3@3oool001D0oooo
0`0000030?ooo`8000000P3oool200000080oooo00<000000?ooo`000000303oool2000000X0oooo
00<000000?ooo`0000002`3oool200000?l0ooooo`3oool<0?ooo`004P3oool3000000@0oooo0`00
00080?ooo`030000003oool0000000/0oooo0P00000;0?ooo`030000003oool0000000L0oooo0`00
003o0?ooool0oooo3P3oool000h0oooo100000050?ooo`80000000<0oooo0000000000002@3oool0
0`000000oooo000000080?ooo`H000002P3oool00`000000oooo000000020?ooo`@00000o`3ooooo
0?oooa40oooo000;0?ooo`<0000000<0oooo0000003oool02P3oool2000000T0oooo00<000000?oo
o`0000000`3oool4000000H0oooo0P0000090?ooo`@00000o`3ooooo0?oooaD0oooo00080?ooo`<0
0000103oool010000000oooo0000000000080?ooo`8000002P3oool00`000000oooo000000020000
00`0oooo0P0000060?ooo`<00000o`3ooooo0?oooaL0oooo00050?ooo`<000001P3oool3000000T0
oooo1000000:0?ooo`<000003@3oool200000?l0ooooo`3ooolP0?ooo`000P3oool3000000L0oooo
0P0000020?ooo`8000001P3oool200000080oooo0P00000<0?ooo`800000303oool200000?l0oooo
o`3ooolP0?ooo`000P00000@0?ooo`80000000@0oooo0000000000000000103oool00`000000oooo
0000000<0?ooo`800000203oool300000?l0ooooo`3ooolR0?ooo`004`3oool3000000L0oooo0P00
000=0?ooo`8000001@3oool200000?l0ooooo`3ooolU0?ooo`005P3oool2000000D0oooo00<00000
0?ooo`0000003@3oool2000000040?ooo`000000000000000?l0ooooo`3ooolW0?ooo`00603oool2
000000@0oooo0P00000>0?ooo`800000o`3ooooo0?ooobX0oooo000J0?ooo`8000000P3oool00`00
0000oooo0000000;0?ooo`800000o`3ooooo0?ooob`0oooo000L0?ooo`80000000<0oooo00000000
0000o`3ooooo0?ooocT0oooo000N0?ooo`80000000<0oooo0000003oool0o`3ooooo0?ooocL0oooo
000P0?ooo`800000o`3ooooo0?ooocP0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 599}, {205.688, 0}} -> {0.0495317, 0.301571, \
0.001718, 0.001718}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(stringDisplay["\<Pythagoras, \[CapitalSigma]\[Omicron]\[Kappa]\[Rho]\
\[Alpha]\[Tau]\[Epsilon]\[Sigma], x = Sin[\[Theta]]\>"];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35049 
%%ImageSize: 600 210.293 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0505051 1.05051 -0.339057 1.05051 [
[.15776 .25055 -8.44442 -9 ]
[.15776 .25055 9.55558 0 ]
[.46073 .15238 -2.99165 -9 ]
[.46073 .15238 3.00835 0 ]
[.78701 .0467 -6.37995 -9 ]
[.78701 .0467 5.62005 0 ]
[.4592 .08729 -4.98437 -12.75 ]
[.4592 .08729 5.01563 0 ]
[.99155 .00491 0 -5.94859 ]
[.99155 .00491 24 3.05141 ]
[.99874 .01538 0 -5.94222 ]
[.99874 .01538 6 3.05778 ]
[1.00588 .02579 0 -5.9359 ]
[1.00588 .02579 18 3.0641 ]
[1.06127 -0.00465 0 -8.41814 ]
[1.06127 -0.00465 10 4.33186 ]
[ 0 0 0 0 ]
[ 1 .35049 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00051 .31421 m
.97292 0 L
s
.15695 .26366 m
.15654 .27021 L
s
[(-10)] .15776 .25055 -0.06173 1 Mshowa
.46069 .16551 m
.46067 .17208 L
s
[(0)] .46073 .15238 -0.00278 1 Mshowa
.78784 .0598 m
.78826 .06636 L
s
[(10)] .78701 .0467 .06333 1 Mshowa
.125 Mabswid
.21594 .2446 m
.21575 .24853 L
s
.2758 .22526 m
.27564 .22919 L
s
.33653 .20563 m
.33642 .20957 L
s
.39815 .18572 m
.39809 .18966 L
s
.52416 .145 m
.5242 .14894 L
s
.58859 .12418 m
.58868 .12812 L
s
.654 .10305 m
.65414 .10699 L
s
.72041 .08159 m
.72061 .08553 L
s
.09879 .28245 m
.0985 .28638 L
s
.04145 .30098 m
.04112 .3049 L
s
.85632 .03768 m
.85663 .0416 L
s
.92588 .0152 m
.92624 .01913 L
s
gsave
.4592 .08729 -65.9844 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97292 0 m
.99937 .03853 L
s
.97905 .00893 m
.9728 .01094 L
s
[(-0.5)] .99155 .00491 -1 .32191 Mshowa
.98624 .01939 m
.97998 .0214 L
s
[(0)] .99874 .01538 -1 .32049 Mshowa
.99337 .02978 m
.98711 .03177 L
s
[(0.5)] 1.00588 .02579 -1 .31909 Mshowa
.125 Mabswid
.9805 .01103 m
.97675 .01224 L
s
.98193 .01312 m
.97818 .01433 L
s
.98337 .01522 m
.97962 .01642 L
s
.9848 .01731 m
.98105 .01851 L
s
.98767 .02147 m
.98391 .02268 L
s
.98909 .02356 m
.98534 .02476 L
s
.99052 .02563 m
.98677 .02683 L
s
.99194 .02771 m
.98819 .0289 L
s
.97761 .00683 m
.97386 .00804 L
s
.97617 .00472 m
.97242 .00593 L
s
.97472 .00262 m
.97097 .00383 L
s
.97327 .00051 m
.96952 .00172 L
s
.99479 .03185 m
.99103 .03304 L
s
.9962 .03391 m
.99245 .03511 L
s
.99762 .03597 m
.99387 .03717 L
s
.99903 .03803 m
.99528 .03923 L
s
gsave
1.06127 -0.00465 -61 -12.4181 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35049 L
0 .35049 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
.05102 .3368 m
.06964 .33088 L
s
.05567 .33533 m
.03384 .31605 L
s
.05722 .33483 m
.0354 .31555 L
s
.06964 .33088 m
.07173 .32897 L
s
.06964 .33088 m
.07329 .32847 L
s
.07173 .32897 m
.07226 .32756 L
s
.07329 .32847 m
.07382 .32706 L
s
.07226 .32756 m
.07176 .32523 L
s
.07382 .32706 m
.07332 .32473 L
s
.07176 .32523 m
.06866 .32247 L
s
.05829 .32078 m
.04583 .32477 L
s
.07332 .32473 m
.07023 .32197 L
s
.06866 .32247 m
.06504 .32113 L
s
.07023 .32197 m
.0666 .32063 L
s
.06504 .32113 m
.06244 .3207 L
s
.06244 .3207 m
.05829 .32078 L
s
.064 .32021 m
.05829 .32078 L
s
.0666 .32063 m
.064 .32021 L
s
.07647 .31997 m
.08587 .31698 L
s
.0796 .31898 m
.07455 .30296 L
s
.08117 .31848 m
.07662 .30483 L
s
.02917 .31755 m
.04008 .31405 L
s
.09214 .31497 m
.10157 .31196 L
s
.11973 .31493 m
.10234 .2991 L
s
.12131 .31443 m
.10392 .2986 L
s
.09842 .31296 m
.07455 .30296 L
s
.10787 .30995 m
.12049 .30592 L
s
.13868 .3089 m
.14501 .30689 L
s
.14343 .30739 m
.12203 .28769 L
s
.14501 .30689 m
.12362 .28718 L
s
.07455 .30296 m
.06724 .30023 L
s
.05834 .30183 m
.05886 .30039 L
s
.05572 .3014 m
.05834 .30183 L
s
.05625 .29996 m
.05572 .3014 L
s
.06724 .30023 m
.06201 .29938 L
s
.05782 .29945 m
.05625 .29996 L
s
.06201 .29938 m
.05782 .29945 L
s
.10234 .2991 m
.10083 .29578 L
s
.10392 .2986 m
.10241 .29527 L
s
.14008 .2984 m
.14586 .29781 L
s
.13486 .29754 m
.14008 .2984 L
s
.14586 .29781 m
.14904 .2968 L
s
.14904 .2968 m
.15121 .29484 L
s
.14904 .2968 m
.15281 .29433 L
s
.10083 .29578 m
.10297 .29382 L
s
.10241 .29527 m
.10297 .29382 L
s
.15121 .29484 m
.15078 .29245 L
s
.15281 .29433 m
.15237 .29194 L
s
.11034 .29272 m
.11398 .2941 L
s
.10297 .29382 m
.10614 .2928 L
s
.10614 .2928 m
.11034 .29272 L
s
.15078 .29245 m
.13958 .28205 L
s
.15237 .29194 m
.14117 .28154 L
s
.11725 .28923 m
.1284 .28565 L
s
.17198 .28821 m
.17619 .28813 L
s
.16937 .28777 m
.17198 .28821 L
s
.17619 .28813 m
.18261 .28608 L
s
.16836 .28683 m
.16937 .28777 L
s
.17097 .28726 m
.16996 .28632 L
s
.16996 .28632 m
.16836 .28683 L
s
.18261 .28608 m
.18481 .28411 L
s
.18481 .28411 m
.18541 .28264 L
s
.13478 .28359 m
.14598 .27999 L
s
.16431 .28304 m
.16068 .28166 L
s
.17014 .28245 m
.16431 .28304 L
s
.18541 .28264 m
.17633 .27408 L
s
.18541 .28264 m
.18501 .28023 L
s
.16591 .28253 m
.16228 .28114 L
s
.17014 .28245 m
.16591 .28253 L
s
.18078 .28031 m
.17014 .28245 L
s
.16068 .28166 m
.15865 .27976 L
s
.16228 .28114 m
.16025 .27924 L
s
.1834 .28075 m
.18078 .28031 L
s
.18501 .28023 m
.17794 .27356 L
s
.15865 .27976 m
.15822 .27734 L
s
.16025 .27924 m
.15982 .27682 L
s
.20413 .27793 m
.20052 .27654 L
s
.20413 .27793 m
.20152 .2775 L
s
.20836 .27785 m
.20413 .27793 L
s
.21159 .27682 m
.20836 .27785 L
s
.20152 .2775 m
.1979 .27611 L
s
.15822 .27734 m
.16202 .27483 L
s
.21383 .27483 m
.21159 .27682 L
s
.15982 .27682 m
.16202 .27483 L
s
.20052 .27654 m
.1965 .27272 L
s
.1979 .27611 m
.19589 .2742 L
s
.21345 .27241 m
.21383 .27483 L
s
.21445 .27336 m
.21383 .27483 L
s
.16202 .27483 m
.16685 .27328 L
s
.19589 .2742 m
.19549 .27177 L
s
.17108 .2732 m
.17633 .27408 L
s
.17633 .27408 m
.17592 .27165 L
s
.2203 .27276 m
.21707 .2738 L
s
.21707 .2738 m
.2213 .27372 L
s
.21445 .27336 m
.21707 .2738 L
s
.2213 .27372 m
.2203 .27276 L
s
.17794 .27356 m
.17753 .27113 L
s
.21407 .27093 m
.21445 .27336 L
s
.16685 .27328 m
.17108 .2732 L
s
.1965 .27272 m
.1961 .27029 L
s
.20944 .26858 m
.21345 .27241 L
s
.19549 .27177 m
.19287 .27133 L
s
.19549 .27177 m
.1961 .27029 L
s
.17592 .27165 m
.17813 .26965 L
s
.19287 .27133 m
.18924 .26993 L
s
.17753 .27113 m
.17813 .26965 L
s
.21207 .26902 m
.21407 .27093 L
s
.1961 .27029 m
.19833 .2683 L
s
.18924 .26993 m
.18823 .26898 L
s
.17813 .26965 m
.17974 .26914 L
s
.20844 .26762 m
.21207 .26902 L
s
.18823 .26898 m
.18883 .2675 L
s
.18823 .26898 m
.18782 .26654 L
s
.20582 .26718 m
.20944 .26858 L
s
.19833 .2683 m
.20157 .26726 L
s
.23491 .2681 m
.22967 .26722 L
s
.24079 .2675 m
.23491 .2681 L
s
.20582 .26718 m
.20844 .26762 L
s
.23654 .26758 m
.2313 .2667 L
s
.24079 .2675 m
.23654 .26758 L
s
.18883 .2675 m
.19268 .26498 L
s
.24404 .26646 m
.24079 .2675 L
s
.20157 .26726 m
.20582 .26718 L
s
.22967 .26722 m
.22506 .26486 L
s
.2313 .2667 m
.22668 .26433 L
s
.18782 .26654 m
.19167 .26401 L
s
.24631 .26445 m
.24404 .26646 L
s
.24794 .26393 m
.24404 .26646 L
s
.18519 .2661 m
.19106 .2655 L
s
.18155 .26469 m
.18519 .2661 L
s
.19268 .26498 m
.20079 .26237 L
s
.22506 .26486 m
.22306 .26293 L
s
.18053 .26373 m
.18155 .26469 L
s
.24759 .26149 m
.24631 .26445 L
s
.22668 .26433 m
.22468 .26241 L
s
.19167 .26401 m
.19978 .2614 L
s
.24923 .26096 m
.24794 .26393 L
s
.18012 .26128 m
.18053 .26373 L
s
.22306 .26293 m
.22168 .25952 L
s
.22468 .26241 m
.22331 .25899 L
s
.20079 .26237 m
.20465 .25984 L
s
.24625 .25807 m
.24759 .26149 L
s
.19978 .2614 m
.20364 .25887 L
s
.18397 .25875 m
.18012 .26128 L
s
.26036 .26124 m
.26691 .25915 L
s
.24788 .25754 m
.24923 .26096 L
s
.20465 .25984 m
.20426 .25738 L
s
.26527 .25968 m
.2514 .24609 L
s
.22168 .25952 m
.22294 .25654 L
s
.26691 .25915 m
.25305 .24556 L
s
.22331 .25899 m
.22457 .25601 L
s
.20364 .25887 m
.20426 .25738 L
s
.19371 .25561 m
.18397 .25875 L
s
.24426 .25613 m
.24625 .25807 L
s
.2459 .25561 m
.24788 .25754 L
s
.20426 .25738 m
.20325 .25641 L
s
.27084 .25662 m
.27511 .25654 L
s
.26559 .25573 m
.27084 .25662 L
s
.22294 .25654 m
.22683 .25399 L
s
.27511 .25654 m
.28003 .25496 L
s
.20325 .25641 m
.1996 .255 L
s
.23964 .25375 m
.24426 .25613 L
s
.22457 .25601 m
.22683 .25399 L
s
.26099 .25335 m
.26559 .25573 L
s
.1996 .255 m
.19371 .25561 L
s
.24127 .25322 m
.2459 .25561 L
s
.28003 .25496 m
.2807 .25347 L
s
.22683 .25399 m
.2301 .25294 L
s
.27643 .25355 m
.27905 .25399 L
s
.23437 .25286 m
.23964 .25375 L
s
.27708 .25205 m
.27643 .25355 L
s
.2807 .25347 m
.27971 .2525 L
s
.23601 .25234 m
.24127 .25322 L
s
.2301 .25294 m
.23437 .25286 L
s
.2301 .25294 m
.23601 .25234 L
s
.27971 .2525 m
.27708 .25205 L
s
.29552 .24873 m
.2998 .24865 L
s
.29289 .24828 m
.29552 .24873 L
s
.2998 .24865 m
.30641 .24654 L
s
.29191 .24731 m
.29289 .24828 L
s
.29454 .24776 m
.29356 .24678 L
s
.24648 .24768 m
.25798 .24398 L
s
.29356 .24678 m
.29191 .24731 L
s
.30641 .24654 m
.30874 .24451 L
s
.30874 .24451 m
.30942 .243 L
s
.28798 .24341 m
.28436 .24198 L
s
.29392 .2428 m
.28798 .24341 L
s
.30942 .243 m
.30061 .23417 L
s
.30942 .243 m
.30913 .24051 L
s
.28963 .24288 m
.28601 .24145 L
s
.29392 .2428 m
.28963 .24288 L
s
.30483 .24059 m
.29392 .2428 L
s
.28436 .24198 m
.28239 .24002 L
s
.28601 .24145 m
.28404 .23949 L
s
.30747 .24104 m
.30483 .24059 L
s
.30913 .24051 m
.30227 .23364 L
s
.28239 .24002 m
.28207 .23753 L
s
.28404 .23949 m
.28372 .237 L
s
.32533 .23921 m
.32269 .23876 L
s
.32962 .23912 m
.32533 .23921 L
s
.33628 .237 m
.32962 .23912 L
s
.32269 .23876 m
.32075 .23679 L
s
.32172 .23778 m
.32241 .23626 L
s
.28207 .23753 m
.28605 .23495 L
s
.28372 .237 m
.28605 .23495 L
s
.33864 .23495 m
.33628 .237 L
s
.32075 .23679 m
.32144 .23528 L
s
.32241 .23626 m
.32476 .23421 L
s
.32144 .23528 m
.32379 .23323 L
s
.33934 .23343 m
.33864 .23495 L
s
.28605 .23495 m
.29102 .23335 L
s
.34294 .23487 m
.33907 .23093 L
s
.33934 .23343 m
.34294 .23487 L
s
.32476 .23421 m
.33115 .22957 L
s
.29533 .23327 m
.30061 .23417 L
s
.30061 .23417 m
.30031 .23167 L
s
.30227 .23364 m
.30197 .23114 L
s
.33907 .23093 m
.33934 .23343 L
s
.29102 .23335 m
.29533 .23327 L
s
.32379 .23323 m
.33018 .22858 L
s
.30031 .23167 m
.30265 .22961 L
s
.30197 .23114 m
.30265 .22961 L
s
.31489 .23089 m
.31097 .22694 L
s
.3146 .22838 m
.31489 .23089 L
s
.30265 .22961 m
.30431 .22908 L
s
.33115 .22957 m
.33352 .22751 L
s
.33018 .22858 m
.33255 .22652 L
s
.31097 .22694 m
.3146 .22838 L
s
.31529 .22685 m
.3146 .22838 L
s
.33352 .22751 m
.33422 .22599 L
s
.31765 .22479 m
.31529 .22685 L
s
.33255 .22652 m
.33325 .225 L
s
.39826 .22628 m
.4236 .21821 L
s
.39826 .22628 m
.40057 .21256 L
s
.33422 .22599 m
.3313 .22302 L
s
.39994 .22574 m
.40227 .21201 L
s
.32433 .22264 m
.31765 .22479 L
s
.3313 .22302 m
.32865 .22256 L
s
.32865 .22256 m
.32433 .22264 L
s
.34594 .22223 m
.34665 .2207 L
s
.34329 .22177 m
.34594 .22223 L
s
.344 .22024 m
.34329 .22177 L
s
.34665 .2207 m
.3447 .21871 L
s
.34665 .2207 m
.344 .22024 L
s
.41963 .21168 m
.42191 .21875 L
s
.3447 .21871 m
.3394 .2178 L
s
.4236 .21821 m
.41963 .21168 L
s
.40227 .21201 m
.37818 .20533 L
s
.38083 .20579 m
.40291 .19869 L
s
.37818 .20533 m
.40366 .19713 L
s
.42605 .20441 m
.4234 .20394 L
s
.43041 .20432 m
.42605 .20441 L
s
.43041 .20432 m
.42511 .2034 L
s
.43382 .20323 m
.43041 .20432 L
s
.4234 .20394 m
.4198 .20248 L
s
.42511 .2034 m
.42151 .20193 L
s
.43534 .20012 m
.43382 .20323 L
s
.43629 .20113 m
.43382 .20323 L
s
.41109 .20264 m
.40195 .19768 L
s
.40366 .19713 m
.41109 .20264 L
s
.4198 .20248 m
.4179 .20046 L
s
.42151 .20193 m
.41866 .1989 L
s
.43611 .19857 m
.43629 .20113 L
s
.4179 .20046 m
.4177 .19789 L
s
.43251 .19709 m
.43534 .20012 L
s
.41866 .1989 m
.42017 .19579 L
s
.43422 .19654 m
.43611 .19857 L
s
.4177 .19789 m
.42017 .19579 L
s
.45091 .19777 m
.43728 .19029 L
s
.45263 .19722 m
.439 .18974 L
s
.4289 .19562 m
.43251 .19709 L
s
.43061 .19507 m
.43422 .19654 L
s
.42017 .19579 m
.42358 .19469 L
s
.42358 .19469 m
.4289 .19562 L
s
.42795 .1946 m
.43061 .19507 L
s
.45949 .19503 m
.45418 .1941 L
s
.46292 .19393 m
.45949 .19503 L
s
.44809 .19473 m
.45058 .19262 L
s
.44809 .19473 m
.44886 .19317 L
s
.45418 .1941 m
.44809 .19473 L
s
.42358 .19469 m
.42795 .1946 L
s
.4612 .19448 m
.46198 .19291 L
s
.4637 .19236 m
.46292 .19393 L
s
.44886 .19317 m
.44853 .188 L
s
.46198 .19291 m
.4637 .19236 L
s
.45058 .19262 m
.45025 .18745 L
s
.47403 .18906 m
.47137 .18859 L
s
.47841 .18898 m
.47403 .18906 L
s
.47841 .18898 m
.4731 .18804 L
s
.48186 .18787 m
.47841 .18898 L
s
.47137 .18859 m
.46778 .18711 L
s
.4731 .18804 m
.4695 .18656 L
s
.44853 .188 m
.45102 .18588 L
s
.48186 .18787 m
.48345 .18473 L
s
.48186 .18787 m
.48438 .18575 L
s
.45025 .18745 m
.45102 .18588 L
s
.45541 .18579 m
.45901 .18728 L
s
.46778 .18711 m
.45414 .17957 L
s
.4695 .18656 m
.45586 .17902 L
s
.45102 .18588 m
.45541 .18579 L
s
.48438 .18575 m
.48425 .18315 L
s
.46575 .18247 m
.4659 .18507 L
s
.48345 .18473 m
.48065 .18166 L
s
.48425 .18315 m
.48238 .18111 L
s
.46826 .18034 m
.46575 .18247 L
s
.48065 .18166 m
.47705 .18017 L
s
.48238 .18111 m
.47878 .17962 L
s
.49996 .18077 m
.4973 .1803 L
s
.50435 .18068 m
.49996 .18077 L
s
.50435 .18068 m
.50782 .17957 L
s
.50435 .18068 m
.49903 .17974 L
s
.47172 .17923 m
.46826 .18034 L
s
.4973 .1803 m
.4937 .1788 L
s
.47705 .18017 m
.47172 .17923 L
s
.49903 .17974 m
.49544 .17825 L
s
.47878 .17962 m
.47612 .17915 L
s
.50782 .17957 m
.50863 .17799 L
s
.50782 .17957 m
.51037 .17744 L
s
.47612 .17915 m
.47172 .17923 L
s
.4937 .1788 m
.49184 .17675 L
s
.49544 .17825 m
.49358 .1762 L
s
.50863 .17799 m
.50563 .16968 L
s
.51037 .17744 m
.50737 .16912 L
s
.512 .17427 m
.51651 .1768 L
s
.49184 .17675 m
.49171 .17414 L
s
.55439 .17658 m
.53517 .15485 L
s
.49358 .1762 m
.49345 .17358 L
s
.55613 .17603 m
.55788 .17547 L
s
.53693 .15428 m
.55613 .17603 L
s
.55788 .17547 m
.53869 .15371 L
s
.55963 .17491 m
.56138 .17435 L
s
.54044 .15315 m
.55963 .17491 L
s
.56138 .17435 m
.5422 .15258 L
s
.50574 .1723 m
.512 .17427 L
s
.49171 .17414 m
.49426 .172 L
s
.56313 .1738 m
.56488 .17324 L
s
.54397 .15202 m
.56313 .1738 L
s
.49345 .17358 m
.49426 .172 L
s
.52696 .17345 m
.54268 .16843 L
s
.52163 .17251 m
.52696 .17345 L
s
.56488 .17324 m
.54573 .15145 L
s
.56663 .17268 m
.56839 .17212 L
s
.54749 .15088 m
.56663 .17268 L
s
.52163 .17251 m
.52604 .17242 L
s
.52604 .17242 m
.54177 .16739 L
s
.5004 .17135 m
.50574 .1723 L
s
.56839 .17212 m
.54925 .15032 L
s
.49426 .172 m
.496 .17144 L
s
.57014 .17157 m
.5719 .17101 L
s
.55102 .14975 m
.57014 .17157 L
s
.496 .17144 m
.5004 .17135 L
s
.5719 .17101 m
.55278 .14918 L
s
.57365 .17045 m
.57541 .16989 L
s
.55454 .14862 m
.57365 .17045 L
s
.53302 .17019 m
.52391 .16248 L
s
.53302 .17019 m
.52216 .16304 L
s
.57541 .16989 m
.55631 .14805 L
s
.50563 .16968 m
.50818 .16752 L
s
.57716 .16933 m
.57892 .16877 L
s
.55808 .14748 m
.57716 .16933 L
s
.50737 .16912 m
.50818 .16752 L
s
.57892 .16877 m
.55984 .14691 L
s
.58068 .16821 m
.58244 .16765 L
s
.56161 .14634 m
.58068 .16821 L
s
.58244 .16765 m
.56338 .14577 L
s
.50818 .16752 m
.50993 .16696 L
s
.53517 .15485 m
.53693 .15428 L
s
.58223 .15445 m
.57955 .15398 L
s
.58667 .15437 m
.58223 .15445 L
s
.58667 .15437 m
.58132 .15341 L
s
.60084 .14984 m
.58667 .15437 L
s
.57955 .15398 m
.57597 .15245 L
s
.53869 .15371 m
.54044 .15315 L
s
.58132 .15341 m
.57774 .15189 L
s
.59194 .15001 m
.5902 .15324 L
s
.5422 .15258 m
.54397 .15202 L
s
.57597 .15245 m
.57416 .15036 L
s
.57774 .15189 m
.57502 .14875 L
s
.54573 .15145 m
.54749 .15088 L
s
.59284 .15106 m
.59994 .14879 L
s
.59281 .1484 m
.59284 .15106 L
s
.57416 .15036 m
.57411 .1477 L
s
.54925 .15032 m
.55102 .14975 L
s
.58923 .14687 m
.59194 .15001 L
s
.55278 .14918 m
.55454 .14862 L
s
.57502 .14875 m
.57674 .14551 L
s
.59101 .1463 m
.59281 .1484 L
s
.55631 .14805 m
.55808 .14748 L
s
.57411 .1477 m
.57674 .14551 L
s
.55984 .14691 m
.56161 .14634 L
s
.58565 .14534 m
.58923 .14687 L
s
.58742 .14477 m
.59101 .1463 L
s
.57674 .14551 m
.58029 .14437 L
s
.58029 .14437 m
.58565 .14534 L
s
.58474 .14429 m
.58742 .14477 L
s
.58029 .14437 m
.58474 .14429 L
s
.60342 .13963 m
.6043 .13801 L
s
.60074 .13915 m
.60342 .13963 L
s
.60162 .13752 m
.60074 .13915 L
s
.6043 .13801 m
.6025 .13589 L
s
.6043 .13801 m
.60162 .13752 L
s
.65077 .13655 m
.66155 .13311 L
s
.6025 .13589 m
.59712 .13492 L
s
.65436 .13541 m
.66179 .11413 L
s
.65616 .13484 m
.6636 .11355 L
s
.66874 .13082 m
.67956 .12736 L
s
.67595 .12851 m
.64193 .12052 L
s
.63833 .12167 m
.64914 .1182 L
s
.65636 .11587 m
.66722 .11238 L
s
.71772 .11247 m
.75064 .10195 L
s
.71251 .106 m
.74549 .09543 L
s
.80352 .09593 m
.79814 .09493 L
s
.80991 .09525 m
.80352 .09593 L
s
.81547 .09348 m
.80991 .09525 L
s
.79814 .09493 m
.79646 .09275 L
s
.82021 .09061 m
.81547 .09348 L
s
.79646 .09275 m
.79848 .08938 L
s
.79646 .09275 m
.79662 .08997 L
s
.82226 .08724 m
.82021 .09061 L
s
.79662 .08997 m
.79764 .08829 L
s
.82662 .08993 m
.82162 .08335 L
s
.82226 .08724 m
.82662 .08993 L
s
.79848 .08938 m
.80135 .0871 L
s
.79764 .08829 m
.8005 .08601 L
s
.82162 .08335 m
.82226 .08724 L
s
.80135 .0871 m
.81082 .08134 L
s
.8005 .08601 m
.80998 .08024 L
s
.84257 .08349 m
.84153 .08518 L
s
.84153 .08518 m
.83883 .08468 L
s
.83883 .08468 m
.83987 .08299 L
s
.83987 .08299 m
.84257 .08349 L
s
.788 .0818 m
.7829 .07519 L
s
.78731 .0779 m
.788 .0818 L
s
.81082 .08134 m
.81371 .07905 L
s
.80998 .08024 m
.81287 .07794 L
s
.83012 .07928 m
.8376 .07689 L
s
.81371 .07905 m
.81474 .07735 L
s
.81287 .07794 m
.81492 .07454 L
s
.7829 .07519 m
.78731 .0779 L
s
.78934 .0745 m
.78731 .0779 L
s
.83572 .07749 m
.82402 .06196 L
s
.81474 .07735 m
.81492 .07454 L
s
.8376 .07689 m
.8259 .06136 L
s
.81492 .07454 m
.81156 .07011 L
s
.79408 .07159 m
.78934 .0745 L
s
.85071 .0727 m
.85822 .0703 L
s
.79968 .06979 m
.79408 .07159 L
s
.85634 .0709 m
.84473 .0553 L
s
.90488 .07048 m
.91813 .06628 L
s
.90488 .07048 m
.87876 .03457 L
s
.85822 .0703 m
.84662 .0547 L
s
.81156 .07011 m
.80613 .0691 L
s
.90677 .06988 m
.88067 .03396 L
s
.80613 .0691 m
.79968 .06979 L
s
.86116 .06799 m
.86763 .06729 L
s
.85575 .06697 m
.86116 .06799 L
s
.86763 .06729 m
.8714 .06609 L
s
.8714 .06609 m
.87435 .06377 L
s
.8714 .06609 m
.87624 .06317 L
s
.87435 .06377 m
.8746 .06094 L
s
.81839 .06377 m
.83154 .05954 L
s
.87624 .06317 m
.87649 .06034 L
s
.8746 .06094 m
.86553 .04861 L
s
.87649 .06034 m
.86743 .04801 L
s
.83907 .05712 m
.85228 .05288 L
s
.96002 .05297 m
.97343 .04871 L
s
.85985 .05044 m
.87312 .04617 L
s
.93184 .04955 m
.92912 .04904 L
s
.93566 .04833 m
.93184 .04955 L
s
.97151 .04932 m
.94603 .01287 L
s
.92912 .04904 m
.92752 .04679 L
s
.97343 .04871 m
.94797 .01224 L
s
.93516 .04434 m
.93566 .04833 L
s
.93677 .0466 m
.93566 .04833 L
s
.91636 .04758 m
.92018 .04636 L
s
.91365 .04707 m
.91636 .04758 L
s
.91012 .04542 m
.91365 .04707 L
s
.91827 .04697 m
.91937 .04523 L
s
.92752 .04679 m
.92782 .04392 L
s
.93708 .04373 m
.93677 .0466 L
s
.92018 .04636 m
.92128 .04462 L
s
.91937 .04523 m
.91614 .04072 L
s
.92128 .04462 m
.91724 .03897 L
s
.93276 .04095 m
.93516 .04434 L
s
.92782 .04392 m
.93195 .03982 L
s
.93467 .04034 m
.93708 .04373 L
s
.92843 .03817 m
.93276 .04095 L
s
.91614 .04072 m
.91643 .03784 L
s
.93034 .03755 m
.93467 .04034 L
s
.93195 .03982 m
.93498 .03746 L
s
.91724 .03897 m
.91753 .03609 L
s
.9249 .03651 m
.92843 .03817 L
s
.91643 .03784 m
.91753 .03609 L
s
.92681 .0359 m
.93034 .03755 L
s
.91945 .03547 m
.9249 .03651 L
s
.91753 .03609 m
.91945 .03547 L
s
.92409 .03538 m
.92681 .0359 L
s
.91945 .03547 m
.92409 .03538 L
s
.87876 .03457 m
.89213 .03026 L
s
.93443 .01661 m
.94797 .01224 L
s
0 g
.25 Mabswid
.00051 .31421 m
.97292 0 L
s
.15695 .26366 m
.15654 .27021 L
s
[(-10)] .15776 .25055 -0.06173 1 Mshowa
.46069 .16551 m
.46067 .17208 L
s
[(0)] .46073 .15238 -0.00278 1 Mshowa
.78784 .0598 m
.78826 .06636 L
s
[(10)] .78701 .0467 .06333 1 Mshowa
.125 Mabswid
.21594 .2446 m
.21575 .24853 L
s
.2758 .22526 m
.27564 .22919 L
s
.33653 .20563 m
.33642 .20957 L
s
.39815 .18572 m
.39809 .18966 L
s
.52416 .145 m
.5242 .14894 L
s
.58859 .12418 m
.58868 .12812 L
s
.654 .10305 m
.65414 .10699 L
s
.72041 .08159 m
.72061 .08553 L
s
.09879 .28245 m
.0985 .28638 L
s
.04145 .30098 m
.04112 .3049 L
s
.85632 .03768 m
.85663 .0416 L
s
.92588 .0152 m
.92624 .01913 L
s
gsave
.4592 .08729 -65.9844 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 210.25},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000dR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo0P00000L0?oo
o`00o`3ooooo0?oooa`0oooo0`00000@0?ooo`040000003oool0oooo000000P0oooo00@000000?oo
o`3oool000006`3oool00?l0ooooo`3ooolI0?ooo`H00000403oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0oooo01T0oooo003o0?ooool0oooo5P3oool3000000<0oooo0`00000:0?oo
o`@000000P3oool010000000oooo0?ooo`0000090?ooo`800000703oool00?l0ooooo`3ooolC0?oo
o`<000001`3oool3000000l0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0K
0?ooo`00o`3ooooo0?oooa00oooo0`00000=0?ooo`030000003oool0oooo00d0oooo0P00000:0?oo
o`<000006`3oool00?l0ooooo`3oool<0?ooo`@000003P3oool4000000`0oooo0P00000Z0?ooo`00
o`3ooooo0?ooo`T0oooo0`00000A0?ooo`<0000000<0oooo0000000000002P3oool010000000oooo
0?ooo`00000Y0?ooo`00o`3ooooo0?ooo`H0oooo0`0000060?ooo`8000003`3oool3000000X0oooo
00@000000?ooo`3oool00000:@3oool00?l0ooooo`3oool30?ooo`<000001@3oool4000000030?oo
o`000000000000h0oooo0P0000000`3oool000000?ooo`080?ooo`040000003oool0oooo000002T0
oooo003o0?ooool0oooo100000040?ooo`<000001@3oool2000000l0oooo0`0000090?ooo`040000
003oool0oooo000002T0oooo003o0?oooo`0oooo0`0000030?ooo`030000003oool0oooo00/0oooo
0P00000?0?ooo`<000002@3oool2000002X0oooo003o0?ooooT0oooo0`0000070?ooo`030000003o
ool0oooo00/0oooo0P00000@0?ooo`800000303oool2000000@0oooo0P0000040?ooo`8000006P3o
ool00?l0oooomP3oool3000001P0oooo0P00000=0?ooo`<000000P3oool00`000000oooo0?ooo`08
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000006@3oool00?l0ooool`3o
ool3000001`0oooo0P00000?0?ooo`<000002P3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo01L0oooo003o0?oooo00oooo0`00000P0?ooo`8000003P3oool2000000030?ooo`00
0000oooo00P0oooo00@000000?ooo`3oool000002@3oool2000001X0oooo003o0?ooon`0oooo1000
000T0?ooo`8000003P3oool2000000030?ooo`000000oooo00L0oooo00@000000?ooo`3oool00000
2@3oool00`000000oooo0?ooo`0I0?ooo`00o`3ooooY0?ooo`<00000:03oool2000000l0oooo0`00
00090?ooo`8000002P3oool3000001T0oooo003o0?ooonH0oooo0`0000060?ooo`800000903oool2
00000100oooo0P00000`0?ooo`00o`3ooon`0?ooo`D000000P3oool2000002X0oooo0`0000050?oo
o`@000009`3oool2000000`0oooo1P00000_0?ooo`00o`3ooonb0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0T0?ooo`<000001@3oool3000002/0oooo0P00000A0?oo
o`800000;P3oool00?l0oooo/P3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool08@3oool3000000T0oooo0P00000C0?ooo`H000004`3oool2000000h0oooo0P0000000`3o
ool000000?ooo`0]0?ooo`00o`3ooonb0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0N0?ooo`<00000303oool200000180oooo0P0000040?ooo`<0000000<0oooo0000
003oool03`3oool2000000h0oooo0P0000000`3oool000000?ooo`0/0?ooo`00o`3ooonb0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0K0?ooo`<000000P3oool00`00
0000oooo0?ooo`0;0?ooo`8000004@3oool2000000H0oooo0P00000A0?ooo`8000003`3oool20000
02h0oooo003o0?oook40oooo0P0000040?ooo`8000006`3oool3000000D0oooo00<000000?ooo`3o
ool0303oool200000100oooo00<000000?ooo`000000103oool400000140oooo0P00000n0?ooo`00
o`3ooooA0?ooo`<00000603oool200000100oooo0P0000030?ooo`040000003oool0oooo0?ooo`<0
0000403oool2000003d0oooo003o0?ooolh0oooo0`00000K0?ooo`800000303oool00`000000oooo
0?ooo`020?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo
0P00000l0?ooo`00o`3oooo:0?ooo`@000005P3oool2000000L0oooo0P00000<0?ooo`80000000<0
oooo0000000000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0100oooo0P00
000l0?ooo`00o`3oooo70?ooo`<000005P3oool4000000X0oooo0P00000=0?ooo`8000001@3oool0
1@000000oooo0?ooo`3oool0000001<0oooo0P00000k0?ooo`00o`3oooo40?ooo`<000005`3oool2
00000080oooo0P00000;0?ooo`800000503oool300000180oooo0P00000m0?ooo`00o`3oooo10?oo
o`<000005@3oool2000000L0oooo0P00000;0?ooo`8000009P3oool3000003l0oooo003o0?oookh0
oooo0`00000E0?ooo`<000002P3oool2000000/0oooo0P00000S0?ooo`800000@P3oool00?l0oooo
^`3oool3000001H0oooo1000000<0?ooo`8000002`3oool2000006H0oooo003o0?oookP0oooo0`00
000G0?ooo`8000000P3oool00`000000oooo0000000<0?ooo`8000002`3oool2000006D0oooo003o
0?oookD0oooo0`00000E0?ooo`800000203oool2000000`0oooo0P00000;0?ooo`800000I@3oool0
0?l0oooo/P3oool3000000030?ooo`000000oooo01<0oooo0P00000;0?ooo`800000303oool20000
00/0oooo0P00001T0?ooo`00o`3ooon_0?ooo`<00000103oool00`000000oooo0?ooo`0@0?ooo`80
000000<0oooo0000003oool02P3oool00`000000oooo0000000;0?ooo`800000303oool2000006<0
oooo003o0?oooj/0oooo100000070?ooo`030000003oool0oooo00h0oooo0P0000020?ooo`800000
303oool00`000000oooo000000090?ooo`8000003P3oool200000680oooo003o0?ooojP0oooo0`00
000;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`000000303oool3000000@0oooo1@00
000?0?ooo`8000001P3oool2000005X0oooo003o0?ooojD0oooo0`00000G0?ooo`<000002P3oool0
0`000000oooo0000000<0?ooo`H000005@3oool2000000030?ooo`000000000000800000G03oool0
0?l0ooooXP3oool3000001H0oooo100000030?ooo`8000002@3oool2000000d0oooo0P00000I0?oo
o`800000H03oool00?l0ooooW`3oool3000001L0oooo0P0000090?ooo`030000003oool0oooo00L0
oooo0P0000090?ooo`<00000O@3oool00?/0oooo0P0000000`3oool000000000002K0?ooo`<00000
603oool2000000`0oooo00<000000?ooo`3oool01P3oool00`000000oooo000000280?ooo`00o03o
ool00`000000oooo0000002I0?ooo`<000005`3oool010000000oooo0?ooo`00000=0?ooo`800000
2@3oool2000008P0oooo003m0?ooo`030000003oool0oooo09D0oooo0`00000K0?ooo`8000003P3o
ool2000000X0oooo0P0000270?ooo`00n`3oool2000000030?ooo`00000000000980oooo0`00000N
0?ooo`8000003@3oool2000000P0oooo0`0000290?ooo`00o`3ooon@0?ooo`<000008P3oool20000
00/0oooo0P00002E0?ooo`00o`3ooon<0?ooo`D000009@3oool00`000000oooo0?ooo`070?ooo`<0
00001@3oool00`000000oooo0?ooo`080?ooo`800000Q03oool00?l0ooooR@3oool3000000@0oooo
00<000000?ooo`3oool0:`3oool3000000L0oooo0P0000080?ooo`<00000Q03oool00?l0ooooQP3o
ool3000000L0oooo00<000000?ooo`3oool0:P3oool2000000X0oooo00<000000?ooo`3oool0S@3o
ool00?l0ooooP`3oool3000003D0oooo0P00000<0?ooo`800000SP3oool00?l0ooooP03oool30000
03P0oooo0P00000;0?ooo`040000003oool00000000008d0oooo003o0?ooogd0oooo0`00000k0?oo
o`030000003oool0oooo00P0oooo0P00002A0?ooo`00o`3ooomj0?ooo`<00000?P3oool00`000000
oooo0?ooo`060?ooo`800000T`3oool00?l0ooooM`3oool3000002<0oooo0P00000L0?ooo`T00000
U@3oool00?l0ooooM03oool3000002<0oooo0`00002l0?ooo`00o`3oooma0?ooo`<000008`3oool3
00000;l0oooo003o0?ooofd0oooo1000000S0?ooo`<00000`P3oool00?l0ooooJP3oool3000002@0
oooo0`00000<0?ooo`800000]`3oool00?l0ooooI`3oool3000000030?ooo`000000oooo0240oooo
0`00000<0?ooo`<00000^@3oool00?l0ooooI03oool3000000D0oooo00<000000?ooo`3oool07@3o
ool2000000`0oooo0`00002l0?ooo`00o`3ooomQ0?ooo`<00000<`3oool300000;l0oooo003o0?oo
oeh0oooo0`00000c0?ooo`<00000`P3oool00?l0ooooF`3oool3000001@0oooo0P00000M0?ooo`<0
0000a@3oool00?l0ooooF03oool3000001@0oooo0`00000M0?ooo`800000b03oool00?l0ooooE@3o
ool3000001D0oooo0P0000000`3oool000000000003W0?ooo`00o`3ooomB0?ooo`<000006P3oool2
00000>P0oooo003o0?ooodl0oooo0`00000F0?ooo`8000001@3oool200000>P0oooo003o0?oood/0
oooo1000000F0?ooo`<000001`3oool200000>P0oooo003o0?ooodP0oooo0`00000H0?ooo`800000
0`3oool5000000030?ooo`00000000000>T0oooo003o0?ooodD0oooo0`00000U0?ooo`@00000j03o
ool00?l0oooo@P3oool300000080oooo00<000000?ooo`3oool0903oool2000000030?ooo`000000
000000<00000h`3oool00?l0oooo?`3oool3000000D0oooo00<000000?ooo`3oool08`3oool20000
00L0oooo1@00003N0?ooo`00o`3oooll0?ooo`<00000;P3oool2000000L0oooo0`00003P0?ooo`00
o`3oooli0?ooo`<00000<@3oool2000000D0oooo0P00003S0?ooo`00o`3ooolf0?ooo`<00000<`3o
ool2000000030?ooo`00000000000>P0oooo003o0?oooc<0oooo0`00000F0?ooo`8000007P3oool3
00000>X0oooo003o0?oooc00oooo0`00000K0?ooo`8000006P3oool200000>d0oooo003n0?ooo`80
0000:`3oool4000001h0oooo0`00003o0?ooo`T0oooo003m0?ooo`040000003oool0oooo000002L0
oooo0`00000S0?ooo`030000003oool0oooo0?l0oooo203oool00?d0oooo00@000000?ooo`3oool0
0000903oool300000?l0oooo<@3oool00?d0oooo00@000000?ooo`3oool000008@3oool3000001d0
oooo1@00003o0?oooa80oooo003m0?ooo`040000003oool0oooo000001h0oooo1000000D0?ooo`80
00001`3oool200000080oooo0P0000000`3oool000000000003o0?oooa00oooo003n0?ooo`800000
703oool3000000<0oooo00<000000?ooo`3oool03`3oool3000000030?ooo`000000000000@0oooo
0P0000060?ooo`80000000<0oooo0000003oool0o`3oool>0?ooo`00o`3ooolJ0?ooo`<000001P3o
ool00`000000oooo0?ooo`0<0?ooo`<0000000D0oooo00000000000000000?ooo`02000000<0oooo
0P0000080?ooo`80000000@0oooo0000000000000000o`3oool;0?ooo`00o`3ooolG0?ooo`<00000
503oool4000000050?ooo`00000000000000003oool00`0000000`3oool00000000000020?ooo`03
0000003oool0000000H0oooo00<000000?ooo`0000000P00003o0?ooo`d0oooo003o0?oooa@0oooo
0`00000D0?ooo`<0000000<0oooo0000000000000P0000001@3oool00000000000000000oooo00<0
000000<0oooo0000000000000P3oool00`000000oooo00000002000000<0oooo0`00003o0?ooo`l0
oooo003o0?oooa40oooo0`00000F0?ooo`030000003oool000000080000000<0oooo000000000000
0P0000001@3oool00000000000000000oooo00<0000000<0oooo0000000000000P3oool700000?l0
oooo4P3oool00?l0oooo3@3oool4000001X0oooo00<000000?ooo`0000000P0000000`3oool00000
00000002000000050?ooo`00000000000000003oool01@00003o0?oooa/0oooo003o0?ooo`X0oooo
0`00000O0?ooo`030000003oool0000000<0000000D0oooo00000000000000000?ooo`0600000003
0?ooo`00000000000?l0oooo6P3oool00?l0oooo1`3oool300000280oooo0P0000000`3oool00000
00000002000000030?ooo`000000000000@0000000D0oooo00000000000000000?ooo`0200000?l0
oooo6@3oool00?l0oooo103oool3000001`0oooo00<000000?ooo`3oool01`3oool2000000030?oo
o`000000000000D0000000D0oooo00000000000000000?ooo`03000000030?ooo`00000000000?l0
oooo603oool00?l0oooo0@3oool3000001h0oooo00<000000?ooo`0000002@3oool5000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000000030?ooo`00000000000?l0
oooo5`3oool00?d0oooo0`00000R0?ooo`<000002@3oool00`000000oooo00000002000000030?oo
o`00000000000080000000D0oooo00000000000000000?ooo`03000000030?ooo`00000000000?l0
oooo5P3oool00?X0oooo0`0000020?ooo`030000003oool0oooo01P0oooo0P0000080?ooo`800000
1@3oool200000080oooo00<000000?ooo`0000000P0000000`3oool0000000000002000000050?oo
o`00000000000000003oool00`0000000`3oool000000000003o0?oooaD0oooo003g0?ooo`<00000
1@3oool00`000000oooo0?ooo`0F0?ooo`8000002`3oool2000000030?ooo`000000000000@00000
0P3oool00`000000oooo00000003000000050?ooo`00000000000000003oool00`000000103oool0
000000000000003o0?oooaL0oooo003d0?ooo`<00000203oool00`000000oooo0?ooo`0A0?ooo`@0
000000<0oooo0000000000002`3oool6000000D0oooo0P0000000`3oool000000000000200000005
0?ooo`00000000000000003oool00`00003o0?oooaX0oooo003a0?ooo`<000002`3oool00`000000
oooo0?ooo`0?0?ooo`800000103oool4000000H0oooo1P00000:0?ooo`80000000<0oooo00000000
00000P000000103oool0000000000000003o0?oooad0oooo003]0?ooo`@000007`3oool2000000L0
oooo1000000E0?ooo`80000000<0oooo0000000000000P00003o0?ooob00oooo003Z0?ooo`<00000
8`3oool2000000P0oooo0P0000000`3oool000000000000D0?ooo`800000o`3ooolT0?ooo`00i`3o
ool3000001<0oooo00<000000?ooo`3oool04@3oool2000000L0oooo0P00003o0?ooocd0oooo003T
0?ooo`<000005@3oool010000000oooo0000000000030?ooo`L000002@3oool800000?l0oooo?P3o
ool00>40oooo0`00000I0?ooo`80000000@0oooo0000003oool000001P3oool300000?l0ooooC@3o
ool00=h0oooo0`00000N0?ooo`@00000203oool200000?l0ooooC03oool00=/0oooo0`00000L0?oo
o`<00000103oool3000000P0oooo00<000000?ooo`3oool0o`3ooom:0?ooo`00f03oool300000003
0?ooo`000000oooo01X0oooo0P0000030?ooo`800000103oool5000000<0oooo00<000000?ooo`3o
ool0o`3ooom;0?ooo`00e@3oool3000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`020?ooo`8000002P3oool700000?l0ooooCP3oool00=80oooo0`00000M0?ooo`040000003o
ool00000000000<0oooo0P00003o0?oooeh0oooo003>0?ooo`@000008@3oool2000000040?ooo`00
0000oooo0?ooo`8000001@3oool200000?l0ooooE`3oool00</0oooo0`00000M0?ooo`@000001P3o
ool<00000?l0ooooF03oool00<P0oooo0`00000N0?ooo`8000000P3oool4000000H0oooo1000003o
0?oooeh0oooo00350?ooo`<000005P3oool3000000H0oooo0P0000070?ooo`<000001P3oool30000
0?l0ooooG@3oool00<80oooo0`00000F0?ooo`@0000000<0oooo0000000000001@3oool2000000P0
oooo0P00003o0?ooofH0oooo002o0?ooo`<000005@3oool4000000L0oooo0P0000040?ooo`800000
1P3oool00`000000oooo0000003o0?ooofH0oooo002l0?ooo`<00000503oool5000000`0oooo00<0
00000?ooo`3oool00P3oool4000000<0oooo0P00003o0?ooofL0oooo002i0?ooo`<000005@3oool4
000001H0oooo1@00003o0?ooofT0oooo002f0?ooo`<0000000<0oooo0000003oool05`3oool40000
0?l0ooooPP3oool00;<0oooo0`0000040?ooo`030000003oool0oooo01X0oooo0`00003o0?ooogl0
oooo002`0?ooo`<000009`3oool400000?l0ooooN`3oool00:`0oooo1000000^0?ooo`800000203o
ool00`000000oooo0?ooo`3o0?ooofh0oooo002Y0?ooo`<00000<P3oool2000000P0oooo0P00003o
0?ooofl0oooo002V0?ooo`<00000=@3oool00`000000oooo0?ooo`080?ooo`800000o`3ooom^0?oo
o`00X`3oool3000001H0oooo1000000N0?ooo`030000003oool0oooo00P0oooo0`00003o0?ooofd0
oooo002P0?ooo`<000006`3oool2000001d0oooo0P0000080?ooo`@00000o`3ooom^0?ooo`00W@3o
ool3000001h0oooo0`00000L0?ooo`8000001P3oool200000?l0ooooLP3oool009X0oooo0`00000F
0?ooo`D000009@3oool00`000000oooo0?ooo`020?ooo`<00000o`3ooomd0?ooo`00U`3oool30000
01H0oooo0`0000050?ooo`030000003oool0oooo0280oooo00<000000?ooo`0000000P00003o0?oo
ogL0oooo002D0?ooo`<0000000<0oooo0000003oool04P3oool010000000oooo0000000000080?oo
o`8000008`3oool200000?l0ooooNP3oool00940oooo0`0000040?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00P3oool2000000P0oooo0P00003o0?oooj00oooo002=0?ooo`@00000
5P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo0P0000040?ooo`030000
003oool0oooo0?l0ooooVP3oool008X0oooo0`00000I0?ooo`800000303oool3000000D0oooo0P00
003o0?oooi/0oooo00270?ooo`<000005P3oool8000000/0oooo0P0000070?ooo`<00000o`3ooonJ
0?ooo`00EP3oool500000080oooo0P00000U0?ooo`<000005`3oool2000000L0oooo0P0000090?oo
o`8000001`3oool00`000000oooo0?ooo`3o0?oooi/0oooo001H0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0O0?ooo`<00000603oool2000000X0oooo0P0000080?oo
o`030000003oool0oooo00@0oooo0P00003o0?oooih0oooo001H0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0L0?ooo`<000006`3oool2000000/0oooo0P0000080?oo
o`H00000o`3ooonP0?ooo`00D03oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo01T0oooo0`00000O0?ooo`800000203oool500000?l0oooo[@3oool005P0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo0`00000S0?oo
o`T00000103oool00`000000oooo0?ooo`3o0?oooj/0oooo001G0?ooo`800000103oool2000001H0
oooo0`00000D0?ooo`040000003oool00000000001/0oooo00<000000?ooo`3oool0o`3ooon[0?oo
o`00LP3oool300000080oooo00<000000?ooo`3oool0403oool4000001@0oooo00<000000?ooo`3o
ool0103oool200000?l0oooo[P3oool006h0oooo100000050?ooo`030000003oool0oooo00h0oooo
0P0000020?ooo`030000003oool0000001<0oooo1`00003o0?oook00oooo001[0?ooo`<000007`3o
ool00`000000oooo0000003o0?ooolT0oooo001X0?ooo`<00000503oool5000000X0oooo00<00000
0?ooo`000000203oool300000?l0oooo_@3oool006D0oooo0`00000E0?ooo`8000001@3oool30000
00P0oooo0`0000070?ooo`<00000o`3ooonm0?ooo`00HP3oool3000000D0oooo1`00000:0?ooo`80
00002@3oool3000000P0oooo100000030?ooo`@00000o`3ooonm0?ooo`00G`3oool3000000H0oooo
0P0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool02P3oool2000000P0oooo
0P000000103oool0000000000000003o0?oool40oooo001L0?ooo`<000001P3oool3000000P0oooo
0P0000090?ooo`030000003oool0oooo00X0oooo0P0000090?ooo`800000o`3oooo40?ooo`00F@3o
ool3000000L0oooo0P0000090?ooo`<000002P3oool00`000000oooo0?ooo`0;0?ooo`8000001@3o
ool300000?l0ooooaP3oool005H0oooo0`00000;0?ooo`030000003oool0oooo00D0oooo1000000;
0?ooo`8000002`3oool200000?l0ooooc`3oool005<0oooo0`0000000`3oool000000?ooo`0;0?oo
o`030000003oool0oooo0080oooo1000000?0?ooo`<000002@3oool200000?l0ooooc`3oool004l0
oooo100000030?ooo`030000003oool0oooo00`0oooo1@0000050?ooo`@000002`3oool4000000D0
oooo0P00003o0?ooom00oooo001<0?ooo`<000001`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`<00000
2`3oool600000?l0oooodP3oool004T0oooo0`00000:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`02000000L0oooo0P00003o0?ooon80oooo0016
0?ooo`<00000603oool2000000L0oooo100000080?ooo`050000003oool0oooo0?ooo`000000o`3o
oooN0?ooo`00@`3oool3000001D0oooo200000090?ooo`030000003oool0000000L0oooo1@00003o
0?ooomh0oooo00100?ooo`<000005P3oool2000000L0oooo0P0000090?ooo`8000001`3oool00`00
0000oooo0?ooo`3o0?ooon00oooo000m0?ooo`<000005`3oool2000000X0oooo0P0000090?ooo`P0
0000o`3ooooS0?ooo`00>P3oool3000001/0oooo00<000000?ooo`3oool02@3oool200000?l0oooo
l`3oool003L0oooo0`00000D0?ooo`040000003oool00000000000L0oooo0P0000070?ooo`D00000
o`3oooob0?ooo`00=03oool3000001D0oooo1000000:0?ooo`P00000103oool00`000000oooo0?oo
o`3o0?oooo00oooo000a0?ooo`<000000P3oool00`000000oooo0?ooo`0A0?ooo`8000000P3oool0
0`000000oooo0000000E0?ooo`030000003oool0oooo0?l0ooool03oool002d0oooo100000050?oo
o`030000003oool0oooo00/0oooo00@000000?ooo`00000000001`3oool00`000000oooo0000000;
0?ooo`8000001@3oool200000?l0ooool`3oool002X0oooo0`00000F0?ooo`<000002P3oool30000
00/0oooo1P00003o0?ooooD0oooo000W0?ooo`<000005`3oool2000000040?ooo`000000oooo0000
00/0oooo0P00003o0?ooool0oooo1P3oool002@0oooo0`00000N0?ooo`030000003oool0000000/0
oooo0P00003o0?ooool0oooo1@3oool00240oooo0`00000E0?ooo`L000001P3oool00`000000oooo
0000000:0?ooo`800000o`3ooooo0?ooo`D0oooo000N0?ooo`<000005P3oool2000000h0oooo00<0
00000?ooo`0000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo103oool001/0oooo0`00000I
0?ooo`8000003`3oool010000000oooo0000000000030?ooo`@00000o`3ooooo0?ooo`L0oooo000H
0?ooo`<000001@3oool4000001@0oooo0P00000?0?ooo`80000000@0oooo0000000000000000o`3o
oooo0?ooo`/0oooo000E0?ooo`<000001P3oool3000000<0oooo0`00000B0?ooo`800000403oool0
0`000000oooo0000003o0?ooool0oooo303oool00180oooo0`0000000`3oool000000?ooo`070?oo
o`8000001P3oool4000000l0oooo0P00000@0?ooo`030000003oool000000?l0ooooo`3oool;0?oo
o`003P3oool4000000@0oooo00<000000?ooo`3oool0403oool4000000h0oooo0P00000@0?ooo`03
0000003oool000000?l0ooooo`3oool:0?ooo`002`3oool3000001`0oooo00<000000?ooo`3oool0
0P00000=0?ooo`8000000`3oool2000000/0oooo00<000000?ooo`000000o`3ooooo0?ooo`T0oooo
00080?ooo`<000007`3oool2000000<0oooo0P00000<0?ooo`@000003@3oool200000?l0ooooo`3o
ool:0?ooo`001@3oool300000280oooo0P0000050?ooo`800000203oool200000080oooo0P00000;
0?ooo`800000o`3ooooo0?ooo``0oooo00020?ooo`<000009P3oool00`000000oooo0?ooo`050?oo
o`8000000P3oool2000000L0oooo0P00003o0?ooool0oooo603oool0008000004`3oool2000001@0
oooo0P0000080?ooo`8000002P3oool200000?l0ooooo`3ooolG0?ooo`004P3oool3000001H0oooo
0P0000060?ooo`8000003@3oool200000?l0ooooo`3ooolF0?ooo`00403oool3000000030?ooo`00
0000oooo01H0oooo1000003o0?ooool0oooo:P3oool001<0oooo00<000000?ooo`0000005P3oool2
00000?l0ooooo`3oool/0?ooo`00503oool00`000000oooo000000080?ooo`H000001@3oool20000
0?l0ooooo`3oool^0?ooo`005@3oool3000000<0oooo100000060?ooo`800000o`3ooooo0?oooc<0
oooo000G0?ooo`@000002`3oool300000?l0ooooo`3ooola0?ooo`00603oool3000000`0oooo0P00
003o0?ooool0oooo<@3oool001T0oooo00<000000?ooo`000000303oool00`000000oooo0?ooo`3o
0?ooool0oooo;`3oool001X0oooo00<000000?ooo`0000002P3oool00`000000oooo0?ooo`3o0?oo
ool0oooo<03oool001/0oooo0`0000070?ooo`800000o`3ooooo0?oooc<0oooo000M0?ooo`800000
0`3oool300000?l0ooooo`3ooole0?ooo`007P3oool400000?l0ooooo`3ooolh0?ooo`00703oool2
00000?l0ooooo`3oooll0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0oooo
o`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?oo
o`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {209.25, 0}} -> {0.0480717, 0.300688, \
0.0017152, 0.0017152}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(fontThickness = 2;\)\), "\n", 
    \(\(stringDisplay["\<ABCDEFGHIJKLMNOPQRSTUVWXYZ\>"];\)\), "\n", 
    \(\(stringDisplay["\<abcdefghijklmnopqrstuvwxyz\>"];\)\), "\n", 
    \(\(stringDisplay[FromCharacterCode[Range[945, 969]]];\)\), "\n", 
    \(\(stringDisplay[
        FromCharacterCode[Range[913, 937]]];\)\), "\[IndentingNewLine]", 
    \(\(fontThickness = 1;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34571 
%%ImageSize: 600 207.426 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0517421 1.05174 -0.342426 1.05174 [
[.16183 .25043 -8.4562 -9 ]
[.16183 .25043 9.5438 0 ]
[.46313 .15296 -2.99349 -9 ]
[.46313 .15296 3.00651 0 ]
[.78732 .04812 -6.37838 -9 ]
[.78732 .04812 5.62162 0 ]
[.46158 .08778 -4.98746 -12.75 ]
[.46158 .08778 5.01254 0 ]
[.9949 .00237 0 -5.94781 ]
[.9949 .00237 24 3.05219 ]
[1.00205 .01278 0 -5.94151 ]
[1.00205 .01278 6 3.05849 ]
[1.00914 .02313 0 -5.93527 ]
[1.00914 .02313 18 3.06473 ]
[1.06386 -0.00842 0 -8.41812 ]
[1.06386 -0.00842 10 4.33188 ]
[ 0 0 0 0 ]
[ 1 .34571 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00051 .31534 m
.978 0 L
s
.16104 .26355 m
.16064 .27011 L
s
[(-10)] .16183 .25043 -0.06042 1 Mshowa
.4631 .1661 m
.46309 .17268 L
s
[(0)] .46313 .15296 -0.00217 1 Mshowa
.78815 .06124 m
.78857 .0678 L
s
[(10)] .78732 .04812 .06306 1 Mshowa
.125 Mabswid
.21973 .24462 m
.21954 .24855 L
s
.27926 .22541 m
.27911 .22935 L
s
.33966 .20593 m
.33955 .20987 L
s
.40093 .18616 m
.40088 .1901 L
s
.52619 .14575 m
.52623 .14969 L
s
.59022 .1251 m
.59031 .12904 L
s
.65521 .10413 m
.65535 .10807 L
s
.72118 .08285 m
.72137 .08679 L
s
.10317 .28222 m
.10289 .28615 L
s
.04611 .30063 m
.04578 .30456 L
s
.85615 .03931 m
.85645 .04324 L
s
.9252 .01703 m
.92556 .02096 L
s
gsave
.46158 .08778 -65.9875 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.978 0 m
.99938 .03114 L
s
.98239 .0064 m
.97613 .00841 L
s
[(-0.5)] .9949 .00237 -1 .32174 Mshowa
.98953 .0168 m
.98327 .0188 L
s
[(0)] 1.00205 .01278 -1 .32034 Mshowa
.99662 .02712 m
.99035 .02912 L
s
[(0.5)] 1.00914 .02313 -1 .31895 Mshowa
.125 Mabswid
.98382 .00848 m
.98007 .00969 L
s
.98525 .01056 m
.9815 .01177 L
s
.98668 .01264 m
.98292 .01385 L
s
.9881 .01472 m
.98435 .01593 L
s
.99095 .01887 m
.98719 .02007 L
s
.99237 .02093 m
.98861 .02214 L
s
.99379 .023 m
.99003 .0242 L
s
.9952 .02506 m
.99145 .02626 L
s
.98095 .00431 m
.9772 .00552 L
s
.97952 .00222 m
.97577 .00343 L
s
.97808 .00012 m
.97433 .00133 L
s
.99803 .02918 m
.99427 .03037 L
s
gsave
1.06386 -0.00842 -61 -12.4181 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34571 L
0 .34571 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.06259 .33134 m
.05182 .30863 L
s
.06259 .33134 m
.03008 .31562 L
s
.05951 .32861 m
.05026 .30913 L
s
.08118 .32542 m
.09985 .31948 L
s
.08584 .32394 m
.06429 .30462 L
s
.08739 .32345 m
.06585 .30412 L
s
.0394 .32013 m
.05336 .31566 L
s
.09985 .31948 m
.10196 .31757 L
s
.09985 .31948 m
.10352 .31707 L
s
.10196 .31757 m
.1025 .31616 L
s
.10352 .31707 m
.10407 .31566 L
s
.02698 .31662 m
.03627 .31363 L
s
.1025 .31616 m
.10203 .31382 L
s
.10407 .31566 m
.1036 .31332 L
s
.07718 .31428 m
.08966 .31029 L
s
.10203 .31382 m
.1 .31198 L
s
.1036 .31332 m
.10156 .31148 L
s
.1 .31198 m
.0964 .31063 L
s
.12074 .31159 m
.11558 .31075 L
s
.12645 .31102 m
.12074 .31159 L
s
.10156 .31148 m
.09796 .31013 L
s
.12231 .31109 m
.11714 .31025 L
s
.12645 .31102 m
.12231 .31109 L
s
.1296 .31002 m
.12645 .31102 L
s
.11558 .31075 m
.11198 .3094 L
s
.0964 .31063 m
.09381 .31021 L
s
.04559 .31063 m
.05493 .30763 L
s
.08966 .31029 m
.09177 .30836 L
s
.08966 .31029 m
.09333 .30786 L
s
.09381 .31021 m
.08966 .31029 L
s
.09538 .30971 m
.08966 .31029 L
s
.11714 .31025 m
.11355 .3089 L
s
.09796 .31013 m
.09538 .30971 L
s
.1333 .30759 m
.1296 .31002 L
s
.11198 .3094 m
.10736 .30713 L
s
.11355 .3089 m
.10893 .30663 L
s
.09177 .30836 m
.09231 .30694 L
s
.09333 .30786 m
.09388 .30644 L
s
.13444 .30474 m
.1333 .30759 L
s
.10736 .30713 m
.10227 .3025 L
s
.13903 .30702 m
.13444 .30474 L
s
.13298 .30145 m
.13903 .30702 L
s
.09231 .30694 m
.09183 .30458 L
s
.10893 .30663 m
.10384 .302 L
s
.09388 .30644 m
.0934 .30408 L
s
.07837 .3001 m
.05961 .30613 L
s
.13444 .30474 m
.13298 .30145 L
s
.09183 .30458 m
.08876 .3018 L
s
.0934 .30408 m
.09033 .3013 L
s
.14849 .30401 m
.16431 .29897 L
s
.15323 .3025 m
.13201 .28286 L
s
.10227 .3025 m
.10077 .29921 L
s
.15481 .302 m
.1336 .28235 L
s
.10384 .302 m
.10234 .2987 L
s
.08876 .3018 m
.08513 .30045 L
s
.09033 .3013 m
.0867 .29994 L
s
.08513 .30045 m
.08254 .30002 L
s
.08254 .30002 m
.07837 .3001 L
s
.08411 .29952 m
.07837 .3001 L
s
.0867 .29994 m
.08411 .29952 L
s
.10077 .29921 m
.1003 .29684 L
s
.16431 .29897 m
.16648 .29703 L
s
.16431 .29897 m
.16806 .29653 L
s
.10234 .2987 m
.10187 .29633 L
s
.16648 .29703 m
.16765 .29416 L
s
.1003 .29684 m
.1014 .29396 L
s
.16806 .29653 m
.16924 .29365 L
s
.10187 .29633 m
.10297 .29346 L
s
.16765 .29416 m
.16724 .29178 L
s
.1014 .29396 m
.1051 .29151 L
s
.16924 .29365 m
.16882 .29127 L
s
.10297 .29346 m
.1051 .29151 L
s
.18177 .29342 m
.20731 .28529 L
s
.11922 .29077 m
.12284 .29213 L
s
.18655 .2919 m
.16549 .2721 L
s
.16724 .29178 m
.16582 .28846 L
s
.1051 .29151 m
.10826 .29049 L
s
.18814 .29139 m
.16709 .27158 L
s
.16882 .29127 m
.16741 .28795 L
s
.11402 .28991 m
.11922 .29077 L
s
.10826 .29049 m
.11402 .28991 L
s
.16582 .28846 m
.16079 .28376 L
s
.16741 .28795 m
.16238 .28325 L
s
.20136 .27964 m
.20571 .2858 L
s
.20731 .28529 m
.20136 .27964 L
s
.14314 .27928 m
.12725 .28439 L
s
.16079 .28376 m
.15617 .28145 L
s
.16238 .28325 m
.15776 .28093 L
s
.21532 .28274 m
.24107 .27455 L
s
.19175 .2827 m
.18375 .27514 L
s
.17816 .282 m
.18775 .27893 L
s
.15617 .28145 m
.15255 .28007 L
s
.22014 .28121 m
.19925 .26125 L
s
.15776 .28093 m
.15415 .27956 L
s
.22174 .2807 m
.20086 .26073 L
s
.15255 .28007 m
.14734 .2792 L
s
.15415 .27956 m
.14893 .27869 L
s
.14734 .2792 m
.14314 .27928 L
s
.14893 .27869 m
.14314 .27928 L
s
.23516 .26885 m
.23945 .27506 L
s
.24107 .27455 m
.23516 .26885 L
s
.16069 .27364 m
.18636 .26539 L
s
.22548 .27194 m
.21754 .26432 L
s
.21184 .27123 m
.22151 .26814 L
s
.19238 .27111 m
.18475 .26591 L
s
.18636 .26539 m
.19238 .27111 L
s
.25626 .26845 m
.25106 .26758 L
s
.2621 .26786 m
.25626 .26845 L
s
.25788 .26794 m
.25268 .26706 L
s
.2621 .26786 m
.25788 .26794 L
s
.26535 .26682 m
.2621 .26786 L
s
.25106 .26758 m
.24748 .26619 L
s
.25268 .26706 m
.2491 .26567 L
s
.26925 .26432 m
.26535 .26682 L
s
.24748 .26619 m
.2429 .26384 L
s
.2491 .26567 m
.24452 .26332 L
s
.27055 .26137 m
.26925 .26432 L
s
.2429 .26384 m
.23797 .25905 L
s
.2751 .26372 m
.27055 .26137 L
s
.26925 .25797 m
.2751 .26372 L
s
.24452 .26332 m
.23959 .25853 L
s
.19441 .26281 m
.20571 .25917 L
s
.27055 .26137 m
.26925 .25797 L
s
.28651 .26009 m
.29795 .25645 L
s
.23797 .25905 m
.23662 .25565 L
s
.29141 .25853 m
.27088 .23823 L
s
.23959 .25853 m
.23824 .25513 L
s
.29304 .25801 m
.27252 .2377 L
s
.23662 .25565 m
.23626 .25321 L
s
.23824 .25513 m
.23789 .25268 L
s
.25586 .25333 m
.26728 .24967 L
s
.30778 .25333 m
.31927 .24967 L
s
.23626 .25321 m
.23753 .25023 L
s
.23789 .25268 m
.23916 .24971 L
s
.26075 .25176 m
.25286 .24402 L
s
.3127 .25176 m
.29228 .23135 L
s
.26238 .25124 m
.25449 .2435 L
s
.31434 .25124 m
.29393 .23082 L
s
.23753 .25023 m
.24143 .24769 L
s
.23916 .24971 m
.24143 .24769 L
s
.28331 .24838 m
.30302 .24208 L
s
.24143 .24769 m
.24469 .24665 L
s
.32586 .24757 m
.3374 .2439 L
s
.25058 .24604 m
.25582 .24693 L
s
.24469 .24665 m
.25058 .24604 L
s
.3308 .246 m
.31048 .2255 L
s
.33245 .24548 m
.31214 .22497 L
s
.26596 .23981 m
.27746 .23612 L
s
.35064 .23969 m
.36225 .23599 L
s
.35561 .23811 m
.33929 .22144 L
s
.35727 .23758 m
.34095 .2209 L
s
.36724 .23441 m
.3789 .2307 L
s
.28733 .23294 m
.29889 .22923 L
s
.37223 .23282 m
.35213 .21212 L
s
.3739 .23229 m
.3538 .21158 L
s
.38892 .22751 m
.39896 .22431 L
s
.30551 .2271 m
.31711 .22337 L
s
.33124 .22661 m
.33193 .22509 L
s
.32861 .22616 m
.33124 .22661 L
s
.32667 .22419 m
.32861 .22616 L
s
.39561 .22538 m
.36149 .21951 L
s
.33193 .22509 m
.3293 .22464 L
s
.3264 .22169 m
.32667 .22419 L
s
.40567 .22218 m
.41744 .21844 L
s
.32875 .21963 m
.3264 .22169 L
s
.33929 .22144 m
.33472 .21901 L
s
.37201 .22132 m
.37395 .2051 L
s
.34095 .2209 m
.33639 .21848 L
s
.37368 .22078 m
.37563 .20456 L
s
.41071 .22058 m
.39081 .19969 L
s
.41239 .22004 m
.3925 .19914 L
s
.33208 .21856 m
.32875 .21963 L
s
.33472 .21901 m
.33208 .21856 L
s
.33639 .21848 m
.33208 .21856 L
s
.34711 .21373 m
.35883 .20996 L
s
.43599 .21253 m
.44276 .21038 L
s
.44107 .21092 m
.43326 .18604 L
s
.44107 .21092 m
.42133 .18988 L
s
.44276 .21038 m
.43609 .18908 L
s
.3689 .20673 m
.379 .20348 L
s
.46483 .20336 m
.47164 .20119 L
s
.46483 .20336 m
.44522 .1822 L
s
.46483 .20336 m
.43326 .18604 L
s
.46653 .20281 m
.44694 .18165 L
s
.38574 .20131 m
.41113 .19315 L
s
.41682 .19918 m
.40944 .1937 L
s
.41113 .19315 m
.41682 .19918 L
s
.47847 .19902 m
.4853 .19684 L
s
.48359 .19739 m
.46409 .17613 L
s
.4853 .19684 m
.48835 .17098 L
s
.48346 .19483 m
.48649 .16893 L
s
.50072 .19194 m
.51103 .18866 L
s
.41623 .19152 m
.42644 .18823 L
s
.50587 .1903 m
.48649 .16893 L
s
.44009 .18385 m
.45207 .18 L
s
.52563 .1827 m
.52036 .18177 L
s
.53173 .18207 m
.52563 .1827 L
s
.52736 .18215 m
.52208 .18122 L
s
.53173 .18207 m
.52736 .18215 L
s
.53519 .18097 m
.53173 .18207 L
s
.52036 .18177 m
.5168 .18029 L
s
.52208 .18122 m
.51853 .17974 L
s
.53774 .17885 m
.53519 .18097 L
s
.53947 .1783 m
.53519 .18097 L
s
.5168 .18029 m
.51141 .17677 L
s
.51853 .17974 m
.51314 .17622 L
s
.53939 .17571 m
.53774 .17885 L
s
.54113 .17516 m
.53947 .1783 L
s
.45894 .17779 m
.46925 .17448 L
s
.51141 .17677 m
.50865 .17371 L
s
.51314 .17622 m
.51038 .17316 L
s
.53931 .17311 m
.53939 .17571 L
s
.54105 .17256 m
.54113 .17516 L
s
.556 .17435 m
.57691 .16769 L
s
.50865 .17371 m
.5067 .16906 L
s
.51038 .17316 m
.50843 .16851 L
s
.53741 .16846 m
.53931 .17311 L
s
.56122 .17269 m
.54215 .15105 L
s
.53915 .16791 m
.54105 .17256 L
s
.56296 .17213 m
.5439 .15048 L
s
.5067 .16906 m
.50658 .16645 L
s
.50843 .16851 m
.50832 .1659 L
s
.53467 .16538 m
.53741 .16846 L
s
.53641 .16483 m
.53915 .16791 L
s
.57691 .16769 m
.57951 .16555 L
s
.57691 .16769 m
.58126 .165 L
s
.50658 .16645 m
.5082 .16328 L
s
.50832 .1659 m
.50994 .16273 L
s
.57951 .16555 m
.58036 .16397 L
s
.52927 .16182 m
.53467 .16538 L
s
.58126 .165 m
.58211 .16341 L
s
.53101 .16127 m
.53641 .16483 L
s
.58036 .16397 m
.58032 .16135 L
s
.58211 .16341 m
.58207 .16079 L
s
.5082 .16328 m
.51249 .16058 L
s
.50994 .16273 m
.51249 .16058 L
s
.52569 .16032 m
.52927 .16182 L
s
.58032 .16135 m
.57763 .15826 L
s
.52744 .15976 m
.53101 .16127 L
s
.56701 .15636 m
.55301 .16084 L
s
.58207 .16079 m
.57938 .1577 L
s
.51249 .16058 m
.51597 .15946 L
s
.52037 .15937 m
.52569 .16032 L
s
.52211 .15881 m
.52744 .15976 L
s
.51597 .15946 m
.52037 .15937 L
s
.51597 .15946 m
.52211 .15881 L
s
.60231 .1583 m
.59701 .15735 L
s
.60847 .15765 m
.60231 .1583 L
s
.57763 .15826 m
.57407 .15675 L
s
.60407 .15774 m
.59877 .15679 L
s
.60847 .15765 m
.60407 .15774 L
s
.57938 .1577 m
.57582 .15619 L
s
.61199 .15653 m
.60847 .15765 L
s
.59701 .15735 m
.59346 .15584 L
s
.59877 .15679 m
.59522 .15528 L
s
.57407 .15675 m
.57142 .15627 L
s
.61463 .15438 m
.61199 .15653 L
s
.61639 .15381 m
.61199 .15653 L
s
.57142 .15627 m
.56701 .15636 L
s
.57317 .15571 m
.56701 .15636 L
s
.57582 .15619 m
.57317 .15571 L
s
.59346 .15584 m
.58812 .15226 L
s
.59522 .15528 m
.58988 .1517 L
s
.61638 .15118 m
.61463 .15438 L
s
.61815 .15061 m
.61639 .15381 L
s
.5369 .15273 m
.54916 .14879 L
s
.58812 .15226 m
.58542 .14914 L
s
.58988 .1517 m
.58719 .14858 L
s
.61638 .14853 m
.61638 .15118 L
s
.61814 .14797 m
.61815 .15061 L
s
.63318 .14979 m
.65447 .14302 L
s
.58542 .14914 m
.58358 .14441 L
s
.58719 .14858 m
.58535 .14384 L
s
.61459 .1438 m
.61638 .14853 L
s
.63849 .1481 m
.61986 .12607 L
s
.61636 .14324 m
.61814 .14797 L
s
.64026 .14754 m
.62165 .1255 L
s
.58358 .14441 m
.58354 .14175 L
s
.58535 .14384 m
.58531 .14119 L
s
.61191 .14067 m
.61459 .1438 L
s
.61368 .1401 m
.61636 .14324 L
s
.65447 .14302 m
.65715 .14084 L
s
.65447 .14302 m
.65893 .14027 L
s
.59064 .14215 m
.59507 .14206 L
s
.58707 .14062 m
.59064 .14215 L
s
.59507 .14206 m
.59684 .14149 L
s
.58354 .14175 m
.58527 .13853 L
s
.59684 .14149 m
.59948 .13931 L
s
.58531 .14119 m
.58704 .13796 L
s
.65715 .14084 m
.65806 .13923 L
s
.60657 .13704 m
.61191 .14067 L
s
.58617 .13957 m
.58707 .14062 L
s
.65893 .14027 m
.65984 .13866 L
s
.60834 .13647 m
.61368 .1401 L
s
.59948 .13931 m
.59946 .13665 L
s
.65806 .13923 m
.65809 .13656 L
s
.65984 .13866 m
.65987 .13599 L
s
.58527 .13853 m
.58967 .13577 L
s
.58704 .13796 m
.58967 .13577 L
s
.64568 .13253 m
.63144 .13709 L
s
.603 .13551 m
.60657 .13704 L
s
.59946 .13665 m
.59763 .13187 L
s
.59946 .13665 m
.59493 .12871 L
s
.65809 .13656 m
.65633 .13446 L
s
.60477 .13494 m
.60834 .13647 L
s
.65987 .13599 m
.65812 .13389 L
s
.58967 .13577 m
.59321 .13464 L
s
.59766 .13455 m
.603 .13551 L
s
.59943 .13398 m
.60477 .13494 L
s
.59321 .13464 m
.59766 .13455 L
s
.59321 .13464 m
.59943 .13398 L
s
.67678 .13459 m
.67146 .13363 L
s
.68302 .13393 m
.67678 .13459 L
s
.65633 .13446 m
.65279 .13293 L
s
.64033 .13424 m
.64301 .13205 L
s
.68839 .13222 m
.68302 .13393 L
s
.65812 .13389 m
.65458 .13236 L
s
.67146 .13363 m
.66972 .13152 L
s
.65279 .13293 m
.65013 .13244 L
s
.65013 .13244 m
.64568 .13253 L
s
.65191 .13187 m
.64568 .13253 L
s
.65458 .13236 m
.65191 .13187 L
s
.6929 .12946 m
.68839 .13222 L
s
.64301 .13205 m
.64303 .12937 L
s
.64301 .13205 m
.64391 .13043 L
s
.59763 .13187 m
.5976 .12919 L
s
.66972 .13152 m
.67155 .12827 L
s
.66972 .13152 m
.66976 .12884 L
s
.64391 .13043 m
.64308 .1213 L
s
.69477 .1262 m
.6929 .12946 L
s
.64303 .12937 m
.6404 .12082 L
s
.5976 .12919 m
.59848 .12757 L
s
.66976 .12884 m
.67067 .12722 L
s
.69916 .1288 m
.69396 .12245 L
s
.69477 .1262 m
.69916 .1288 L
s
.59493 .12871 m
.5958 .12708 L
s
.60293 .12748 m
.60383 .12854 L
s
.67155 .12827 m
.67426 .12607 L
s
.61452 .12779 m
.627 .12378 L
s
.59848 .12757 m
.60025 .127 L
s
.60025 .127 m
.60293 .12748 L
s
.59935 .12594 m
.60293 .12748 L
s
.67067 .12722 m
.67339 .12501 L
s
.5958 .12708 m
.59935 .12594 L
s
.69396 .12245 m
.69477 .1262 L
s
.67426 .12607 m
.68329 .12051 L
s
.70815 .12594 m
.73524 .11732 L
s
.70297 .11958 m
.70815 .12594 L
s
.70995 .12537 m
.70297 .11958 L
s
.67339 .12501 m
.68242 .11945 L
s
.72077 .12192 m
.70262 .09947 L
s
.72257 .12135 m
.70444 .09889 L
s
.64308 .1213 m
.64398 .11967 L
s
.66095 .12095 m
.65565 .11457 L
s
.6601 .11719 m
.66095 .12095 L
s
.6404 .12082 m
.6413 .11918 L
s
.64845 .11958 m
.64934 .12064 L
s
.68329 .12051 m
.68602 .11829 L
s
.64398 .11967 m
.64577 .11909 L
s
.64489 .11803 m
.64845 .11958 L
s
.64577 .11909 m
.64845 .11958 L
s
.68242 .11945 m
.68515 .11723 L
s
.6413 .11918 m
.64489 .11803 L
s
.68602 .11829 m
.68695 .11665 L
s
.73011 .11092 m
.73343 .1179 L
s
.73524 .11732 m
.73011 .11092 L
s
.68515 .11723 m
.68701 .11395 L
s
.65565 .11457 m
.6601 .11719 L
s
.66193 .1139 m
.6601 .11719 L
s
.68695 .11665 m
.68701 .11395 L
s
.74249 .11501 m
.75521 .11096 L
s
.68701 .11395 m
.68351 .10967 L
s
.66645 .1111 m
.66193 .1139 L
s
.74794 .11328 m
.73512 .09718 L
s
.74975 .1127 m
.73694 .0966 L
s
.67186 .10936 m
.66645 .1111 L
s
.68351 .10967 m
.67815 .10869 L
s
.67815 .10869 m
.67186 .10936 L
s
.76796 .10691 m
.77893 .10342 L
s
.76074 .08897 m
.77344 .10516 L
s
.78442 .10167 m
.79542 .09817 L
s
.69718 .10122 m
.70989 .09714 L
s
.78808 .1005 m
.78327 .07355 L
s
.78992 .09992 m
.78581 .07684 L
s
.73512 .09718 m
.73437 .09335 L
s
.73694 .0966 m
.73619 .09277 L
s
.80645 .09466 m
.81751 .09114 L
s
.73437 .09335 m
.7363 .09001 L
s
.73619 .09277 m
.73813 .08942 L
s
.81382 .09232 m
.78327 .07355 L
s
.7363 .09001 m
.74093 .08716 L
s
.82121 .08997 m
.83415 .08585 L
s
.73813 .08942 m
.74093 .08716 L
s
.75634 .0863 m
.76074 .08897 L
s
.82675 .0882 m
.81669 .06281 L
s
.8286 .08761 m
.82088 .06833 L
s
.74093 .08716 m
.7446 .08598 L
s
.75096 .0853 m
.75634 .0863 L
s
.7446 .08598 m
.75096 .0853 L
s
.84157 .08349 m
.83163 .05801 L
s
.84157 .08349 m
.81669 .06281 L
s
.84342 .0829 m
.83579 .06355 L
s
.85086 .08053 m
.86202 .07698 L
s
.85644 .07876 m
.83163 .05801 L
s
.86575 .07579 m
.87696 .07223 L
s
.86949 .0746 m
.87673 .04352 L
s
.87135 .07401 m
.87862 .04291 L
s
.8882 .06865 m
.89946 .06507 L
s
.8957 .06626 m
.85224 .05139 L
s
.90322 .06387 m
.91452 .06028 L
s
.90698 .06267 m
.91135 .04622 L
s
.90887 .06207 m
.91325 .04562 L
s
.92774 .05607 m
.9391 .05245 L
s
.93531 .05366 m
.91325 .04562 L
s
.84849 .05259 m
.85977 .04897 L
s
.9467 .05004 m
.97337 .04155 L
s
.94194 .04333 m
.9467 .05004 L
s
.9486 .04943 m
.94194 .04333 L
s
.91135 .04622 m
.90326 .03499 L
s
.91325 .04562 m
.90516 .03438 L
s
.87107 .04534 m
.8824 .04169 L
s
.97146 .04216 m
.92994 .02642 L
s
.97337 .04155 m
.93185 .0258 L
s
.89756 .03682 m
.91086 .03255 L
s
.92994 .02642 m
.95678 .01779 L
s
.96155 .02462 m
.95486 .01841 L
s
.95678 .01779 m
.96155 .02462 L
s
0 g
.25 Mabswid
.00051 .31534 m
.978 0 L
s
.16104 .26355 m
.16064 .27011 L
s
[(-10)] .16183 .25043 -0.06042 1 Mshowa
.4631 .1661 m
.46309 .17268 L
s
[(0)] .46313 .15296 -0.00217 1 Mshowa
.78815 .06124 m
.78857 .0678 L
s
[(10)] .78732 .04812 .06306 1 Mshowa
.125 Mabswid
.21973 .24462 m
.21954 .24855 L
s
.27926 .22541 m
.27911 .22935 L
s
.33966 .20593 m
.33955 .20987 L
s
.40093 .18616 m
.40088 .1901 L
s
.52619 .14575 m
.52623 .14969 L
s
.59022 .1251 m
.59031 .12904 L
s
.65521 .10413 m
.65535 .10807 L
s
.72118 .08285 m
.72137 .08679 L
s
.10317 .28222 m
.10289 .28615 L
s
.04611 .30063 m
.04578 .30456 L
s
.85615 .03931 m
.85645 .04324 L
s
.9252 .01703 m
.92556 .02096 L
s
gsave
.46158 .08778 -65.9875 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 207.375},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cb000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooD@3oool2000000L0oooo003o0?ooool0ooooDP3oool00`000000oooo0?ooo`05
0?ooo`00o`3ooooo0?oooe<0oooo00<000000?ooo`3oool0103oool00?l0ooooo`3ooomB0?ooo`03
0000003oool0000000D0oooo003o0?ooool0ooooD@3oool010000000oooo0?ooo`0000050?ooo`00
o`3ooooo0?oooe00oooo0`0000000`3oool00000000000040?ooo`00o`3ooooo0?oooeX0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo0P00000L0?oo
o`00o`3ooooo0?ooobl0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`00000K
0?ooo`00o`3ooooo0?oooah0oooo0P00000?0?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`3oool06@3oool00?l0ooooo`3ooolK0?ooo`@0000000<0oooo0000003oool01`3oool40000
0080oooo00@000000?ooo`3oool000002@3oool2000001`0oooo003o0?ooool0oooo603oool30000
00<0oooo0`00000>0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool06`3oool0
0?l0ooooo`3ooolE0?ooo`<000001`3oool3000000`0oooo1000000:0?ooo`<000006`3oool00?l0
ooooo`3ooolB0?ooo`<000002`3oool3000000X0oooo00@000000?ooo`3oool00000:@3oool00?l0
ooooo`3oool>0?ooo`@00000303oool200000080oooo0P0000090?ooo`040000003oool0oooo0000
02T0oooo003o0?ooool0oooo2`3oool300000180oooo0P0000000`3oool000000?ooo`080?ooo`04
0000003oool0oooo000002T0oooo003o0?ooool0oooo203oool3000001H0oooo0P0000000`3oool0
00000?ooo`070?ooo`040000003oool0oooo000002T0oooo003o0?ooool0oooo1@3oool3000001X0
oooo100000080?ooo`800000:P3oool00?l0ooooo`3oool20?ooo`<000003@3oool2000000h0oooo
0P0000000`3oool000000?ooo`0;0?ooo`800000103oool2000000@0oooo0P00000J0?ooo`00o`3o
ooon0?ooo`@000003@3oool5000000h0oooo0P0000000`3oool000000?ooo`090?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000006@3oool00?l0oooon`3oool3000000<0oooo
00<000000?ooo`3oool0203oool8000000d0oooo00<000000?ooo`0000000`0000090?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`3oool05`3oool00?l0oooon03oool3000000H0oooo
00<000000?ooo`3oool01@3oool700000080oooo0`00000?0?ooo`<000002@3oool010000000oooo
0?ooo`0000090?ooo`8000006P3oool00?l0oooom@3oool3000000`0oooo00<000000?ooo`000000
1P0000060?ooo`<000004@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo000000T0
oooo00<000000?ooo`3oool06@3oool00?l0oooolP3oool3000000h0oooo1`00000:0?ooo`<00000
3P3oool4000000P0oooo0P00000:0?ooo`<000006@3oool00?l0ooook`3oool300000100oooo2000
000;0?ooo`030000003oool0oooo00d0oooo1@00000_0?ooo`00o`3oooo[0?ooo`@00000503oool:
000001P0oooo0P0000020?ooo`030000003oool0oooo02d0oooo003o0?ooonP0oooo0`00000>0?oo
o`030000003oool0oooo00X0oooo2@00000H0?ooo`80000000<0oooo0000003oool0;@3oool00?l0
ooooi@3oool3000000h0oooo1@00000>0?ooo`T00000A`3oool00?l0oooo[`3oool500000080oooo
0P00000Z0?ooo`<000003`3oool600000180oooo200000150?ooo`00o`3ooona0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0T0?ooo`<000003`3oool7000001H0oooo
2@0000120?ooo`00o`3ooona0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0Q0?ooo`<000004@3oool9000001P0oooo200000100?ooo`00o`3ooona0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0N0?ooo`<000003@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo0`00000K0?ooo`P00000?@3oool00?l0oooo/@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06`3oool300000080oooo
00<000000?ooo`3oool0203oool5000000`0oooo0`00000@0?ooo`030000003oool0oooo00X0oooo
1P00000l0?ooo`00o`3ooon`0?ooo`800000103oool2000001/0oooo0`0000050?ooo`030000003o
ool0oooo00D0oooo1`00000=0?ooo`@000003P3oool3000000T0oooo1`00000m0?ooo`00o`3oooo@
0?ooo`<000003`3oool600000100oooo1@00000=0?ooo`<000001P3oool600000400oooo003o0?oo
old0oooo0`00000C0?ooo`030000003oool0000000800000403oool8000000/0oooo0`0000020?oo
o`H00000@`3oool00?l0oooob@3oool4000000d0oooo100000070?ooo`<00000403oool300000003
0?ooo`000000000000@000002P3oool8000004D0oooo003o0?ooolH0oooo0`00000=0?ooo`P00000
1P3oool400000100oooo0`0000040?ooo`H000000`3oool010000000oooo0?ooo`3oool5000004P0
oooo003o0?oool<0oooo0`00000@0?ooo`H00000203oool300000140oooo0`0000060?ooo`T00000
0`3oool2000004X0oooo003o0?oool00oooo0`00000E0?ooo`L000001@3oool300000100oooo0`00
00080?ooo`L00000D03oool00?l0oooo_@3oool3000000d0oooo00<000000?ooo`3oool02`3oool7
00000080oooo0`00000@0?ooo`<000001`3oool600000580oooo003o0?oookX0oooo0`00000?0?oo
o`<000003`3oool900000100oooo0`0000080?ooo`030000003oool0oooo05@0oooo003o0?oookL0
oooo0`00000C0?ooo`<000004@3oool7000000l0oooo0`0000000`3oool000000?ooo`1L0?ooo`00
o`3ooond0?ooo`<000003P3oool00`000000oooo0?ooo`050?ooo`@000004P3oool8000000`0oooo
1P00001L0?ooo`00o`3ooona0?ooo`<0000000<0oooo0000003oool03@3oool3000000H0oooo1P00
000@0?ooo`<0000000<0oooo0000000000001@0000040?ooo`030000003oool0oooo00L00000G@3o
ool00?l0oooo[P3oool3000000@0oooo00<000000?ooo`3oool03@3oool3000000H0oooo1P00000?
0?ooo`<00000103oool?00000600oooo003o0?oooj/0oooo0`0000070?ooo`030000003oool0oooo
00d0oooo1@0000040?ooo`<0000000@0oooo00000000000000003@3oool4000000H0oooo1`000002
0?ooo`030000003oool0oooo0640oooo003o0?ooojL0oooo1000000:0?ooo`030000003oool0oooo
00d0oooo1P0000030?ooo`@0000000@0oooo0000000000000000303oool3000000H0oooo1P00001X
0?ooo`00o`3ooonT0?ooo`<000007`3oool6000000<0oooo0`0000020?ooo`<000002`3oool30000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0JP3oool00?l0ooooX@3oool3000000h0
oooo00<000000?ooo`3oool04@3oool3000000040?ooo`000000000000000080oooo0`0000030?oo
o`@000002@3oool600000740oooo003l0?ooo`80000000<0oooo000000000000W03oool300000100
oooo1000000A0?ooo`@0000000@0oooo00000000000000000P3oool3000000<0oooo100000060?oo
o`L00000LP3oool00?d0oooo00<000000?ooo`000000VP3oool3000001@0oooo1000000A0?ooo`<0
00000P3oool3000000040?ooo`0000000000000000D0oooo0`0000030?ooo`H00000M@3oool00?h0
oooo00<000000?ooo`3oool0UP3oool3000001L0oooo1P00000?0?ooo`<000000`3oool7000000D0
oooo2000001h0?ooo`00o03oool2000000030?ooo`000000000009<0oooo0`00000J0?ooo`P00000
3P3oool3000000<0oooo1P0000040?ooo`L00000NP3oool00?l0ooooTP3oool3000001d0oooo1000
00000`3oool0000000000002000000d0oooo0`0000050?ooo`@000000`3oool5000007d0oooo003o
0?ooohl0oooo0`00000>0?ooo`030000003oool0oooo0100oooo0`0000030?ooo`@000002`3oool4
000000D0oooo100000030?ooo`030000003oool0oooo07h0oooo003o0?oooh`0oooo0`0000000`3o
ool000000?ooo`090?ooo`030000003oool0000000H000003`3oool3000000@0oooo1@00000:0?oo
o`<000001P3oool2000008D0oooo003o0?ooohT0oooo0`0000040?ooo`030000003oool0oooo00H0
oooo3P00000<0?ooo`<000001P3oool5000000P0oooo1P00002:0?ooo`00o`3ooon50?ooo`@00000
3`3oool6000000D0oooo1@00000;0?ooo`<00000203oool4000000D0oooo2000002:0?ooo`00o`3o
oon20?ooo`<000004P3oool4000000/0oooo0P00000;0?ooo`@000002@3oool4000000030?ooo`00
0000oooo00D00000S@3oool00?l0ooooO`3oool3000001D0oooo0`00000=0?ooo`8000002P3oool4
000000X0oooo1P00002B0?ooo`00o`3oooml0?ooo`<000005`3oool3000000l0oooo0P00000:0?oo
o`<00000203oool7000009<0oooo003o0?ooogT0oooo0`00000>0?ooo`030000003oool0oooo00T0
oooo1000000?0?ooo`030000003oool0oooo00P0oooo0`0000070?ooo`D00000UP3oool00?l0oooo
MP3oool3000000d0oooo1@00000;0?ooo`@000003`3oool2000000T0oooo0`0000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0U`3oool00?l0ooooL`3oool3000000`0oooo2000
000<0?ooo`D000003`3oool2000000P0oooo1P00002O0?ooo`00o`3ooom`0?ooo`<000003P3oool9
000000h0oooo1000000?0?ooo`8000000`3oool00`000000oooo0000000600000:00oooo003o0?oo
ofd0oooo0`00000A0?ooo`030000003oool0oooo00<0oooo0`00000?0?ooo`@000003`3oool80000
00030?ooo`00000000000:80oooo003o0?ooofX0oooo0`00000K0?ooo`<000003`3oool3000000d0
oooo1`00002X0?ooo`00o`3ooomW0?ooo`<0000000<0oooo0000003oool02`3oool00`000000oooo
0?ooo`0>0?ooo`<000003`3oool3000000/0oooo1@00002[0?ooo`00o`3ooomS0?ooo`@00000103o
ool00`000000oooo0?ooo`060?ooo`P000003@3oool4000000h0oooo1000000;0?ooo`030000003o
ool0oooo0:`0oooo003o0?ooof00oooo0`00000>0?ooo``000003@3oool4000000L0oooo00<00000
0?ooo`3oool0103oool400000;T0oooo003o0?oooed0oooo0`00000?0?ooo`H000001P3oool30000
00d0oooo100000050?ooo`<000001P3oool700000;D0oooo003o0?oooeX0oooo0`00000>0?ooo`03
0000003oool0oooo00@000002P3oool3000000d0oooo0`0000060?ooo`<00000103oool800000;D0
oooo003o0?oooeL0oooo0`00000<0?ooo`040000003oool0oooo0?ooo`H00000303oool2000000l0
oooo0`0000060?ooo`<000000`3oool500000;P0oooo003o0?oooe@0oooo0`00000=0?ooo`D00000
0P3oool5000000X0oooo1@0000070?ooo`030000003oool0oooo00@0oooo100000040?ooo`D00000
_`3oool00?l0ooooD@3oool3000000l0oooo1`0000020?ooo`<000002@3oool6000000L0oooo0`00
00060?ooo`/00000`03oool00?l0ooooCP3oool300000140oooo1`0000040?ooo`<000001`3oool6
000000@0oooo00<000000?ooo`3oool00P3oool3000000H0oooo1`0000330?ooo`00o`3ooom;0?oo
o`<000005@3oool3000000030?ooo`000000000000@0oooo0P0000060?ooo`L00000103oool30000
00@0oooo0`0000020?ooo`L00000aP3oool00?l0ooooA`3oool4000000030?ooo`000000000000X0
oooo1@0000060?ooo`<000003P3oool6000000H0oooo100000040?ooo`T00000b03oool00?l0oooo
A@3oool300000080oooo1@0000060?ooo`P000001P3oool3000000h0oooo1@0000070?ooo`D00000
0`3oool500000<`0oooo003o0?oood40oooo100000020?ooo`T000001@3oool7000000P0oooo0P00
000<0?ooo`D000002@3oool6000000<0oooo0P00003>0?ooo`00o`3oooln0?ooo`<000001P3oool9
000000T0oooo0`0000080?ooo`<0000000D0oooo000000000000oooo000000060?ooo`<000002@3o
ool400000080oooo00<000000?ooo`3oool0dP3oool00?l0oooo>`3oool3000000`0oooo0`00000=
0?ooo`<000001P3oool;000000@0oooo0`0000060?ooo`H00000f03oool00?l0oooo>03oool30000
00`0oooo00<000000?ooo`0000001P00000:0?ooo`@00000103oool=000000<0oooo3@00003J0?oo
o`00o`3ooole0?ooo`<000003P3oool<000000T0oooo300000030?ooo`H00000103oool800000=d0
oooo003o0?oooc80oooo0`00000@0?ooo`h000002@3oool6000000X0oooo0`0000070?ooo`800000
h@3oool00?l0oooo0P00000]0?ooo`<000004P3oool4000000<0oooo0`0000020?ooo`D00000203o
ool4000000/0oooo1000003Y0?ooo`00oP3oool010000000oooo0?ooo`00000Y0?ooo`<000005@3o
ool5000000040?ooo`0000000000000000@0oooo1P0000070?ooo`<000002P3oool400000>X0oooo
003n0?ooo`040000003oool0oooo000002H0oooo0`00000G0?ooo`T000001`3oool5000000L0oooo
0`0000060?ooo`H00000j`3oool00?h0oooo00@000000?ooo`3oool000008`3oool3000001X0oooo
0`0000000`3oool0000000000002000000T0oooo100000070?ooo`@000000P3oool700000>d0oooo
003n0?ooo`040000003oool0oooo00000200oooo0`00000M0?ooo`@000003P3oool3000000P0oooo
2@00003`0?ooo`00o`3oool2000001d0oooo100000000`3oool000000?ooo`080?ooo`030000003o
ool0oooo01<0oooo0`00000>0?ooo`@000001P3oool700000?<0oooo003o0?oooa`0oooo0`000005
0?ooo`030000003oool0oooo00H0oooo1@00000B0?ooo`@000003@3oool3000000H0oooo1P00003e
0?ooo`00o`3ooolI0?ooo`<000003P3oool8000001<0oooo1000000<0?ooo`@000001P3oool00`00
0000oooo0?ooo`3g0?ooo`00o`3ooolF0?ooo`<000004@3oool7000000d0oooo00<000000?ooo`3o
ool01@3oool5000000T0oooo1000003o0?ooo`80oooo003o0?oooa<0oooo0`00000H0?ooo`@00000
203oool6000000030?ooo`000000oooo00@0oooo1P0000040?ooo`030000003oool0000000<00000
o`3oool30?ooo`00o`3oool@0?ooo`<000002`3oool00`000000oooo0?ooo`02000000`0oooo1000
00040?ooo``000001P3oool=00000?l0oooo103oool00?l0oooo3@3oool3000000`0oooo2`000008
0?oooaD000001`3oool900000?l0oooo1P3oool00?l0oooo2P3oool3000000h0oooo3@0000080?oo
o`L000002@3oool5000000T0oooo00<000000?ooo`3oool0o`3oool90?ooo`00o`3oool70?ooo`<0
0000403oool3000000L0oooo1P0000070?ooo`D000002`3oool300000?l0oooo5P3oool00?l0oooo
103oool300000180oooo0`00000:0?ooo`D000001`3oool4000000/0oooo1000003o0?oooaD0oooo
003o0?ooo`40oooo0`00000D0?ooo`<00000303oool5000000L0oooo100000090?ooo`@00000o`3o
oolF0?ooo`00o03oool5000000`0oooo00<000000?ooo`3oool01`3oool4000000d0oooo10000007
0?ooo`@000001@3oool600000?l0oooo5`3oool00?T0oooo0`0000040?ooo`030000003oool0oooo
00T0oooo0`0000080?ooo`@000003P3oool3000000L0oooo1@0000000`3oool00000000000050000
0?l0oooo6@3oool00?H0oooo0`0000070?ooo`030000003oool0oooo00T0oooo100000070?ooo`@0
00003P3oool3000000P0oooo2@00003o0?oooa`0oooo003c0?ooo`<000002P3oool010000000oooo
0?ooo`0000080?ooo`D000001`3oool4000000d0oooo100000060?ooo`L00000o`3ooolO0?ooo`00
l03oool3000000d0oooo1@0000070?ooo`H000001`3oool4000000`0oooo0`0000060?ooo`D00000
o`3ooolR0?ooo`00k@3oool3000000h0oooo1P0000080?ooo`<0000000@0oooo0000000000000000
1`3oool4000000/0oooo0`0000070?ooo`030000003oool0oooo0?l0oooo8`3oool00>X0oooo0`00
000@0?ooo`H000002@3oool300000080oooo0P0000080?ooo`D0000000<0oooo0000003oool01@3o
ool400000?l0oooo;@3oool00>L0oooo0`00000<0?ooo`D000000`3oool00`000000oooo0?ooo`03
000000P0oooo0`0000030?ooo`800000203oool800000080oooo1@00003o0?ooobh0oooo003T0?oo
o`<00000303oool8000000L0oooo0`0000060?ooo`@000000`3oool3000000T0oooo2`00003o0?oo
oc00oooo003Q0?ooo`<000002`3oool010000000oooo0?ooo`3oool7000000T0oooo0`0000050?oo
o`<000001@3oool3000000T0oooo2000003o0?oooc80oooo003M0?ooo`@000002`3oool00`000000
oooo00000003000000D0oooo100000090?ooo`<00000103oool3000000H0oooo0`00003o0?oood80
oooo003J0?ooo`@000002`3oool5000000030?ooo`000000000000<00000103oool4000000T0oooo
0`0000030?ooo`<000001`3oool300000?l0oooo@@3oool00=L0oooo0`0000030?ooo`030000003o
ool0oooo00H0oooo1`0000020?ooo`H00000103oool4000000T0oooo0`0000020?ooo`<000001`3o
ool600000?l0oooo?P3oool00=@0oooo0`00000;0?ooo`80000000<0oooo0000000000001@000003
0?ooo`P000000`3oool4000000T0oooo0`000000103oool000000000000000060?ooo`L00000o`3o
ooln0?ooo`00d@3oool3000000`0oooo1@0000000`3oool000000?ooo`020?ooo`<000000`3oool3
000000030?ooo`000000000000<000000P3oool4000000T0oooo1P0000060?ooo`050000003oool0
oooo0?ooo`000000o`3ooom00?ooo`00cP3oool3000000`0oooo2@0000050?ooo`<000000P3oool4
00000080oooo2P0000090?ooo`D00000o`3ooom;0?ooo`00b`3oool3000000/0oooo00<000000?oo
o`0000001@0000020?ooo`@000001@3oool3000000030?ooo`000000000000800000103oool90000
00L0oooo1P00003o0?oood/0oooo00380?ooo`<000003@3oool6000000L0oooo0`0000050?ooo`80
00000P3oool3000000H0oooo200000050?ooo`H00000o`3ooom<0?ooo`00a@3oool3000000d0oooo
1`00000:0?ooo`030000003oool0oooo00D0oooo0P0000000`3oool0000000000002000000L0oooo
1`0000020?ooo`030000003oool000000?l0ooooD@3oool00<80oooo0`00000<0?ooo`030000003o
ool0oooo00T000004@3oool3000000040?ooo`0000000000000000P0oooo2@00003o0?oooe<0oooo
002o0?ooo`<00000303oool500000080oooo00@000000?ooo`3oool0oooo1@00000A0?ooo`H00000
2P3oool600000?l0ooooE03oool00;`0oooo0`00000=0?ooo`H00000203oool500000140oooo1P00
000:0?ooo`800000o`3ooomG0?ooo`00^03oool4000000X0oooo00<000000?ooo`3oool00P3oool5
000000/0oooo1000000B0?ooo`D00000o`3ooomS0?ooo`00]@3oool3000000<0oooo00<000000?oo
o`3oool01@3oool5000000@0oooo00@000000?ooo`0000000000303oool400000180oooo1000003o
0?ooof<0oooo002b0?ooo`<000002`3oool7000000L0oooo0P00000=0?ooo`@00000403oool60000
0?l0ooooHP3oool00:l0oooo0`00000=0?ooo`L000001`3oool3000000h0oooo1000000>0?ooo`H0
0000o`3ooomS0?ooo`00[03oool300000140oooo00<000000?ooo`000000100000060?ooo`<00000
3`3oool4000000d0oooo00<000000?ooo`3oool0o`3ooomV0?ooo`00Z@3oool3000000/0oooo00@0
00000?ooo`0000000000203oool5000000D0oooo0`00000@0?ooo`@00000o`3ooome0?ooo`00YP3o
ool3000000d0oooo1`0000070?ooo`D00000103oool300000140oooo1`00003o0?ooog40oooo002S
0?ooo`<000003P3oool:000000L0oooo2P00000A0?ooo`P00000o`3oooma0?ooo`00X03oool30000
00`0oooo00@000000?ooo`3oool0oooo100000030?ooo`D000001`3oool?000000L0oooo00@00000
0?ooo`3oool0oooo1@00003o0?ooog@0oooo002M0?ooo`<000002`3oool600000080oooo0`000005
0?ooo`D000001`3oool5000000030?ooo`000000oooo00l00000o`3ooomk0?ooo`00VP3oool30000
00`0oooo1`0000030?ooo`D00000103oool5000000P0oooo100000080?ooo`P00000o`3oooml0?oo
o`00UP3oool5000000X0oooo00<000000?ooo`3oool01`0000060?ooo`@00000103oool4000000T0
oooo100000080?ooo`@00000o`3ooomo0?ooo`00T`3oool3000000@0oooo00<000000?ooo`3oool0
103oool600000080oooo00<000000?ooo`3oool0100000060?ooo`8000001P3oool4000000T0oooo
100000020?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3ooomo0?ooo`00T03o
ool3000000`0oooo1`0000070?ooo`@000003P3oool4000000T0oooo1`00003o0?ooohH0oooo002=
0?ooo`<000003P3oool7000000T0oooo1000000>0?ooo`@000001`3oool700000?l0ooooQ`3oool0
08X0oooo0`00000<0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0100000090?oo
o`D000003@3oool4000000<0oooo00<000000?ooo`0000001@00003o0?ooohT0oooo001H0?ooo`D0
00000P3oool2000002H0oooo0`00000;0?ooo`H00000203oool4000000T0oooo1@00000=0?ooo`P0
000000<0oooo0000003oool0o`3ooon<0?ooo`00FP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0803oool3000000`0oooo1`00000:0?ooo`@000002P3oool4000000`0
oooo1`00003o0?oooi00oooo001J0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0M0?ooo`<000003P3oool7000000`0oooo1@0000090?ooo`@000002P3oool500000?l0
ooooT`3oool00580oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0J0?ooo`<000002P3oool2000000H0oooo00<000000?ooo`3oool01000000:0?ooo`L0
00002@3oool400000080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oooi@0
oooo001J0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0G0?ooo`<0
0000303oool4000000T0oooo100000060?ooo`/000002@3oool700000?l0ooooW@3oool005T0oooo
0P0000040?ooo`8000005`3oool3000000X0oooo00<000000?ooo`0000001`0000090?ooo`@00000
0`3oool6000000<0oooo1@0000070?ooo`L00000o`3ooonN0?ooo`00M03oool4000000030?ooo`00
0000oooo00T0oooo3@0000020?ooo`030000003oool0oooo00<0oooo2@0000070?ooo`D000000P3o
ool00`000000oooo0?ooo`0600000?l0ooooX03oool00740oooo0`0000050?ooo`030000003oool0
oooo00L0oooo1@0000050?ooo`P000001@3oool6000000X0oooo200000020?ooo`030000003oool0
oooo0?l0ooooXP3oool006h0oooo0`00000A0?ooo`<00000203oool7000000P0oooo1000000:0?oo
o`L00000o`3ooonX0?ooo`00J`3oool3000001<0oooo0`0000080?ooo`H000002`3oool4000000P0
oooo1P00003o0?ooojX0oooo001X0?ooo`<000005`3oool2000000T0oooo00@000000?ooo`3oool0
00003@3oool400000080oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00003o0?oo
oj/0oooo001U0?ooo`<000006P3oool300000100oooo00<000000?ooo`3oool01`3oool700000?l0
oooo/`3oool00680oooo0`00000<0?ooo`030000003oool0oooo00h0oooo1000000>0?ooo`<00000
1`3oool700000?l0oooo]03oool005l0oooo0`00000<0?ooo`D000003`3oool5000000d0oooo1000
00050?ooo`H00000o`3ooonf0?ooo`00G03oool3000000`0oooo1`0000060?ooo`030000003oool0
oooo00L0oooo1P00000<0?ooo`D000001@3oool00`000000oooo0?ooo`3o0?oookP0oooo001I0?oo
o`<000002P3oool200000080oooo200000050?ooo`<000002P3oool6000000T0oooo1`00003o0?oo
okl0oooo001F0?ooo`@000002P3oool500000080oooo00@000000?ooo`3oool0oooo100000050?oo
o`<000002`3oool6000000D0oooo1@0000020?ooo`030000003oool0oooo0?l0oooo_P3oool00580
oooo100000020?ooo`030000003oool0oooo00H0oooo2@0000060?ooo`@000001@3oool2000000L0
oooo00<000000?ooo`3oool00P3oool=00000?l0ooooa@3oool004l0oooo0`0000060?ooo`030000
003oool0oooo00<0oooo1`0000020?ooo`@000001P3oool;000000D0oooo0`0000040?ooo`/00000
o`3oooo60?ooo`00C03oool3000000T0oooo00<000000?ooo`3oool01`0000070?ooo`<000001P3o
ool;000000D0oooo0`0000070?ooo`800000o`3oooo;0?ooo`00B@3oool3000000`0oooo1`000006
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool4000000@0oooo0P000006
0?ooo`<00000o`3ooooC0?ooo`00AP3oool3000000h0oooo200000050?ooo`<000003@3oool40000
00@0oooo00<000000?ooo`3oool00`3oool500000?l0oooodP3oool004<0oooo0`00000<0?ooo`03
0000003oool0oooo00<0oooo00@000000?ooo`3oool0oooo1@0000040?ooo`<000003@3oool40000
00H0oooo1`00003o0?ooom<0oooo00100?ooo`<00000303oool7000000L0oooo1@0000040?ooo`<0
00001P3oool00`000000oooo0?ooo`040?ooo`@000000`3oool600000?l0ooooeP3oool003d0oooo
0`0000090?ooo`030000003oool0oooo00`000001P3oool<000000@0oooo0`0000060?ooo`T00000
o`3ooooI0?ooo`00>@3oool4000000/0oooo4P0000050?ooo``00000103oool3000000D0oooo1`00
003o0?ooom/0oooo000g0?ooo`<00000303oool7000000T0oooo1@0000050?ooo`D00000103oool3
000000@0oooo0`0000030?ooo`D00000o`3ooooN0?ooo`00=03oool3000000030?ooo`000000oooo
00/0oooo2000000<0?ooo`<000001P3oool5000000<0oooo00<000000?ooo`3oool00P3oool50000
00<0oooo00<000000?ooo`3oool0o`3ooooO0?ooo`00<03oool4000000@0oooo00<000000?ooo`3o
ool02`3oool010000000oooo0?ooo`3oool4000000`0oooo0`0000060?ooo`D00000103oool70000
0?l0ooooiP3oool002d0oooo0`00000;0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool01P3oool4000000`0oooo0`0000060?ooo`D0000000<0oooo0000000000001000003o0?ooonT0
oooo000Z0?ooo`<000003@3oool;000000L0oooo1@00000:0?ooo`@000001P3oool800000?l0oooo
k03oool002L0oooo0`00000>0?ooo`h000001`3oool5000000T0oooo0`0000060?ooo`L00000o`3o
ooo^0?ooo`00903oool300000100oooo100000090?ooo`030000003oool0oooo00L0oooo1@000008
0?ooo`<000001@3oool500000?l0ooool@3oool00240oooo0`00000B0?ooo`@000005@3oool50000
00L0oooo100000050?ooo`030000003oool0oooo0?l0oooolP3oool001h0oooo0`00000:0?ooo`04
0000003oool0oooo0?ooo`8000001@3oool3000001L0oooo1@0000050?ooo`@00000o`3ooook0?oo
o`006`3oool3000000X0oooo2`0000030?ooo`@000003`3oool00`000000oooo0?ooo`050?ooo``0
0000o`3ooool0?ooo`00603oool3000000/0oooo3P0000020?ooo`D000003@3oool3000000L0oooo
2@00003o0?ooooh0oooo000E0?ooo`<0000000<0oooo0000003oool0203oool6000000P0oooo0`00
00030?ooo`D000003@3oool3000000D0oooo1@00003o0?ooool0oooo103oool00180oooo0`000004
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P00000:0?ooo`<00000103oool5
000000`0oooo100000040?ooo`040000003oool0oooo00000?l0ooooo`3oool50?ooo`003P3oool4
000000T0oooo3000000;0?ooo`<00000103oool6000000T0oooo1P00003o0?ooool0oooo303oool0
00/0oooo0`00000;0?ooo`H000000P3oool00`000000oooo0?ooo`05000000P0oooo1P0000040?oo
o`H000001@3oool400000080oooo00<000000?ooo`3oool0o`3ooooo0?ooo`/0oooo00080?ooo`<0
00003@3oool6000000L0oooo1@0000040?ooo`/000001@3oool;00000?l0ooooo`3ooolA0?ooo`00
1@3oool3000000`0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`02000000T0oooo
4`0000050?ooo`T00000o`3ooooo0?oooa80oooo00020?ooo`<000002P3oool6000000L0oooo0`00
00090?ooo`H000002@3oool4000000H0oooo0P00003o0?ooool0oooo5`3oool0008000002`3oool7
000000D0oooo1P00000:0?ooo`@000002P3oool300000?l0ooooo`3ooolP0?ooo`003@3oool20000
00030?ooo`000000000000h000002P3oool5000000P0oooo1000003o0?ooool0oooo7`3oool00180
oooo1`0000040?ooo`<000002`3oool5000000@0oooo1P00003o0?ooool0oooo803oool001@0oooo
1@0000050?ooo`8000003@3oool;00000?l0ooooo`3ooolR0?ooo`005P3oool5000000<0oooo0`00
000;0?ooo`P00000o`3ooooo0?ooobH0oooo000H0?ooo`D000000P3oool2000000/0oooo1@00003o
0?ooool0oooo:@3oool001X0oooo2000003o0?ooool0oooo>03oool001`0oooo1P00003o0?ooool0
oooo>03oool001h0oooo1@00003o0?ooool0oooo=`3oool00200oooo1000003o0?ooool0oooo=P3o
ool00280oooo00<000000?ooo`3oool0o`3ooooo0?ooocD0oooo003o0?ooool0ooooFP3oool00?l0
ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ
0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00001\
\>"],
  ImageRangeCache->{{{0, 599}, {206.375, 0}} -> {0.0491916, 0.301489, \
0.00171738, 0.00171738}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35 
%%ImageSize: 600 210.001 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0507744 1.05077 -0.339506 1.05077 [
[.12796 .26047 -8.39439 -9 ]
[.12796 .26047 9.60561 0 ]
[.45857 .15337 -2.99046 -9 ]
[.45857 .15337 3.00954 0 ]
[.81711 .03727 -6.41697 -9 ]
[.81711 .03727 5.58303 0 ]
[.45971 .08739 -4.98504 -12.75 ]
[.45971 .08739 5.01496 0 ]
[.99308 .00563 0 -5.9478 ]
[.99308 .00563 24 3.0522 ]
[1.00095 .01709 0 -5.94083 ]
[1.00095 .01709 6 3.05917 ]
[1.00875 .02847 0 -5.93393 ]
[1.00875 .02847 18 3.06607 ]
[1.06176 -0.00547 0 -8.41834 ]
[1.06176 -0.00547 10 4.33166 ]
[ 0 0 0 0 ]
[ 1 .35 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00056 .31445 m
.97395 0 L
s
.12708 .27357 m
.12664 .28013 L
s
[(-10)] .12796 .26047 -0.06729 1 Mshowa
.45853 .1665 m
.45851 .17307 L
s
[(0)] .45857 .15337 -0.00318 1 Mshowa
.81802 .05037 m
.81847 .05692 L
s
[(10)] .81711 .03727 .06949 1 Mshowa
.125 Mabswid
.19129 .25283 m
.19107 .25677 L
s
.25651 .23176 m
.25634 .2357 L
s
.32277 .21036 m
.32266 .2143 L
s
.3901 .18861 m
.39004 .19255 L
s
.52807 .14404 m
.52812 .14798 L
s
.59877 .1212 m
.59886 .12514 L
s
.67063 .09798 m
.67079 .10192 L
s
.74371 .07438 m
.74392 .07831 L
s
.06387 .29399 m
.06356 .29792 L
s
.00163 .3141 m
.00127 .31802 L
s
.8936 .02596 m
.89393 .02988 L
s
.97048 .00112 m
.97087 .00504 L
s
gsave
.45971 .08739 -65.985 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97395 0 m
.99931 .03694 L
s
.98058 .00965 m
.97433 .01166 L
s
[(-0.5)] .99308 .00563 -1 .32173 Mshowa
.98844 .0211 m
.98218 .0231 L
s
[(0)] 1.00095 .01709 -1 .32019 Mshowa
.99623 .03246 m
.98998 .03445 L
s
[(0.5)] 1.00875 .02847 -1 .31865 Mshowa
.125 Mabswid
.98216 .01195 m
.9784 .01315 L
s
.98373 .01424 m
.97998 .01545 L
s
.9853 .01653 m
.98155 .01774 L
s
.98687 .01882 m
.98312 .02002 L
s
.99 .02338 m
.98625 .02458 L
s
.99156 .02565 m
.98781 .02685 L
s
.99312 .02793 m
.98937 .02912 L
s
.99468 .03019 m
.99093 .03139 L
s
.979 .00735 m
.97525 .00856 L
s
.97742 .00505 m
.97367 .00626 L
s
.97583 .00274 m
.97208 .00395 L
s
.97425 .00043 m
.9705 .00164 L
s
.99779 .03472 m
.99403 .03591 L
s
gsave
1.06176 -0.00547 -61 -12.4183 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35 L
0 .35 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.04812 .33063 m
.05266 .33055 L
s
.04529 .33018 m
.04812 .33063 L
s
.05266 .33055 m
.05947 .32838 L
s
.08271 .33051 m
.08955 .32834 L
s
.04415 .32917 m
.04529 .33018 L
s
.04699 .32963 m
.04585 .32863 L
s
.04585 .32863 m
.04415 .32917 L
s
.08784 .32888 m
.06412 .30764 L
s
.05947 .32838 m
.06175 .32629 L
s
.08955 .32834 m
.06583 .30709 L
s
.06175 .32629 m
.06232 .32474 L
s
.03959 .32515 m
.03561 .32369 L
s
.04584 .32453 m
.03959 .32515 L
s
.06232 .32474 m
.0521 .31565 L
s
.06232 .32474 m
.06177 .32217 L
s
.0413 .32461 m
.03731 .32314 L
s
.04584 .32453 m
.0413 .32461 L
s
.05722 .32226 m
.04584 .32453 L
s
.03561 .32369 m
.03332 .32167 L
s
.03731 .32314 m
.03502 .32112 L
s
.06006 .32272 m
.05722 .32226 L
s
.06177 .32217 m
.05381 .3151 L
s
.03332 .32167 m
.03273 .3191 L
s
.03502 .32112 m
.03444 .31856 L
s
.08399 .31919 m
.08855 .3191 L
s
.07831 .31826 m
.08399 .31919 L
s
.03273 .3191 m
.03671 .31645 L
s
.08855 .3191 m
.09198 .31801 L
s
.03444 .31856 m
.03671 .31645 L
s
.09198 .31801 m
.0943 .3159 L
s
.09198 .31801 m
.09602 .31535 L
s
.03671 .31645 m
.04183 .3148 L
s
.0943 .3159 m
.09549 .31277 L
s
.04639 .31472 m
.0521 .31565 L
s
.0521 .31565 m
.05153 .31307 L
s
.09602 .31535 m
.09721 .31222 L
s
.05381 .3151 m
.05324 .31252 L
s
.04183 .3148 m
.04639 .31472 L
s
.05153 .31307 m
.05381 .31095 L
s
.09549 .31277 m
.09384 .30917 L
s
.05324 .31252 m
.05381 .31095 L
s
.09721 .31222 m
.09556 .30862 L
s
.05381 .31095 m
.05553 .3104 L
s
.07041 .307 m
.06925 .31014 L
s
.09384 .30917 m
.09158 .30713 L
s
.11672 .30874 m
.11102 .30781 L
s
.12303 .30811 m
.11672 .30874 L
s
.09556 .30862 m
.09331 .30658 L
s
.11845 .30819 m
.11275 .30726 L
s
.12303 .30811 m
.11845 .30819 L
s
.12822 .30645 m
.12303 .30811 L
s
.11102 .30781 m
.10593 .3053 L
s
.11275 .30726 m
.10766 .30475 L
s
.09158 .30713 m
.08647 .30462 L
s
.07272 .30487 m
.07041 .307 L
s
.09331 .30658 m
.08819 .30407 L
s
.13058 .30432 m
.12822 .30645 L
s
.10593 .3053 m
.10368 .30326 L
s
.07617 .30377 m
.07272 .30487 L
s
.10766 .30475 m
.10541 .3027 L
s
.08647 .30462 m
.08075 .30368 L
s
.13182 .30116 m
.13058 .30432 L
s
.08819 .30407 m
.08248 .30313 L
s
.08075 .30368 m
.07617 .30377 L
s
.08248 .30313 m
.07617 .30377 L
s
.10368 .30326 m
.10203 .29963 L
s
.10541 .3027 m
.10376 .29907 L
s
.17075 .30253 m
.17774 .30031 L
s
.13008 .30172 m
.12723 .30125 L
s
.12723 .30125 m
.12785 .29967 L
s
.1307 .30014 m
.13182 .30116 L
s
.17599 .30087 m
.15274 .27916 L
s
.17774 .30031 m
.1545 .2786 L
s
.12785 .29967 m
.1307 .30014 L
s
.10203 .29963 m
.10324 .29646 L
s
.10376 .29907 m
.10497 .2959 L
s
.15145 .29766 m
.14574 .29672 L
s
.1578 .29702 m
.15145 .29766 L
s
.1532 .2971 m
.14749 .29616 L
s
.1578 .29702 m
.1532 .2971 L
s
.16129 .2959 m
.1578 .29702 L
s
.14574 .29672 m
.14066 .29419 L
s
.10324 .29646 m
.10732 .29376 L
s
.14749 .29616 m
.14241 .29363 L
s
.16368 .29376 m
.16129 .2959 L
s
.10497 .2959 m
.10732 .29376 L
s
.14066 .29419 m
.13843 .29212 L
s
.10732 .29376 m
.11079 .29264 L
s
.16497 .29057 m
.16368 .29376 L
s
.14241 .29363 m
.14017 .29156 L
s
.11714 .29199 m
.12287 .29294 L
s
.11079 .29264 m
.11714 .29199 L
s
.13843 .29212 m
.13682 .28846 L
s
.14017 .29156 m
.13857 .2879 L
s
.13682 .28846 m
.13808 .28527 L
s
.13857 .2879 m
.13983 .28471 L
s
.18648 .28648 m
.18076 .28553 L
s
.19286 .28583 m
.18648 .28648 L
s
.18824 .28592 m
.18252 .28497 L
s
.19286 .28583 m
.18824 .28592 L
s
.19815 .28414 m
.19286 .28583 L
s
.18076 .28553 m
.17569 .28298 L
s
.13808 .28527 m
.14221 .28254 L
s
.18252 .28497 m
.17745 .28241 L
s
.13983 .28471 m
.14221 .28254 L
s
.20058 .28198 m
.19815 .28414 L
s
.22766 .28306 m
.22372 .28155 L
s
.23229 .28298 m
.22766 .28306 L
s
.23229 .28298 m
.22943 .2825 L
s
.23583 .28185 m
.23229 .28298 L
s
.17569 .28298 m
.17348 .2809 L
s
.14221 .28254 m
.14572 .28142 L
s
.22943 .2825 m
.22549 .28098 L
s
.17745 .28241 m
.17524 .28033 L
s
.17745 .28241 m
.19863 .27564 L
s
.15035 .28133 m
.15609 .28228 L
s
.20015 .27933 m
.20058 .28198 L
s
.20125 .28038 m
.20058 .28198 L
s
.23652 .28024 m
.23583 .28185 L
s
.22372 .28155 m
.20401 .26269 L
s
.14572 .28142 m
.15035 .28133 L
s
.22549 .28098 m
.20579 .26211 L
s
.17348 .2809 m
.17192 .2772 L
s
.23475 .28081 m
.23189 .28033 L
s
.20082 .27773 m
.20125 .28038 L
s
.17524 .28033 m
.17368 .27664 L
s
.23189 .28033 m
.23258 .27873 L
s
.23544 .2792 m
.23652 .28024 L
s
.19686 .2762 m
.20015 .27933 L
s
.23258 .27873 m
.23544 .2792 L
s
.15274 .27916 m
.15977 .2769 L
s
.21405 .27907 m
.22823 .27455 L
s
.19863 .27564 m
.20082 .27773 L
s
.17192 .2772 m
.17322 .27398 L
s
.17368 .27664 m
.17499 .27341 L
s
.17322 .27398 m
.17741 .27123 L
s
.17499 .27341 m
.17741 .27123 L
s
.17741 .27123 m
.18095 .2701 L
s
.18736 .26944 m
.19312 .2704 L
s
.18095 .2701 m
.18736 .26944 L
s
.24495 .26782 m
.24099 .26629 L
s
.24495 .26782 m
.24208 .26734 L
s
.2496 .26773 m
.24495 .26782 L
s
.25317 .26659 m
.2496 .26773 L
s
.28039 .26769 m
.28756 .26541 L
s
.24208 .26734 m
.23812 .2658 L
s
.25567 .2644 m
.25317 .26659 L
s
.24099 .26629 m
.23664 .26207 L
s
.28577 .26598 m
.26313 .24369 L
s
.23812 .2658 m
.23594 .2637 L
s
.28756 .26541 m
.26493 .24311 L
s
.25529 .26172 m
.25567 .2644 L
s
.25637 .26277 m
.25567 .2644 L
s
.19867 .2644 m
.21113 .2604 L
s
.23594 .2637 m
.23555 .26101 L
s
.26283 .26211 m
.25925 .26326 L
s
.25925 .26326 m
.26391 .26317 L
s
.25637 .26277 m
.25925 .26326 L
s
.26391 .26317 m
.26283 .26211 L
s
.256 .26009 m
.25637 .26277 L
s
.23664 .26207 m
.23624 .25938 L
s
.25095 .25749 m
.25529 .26172 L
s
.23555 .26101 m
.23267 .26053 L
s
.23555 .26101 m
.23624 .25938 L
s
.23267 .26053 m
.2287 .25899 L
s
.25383 .25797 m
.256 .26009 L
s
.23624 .25938 m
.23873 .25718 L
s
.2287 .25899 m
.2276 .25793 L
s
.24987 .25643 m
.25383 .25797 L
s
.2276 .25793 m
.22829 .25629 L
s
.2276 .25793 m
.2272 .25523 L
s
.24699 .25594 m
.25095 .25749 L
s
.23873 .25718 m
.24231 .25603 L
s
.24699 .25594 m
.24987 .25643 L
s
.22829 .25629 m
.23257 .25351 L
s
.24231 .25603 m
.24699 .25594 L
s
.28259 .25581 m
.28906 .25515 L
s
.27683 .25484 m
.28259 .25581 L
s
.2272 .25523 m
.23147 .25245 L
s
.28906 .25515 m
.29267 .254 L
s
.22431 .25475 m
.23078 .25408 L
s
.22032 .2532 m
.22431 .25475 L
s
.29267 .254 m
.29521 .25178 L
s
.29267 .254 m
.29701 .2512 L
s
.23257 .25351 m
.24153 .25063 L
s
.32618 .25174 m
.32543 .25338 L
s
.32543 .25338 m
.32256 .25289 L
s
.21922 .25213 m
.22032 .2532 L
s
.32256 .25289 m
.32331 .25125 L
s
.23147 .25245 m
.24044 .24956 L
s
.21881 .24943 m
.21922 .25213 L
s
.29521 .25178 m
.29487 .24907 L
s
.32331 .25125 m
.32618 .25174 L
s
.29701 .2512 m
.29668 .2485 L
s
.24153 .25063 m
.24583 .24783 L
s
.24044 .24956 m
.24474 .24676 L
s
.22308 .24663 m
.21881 .24943 L
s
.29487 .24907 m
.28302 .23729 L
s
.29668 .2485 m
.28484 .23671 L
s
.24583 .24783 m
.24544 .24511 L
s
.31256 .24765 m
.31982 .24534 L
s
.24474 .24676 m
.24544 .24511 L
s
.23386 .24315 m
.22308 .24663 L
s
.34799 .2448 m
.34722 .24645 L
s
.34722 .24645 m
.34435 .24596 L
s
.34435 .24596 m
.34512 .24431 L
s
.318 .24592 m
.30302 .23087 L
s
.25772 .24543 m
.27035 .24137 L
s
.31982 .24534 m
.30484 .23028 L
s
.24544 .24511 m
.24435 .24404 L
s
.34512 .24431 m
.34799 .2448 L
s
.24435 .24404 m
.24036 .24248 L
s
.24036 .24248 m
.23386 .24315 L
s
.35816 .24297 m
.36547 .24065 L
s
.36364 .24123 m
.34145 .21852 L
s
.33437 .2407 m
.34166 .23837 L
s
.36547 .24065 m
.34329 .21793 L
s
.27759 .23904 m
.29028 .23496 L
s
.33984 .23895 m
.32065 .21947 L
s
.34166 .23837 m
.32248 .21888 L
s
.29755 .23262 m
.31031 .22853 L
s
.39852 .23015 m
.4059 .2278 L
s
.37096 .22902 m
.38201 .2255 L
s
.40405 .22839 m
.3821 .20546 L
s
.4059 .2278 m
.38395 .20486 L
s
.37648 .22726 m
.34754 .22229 L
s
.35913 .22428 m
.36172 .212 L
s
.36097 .22369 m
.36357 .21141 L
s
.31332 .22183 m
.31408 .22015 L
s
.31041 .22133 m
.31332 .22183 L
s
.30934 .22024 m
.31041 .22133 L
s
.33594 .22029 m
.34881 .21615 L
s
.31009 .21856 m
.30934 .22024 L
s
.31408 .22015 m
.31117 .21965 L
s
.32065 .21947 m
.31666 .21788 L
s
.32248 .21888 m
.3185 .21729 L
s
.31375 .21738 m
.31009 .21856 L
s
.31666 .21788 m
.31375 .21738 L
s
.3185 .21729 m
.31375 .21738 L
s
.41159 .21606 m
.41902 .21369 L
s
.41716 .21429 m
.40257 .19888 L
s
.35619 .21378 m
.36727 .21022 L
s
.41902 .21369 m
.40443 .19828 L
s
.42171 .21141 m
.42833 .21072 L
s
.41591 .2104 m
.42171 .21141 L
s
.42833 .21072 m
.43206 .20954 L
s
.43206 .20954 m
.43475 .20725 L
s
.43206 .20954 m
.43662 .20665 L
s
.37653 .20725 m
.38953 .20307 L
s
.43475 .20725 m
.43456 .20445 L
s
.43662 .20665 m
.43643 .20385 L
s
.44223 .20486 m
.44887 .20417 L
s
.43643 .20385 m
.44223 .20486 L
s
.43456 .20445 m
.42314 .19227 L
s
.44887 .20417 m
.45262 .20298 L
s
.43643 .20385 m
.42501 .19167 L
s
.45262 .20298 m
.45534 .20068 L
s
.45262 .20298 m
.45722 .20008 L
s
.39698 .20068 m
.41004 .19648 L
s
.45534 .20068 m
.45516 .19786 L
s
.45722 .20008 m
.45704 .19726 L
s
.45516 .19786 m
.44381 .18563 L
s
.45704 .19726 m
.4457 .18502 L
s
.47328 .19639 m
.48082 .19398 L
s
.47893 .19458 m
.46458 .17895 L
s
.41752 .19407 m
.43064 .18986 L
s
.48082 .19398 m
.46648 .17834 L
s
.48357 .19167 m
.49026 .19097 L
s
.47776 .19065 m
.48357 .19167 L
s
.49026 .19097 m
.49404 .18976 L
s
.49404 .18976 m
.49681 .18744 L
s
.49404 .18976 m
.49871 .18684 L
s
.43816 .18744 m
.45135 .1832 L
s
.49681 .18744 m
.49668 .1846 L
s
.49871 .18684 m
.49858 .18399 L
s
.49668 .1846 m
.48546 .17224 L
s
.49858 .18399 m
.48736 .17163 L
s
.45891 .18077 m
.47216 .17651 L
s
.52151 .17956 m
.51568 .17853 L
s
.52824 .17886 m
.52151 .17956 L
s
.52342 .17895 m
.51759 .17792 L
s
.52824 .17886 m
.52342 .17895 L
s
.53205 .17764 m
.52824 .17886 L
s
.51568 .17853 m
.51074 .17576 L
s
.51759 .17792 m
.51265 .17515 L
s
.53487 .1753 m
.53205 .17764 L
s
.53678 .17469 m
.53205 .17764 L
s
.51074 .17576 m
.50872 .17351 L
s
.53669 .17182 m
.53487 .1753 L
s
.51265 .17515 m
.51062 .1729 L
s
.5386 .17121 m
.53678 .17469 L
s
.47976 .17407 m
.49307 .16979 L
s
.50872 .17351 m
.50758 .16951 L
s
.51062 .1729 m
.50949 .1689 L
s
.53559 .16781 m
.53669 .17182 L
s
.55118 .17154 m
.55886 .16909 L
s
.53751 .1672 m
.5386 .17121 L
s
.55694 .1697 m
.53584 .14575 L
s
.50758 .16951 m
.50937 .16602 L
s
.55886 .16909 m
.53777 .14513 L
s
.50949 .1689 m
.51128 .16541 L
s
.53358 .16555 m
.53559 .16781 L
s
.53549 .16493 m
.53751 .1672 L
s
.56171 .16673 m
.56655 .16663 L
s
.55587 .16569 m
.56171 .16673 L
s
.56655 .16663 m
.5704 .16541 L
s
.50937 .16602 m
.51409 .16304 L
s
.52863 .16276 m
.53358 .16555 L
s
.51128 .16541 m
.51409 .16304 L
s
.5704 .16541 m
.57326 .16304 L
s
.5704 .16541 m
.57519 .16243 L
s
.53055 .16214 m
.53549 .16493 L
s
.51409 .16304 m
.51792 .16181 L
s
.57326 .16304 m
.57514 .15953 L
s
.52277 .16172 m
.52863 .16276 L
s
.57519 .16243 m
.57707 .15892 L
s
.52469 .1611 m
.53055 .16214 L
s
.51792 .16181 m
.52277 .16172 L
s
.51792 .16181 m
.52469 .1611 L
s
.57514 .15953 m
.57409 .15549 L
s
.57707 .15892 m
.57603 .15487 L
s
.54971 .15306 m
.54786 .15659 L
s
.57409 .15549 m
.5721 .15321 L
s
.57603 .15487 m
.57404 .15259 L
s
.60035 .1544 m
.5945 .15335 L
s
.60715 .15368 m
.60035 .1544 L
s
.60229 .15378 m
.59644 .15273 L
s
.60715 .15368 m
.60229 .15378 L
s
.61104 .15244 m
.60715 .15368 L
s
.5945 .15335 m
.58959 .15053 L
s
.5721 .15321 m
.56718 .15039 L
s
.55256 .15068 m
.54971 .15306 L
s
.59644 .15273 m
.59153 .14991 L
s
.57404 .15259 m
.56911 .14977 L
s
.61395 .15006 m
.61104 .15244 L
s
.55643 .14944 m
.55256 .15068 L
s
.58959 .15053 m
.58761 .14824 L
s
.56718 .15039 m
.5613 .14934 L
s
.61589 .14652 m
.61395 .15006 L
s
.61883 .14996 m
.59812 .12566 L
s
.59153 .14991 m
.58955 .14762 L
s
.56911 .14977 m
.56324 .14872 L
s
.5613 .14934 m
.55643 .14944 L
s
.56324 .14872 m
.55643 .14944 L
s
.62077 .14934 m
.60008 .12503 L
s
.58761 .14824 m
.58658 .14417 L
s
.53005 .14762 m
.54357 .14325 L
s
.58955 .14762 m
.58852 .14354 L
s
.63053 .14623 m
.63835 .14373 L
s
.63639 .14436 m
.6227 .12814 L
s
.58658 .14417 m
.58848 .14061 L
s
.63835 .14373 m
.62466 .12751 L
s
.58852 .14354 m
.59043 .13998 L
s
.64325 .14071 m
.64814 .14061 L
s
.63739 .13965 m
.64325 .14071 L
s
.58848 .14061 m
.59334 .13758 L
s
.64814 .14061 m
.65403 .13873 L
s
.59043 .13998 m
.59334 .13758 L
s
.6325 .1368 m
.63739 .13965 L
s
.65403 .13873 m
.65503 .13695 L
s
.59334 .13758 m
.59724 .13632 L
s
.65013 .13704 m
.65306 .13758 L
s
.60214 .13622 m
.60802 .13729 L
s
.65112 .13526 m
.65013 .13704 L
s
.65503 .13695 m
.65406 .13579 L
s
.59724 .13632 m
.60214 .13622 L
s
.65406 .13579 m
.65112 .13526 L
s
.6688 .13255 m
.66587 .13202 L
s
.67371 .13245 m
.6688 .13255 L
s
.68161 .12994 m
.67371 .13245 L
s
.66587 .13202 m
.66394 .12969 L
s
.66491 .13086 m
.66591 .12906 L
s
.71203 .13052 m
.69584 .1106 L
s
.61681 .13003 m
.63056 .12561 L
s
.6846 .12751 m
.68161 .12994 L
s
.71401 .12989 m
.69783 .10996 L
s
.66394 .12969 m
.66495 .1279 L
s
.66591 .12906 m
.6689 .12663 L
s
.66495 .1279 m
.66793 .12547 L
s
.59224 .12756 m
.60596 .12313 L
s
.68563 .12571 m
.6846 .12751 L
s
.68952 .12741 m
.68569 .12274 L
s
.68563 .12571 m
.68952 .12741 L
s
.6689 .12663 m
.67686 .12113 L
s
.68569 .12274 m
.68563 .12571 L
s
.66793 .12547 m
.6759 .11996 L
s
.69943 .12425 m
.71533 .11918 L
s
.65813 .12269 m
.65424 .118 L
s
.65816 .11972 m
.65813 .12269 L
s
.67686 .12113 m
.67986 .11869 L
s
.6759 .11996 m
.6789 .11752 L
s
.65424 .118 m
.65816 .11972 L
s
.65917 .11791 m
.65816 .11972 L
s
.67986 .11869 m
.68088 .11688 L
s
.66216 .11546 m
.65917 .11791 L
s
.6789 .11752 m
.67992 .1157 L
s
.68088 .11688 m
.67799 .11335 L
s
.6701 .11291 m
.66216 .11546 L
s
.7293 .11472 m
.73729 .11217 L
s
.67799 .11335 m
.67504 .11281 L
s
.67504 .11281 m
.6701 .11291 L
s
.73529 .11281 m
.72489 .09979 L
s
.73729 .11217 m
.72689 .09915 L
s
.69584 .1106 m
.69495 .10642 L
s
.69783 .10996 m
.69695 .10577 L
s
.75133 .1077 m
.75937 .10513 L
s
.69495 .10642 m
.69798 .10395 L
s
.75736 .10577 m
.74419 .0891 L
s
.69695 .10577 m
.69798 .10395 L
s
.75937 .10513 m
.74621 .08845 L
s
.70694 .10256 m
.71086 .10429 L
s
.69798 .10395 m
.70198 .10266 L
s
.70198 .10266 m
.70694 .10256 L
s
.77145 .10128 m
.78357 .09741 L
s
.77549 .09999 m
.77459 .07933 L
s
.72489 .09979 m
.72499 .09677 L
s
.77751 .09935 m
.77646 .08174 L
s
.72689 .09915 m
.727 .09612 L
s
.72499 .09677 m
.73008 .09363 L
s
.727 .09612 m
.73008 .09363 L
s
.79167 .09483 m
.80385 .09095 L
s
.73008 .09363 m
.7341 .09234 L
s
.7411 .09159 m
.74702 .09269 L
s
.7341 .09234 m
.7411 .09159 L
s
.79978 .09224 m
.77459 .07933 L
s
.80791 .08965 m
.82217 .0851 L
s
.74419 .0891 m
.75228 .0865 L
s
.81402 .0877 m
.8093 .06818 L
s
.81605 .08705 m
.81207 .07182 L
s
.83034 .08249 m
.82572 .0629 L
s
.83034 .08249 m
.8093 .06818 L
s
.83238 .08184 m
.82848 .06656 L
s
.84057 .07923 m
.85288 .0753 L
s
.84672 .07727 m
.82572 .0629 L
s
.85905 .07334 m
.87141 .06939 L
s
.86317 .07202 m
.87329 .04761 L
s
.86523 .07137 m
.87537 .04694 L
s
.87967 .06676 m
.89209 .0628 L
s
.88795 .06412 m
.85048 .05494 L
s
.89831 .06081 m
.91079 .05683 L
s
.90247 .05949 m
.9025 .03823 L
s
.90455 .05882 m
.90429 .04071 L
s
.84634 .05627 m
.85876 .05228 L
s
.91912 .05418 m
.93165 .05018 L
s
.92747 .05151 m
.9025 .03823 L
s
.86706 .04962 m
.87954 .04561 L
s
.94212 .04684 m
.96734 .0388 L
s
.93861 .0419 m
.94212 .04684 L
s
.94421 .04617 m
.93861 .0419 L
s
.96523 .03947 m
.92979 .02946 L
s
.96734 .0388 m
.9319 .02878 L
s
.9025 .03823 m
.89473 .0346 L
s
.88337 .03673 m
.88455 .03481 L
s
.88037 .03616 m
.88337 .03673 L
s
.88156 .03424 m
.88037 .03616 L
s
.89473 .0346 m
.88874 .03346 L
s
.88365 .03356 m
.88156 .03424 L
s
.88874 .03346 m
.88365 .03356 L
s
.92979 .02946 m
.95513 .02131 L
s
.95864 .02633 m
.95302 .02199 L
s
.95513 .02131 m
.95864 .02633 L
s
0 g
.25 Mabswid
.00056 .31445 m
.97395 0 L
s
.12708 .27357 m
.12664 .28013 L
s
[(-10)] .12796 .26047 -0.06729 1 Mshowa
.45853 .1665 m
.45851 .17307 L
s
[(0)] .45857 .15337 -0.00318 1 Mshowa
.81802 .05037 m
.81847 .05692 L
s
[(10)] .81711 .03727 .06949 1 Mshowa
.125 Mabswid
.19129 .25283 m
.19107 .25677 L
s
.25651 .23176 m
.25634 .2357 L
s
.32277 .21036 m
.32266 .2143 L
s
.3901 .18861 m
.39004 .19255 L
s
.52807 .14404 m
.52812 .14798 L
s
.59877 .1212 m
.59886 .12514 L
s
.67063 .09798 m
.67079 .10192 L
s
.74371 .07438 m
.74392 .07831 L
s
.06387 .29399 m
.06356 .29792 L
s
.00163 .3141 m
.00127 .31802 L
s
.8936 .02596 m
.89393 .02988 L
s
.97048 .00112 m
.97087 .00504 L
s
gsave
.45971 .08739 -65.985 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 210},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000dR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo
003o0?ooool0ooooFP3oool00?l0ooooo`3ooomA0?ooo`8000001`3oool00?l0ooooo`3ooomB0?oo
o`030000003oool0oooo00D0oooo003o0?ooool0ooooD`3oool00`000000oooo0?ooo`040?ooo`00
o`3ooooo0?oooe80oooo00<000000?ooo`0000001@3oool00?l0ooooo`3ooomA0?ooo`040000003o
ool0oooo000000D0oooo003o0?ooool0ooooD03oool3000000030?ooo`000000000000@0oooo003o
0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooc00oooo0P0000040?ooo`80
0000103oool2000001`0oooo003o0?ooool0oooo703oool300000100oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`00000K0?ooo`00o`3ooooo0?oooaX0oooo100000000`3oool0
00000?ooo`0>0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool06@3oool00?l0
ooooo`3ooolG0?ooo`<000000P3oool5000000P0oooo100000020?ooo`040000003oool0oooo0000
00T0oooo0P00000L0?ooo`00o`3ooooo0?oooa@0oooo0`0000070?ooo`<000003P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo01/0oooo003o0?ooool0oooo4@3oool3000000/0
oooo0`00000>0?ooo`8000002P3oool3000001/0oooo003o0?ooool0oooo3@3oool4000000l0oooo
0P00000=0?ooo`800000:@3oool00?l0ooooo`3oool:0?ooo`<000004@3oool200000080oooo00<0
00000?ooo`3oool02@3oool010000000oooo0?ooo`00000X0?ooo`00o`3ooooo0?ooo`L0oooo0`00
000F0?ooo`80000000<0oooo0000003oool02@3oool010000000oooo0?ooo`00000X0?ooo`00o`3o
oooo0?ooo`@0oooo0`00000J0?ooo`@000002@3oool010000000oooo0?ooo`00000X0?ooo`00o`3o
oooo0?ooo`40oooo0`00000N0?ooo`<000002@3oool010000000oooo0?ooo`00000X0?ooo`00o`3o
ooom0?ooo`<000004P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00L0oooo0P00
000Y0?ooo`00o`3ooooj0?ooo`<000004P3oool5000000h0oooo1000000c0?ooo`00o`3oooo00?oo
o`D000000P3oool2000002h0oooo0`00000B0?ooo`P000003@3oool3000000030?ooo`000000oooo
00/0oooo0P0000040?ooo`800000103oool2000001T0oooo003o0?oool80oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo02P0oooo0`00000C0?ooo`H0000000<0oooo0000
000000000P00000?0?ooo`<000002P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0
oooo000001P0oooo003o0?oool80oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo02@0oooo1000000C0?ooo`H000001@3oool400000100oooo0P0000090?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`3oool05P3oool00?l0oooo`P3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool08@3oool4000001<0oooo1`0000090?ooo`030000
003oool0oooo00d0oooo0P0000000`3oool000000?ooo`080?ooo`040000003oool0oooo000000T0
oooo0P00000I0?ooo`00o`3oooo20?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0N0?ooo`<000000`3oool00`000000oooo0?ooo`0@0?ooo`H00000703oool200000003
0?ooo`000000oooo00L0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0H0?oo
o`00o`3oooo10?ooo`800000103oool2000001h0oooo0`0000001@3oool000000?ooo`3oool00000
01D0oooo2@00000I0?ooo`80000000<0oooo0000003oool01`3oool2000000X0oooo0`00000H0?oo
o`00o`3ooooT0?ooo`<000000`3oool8000001H0oooo2@00000G0?ooo`<00000;P3oool00?l0oooo
h@3oool3000000D0oooo2`00000G0?ooo`X000004@3oool200000080oooo00<000000?ooo`3oool0
;03oool00?l0oooogP3oool3000000L0oooo100000050?ooo`D00000603oool<000000h0oooo0P00
00000`3oool000000?ooo`0/0?ooo`00o`3ooooK0?ooo`<000002P3oool4000000L0oooo1@00000J
0?ooo`T00000?P3oool00?l0oooof03oool3000001T0oooo1P00000?0?ooo`030000003oool0oooo
00L0oooo1`00000o0?ooo`00o`3ooooE0?ooo`<00000703oool8000000`0oooo0`0000060?ooo`H0
000000<0oooo0000003oool0?`3oool00?l0ooood@3oool4000001l0oooo0`0000020?ooo`D00000
2`3oool4000000030?ooo`000000000000@00000A@3oool00?l0oooocP3oool3000001@0oooo1000
000;0?ooo`<00000103oool5000000X0oooo200000170?ooo`00o`3oooo;0?ooo`<000004`3oool8
000000/0oooo0`0000060?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`D00000BP3oool0
0?l0oooob03oool3000001H0oooo1P00000=0?ooo`<00000203oool8000000@0oooo00<000000?oo
o`3oool0B`3oool00?l0ooooa@3oool3000001/0oooo0`00000>0?ooo`<000002@3oool6000005<0
oooo003o0?oool80oooo0`0000000`3oool000000?ooo`0?0?ooo`80000000<0oooo000000000000
0P0000050?ooo`<000003P3oool3000000L0oooo1P00001E0?ooo`00o`3ooono0?ooo`<000001@3o
ool00`000000oooo0?ooo`0<0?ooo`P000001@3oool2000000l0oooo0`0000060?ooo`@00000F03o
ool00?l0oooo_03oool3000000P0oooo00<000000?ooo`3oool0303oool;000000040?ooo`000000
0000000000l0oooo1`0000030?ooo`030000003oool0oooo05P0oooo003o0?oookT0oooo0`00000Q
0?ooo`P000003P3oool8000005h0oooo003o0?oookH0oooo0`00000X0?ooo`P000001P3oool01000
0000oooo0?ooo`3oool400000680oooo003o0?oook80oooo1000000E0?ooo`030000003oool0oooo
01<0oooo0`0000000`3oool000000000000:000000<0oooo0P00001S0?ooo`00o`3ooon_0?ooo`<0
0000603oool3000001<0oooo0`0000060?ooo`L00000J@3oool00?l0oooo[03oool300000180oooo
00<000000?ooo`3oool01`3oool400000140oooo0`0000050?ooo`H00000J`3oool00?l0ooooZ@3o
ool3000001@0oooo100000070?ooo`D00000403oool2000000D0oooo1000001^0?ooo`00o`3ooonV
0?ooo`<00000603oool4000000H0oooo1P00000>0?ooo`H000000`3oool00`000000oooo0?ooo`1^
0?ooo`00o`3ooonS0?ooo`<000006`3oool6000000@0oooo0`0000000`3oool00000000000020000
00X0oooo2000001d0?ooo`00o03oool2000000030?ooo`000000000009h0oooo0`00000N0?ooo`L0
00000`3oool300000080oooo100000060?ooo`030000003oool0oooo00@00000N03oool00?d0oooo
00<000000?ooo`000000W03oool300000240oooo10000000103oool000000000000000030?ooo`<0
00000`3oool400000080oooo100000030?ooo`030000003oool0oooo07L0oooo003n0?ooo`030000
003oool0oooo09P0oooo1000000T0?ooo`<000000P3oool4000000040?ooo`0000000000000000@0
oooo2000001n0?ooo`00o03oool2000000030?ooo`000000000009D0oooo0`0000030?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool3000000<0oooo1`0000040?ooo`H00000
P03oool00?l0ooooT`3oool4000001H0oooo1000000A0?ooo`@00000103oool5000000<0oooo1@00
00220?ooo`00o`3ooon@0?ooo`<000006`3oool500000100oooo0`0000050?ooo`D000000`3oool0
0`000000oooo0?ooo`230?ooo`00o`3ooon=0?ooo`<000007P3oool7000000h0oooo0`0000030?oo
o`040000003oool0oooo0?ooo`800000RP3oool00?l0ooooRP3oool300000240oooo0`0000000`3o
ool0000000000003000000`0oooo1`00002?0?ooo`00o`3ooon70?ooo`<000004`3oool6000000/0
oooo0`0000030?ooo`D00000203oool800000900oooo003o0?oooh@0oooo0`00000E0?ooo`L00000
2`3oool3000000D0oooo1@0000030?ooo`030000003oool0000000D00000T`3oool00?l0ooooP@3o
ool3000001@0oooo2@00000=0?ooo`<000001`3oool9000009P0oooo003o0?ooogh0oooo0`00000E
0?ooo``00000303oool3000000L0oooo1`00002J0?ooo`00o`3ooomk0?ooo`<000005@3oool60000
00H0oooo1000000;0?ooo`<000001P3oool6000009`0oooo003o0?ooogL0oooo1000000G0?ooo`D0
00002@3oool3000000/0oooo0`0000070?ooo`030000003oool0oooo09h0oooo003o0?ooog@0oooo
0`00000K0?ooo`<00000303oool3000000X0oooo1P00002U0?ooo`00o`3oooma0?ooo`<0000000<0
oooo0000003oool06`3oool4000000/0oooo100000070?ooo`P00000Y@3oool00?l0ooooKP3oool3
000000@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`D000002`3oool4
000000H0oooo1P00002W0?ooo`00o`3ooom[0?ooo`<000005@3oool9000000P0oooo1000000;0?oo
o`@00000/P3oool00?l0ooooJ03oool3000001L0oooo2P0000090?ooo`<000002@3oool700000;40
oooo003o0?ooofD0oooo0`00000I0?ooo`@00000403oool4000000L0oooo1`00002b0?ooo`00o`3o
oomR0?ooo`<000007@3oool300000140oooo100000060?ooo`030000003oool0oooo0;H0oooo003o
0?oooel0oooo0`00000B0?ooo`040000003oool0oooo000000/0oooo0`00000A0?ooo`@00000_P3o
ool00?l0ooooG03oool3000001<0oooo200000090?ooo`@000003P3oool600000;h0oooo003o0?oo
oeP0oooo1000000D0?ooo`/000002@3oool3000000d0oooo1`00002n0?ooo`00o`3ooomE0?ooo`<0
00004`3oool00`000000oooo0?ooo`05000000H0oooo0`0000090?ooo`<00000303oool00`000000
oooo0?ooo`320?ooo`00o`3ooomB0?ooo`<000005@3oool7000000H0oooo1@00000:0?ooo`<00000
103oool00`000000oooo0?ooo`390?ooo`00o`3ooom?0?ooo`<000006@3oool5000000H0oooo1@00
000;0?ooo`T00000bP3oool00?l0ooooC03oool300000080oooo00<000000?ooo`3oool0603oool3
000000D0oooo1P0000030?ooo`030000003oool0oooo00L0oooo1`00003;0?ooo`00o`3ooom90?oo
o`T00000303oool00`000000oooo0?ooo`0<0?ooo`<000000`3oool6000000<0oooo0`0000060?oo
o`L00000c@3oool00?l0ooooAP3oool;000000X0oooo1@00000=0?ooo`8000000`3oool6000000@0
oooo100000040?ooo`P00000c@3oool00?l0oooo@`3oool300000080oooo200000090?ooo`H00000
4P3oool5000000D0oooo1P0000040?ooo`040000003oool0oooo0?ooo`@00000c03oool00?l0oooo
@03oool3000000D0oooo00<000000?ooo`3oool00P3oool4000000H0oooo1`00000B0?ooo`D00000
1P3oool200000080oooo00<000000?ooo`3oool0203oool400000</0oooo003o0?ooocd0oooo0`00
000>0?ooo`@00000103oool900000140oooo0`0000030?ooo`H000003`3oool300000</0oooo003o
0?ooocT0oooo1000000B0?ooo`@00000103oool010000000oooo0?ooo`3oool500000100oooo3000
000?0?ooo`030000003oool000000</0oooo003o0?ooocH0oooo0`00000C0?ooo`030000003oool0
oooo00D00000203oool4000000X0oooo0P0000050?ooo`H00000hP3oool00?l0oooo<`3oool30000
01@0oooo2P0000090?ooo`@00000203oool400000>`0oooo003o0?oooc00oooo0`00000E0?ooo`d0
00002@3oool5000000D0oooo1P00003[0?ooo`00o@3oool2000002d0oooo0`00000G0?ooo`@00000
1`3oool4000000P0oooo200000020?ooo`D00000k03oool00?`0oooo00@000000?ooo`3oool00000
:@3oool3000000030?ooo`000000oooo01H0oooo0`00000:0?ooo`@00000203oool=00000>d0oooo
003l0?ooo`040000003oool0oooo000002H0oooo2@00000F0?ooo`<000002`3oool4000000P0oooo
2@00003`0?ooo`00o03oool010000000oooo0?ooo`00000S0?ooo`<000000P3oool6000001H0oooo
1000000<0?ooo`@000001@3oool600000?D0oooo003l0?ooo`040000003oool0oooo00000200oooo
0`0000000`3oool000000?ooo`07000000X0oooo0P00000;0?ooo`@00000303oool5000000<0oooo
100000000`3oool000000?ooo`3e0?ooo`00o@3oool2000001d0oooo100000040?ooo`D0000000<0
oooo0000000000000P0000040?ooo`030000003oool0000000L00000203oool5000000/0oooo1P00
00030?ooo`030000003oool0oooo0?P0oooo003o0?oooaX0oooo0`00000:0?ooo`030000003oool0
oooo0080oooo100000020?ooo`h000001@3oool7000000L0oooo1`00003o0?ooo`00o`3ooolG0?oo
o`<000004P3oool:000000D0oooo1P0000070?ooo`L000000P3oool500000080oooo00<000000?oo
o`3oool0oP3oool00?l0oooo503oool3000001H0oooo1P0000090?ooo`D00000203oool;00000?l0
oooo1P3oool00?l0oooo4@3oool3000001X0oooo1000000<0?ooo`<00000203oool900000?l0oooo
203oool00?l0oooo3P3oool3000001h0oooo1000000<0?ooo`<00000o`3ooolH0?ooo`00o`3oool;
0?ooo`<000004P3oool00`000000oooo0?ooo`02000000X0oooo1@00000<0?ooo`800000o`3ooolH
0?ooo`00o`3oool80?ooo`<000004`3oool:000000P0oooo1@00000:0?ooo`<00000o`3ooolH0?oo
o`00o`3oool50?ooo`<00000503oool?000000H0oooo1@0000070?ooo`D00000o`3ooolH0?ooo`00
o`3oool20?ooo`<000005P3oool4000000L0oooo1P0000060?ooo`D00000103oool600000?l0oooo
6@3oool00?d0oooo1000000H0?ooo`<000002`3oool5000000H0oooo2`00003o0?oooa`0oooo003j
0?ooo`<0000000<0oooo0000003oool06@3oool3000000`0oooo0`0000070?ooo`T00000o`3ooolN
0?ooo`00m`3oool3000000@0oooo00<000000?ooo`3oool0303oool5000000L0oooo0`00000<0?oo
o`<000001P3oool600000?l0oooo8P3oool00?@0oooo0`0000070?ooo`030000003oool0oooo00T0
oooo200000070?ooo`<00000303oool3000000D0oooo1@00003o0?ooob@0oooo003a0?ooo`<00000
2P3oool00`000000oooo0?ooo`090?ooo`L00000203oool4000000/0oooo0`0000060?ooo`030000
003oool0oooo0?l0oooo9@3oool00>h0oooo0`00000M0?ooo`@00000203oool6000000L0oooo1000
003o0?ooobh0oooo003[0?ooo`<000004`3oool5000000T0oooo0`0000090?ooo`P000000P3oool5
00000?l0oooo;`3oool00>P0oooo0`00000C0?ooo`P000002P3oool3000000T0oooo3000003o0?oo
oc40oooo003U0?ooo`<000004P3oool010000000oooo0?ooo`3oool7000000/0oooo100000090?oo
o`T00000o`3ooolc0?ooo`00hP3oool300000180oooo1@0000060?ooo`@000002`3oool400000?l0
ooooA03oool00=h0oooo1000000C0?ooo`H00000203oool4000000/0oooo0`00003o0?oood@0oooo
003K0?ooo`<000005@3oool7000000X0oooo1000000:0?ooo`@00000o`3ooom30?ooo`00f03oool3
000001L0oooo2@00000:0?ooo`D00000203oool300000?l0ooooA03oool00=D0oooo1000000A0?oo
o`D00000103oool010000000oooo0?ooo`3oool4000000X0oooo200000020?ooo`D00000o`3ooom5
0?ooo`00dP3oool3000000<0oooo00<000000?ooo`3oool0303oool8000000T0oooo1000000:0?oo
o`d00000o`3ooom60?ooo`00c`3oool3000001D0oooo1`00000;0?ooo`@000002P3oool900000?l0
ooooB@3oool00<`0oooo0`00000L0?ooo`@000002`3oool4000000P0oooo1@00003o0?ooodh0oooo
00390?ooo`<000004`3oool5000000P0oooo1000000;0?ooo`<000001`3oool500000?l0ooooC`3o
ool00<H0oooo0`00000C0?ooo`P000002@3oool4000000X0oooo0`0000080?ooo`030000003oool0
oooo0?l0ooooD03oool00<80oooo1000000B0?ooo`040000003oool0oooo0?ooo`L000002`3oool4
000000T0oooo1000003o0?oooeX0oooo002o0?ooo`<000004P3oool6000000H0oooo1000000;0?oo
o`@000001P3oool500000?l0ooooF`3oool00;`0oooo0`00000D0?ooo`H00000203oool4000000/0
oooo3000003o0?oooed0oooo002i0?ooo`<00000503oool7000000/0oooo1000000:0?ooo`X00000
o`3ooomO0?ooo`00]P3oool300000180oooo00@000000?ooo`3oool0oooo2@00000;0?ooo`@00000
203oool400000?l0ooooIP3oool00;<0oooo0`00000B0?ooo`D000000`3oool010000000oooo0?oo
o`3oool5000000X0oooo1`0000030?ooo`D00000o`3ooomW0?ooo`00/03oool400000140oooo1`00
00090?ooo`D000002P3oool<00000?l0ooooJ@3oool00:d0oooo0`0000020?ooo`030000003oool0
oooo00l0oooo1P00000<0?ooo`D000002P3oool900000?l0ooooJ`3oool00:X0oooo0`0000001P3o
ool000000?ooo`000000oooo00000180oooo00<000000?ooo`0000000P00000=0?ooo`D00000203o
ool500000?l0ooooL03oool00:L0oooo0`0000020?ooo`L000002P3oool5000000D0oooo0`00000>
0?ooo`D000001P3oool500000?l0ooooL@3oool00:<0oooo100000040?ooo`T000001P3oool80000
00D0oooo0`00000?0?ooo`D000001P3oool00`000000oooo0?ooo`3o0?ooog80oooo002P0?ooo`<0
00001`3oool;000000D0oooo1`0000060?ooo`<000004@3oool400000?l0ooooNP3oool009d0oooo
0`00000:0?ooo`D000000`3oool4000000P0oooo20000000103oool0000000000000000B0?ooo`@0
0000o`3ooomi0?ooo`00VP3oool300000100oooo00<000000?ooo`3oool00`3oool4000000P0oooo
300000080?ooo`030000003oool0oooo00L0oooo1000003o0?ooogP0oooo002G0?ooo`<000004P3o
ool00`000000oooo0?ooo`050?ooo`@00000203oool400000080oooo3`0000090?ooo`@00000o`3o
oomg0?ooo`00U03oool300000180oooo1@0000070?ooo`@00000203oool4000000H0oooo2@000009
0?ooo`H00000o`3ooomf0?ooo`00T@3oool3000001<0oooo1P0000090?ooo`@00000203oool40000
00H0oooo1@00000;0?ooo`H00000o`3ooomg0?ooo`00SP3oool3000001@0oooo1`00000;0?ooo`@0
0000203oool4000000H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3o0?ooogX0
oooo002;0?ooo`@000004P3oool00`000000oooo0?ooo`09000000/0oooo100000080?ooo`@00000
o`3ooonA0?ooo`00R03oool3000000<0oooo00<000000?ooo`3oool0303oool5000000<0oooo00@0
00000?ooo`3oool0oooo1@00000;0?ooo`@00000203oool400000?l0ooooT03oool008@0oooo1000
000A0?ooo`P000002@3oool4000000`0oooo100000080?ooo`@00000o`3ooon?0?ooo`00P@3oool3
000001@0oooo2@00000:0?ooo`@000002P3oool6000000P0oooo1000003o0?ooohh0oooo001n0?oo
o`<00000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00<0oooo1000000:0?oo
o`@00000203oool6000000P0oooo1P00003o0?ooohd0oooo001k0?ooo`<000000`3oool7000000T0
oooo1@0000090?ooo`@000002P3oool4000000L0oooo00<000000?ooo`3oool01P3oool010000000
oooo0?ooo`3oool600000?l0ooooSP3oool007P0oooo4@0000050?ooo`P000002P3oool4000000X0
oooo1000000<0?ooo`D000000P3oool00`000000oooo0?ooo`3o0?oooi40oooo00150?ooo`D00000
0P3oool2000002L0oooo0`0000020?ooo`L000001P3oool3000000@0oooo1`00000;0?ooo`D00000
203oool6000000/0oooo1000003o0?oooiL0oooo00170?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0Q0?ooo`<00000103oool3000000T0oooo1@0000080?ooo`@00000
2`3oool5000000H0oooo1P00000<0?ooo`<00000o`3ooonH0?ooo`00A`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool07P3oool3000000H0oooo0`0000070?ooo`L00000
2P3oool4000000/0oooo0`0000070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooonS0?ooo`00?`3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01/0oooo0`0000090?ooo`<000001@3oool7000000d0oooo1000000:0?ooo`@00000
303oool300000?l0ooooY03oool004L0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo01L0oooo1000000<0?ooo`D0000000<0oooo0000000000001P00000?0?ooo`D00000
1P3oool00`000000oooo00000002000000`0oooo1000003o0?oooj@0oooo00160?ooo`800000103o
ool2000001L0oooo0`0000000`3oool000000?ooo`0=0?ooo`X000000P3oool00`000000oooo0?oo
o`030?ooo`8000002P3oool>000000d0oooo1000003o0?oooj@0oooo001R0?ooo`<00000103oool0
0`000000oooo0?ooo`0?0?ooo`H000000P3oool:000000X0oooo3000003o0?oookH0oooo001O0?oo
o`<000006P3oool6000000030?ooo`000000000000X000002P3oool400000?l0oooo_03oool005`0
oooo0`00000B0?ooo`D000001P3oool8000000P0oooo100000000`3oool000000?ooo`070?ooo`@0
0000o`3ooonk0?ooo`00F@3oool300000180oooo2000000:0?ooo`D000001`3oool7000000P0oooo
1000003o0?oookX0oooo001F0?ooo`<000005@3oool7000000`0oooo1@0000060?ooo`P00000203o
ool400000?l0oooo^@3oool005<0oooo0`00000L0?ooo`@000002`3oool7000000@0oooo1`000008
0?ooo`H00000o`3ooonh0?ooo`00D03oool300000140oooo00<000000?ooo`000000303oool40000
00d0oooo2@00000=0?ooo`H00000o`3oooni0?ooo`00C@3oool300000180oooo2@0000090?ooo`@0
00003@3oool8000000d0oooo00<000000?ooo`3oool0o`3ooonl0?ooo`00B@3oool4000001@0oooo
2`0000090?ooo`@00000o`3ooooP0?ooo`00AP3oool3000001L0oooo0`0000080?ooo`030000003o
ool0oooo00P0oooo100000040?ooo`030000003oool0oooo0?l0oooof03oool004<0oooo1000000A
0?ooo`030000003oool0oooo00@0oooo0`00000;0?ooo`800000203oool800000?l0oooofP3oool0
0400oooo0`0000030?ooo`030000003oool0oooo00`0oooo1@0000040?ooo`<000002@3oool60000
00H0oooo200000030?ooo`030000003oool0oooo0?l0ooooe@3oool003d0oooo0`0000060?ooo`03
0000003oool0oooo00/0oooo1@0000060?ooo`<00000103oool;000000@0oooo200000030?ooo`@0
0000o`3ooooE0?ooo`00>P3oool3000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`D00000203oool:000000@0oooo0`0000040?ooo`030000003oool0oooo0080oooo
100000000`3oool000000000000400000?l0ooooe03oool003L0oooo0`00000C0?ooo``000001`3o
ool6000000L0oooo1000000:0?ooo`T00000o`3ooooE0?ooo`00=03oool3000001D0oooo3P000006
0?ooo`H00000103oool6000000`0oooo1`00003o0?ooomH0oooo000a0?ooo`<000005`3oool40000
00L0oooo1@0000060?ooo`d000003`3oool400000?l0oooof03oool002h0oooo0`00000J0?ooo`<0
00002@3oool5000000P0oooo1`00003o0?ooonh0oooo000Z0?ooo`@000007@3oool3000000X0oooo
1P0000090?ooo`030000003oool0oooo0?l0ooook`3oool002L0oooo0`00000C0?ooo`030000003o
ool0oooo00/0oooo1000000:0?ooo`H00000o`3ooooj0?ooo`00903oool3000001@0oooo2P000006
0?ooo`D000002P3oool600000?l0oooon@3oool00240oooo0`00000E0?ooo``000001`3oool60000
00D0oooo00<000000?ooo`0000001`00003o0?ooooP0oooo000N0?ooo`<000000P3oool00`000000
oooo0?ooo`0B0?ooo`@000004P3oool=00000080oooo1@00003o0?ooooL0oooo000K0?ooo`<00000
1@3oool00`000000oooo0?ooo`0B0?ooo`<000003@3oool00`000000oooo0?ooo`050?ooo`X00000
103oool500000?l0oooomP3oool001P0oooo0`00000M0?ooo`8000002`3oool5000000X0oooo00<0
00000?ooo`3oool01`3oool600000?l0oooom@3oool001D0oooo0`00000B0?ooo`030000003oool0
000000<0oooo00<000000?ooo`3oool01@3oool3000000X0oooo1P00000B0?ooo`H00000o`3oooof
0?ooo`004P3oool3000001<0oooo2P0000060?ooo`@000002@3oool5000001<0oooo00D000000?oo
o`3oool0oooo0000003o0?ooooL0oooo000>0?ooo`@000004@3oool200000080oooo3@0000050?oo
o`H00000203oool200000?l0ooooo`3ooolA0?ooo`002`3oool3000001@0oooo1`0000060?ooo`L0
0000103oool800000080oooo1@00003o0?ooool0oooo4@3oool000P0oooo0`00000B0?ooo`030000
003oool0oooo00<0oooo1@00000:0?ooo`D000001P3oool;00000?l0ooooo`3ooolB0?ooo`001@3o
ool3000001@0oooo0`0000050?ooo`@000002`3oool3000000T0oooo1P00003o0?ooool0oooo5@3o
ool00080oooo0`00000B0?ooo`040000003oool000000?ooo`@000001P3oool4000000X0oooo0`00
003o0?ooool0oooo903oool0008000004P3oool;000000L0oooo100000090?ooo`<00000o`3ooooo
0?ooob@0oooo00000`000000oooo0?ooo`0@0?ooo`d000001`3oool5000000L0oooo1000003o0?oo
ool0oooo8`3oool000030000003oool0oooo00l0oooo0`0000060?ooo`L000001P3oool700000080
oooo1@00003o0?ooool0oooo903oool00140oooo0`0000090?ooo`H000001P3oool;00000?l0oooo
o`3ooolV0?ooo`004@3oool4000000L0oooo200000070?ooo`L00000o`3ooooo0?ooobP0oooo000A
0?ooo`H000000P3oool:000000T0oooo1000003o0?ooool0oooo:P3oool001<0oooo2P0000040?oo
o`<000002@3oool400000?l0ooooo`3ooolY0?ooo`00503oool6000000H0oooo1000000:0?ooo`@0
0000o`3ooooo0?ooobP0oooo000G0?ooo`@000000P3oool6000000X0oooo1P00003o0?ooool0oooo
9`3oool001L0oooo2P00000;0?ooo`H00000o`3ooooo0?ooobP0oooo000H0?ooo`H000003P3oool0
0`000000oooo0?ooo`3o0?ooool0oooo:`3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {209, 0}} -> {0.0483161, 0.300546, 0.00171557, \
0.00171557}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .35319 
%%ImageSize: 600 211.916 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0505595 1.05056 -0.337706 1.05056 [
[.00778 .29926 -8.189 -9 ]
[.00778 .29926 9.811 0 ]
[.22664 .2283 -5.70876 -9 ]
[.22664 .2283 6.29124 0 ]
[.45777 .15337 -2.9899 -9 ]
[.45777 .15337 3.0101 0 ]
[.70223 .07415 -3.1377 -9 ]
[.70223 .07415 2.8623 0 ]
[.96122 -0.00975 -6.59904 -9 ]
[.96122 -0.00975 5.40096 0 ]
[.45928 .08729 -4.98447 -12.75 ]
[.45928 .08729 5.01553 0 ]
[.99062 .00375 0 -5.95 ]
[.99062 .00375 24 3.05 ]
[.99606 .0117 0 -5.94516 ]
[.99606 .0117 30 3.05484 ]
[1.00148 .0196 0 -5.94036 ]
[1.00148 .0196 6 3.05964 ]
[1.00687 .02746 0 -5.93559 ]
[1.00687 .02746 24 3.06441 ]
[1.06103 -0.00479 0 -8.41925 ]
[1.06103 -0.00479 10 4.33075 ]
[ 0 0 0 0 ]
[ 1 .35319 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00078 .31423 m
.97278 0 L
s
.0066 .31234 m
.00601 .31888 L
s
[(-10)] .00778 .29926 -0.09011 1 Mshowa
.22601 .24142 m
.22569 .24797 L
s
[(-5)] .22664 .2283 -0.04854 1 Mshowa
.45773 .1665 m
.4577 .17307 L
s
[(0)] .45777 .15337 -0.00337 1 Mshowa
.70283 .08727 m
.70314 .09383 L
s
[(5)] .70223 .07415 .0459 1 Mshowa
.96252 .00331 m
.96318 .00985 L
s
[(10)] .96122 -0.00975 .09984 1 Mshowa
.125 Mabswid
.04954 .29846 m
.04922 .30239 L
s
.09295 .28443 m
.09266 .28836 L
s
.13682 .27025 m
.13656 .27418 L
s
.18117 .25591 m
.18095 .25984 L
s
.27133 .22676 m
.27117 .2307 L
s
.31716 .21195 m
.31704 .21588 L
s
.36349 .19697 m
.36341 .20091 L
s
.41035 .18182 m
.4103 .18576 L
s
.50564 .15101 m
.50567 .15495 L
s
.5541 .13535 m
.55416 .13929 L
s
.60311 .1195 m
.60321 .12344 L
s
.65269 .10348 m
.65283 .10742 L
s
.75357 .07087 m
.75379 .0748 L
s
.80489 .05427 m
.80515 .05821 L
s
.85682 .03749 m
.85712 .04142 L
s
.90936 .0205 m
.9097 .02443 L
s
gsave
.45928 .08729 -65.9845 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97278 0 m
.99905 .03829 L
s
.97812 .00778 m
.97187 .0098 L
s
[(-0.5)] .99062 .00375 -1 .32222 Mshowa
.98356 .01571 m
.97731 .01772 L
s
[(-0.25)] .99606 .0117 -1 .32115 Mshowa
.98897 .02361 m
.98272 .02561 L
s
[(0)] 1.00148 .0196 -1 .32008 Mshowa
.99436 .03145 m
.9881 .03345 L
s
[(0.25)] 1.00687 .02746 -1 .31902 Mshowa
.125 Mabswid
.97374 .0014 m
.96999 .00261 L
s
.97484 .003 m
.97109 .00421 L
s
.97593 .0046 m
.97218 .00581 L
s
.97702 .00619 m
.97327 .0074 L
s
.97921 .00937 m
.97546 .01058 L
s
.9803 .01096 m
.97655 .01217 L
s
.98139 .01255 m
.97764 .01375 L
s
.98247 .01413 m
.97872 .01534 L
s
.98465 .0173 m
.98089 .0185 L
s
.98573 .01888 m
.98198 .02008 L
s
.98681 .02045 m
.98306 .02166 L
s
.98789 .02203 m
.98414 .02323 L
s
.99005 .02518 m
.9863 .02638 L
s
.99113 .02675 m
.98738 .02795 L
s
.99221 .02832 m
.98846 .02952 L
s
.99328 .02989 m
.98953 .03108 L
s
.99543 .03302 m
.99168 .03421 L
s
.99651 .03458 m
.99275 .03578 L
s
.99758 .03614 m
.99382 .03734 L
s
.99865 .0377 m
.99489 .03889 L
s
gsave
1.06103 -0.00479 -61 -12.4193 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .35319 L
0 .35319 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.05037 .33194 m
.04645 .33131 L
s
.05663 .33183 m
.05037 .33194 L
s
.05663 .33183 m
.06134 .33033 L
s
.05663 .33183 m
.0488 .33056 L
s
.04645 .33131 m
.04095 .32929 L
s
.0488 .33056 m
.0433 .32853 L
s
.06134 .33033 m
.06213 .32819 L
s
.06134 .33033 m
.06449 .32743 L
s
.04095 .32929 m
.0378 .32651 L
s
.0433 .32853 m
.04015 .32575 L
s
.06213 .32819 m
.05587 .31691 L
s
.06449 .32743 m
.05824 .31616 L
s
.06608 .32314 m
.07313 .32657 L
s
.0378 .32651 m
.037 .32297 L
s
.09826 .3261 m
.103 .32459 L
s
.09826 .3261 m
.09043 .32483 L
s
.04015 .32575 m
.03935 .32221 L
s
.09435 .32546 m
.08888 .32343 L
s
.09043 .32483 m
.08496 .3228 L
s
.103 .32459 m
.10383 .32245 L
s
.103 .32459 m
.10621 .32169 L
s
.08888 .32343 m
.07479 .31656 L
s
.05666 .32047 m
.06608 .32314 L
s
.037 .32297 m
.04013 .32006 L
s
.08496 .3228 m
.07085 .31592 L
s
.10383 .32245 m
.10074 .31965 L
s
.03935 .32221 m
.04013 .32006 L
s
.10621 .32169 m
.10312 .3189 L
s
.04879 .31919 m
.05666 .32047 L
s
.04013 .32006 m
.04249 .3193 L
s
.10074 .31965 m
.09527 .31761 L
s
.04249 .3193 m
.04879 .31919 L
s
.10312 .3189 m
.09764 .31686 L
s
.08896 .31773 m
.08978 .31557 L
s
.08896 .31773 m
.09216 .31481 L
s
.09527 .31761 m
.08896 .31773 L
s
.09764 .31686 m
.08896 .31773 L
s
.05587 .31691 m
.05904 .31399 L
s
.07247 .31159 m
.07479 .31656 L
s
.07479 .31656 m
.05747 .30684 L
s
.05824 .31616 m
.05904 .31399 L
s
.07085 .31592 m
.0551 .3076 L
s
.08978 .31557 m
.08904 .312 L
s
.09216 .31481 m
.09142 .31124 L
s
.05904 .31399 m
.0614 .31323 L
s
.11586 .31294 m
.12064 .31142 L
s
.108 .31165 m
.11586 .31294 L
s
.08904 .312 m
.08592 .30919 L
s
.108 .31165 m
.11432 .31153 L
s
.07565 .30866 m
.07247 .31159 L
s
.11432 .31153 m
.1191 .31001 L
s
.12064 .31142 m
.12388 .30848 L
s
.09142 .31124 m
.0883 .30842 L
s
.1191 .31001 m
.12234 .30707 L
s
.08592 .30919 m
.07803 .3079 L
s
.07803 .3079 m
.07565 .30866 L
s
.12388 .30848 m
.12164 .30348 L
s
.0883 .30842 m
.08436 .30778 L
s
.08436 .30778 m
.07803 .3079 L
s
.12234 .30707 m
.12164 .30348 L
s
.16667 .30625 m
.17149 .30472 L
s
.16274 .3056 m
.16667 .30625 L
s
.1374 .30607 m
.13038 .3026 L
s
.16122 .30419 m
.16274 .3056 L
s
.16515 .30484 m
.16997 .3033 L
s
.16122 .30419 m
.16515 .30484 L
s
.17149 .30472 m
.17238 .30254 L
s
.16058 .30059 m
.16122 .30419 L
s
.12164 .30348 m
.11389 .29639 L
s
.16997 .3033 m
.17176 .29893 L
s
.13038 .3026 m
.11389 .29639 L
s
.17238 .30254 m
.17176 .29893 L
s
.16476 .29544 m
.16058 .30059 L
s
.15029 .30006 m
.14635 .29941 L
s
.15664 .29994 m
.15029 .30006 L
s
.15664 .29994 m
.14875 .29864 L
s
.16146 .2984 m
.15664 .29994 L
s
.14635 .29941 m
.14086 .29733 L
s
.14875 .29864 m
.14327 .29656 L
s
.16324 .29401 m
.16146 .2984 L
s
.14086 .29733 m
.13778 .29449 L
s
.14327 .29656 m
.13865 .29229 L
s
.11389 .29639 m
.10285 .29223 L
s
.11389 .29639 m
.10525 .29146 L
s
.16413 .29181 m
.16476 .29544 L
s
.13778 .29449 m
.1371 .29086 L
s
.15864 .28973 m
.16324 .29401 L
s
.13865 .29229 m
.14039 .28788 L
s
.16106 .28895 m
.16413 .29181 L
s
.1371 .29086 m
.14039 .28788 L
s
.18172 .29003 m
.1802 .2886 L
s
.1881 .28991 m
.18172 .29003 L
s
.1881 .28991 m
.18415 .28925 L
s
.19539 .28758 m
.1881 .28991 L
s
.15315 .28764 m
.15864 .28973 L
s
.18415 .28925 m
.18263 .28782 L
s
.15557 .28687 m
.16106 .28895 L
s
.1802 .2886 m
.1811 .28639 L
s
.14039 .28788 m
.14523 .28633 L
s
.18263 .28782 m
.18444 .2834 L
s
.14523 .28633 m
.15315 .28764 L
s
.19874 .28459 m
.19539 .28758 L
s
.15161 .28621 m
.15557 .28687 L
s
.1811 .28639 m
.18444 .2834 L
s
.22336 .28633 m
.21942 .28567 L
s
.14523 .28633 m
.15161 .28621 L
s
.21942 .28567 m
.21792 .28424 L
s
.17562 .2843 m
.17166 .28364 L
s
.18444 .2834 m
.17562 .2843 L
s
.21792 .28424 m
.2213 .28124 L
s
.17166 .28364 m
.1686 .28076 L
s
.17805 .28352 m
.17409 .28286 L
s
.18444 .2834 m
.17805 .28352 L
s
.17409 .28286 m
.17103 .27998 L
s
.21246 .28214 m
.2085 .28148 L
s
.2213 .28124 m
.21246 .28214 L
s
.2085 .28148 m
.20303 .27938 L
s
.2149 .28136 m
.21095 .2807 L
s
.2213 .28124 m
.2149 .28136 L
s
.23015 .28034 m
.2213 .28124 L
s
.2213 .28124 m
.22865 .2789 L
s
.1686 .28076 m
.17193 .27776 L
s
.21095 .2807 m
.20548 .2786 L
s
.22865 .2789 m
.23015 .28034 L
s
.17103 .27998 m
.17193 .27776 L
s
.20303 .27938 m
.2 .27649 L
s
.20548 .2786 m
.20244 .27571 L
s
.17193 .27776 m
.17924 .27541 L
s
.2 .27649 m
.1994 .27282 L
s
.20244 .27571 m
.20185 .27203 L
s
.17924 .27541 m
.18565 .27529 L
s
.23697 .27432 m
.24188 .27276 L
s
.23301 .27366 m
.23697 .27432 L
s
.22754 .27155 m
.23301 .27366 L
s
.23942 .27354 m
.24038 .27131 L
s
.1994 .27282 m
.20033 .27058 L
s
.24188 .27276 m
.24285 .27052 L
s
.20185 .27203 m
.20371 .26755 L
s
.24038 .27131 m
.23888 .26986 L
s
.20033 .27058 m
.20371 .26755 L
s
.24285 .27052 m
.24135 .26907 L
s
.23888 .26986 m
.2234 .26124 L
s
.24531 .26973 m
.25174 .26961 L
s
.24135 .26907 m
.24531 .26973 L
s
.25174 .26961 m
.25668 .26804 L
s
.24135 .26907 m
.22586 .26045 L
s
.25668 .26804 m
.25765 .2658 L
s
.25668 .26804 m
.26013 .26501 L
s
.20371 .26755 m
.20465 .26531 L
s
.25765 .2658 m
.25466 .26288 L
s
.1927 .26331 m
.19177 .26555 L
s
.20465 .26531 m
.2016 .26239 L
s
.26013 .26501 m
.25714 .26209 L
s
.19761 .26172 m
.1927 .26331 L
s
.25466 .26288 m
.23217 .2506 L
s
.29731 .26282 m
.29334 .26215 L
s
.30228 .26124 m
.29731 .26282 L
s
.2016 .26239 m
.19761 .26172 L
s
.29334 .26215 m
.29039 .25923 L
s
.25714 .26209 m
.23465 .2498 L
s
.30035 .25605 m
.30228 .26124 L
s
.3033 .25898 m
.30228 .26124 L
s
.275 .26026 m
.27996 .25868 L
s
.27102 .25959 m
.275 .26026 L
s
.26556 .25746 m
.27102 .25959 L
s
.27748 .25947 m
.27848 .25721 L
s
.29039 .25923 m
.28992 .2555 L
s
.30285 .25526 m
.3033 .25898 L
s
.27996 .25868 m
.28096 .25642 L
s
.27848 .25721 m
.27252 .25134 L
s
.28096 .25642 m
.27351 .24906 L
s
.29592 .25164 m
.30035 .25605 L
s
.28992 .2555 m
.29444 .25017 L
s
.29842 .25084 m
.30285 .25526 L
s
.28897 .24802 m
.29592 .25164 L
s
.27252 .25134 m
.27202 .24759 L
s
.29147 .24722 m
.29842 .25084 L
s
.29444 .25017 m
.29795 .2471 L
s
.27351 .24906 m
.27302 .24531 L
s
.2835 .24586 m
.28897 .24802 L
s
.27202 .24759 m
.27302 .24531 L
s
.32139 .2474 m
.30604 .23864 L
s
.28599 .24506 m
.29147 .24722 L
s
.3239 .2466 m
.30856 .23783 L
s
.27551 .24451 m
.2835 .24586 L
s
.27302 .24531 m
.27551 .24451 L
s
.282 .24439 m
.28599 .24506 L
s
.27551 .24451 m
.282 .24439 L
s
.34403 .24019 m
.32324 .22919 L
s
.34655 .23938 m
.32576 .22838 L
s
.30604 .23864 m
.30456 .23715 L
s
.37512 .23808 m
.38019 .23647 L
s
.30856 .23783 m
.30707 .23634 L
s
.30456 .23715 m
.30559 .23485 L
s
.38019 .23647 m
.38128 .23417 L
s
.38019 .23647 m
.38382 .23336 L
s
.30707 .23634 m
.30811 .23405 L
s
.35666 .23616 m
.34869 .23479 L
s
.36172 .23454 m
.35666 .23616 L
s
.33964 .23572 m
.34323 .23262 L
s
.33964 .23572 m
.3407 .23342 L
s
.34869 .23479 m
.33964 .23572 L
s
.35919 .23535 m
.36027 .23305 L
s
.31714 .23311 m
.32262 .23529 L
s
.30559 .23485 m
.31062 .23324 L
s
.3628 .23224 m
.36172 .23454 L
s
.38128 .23417 m
.38175 .21041 L
s
.3407 .23342 m
.33989 .22582 L
s
.38382 .23336 m
.38431 .20959 L
s
.31062 .23324 m
.31714 .23311 L
s
.36027 .23305 m
.3628 .23224 L
s
.34323 .23262 m
.34243 .225 L
s
.33989 .22582 m
.3435 .22269 L
s
.38313 .22576 m
.3613 .21697 L
s
.38313 .22576 m
.35875 .21779 L
s
.34243 .225 m
.3435 .22269 L
s
.35004 .22256 m
.35551 .22475 L
s
.3435 .22269 m
.35004 .22256 L
s
.41012 .21911 m
.38105 .20267 L
s
.41269 .21829 m
.38362 .20184 L
s
.4281 .21338 m
.41291 .20439 L
s
.43067 .21256 m
.41548 .20356 L
s
.39892 .21085 m
.39603 .20781 L
s
.44098 .20927 m
.44873 .2068 L
s
.39603 .20781 m
.39715 .20547 L
s
.44615 .20762 m
.4307 .1947 L
s
.44873 .2068 m
.43759 .19847 L
s
.39715 .20547 m
.40229 .20382 L
s
.41291 .20439 m
.41146 .20286 L
s
.40889 .20369 m
.41291 .20439 L
s
.40229 .20382 m
.40889 .20369 L
s
.41548 .20356 m
.41404 .20203 L
s
.41146 .20286 m
.4126 .20051 L
s
.41404 .20203 m
.41518 .19968 L
s
.42179 .19955 m
.42725 .20178 L
s
.46687 .20102 m
.46947 .20019 L
s
.46262 .19642 m
.46687 .20102 L
s
.4126 .20051 m
.41777 .19885 L
s
.46947 .20019 m
.46262 .19642 L
s
.4959 .19968 m
.4919 .19898 L
s
.41777 .19885 m
.42179 .19955 L
s
.4919 .19898 m
.4905 .19744 L
s
.43759 .19847 m
.4307 .1947 L
s
.4905 .19744 m
.49432 .19425 L
s
.46262 .19642 m
.45316 .19348 L
s
.4333 .19386 m
.4307 .1947 L
s
.48769 .19438 m
.48368 .19367 L
s
.49693 .19342 m
.48769 .19438 L
s
.49432 .19425 m
.50216 .19175 L
s
.44251 .1929 m
.4333 .19386 L
s
.48368 .19367 m
.48086 .19059 L
s
.4903 .19354 m
.48629 .19284 L
s
.49693 .19342 m
.4903 .19354 L
s
.45316 .19348 m
.44251 .1929 L
s
.48629 .19284 m
.48347 .18976 L
s
.48086 .19059 m
.48468 .18738 L
s
.48347 .18976 m
.48468 .18738 L
s
.47804 .18751 m
.47401 .1868 L
s
.4873 .18654 m
.47804 .18751 L
s
.48468 .18738 m
.49253 .18487 L
s
.47401 .1868 m
.47118 .18371 L
s
.48065 .18667 m
.47663 .18596 L
s
.4873 .18654 m
.48065 .18667 L
s
.47663 .18596 m
.47379 .18287 L
s
.51247 .18448 m
.50845 .18377 L
s
.51912 .18435 m
.51247 .18448 L
s
.51912 .18435 m
.51108 .18293 L
s
.52438 .18268 m
.51912 .18435 L
s
.50845 .18377 m
.50303 .18151 L
s
.47118 .18371 m
.47499 .18048 L
s
.51108 .18293 m
.50565 .18067 L
s
.47379 .18287 m
.47499 .18048 L
s
.52687 .17789 m
.52438 .18268 L
s
.52826 .17944 m
.52438 .18268 L
s
.50303 .18151 m
.50022 .17841 L
s
.50565 .18067 m
.50144 .17601 L
s
.47499 .18048 m
.47882 .17724 L
s
.52812 .17549 m
.52826 .17944 L
s
.50022 .17841 m
.50004 .17445 L
s
.5227 .17322 m
.52687 .17789 L
s
.47882 .17724 m
.48002 .17484 L
s
.50144 .17601 m
.5039 .1712 L
s
.52534 .17237 m
.52812 .17549 L
s
.54814 .1751 m
.57735 .16579 L
s
.54008 .17367 m
.54814 .1751 L
s
.48002 .17484 m
.4786 .17328 L
s
.50004 .17445 m
.5039 .1712 L
s
.47456 .17257 m
.46931 .17426 L
s
.54008 .17367 m
.54676 .17354 L
s
.54676 .17354 m
.57598 .16422 L
s
.4786 .17328 m
.47456 .17257 L
s
.51726 .17094 m
.5227 .17322 L
s
.5199 .17009 m
.52534 .17237 L
s
.5039 .1712 m
.50918 .16951 L
s
.55471 .17101 m
.53831 .16016 L
s
.55471 .17101 m
.53566 .16101 L
s
.50918 .16951 m
.51726 .17094 L
s
.51586 .16938 m
.5199 .17009 L
s
.50918 .16951 m
.51586 .16938 L
s
.56533 .16762 m
.55429 .15503 L
s
.56533 .16762 m
.55162 .15588 L
s
.59468 .15825 m
.59064 .15753 L
s
.6014 .15812 m
.59468 .15825 L
s
.6014 .15812 m
.59332 .15667 L
s
.60676 .15641 m
.6014 .15812 L
s
.59064 .15753 m
.58523 .15522 L
s
.59332 .15667 m
.58791 .15437 L
s
.60676 .15641 m
.60942 .15153 L
s
.60676 .15641 m
.61077 .15311 L
s
.58523 .15522 m
.5648 .14352 L
s
.58791 .15437 m
.56748 .14265 L
s
.61077 .15311 m
.61075 .14909 L
s
.58243 .14803 m
.58249 .15206 L
s
.60942 .15153 m
.60534 .14677 L
s
.61075 .14909 m
.60804 .14591 L
s
.63771 .14856 m
.63367 .14783 L
s
.64716 .14756 m
.63771 .14856 L
s
.58643 .14471 m
.58243 .14803 L
s
.63367 .14783 m
.62828 .14551 L
s
.65528 .14498 m
.64716 .14756 L
s
.60534 .14677 m
.59993 .14445 L
s
.60804 .14591 m
.60262 .14358 L
s
.62828 .14551 m
.62558 .14232 L
s
.66209 .14079 m
.65528 .14498 L
s
.59181 .14299 m
.58643 .14471 L
s
.59993 .14445 m
.59181 .14299 L
s
.60262 .14358 m
.59856 .14285 L
s
.59856 .14285 m
.59181 .14299 L
s
.62558 .14232 m
.62558 .13826 L
s
.66347 .13833 m
.66209 .14079 L
s
.62558 .13826 m
.62829 .13332 L
s
.62829 .13332 m
.6351 .12499 L
s
.68395 .12977 m
.67989 .12903 L
s
.69074 .12963 m
.68395 .12977 L
s
.69074 .12963 m
.68262 .12815 L
s
.71268 .12264 m
.69074 .12963 L
s
.67989 .12903 m
.6745 .12668 L
s
.68262 .12815 m
.67723 .1258 L
s
.69906 .12291 m
.69621 .12789 L
s
.6745 .12668 m
.67184 .12344 L
s
.67723 .1258 m
.67324 .12095 L
s
.6351 .12499 m
.63511 .12088 L
s
.70038 .12452 m
.71137 .12102 L
s
.70049 .12041 m
.70038 .12452 L
s
.67184 .12344 m
.6719 .11933 L
s
.6951 .11804 m
.69906 .12291 L
s
.67324 .12095 m
.67605 .11594 L
s
.63511 .12088 m
.6324 .11764 L
s
.69785 .11716 m
.70049 .12041 L
s
.6719 .11933 m
.67605 .11594 L
s
.62831 .11689 m
.62285 .11865 L
s
.72644 .11825 m
.75133 .11031 L
s
.71832 .11676 m
.72644 .11825 L
s
.6897 .11567 m
.6951 .11804 L
s
.6324 .11764 m
.62831 .11689 L
s
.69245 .11479 m
.69785 .11716 L
s
.71832 .11676 m
.72514 .11662 L
s
.72514 .11662 m
.75004 .10868 L
s
.67605 .11594 m
.68154 .11418 L
s
.68154 .11418 m
.6897 .11567 L
s
.68837 .11405 m
.69245 .11479 L
s
.68154 .11418 m
.68837 .11405 L
s
.73619 .1131 m
.72296 .10089 L
s
.73619 .1131 m
.72018 .10178 L
s
.76244 .10677 m
.76801 .10499 L
s
.75837 .10602 m
.76244 .10677 L
s
.753 .10363 m
.75837 .10602 L
s
.76522 .10588 m
.76672 .10335 L
s
.76801 .10499 m
.76951 .10246 L
s
.76672 .10335 m
.76414 .10007 L
s
.76951 .10246 m
.76693 .09918 L
s
.76414 .10007 m
.75747 .09602 L
s
.78474 .09966 m
.78626 .09712 L
s
.78754 .09876 m
.78474 .09966 L
s
.76693 .09918 m
.76026 .09512 L
s
.7837 .09382 m
.78754 .09876 L
s
.75747 .09602 m
.75488 .09272 L
s
.76026 .09512 m
.75767 .09182 L
s
.77704 .08975 m
.7837 .09382 L
s
.75488 .09272 m
.75916 .08927 L
s
.75767 .09182 m
.75916 .08927 L
s
.80589 .09085 m
.80181 .0901 L
s
.80181 .0901 m
.79645 .08768 L
s
.76886 .08823 m
.77704 .08975 L
s
.75916 .08927 m
.76196 .08837 L
s
.76196 .08837 m
.76886 .08823 L
s
.79645 .08768 m
.79389 .08436 L
s
.82404 .08712 m
.81996 .08636 L
s
.82969 .08533 m
.82404 .08712 L
s
.81996 .08636 m
.81461 .08394 L
s
.82278 .08546 m
.81461 .08394 L
s
.82843 .08366 m
.82278 .08546 L
s
.83125 .08276 m
.82969 .08533 L
s
.79389 .08436 m
.79542 .08179 L
s
.79389 .08436 m
.79414 .08012 L
s
.81461 .08394 m
.80797 .07984 L
s
.82999 .08109 m
.82843 .08366 L
s
.82873 .07943 m
.83125 .08276 L
s
.79542 .08179 m
.79978 .07831 L
s
.84099 .08172 m
.84382 .08082 L
s
.84382 .08082 m
.84541 .07824 L
s
.84382 .08082 m
.84824 .07734 L
s
.79414 .08012 m
.7985 .07664 L
s
.80797 .07984 m
.80132 .07574 L
s
.80797 .07984 m
.79053 .07085 L
s
.82337 .07699 m
.82873 .07943 L
s
.8221 .07532 m
.82873 .07943 L
s
.79978 .07831 m
.80542 .0765 L
s
.84541 .07824 m
.84009 .057 L
s
.84824 .07734 m
.84295 .05608 L
s
.81518 .07546 m
.82337 .07699 L
s
.7985 .07664 m
.80414 .07483 L
s
.80542 .0765 m
.81518 .07546 L
s
.80132 .07574 m
.79336 .06994 L
s
.8139 .07378 m
.8221 .07532 L
s
.80414 .07483 m
.8139 .07378 L
s
.86654 .07357 m
.85711 .07036 L
s
.85711 .07036 m
.83122 .06404 L
s
.88365 .06812 m
.88937 .06629 L
s
.87956 .06735 m
.88365 .06812 L
s
.91146 .06756 m
.88187 .04144 L
s
.87422 .06489 m
.87956 .06735 L
s
.88651 .0672 m
.88814 .06461 L
s
.91433 .06664 m
.87899 .04237 L
s
.88937 .06629 m
.891 .06369 L
s
.88814 .06461 m
.88319 .05785 L
s
.83122 .06404 m
.82172 .06081 L
s
.891 .06369 m
.88358 .05353 L
s
.88319 .05785 m
.88234 .05183 L
s
.84009 .057 m
.84454 .05346 L
s
.91442 .05204 m
.92096 .05622 L
s
.84295 .05608 m
.84454 .05346 L
s
.88358 .05353 m
.88522 .05091 L
s
.84454 .05346 m
.8474 .05254 L
s
.90908 .04956 m
.91442 .05204 L
s
.88234 .05183 m
.88397 .04921 L
s
.88522 .05091 m
.89385 .04814 L
s
.89962 .04629 m
.90908 .04956 L
s
.90085 .048 m
.90908 .04956 L
s
.88397 .04921 m
.89261 .04643 L
s
.93707 .04899 m
.93297 .04821 L
s
.94407 .04885 m
.93707 .04899 L
s
.93707 .04899 m
.94287 .04714 L
s
.94287 .04714 m
.94407 .04885 L
s
.93297 .04821 m
.92764 .04572 L
s
.89385 .04814 m
.90085 .048 L
s
.89261 .04643 m
.89962 .04629 L
s
.92764 .04572 m
.9252 .0423 L
s
.96149 .0433 m
.96029 .04159 L
s
.9632 .04066 m
.96149 .0433 L
s
.9252 .0423 m
.92856 .03701 L
s
.9252 .0423 m
.92566 .03794 L
s
.94625 .04187 m
.94019 .03328 L
s
.96029 .04159 m
.9632 .04066 L
s
.94262 .03672 m
.94916 .04094 L
s
.96371 .03629 m
.9632 .04066 L
s
.92566 .03794 m
.92734 .03529 L
s
.92856 .03701 m
.93437 .03514 L
s
.94262 .03672 m
.9431 .03234 L
s
.93437 .03514 m
.94262 .03672 L
s
.93728 .03421 m
.94262 .03672 L
s
.96131 .03285 m
.96371 .03629 L
s
.92734 .03529 m
.93315 .03342 L
s
.93315 .03342 m
.93728 .03421 L
s
.94019 .03328 m
.94188 .03062 L
s
.95598 .03033 m
.96131 .03285 L
s
.9431 .03234 m
.94893 .03047 L
s
.94188 .03062 m
.94772 .02875 L
s
.94893 .03047 m
.95598 .03033 L
s
.94772 .02875 m
.95598 .03033 L
s
0 g
.25 Mabswid
.00078 .31423 m
.97278 0 L
s
.0066 .31234 m
.00601 .31888 L
s
[(-10)] .00778 .29926 -0.09011 1 Mshowa
.22601 .24142 m
.22569 .24797 L
s
[(-5)] .22664 .2283 -0.04854 1 Mshowa
.45773 .1665 m
.4577 .17307 L
s
[(0)] .45777 .15337 -0.00337 1 Mshowa
.70283 .08727 m
.70314 .09383 L
s
[(5)] .70223 .07415 .0459 1 Mshowa
.96252 .00331 m
.96318 .00985 L
s
[(10)] .96122 -0.00975 .09984 1 Mshowa
.125 Mabswid
.04954 .29846 m
.04922 .30239 L
s
.09295 .28443 m
.09266 .28836 L
s
.13682 .27025 m
.13656 .27418 L
s
.18117 .25591 m
.18095 .25984 L
s
.27133 .22676 m
.27117 .2307 L
s
.31716 .21195 m
.31704 .21588 L
s
.36349 .19697 m
.36341 .20091 L
s
.41035 .18182 m
.4103 .18576 L
s
.50564 .15101 m
.50567 .15495 L
s
.5541 .13535 m
.55416 .13929 L
s
.60311 .1195 m
.60321 .12344 L
s
.65269 .10348 m
.65283 .10742 L
s
.75357 .07087 m
.75379 .0748 L
s
.80489 .05427 m
.80515 .05821 L
s
.85682 .03749 m
.85712 .04142 L
s
.90936 .0205 m
.9097 .02443 L
s
gsave
.45928 .08729 -65.9845 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 211.875},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000db000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0oooo4P3oool500000080oooo0P00000o0?ooo`00o`3ooooo0?oooa@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo03`0oooo003o0?ooool0
oooo503oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0?03oool00?l0
ooooo`3ooolD0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0l0?oo
o`00o`3ooooo0?oooa@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
03`0oooo003o0?ooool0oooo4`3oool2000000@0oooo0P00000o0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3ooom@0?ooo`<0
000000<0oooo000000000000103oool00?l0ooooo`3oool`0?ooo`800000103oool2000000@0oooo
0P00000L0?ooo`00o`3ooooo0?ooobl0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000K0?ooo`00o`3ooooo0?oooad0oooo0P00000@0?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool06@3oool00?l0ooooo`3ooolJ0?ooo`H000002@3oool400000080oooo
00@000000?ooo`3oool000002@3oool2000001`0oooo003o0?ooool0oooo5`3oool3000000<0oooo
1000000>0?ooo`030000003oool0oooo00<00000103oool2000000030?ooo`000000oooo00@00000
0`3oool2000001<0oooo003o0?ooool0oooo503oool3000000030?ooo`000000oooo00@0oooo0`00
000?0?ooo`<000000P3oool00`000000oooo0?ooo`040?ooo`<000001@3oool010000000oooo0?oo
o`00000B0?ooo`00o`3ooooo0?oooa40oooo0`0000050?ooo`030000003oool0oooo0080oooo1000
000@0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0@0?ooo`00o`3ooooo0?ooo`d0oooo100000080?ooo`040000003oool0oooo0?ooo`<00000
00<0oooo0000003oool02@3oool400000080oooo00@000000?ooo`3oool000002P3oool00`000000
oooo0?ooo`020?ooo`8000004`3oool00?l0ooooo`3oool:0?ooo`<000004P3oool2000000030?oo
o`000000oooo00h0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo0180oooo003o0?ooool0oooo1`3oool3000001H0oooo1000000<0?ooo`80
000000<0oooo0000000000002P3oool2000000@0oooo0`00000B0?ooo`00o`3ooooo0?ooo`@0oooo
0`00000J0?ooo`<000002`3oool010000000oooo0?ooo`00000W0?ooo`00o`3ooooo0?ooo`40oooo
0`00000O0?ooo`8000002P3oool010000000oooo0?ooo`00000W0?ooo`00o`3oooom0?ooo`<00000
7`3oool4000000030?ooo`000000oooo00P0oooo00@000000?ooo`3oool000009`3oool00?l0oooo
nP3oool3000002D0oooo100000080?ooo`030000003oool0oooo00<00000103oool2000000<0oooo
100000030?ooo`8000004`3oool00?l0oooom`3oool4000002P0oooo0`0000090?ooo`<000000P3o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool00000
4P3oool00?l0oooom03oool3000000<0oooo00<000000?ooo`3oool09P3oool4000000X0oooo00@0
00000?ooo`3oool000002@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo
003o0?oooo40oooo0`00000^0?ooo`D000002P3oool010000000oooo0?ooo`00000:0?ooo`030000
003oool0oooo0080oooo0P00000C0?ooo`00o`3oooo]0?ooo`@000007@3oool2000001D0oooo1000
00080?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`0B0?ooo`00o`3ooooZ0?ooo`<000007`3oool900000100oooo0P0000000`3oool00000
0?ooo`080?ooo`8000002P3oool2000000@0oooo0`00000B0?ooo`00o`3ooooW0?ooo`<000007@3o
ool010000000oooo0?ooo`3oool=000000h0oooo1000000_0?ooo`00o`3ooooT0?ooo`<000007@3o
oolE000000`0oooo0`0000000`3oool000000?ooo`0^0?ooo`00o`3ooooQ0?ooo`<000007`3oool:
000000X0oooo0P00000>0?ooo`80000000<0oooo0000003oool0;@3oool00?l0oooogP3oool30000
0280oooo300000080?ooo`8000003`3oool4000002d0oooo003o0?ooom/0oooo0`00000T0?ooo`<0
00001P3oool6000000H0oooo0P00000@0?ooo`<00000;@3oool00?l0oooof03oool300000080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0000000F0?ooo`<00000203oool5000000@0oooo
1000000o0?ooo`00o`3ooooE0?ooo`<000001@3oool00`000000oooo0?ooo`080?ooo`D000005@3o
ool3000000T0oooo00<000000?ooo`000000103oool400000400oooo003o0?ooom80oooo0`00000D
0?ooo`D000000`3oool010000000oooo0?ooo`00000=0?ooo`<000002@3oool00`000000oooo0?oo
o`050?ooo`<00000@03oool00?l0oooocP3oool4000001P0oooo3P00000;0?ooo`D00000103oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo03l0oooo003o0?oool/0oooo0`00000N0?oo
o`l000002@3oool:000004/0oooo003o0?ooolP0oooo0`00000P0?oooa4000002`3oool8000004X0
oooo003o0?ooolD0oooo0`00000>0?ooo`030000003oool0oooo0140oooo2@0000070?ooo`@00000
2P3oool6000004/0oooo003o0?oool80oooo0`00000@0?ooo`@000004@3oool400000080oooo1000
00070?ooo`@00000FP3oool00?l0oooo_`3oool300000180oooo1@00000A0?ooo`@00000103oool3
000000P0oooo1000001H0?ooo`00o`3ooonl0?ooo`<0000000<0oooo0000003oool04@3oool40000
01<0oooo0P0000000`3oool00000000000040?ooo`@000001`3oool4000005L0oooo003o0?oookT0
oooo0`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool3000001<0
oooo0`0000000`3oool000000?ooo`040?ooo`@00000203oool00`000000oooo0?ooo`1F0?ooo`00
o`3ooon60?ooo`800000;P3oool300000100oooo100000070?ooo`<000004`3oool6000000D0oooo
1@00001O0?ooo`00o`3ooon50?ooo`040000003oool0oooo000002X0oooo0`00000D0?ooo`H00000
103oool3000001D0oooo1@0000050?ooo`D00000GP3oool00?l0ooooR03oool00`000000oooo0?oo
o`0U0?ooo`<000006@3oool7000000030?ooo`0000000000008000003P3oool00`000000oooo0?oo
o`040?ooo`D000001P3oool5000005`0oooo003o0?ooohH0oooo0P00000T0?ooo`@000007`3oool9
000000d0oooo1@0000020?ooo`D00000203oool5000005/0oooo003o0?ooohH0oooo00<000000?oo
o`3oool0803oool3000000h0oooo00<000000?ooo`3oool05P3oool7000000`0oooo2P00000:0?oo
o`D00000FP3oool00?l0ooooQP3oool3000001d0oooo0`00000?0?ooo`@000006@3oool9000000X0
oooo1P00000=0?ooo`030000003oool0000005/0oooo003o0?oooj<0oooo0`00000A0?ooo`H00000
603oool4000000030?ooo`000000000000L00000MP3oool00?h0oooo0P0000000`3oool000000000
002L0?ooo`<0000000<0oooo0000003oool04P3oool600000080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo0`0000040?ooo`H00000MP3o
ool00?l0oooo00<000000?ooo`000000VP3oool3000000@0oooo00<000000?ooo`3oool04`3ooolB
000000X0oooo0`0000200?ooo`00o`3oool10?ooo`030000003oool0oooo09H0oooo0`00000N0?oo
oa8000002@3oool300000800oooo003n0?ooo`80000000<0oooo000000000000T`3oool300000200
oooo2@0000070?ooo`@00000203oool4000007l0oooo003o0?oooi@0oooo0`00000R0?ooo`D00000
0P3oool5000000H0oooo100000050?ooo`D00000P03oool00?l0ooooT@3oool3000002D0oooo1000
00050?ooo`D000001P3oool3000000<0oooo100000220?ooo`00o`3ooon=0?ooo`@00000:03oool3
000000P0oooo3@0000030?ooo`030000003oool0oooo0880oooo003o0?ooohX0oooo0`00000/0?oo
o`@000002@3oool:000008T0oooo003o0?ooohL0oooo0`00000M0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool3000000/0oooo1P00002:0?ooo`00o`3ooon40?ooo`<00000
00<0oooo0000003oool0703oool=000000T0oooo1000000;0?ooo`030000003oool0oooo08/0oooo
003o0?oooh40oooo0`0000040?ooo`030000003oool0oooo01X0oooo400000080?ooo`D00000U`3o
ool00?l0ooooOP3oool3000000L0oooo00<000000?ooo`3oool06@3oool5000000T0oooo10000008
0?ooo`@00000U`3oool00?l0ooooN`3oool3000000X0oooo00<000000?ooo`3oool06P3oool50000
00X0oooo0`00002R0?ooo`00o`3ooomh0?ooo`<00000:P3oool6000000X0oooo0`00002Q0?ooo`00
o`3ooome0?ooo`<00000;P3oool6000000T0oooo1000002P0?ooo`00o`3ooomb0?ooo`<000007@3o
ool2000001@0oooo1P0000060?ooo`@00000X@3oool00?l0ooooKP3oool4000001l0oooo1000000?
0?ooo`030000003oool0oooo00<0oooo1@0000060?ooo`030000003oool0oooo0:40oooo003o0?oo
of/0oooo0`00000T0?ooo`@000003@3oool500000080oooo1000002[0?ooo`00o`3ooomX0?ooo`<0
000000<0oooo0000003oool09@3oool4000000d0oooo2P00002[0?ooo`00o`3ooomU0?ooo`<00000
103oool00`000000oooo0?ooo`0V0?ooo`@000003P3oool600000:`0oooo003o0?ooof80oooo0`00
000a0?ooo`@000001@3oool4000000H0oooo00<000000?ooo`3oool0[@3oool00?l0ooooG`3oool3
000003D0oooo3@00002e0?ooo`00o`3ooomL0?ooo`<00000703oool2000000D0oooo00<000000?oo
o`3oool04`3oool<00000;D0oooo003o0?oooeT0oooo0`0000030?ooo`030000003oool0oooo01L0
oooo3@00000:0?ooo`040000003oool0oooo0?ooo``00000^@3oool00?l0ooooEP3oool3000000<0
oooo1P00000F0?ooo`l000002@3oool<00000;d0oooo003o0?oooe<0oooo0`0000050?ooo`P00000
503oool3000000L0oooo1`0000080?ooo`T00000`03oool00?l0ooooC`3oool4000000T0oooo00<0
00000?ooo`3oool00P3oool300000180oooo1000000:0?ooo`D00000103oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0<40oooo003o0?oood`0oooo0`0000020?ooo`030000003oool0
oooo00h0oooo0`00000A0?ooo`@000002`3oool300000080oooo1@00003:0?ooo`00o`3ooom90?oo
o`<000001@3oool00`000000oooo0?ooo`0>0?ooo`8000004P3oool5000000X0oooo2@00003;0?oo
o`00o`3ooom60?ooo`<000006@3oool300000140oooo1P0000080?ooo`L00000cP3oool00?l0oooo
@`3oool3000001/0oooo0`00000C0?ooo`L000000`3oool700000=40oooo003o0?oood00oooo0`00
000M0?ooo`<000005@3oool=00000=@0oooo003o0?ooocd0oooo0`00000O0?ooo`<00000603oool8
00000=L0oooo003o0?ooocX0oooo0`00000Q0?ooo`<00000n03oool00?l0oooo=`3oool3000002@0
oooo0P00003i0?ooo`00o`3ooold0?ooo`<000009P3oool200000?X0oooo003o0?ooo`800000;P3o
ool400000080oooo00<000000?ooo`3oool08`3oool2000001<0oooo0P00003V0?ooo`00oP3oool0
10000000oooo0?ooo`00000Z0?ooo`<000001P3oool00`000000oooo0?ooo`0S0?ooo`8000004`3o
ool200000>H0oooo003n0?ooo`040000003oool0oooo000002L0oooo0`00000?0?ooo`800000303o
ool2000000D0oooo00<000000?ooo`3oool0203oool300000140oooo1000003U0?ooo`00oP3oool0
10000000oooo0?ooo`00000T0?ooo`<000004@3oool5000000P0oooo3@0000070?ooo`@000003P3o
ool500000>H0oooo003n0?ooo`040000003oool0oooo00000240oooo0`00000E0?ooo`H00000103o
ool@000000P0oooo1@0000060?ooo`P00000j03oool00?l0oooo0P00000O0?ooo`<000006P3oool6
000000030?ooo`0000000000008000001P3oool7000000T0oooo4000003Z0?ooo`00o`3ooolN0?oo
o`<000007`3oool7000000/0oooo1000000<0?ooo`P00000k`3oool00?l0oooo6`3oool3000002<0
oooo1`00000;0?ooo`<000003@3oool200000?@0oooo003o0?oooaP0oooo1000000J0?ooo`030000
003oool0oooo00X0oooo1`0000090?ooo`@00000o`3oool30?ooo`00o`3ooolE0?ooo`<000000`3o
ool00`000000oooo0?ooo`0G0?ooo`<000003@3oool8000000H0oooo0`00003o0?ooo`@0oooo003o
0?oooa80oooo0`00000O0?ooo`D000003P3oool>00000?l0oooo1@3oool00?l0oooo3P3oool40000
01/0oooo00<000000?ooo`3oool01@3oool5000000h0oooo3000003o0?ooo`H0oooo003o0?ooo`/0
oooo0`00000N0?ooo`@000001P3oool4000000l0oooo2000003o0?ooo`T0oooo003o0?ooo`P0oooo
0`00000P0?ooo`H000001P3oool4000000L0oooo00<000000?ooo`3oool0o`3ooolE0?ooo`00o`3o
ool50?ooo`<00000903oool6000000H0oooo100000030?ooo`D00000o`3ooolF0?ooo`00o`3oool2
0?ooo`<00000:@3oool6000000H0oooo2P00003o0?oooaH0oooo003n0?ooo`<000006P3oool20000
00<0oooo00<000000?ooo`3oool0303oool5000000D0oooo2@00003o0?oooaL0oooo003k0?ooo`<0
00000P3oool00`000000oooo0?ooo`0F0?ooo`X000003P3oool>00000?l0oooo6P3oool00?P0oooo
0`0000050?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000303oool>000000d0oooo
2@00003o0?oooad0oooo003e0?ooo`<00000203oool00`000000oooo0?ooo`030?ooo`L000002P3o
ool3000000L0oooo1P00000:0?ooo`P00000o`3ooolP0?ooo`00lP3oool300000100oooo2@000008
0?ooo`@000002P3oool4000000@0oooo2P00003o0?ooob<0oooo003^0?ooo`@00000503oool00`00
0000oooo0?ooo`020?ooo`8000002@3oool4000000/0oooo100000030?ooo`L00000o`3ooolV0?oo
o`00j`3oool3000001/0oooo100000090?ooo`D000002P3oool300000?l0oooo<@3oool00>P0oooo
0`00000M0?ooo`@000002P3oool6000000T0oooo1000003o0?oooc00oooo003U0?ooo`<000007`3o
ool3000000h0oooo1P0000070?ooo`<00000o`3ooola0?ooo`00hP3oool3000000030?ooo`000000
oooo01h0oooo1@0000080?ooo`030000003oool0oooo00<0oooo3P00003o0?oooc80oooo003O0?oo
o`<00000103oool00`000000oooo0?ooo`0N0?ooo`H000000P3oool5000000P0oooo2P00003o0?oo
oc<0oooo003L0?ooo`<00000:@3oool;000000X0oooo1P00003o0?ooocH0oooo003I0?ooo`<00000
;03oool900000?l0ooooB03oool00=H0oooo0`00000M0?ooo`800000503oool5000000L0oooo00<0
00000?ooo`3oool0o`3oooln0?ooo`00d`3oool3000001/0oooo3@00000?0?ooo`H0000000<0oooo
0000000000000`00003o0?oood00oooo003?0?ooo`@000007@3ooolD000000T0oooo2`00003o0?oo
od40oooo003<0?ooo`<000008@3oool6000000L0oooo200000080?ooo`T00000o`3ooom30?ooo`00
b@3oool4000001X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`D00000
303oool4000000X0oooo0`00003o0?ooodD0oooo00360?ooo`<000000`3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo00`0oooo2P0000030?ooo`D00000303oool4000000X0oooo1000
003o0?oood<0oooo00330?ooo`<000001P3oool00`000000oooo0?ooo`070?ooo`@000001`3oool0
10000000oooo0?ooo`3oool<000000<0oooo1P00000:0?ooo`<000002`3oool400000?l0oooo@`3o
ool00<00oooo0`00000B0?ooo`L000000P3oool>000000<0oooo00<000000?ooo`3oool0103oool5
000000X0oooo00<000000?ooo`3oool0o`3ooomA0?ooo`00_@3oool3000001H0oooo5`00000:0?oo
o`D00000o`3ooomM0?ooo`00^P3oool3000001/0oooo1`0000080?ooo`P00000203oool600000?l0
ooooG03oool00;L0oooo0`00000L0?ooo`8000000P3oool7000000P0oooo1`0000060?ooo`H00000
o`3ooomM0?ooo`00]03oool3000001h0oooo0`0000030?ooo`P000001`3oool8000000@0oooo00<0
00000?ooo`3oool0o`3ooomP0?ooo`00/03oool400000240oooo0`0000050?ooo`L00000203oool7
00000?l0ooooIP3oool008<0oooo0P00000X0?ooo`<000000P3oool00`000000oooo0?ooo`0P0?oo
o`<000001`3oool7000000L0oooo1@00003o0?ooofL0oooo00220?ooo`040000003oool0oooo0000
02@0oooo0`0000050?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool30000
00T0oooo1`0000070?ooo`030000003oool0oooo0?l0ooooI`3oool008D0oooo00<000000?ooo`3o
ool07`3oool3000001l0oooo1P0000060?ooo`<000002P3oool700000?l0ooooL03oool007`0oooo
100000030?ooo`8000007`3oool300000280oooo2@0000030?ooo`<00000303oool400000?l0oooo
L@3oool008<0oooo00<000000?ooo`3oool06`3oool3000001d0oooo00@000000?ooo`3oool00000
203oool;000000h0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`00P`3oool3000001P0oooo0`00
000N0?ooo`T00000203oool800000?l0ooooP@3oool009/0oooo0`00000P0?ooo`/000002`3oool5
00000?l0ooooP03oool009P0oooo0`00000K0?ooo`8000001P3oool4000000D0oooo00<000000?oo
o`3oool02`3oool300000?l0ooooP@3oool009D0oooo0`0000000`3oool000000?ooo`0J0?ooo`D0
0000103oool4000001<0oooo0`00003o0?oooh40oooo002A0?ooo`@00000103oool00`000000oooo
0?ooo`0C0?ooo`040000003oool0oooo000000<0oooo1P0000020?ooo`@00000203oool00`000000
oooo0?ooo`080?ooo`<00000o`3ooon10?ooo`00SP3oool3000001/0oooo200000040?ooo``00000
1@3oool3000000T0oooo0`00003o0?oooh40oooo002;0?ooo`<000007@3oool;000000@0oooo4`00
00080?ooo`@00000o`3ooon00?ooo`00R03oool300000200oooo100000040?ooo`@00000103ooolA
000000H0oooo1P00003o0?oooh40oooo00250?ooo`<000008P3oool7000000@0oooo00<000000?oo
o`3oool01@3oool7000000@0oooo0P0000070?ooo`D00000o`3ooon30?ooo`00PP3oool3000002D0
oooo2000000=0?ooo`H000003@3oool00`000000oooo0?ooo`3o0?oooh@0oooo001o0?ooo`<00000
;03oool6000000d0oooo00<000000?ooo`000000o`3ooonE0?ooo`00O03oool3000000030?ooo`00
0000oooo01P0oooo00<000000?ooo`3oool00`3oool2000000h0oooo1@00003o0?oooj@0oooo001i
0?ooo`<00000103oool00`000000oooo0?ooo`0F0?ooo``000000`3oool00`000000oooo0?ooo`06
0?ooo`H00000o`3ooonR0?ooo`00MP3oool3000000L0oooo00<000000?ooo`3oool05@3ooolB0000
00T0oooo1@00003o0?oooj40oooo001b0?ooo`@000002P3oool01P000000oooo0?ooo`000000oooo
000001<0oooo0`0000050?ooo`P00000303oool200000?l0ooooXP3oool006l0oooo0`00000@0?oo
o`H000004@3oool4000000H0oooo1`00003o0?ooojl0oooo001/0?ooo`<00000503oool700000100
oooo100000060?ooo`H00000o`3ooon_0?ooo`00J@3oool3000001T0oooo1`00000?0?ooo`@00000
103oool3000000030?ooo`000000000000800000o`3ooon^0?ooo`00IP3oool3000001h0oooo1`00
00080?ooo`030000003oool0oooo00<0oooo100000020?ooo`<000000`3oool300000?l0oooo[P3o
ool006<0oooo0`0000000`3oool000000?ooo`0G0?ooo`030000003oool0oooo00H0oooo1`000005
0?ooo`D000000P3oool3000000@0oooo0P0000040?ooo`<00000o`3ooon]0?ooo`00H03oool30000
00@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`@000001`3oool80000
00@0oooo2@0000040?ooo`<000000`3oool400000?l0oooo[03oool005d0oooo0`00000>0?ooo`H0
00002P3oool6000000P0oooo1`0000050?ooo`L000001@3oool800000?l0oooo[@3oool005X0oooo
0`00000@0?ooo`P000002P3oool7000000P0oooo1P00000A0?ooo`H00000o`3ooon^0?ooo`00E`3o
ool300000180oooo0`0000040?ooo`<000002`3oool6000000T0oooo1@00000B0?ooo`030000003o
ool0oooo0?l0oooo[`3oool005@0oooo0`00000F0?ooo`030000003oool0oooo00<0oooo0`00000<
0?ooo`L000001`3oool400000?l0ooooa@3oool00500oooo1000000N0?ooo`<000003`3oool80000
0080oooo1@00003o0?ooolH0oooo001=0?ooo`<000008@3oool4000000`0oooo00@000000?ooo`3o
ool0oooo3@00003o0?ooolL0oooo001:0?ooo`<000000P3oool00`000000oooo0?ooo`0N0?ooo`D0
00002`3oool5000000030?ooo`000000000000L00000o`3oooo:0?ooo`00A`3oool3000000D0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`<000003@3oool900000?l0oooo
c`3oool004@0oooo0`00000K0?ooo`T000001`3oool4000000d0oooo1@00003o0?ooom40oooo0011
0?ooo`<000007@3oool:000000L0oooo1@00000:0?ooo`030000003oool0oooo0?l0ooooe@3oool0
03h0oooo0`00000O0?ooo`<000003`3oool7000000@0oooo1P00003o0?ooomH0oooo000k0?ooo`<0
00008@3oool5000000D0oooo00<000000?ooo`3oool01`3oool@00000?l0ooooeP3oool003P0oooo
0`00000U0?ooo`/000001P3oool010000000oooo0?ooo`3oool900000?l0oooof`3oool000L0oooo
1@0000020?ooo`8000009@3oool3000001/0oooo00<000000?ooo`3oool00P3oool2000000P0oooo
200000050?ooo`@000001`3oool600000?l0oooof@3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo01h0oooo100000020?ooo`030000003oool0oooo01L0oooo
300000060?ooo`80000000<0oooo0000000000000P0000030?ooo`D00000203oool700000?l0oooo
f03oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01/0oooo
0`0000060?ooo`030000003oool0oooo01D0oooo3`0000080?ooo`X000003`3oool00`000000oooo
0?ooo`3o0?ooomL0oooo00000`3oool0000000000002000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo01P0oooo0`00000>0?ooo`800000403oool4000000L0oooo
1P0000070?ooo`P00000o`3oooo[0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool05@3oool300000100oooo1@00000>0?ooo`@000002@3oool5000000L0oooo
1@00003o0?ooond0oooo00080?ooo`800000103oool2000001D0oooo0`00000D0?ooo`L000002`3o
ool5000000T0oooo0`00003o0?ooooX0oooo000R0?ooo`<000006P3oool6000000T0oooo1P000008
0?ooo`<00000o`3ooooj0?ooo`007`3oool300000200oooo1@0000090?ooo`H00000103oool50000
00<0oooo00<000000?ooo`3oool0o`3ooood0?ooo`00703oool4000002<0oooo1`0000070?ooo`d0
00000`3oool200000?l0oooomP3oool001T0oooo0`0000030?ooo`030000003oool0oooo0280oooo
200000070?ooo`X00000103oool200000?l0oooomP3oool001H0oooo0`0000060?ooo`030000003o
ool0oooo02<0oooo0`0000000`3oool0000000000003000000d0oooo2000003o0?ooooH0oooo000B
0?ooo`@00000303oool200000280oooo0P0000030?ooo`D000002`3oool900000?l0oooom@3oool0
00l0oooo0`00000?0?ooo`D000001`3oool00`000000oooo0?ooo`030?ooo`8000004@3oool30000
00@0oooo1000000:0?ooo`P00000o`3oooof0?ooo`00303oool3000001<0oooo1P0000040?ooo`/0
00003P3oool5000000D0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3o0?ooooL0
oooo00090?ooo`<00000603oool6000000030?ooo`000000000000/000002P3oool700000?l0oooo
o`3ooolA0?ooo`001P3oool3000001/0oooo2@0000070?ooo`<000001`3oool:00000?l0ooooo`3o
oolB0?ooo`00103oool2000000030?ooo`000000oooo01X0oooo0`0000000`3oool0000000000005
000000H0oooo100000060?ooo`T00000o`3ooooo0?oooa<0oooo00070?ooo`030000003oool0oooo
01P0oooo100000020?ooo`P00000103oool3000000030?ooo`00000000000?l0ooooo`3ooolP0?oo
o`001`3oool00`000000oooo0?ooo`0@0?ooo`040000003oool0oooo000000<0oooo1@0000040?oo
o`L000000P3oool:00000?l0ooooo`3ooolM0?ooo`001`3oool00`000000oooo0?ooo`0?0?ooo`/0
000000<0oooo0000003oool01@3ooolC00000?l0ooooo`3ooolK0?ooo`00603ooolA000000D0oooo
1`0000060?ooo`D00000o`3ooooo0?oooaX0oooo000G0?ooo`@00000203oool8000000D0oooo2000
00040?ooo`<00000o`3ooooo0?oooa/0oooo000G0?ooo`D00000203oool9000000D0oooo3000003o
0?ooool0oooo703oool001L0oooo1@0000090?ooo`@0000000<0oooo0000000000000P0000070?oo
o`P00000o`3ooooo0?oooad0oooo000G0?ooo`P000001P3oool3000000@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3o0?ooool0oooo7@3oool001X0oooo3@00003o0?ooool0oooo
<`3oool001/0oooo2`00003o0?ooool0oooo=03oool001`0oooo2000003o0?ooool0oooo=P3oool0
0?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3o
oomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00
o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oo
oeX0oooo0000\
\>"],
  ImageRangeCache->{{{0, 599}, {210.875, 0}} -> {0.0413913, 0.29514, \
0.00172616, 0.00172616}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .34453 
%%ImageSize: 600 206.717 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0521186 1.05212 -0.343311 1.05212 [
[.14863 .25506 -8.43515 -9 ]
[.14863 .25506 9.56485 0 ]
[.46395 .1531 -2.9941 -9 ]
[.46395 .1531 3.0059 0 ]
[.80438 .04307 -6.39882 -9 ]
[.80438 .04307 5.60118 0 ]
[.4623 .08793 -4.9884 -12.75 ]
[.4623 .08793 5.0116 0 ]
[.99327 -0.00224 0 -5.94996 ]
[.99327 -0.00224 24 3.05004 ]
[1.00077 .0087 0 -5.94335 ]
[1.00077 .0087 6 3.05665 ]
[1.00822 .01957 0 -5.9368 ]
[1.00822 .01957 18 3.0632 ]
[1.06463 -0.00957 0 -8.41822 ]
[1.06463 -0.00957 10 4.33178 ]
[ 0 0 0 0 ]
[ 1 .34453 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.00053 .31568 m
.97952 0 L
s
.14781 .26819 m
.1474 .27475 L
s
[(-10)] .14863 .25506 -0.06276 1 Mshowa
.46393 .16626 m
.46391 .17283 L
s
[(0)] .46395 .1531 -0.00197 1 Mshowa
.80525 .05619 m
.80569 .06275 L
s
[(10)] .80438 .04307 .06647 1 Mshowa
.125 Mabswid
.20915 .24841 m
.20895 .25235 L
s
.27141 .22833 m
.27126 .23227 L
s
.33461 .20795 m
.33451 .2119 L
s
.39878 .18726 m
.39872 .19121 L
s
.53008 .14492 m
.53012 .14887 L
s
.59727 .12326 m
.59736 .1272 L
s
.66551 .10125 m
.66566 .1052 L
s
.73483 .0789 m
.73503 .08284 L
s
.08737 .28768 m
.08707 .29161 L
s
.0278 .30689 m
.02747 .31082 L
s
.87681 .03312 m
.87713 .03705 L
s
.94952 .00967 m
.9499 .0136 L
s
gsave
.4623 .08793 -65.9884 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
.97952 0 m
.99935 .02889 L
s
.98075 .00179 m
.97449 .00381 L
s
[(-0.5)] .99327 -0.00224 -1 .32221 Mshowa
.98825 .01272 m
.98199 .01473 L
s
[(0)] 1.00077 .0087 -1 .32075 Mshowa
.9957 .02357 m
.98943 .02557 L
s
[(0.5)] 1.00822 .01957 -1 .31929 Mshowa
.125 Mabswid
.98225 .00398 m
.9785 .00519 L
s
.98376 .00617 m
.98 .00738 L
s
.98526 .00836 m
.9815 .00957 L
s
.98675 .01054 m
.983 .01175 L
s
.98974 .0149 m
.98599 .0161 L
s
.99124 .01707 m
.98748 .01827 L
s
.99272 .01924 m
.98897 .02044 L
s
.99421 .0214 m
.99045 .0226 L
s
.99718 .02573 m
.99342 .02692 L
s
.99866 .02788 m
.9949 .02908 L
s
gsave
1.06463 -0.00957 -61 -12.4182 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .34453 L
0 .34453 L
closepath
clip
newpath
0 0 0 r
2 Mabswid
.06023 .32887 m
.04891 .30502 L
s
.06023 .32887 m
.0261 .31236 L
s
.05701 .32601 m
.04728 .30555 L
s
.07974 .32266 m
.09934 .31642 L
s
.08463 .3211 m
.06201 .30081 L
s
.08626 .32059 m
.06365 .30028 L
s
.0359 .3171 m
.05054 .3124 L
s
.09934 .31642 m
.10155 .31441 L
s
.09934 .31642 m
.10319 .31389 L
s
.10155 .31441 m
.10212 .31293 L
s
.10319 .31389 m
.10376 .3124 L
s
.02285 .31341 m
.0326 .31027 L
s
.10212 .31293 m
.10163 .31047 L
s
.10376 .3124 m
.10327 .30995 L
s
.11574 .3112 m
.14047 .30332 L
s
.07554 .31095 m
.08864 .30676 L
s
.10163 .31047 m
.0995 .30854 L
s
.10327 .30995 m
.10114 .30801 L
s
.12068 .30962 m
.09824 .28915 L
s
.12232 .3091 m
.09989 .28861 L
s
.0995 .30854 m
.09571 .30712 L
s
.10114 .30801 m
.09736 .3066 L
s
.09571 .30712 m
.093 .30668 L
s
.04238 .30712 m
.05218 .30397 L
s
.08864 .30676 m
.09086 .30474 L
s
.08864 .30676 m
.0925 .30421 L
s
.093 .30668 m
.08864 .30676 L
s
.09464 .30615 m
.08864 .30676 L
s
.09736 .3066 m
.09464 .30615 L
s
.09086 .30474 m
.09142 .30324 L
s
.0925 .30421 m
.09307 .30271 L
s
.13413 .29747 m
.13882 .30385 L
s
.14047 .30332 m
.13413 .29747 L
s
.09142 .30324 m
.09092 .30077 L
s
.09307 .30271 m
.09257 .30024 L
s
.07679 .29605 m
.05709 .30239 L
s
.09092 .30077 m
.08769 .29784 L
s
.09257 .30024 m
.08934 .29731 L
s
.08769 .29784 m
.08389 .29642 L
s
.1587 .29751 m
.14983 .27254 L
s
.1587 .29751 m
.12312 .28114 L
s
.08934 .29731 m
.08554 .29589 L
s
.08389 .29642 m
.08116 .29597 L
s
.08116 .29597 m
.07679 .29605 L
s
.08281 .29544 m
.07679 .29605 L
s
.08554 .29589 m
.08281 .29544 L
s
.15555 .29458 m
.14816 .27308 L
s
.17701 .29168 m
.20379 .28315 L
s
.09328 .29074 m
.10486 .28702 L
s
.18202 .29009 m
.1599 .2693 L
s
.18369 .28956 m
.16158 .26876 L
s
.19754 .27722 m
.20212 .28369 L
s
.20379 .28315 m
.19754 .27722 L
s
.12586 .28159 m
.14922 .27407 L
s
.12312 .28114 m
.14983 .27254 L
s
.18746 .28044 m
.17906 .2725 L
s
.1732 .27969 m
.18327 .27647 L
s
.21556 .27941 m
.23921 .27188 L
s
.20933 .27345 m
.21556 .27941 L
s
.21725 .27887 m
.20933 .27345 L
s
.23751 .27242 m
.19361 .25845 L
s
.23921 .27188 m
.19531 .2579 L
s
.15486 .27092 m
.18178 .26226 L
s
.24768 .26918 m
.25958 .26539 L
s
.18811 .26826 m
.18009 .2628 L
s
.18178 .26226 m
.18811 .26826 L
s
.25278 .26755 m
.23102 .24641 L
s
.25448 .26701 m
.23273 .24586 L
s
.2698 .26213 m
.28176 .25832 L
s
.27492 .2605 m
.25329 .23924 L
s
.27663 .25996 m
.255 .23869 L
s
.19361 .25845 m
.21738 .2508 L
s
.24416 .25698 m
.26466 .25042 L
s
.22365 .25686 m
.21568 .25135 L
s
.21738 .2508 m
.22365 .25686 L
s
.29617 .2524 m
.2907 .25147 L
s
.30234 .25177 m
.29617 .2524 L
s
.29789 .25185 m
.29242 .25093 L
s
.30234 .25177 m
.29789 .25185 L
s
.30578 .25067 m
.30234 .25177 L
s
.2907 .25147 m
.28694 .25 L
s
.29242 .25093 m
.28866 .24945 L
s
.30821 .24856 m
.30578 .25067 L
s
.30993 .24802 m
.30578 .25067 L
s
.28694 .25 m
.28113 .24649 L
s
.28866 .24945 m
.28285 .24594 L
s
.30963 .24544 m
.30821 .24856 L
s
.2259 .24806 m
.23786 .24421 L
s
.31135 .24489 m
.30993 .24802 L
s
.28113 .24649 m
.27805 .24345 L
s
.28285 .24594 m
.27977 .24289 L
s
.29177 .24577 m
.2846 .23865 L
s
.30932 .24285 m
.30963 .24544 L
s
.31105 .2423 m
.31135 .24489 L
s
.32648 .24408 m
.3386 .24022 L
s
.27805 .24345 m
.27565 .23882 L
s
.27977 .24289 m
.27738 .23827 L
s
.30698 .23822 m
.30932 .24285 L
s
.2887 .24273 m
.29905 .23941 L
s
.30211 .24247 m
.29496 .23533 L
s
.33167 .24243 m
.31034 .22088 L
s
.30871 .23767 m
.31105 .2423 L
s
.3334 .24188 m
.31208 .22032 L
s
.28768 .24171 m
.29803 .23839 L
s
.24814 .2409 m
.26016 .23703 L
s
.27565 .23882 m
.27532 .23622 L
s
.34381 .23856 m
.35598 .23469 L
s
.27738 .23827 m
.27704 .23567 L
s
.30392 .23516 m
.30698 .23822 L
s
.30565 .2346 m
.30871 .23767 L
s
.34902 .2369 m
.32779 .21527 L
s
.35076 .23635 m
.32953 .2147 L
s
.27532 .23622 m
.2767 .23306 L
s
.27704 .23567 m
.27843 .23251 L
s
.2981 .23161 m
.30392 .23516 L
s
.29983 .23106 m
.30565 .2346 L
s
.2767 .23306 m
.28085 .23037 L
s
.27843 .23251 m
.28085 .23037 L
s
.29432 .23011 m
.2981 .23161 L
s
.36644 .23136 m
.37693 .22802 L
s
.29605 .22956 m
.29983 .23106 L
s
.28085 .23037 m
.28431 .22926 L
s
.2888 .22917 m
.29432 .23011 L
s
.29053 .22862 m
.29605 .22956 L
s
.28431 .22926 m
.2888 .22917 L
s
.28431 .22926 m
.29053 .22862 L
s
.37343 .22913 m
.33766 .22299 L
s
.34868 .22488 m
.35057 .20793 L
s
.35043 .22432 m
.35233 .20737 L
s
.30512 .22256 m
.31731 .21864 L
s
.39798 .22131 m
.38941 .19543 L
s
.39798 .22131 m
.36465 .2034 L
s
.395 .21821 m
.38764 .196 L
s
.32254 .21695 m
.33478 .21301 L
s
.41913 .21457 m
.42621 .21232 L
s
.42444 .21288 m
.4161 .18684 L
s
.42444 .21288 m
.40363 .19086 L
s
.42621 .21232 m
.41908 .19002 L
s
.3453 .20963 m
.35585 .20623 L
s
.44928 .20497 m
.45641 .2027 L
s
.44928 .20497 m
.42861 .18281 L
s
.44928 .20497 m
.4161 .18684 L
s
.36113 .20453 m
.37171 .20113 L
s
.45106 .2044 m
.4304 .18224 L
s
.46355 .20043 m
.4707 .19815 L
s
.46891 .19872 m
.44835 .17646 L
s
.4707 .19815 m
.47375 .17106 L
s
.38232 .19771 m
.39296 .19429 L
s
.46875 .19605 m
.47179 .16892 L
s
.48683 .19301 m
.49761 .18958 L
s
.39829 .19257 m
.40897 .18914 L
s
.49222 .1913 m
.47179 .16892 L
s
.50939 .1872 m
.50278 .18246 L
s
.50747 .18507 m
.53281 .177 L
s
.42325 .18454 m
.43578 .18051 L
s
.50651 .18401 m
.53186 .17593 L
s
.53654 .17855 m
.52995 .17379 L
s
.44296 .1782 m
.45375 .17472 L
s
.50796 .1753 m
.50132 .17053 L
s
.50603 .17316 m
.51692 .16968 L
s
.50507 .17209 m
.51596 .1686 L
s
.52066 .17124 m
.51403 .16645 L
s
.55283 .17062 m
.54729 .16963 L
s
.55926 .16995 m
.55283 .17062 L
s
.55466 .17004 m
.54911 .16905 L
s
.55926 .16995 m
.55466 .17004 L
s
.56291 .16878 m
.55926 .16995 L
s
.54729 .16963 m
.54356 .16807 L
s
.54911 .16905 m
.54538 .16748 L
s
.56562 .16654 m
.56291 .16878 L
s
.56745 .16596 m
.56291 .16878 L
s
.54356 .16807 m
.53792 .16434 L
s
.492 .16798 m
.48531 .16318 L
s
.54538 .16748 m
.53974 .16376 L
s
.5674 .16322 m
.56562 .16654 L
s
.56923 .16264 m
.56745 .16596 L
s
.49005 .16582 m
.51552 .15763 L
s
.48907 .16475 m
.51455 .15655 L
s
.53792 .16434 m
.53504 .16111 L
s
.53974 .16376 m
.53687 .16052 L
s
.56734 .16048 m
.5674 .16322 L
s
.56917 .15989 m
.56923 .16264 L
s
.5849 .16178 m
.62179 .15003 L
s
.53504 .16111 m
.53303 .15619 L
s
.53687 .16052 m
.53486 .1556 L
s
.56538 .15556 m
.56734 .16048 L
s
.59041 .16002 m
.57056 .13713 L
s
.56722 .15497 m
.56917 .15989 L
s
.59225 .15944 m
.57241 .13653 L
s
.51928 .15921 m
.51262 .15438 L
s
.53303 .15619 m
.53294 .15343 L
s
.53486 .1556 m
.53477 .15284 L
s
.56253 .1523 m
.56538 .15556 L
s
.56437 .15171 m
.56722 .15497 L
s
.53294 .15343 m
.53468 .15008 L
s
.53477 .15284 m
.53652 .14949 L
s
.61439 .15239 m
.59468 .12937 L
s
.55688 .14853 m
.56253 .1523 L
s
.61624 .1518 m
.59654 .12877 L
s
.55872 .14794 m
.56437 .15171 L
s
.53468 .15008 m
.53922 .14721 L
s
.53652 .14949 m
.53922 .14721 L
s
.55313 .14694 m
.55688 .14853 L
s
.55497 .14635 m
.55872 .14794 L
s
.62921 .14767 m
.65153 .14056 L
s
.53922 .14721 m
.5429 .14603 L
s
.54754 .14594 m
.55313 .14694 L
s
.54938 .14535 m
.55497 .14635 L
s
.5429 .14603 m
.54754 .14594 L
s
.5429 .14603 m
.54938 .14535 L
s
.63478 .1459 m
.6152 .12276 L
s
.63664 .1453 m
.61707 .12216 L
s
.65153 .14056 m
.65435 .13827 L
s
.65153 .14056 m
.65621 .13768 L
s
.56502 .13891 m
.57797 .13474 L
s
.65435 .13827 m
.65529 .13658 L
s
.65621 .13768 m
.65716 .13598 L
s
.65529 .13658 m
.65532 .13378 L
s
.65716 .13598 m
.65719 .13318 L
s
.66648 .1358 m
.64709 .1125 L
s
.66835 .1352 m
.67022 .13461 L
s
.64898 .11189 m
.66835 .1352 L
s
.67022 .13461 m
.65086 .11129 L
s
.6721 .13401 m
.67397 .13341 L
s
.65274 .11068 m
.6721 .13401 L
s
.65532 .13378 m
.65256 .13047 L
s
.67397 .13341 m
.65463 .11007 L
s
.64137 .12844 m
.62643 .13323 L
s
.65719 .13318 m
.65443 .12987 L
s
.67585 .13282 m
.67772 .13222 L
s
.65652 .10946 m
.67585 .13282 L
s
.67772 .13222 m
.6584 .10886 L
s
.6796 .13162 m
.68148 .13102 L
s
.66029 .10825 m
.6796 .13162 L
s
.58911 .13116 m
.60213 .12697 L
s
.68148 .13102 m
.66218 .10764 L
s
.65256 .13047 m
.64884 .12886 L
s
.68336 .13042 m
.68523 .12983 L
s
.66407 .10703 m
.68336 .13042 L
s
.65443 .12987 m
.65071 .12826 L
s
.68523 .12983 m
.66596 .10642 L
s
.68711 .12923 m
.689 .12863 L
s
.66785 .10582 m
.68711 .12923 L
s
.64884 .12886 m
.64604 .12835 L
s
.689 .12863 m
.66975 .10521 L
s
.64604 .12835 m
.64137 .12844 L
s
.64791 .12775 m
.64137 .12844 L
s
.65071 .12826 m
.64791 .12775 L
s
.69088 .12803 m
.69276 .12743 L
s
.67164 .1046 m
.69088 .12803 L
s
.69276 .12743 m
.67353 .10399 L
s
.69464 .12683 m
.69653 .12623 L
s
.67543 .10338 m
.69464 .12683 L
s
.69653 .12623 m
.67732 .10277 L
s
.7003 .12503 m
.72868 .11599 L
s
.7003 .12503 m
.70446 .10965 L
s
.60959 .12457 m
.62268 .12035 L
s
.70218 .12443 m
.70636 .10904 L
s
.72518 .10867 m
.72678 .11659 L
s
.72868 .11599 m
.72518 .10867 L
s
.64709 .1125 m
.64898 .11189 L
s
.74008 .11236 m
.76872 .10324 L
s
.73471 .10563 m
.74008 .11236 L
s
.74199 .11175 m
.73471 .10563 L
s
.65086 .11129 m
.65274 .11068 L
s
.65463 .11007 m
.65652 .10946 L
s
.70636 .10904 m
.68112 .10155 L
s
.6584 .10886 m
.66029 .10825 L
s
.75342 .10811 m
.73458 .08434 L
s
.66218 .10764 m
.66407 .10703 L
s
.75533 .1075 m
.7365 .08372 L
s
.66596 .10642 m
.66785 .10582 L
s
.66975 .10521 m
.67164 .1046 L
s
.67353 .10399 m
.67543 .10338 L
s
.7634 .09646 m
.76681 .10385 L
s
.76872 .10324 m
.7634 .09646 L
s
.68394 .10206 m
.70868 .0941 L
s
.68112 .10155 m
.70968 .09236 L
s
.78023 .09957 m
.78407 .09835 L
s
.77743 .09905 m
.78023 .09957 L
s
.77374 .09741 m
.77743 .09905 L
s
.71704 .09854 m
.70777 .09297 L
s
.70968 .09236 m
.71704 .09854 L
s
.77935 .09844 m
.78319 .09722 L
s
.77374 .09741 m
.77935 .09844 L
s
.78407 .09835 m
.78511 .0966 L
s
.77197 .09514 m
.77374 .09741 L
s
.78319 .09722 m
.78528 .09373 L
s
.78511 .0966 m
.78528 .09373 L
s
.79755 .09406 m
.79474 .09354 L
s
.80141 .09283 m
.79755 .09406 L
s
.78528 .09373 m
.78367 .08857 L
s
.79474 .09354 m
.79106 .09188 L
s
.79667 .09292 m
.79106 .09188 L
s
.80053 .09169 m
.79667 .09292 L
s
.80246 .09108 m
.80141 .09283 L
s
.79106 .09188 m
.7856 .08795 L
s
.80264 .08819 m
.80053 .09169 L
s
.80264 .08819 m
.80246 .09108 L
s
.78367 .08857 m
.77122 .07255 L
s
.80088 .08591 m
.80264 .08819 L
s
.7856 .08795 m
.77316 .07192 L
s
.72882 .08619 m
.74227 .08187 L
s
.82268 .08605 m
.83627 .08172 L
s
.8285 .0842 m
.81013 .06002 L
s
.83044 .08358 m
.81209 .05939 L
s
.81357 .08044 m
.81075 .07991 L
s
.82027 .07972 m
.81357 .08044 L
s
.81075 .07991 m
.80706 .07824 L
s
.81551 .07982 m
.8127 .07929 L
s
.82027 .07972 m
.81551 .07982 L
s
.82999 .07662 m
.82027 .07972 L
s
.8127 .07929 m
.809 .07762 L
s
.80706 .07824 m
.80442 .0748 L
s
.809 .07762 m
.80637 .07418 L
s
.85186 .07676 m
.86358 .07303 L
s
.83302 .07422 m
.82999 .07662 L
s
.83497 .0736 m
.82999 .07662 L
s
.85576 .07552 m
.8632 .04294 L
s
.85772 .07489 m
.86518 .04231 L
s
.80442 .0748 m
.80461 .07187 L
s
.76542 .07441 m
.77898 .07005 L
s
.8341 .07245 m
.83302 .07422 L
s
.80637 .07418 m
.80655 .07125 L
s
.83605 .07183 m
.83497 .0736 L
s
.83431 .06952 m
.8341 .07245 L
s
.80461 .07187 m
.80567 .0701 L
s
.83627 .0689 m
.83605 .07183 L
s
.80655 .07125 m
.80762 .06947 L
s
.80567 .0701 m
.81063 .06707 L
s
.8317 .06606 m
.83431 .06952 L
s
.80762 .06947 m
.81063 .06707 L
s
.87534 .06928 m
.88713 .06553 L
s
.83366 .06543 m
.83627 .0689 L
s
.81063 .06707 m
.82039 .06394 L
s
.88319 .06678 m
.83757 .05119 L
s
.828 .06437 m
.8317 .06606 L
s
.82996 .06374 m
.83366 .06543 L
s
.82517 .06384 m
.828 .06437 L
s
.82039 .06394 m
.82517 .06384 L
s
.82039 .06394 m
.82713 .06321 L
s
.82713 .06321 m
.82996 .06374 L
s
.80427 .06191 m
.81795 .05751 L
s
.90486 .05988 m
.91871 .05547 L
s
.91079 .05799 m
.89296 .03337 L
s
.91277 .05736 m
.89495 .03273 L
s
.88991 .05605 m
.89103 .05426 L
s
.88991 .05605 m
.89301 .05362 L
s
.88708 .05552 m
.88991 .05605 L
s
.89103 .05426 m
.8896 .04895 L
s
.89301 .05362 m
.89158 .04832 L
s
.83364 .05246 m
.84544 .04866 L
s
.8896 .04895 m
.88987 .04598 L
s
.89158 .04832 m
.89185 .04534 L
s
.88987 .04598 m
.891 .04417 L
s
.94569 .04544 m
.95251 .0447 L
s
.94004 .04436 m
.94569 .04544 L
s
.91877 .04539 m
.92359 .04529 L
s
.91341 .04133 m
.91877 .04539 L
s
.89185 .04534 m
.89298 .04353 L
s
.92359 .04529 m
.92474 .04348 L
s
.92076 .04475 m
.92359 .04529 L
s
.85727 .04485 m
.86914 .04103 L
s
.94769 .0448 m
.95251 .0447 L
s
.94204 .04373 m
.94769 .0448 L
s
.9154 .04069 m
.92076 .04475 L
s
.95251 .0447 m
.9605 .04216 L
s
.93554 .04147 m
.94004 .04436 L
s
.891 .04417 m
.8961 .04108 L
s
.93754 .04084 m
.94204 .04373 L
s
.89298 .04353 m
.8961 .04108 L
s
.9605 .04216 m
.96367 .03971 L
s
.9605 .04216 m
.96568 .03907 L
s
.93219 .03676 m
.93554 .04147 L
s
.90972 .03961 m
.91341 .04133 L
s
.8961 .04108 m
.90206 .03917 L
s
.93419 .03612 m
.93754 .04084 L
s
.91172 .03897 m
.9154 .04069 L
s
.96367 .03971 m
.96603 .03607 L
s
.90689 .03907 m
.90972 .03961 L
s
.90206 .03917 m
.90689 .03907 L
s
.90206 .03917 m
.90888 .03843 L
s
.96568 .03907 m
.96803 .03543 L
s
.90888 .03843 m
.91172 .03897 L
s
.93167 .03258 m
.93219 .03676 L
s
.93283 .03075 m
.93419 .03612 L
s
.96603 .03607 m
.96555 .03189 L
s
.96803 .03543 m
.96756 .03125 L
s
.88699 .03529 m
.90092 .0308 L
s
.9323 .02655 m
.93167 .03258 L
s
.96555 .03189 m
.96224 .02714 L
s
.96756 .03125 m
.96425 .0265 L
s
.9323 .02655 m
.93283 .03075 L
s
.92545 .02729 m
.92492 .02308 L
s
.96224 .02714 m
.9569 .02303 L
s
.93294 .0205 m
.9323 .02655 L
s
.96425 .0265 m
.95975 .02358 L
s
.92576 .02427 m
.93178 .02234 L
s
.95975 .02358 m
.95238 .0201 L
s
.92492 .02308 m
.93294 .0205 L
s
.9569 .02303 m
.95238 .0201 L
s
.95238 .0201 m
.94501 .01661 L
s
.94786 .01716 m
.9539 .01522 L
s
.95307 .01402 m
.95759 .01696 L
s
.94501 .01661 m
.95307 .01402 L
s
0 g
.25 Mabswid
.00053 .31568 m
.97952 0 L
s
.14781 .26819 m
.1474 .27475 L
s
[(-10)] .14863 .25506 -0.06276 1 Mshowa
.46393 .16626 m
.46391 .17283 L
s
[(0)] .46395 .1531 -0.00197 1 Mshowa
.80525 .05619 m
.80569 .06275 L
s
[(10)] .80438 .04307 .06647 1 Mshowa
.125 Mabswid
.20915 .24841 m
.20895 .25235 L
s
.27141 .22833 m
.27126 .23227 L
s
.33461 .20795 m
.33451 .2119 L
s
.39878 .18726 m
.39872 .19121 L
s
.53008 .14492 m
.53012 .14887 L
s
.59727 .12326 m
.59736 .1272 L
s
.66551 .10125 m
.66566 .1052 L
s
.73483 .0789 m
.73503 .08284 L
s
.08737 .28768 m
.08707 .29161 L
s
.0278 .30689 m
.02747 .31082 L
s
.87681 .03312 m
.87713 .03705 L
s
.94952 .00967 m
.9499 .0136 L
s
gsave
.4623 .08793 -65.9884 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{600, 206.688},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40009H0000cR000`400?l00000o`00003oo`3ooooo
0?oooeX0oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooe40oooo
0P0000070?ooo`00o`3ooooo0?oooe80oooo00<000000?ooo`3oool01@3oool00?l0ooooo`3ooomC
0?ooo`030000003oool0oooo00@0oooo003o0?ooool0ooooDP3oool00`000000oooo000000050?oo
o`00o`3ooooo0?oooe40oooo00@000000?ooo`3oool000001@3oool00?l0ooooo`3ooom@0?ooo`<0
000000<0oooo000000000000103oool00?l0ooooo`3oool_0?ooo`800000103oool2000000@0oooo
0P00000M0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool00000203oool010000000oooo
0?ooo`00000L0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0?ooo`0J0?ooo`00o`3ooooo0?ooobP0oooo100000020?ooo`040000003oool0oooo000000T0
oooo0P00000M0?ooo`00o`3ooooo0?ooobh0oooo00@000000?ooo`3oool000002@3oool00`000000
oooo0?ooo`0L0?ooo`00o`3ooooo0?oooah0oooo0P00000?0?ooo`8000002P3oool3000001`0oooo
003o0?ooool0oooo6`3oool3000000030?ooo`000000000000`0oooo0P00000[0?ooo`00o`3ooooo
0?oooaP0oooo0`0000020?ooo`80000000<0oooo0000000000002P3oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?oooaD0oooo0`0000070?ooo`<000002P3oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?oooa80oooo0`00000;0?ooo`<000002@3oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?ooo`h0oooo1000000@0?ooo`800000203oool010000000oooo0?ooo`00
000Z0?ooo`00o`3ooooo0?ooo`/0oooo0`0000000`3oool000000?ooo`0@0?ooo`<000002@3oool2
000002/0oooo003o0?ooool0oooo203oool3000000@0oooo00<000000?ooo`0000003`3oool40000
00`0oooo0P0000040?ooo`800000103oool2000001/0oooo003o0?ooool0oooo1@3oool3000000@0
oooo1`00000>0?ooo`80000000<0oooo0000000000002P3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo000001X0oooo003o0?ooool0oooo0P3oool3000000H0oooo2@00000?0?oo
o`<000002P3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0oooo01P0oooo003o0?oo
ooh0oooo0`0000090?ooo`X000003`3oool3000000T0oooo00@000000?ooo`3oool000002@3oool2
000001/0oooo003o0?oooo/0oooo0`0000070?ooo`030000003oool0oooo00D0oooo1P00000C0?oo
o`030000003oool0oooo00H0oooo00@000000?ooo`3oool000002@3oool00`000000oooo0?ooo`0J
0?ooo`00o`3ooooh0?ooo`<000001@3oool7000000P0oooo1@00000@0?ooo`@00000203oool20000
00X0oooo0`00000J0?ooo`00o`3ooooe0?ooo`<000001`3oool7000000X0oooo1@00000?0?ooo`@0
0000<@3oool00?l0oooolP3oool3000000X0oooo1`00000<0?ooo`D000003@3oool200000080oooo
00<000000?ooo`3oool0;P3oool00?l0ooook`3oool3000000d0oooo0`000000103oool000000000
0000000=0?ooo`D000003P3oool300000300oooo003o0?oookP0oooo1@0000020?ooo`800000:P3o
ool4000000@0oooo00<000000?ooo`3oool02@3oool200000080oooo0`00000?0?ooo`@000003P3o
ool3000002l0oooo003o0?oookX0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo02@0oooo0`0000050?ooo`D000003P3oool300000100oooo1000000o0?ooo`00o`3ooonj
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0Q0?ooo`<000001P3o
ool6000000l0oooo0`00000@0?ooo`<00000@03oool00?l0oooo^P3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool07P3oool3000000030?ooo`000000oooo00<0oooo1`00
000A0?ooo`<00000403oool300000400oooo003o0?oookX0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo01/0oooo0`0000040?ooo`040000003oool0oooo0?ooo`T00000
103oool00`000000oooo0?ooo`090?ooo`<00000403oool300000400oooo003o0?oookT0oooo0P00
00040?ooo`8000006`3oool3000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`<0000000<0oooo000000000000100000090?ooo`@000003`3oool300000400oooo003o
0?ooomT0oooo0`0000050?ooo`030000003oool0oooo00`0oooo300000070?ooo`D000003@3oool4
00000400oooo003o0?ooomH0oooo0`0000050?ooo`D000002`3oool?000000<0oooo00<000000?oo
o`3oool00P3oool6000000T0oooo100000110?ooo`00o`3ooooC0?ooo`<000001@3oool7000000/0
oooo10000000103oool000000000000000050?ooo`P00000103oool8000000030?ooo`0000000000
00D00000@`3oool00?l0ooood03oool3000000L0oooo1P00000<0?ooo`@000000`3oool3000000D0
oooo1P0000060?ooo`h00000A03oool00?l0ooooc@3oool3000000@0oooo00<000000?ooo`3oool0
103oool00`000000oooo00000002000000`0oooo0`0000040?ooo`<000001P3oool4000000P0oooo
200000190?ooo`00o`3oooo90?ooo`@00000103oool5000000L0oooo0`00000<0?ooo`@00000103o
ool300000680oooo003o0?ooolH0oooo0`0000050?ooo`L000001`3oool4000000`0oooo10000005
0?ooo`<00000H@3oool00?l0oooo``3oool3000000L0oooo1`0000080?ooo`<000003@3oool40000
00H0oooo0P00001Q0?ooo`00o`3oooo00?ooo`<000002`3oool00`000000oooo0?ooo`06000000D0
oooo0`00000=0?ooo`D000001@3oool3000000@0oooo00<000000?ooo`3oool0F@3oool00?l0oooo
_@3oool3000000D0oooo00<000000?ooo`3oool0303oool600000080oooo0`00000;0?ooo`H00000
1`3oool7000005/0oooo003o0?oookX0oooo0`000000103oool000000?ooo`3oool500000140oooo
2000000;0?ooo`@000001`3oool8000005`0oooo003o0?oookL0oooo0`0000030?ooo`P000005@3o
ool6000001@0oooo1P00001O0?ooo`00o`3ooond0?ooo`<000001@3oool8000000H0oooo00<00000
0?ooo`0000003P3oool800000140oooo00<000000?ooo`3oool0HP3oool00?l0oooo/@3oool30000
00P0oooo00<000000?ooo`0000000`3oool3000000030?ooo`000000000000L00000303oool30000
0080oooo1P0000050?ooo`030000003oool0oooo06/0oooo003o0?ooojh0oooo0`00000@0?ooo`l0
00002`3oool3000000D0oooo2P00001/0?ooo`00o`3ooon[0?ooo`<000004@3ooolA000000/0oooo
0`0000080?ooo`H00000K@3oool00?l0ooooY`3oool4000001<0oooo100000020?ooo`<000001P3o
ool3000000X0oooo100000070?ooo`D00000K`3oool00?l0ooooY03oool3000000@0oooo1@00000=
0?ooo`@00000103oool3000000D0oooo0`00000:0?ooo`<000001`3oool400000740oooo003o0?oo
oj40oooo0`0000040?ooo`P000003@3oool3000000H0oooo0`0000040?ooo`@000002@3oool30000
00030?ooo`000000oooo00D0oooo00<000000?ooo`3oool0L@3oool00?`0oooo0P0000000`3oool0
00000000002L0?ooo`<000001`3oool6000000l0oooo0`0000060?ooo`@000000P3oool4000000X0
oooo1P00001i0?ooo`00o@3oool00`000000oooo0000002J0?ooo`<000003P3oool3000000h0oooo
100000060?ooo`<000000P3oool3000000T0oooo1`00001j0?ooo`00oP3oool00`000000oooo0?oo
o`2F0?ooo`<000004P3oool3000000d0oooo1P0000030?ooo`P000002@3oool5000007d0oooo003l
0?ooo`80000000<0oooo000000000000T`3oool3000001H0oooo0P00000?0?ooo`h000000P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo07h0oooo003o0?oooi80oooo0`0000020?oo
o`030000003oool0oooo01@0oooo0`00000@0?ooo`H000000P3oool8000008P0oooo003o0?ooohl0
oooo0`0000050?ooo`D000004`3oool300000140oooo00<000000?ooo`3oool0103oool6000008T0
oooo003o0?oooh`0oooo0`0000050?ooo`P00000503oool3000000T0oooo00<000000?ooo`3oool0
2@3oool6000008/0oooo003o0?ooohT0oooo0`0000080?ooo`H000005`3oool3000000L0oooo0`00
00090?ooo`D00000S@3oool00?l0ooooQ@3oool4000000l0oooo0`00000F0?ooo`@000001`3oool3
000000T0oooo00<000000?ooo`3oool0SP3oool00?l0ooooPP3oool3000000@0oooo00<000000?oo
o`3oool03@3oool3000001H0oooo1@0000040?ooo`<00000V`3oool00?l0ooooO`3oool3000000@0
oooo1@00000?0?ooo`8000005P3oool;000009`0oooo003o0?ooog`0oooo0`0000040?ooo`T00000
3P3oool3000000l0oooo00<000000?ooo`3oool00`3oool3000000030?ooo`000000000000D00000
W03oool00?l0ooooN@3oool3000000@0oooo3@00000>0?ooo`<000002@3oool010000000oooo0?oo
o`3oool3000000@0oooo0P0000030?ooo`H00000W03oool00?l0ooooMP3oool3000000@0oooo2P00
00030?ooo`@000003P3oool3000000L0oooo0`0000030?ooo`T00000Y03oool00?l0ooooL`3oool3
000000<0oooo2`0000070?ooo`@000003P3oool3000000L0oooo0`0000030?ooo`L00000Y@3oool0
0?l0ooooL03oool3000000<0oooo3000000;0?ooo`030000003oool0oooo00h0oooo0P0000080?oo
o`<000000`3oool500000:H0oooo003o0?ooofd0oooo0`0000000`3oool000000?ooo`0=000001h0
oooo0`0000060?ooo`D00000[@3oool00?l0ooooJP3oool3000000<0oooo2P0000000`3oool00000
00000005000001D0oooo00<000000?ooo`3oool01@3oool300000080oooo1`00002^0?ooo`00o`3o
oomW0?ooo`<000000`3oool>000000@0oooo1P00000=0?ooo`040000003oool0oooo0?ooo`<00000
1`3oool700000080oooo00<000000?ooo`3oool0[@3oool00?l0ooooH`3oool4000000<0oooo4@00
00060?ooo`L000002P3oool2000000<0oooo100000030?ooo`H00000]@3oool00?l0ooooH03oool3
000000<0oooo00<000000?ooo`0000004`0000080?ooo`D000002@3oool2000000@0oooo2`00002f
0?ooo`00o`3ooomM0?ooo`<000001@3ooolH000000P0oooo0`00000:0?ooo`8000001@3oool50000
0;/0oooo003o0?oooeX0oooo0`0000080?oooaT000001`3oool3000000X0oooo0`0000050?ooo`80
0000_@3oool00?l0ooooE`3oool3000000d0oooo600000060?ooo`<000002@3oool400000<@0oooo
003o0?oooe@0oooo0`00000A0?oooaP00000103oool4000000H0oooo1`0000340?ooo`00o`3ooomA
0?ooo`<000005@3ooolG000000@0oooo0`0000040?ooo`H000000P3oool200000<@0oooo003o0?oo
odh0oooo0`0000040?ooo`D000003`3ooolH000000<0oooo0`0000000`3oool00000000000040000
0</0oooo003o0?oood/0oooo0`0000040?ooo`P00000403ooolH00000080oooo1`00003>0?ooo`00
o`3ooom80?ooo`@000000P3oool010000000oooo0?ooo`3oool700000180oooo7@00003A0?ooo`00
o`3ooom50?ooo`<000000`3oool5000000H0oooo100000090?ooo`070000003oool0oooo0?ooo`00
0000oooo000000020?oooaL0000000<0oooo000000000000d`3oool00?l0oooo@@3oool4000000@0
oooo1P0000080?ooo`<000001P3oool<000000030?ooo`000000000001@00000eP3oool00?l0oooo
?P3oool3000000D0oooo1`00000;0?ooo`<000000`3oool?000000030?ooo`000000000001400000
f03oool00?l0oooo>`3oool3000000L0oooo2@00000:0?ooo`T000002@3oool3000000030?ooo`00
0000000000h00000f`3oool00?l0oooo>03oool3000000/0oooo00<000000?ooo`3oool00P3oool4
000000X0oooo1P00000;0?ooo`<000000P3oool<00000=h0oooo003o0?ooocD0oooo0`0000040?oo
o`D000002`3oool3000000/0oooo1000000<0?ooo`<000000`3oool700000>80oooo003o0?oooc80
oooo0`0000040?ooo`P00000303oool3000000/0oooo1000000;0?ooo`@000000`3oool300000>D0
oooo003o0?ooo`800000;@3oool3000000L0oooo1`00000=0?ooo`@000002`3oool3000000X0oooo
1000003/0?ooo`00oP3oool010000000oooo0?ooo`00000Y0?ooo`<000003P3oool4000000d0oooo
1000000;0?ooo`<000001P3oool600000>d0oooo003n0?ooo`040000003oool0oooo000002H0oooo
0`00000B0?ooo`@000003@3oool4000000X0oooo100000020?ooo`L00000k`3oool00?h0oooo00@0
00000?ooo`3oool000008`3oool3000000@0oooo00<000000?ooo`3oool00`3oool2000000X0oooo
1000000=0?ooo`<000002`3oool900000?80oooo003n0?ooo`040000003oool0oooo00000200oooo
100000040?ooo``00000203oool4000000h0oooo0`0000090?ooo`L00000m@3oool00?l0oooo0P00
000M0?ooo`@000000`3oool00`000000oooo0000000?000000P0oooo1000000=0?ooo`@00000103o
ool00`000000oooo0?ooo`0600000?L0oooo003o0?oooa`0oooo0`0000070?ooo`H000002@3oool5
000000L0oooo1000000=0?ooo`T000000P3oool00`000000oooo0?ooo`3i0?ooo`00o`3ooolI0?oo
o`<000002`3oool3000000`0oooo1@0000070?ooo`@000003@3oool700000?l0oooo003o0?oooaH0
oooo0`0000030?ooo`030000003oool0oooo00L0oooo0`00000?0?ooo`<00000203oool4000000T0
oooo1`00003o0?ooo`<0oooo003o0?oooa<0oooo0`0000050?ooo`@000001`3oool3000000l0oooo
100000080?ooo`@000001@3oool800000?l0oooo1@3oool00?l0oooo403oool3000000L0oooo1`00
00050?ooo`@000003`3oool3000000P0oooo1@0000000`3oool000000000000500000?l0oooo2@3o
ool00?l0oooo3@3oool3000000H0oooo300000040?ooo`D000003P3oool3000000T0oooo2@00003o
0?ooo``0oooo003o0?ooo`X0oooo100000050?ooo`T00000103oool00`000000oooo0?ooo`050?oo
o`<000003P3oool4000000L0oooo1`00003o0?ooo`l0oooo003o0?ooo`L0oooo0`0000020?ooo`d0
0000403oool3000000d0oooo0`0000070?ooo`D00000o`3ooolB0?ooo`00o`3oool40?ooo`<00000
1P3oool:000000H0oooo00<000000?ooo`3oool02@3oool4000000`0oooo0`0000080?ooo`030000
003oool0oooo0?l0oooo4`3oool00?l0oooo0@3oool3000000X0oooo1P0000080?ooo`<000002`3o
ool5000000T0oooo1000003o0?oooah0oooo003l0?ooo`D00000103oool00`000000oooo0?ooo`07
0?ooo`<00000203oool6000000X0oooo1P0000050?ooo`030000003oool0000000800000o`3ooolO
0?ooo`00n@3oool3000000@0oooo00@000000?ooo`3oool0oooo0`0000090?ooo`030000003oool0
oooo0080oooo00<000000?ooo`0000002@00000;0?ooo`d00000o`3ooolP0?ooo`00mP3oool30000
00L0oooo00@000000?ooo`3oool0oooo1000000<0?ooo`X0000000@0oooo00000000000000000`3o
ool00`000000oooo0?ooo`060?ooo`X00000o`3ooolQ0?ooo`00l`3oool3000000D0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`3oool5000000`0oooo1P0000050?ooo`040000003o
ool0oooo0?ooo`<000002@3oool200000?l0oooo9`3oool00?00oooo0`0000050?ooo`D000001`3o
ool6000000d0oooo1000000:0?ooo`<00000o`3ooola0?ooo`00k@3oool3000000D0oooo1`000008
0?ooo`<0000000@0oooo00000000000000003P3oool00`000000oooo0?ooo`070?ooo`H00000o`3o
ool`0?ooo`00jP3oool3000000L0oooo1`0000090?ooo`<000000P3oool2000001@0oooo2`00003o
0?ooobl0oooo003W0?ooo`<000000`3oool5000000<0oooo00@000000?ooo`3oool0oooo0`000008
0?ooo`<000000`3oool2000000X0oooo00<000000?ooo`3oool00`3oool8000000@0oooo00<00000
0?ooo`3oool0o`3oool^0?ooo`00i03oool3000000<0oooo200000080?ooo`<000001`3oool30000
00<0oooo0`0000080?ooo``00000o`3ooolh0?ooo`00h@3oool3000000H0oooo1`00000:0?ooo`<0
00001@3oool4000000@0oooo0`0000080?ooo`T00000o`3ooolj0?ooo`00gP3oool3000000D0oooo
00<000000?ooo`3oool01@3oool4000000X0oooo0P0000050?ooo`<000001P3oool3000000P0oooo
1@00003o0?ooocd0oooo003J0?ooo`@00000103oool00`000000oooo0?ooo`04000000H0oooo1000
000:0?ooo`800000103oool3000000L0oooo0`0000030?ooo`030000003oool0oooo0080oooo0`00
003o0?oooch0oooo003G0?ooo`<000000P3oool00`000000oooo0?ooo`0500000080oooo1@000005
0?ooo`@000002@3oool3000000<0oooo0`0000080?ooo`L00000103oool00`000000oooo0?ooo`3o
0?ooocd0oooo003D0?ooo`<000001@3oool7000000<0oooo1P0000040?ooo`@000002P3oool30000
0080oooo0`0000070?ooo`L00000o`3ooom50?ooo`00d@3oool3000000<0oooo00@000000?ooo`00
0000oooo1`0000040?ooo`<0000000<0oooo0000000000000P0000030?ooo`@000002P3oool30000
00040?ooo`0000000000000000H0oooo1@00003o0?ooodP0oooo003>0?ooo`<000001@3oool50000
00030?ooo`000000oooo0080oooo0`0000040?ooo`<0000000<0oooo0000000000000`0000020?oo
o`@000002P3oool6000000L0oooo00<000000?ooo`3oool0o`3ooom90?ooo`00b`3oool3000000D0
oooo1`0000070?ooo`<000000`3oool3000000<0oooo1@0000000`3oool0000000000002000000X0
oooo1@00003o0?oooe<0oooo00380?ooo`<000000P3oool00`000000oooo0?ooo`020?ooo`L00000
2@3oool300000080oooo0`0000050?ooo`T00000203oool600000?l0ooooD`3oool00<D0oooo0`00
00020?ooo`D00000103oool00`000000oooo0?ooo`04000000T0oooo0P0000020?ooo`<000001`3o
ool8000000<0oooo00<000000?ooo`3oool01P00003o0?oooe@0oooo00320?ooo`<000000P3oool7
000000P0oooo1000000:0?ooo`8000000P3oool3000000P0oooo2`0000000`3oool000000?ooo`3o
0?oooeP0oooo002o0?ooo`<000000P3oool00`000000oooo00000005000000/0oooo0`00000:0?oo
o`<0000000@0oooo00000000000000002@3oool900000?l0ooooG03oool00;`0oooo0`0000020?oo
o`D0000000<0oooo0000003oool01@0000090?ooo`@000002P3oool6000000/0oooo1@00003o0?oo
oeh0oooo002h0?ooo`@000000`3oool6000000H0oooo1@0000070?ooo`@000002`3oool6000000`0
oooo00<000000?ooo`3oool0o`3ooomN0?ooo`00]@3oool3000000030?ooo`000000oooo00<0oooo
1@00000:0?ooo`D000001P3oool3000000`0oooo1@00003o0?ooofd0oooo002b0?ooo`<00000103o
ool00`000000oooo0?ooo`030?ooo`@00000303oool4000000D0oooo1000000<0?ooo`@00000o`3o
oom]0?ooo`00[`3oool3000000<0oooo1@0000060?ooo`<000003P3oool4000000<0oooo1000000;
0?ooo`H00000o`3ooom/0?ooo`00[03oool3000000<0oooo200000060?ooo`<000003`3oool50000
0080oooo0`00000:0?ooo`H00000o`3ooom]0?ooo`00Z@3oool3000000H0oooo1`0000070?ooo`<0
00004@3oool9000000T0oooo00<000000?ooo`3oool0o`3ooom`0?ooo`00YP3oool300000080oooo
1@0000060?ooo`@000001P3oool3000001<0oooo1`00003o0?ooog`0oooo002S0?ooo`<000000P3o
ool8000000L0oooo100000050?ooo`<000005@3oool500000?l0ooooO03oool00:00oooo0`000005
0?ooo`L000002@3oool4000000@0oooo0`00000G0?ooo`@00000o`3ooomk0?ooo`00W@3oool30000
00`0oooo100000090?ooo`T000006P3oool00`000000oooo0?ooo`3o0?ooogX0oooo002J0?ooo`<0
0000403oool4000000T0oooo3P0000080?ooo`030000003oool0oooo0?l0ooooQP3oool009H0oooo
100000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0203oool4000000T0oooo
5`00003o0?ooohL0oooo002C0?ooo`@00000103oool;000000T0oooo100000090?ooo`@00000203o
ool900000?l0ooooR03oool00900oooo0`0000030?ooo`030000003oool0oooo00l00000203oool4
000000T0oooo100000080?ooo`D00000o`3ooon;0?ooo`00S@3oool3000000H0oooo00<000000?oo
o`0000000`0000050?ooo`T000001`3oool4000000T0oooo100000020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0o`3ooon<0?ooo`00RP3oool300000080oooo00<000000?ooo`3o
ool01P3oool3000000L0oooo0`0000000`3oool0000000000003000000L0oooo100000090?ooo`L0
0000o`3ooonC0?ooo`00Q`3oool300000080oooo1@0000060?ooo`<000000`3oool00`000000oooo
0?ooo`030?ooo`<000000P3oool3000000P0oooo100000070?ooo`L00000o`3ooonD0?ooo`00Q03o
ool300000080oooo1`0000070?ooo`@0000000@0oooo00000000000000000P3oool600000080oooo
0`0000080?ooo`@000001@3oool600000?l0ooooUP3oool00500oooo1@0000020?ooo`800000:03o
ool3000000@0oooo200000070?ooo`@000000P3oool;000000030?ooo`000000000000800000203o
ool700000080oooo00<000000?ooo`3oool0o`3ooonH0?ooo`00DP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool08P3oool3000000P0oooo00<000000?ooo`3oool01@00
00070?ooo`<000000`3oool7000000050?ooo`00000000000000003oool0100000060?ooo`P00000
o`3ooonM0?ooo`00DP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
7`3oool300000080oooo100000090?ooo`D000001P3oool5000000030?ooo`000000000000800000
1@3oool00`000000oooo0?ooo`03000000L0oooo1@00003o0?oooj00oooo001:0?ooo`@00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3000000030?oo
o`000000000000H000002P3oool5000000H0oooo1@0000020?ooo`<000001`3oool400000?l0oooo
Z`3oool00580oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01P0oooo
100000040?ooo`L00000303oool5000000H0oooo1P0000000`3oool000000?ooo`070?ooo`<00000
o`3ooon/0?ooo`00D@3oool2000000@0oooo0P00000H0?ooo`<000000`3oool2000000H0oooo1@00
000<0?ooo`D000001P3oool7000000D0oooo00<000000?ooo`0000000P00003o0?ooojd0oooo001^
0?ooo`<000000P3oool00`000000oooo00000004000000H0oooo1@00000:0?ooo`L000001P3oool?
00000?l0oooo[P3oool006/0oooo0`0000040?ooo`T000001P3oool5000000D0oooo300000060?oo
o`d00000o`3ooon_0?ooo`00J03oool3000000@0oooo1P0000030?ooo`@000001P3oool=000000D0
oooo1000000:0?ooo`<00000o`3ooond0?ooo`00I@3oool3000000<0oooo1`0000080?ooo`<00000
1P3oool8000000X0oooo100000020?ooo`030000003oool0oooo0?l0oooo^`3oool00680oooo0`00
00050?ooo`H000002`3oool00`000000oooo0?ooo`060?ooo`D000003@3oool700000?l0oooo_03o
ool005l0oooo0`0000020?ooo`030000003oool0oooo00@0oooo2000000C0?ooo`@000002`3oool7
00000?l0oooo_@3oool005`0oooo0`0000020?ooo`D00000203oool800000140oooo100000090?oo
o`H00000o`3ooono0?ooo`00F@3oool300000080oooo2@00000:0?ooo`P000003`3oool4000000<0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?oool40oooo001F0?ooo`<00000
0P3oool7000000030?ooo`000000000000<00000303oool8000000d0oooo2000003o0?ooolP0oooo
001B0?ooo`@000000P3oool7000000H0oooo1000000>0?ooo`P000002P3oool700000?l0oooob@3o
ool004l0oooo0`0000030?ooo`L000002P3oool400000100oooo200000060?ooo`D00000o`3oooo<
0?ooo`00C03oool300000080oooo0P0000000`3oool0000000000006000000L0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo200000040?oo
o`030000003oool0oooo0?l0ooooc@3oool004T0oooo0`0000030?ooo`D0000000<0oooo0000003o
ool00P3oool4000000D0oooo0`00000=0?ooo`@000002P3oool600000?l0ooood`3oool004H0oooo
0`0000030?ooo`P000001P3oool4000000D0oooo0`00000=0?ooo`@000001`3oool700000?l0oooo
e03oool004<0oooo0`0000040?ooo`X000001`3oool4000000<0oooo1@0000060?ooo`030000003o
ool0oooo00@0oooo1@0000020?ooo`H00000o`3ooooH0?ooo`00@03oool3000000@0oooo20000003
0?ooo`<000001`3oool<000000@0oooo0`0000060?ooo`T00000o`3ooooK0?ooo`00?@3oool30000
00@0oooo200000060?ooo`<00000203oool6000000<0oooo0`0000040?ooo`<000001P3oool50000
0?l0oooogP3oool003X0oooo0`0000060?ooo`H000002@3oool3000000T0oooo1@0000040?ooo`03
0000003oool0oooo00@0oooo0`0000060?ooo`030000003oool0oooo0?l0oooog`3oool003L0oooo
0`00000:0?ooo`D000002P3oool3000000T0oooo1@0000090?ooo`D00000o`3ooooW0?ooo`00=03o
ool3000000l0oooo1@0000080?ooo`<000002P3oool5000000D0oooo1`00003o0?ooonP0oooo000`
0?ooo`@000000P3oool5000000d0oooo1@0000070?ooo`<000002P3oool5000000030?ooo`000000
000000D00000o`3oooo[0?ooo`00;@3oool400000080oooo2000000?0?ooo`H00000103oool30000
00/0oooo2@00003o0?ooonh0oooo000Z0?ooo`<000000`3oool00`000000oooo0?ooo`0700000180
oooo1P0000020?ooo`<000002P3oool700000?l0ooool@3oool002L0oooo0`0000060?ooo`030000
003oool0oooo00@0oooo1000000D0?ooo`D0000000@0oooo0000000000000000203oool500000?l0
oooom03oool002@0oooo0`0000030?ooo`040000003oool0oooo0?ooo`800000203oool4000001D0
oooo1`0000090?ooo`030000003oool0oooo0?l0oooom@3oool00240oooo0`0000030?ooo`/00000
1`3oool4000000d0oooo00<000000?ooo`3oool01P3oool500000?l0ooooo`3oool20?ooo`007P3o
ool300000080oooo4@0000060?ooo`D000002P3oool3000000T0oooo1000003o0?ooool0oooo0@3o
ool001/0oooo0`0000040?ooo`H00000203oool5000000H0oooo1@00000:0?ooo`<000002P3oool0
0`000000oooo0?ooo`3o0?ooool0oooo000H0?ooo`<0000000@0oooo0000003oool0oooo1`00000;
0?ooo`<00000203oool5000000X0oooo0`00003o0?ooool0oooo303oool001D0oooo0`0000000`3o
ool000000000000<000000X0oooo0`0000090?ooo`D00000203oool500000?l0ooooo`3oool;0?oo
o`004P3oool300000080oooo1P0000020?ooo`040000003oool0oooo0?ooo`D000002@3oool50000
00P0oooo1@0000040?ooo`L00000o`3ooooo0?ooo``0oooo000>0?ooo`@00000103oool7000000L0
oooo1@0000040?ooo`/000001`3oool;00000?l0ooooo`3oool@0?ooo`002`3oool3000000050?oo
o`000000oooo0?ooo`000000103oool00`000000oooo0?ooo`03000000P0oooo5@0000060?ooo`L0
0000o`3ooooo0?oooa<0oooo00080?ooo`<000000`3oool6000000L0oooo0`0000080?ooo`L00000
2P3oool4000000D0oooo1000003o0?ooool0oooo5P3oool000D0oooo0`0000040?ooo`L000001@3o
ool6000000T0oooo1@00000;0?ooo`<000001P3oool00`000000oooo0000003o0?ooool0oooo5`3o
ool00080oooo0`0000060?ooo`P000000`3oool9000000X0oooo100000090?ooo`D00000o`3ooooo
0?oooal0oooo0002000000X0oooo00@000000?ooo`3oool0oooo2@0000030?ooo`<000002`3oool4
000000D0oooo1`00003o0?ooool0oooo803oool00180oooo1@0000050?ooo`<00000303oool40000
0080oooo1P00003o0?ooool0oooo8`3oool001<0oooo1`0000030?ooo`<00000303oool800000?l0
ooooo`3ooolV0?ooo`005P3oool6000000040?ooo`0000000000000000`0oooo1P00003o0?ooool0
oooo:03oool001T0oooo2000000:0?ooo`D00000o`3ooooo0?ooobX0oooo000K0?ooo`H000002`3o
ool00`000000oooo0?ooo`3o0?ooool0oooo:`3oool001d0oooo1@00003o0?ooool0oooo>03oool0
01l0oooo1000003o0?ooool0oooo=`3oool00240oooo00<000000?ooo`3oool0o`3ooooo0?ooocH0
oooo003o0?ooool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?oo
ool0ooooFP3oool00?l0ooooo`3ooomJ0?ooo`00o`3ooooo0?oooeX0oooo003o0?ooool0ooooFP3o
ool00?l0ooooo`3ooomJ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 599}, {205.688, 0}} -> {0.0495317, 0.301571, \
0.001718, 0.001718}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Positioning Text in 3D Space", "Section"],

Cell[TextData[{
  "Positioning text in 3D space requires familiarity with rotations and Euler \
angles. In Text3D the Euler angle sequence commonly used in many physics \
problems is employed.\n1) The text starts out aligned in the xy-plane along \
the x-axis.\n2) The text is rotated counterclockwise in the xy-plane by the \
angle ",
  Cell[BoxData[
      \(\[Psi]\)]],
  ". (A right handed rotation about the z-azis.)\n3) The text is then rotated \
in a right handed sense about the y-axis by an angle \[Phi].\n4) The text is \
then rotated again in a right handed sense about the z-axis by an angle \
\[Theta].\nNotice that in Text3D the order of the angles is ",
  Cell[BoxData[
      \({\[Phi], \[Theta], \[Psi]}\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The letters of the text will lie in a plane, which we may call the text \
plane. The text plane will have a normal vector. We can describe the \
direction of the normal vector as a point on the unit sphere ",
  Cell[BoxData[
      \({Cos[\[Theta]] Sin[\[Phi]], Sin[\[Theta]] Sin[\[Phi]], 
        Cos[\[Phi]]}\)]],
  ". ",
  Cell[BoxData[
      \(\[Phi]\)]],
  " is the angle from the north pole, sometimes called colatitude. ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " is the longitude starting from the line of the x-axis. The ",
  Cell[BoxData[
      \(\[Psi]\)]],
  " angle has the effect of rotating the text  in the text plane."
}], "Text"],

Cell["\<\
Later, we will see how the text plane can be transformed to a curved surface.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
\[Psi] Variation - Rotating in the Text Plane\
\>", "Subsection"],

Cell["\<\
This section shows the effect of varying \[Psi], the third angle in the list \
of angles. \[Psi] rotates the initial text counterclockwise around the \
z-axis.  The following routine produces one frame for the animation below. \
The notebook uses many animations and you may wish to delete one before doing \
another if you are short on memory space.\
\>", "Text"],

Cell[BoxData[
    \(\(\(\[Psi]frame[\[Phi]_, \[Theta]_]\)[\[Psi]_] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{AbsoluteThickness[1], 
            Blue, \[IndentingNewLine]Text3D["\<DrawGraphics!\>", {0, 0, 
                0}, {1, 1}, {\[Phi], \[Theta], \[Psi]}, 
              Font3D \[Rule] FuturaFont3D]}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                  1}, {\(-1\), 1}} 10, \[IndentingNewLine]ImageSize \[Rule] 
            400];\)\)], "Input"],

Cell[TextData[{
  "The following shows the effect of ",
  Cell[BoxData[
      \(\[Psi]\)]],
  " without any other rotations."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Psi]frame[0, 0]\)[\[Psi]], {\[Psi], 0, 2  \[Pi] - del, 
        del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37024 .64733 m
.38086 .64396 L
s
.37024 .64733 m
.35044 .62848 L
s
.38086 .64396 m
.3845 .64162 L
s
.3845 .64162 m
.38569 .63886 L
s
.38569 .63886 m
.38536 .63658 L
s
.38536 .63658 m
.3841 .63339 L
s
.3841 .63339 m
.37942 .62886 L
s
.39577 .63086 m
.38268 .61809 L
s
.37942 .62886 m
.37507 .62663 L
s
.39946 .62848 m
.40346 .62841 L
s
.39452 .62765 m
.39946 .62848 L
s
.36114 .62503 m
.35044 .62848 L
s
.40346 .62841 m
.40809 .62693 L
s
.39018 .62541 m
.39452 .62765 L
s
.37507 .62663 m
.37165 .6253 L
s
.37165 .6253 m
.36669 .62446 L
s
.36669 .62446 m
.36114 .62503 L
s
.41956 .62206 m
.41462 .62123 L
s
.42359 .62199 m
.41956 .62206 L
s
.42826 .6205 m
.42359 .62199 L
s
.41462 .62123 m
.41029 .61897 L
s
.43046 .61859 m
.42826 .6205 L
s
.41029 .61897 m
.40844 .61713 L
s
.43175 .61575 m
.43046 .61859 L
s
.43449 .61851 m
.42162 .60554 L
s
.40844 .61713 m
.40721 .61386 L
s
.44544 .61502 m
.43894 .59996 L
s
.40721 .61386 m
.40846 .61101 L
s
.45801 .61101 m
.45161 .59587 L
s
.45801 .61101 m
.43894 .59996 L
s
.40846 .61101 m
.41065 .60907 L
s
.41065 .60907 m
.41535 .60756 L
s
.41941 .60748 m
.42439 .60834 L
s
.41535 .60756 m
.41941 .60748 L
s
.49186 .60752 m
.4869 .60667 L
s
.49592 .60744 m
.49186 .60752 L
s
.50229 .60542 m
.49592 .60744 L
s
.47064 .60698 m
.45161 .59587 L
s
.4869 .60667 m
.48354 .60531 L
s
.5046 .60348 m
.50229 .60542 L
s
.48354 .60531 m
.47926 .60301 L
s
.50604 .60058 m
.5046 .60348 L
s
.47926 .60301 m
.47477 .59831 L
s
.50587 .59819 m
.50604 .60058 L
s
.47477 .59831 m
.47366 .59497 L
s
.47366 .59497 m
.47345 .59256 L
s
.51374 .59323 m
.50131 .57985 L
s
.49075 .59319 m
.49877 .59062 L
s
.47345 .59256 m
.47484 .58963 L
s
.5177 .59074 m
.5218 .59066 L
s
.51271 .58987 m
.5177 .59074 L
s
.5218 .59066 m
.52665 .58911 L
s
.4961 .58776 m
.49877 .59062 L
s
.50844 .58752 m
.51271 .58987 L
s
.47484 .58963 m
.47714 .58764 L
s
.4927 .58637 m
.4961 .58776 L
s
.47714 .58764 m
.48356 .58557 L
s
.48768 .58549 m
.4927 .58637 L
s
.48356 .58557 m
.48768 .58549 L
s
.53876 .58402 m
.53376 .58314 L
s
.54288 .58394 m
.53876 .58402 L
s
.54777 .58238 m
.54288 .58394 L
s
.53376 .58314 m
.5295 .58078 L
s
.55016 .58038 m
.54777 .58238 L
s
.5295 .58078 m
.52774 .57885 L
s
.5517 .5774 m
.55016 .58038 L
s
.5543 .5803 m
.5421 .56671 L
s
.52774 .57885 m
.52672 .57543 L
s
.56577 .57664 m
.54749 .55608 L
s
.52672 .57543 m
.52822 .57244 L
s
.5682 .57462 m
.57235 .57454 L
s
.56318 .57373 m
.5682 .57462 L
s
.57235 .57454 m
.57729 .57296 L
s
.57729 .57296 m
.57974 .57094 L
s
.60472 .57292 m
.58687 .55227 L
s
.52822 .57244 m
.53061 .57041 L
s
.57974 .57094 m
.58133 .56793 L
s
.53061 .57041 m
.53553 .56883 L
s
.53969 .56874 m
.54473 .56964 L
s
.53553 .56883 m
.53969 .56874 L
s
.58133 .56793 m
.58042 .56446 L
s
.55781 .56291 m
.55625 .56593 L
s
.58042 .56446 m
.5787 .5625 L
s
.63723 .56385 m
.63473 .5634 L
s
.63809 .56233 m
.63723 .56385 L
s
.60297 .56352 m
.60715 .56344 L
s
.59543 .56217 m
.60297 .56352 L
s
.60715 .56344 m
.61215 .56184 L
s
.63473 .5634 m
.63558 .56188 L
s
.56025 .56086 m
.55781 .56291 L
s
.5787 .5625 m
.57446 .56008 L
s
.63558 .56188 m
.63809 .56233 L
s
.61215 .56184 m
.61466 .55979 L
s
.56522 .55925 m
.56025 .56086 L
s
.57446 .56008 m
.56941 .55917 L
s
.61466 .55979 m
.61381 .55629 L
s
.56941 .55917 m
.56522 .55925 L
s
.61381 .55629 m
.60534 .54632 L
s
.6306 .55596 m
.61885 .54197 L
s
.64666 .54957 m
.64162 .54866 L
s
.65088 .54949 m
.64666 .54957 L
s
.65597 .54787 m
.65088 .54949 L
s
.64162 .54866 m
.63743 .5462 L
s
.65855 .54578 m
.65597 .54787 L
s
.63743 .5462 m
.63576 .54419 L
s
.66031 .54268 m
.65855 .54578 L
s
.63576 .54419 m
.63495 .54062 L
s
.67391 .54088 m
.67057 .5394 L
s
.67986 .54025 m
.67391 .54088 L
s
.63495 .54062 m
.63667 .53751 L
s
.68501 .5386 m
.67986 .54025 L
s
.67057 .5394 m
.67065 .53683 L
s
.71128 .53911 m
.70008 .52484 L
s
.68936 .53594 m
.68501 .5386 L
s
.63667 .53751 m
.63925 .53539 L
s
.67065 .53683 m
.67326 .53472 L
s
.68947 .53336 m
.68936 .53594 L
s
.63925 .53539 m
.64437 .53374 L
s
.67326 .53472 m
.68105 .53094 L
s
.64862 .53366 m
.65371 .53459 L
s
.64437 .53374 m
.64862 .53366 L
s
.66407 .52868 m
.664 .53128 L
s
.68105 .53094 m
.68368 .52881 L
s
.68368 .52881 m
.68378 .52621 L
s
.66841 .52599 m
.66407 .52868 L
s
.68378 .52621 m
.68297 .52518 L
s
.67359 .52432 m
.66841 .52599 L
s
.68297 .52518 m
.6796 .52368 L
s
.6796 .52368 m
.67359 .52432 L
s
.69697 .51809 m
.69604 .51968 L
s
.69604 .51968 m
.69348 .51921 L
s
.69348 .51921 m
.69441 .51761 L
s
.69441 .51761 m
.69697 .51809 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000K0?ooo`80
003o00<0oooo0000003oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000N0?ooo`040000o`3oool0oooo000005P0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1E0?ooo`<00000703oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`1A0?ooo`<000006`3oool40000o`030?ooo`000?l0003o00D0oooo00<0003o0000003oool0F03o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3
000001d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0B@3oool300000200oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`03000000000?l0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0
oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04D0
oooo0`00000K0?ooo`D0003o1`3oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000000
003o0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000703oool20000o`X0oooo
0P000?l50?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`000?l0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0m0?ooo`<000007P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo0P00
0?l50?ooo`040000003oool0oooo0000oeH0oooo00<000000?ooo`3oool05@3oool002P0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000006`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool40000o`L0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo03D0oooo0`00000O0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?oo
o`<00000703oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<0
0000803oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1P000?lA0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0Y0?ooo`<000006`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000003`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<000004`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0703oool4000001L0oooo00<0003o0?ooo`3oool01P000?l60?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0603oool3000001`0oooo0P000?l60?ooo`80003o1@3oool70000o`P0oooo0P000?lH0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0D0?ooo`<000006P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0@0?ooo`<000006`3oool20000o`030?ooo`000?l0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02D0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000L0?ooo`80003o0P3oool30000o`@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02@0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000N0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool60000o`T0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool300000200oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo00<0003o0?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool00`00000J0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool20000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo0P000?l00`3oool0003o0?ooo`0f0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0
oooo01D0oooo0`000?l60?ooo`030000o`3oool0oooo00H0oooo1P000?lj0?ooo`800000F`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
01<0oooo0P000?l30?ooo`<0003o0`3oool00`000?l0oooo0?ooo`130?ooo`<000000P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`80003o0`3oool70000ocX0
oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo
0P000?l60?ooo`030000o`3oool0oooo03X0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`090?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0AP3oool3000000h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo00T0oooo0`000?l60?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0=`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0000o`000?l50?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0<`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo0`000?l20?oo
o`040000o`3oool0oooo0?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0300oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000003o0?ooo`060?ooo`060000o`3oool0003o
0000o`3oool0003o103oool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?oo
o`0^0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo08X0oooo1P000?l60?ooo`040000o`3oool0oooo0?ooo`80003o2`3o
ool50000obh0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0RP3oool01@000?l0oooo0?ooo`3oool000000080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03P0oooo0`00
000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002;
0?ooo`050000o`3oool0oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo03X0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0RP3oool01@000?l0oooo0?ooo`3oool0000000@0oooo00<0
003o0?ooo`3oool0>`3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`210?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`000000103oool00`000?l0oooo0000o`0i0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo0880oooo00<0003o0?oo
o`3oool01`3oool70000ocP0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0M`3oool60000o`H0oooo00<0003o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07D0oooo0`000?l60?ooo`80003o
1@3oool70000o`80oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1f0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000003o
ool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`070?ooo`80003o2`3oool0
0`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo07P0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0N@3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0:03oool3000004h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000007X0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
001m0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q
0?ooo`030000003oool0oooo07d0oooo00<0003o0?ooo`3oool00P000?l=0?ooo`030000003oool0
oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo07h0oooo0P000?l?0?ooo`030000003oool0oooo
01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0
oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.34884 .62729 m
.3607 .62524 L
s
.34884 .62729 m
.33571 .60619 L
s
.3607 .62524 m
.36518 .62336 L
s
.36518 .62336 m
.36736 .62078 L
s
.36736 .62078 m
.36785 .61848 L
s
.36785 .61848 m
.36772 .61517 L
s
.36772 .61517 m
.36466 .61012 L
s
.3803 .61409 m
.37178 .59986 L
s
.38886 .6126 m
.39401 .61171 L
s
.38483 .61219 m
.38886 .6126 L
s
.3802 .61077 m
.38483 .61219 L
s
.37667 .60802 m
.3802 .61077 L
s
.36466 .61012 m
.3611 .60737 L
s
.4112 .60872 m
.40717 .60831 L
s
.41637 .60782 m
.4112 .60872 L
s
.40717 .60831 m
.40254 .60687 L
s
.41924 .60621 m
.41637 .60782 L
s
.3611 .60737 m
.35815 .60564 L
s
.40254 .60687 m
.39904 .60412 L
s
.42327 .60662 m
.4151 .59226 L
s
.42153 .60356 m
.41924 .60621 L
s
.3477 .60409 m
.33571 .60619 L
s
.35815 .60564 m
.35347 .6042 L
s
.43538 .60452 m
.43428 .58889 L
s
.35347 .6042 m
.3477 .60409 L
s
.39904 .60412 m
.39785 .60207 L
s
.4879 .60323 m
.48388 .60281 L
s
.49488 .60202 m
.4879 .60323 L
s
.48388 .60281 m
.4793 .60137 L
s
.44925 .60211 m
.44828 .58643 L
s
.44925 .60211 m
.43428 .58889 L
s
.39785 .60207 m
.39779 .5987 L
s
.49783 .60039 m
.49488 .60202 L
s
.4793 .60137 m
.47647 .59962 L
s
.50026 .59773 m
.49783 .60039 L
s
.46316 .59969 m
.44828 .58643 L
s
.47647 .59962 m
.47307 .59684 L
s
.39779 .5987 m
.40005 .59603 L
s
.50094 .59537 m
.50026 .59773 L
s
.47307 .59684 m
.4703 .59168 L
s
.40005 .59603 m
.40293 .59439 L
s
.41221 .5939 m
.41686 .59536 L
s
.40293 .59439 m
.40814 .59348 L
s
.40814 .59348 m
.41221 .5939 L
s
.4703 .59168 m
.47039 .58826 L
s
.51042 .59147 m
.50293 .57684 L
s
.51922 .58994 m
.52451 .58902 L
s
.51517 .58952 m
.51922 .58994 L
s
.51059 .58805 m
.51517 .58952 L
s
.48785 .58862 m
.49665 .58708 L
s
.47039 .58826 m
.47103 .58587 L
s
.50722 .58523 m
.51059 .58805 L
s
.49502 .58395 m
.49665 .58708 L
s
.54218 .58595 m
.53813 .58552 L
s
.5475 .58503 m
.54218 .58595 L
s
.47103 .58587 m
.47344 .58316 L
s
.53813 .58552 m
.53355 .58405 L
s
.55054 .58336 m
.5475 .58503 L
s
.53355 .58405 m
.53022 .58122 L
s
.49217 .58216 m
.49502 .58395 L
s
.55459 .58379 m
.54747 .56902 L
s
.55308 .58065 m
.55054 .58336 L
s
.47344 .58316 m
.47641 .58149 L
s
.60609 .58278 m
.59603 .5605 L
s
.48755 .58069 m
.49217 .58216 L
s
.56704 .58163 m
.55645 .55932 L
s
.47641 .58149 m
.48347 .58026 L
s
.53022 .58122 m
.52918 .57912 L
s
.48347 .58026 m
.48755 .58069 L
s
.57416 .58039 m
.57951 .57946 L
s
.5701 .57996 m
.57416 .58039 L
s
.56554 .57848 m
.5701 .57996 L
s
.57951 .57946 m
.58259 .57779 L
s
.52918 .57912 m
.52939 .57565 L
s
.64059 .57794 m
.63834 .5772 L
s
.64194 .57658 m
.64059 .57794 L
s
.58259 .57779 m
.58519 .57506 L
s
.63834 .5772 m
.63969 .57583 L
s
.63969 .57583 m
.64194 .57658 L
s
.52939 .57565 m
.53191 .57291 L
s
.58519 .57506 m
.58552 .57157 L
s
.61174 .57386 m
.61713 .57292 L
s
.60768 .57342 m
.61174 .57386 L
s
.60086 .57118 m
.60768 .57342 L
s
.61713 .57292 m
.62027 .57123 L
s
.53191 .57291 m
.53495 .57122 L
s
.5444 .57071 m
.549 .57221 L
s
.58552 .57157 m
.58454 .56944 L
s
.62027 .57123 m
.62067 .56773 L
s
.53495 .57122 m
.54031 .57028 L
s
.54031 .57028 m
.5444 .57071 L
s
.5641 .56726 m
.56153 .57002 L
s
.63696 .56947 m
.63051 .55445 L
s
.58454 .56944 m
.58127 .56656 L
s
.62067 .56773 m
.61596 .557 L
s
.56719 .56556 m
.5641 .56726 L
s
.58127 .56656 m
.57668 .56505 L
s
.65868 .5657 m
.65461 .56526 L
s
.66413 .56475 m
.65868 .5657 L
s
.57259 .56461 m
.56719 .56556 L
s
.65461 .56526 m
.65008 .56375 L
s
.57668 .56505 m
.57259 .56461 L
s
.66732 .56305 m
.66413 .56475 L
s
.65008 .56375 m
.64691 .56085 L
s
.71993 .56308 m
.7142 .54794 L
s
.67008 .56027 m
.66732 .56305 L
s
.64691 .56085 m
.646 .5587 L
s
.68962 .56032 m
.68371 .5602 L
s
.6951 .55937 m
.68962 .56032 L
s
.68371 .5602 m
.68103 .55836 L
s
.70017 .55733 m
.6951 .55937 L
s
.646 .5587 m
.64646 .55514 L
s
.68103 .55836 m
.68199 .55588 L
s
.70116 .55485 m
.70017 .55733 L
s
.68199 .55588 m
.68522 .55416 L
s
.64646 .55514 m
.6492 .55233 L
s
.68522 .55416 m
.69396 .55148 L
s
.6492 .55233 m
.65241 .5506 L
s
.66201 .55009 m
.66656 .55162 L
s
.69396 .55148 m
.69721 .54975 L
s
.65241 .5506 m
.6579 .54964 L
s
.6579 .54964 m
.66201 .55009 L
s
.69721 .54975 m
.69821 .54724 L
s
.67852 .54719 m
.67756 .54969 L
s
.69821 .54724 m
.69778 .54615 L
s
.6836 .54513 m
.67852 .54719 L
s
.69778 .54615 m
.69509 .54428 L
s
.68913 .54416 m
.6836 .54513 L
s
.69509 .54428 m
.68913 .54416 L
s
.71357 .54104 m
.71213 .54247 L
s
.71213 .54247 m
.70987 .54169 L
s
.70987 .54169 m
.7113 .54027 L
s
.7113 .54027 m
.71357 .54104 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool00P000?mE0?ooo`030000003oool0oooo
01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000003H0
oooo1@000?l20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<00000=`3oool20000o`D0oooo
00<0003o0?ooo`0000000`3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool300000300oooo1@00
0?l50?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`0000000`3oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0:@3oool300000380oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`07
0?ooo`80003o0P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000^0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool40000o`<0oooo00<0003o0000
003oool00`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000002`0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool0103oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000
603oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0P3oool60000o`80oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1B0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000001`0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1B0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
00000200oooo00<0003o0?ooo`3oool01`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`H0003o3P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000001l0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00L0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool05`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001d0oooo1`000?l3
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000O0?oo
o`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0
oooo00<0oooo1`000?lP0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000005`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool20000
oaL0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<000006P3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0`000?l30?ooo`80003o1`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000004`3oool70000o`@0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`000?l00P000?l:0?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`80003o2@3oool30000o`80
oooo0P000?l00`3oool0003o0?ooo`0e0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`80003o0`3oool20000o`/0oooo0P000?lg0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`000?l0oooo0000o`040000oc/0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0R03oool01@000?l0oooo0?ooo`000?l0000000D0oooo0P000?l30?ooo`030000o`3o
ool0003o00D0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0k0?ooo`<000002P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08H0oooo0`000?l00`3oool0003o0000o`020000o`D0oooo00<0003o0?ooo`000?l00P3oool0
0`000?l0oooo0?ooo`020000o`<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0k
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?oo
o`060000o`3oool0oooo0000o`3oool0003o103oool01@000?l0oooo0?ooo`3oool0003o00T0oooo
00<0003o0?ooo`3oool0>@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool01@3oool00`000000003o0?ooo`030?ooo`040000o`3oool0oooo0?ooo`80003o
1@3oool010000?l0oooo0?ooo`3oool30000o`D0oooo00<0003o0?ooo`3oool0=`3oool3000001H0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`1a0?ooo`D0003o1P3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3oool00`000000003o
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool50000ocH0oooo
1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0KP3oool30000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`170?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo06l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00P0oooo1@000?l00`000000oooo0?ooo`1:0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
0700oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo
00H0oooo00<000000?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool200000780oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0003o0080003o2@3oool00`000000oooo0?ooo`140?ooo`<0
0000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo0740oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000
003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0LP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00l0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
07<0oooo00@0003o0?ooo`3oool0oooo10000?lB0?ooo`030000003oool0oooo03P0oooo0`00000j
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0M@3oool30000oaH0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000
A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240
oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.33453 .60481 m
.34718 .60423 L
s
.33453 .60481 m
.32889 .58225 L
s
.34718 .60423 m
.35235 .60292 L
s
.35235 .60292 m
.35547 .60063 L
s
.35547 .60063 m
.35678 .59842 L
s
.35678 .59842 m
.35785 .59512 L
s
.4815 .59811 m
.47768 .59721 L
s
.48879 .59778 m
.4815 .59811 L
s
.49227 .59655 m
.48879 .59778 L
s
.47768 .59721 m
.47369 .59524 L
s
.4956 .59423 m
.49227 .59655 L
s
.37083 .59561 m
.36739 .58047 L
s
.47369 .59524 m
.47151 .59317 L
s
.37992 .5952 m
.38538 .59495 L
s
.37604 .59429 m
.37992 .5952 L
s
.35785 .59512 m
.35658 .58974 L
s
.37192 .59231 m
.37604 .59429 L
s
.4971 .592 m
.4956 .59423 L
s
.4036 .59411 m
.39973 .5932 L
s
.40907 .59386 m
.4036 .59411 L
s
.4125 .59262 m
.40907 .59386 L
s
.41636 .59353 m
.41334 .57835 L
s
.39973 .5932 m
.39563 .59122 L
s
.47151 .59317 m
.46914 .59002 L
s
.42913 .59294 m
.4336 .57741 L
s
.41572 .5903 m
.4125 .59262 L
s
.60398 .59253 m
.60203 .56963 L
s
.36936 .58916 m
.37192 .59231 L
s
.44373 .59227 m
.44834 .57673 L
s
.44373 .59227 m
.4336 .57741 L
s
.63893 .59202 m
.63703 .59103 L
s
.6407 .59086 m
.63893 .59202 L
s
.45835 .59161 m
.44834 .57673 L
s
.39563 .59122 m
.39312 .58806 L
s
.63703 .59103 m
.63879 .58986 L
s
.63879 .58986 m
.6407 .59086 L
s
.46914 .59002 m
.46824 .58461 L
s
.35658 .58974 m
.354 .58658 L
s
.50777 .58934 m
.50559 .57409 L
s
.51694 .58892 m
.52244 .58867 L
s
.51312 .58801 m
.51694 .58892 L
s
.39312 .58806 m
.39266 .5859 L
s
.50914 .58601 m
.51312 .58801 L
s
.5408 .58783 m
.53699 .58692 L
s
.5463 .58758 m
.5408 .58783 L
s
.54985 .58633 m
.5463 .58758 L
s
.71991 .58725 m
.71967 .57196 L
s
.55365 .58724 m
.55189 .57195 L
s
.53699 .58692 m
.53304 .58492 L
s
.56652 .58665 m
.56404 .56359 L
s
.354 .58658 m
.35165 .5845 L
s
.55328 .58399 m
.54985 .58633 L
s
.57388 .58632 m
.5794 .58606 L
s
.57008 .5854 m
.57388 .58632 L
s
.5794 .58606 m
.58297 .58481 L
s
.50684 .58284 m
.50914 .58601 L
s
.39266 .5859 m
.3938 .58256 L
s
.56617 .5834 m
.57008 .5854 L
s
.53304 .58492 m
.53078 .58174 L
s
.58297 .58481 m
.58645 .58247 L
s
.46824 .58461 m
.46954 .58126 L
s
.61255 .58455 m
.61808 .58429 L
s
.60877 .58363 m
.61255 .58455 L
s
.35165 .5845 m
.34748 .58249 L
s
.61808 .58429 m
.62169 .58304 L
s
.48661 .58377 m
.49581 .58335 L
s
.60296 .58062 m
.60877 .58363 L
s
.63838 .58336 m
.63739 .568 L
s
.49532 .58008 m
.49581 .58335 L
s
.62169 .58304 m
.6233 .57968 L
s
.3938 .58256 m
.39702 .58021 L
s
.34748 .58249 m
.34172 .58166 L
s
.58645 .58247 m
.58799 .57911 L
s
.66054 .58235 m
.65679 .58143 L
s
.66609 .5821 m
.66054 .58235 L
s
.34172 .58166 m
.32889 .58225 L
s
.66974 .58084 m
.66609 .5821 L
s
.53078 .58174 m
.5305 .57956 L
s
.40988 .57961 m
.41399 .58162 L
s
.65679 .58143 m
.65297 .57942 L
s
.46954 .58126 m
.47102 .579 L
s
.69199 .58091 m
.6864 .58007 L
s
.69755 .58066 m
.69199 .58091 L
s
.67335 .57848 m
.66974 .58084 L
s
.70308 .57931 m
.69755 .58066 L
s
.39702 .58021 m
.40047 .57894 L
s
.49314 .57798 m
.49532 .58008 L
s
.6864 .58007 m
.68447 .57797 L
s
.6233 .57968 m
.62249 .56869 L
s
.40598 .57869 m
.40988 .57961 L
s
.5305 .57956 m
.53192 .57619 L
s
.65297 .57942 m
.65094 .57622 L
s
.70488 .57704 m
.70308 .57931 L
s
.58799 .57911 m
.58778 .57692 L
s
.47102 .579 m
.47435 .57664 L
s
.40047 .57894 m
.40598 .57869 L
s
.48912 .57595 m
.49314 .57798 L
s
.68447 .57797 m
.68625 .57569 L
s
.58778 .57692 m
.58561 .57371 L
s
.47435 .57664 m
.47787 .57537 L
s
.65094 .57622 m
.65081 .57402 L
s
.53192 .57619 m
.53535 .57382 L
s
.48525 .57503 m
.48912 .57595 L
s
.68625 .57569 m
.68993 .57443 L
s
.47787 .57537 m
.48525 .57503 L
s
.54831 .57322 m
.55227 .57525 L
s
.5687 .57228 m
.56523 .57465 L
s
.68993 .57443 m
.69919 .5729 L
s
.65081 .57402 m
.65249 .57063 L
s
.53535 .57382 m
.53891 .57255 L
s
.58561 .57371 m
.58169 .57168 L
s
.54447 .57229 m
.54831 .57322 L
s
.69919 .5729 m
.70289 .57162 L
s
.53891 .57255 m
.54447 .57229 L
s
.5723 .571 m
.5687 .57228 L
s
.58169 .57168 m
.57787 .57075 L
s
.70289 .57162 m
.7047 .56933 L
s
.57787 .57075 m
.5723 .571 L
s
.65249 .57063 m
.65609 .56824 L
s
.66914 .56764 m
.67297 .56968 L
s
.7047 .56933 m
.70467 .56822 L
s
.68594 .56687 m
.68415 .56917 L
s
.65609 .56824 m
.65976 .56696 L
s
.70467 .56822 m
.70275 .56609 L
s
.66536 .56671 m
.66914 .56764 L
s
.65976 .56696 m
.66536 .56671 L
s
.6915 .5655 m
.68594 .56687 L
s
.72144 .56523 m
.71959 .56642 L
s
.71959 .56642 m
.7177 .5654 L
s
.70275 .56609 m
.69711 .56524 L
s
.69711 .56524 m
.6915 .5655 L
s
.7177 .5654 m
.71955 .5642 L
s
.71955 .5642 m
.72144 .56523 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
000O0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000R
0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool01`3oool50000o`030000003oool0
oooo0080oooo0P000?mD0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0403oool3000002D0oooo00<0003o0?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo0`000?l00`3oool0003o0?ooo`040?oo
o`<0003o1@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000002@0oooo00D0003o0?ooo`3o
ool0oooo0000o`020?ooo`D0003o1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool20000o`D0oooo0P000?l:0?ooo`030000o`000000oooo
00<0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000E0?ooo`030000o`3oool0oooo00P0
oooo1P000?l00`3oool0003o0?ooo`020?ooo`<0003o1@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00/0oooo1@000?l00`3oool000000?ooo`030?ooo`030000o`3oool0oooo05<0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`040?ooo`03000000000?l0000000<0oooo00<0003o0?ooo`3oool01`3oool60000o`D0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`240?ooo`L0003o00<000000?ooo`3oool00`00
00000`3oool0003o0?ooo`030?ooo`80003o1P3oool20000o`H0oooo0`000?l20?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3o
ool0oooo0?ooo`80003o1@3oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo05<0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool80000o`L0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool00000000000<0oooo
00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool00P000?l80?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P000?l60?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool70000o`H0oooo1@000?l00`3oool00000
0?ooo`030?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00
001[0?ooo`030000o`3oool0oooo00D0oooo0P000?l50?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00@0
003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo
0P000?l60?ooo`P0003o1@3oool00`000?l0oooo0?ooo`0E0?ooo`800000103oool00`000?l0oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`000?l000000?ooo`030?ooo`060000o`3oool0oooo0000o`3oool0
003o0`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0`000?l80?ooo`L0003o103oool00`00
0?l0oooo0000o`030000o`P0oooo00<0003o0?ooo`3oool07`3oool300000080oooo00D000000?oo
o`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
06/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l000000?ooo`020?ooo`040000o`3oool0oooo
0?ooo`80003o103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool010000?lM0?ooo`030000o`3oool0oooo00X0oooo0P000?l?0?ooo`@000001P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
06/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00H0oooo0`000?l40?ooo`80003o00D000000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo02D0oooo00<0003o0?ooo`3oool02@3oool20000o`d0oooo0`00000:0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0K@3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo1`000?l50?ooo`@0003o0P3oool00`00
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0?@3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`1]0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0503oool00`000000
oooo0?ooo`0B0?ooo`P0003o?@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06h0oooo00<0
003o0?ooo`3oool010000?lH0?ooo`030000003oool0oooo0500oooo1000000J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0KP3oool3
0000oa`0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
04X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo
0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo
000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71156 .61056 m
.7166 .59578 L
s
.63244 .60548 m
.63095 .60429 L
s
.63455 .60457 m
.63244 .60548 L
s
.63306 .60337 m
.63455 .60457 L
s
.63095 .60429 m
.63306 .60337 L
s
.59854 .60176 m
.60464 .57925 L
s
.69254 .60152 m
.68715 .6011 L
s
.69828 .60088 m
.69254 .60152 L
s
.68715 .6011 m
.6821 .59961 L
s
.70078 .5989 m
.69828 .60088 L
s
.6821 .59961 m
.68098 .59735 L
s
.66197 .59913 m
.65656 .5987 L
s
.6659 .59835 m
.66197 .59913 L
s
.65656 .5987 m
.65328 .59736 L
s
.67017 .5965 m
.6659 .59835 L
s
.65328 .59736 m
.65031 .59495 L
s
.68098 .59735 m
.68347 .59536 L
s
.63492 .59701 m
.63931 .58199 L
s
.61504 .59546 m
.61895 .59468 L
s
.60961 .59503 m
.61504 .59546 L
s
.68347 .59536 m
.68742 .59458 L
s
.60628 .59368 m
.60961 .59503 L
s
.65031 .59495 m
.64947 .5916 L
s
.61895 .59468 m
.62167 .59161 L
s
.68742 .59458 m
.69678 .59422 L
s
.69678 .59422 m
.70074 .59343 L
s
.60171 .59005 m
.60628 .59368 L
s
.70074 .59343 m
.70326 .59144 L
s
.4843 .59288 m
.477 .59231 L
s
.48816 .59209 m
.4843 .59288 L
s
.57698 .59248 m
.58088 .5917 L
s
.57153 .59206 m
.57698 .59248 L
s
.477 .59231 m
.47356 .59095 L
s
.49225 .59023 m
.48816 .59209 L
s
.56816 .5907 m
.57153 .59206 L
s
.58088 .5917 m
.58507 .58984 L
s
.62167 .59161 m
.62472 .58083 L
s
.64947 .5916 m
.65011 .58946 L
s
.56426 .59149 m
.56993 .56869 L
s
.70326 .59144 m
.70361 .59037 L
s
.47356 .59095 m
.47032 .58852 L
s
.56506 .58827 m
.56816 .5907 L
s
.55153 .5905 m
.55517 .57535 L
s
.7206 .5895 m
.71843 .59043 L
s
.71843 .59043 m
.71699 .58922 L
s
.70361 .59037 m
.70252 .58808 L
s
.49452 .58823 m
.49225 .59023 L
s
.54425 .58993 m
.53878 .5895 L
s
.54814 .58914 m
.54425 .58993 L
s
.58507 .58984 m
.58774 .58676 L
s
.71916 .58828 m
.7206 .5895 L
s
.53878 .5895 m
.53538 .58814 L
s
.65011 .58946 m
.6529 .58637 L
s
.71699 .58922 m
.71916 .58828 L
s
.5523 .58727 m
.54814 .58914 L
s
.68622 .58679 m
.68372 .5888 L
s
.47032 .58852 m
.4689 .58623 L
s
.53538 .58814 m
.53223 .5857 L
s
.70252 .58808 m
.69744 .58657 L
s
.51507 .58765 m
.52054 .58807 L
s
.6699 .5855 m
.67285 .58794 L
s
.51165 .58628 m
.51507 .58765 L
s
.50593 .58693 m
.50917 .57172 L
s
.69201 .58614 m
.68622 .58679 L
s
.58774 .58676 m
.5883 .5846 L
s
.69744 .58657 m
.69201 .58614 L
s
.6529 .58637 m
.65718 .5845 L
s
.50845 .58384 m
.51165 .58628 L
s
.4689 .58623 m
.46768 .58285 L
s
.53223 .5857 m
.53114 .58232 L
s
.6666 .58414 m
.6699 .5855 L
s
.5883 .5846 m
.58732 .58121 L
s
.65718 .5845 m
.66115 .58371 L
s
.66115 .58371 m
.6666 .58414 L
s
.50731 .58045 m
.50845 .58384 L
s
.45647 .58307 m
.45184 .5672 L
s
.46768 .58285 m
.46871 .57742 L
s
.53114 .58232 m
.53163 .58015 L
s
.44177 .58192 m
.45184 .5672 L
s
.44177 .58192 m
.437 .56603 L
s
.34114 .58174 m
.34681 .58109 L
s
.3282 .58073 m
.34114 .58174 L
s
.58732 .58121 m
.58423 .57875 L
s
.34681 .58109 m
.35076 .5792 L
s
.42704 .58077 m
.437 .56603 L
s
.3282 .58073 m
.33063 .55764 L
s
.53163 .58015 m
.53421 .57703 L
s
.41415 .57976 m
.41655 .56441 L
s
.57141 .57774 m
.56721 .57963 L
s
.48711 .57886 m
.4963 .57958 L
s
.49697 .57632 m
.4963 .57958 L
s
.35076 .5792 m
.35287 .57717 L
s
.40677 .57918 m
.40123 .57875 L
s
.41063 .57838 m
.40677 .57918 L
s
.58423 .57875 m
.58085 .57737 L
s
.40123 .57875 m
.3977 .57737 L
s
.55124 .57615 m
.55439 .57862 L
s
.41466 .57649 m
.41063 .57838 L
s
.57535 .57694 m
.57141 .57774 L
s
.46871 .57742 m
.47117 .57429 L
s
.58085 .57737 m
.57535 .57694 L
s
.3977 .57737 m
.39432 .5749 L
s
.37721 .57687 m
.38276 .57731 L
s
.35287 .57717 m
.35512 .57404 L
s
.53421 .57703 m
.53838 .57514 L
s
.37365 .57549 m
.37721 .57687 L
s
.49558 .57399 m
.49697 .57632 L
s
.54783 .57477 m
.55124 .57615 L
s
.36796 .57615 m
.36994 .56074 L
s
.37023 .57302 m
.37365 .57549 L
s
.53838 .57514 m
.54231 .57433 L
s
.39432 .5749 m
.39294 .57147 L
s
.54231 .57433 m
.54783 .57477 L
s
.47117 .57429 m
.47344 .57224 L
s
.35512 .57404 m
.35578 .56856 L
s
.49233 .57151 m
.49558 .57399 L
s
.3688 .56958 m
.37023 .57302 L
s
.47344 .57224 m
.47756 .57034 L
s
.48886 .57012 m
.49233 .57151 L
s
.39294 .57147 m
.39326 .56928 L
s
.47756 .57034 m
.48147 .56953 L
s
.48147 .56953 m
.48886 .57012 L
s
.39326 .56928 m
.39559 .56612 L
s
.35578 .56856 m
.35432 .5651 L
s
.41266 .56523 m
.41603 .56773 L
s
.39559 .56612 m
.39963 .5642 L
s
.40911 .56383 m
.41266 .56523 L
s
.35432 .5651 m
.35272 .56274 L
s
.39963 .5642 m
.40352 .56339 L
s
.40352 .56339 m
.40911 .56383 L
s
.35272 .56274 m
.34924 .56023 L
s
.34924 .56023 m
.34375 .55867 L
s
.34375 .55867 m
.33063 .55764 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0J@3oool60000oa80oooo00<000000?ooo`3oool08@3oool3000004`0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`1Z0?ooo`030000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0oooo00L0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`04000000000?l0003o0000oaL0oooo
0`00001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool30000o`030000003oool0oooo00<0003o1`3oool00`000?l0oooo0?oo
o`070?ooo`<00000E`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0003o00H0oooo0P000?l40?ooo`030000o`3oool00000008000001P3oool20000oal0oooo00<0
003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool010000000oooo0?ooo`00
0?l60?ooo`030000o`3oool0003o0080oooo0P000?l00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0003o1P3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0300oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`L0oooo00<0003o
0?ooo`3oool0103oool00`000000003o0?ooo`050?ooo`040000o`3oool0oooo0000o`80000000<0
003o0?ooo`000?l01P3oool20000o`H0oooo0P000?l40?ooo`030000o`3oool0oooo00T0oooo0`00
0?l70?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0000o`040000o`<0oooo0P000?l50?ooo`030000o`3oool0
oooo00<0oooo00L0003o00000000000000000000o`3oool0003o0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1P3oool30000o`<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030000obh0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`1Z0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03`3oool60000o`030000003o
ool0oooo0080000000<0003o0?ooo`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo0P000?l30?ooo`<0003o0`3oool20000o`H0oooo00<0003o0?ooo`3oool08`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo06X0oooo2@000?lI0?ooo`80000000<0oooo0000o`3oool0103oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<0
00000?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`H0003o2`3oool2000005/0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool60000o`<0oooo0`000?l50?ooo`040000o`3o
ool0oooo0?ooo`80003o1`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo
0?ooo`020?ooo`<0003o0`0000000`000?l0oooo000000030?ooo`030000o`3oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0@0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0?0?ooo`H0003o0`3oool00`000?l0oooo0000
o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool4000000<0oooo00D0
003o0?ooo`3oool000000?ooo`030000oeD0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0B0?ooo`H0003o6`3oool00`000?l0oooo0?oo
o`050000o`H0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`070?ooo`<000001P3oool20000o`80oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0440oooo00<0003o0?ooo`000?l01@000?l50?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool3000000<0oooo1P000?l50?ooo`03000000000?l0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`100?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool30000o`<000000P000?l30?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0@03oool00`000?l0oooo0?ooo`0A0?ooo`<000000P000?l60?ooo`L0003o1@3oool00`000?l0
oooo0000001F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`090?ooo`80003o0P3oool4000001L0oooo
00@0003o0?ooo`3oool00000E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000K0?ooo`040000o`3oool0oooo000005H0
oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`1:0?ooo`<000007@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`170?ooo`<00000803oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3
000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?oo
o`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<0
0000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3o
ool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool2
00000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo
0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?oo
o`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3o
ool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo
0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo
0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?oo
o`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3o
ool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<0
00000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?oo
o`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00
001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?oo
o`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3o
ool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo
01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`00
00270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00
603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@000002
0?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?oo
o`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<0
00000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3o
ool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000
003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103o
ool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700
oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool0
0000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool0
0`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
04L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo
0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool0
0`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
04h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo
00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo
0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo1000
00030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?
0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`04
0000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000
003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo
00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P00
00000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3o
ool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
06<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0
oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo
001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo1000
00090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?oo
o`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003o
ool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0
oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool40000
02P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0
oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo
001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<00000
0?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?oo
o`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3o
ool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?oo
o`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?oo
o`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?oo
o`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`80
0000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3o
ool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3o
ool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool0
0`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo
0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0
oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo
0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00
001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo10000020
0?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?oo
o`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000
003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3o
ool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo
0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo
03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0
oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo
1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000
002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;
0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?oo
o`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?oo
o`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?oo
o`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3o
ool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0
oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C
0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?oo
o`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.69558 .63207 m
.70548 .61839 L
s
.68625 .62115 m
.68055 .62108 L
s
.68932 .61953 m
.68625 .62115 L
s
.68055 .62108 m
.67555 .62003 L
s
.67555 .62003 m
.67123 .618 L
s
.67123 .618 m
.67094 .61568 L
s
.62151 .61777 m
.62049 .61643 L
s
.62386 .61713 m
.62151 .61777 L
s
.62284 .61579 m
.62386 .61713 L
s
.62049 .61643 m
.62284 .61579 L
s
.67094 .61568 m
.67401 .61405 L
s
.65211 .61513 m
.64707 .61408 L
s
.65615 .61484 m
.65211 .61513 L
s
.66088 .61357 m
.65615 .61484 L
s
.68713 .61453 m
.69117 .61424 L
s
.67806 .61376 m
.68713 .61453 L
s
.69117 .61424 m
.69426 .61261 L
s
.64707 .61408 m
.64438 .61238 L
s
.67401 .61405 m
.67806 .61376 L
s
.71144 .61281 m
.70905 .61345 L
s
.70905 .61345 m
.7081 .61211 L
s
.71049 .61146 m
.71144 .61281 L
s
.69426 .61261 m
.69497 .61162 L
s
.64438 .61238 m
.64237 .60969 L
s
.7081 .61211 m
.71049 .61146 L
s
.69497 .61162 m
.69472 .60928 L
s
.59005 .61009 m
.60381 .58892 L
s
.62684 .60984 m
.63629 .59579 L
s
.64237 .60969 m
.64272 .60634 L
s
.69472 .60928 m
.69039 .60722 L
s
.6796 .60609 m
.67652 .60773 L
s
.69039 .60722 m
.68535 .60615 L
s
.64272 .60634 m
.64408 .60434 L
s
.68535 .60615 m
.6796 .60609 L
s
.6082 .60594 m
.61226 .60565 L
s
.60311 .60488 m
.6082 .60594 L
s
.61226 .60565 m
.61595 .603 L
s
.66443 .60288 m
.66642 .6056 L
s
.60036 .60316 m
.60311 .60488 L
s
.64408 .60434 m
.64783 .60168 L
s
.59721 .59907 m
.60036 .60316 L
s
.61595 .603 m
.62265 .5929 L
s
.66175 .60117 m
.66443 .60288 L
s
.64783 .60168 m
.65259 .60038 L
s
.65667 .60009 m
.66175 .60117 L
s
.65259 .60038 m
.65667 .60009 L
s
.57238 .59845 m
.57645 .59816 L
s
.56724 .59737 m
.57238 .59845 L
s
.57645 .59816 m
.58117 .59685 L
s
.56444 .59564 m
.56724 .59737 L
s
.58117 .59685 m
.58482 .59417 L
s
.56037 .59593 m
.57386 .5744 L
s
.56227 .59289 m
.56444 .59564 L
s
.58482 .59417 m
.58613 .59214 L
s
.54832 .59341 m
.55718 .57907 L
s
.58613 .59214 m
.58636 .58872 L
s
.54141 .59197 m
.53623 .59088 L
s
.54549 .59167 m
.54141 .59197 L
s
.5502 .59036 m
.54549 .59167 L
s
.53623 .59088 m
.53339 .58914 L
s
.53339 .58914 m
.53116 .58637 L
s
.58636 .58872 m
.58422 .58595 L
s
.48161 .58751 m
.47463 .58606 L
s
.48569 .58722 m
.48161 .58751 L
s
.51368 .58617 m
.51889 .58726 L
s
.49037 .5859 m
.48569 .58722 L
s
.53116 .58637 m
.53128 .58292 L
s
.51081 .58441 m
.51368 .58617 L
s
.47463 .58606 m
.47171 .5843 L
s
.58422 .58595 m
.58143 .58419 L
s
.49331 .58421 m
.49037 .5859 L
s
.57214 .5834 m
.56739 .58472 L
s
.50854 .58162 m
.51081 .58441 L
s
.50497 .58434 m
.51351 .56984 L
s
.47171 .5843 m
.46938 .58152 L
s
.58143 .58419 m
.57624 .5831 L
s
.57624 .5831 m
.57214 .5834 L
s
.53128 .58292 m
.53253 .58086 L
s
.55307 .57937 m
.55527 .58217 L
s
.50861 .57816 m
.50854 .58162 L
s
.46938 .58152 m
.46879 .57909 L
s
.53253 .58086 m
.53614 .57813 L
s
.55022 .5776 m
.55307 .57937 L
s
.46879 .57909 m
.46878 .57561 L
s
.53614 .57813 m
.54088 .5768 L
s
.545 .5765 m
.55022 .5776 L
s
.54088 .5768 m
.545 .5765 L
s
.48933 .57411 m
.49811 .57595 L
s
.49992 .57284 m
.49811 .57595 L
s
.46878 .57561 m
.47172 .57041 L
s
.45763 .57444 m
.45868 .55826 L
s
.49937 .57038 m
.49992 .57284 L
s
.44349 .57148 m
.45868 .55826 L
s
.44349 .57148 m
.44441 .55525 L
s
.47172 .57041 m
.47526 .56764 L
s
.49706 .56755 m
.49937 .57038 L
s
.4293 .56851 m
.44441 .55525 L
s
.47526 .56764 m
.47821 .56592 L
s
.49414 .56575 m
.49706 .56755 L
s
.47821 .56592 m
.48294 .56456 L
s
.41685 .56591 m
.4247 .55108 L
s
.48707 .56426 m
.49414 .56575 L
s
.48294 .56456 m
.48707 .56426 L
s
.40972 .56441 m
.40436 .56329 L
s
.41384 .56411 m
.40972 .56441 L
s
.41852 .56275 m
.41384 .56411 L
s
.40436 .56329 m
.40133 .56149 L
s
.40133 .56149 m
.39884 .55862 L
s
.38105 .55841 m
.38644 .55954 L
s
.34907 .55875 m
.35372 .55738 L
s
.34314 .55868 m
.34907 .55875 L
s
.33048 .55604 m
.34314 .55868 L
s
.39884 .55862 m
.39869 .55506 L
s
.37799 .5566 m
.38105 .55841 L
s
.35372 .55738 m
.35657 .55564 L
s
.37545 .55372 m
.37799 .5566 L
s
.37205 .55653 m
.37955 .54154 L
s
.33048 .55604 m
.34123 .53344 L
s
.35657 .55564 m
.35994 .55282 L
s
.39869 .55506 m
.39978 .55293 L
s
.42055 .55139 m
.42301 .55428 L
s
.37525 .55014 m
.37545 .55372 L
s
.39978 .55293 m
.40324 .55011 L
s
.35994 .55282 m
.36257 .54748 L
s
.41751 .54956 m
.42055 .55139 L
s
.40324 .55011 m
.40795 .54873 L
s
.41211 .54842 m
.41751 .54956 L
s
.40795 .54873 m
.41211 .54842 L
s
.36257 .54748 m
.36234 .54387 L
s
.36234 .54387 m
.36158 .54133 L
s
.36158 .54133 m
.359 .53839 L
s
.359 .53839 m
.35405 .53615 L
s
.35405 .53615 m
.34123 .53344 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo06`0oooo0`000?l80?ooo`030000003oool0oooo04D0oooo
0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`1[0?ooo`040000o`3oool0oooo0?ooo`<0003o
1P3oool00`000000oooo0?ooo`110?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1[0?ooo`030000o`3o
ool0oooo00@0oooo0P000?l50?ooo`030000003oool0oooo03d0oooo0`00000g0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0JP3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>@3oool3
000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`00
0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l000000?ooo`0f0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo000003<0oooo0`0000100?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0JP3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo000000050?oo
o`L0003o8`3oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000?l01`3oool20000
oah0oooo0`0000160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo0`00001Z0?ooo`<0003o1`3oool00`000?l0oooo0?ooo`030?ooo`80003o1@3oool00`000000
oooo0000o`080?ooo`80003o1`3oool00`000?l0oooo0?ooo`0A0?ooo`<00000B@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo06`0oooo
1`000?l60?ooo`040000o`3oool0003o0000o`@0oooo00<000000?ooo`000?l01`3oool00`000?l0
oooo0?ooo`050?ooo`80003o103oool00`000?l0oooo0?ooo`090?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo07h0oooo
0P000?l30?ooo`03000000000?l0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0000o`030?ooo`80003o1`3oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`03000000000?l0003o0080oooo0`00
0?l50?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0000o`040?ooo`<00000E03o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08D0oooo00H000000?ooo`000?l0003o0?ooo`000?l50?ooo`060000o`3oool0oooo0?ooo`00
0?l0oooo0P000?l0103oool0003o0?ooo`3oool300000080oooo1`000?m>0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`030000o`0000000000
00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0:0?ooo`030000o`3oool000000080000000<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0A@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0203oool3000000<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`80003o0P3oool01@000?l0oooo0?ooo`3oool0003o01L0oooo00<0003o0?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000000/0oooo00<0003o0?ooo`3oool0
1P3oool30000o`<0oooo00<0003o0?ooo`3oool02@3oool20000o`T0oooo00<0003o0?ooo`3oool0
;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000>0?ooo`030000o`3oool0oooo00/0oooo0P00
0?l90?ooo`80003o0P3oool30000o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`3oool0;`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08`0oooo0P00000A0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool2
0000o`L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo
0140oooo00<0003o0?ooo`3oool01@3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l01`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo1`000?l/0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0180oooo1`000?l70?ooo`<0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0V0?ooo`<000000P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0:03oool20000o`@0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06`3oool40000
00H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo10000?l50?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140
oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`80003o1`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`090?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool70000o`D0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo0`00
000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0o0?ooo`80003o1P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo0P000?l300000080003o503oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0?`3oool00`000?l0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00@0003o0?oo
o`3oool0oooo100000050?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03h0oooo00@0003o0?ooo`3oool0oooo1@000?l50?ooo`060000o`00000000000000003oool0003o
1`3oool00`000?l0oooo0?ooo`020?ooo`<0003o3@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3o
ool00`000?l0oooo0?ooo`090?ooo`<000000`3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3o
ool0oooo0?ooo`@0003o2P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?oo
o`070?ooo`<0000000<0oooo0000o`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0080oooo0P000?l50?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000;0?ooo`040000o`3oool0
oooo0?ooo`80003o103oool90000o`@0oooo0P000?l60?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`10
0?ooo`@00000103oool30000o`P0oooo0`000?l50?ooo`030000o`3oool0oooo01@0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03h0oooo0`0000090?ooo`030000o`3oool0oooo00l0oooo0`000?l40?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>`3oool300000240oooo10000?l50?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03P0oooo0`00000/0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03D0oooo0`00000_0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0340oooo1000000a0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02h0oooo0`00000d0?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?oo
o`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q
0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<0
0000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<0
0000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000
IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0
oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@0
00000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
3P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo
0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool40000
0440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo
0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.67289 .65099 m
.68708 .63892 L
s
.66775 .63933 m
.66232 .6386 L
s
.67125 .63813 m
.66775 .63933 L
s
.66232 .6386 m
.65789 .637 L
s
.65789 .637 m
.65445 .63452 L
s
.69469 .63423 m
.69219 .63457 L
s
.69219 .63457 m
.69175 .63316 L
s
.65445 .63452 m
.65498 .63223 L
s
.69425 .63282 m
.69469 .63423 L
s
.67485 .63323 m
.67836 .63202 L
s
.67088 .63303 m
.67485 .63323 L
s
.69175 .63316 m
.69425 .63282 L
s
.66246 .63122 m
.67088 .63303 L
s
.65498 .63223 m
.65849 .63102 L
s
.67836 .63202 m
.67938 .63114 L
s
.65849 .63102 m
.66246 .63122 L
s
.67938 .63114 m
.67995 .62885 L
s
.64107 .62968 m
.63709 .62948 L
s
.64606 .629 m
.64107 .62968 L
s
.63709 .62948 m
.63261 .62786 L
s
.67995 .62885 m
.67653 .62634 L
s
.60669 .62841 m
.60617 .62699 L
s
.60918 .62807 m
.60669 .62841 L
s
.60866 .62665 m
.60918 .62807 L
s
.63261 .62786 m
.63061 .62589 L
s
.60617 .62699 m
.60866 .62665 L
s
.67653 .62634 m
.67208 .62472 L
s
.63061 .62589 m
.62961 .62304 L
s
.6666 .62397 m
.66308 .6252 L
s
.67208 .62472 m
.6666 .62397 L
s
.62961 .62304 m
.63111 .61983 L
s
.65317 .61907 m
.65413 .62193 L
s
.61459 .62134 m
.62859 .60882 L
s
.63111 .61983 m
.63312 .61805 L
s
.65119 .61708 m
.65317 .61907 L
s
.63312 .61805 m
.63764 .61592 L
s
.57891 .61718 m
.59963 .59823 L
s
.64669 .61543 m
.65119 .61708 L
s
.63764 .61592 m
.64267 .61523 L
s
.60197 .61553 m
.60646 .61339 L
s
.59795 .61532 m
.60197 .61553 L
s
.64267 .61523 m
.64669 .61543 L
s
.59339 .61367 m
.59795 .61532 L
s
.59133 .61167 m
.59339 .61367 L
s
.60646 .61339 m
.61644 .60438 L
s
.5897 .60731 m
.59133 .61167 L
s
.56988 .60391 m
.57492 .60321 L
s
.56583 .60371 m
.56988 .60391 L
s
.5612 .60203 m
.56583 .60371 L
s
.57492 .60321 m
.57941 .60105 L
s
.55909 .60001 m
.5612 .60203 L
s
.57941 .60105 m
.58138 .59922 L
s
.55794 .59706 m
.55909 .60001 L
s
.55502 .5998 m
.57568 .58044 L
s
.58138 .59922 m
.58281 .59592 L
s
.58281 .59592 m
.5817 .59296 L
s
.54416 .59587 m
.55783 .58295 L
s
.54201 .59383 m
.53793 .59362 L
s
.54707 .59312 m
.54201 .59383 L
s
.53793 .59362 m
.53325 .59192 L
s
.5817 .59296 m
.5796 .59091 L
s
.53325 .59192 m
.53108 .58987 L
s
.5796 .59091 m
.57495 .58921 L
s
.53108 .58987 m
.52988 .58689 L
s
.57086 .589 m
.56578 .58971 L
s
.57495 .58921 m
.57086 .589 L
s
.52988 .58689 m
.53121 .58354 L
s
.51284 .58455 m
.51757 .58625 L
s
.55372 .58274 m
.55488 .58574 L
s
.51065 .58248 m
.51284 .58455 L
s
.53121 .58354 m
.53315 .58168 L
s
.55157 .58066 m
.55372 .58274 L
s
.5094 .57947 m
.51065 .58248 L
s
.48498 .58213 m
.48086 .58192 L
s
.49005 .58141 m
.48498 .58213 L
s
.48086 .58192 m
.47449 .57963 L
s
.50495 .58169 m
.51842 .56855 L
s
.53315 .58168 m
.53764 .57945 L
s
.49353 .58012 m
.49005 .58141 L
s
.54686 .57894 m
.55157 .58066 L
s
.47449 .57963 m
.47224 .57754 L
s
.5107 .57608 m
.5094 .57947 L
s
.53764 .57945 m
.54274 .57873 L
s
.54274 .57873 m
.54686 .57894 L
s
.47224 .57754 m
.47092 .57452 L
s
.47092 .57452 m
.4712 .57206 L
s
.49319 .56972 m
.50117 .57262 L
s
.50405 .56979 m
.50117 .57262 L
s
.4712 .57206 m
.47243 .56864 L
s
.50438 .56732 m
.50405 .56979 L
s
.47243 .56864 m
.47716 .5639 L
s
.50311 .56425 m
.50438 .56732 L
s
.46184 .5661 m
.46861 .55034 L
s
.50087 .56213 m
.50311 .56425 L
s
.47716 .5639 m
.48163 .56163 L
s
.49445 .55979 m
.50087 .56213 L
s
.48163 .56163 m
.48515 .56031 L
s
.44891 .56143 m
.46861 .55034 L
s
.44891 .56143 m
.45558 .54557 L
s
.48515 .56031 m
.49028 .55957 L
s
.49028 .55957 m
.49445 .55979 L
s
.43591 .55672 m
.45558 .54557 L
s
.42447 .55259 m
.43754 .53898 L
s
.42212 .55044 m
.41791 .55022 L
s
.42725 .54969 m
.42212 .55044 L
s
.41791 .55022 m
.41298 .54843 L
s
.41298 .54843 m
.4106 .54627 L
s
.4106 .54627 m
.40915 .54313 L
s
.40915 .54313 m
.41027 .5396 L
s
.39149 .54066 m
.39646 .54246 L
s
.4333 .53876 m
.43472 .54192 L
s
.38907 .53848 m
.39149 .54066 L
s
.41027 .5396 m
.41212 .53764 L
s
.43094 .53657 m
.4333 .53876 L
s
.38757 .53531 m
.38907 .53848 L
s
.38317 .53765 m
.39602 .5238 L
s
.41212 .53764 m
.41656 .53529 L
s
.35936 .53691 m
.36451 .53615 L
s
.35343 .53608 m
.35936 .53691 L
s
.42599 .53476 m
.43094 .53657 L
s
.36451 .53615 m
.36799 .53479 L
s
.34165 .53185 m
.35343 .53608 L
s
.38865 .53174 m
.38757 .53531 L
s
.41656 .53529 m
.42174 .53453 L
s
.36799 .53479 m
.37238 .53244 L
s
.42174 .53453 m
.42599 .53476 L
s
.37238 .53244 m
.37693 .52749 L
s
.34165 .53185 m
.36056 .51084 L
s
.37693 .52749 m
.37799 .52389 L
s
.37799 .52389 m
.37813 .52128 L
s
.37813 .52128 m
.3766 .51804 L
s
.3766 .51804 m
.37244 .51519 L
s
.37244 .51519 m
.36056 .51084 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`3oool3
0000of80oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
003o00<0oooo0`000?mL0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0EP3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1_0?ooo`030000o`3oool0000000L0
oooo00<0003o0?ooo`3oool0D@3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1^0?ooo`050000o`3oool0oooo0?ooo`00
00001P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04P0oooo0`00000U0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000
KP3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`160?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`800000KP3oool00`000?l0oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`130?ooo`<00000:`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?oo
o`1/0?ooo`80003o203oool00`000000oooo0000o`050?ooo`030000o`3oool0oooo0440oooo0`00
000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<00000
0?ooo`000000803oool00`000000oooo0?ooo`1^0?ooo`80003o1`3oool00`000000003o0?ooo`03
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0<P3oool300000340oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?oo
o`030000003oool0oooo0700oooo20000?l00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
00P0oooo0P000?l00`3oool0003o0000o`020000obd0oooo0`00000d0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0
oooo00H000000?ooo`3oool0003o0?ooo`000?l70?ooo`80003o1P3oool00`000?l0oooo0000o`0X
0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool00P3oool30000o`<0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0T0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0280oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0F0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01`3o
ool60000o`P0oooo0P000?l50?ooo`030000o`3oool0oooo00h0oooo0`0000130?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo0P000?l00`3oool0003o0?ooo`02
0?ooo`80003o3P3oool3000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool300000840oooo00<000000?ooo`3oool03`3oool20000o`80oooo00<0003o0?oo
o`3oool00P000?l00`3oool0003o0?ooo`0:0?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool0303oool20000o`@0oooo0`000?l20?ooo`030000o`3oool0oooo00L0oooo0`00001<0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0@0?ooo`80003o103oool00`000?l0oooo0?ooo`030?ooo`800000
1@000?m=0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0D0?ooo`040000o`3oool0oooo0?ooo`800000
0`000?l50?ooo`80003oB`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool04`3oool01P000?l000000000
00000000oooo0000o`T0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000000<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`0000060?ooo`030000o`3o
ool0oooo00D0oooo0P000?l20?ooo`050000o`3oool0oooo0?ooo`000?l0AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0203oool3000000P0oooo00<0003o0?ooo`3oool0203oool20000o`<0oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000000`0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`030000
0100oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80003o2@3oool50000
ocX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`800000503oool60000o`@0oooo00<0003o0?ooo`000?l0203oool00`000?l0
oooo0?ooo`030?ooo`80003o203oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0200oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o00D0oooo
00<0003o0?ooo`3oool0;@3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0Q0?ooo`80003o0`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:`3oool300000080oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0103oool20000o`@0oooo1P000?lV
0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool20000o`<0oooo00<0003o0?oo
o`3oool00`3oool20000o`D0oooo00<0003o0?ooo`3oool0803oool3000000X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02X0oooo0`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool07@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo0`00000B0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0`0?ooo`80003o1`3oool20000o`@0oooo00<0003o0?ooo`3oool04P3o
ool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo1`000?l50?ooo`030000o`3oool0
oooo00l0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00`3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03`0
oooo0P000?l80?ooo`040000o`3oool0oooo0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0>`3oool00`000?l0oooo0000o`060?ooo`80003o00D0oooo00000000000000000000o`0U0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`03
0000003oool0oooo03X0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`040000o`0000000000
00000080oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`000000000000800000103oool00`000?l0oooo0?ooo`040?oo
o`H0003o7@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000000L0oooo00<0003o0?ooo`3o
ool00P3oool30000o`D0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool3000000T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo01/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000B0?ooo`030000o`3o
ool0oooo00T0oooo1@000?lG0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000303oool2
0000o`L0oooo0P000?l?0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0340oooo1000000J0?ooo`D0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
01D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00000U0?ooo`030000o`3oool0003o00L0
003o103oool20000oa80oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00000X0?ooo`030000
o`3oool0oooo00/0oooo0P000?lB0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000;03o
ool30000o`80oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0
oooo02D0oooo0`00000b0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo
0240oooo1000000k0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0
oooo0`00000n0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0K0?ooo`<00000@03oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`0000120?ooo`030000o`3oool0oooo01d0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0
oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P
0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00
000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3o
ool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0
oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool20000
02D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00
001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3o
ool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900
oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool5
00000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P00
00090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo
00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo
0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00
001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`80
0000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo
0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`800000
2`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3o
ool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0
oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0
oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo
00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000
D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03o
ool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?oo
o`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@00000
1@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3o
ool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool0
06X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<0
00000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?oo
o`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000
<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool0
0`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool20000
00d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool50000
0480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo
09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00
000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V
0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?oo
o`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000
003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3o
ool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool4
00000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool40000
08@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo
00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00
000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?oo
o`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0
=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03o
ool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool00000
02<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool40000
0;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`00
0000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`800000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P00
00050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool5
00000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool30000
0080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.64461 .66669 m
.66239 .65664 L
s
.64372 .65479 m
.63876 .65344 L
s
.64749 .65403 m
.64372 .65479 L
s
.63876 .65344 m
.63505 .65137 L
s
.6713 .65298 m
.66879 .65302 L
s
.66879 .65302 m
.66886 .6516 L
s
.67136 .65156 m
.6713 .65298 L
s
.66886 .6516 m
.67136 .65156 L
s
.63505 .65137 m
.63261 .64856 L
s
.65264 .6497 m
.65643 .64894 L
s
.64891 .64904 m
.65264 .6497 L
s
.64146 .6463 m
.64891 .64904 L
s
.65643 .64894 m
.65772 .64821 L
s
.63261 .64856 m
.63391 .64641 L
s
.65772 .64821 m
.65905 .64605 L
s
.63391 .64641 m
.6377 .64564 L
s
.6377 .64564 m
.64146 .6463 L
s
.65905 .64605 m
.65665 .64322 L
s
.65665 .64322 m
.65294 .64112 L
s
.62141 .64229 m
.61764 .64163 L
s
.62645 .64222 m
.62141 .64229 L
s
.61764 .64163 m
.61389 .63953 L
s
.65294 .64112 m
.64794 .63976 L
s
.64794 .63976 m
.64414 .64053 L
s
.61389 .63953 m
.61264 .63738 L
s
.61264 .63738 m
.61267 .63449 L
s
.58864 .63701 m
.58863 .63556 L
s
.59117 .63697 m
.58864 .63701 L
s
.59116 .63552 m
.59117 .63697 L
s
.63675 .63342 m
.63667 .63632 L
s
.58863 .63556 m
.59116 .63552 L
s
.61267 .63449 m
.61524 .63155 L
s
.63553 .63126 m
.63675 .63342 L
s
.61524 .63155 m
.61779 .63006 L
s
.63177 .62913 m
.63553 .63126 L
s
.59875 .63106 m
.61664 .62055 L
s
.61779 .63006 m
.62289 .62853 L
s
.62797 .62845 m
.63177 .62913 L
s
.62289 .62853 m
.62797 .62845 L
s
.58857 .6239 m
.59366 .62236 L
s
.58474 .62322 m
.58857 .6239 L
s
.5809 .62107 m
.58474 .62322 L
s
.56562 .62277 m
.59234 .60679 L
s
.59366 .62236 m
.60646 .61478 L
s
.5796 .61888 m
.5809 .62107 L
s
.57955 .61443 m
.5796 .61888 L
s
.56149 .60874 m
.56663 .60866 L
s
.55761 .60804 m
.56149 .60874 L
s
.56663 .60866 m
.57175 .60709 L
s
.55369 .60585 m
.55761 .60804 L
s
.57175 .60709 m
.5743 .60555 L
s
.55234 .60362 m
.55369 .60585 L
s
.5743 .60555 m
.57684 .6025 L
s
.55226 .6006 m
.55234 .60362 L
s
.54845 .60292 m
.57534 .58655 L
s
.57684 .6025 m
.5768 .59948 L
s
.5768 .59948 m
.57548 .59723 L
s
.53924 .59777 m
.5571 .58682 L
s
.57548 .59723 m
.57156 .59501 L
s
.53786 .59551 m
.53395 .59481 L
s
.54305 .59543 m
.53786 .59551 L
s
.57156 .59501 m
.56766 .59431 L
s
.53395 .59481 m
.52997 .59258 L
s
.56766 .59431 m
.56247 .59438 L
s
.52997 .59258 m
.52858 .59031 L
s
.52858 .59031 m
.52845 .58724 L
s
.55317 .58611 m
.55325 .58918 L
s
.52845 .58724 m
.53093 .58413 L
s
.5518 .58382 m
.55317 .58611 L
s
.51259 .58286 m
.51662 .58511 L
s
.53093 .58413 m
.53348 .58255 L
s
.54782 .58156 m
.5518 .58382 L
s
.51117 .58056 m
.51259 .58286 L
s
.53348 .58255 m
.53865 .58092 L
s
.54388 .58085 m
.54782 .58156 L
s
.53865 .58092 m
.54388 .58085 L
s
.51101 .57746 m
.51117 .58056 L
s
.50586 .57909 m
.52369 .56789 L
s
.51347 .57431 m
.51101 .57746 L
s
.48608 .57705 m
.4821 .57633 L
s
.49132 .57698 m
.48608 .57705 L
s
.4952 .57614 m
.49132 .57698 L
s
.4821 .57633 m
.47664 .5733 L
s
.47664 .5733 m
.47516 .57097 L
s
.47516 .57097 m
.47493 .56784 L
s
.49854 .56591 m
.50534 .56974 L
s
.50917 .56732 m
.50534 .56974 L
s
.47493 .56784 m
.47607 .56546 L
s
.51036 .56494 m
.50917 .56732 L
s
.47607 .56546 m
.47849 .56226 L
s
.5102 .56178 m
.51036 .56494 L
s
.47849 .56226 m
.48483 .5582 L
s
.50875 .55942 m
.5102 .56178 L
s
.50328 .55632 m
.50875 .55942 L
s
.46894 .55844 m
.4812 .54381 L
s
.48483 .5582 m
.49003 .55652 L
s
.49003 .55652 m
.49395 .55567 L
s
.49926 .55559 m
.50328 .55632 L
s
.49395 .55567 m
.49926 .55559 L
s
.45783 .55222 m
.4812 .54381 L
s
.45783 .55222 m
.47003 .53748 L
s
.44663 .54595 m
.47003 .53748 L
s
.43677 .54044 m
.45455 .52871 L
s
.4352 .53802 m
.4311 .53727 L
s
.44056 .53794 m
.4352 .53802 L
s
.4311 .53727 m
.42684 .53488 L
s
.42684 .53488 m
.42525 .53245 L
s
.42525 .53245 m
.42492 .52916 L
s
.45044 .52795 m
.45072 .53124 L
s
.42492 .52916 m
.42729 .52583 L
s
.44888 .5255 m
.45044 .52795 L
s
.40823 .52447 m
.41254 .52688 L
s
.42729 .52583 m
.42983 .52413 L
s
.44461 .52308 m
.44888 .5255 L
s
.40661 .52201 m
.40823 .52447 L
s
.42983 .52413 m
.43507 .5224 L
s
.44048 .52231 m
.44461 .52308 L
s
.43507 .5224 m
.44048 .52231 L
s
.40624 .51868 m
.40661 .52201 L
s
.40101 .52043 m
.41875 .50843 L
s
.40858 .51531 m
.40624 .51868 L
s
.37749 .51662 m
.38291 .51654 L
s
.37185 .51504 m
.37749 .51662 L
s
.38291 .51654 m
.38688 .51564 L
s
.38688 .51564 m
.39211 .51389 L
s
.36156 .50932 m
.37185 .51504 L
s
.39211 .51389 m
.39842 .50959 L
s
.39842 .50959 m
.40076 .50617 L
s
.36156 .50932 m
.38802 .49101 L
s
.40076 .50617 m
.40184 .50361 L
s
.40184 .50361 m
.40146 .50022 L
s
.40146 .50022 m
.39833 .49686 L
s
.39833 .49686 m
.38802 .49101 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo06l0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0403oool20000o`03
0?ooo`000?l0003o06`0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0IP3oool3000000D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0680oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0:0?ooo`80003o2@3oool00`000?l0oooo0?ooo`1N0?ooo`<000002`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`1K0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`050?ooo`80003o2`3oool00`000?l0oooo0?ooo`1I0?ooo`<000004@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1?0?ooo`<00000503oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`030?ooo`80003o2@3oool00`00
0?l0oooo0?ooo`040?ooo`80003oC`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0103oool20000o`@0oooo0`000?l50?ooo`80003oCP3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`050?ooo`@0003o1P3oool20000odd0
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0003o04T0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo1@00
0?lg0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X
0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`04
0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`0a0?ooo`<00000:03oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0>0?oo
o`80003o0`3oool00`000?l0oooo0?ooo`070?ooo`80003o;P3oool3000002/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0:P3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
1@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02P0oooo0`00000a0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0140oooo0`000?l30?ooo`80003o:03o
ool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0C0?ooo`<0003o2@3oool2
0000oa`0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00D0oooo10000?lJ0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool05`3oool30000o`80
oooo00<0003o0?ooo`3oool00P3oool20000oa80oooo0`00000m0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0D0?ooo`80003o1@3oool00`000?l0oooo0?ooo`030000oa00oooo0`0000100?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0I0?ooo`@0003o00<0oooo0000o`3oool03@3oool3000004<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo01L0oooo0P000?l40?ooo`030000o`3oool0oooo00T0oooo0`000016
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?oo
o`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool01@3oool30000o`800000B@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`030?ooo`<0003o0P0000000`3oool0
003o0000o`190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`80003o0P0000060?ooo`80003o
B03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0603oool2000000030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000030?ooo`000?l0
oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`180?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<00000103oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`@0oooo00<0
003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000000L0oooo00<0003o
0?ooo`3oool0203oool20000o`<0oooo0P000?m40?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?oo
o`<000002`3oool00`000?l0oooo0?ooo`0:0?ooo`80003oAP3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool3000000l0oooo1`000?l30?ooo`80003oB03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000K0?ooo`030000o`3oool0003o04P0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000803oool20000o`L0oooo1P00
0?lj0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`80003o=`3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`000?l01@3oool00`000?l0oooo0?ooo`0Z0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool09P3oool00`000?l0oooo0?ooo`060?ooo`80003o103oool20000obT0oooo100000060?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00@0oooo0P000?l40?ooo`80003o
:03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo1P000?l50?ooo`D0003o8`3o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool00`3oool2
0000o`D0oooo00<0003o0?ooo`3oool07@3oool300000180oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02h0oooo0P000?l80?ooo`030000o`3oool0oooo01T0oooo0`00000F0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0]0?ooo`030000o`3oool0003o00P0oooo00<0003o0?ooo`3oool05@3oool4000001X0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00`0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0`0?ooo`L0003o1@3oool20000o``0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0j
0?ooo`80003o2`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`070?oo
o`040000o`0000000000000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03L0oooo0`000?l60?oo
o`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0=P3oool20000o`80oooo00@0003o0?ooo`3o
ool0oooo0`0000000`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo0080oooo00H0003o00000000000000000?ooo`000?l70?ooo`80003o:`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>03oool3000000@0003o1P3oool20000obh0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03D0oooo0`00000;0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0a0?ooo`@00000303oool20000o`D0oooo10000?l00`3oool0003o
0?ooo`0X0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<000005P3oool00`000?l0oooo0?oo
o`040?ooo`80003o:03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000l0oooo0P000?l7
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:03oool300000180oooo0P000?l70?ooo`030000o`3oool0oooo0300oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3o
ool09@3oool3000001l0oooo0P000?l90?ooo`@0003o903oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000
903oool30000o`X0oooo0P000?lS0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
3`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000;@3o
ool50000o`D0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01/0oooo0`00000`0?ooo`030000o`3oool0oooo0080oooo1@000?lT0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000d0?ooo`030000o`3oool0
oooo00T0oooo0P000?lP0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool0
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01D0oooo0`00000h0?ooo`@0003o1`3oool20000ob40oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@00000A03oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`0000160?ooo`80003o9`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00/0oooo0`0000170?ooo`80003o:@3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0203oool3000004P0oooo0P000?l/0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`@00000BP3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
07l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`28
0?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61195 .67867 m
.63256 .67095 L
s
.64239 .66843 m
.63997 .66818 L
s
.64295 .66707 m
.64239 .66843 L
s
.63997 .66818 m
.64053 .66681 L
s
.64053 .66681 m
.64295 .66707 L
s
.61523 .667 m
.61091 .66512 L
s
.61913 .6667 m
.61523 .667 L
s
.61091 .66512 m
.60806 .66267 L
s
.6256 .66309 m
.62951 .66279 L
s
.62222 .66202 m
.6256 .66309 L
s
.62951 .66279 m
.631 .66223 L
s
.60806 .66267 m
.60668 .65966 L
s
.631 .66223 m
.63303 .66029 L
s
.616 .65849 m
.62222 .66202 L
s
.63303 .66029 m
.6317 .65727 L
s
.60668 .65966 m
.60869 .65771 L
s
.61261 .65741 m
.616 .65849 L
s
.60869 .65771 m
.61261 .65741 L
s
.6317 .65727 m
.62886 .6548 L
s
.62886 .6548 m
.62453 .65289 L
s
.62453 .65289 m
.62059 .6532 L
s
.60294 .65277 m
.59804 .65225 L
s
.59804 .65225 m
.59463 .65117 L
s
.59463 .65117 m
.59173 .64868 L
s
.59173 .64868 m
.59127 .64645 L
s
.61594 .64542 m
.61486 .64823 L
s
.59127 .64645 m
.59231 .64363 L
s
.61552 .64318 m
.61594 .64542 L
s
.59231 .64363 m
.59582 .64107 L
s
.5706 .64351 m
.56813 .64325 L
s
.5711 .6421 m
.5706 .64351 L
s
.56813 .64325 m
.56863 .64184 L
s
.61263 .64067 m
.61552 .64318 L
s
.56863 .64184 m
.5711 .6421 L
s
.59582 .64107 m
.59881 .63992 L
s
.6092 .63956 m
.61263 .64067 L
s
.59881 .63992 m
.60427 .63904 L
s
.60427 .63904 m
.6092 .63956 L
s
.58002 .63865 m
.601 .63054 L
s
.57265 .63047 m
.57813 .62957 L
s
.56917 .62935 m
.57265 .63047 L
s
.57813 .62957 m
.59317 .62371 L
s
.56618 .62679 m
.56917 .62935 L
s
.56569 .6245 m
.56618 .62679 L
s
.55072 .62662 m
.58229 .61424 L
s
.5672 .62016 m
.56569 .6245 L
s
.55665 .61297 m
.56219 .61206 L
s
.55162 .61243 m
.55665 .61297 L
s
.54809 .61129 m
.55162 .61243 L
s
.56219 .61206 m
.56521 .61086 L
s
.54504 .60867 m
.54809 .61129 L
s
.56521 .61086 m
.56874 .6082 L
s
.54451 .60633 m
.54504 .60867 L
s
.56874 .6082 m
.56976 .60525 L
s
.54549 .60337 m
.54451 .60633 L
s
.56976 .60525 m
.56926 .60289 L
s
.54096 .60518 m
.57287 .59246 L
s
.56926 .60289 m
.56623 .60025 L
s
.56623 .60025 m
.56268 .59909 L
s
.56268 .59909 m
.55761 .59854 L
s
.53377 .59902 m
.55503 .5905 L
s
.53831 .5972 m
.53322 .59665 L
s
.53322 .59665 m
.52964 .59548 L
s
.52964 .59548 m
.52653 .59282 L
s
.52653 .59282 m
.52597 .59043 L
s
.55146 .58933 m
.55046 .59233 L
s
.52597 .59043 m
.52692 .58741 L
s
.55093 .58692 m
.55146 .58933 L
s
.52692 .58741 m
.53045 .58467 L
s
.54784 .58423 m
.55093 .58692 L
s
.53045 .58467 m
.53349 .58344 L
s
.54424 .58305 m
.54784 .58423 L
s
.51294 .58117 m
.5161 .58387 L
s
.53349 .58344 m
.53911 .58249 L
s
.53911 .58249 m
.54424 .58305 L
s
.51236 .57875 m
.51294 .58117 L
s
.51329 .57569 m
.51236 .57875 L
s
.50767 .57665 m
.52908 .5679 L
s
.51682 .57291 m
.51329 .57569 L
s
.49414 .57278 m
.48896 .57221 L
s
.49825 .57244 m
.49414 .57278 L
s
.48896 .57221 m
.4853 .57101 L
s
.4853 .57101 m
.48099 .56735 L
s
.50513 .56283 m
.51046 .56743 L
s
.51506 .56554 m
.51046 .56743 L
s
.48099 .56735 m
.48035 .56488 L
s
.51707 .56336 m
.51506 .56554 L
s
.48035 .56488 m
.48124 .56178 L
s
.51802 .56024 m
.51707 .56336 L
s
.48124 .56178 m
.48321 .55958 L
s
.51744 .55776 m
.51802 .56024 L
s
.48321 .55958 m
.48671 .55675 L
s
.51317 .55404 m
.51744 .55776 L
s
.48671 .55675 m
.49439 .55356 L
s
.50948 .55281 m
.51317 .55404 L
s
.49439 .55356 m
.50008 .55257 L
s
.50424 .55223 m
.50948 .55281 L
s
.50008 .55257 m
.50424 .55223 L
s
.47866 .5518 m
.4959 .539 L
s
.46991 .54429 m
.4959 .539 L
s
.46991 .54429 m
.48715 .53138 L
s
.46107 .53672 m
.48715 .53138 L
s
.45327 .53004 m
.47499 .52079 L
s
.45791 .52807 m
.45258 .52746 L
s
.45258 .52746 m
.44879 .5262 L
s
.44879 .5262 m
.44541 .52331 L
s
.44541 .52331 m
.4447 .52071 L
s
.4712 .51952 m
.47032 .52278 L
s
.4447 .52071 m
.44554 .51744 L
s
.47053 .51691 m
.4712 .51952 L
s
.44554 .51744 m
.44907 .51446 L
s
.46718 .51399 m
.47053 .51691 L
s
.44907 .51446 m
.45219 .51312 L
s
.46337 .5127 m
.46718 .51399 L
s
.43065 .51066 m
.43408 .5136 L
s
.45219 .51312 m
.45799 .51209 L
s
.45799 .51209 m
.46337 .5127 L
s
.42992 .50803 m
.43065 .51066 L
s
.43073 .5047 m
.42992 .50803 L
s
.42492 .50575 m
.44679 .49623 L
s
.43426 .50168 m
.43073 .5047 L
s
.40829 .49956 m
.41256 .49919 L
s
.40286 .49894 m
.40829 .49956 L
s
.41256 .49919 m
.41839 .49814 L
s
.3978 .49663 m
.40286 .49894 L
s
.41839 .49814 m
.4262 .49472 L
s
.38956 .48964 m
.3978 .49663 L
s
.4262 .49472 m
.42974 .49167 L
s
.42974 .49167 m
.43173 .48929 L
s
.38956 .48964 m
.42248 .47506 L
s
.43173 .48929 m
.43256 .4859 L
s
.43256 .4859 m
.43065 .48217 L
s
.43065 .48217 m
.42248 .47506 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool08P3oool20000o`03
0?ooo`000?l0oooo06D0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0O0?ooo`80003o
103oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0703o
ool20000o`L0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`<00000CP3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo01T0oooo0P000?l:0?ooo`030000o`3oool0oooo0640oooo00@000000?ooo`3oool0oooo0`00
001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool05P3oool20000o``0oooo00<0003o0?ooo`3oool0H@3oool4000005D0oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0C0?oo
o`80003o3@3oool20000of40oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool04`3oool20000o`/0oooo00<0003o0?ooo`3o
ool0GP3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0
1`3oool20000o`H0oooo00<0003o0?ooo`3oool0E03oool3000000D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool05@3o
ool90000o`H0oooo0P000?mD0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08@3oool2
0000oe<0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool20000
oe80oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
01/0oooo0`000?m@0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo04/0oooo0`00000D0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool01@3oool60000
ocd0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
01/0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=`3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool0<`3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool01`3oool20000obl0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`0M0?ooo`030000o`3oool0oooo00H0oooo0P000?l]0?ooo`<000009@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`030?ooo`80003o;03oool3000002P0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?oo
o`3oool07@3oool50000ob/0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool07@3oool20000o`T0oooo0`000?lN0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0R0?ooo`L0003o703oool300000340oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool07P3oool30000o`@0oooo00<0003o0?ooo`3oool06@3o
ool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo0080oooo0`000?lB0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0803oool90000
oa00oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?ooo`<0003o103oool00`000?l0
oooo0?ooo`0=0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo
0?ooo`0;0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0803oool20000o`/0oooo0`00
00130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0oooo1@000?l0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo0`0000210?ooo`030000003oool0oooo0280oooo0`000?l300000080oooo00<0003o0?oo
o`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool07`3oool20000o`<000001P3oool20000od@0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo01`0oooo00@000000000o`00000000002P3oool00`000?l0
oooo0?ooo`130?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<0000000<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo01@0oooo0`0000030?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0003o
AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0403oool3000000H0oooo00<0003o0?ooo`3oool0203o
ool20000o`@0oooo0P000?m10?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000002P3oool3
0000o`/0oooo0P000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000403oool40000
o`@0oooo0`000?m50?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000006@3oool40000odH0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00<000007P3oool00`000?l0oooo0?ooo`150?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03o
ool200000240oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`3oool00`3oool30000o`040?ooo`000?l0003o0000ocT0oooo0P00
001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool09@3oool20000o`L0oooo00<0003o0?ooo`3oool0<`3oool300000080oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01`3oool20000obl0oooo100000060?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00H0oooo0P000?l50?ooo`80
003o9P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0
0`3oool20000o`D0oooo0P000?lU0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09`3o
ool50000o`D0oooo0P000?lT0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool2
0000o`D0oooo0P000?l0103oool0003o0000o`000?lO0?ooo`<000005P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0;03oool30000o`H0oooo00<0003o0?ooo`3oool0603oool4000001X0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02/0oooo0P000?l80?ooo`030000o`3oool0oooo01D0oooo0`00000N0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04P3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0
0P3oool30000oa80oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
4@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo02h0oooo10000?l70?ooo`80003o2@3o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03L0oooo0P000?l70?ooo`@00000;P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0=@3oool30000o`H0oooo0`00000c0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0c0?ooo`<0003o1@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo
0P000?l20?ooo`030000o`3oool0oooo00<000000`3oool20000ocD0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02l0oooo0P000?l40?ooo`<000000`3oool30000ocP0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0340oooo100000000`3oool0003o0000o`030000o`H0oooo0P000?ld0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0^0?ooo`<000003P3oool20000ocL0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00000>0?ooo`<0003o>@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000l0oooo
0P000?l70?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000h0oooo00<0
003o0?ooo`3oool01`3oool30000o`040?ooo`000?l0003o0000oc<0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool400000140oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool07P3oool3000001d0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool30000
0240oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000U0?ooo`80003o>`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000:P3oool20000o`D0
oooo10000?la0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool400000300oooo
0P000?l60?ooo`030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool03P3oool3000003<0oooo00<0003o0?ooo`3oool00P000?l50?ooo`030000o`3o
ool0oooo02l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000=`3oool0
10000?l0oooo0?ooo`3oool50000oc80oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000k
0?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000o0?oo
o`<0003o1`3oool20000obl0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000B@3oool20000
oc@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo1000001:0?ooo`80003o=`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`800000T03oool3000004X0oooo0`000?li0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<0
00000?ooo`3oool0AP3oool20000ocd0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03o
ool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00
000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.57619 .68658 m
.59883 .68143 L
s
.6092 .68011 m
.60696 .67958 L
s
.61021 .67884 m
.6092 .68011 L
s
.60696 .67958 m
.60797 .67832 L
s
.60797 .67832 m
.61021 .67884 L
s
.58733 .67574 m
.58344 .67558 L
s
.58344 .67558 m
.57991 .67325 L
s
.57991 .67325 m
.578 .67054 L
s
.59873 .67313 m
.60036 .67276 L
s
.59484 .67298 m
.59873 .67313 L
s
.59195 .67154 m
.59484 .67298 L
s
.60036 .67276 m
.603 .67111 L
s
.58716 .66739 m
.59195 .67154 L
s
.603 .67111 m
.60276 .66802 L
s
.578 .67054 m
.57772 .66744 L
s
.60276 .66802 m
.60088 .66529 L
s
.57772 .66744 m
.58034 .66578 L
s
.58425 .66594 m
.58716 .66739 L
s
.58034 .66578 m
.58425 .66594 L
s
.60088 .66529 m
.59736 .66293 L
s
.59736 .66293 m
.59344 .66277 L
s
.5765 .6603 m
.57193 .65922 L
s
.57193 .65922 m
.569 .65776 L
s
.569 .65776 m
.56705 .655 L
s
.59166 .65466 m
.58964 .65726 L
s
.56705 .655 m
.56739 .65277 L
s
.59203 .65242 m
.59166 .65466 L
s
.56739 .65277 m
.56938 .65015 L
s
.59012 .64964 m
.59203 .65242 L
s
.56938 .65015 m
.57368 .64806 L
s
.58718 .64816 m
.59012 .64964 L
s
.58259 .64707 m
.58718 .64816 L
s
.57368 .64806 m
.57698 .64729 L
s
.5483 .64748 m
.54599 .64693 L
s
.54928 .64616 m
.5483 .64748 L
s
.57698 .64729 m
.58259 .64707 L
s
.54599 .64693 m
.54697 .64561 L
s
.54697 .64561 m
.54928 .64616 L
s
.55918 .64384 m
.58239 .63841 L
s
.55487 .63498 m
.56052 .63475 L
s
.55188 .63347 m
.55487 .63498 L
s
.56052 .63475 m
.57718 .63083 L
s
.54987 .63062 m
.55188 .63347 L
s
.55019 .62832 m
.54987 .63062 L
s
.53485 .62861 m
.56993 .6203 L
s
.55318 .62427 m
.55019 .62832 L
s
.54543 .61599 m
.55114 .61576 L
s
.54071 .61485 m
.54543 .61599 L
s
.55114 .61576 m
.5545 .61495 L
s
.5545 .61495 m
.55887 .61278 L
s
.53766 .61331 m
.54071 .61485 L
s
.5356 .61039 m
.53766 .61331 L
s
.55887 .61278 m
.5609 .61003 L
s
.53591 .60803 m
.5356 .61039 L
s
.5609 .61003 m
.56124 .60767 L
s
.5379 .60526 m
.53591 .60803 L
s
.56124 .60767 m
.55921 .60472 L
s
.53284 .60647 m
.5684 .59792 L
s
.55921 .60472 m
.55617 .60316 L
s
.55617 .60316 m
.55142 .60201 L
s
.52799 .59958 m
.55173 .59384 L
s
.53306 .59836 m
.52828 .59719 L
s
.52828 .59719 m
.52519 .59562 L
s
.52519 .59562 m
.52309 .59263 L
s
.54865 .59226 m
.54663 .59508 L
s
.52309 .59263 m
.52338 .59022 L
s
.54898 .58985 m
.54865 .59226 L
s
.52338 .59022 m
.52537 .58739 L
s
.54691 .58685 m
.54898 .58985 L
s
.52537 .58739 m
.52978 .58514 L
s
.54382 .58525 m
.54691 .58685 L
s
.53901 .58407 m
.54382 .58525 L
s
.52978 .58514 m
.53319 .58431 L
s
.53319 .58431 m
.53901 .58407 L
s
.51388 .57957 m
.51602 .5826 L
s
.51416 .57712 m
.51388 .57957 L
s
.51615 .57424 m
.51416 .57712 L
s
.5103 .57449 m
.53434 .56857 L
s
.52058 .57196 m
.51615 .57424 L
s
.50254 .5692 m
.49839 .56902 L
s
.49839 .56902 m
.4935 .56782 L
s
.4935 .56782 m
.49032 .56618 L
s
.49032 .56618 m
.48738 .56206 L
s
.51269 .56064 m
.51629 .5658 L
s
.52146 .56453 m
.51629 .5658 L
s
.52419 .56264 m
.52146 .56453 L
s
.52622 .55972 m
.52419 .56264 L
s
.48738 .56206 m
.48762 .55956 L
s
.52652 .55721 m
.52622 .55972 L
s
.48762 .55956 m
.48959 .55662 L
s
.52365 .55304 m
.52652 .55721 L
s
.48959 .55662 m
.4923 .55472 L
s
.4923 .55472 m
.49675 .55238 L
s
.52047 .55138 m
.52365 .55304 L
s
.49675 .55238 m
.50541 .55022 L
s
.51555 .55015 m
.52047 .55138 L
s
.50541 .55022 m
.51135 .54996 L
s
.51135 .54996 m
.51555 .55015 L
s
.49058 .54651 m
.51203 .53615 L
s
.48461 .53804 m
.51203 .53615 L
s
.48461 .53804 m
.50613 .52757 L
s
.47859 .52949 m
.50613 .52757 L
s
.47326 .52194 m
.49793 .51564 L
s
.47853 .52059 m
.47349 .51932 L
s
.47349 .51932 m
.4702 .51759 L
s
.4702 .51759 m
.46789 .51431 L
s
.49465 .51391 m
.49262 .517 L
s
.46789 .51431 m
.46811 .51167 L
s
.49491 .51127 m
.49465 .51391 L
s
.46811 .51167 m
.4701 .50857 L
s
.49264 .50797 m
.49491 .51127 L
s
.4701 .50857 m
.47464 .5061 L
s
.48935 .50622 m
.49264 .50797 L
s
.48427 .50492 m
.48935 .50622 L
s
.47464 .5061 m
.47818 .50518 L
s
.47818 .50518 m
.48427 .50492 L
s
.45778 .49998 m
.46013 .50331 L
s
.45799 .49729 m
.45778 .49998 L
s
.45998 .49413 m
.45799 .49729 L
s
.45385 .4944 m
.47884 .48791 L
s
.46454 .49163 m
.45998 .49413 L
s
.44394 .48634 m
.45009 .48607 L
s
.43958 .48614 m
.44394 .48634 L
s
.4344 .48482 m
.43958 .48614 L
s
.45009 .48607 m
.45903 .48373 L
s
.4302 .48188 m
.4344 .48482 L
s
.45903 .48373 m
.46362 .48119 L
s
.42451 .4739 m
.4302 .48188 L
s
.46362 .48119 m
.46643 .47912 L
s
.46643 .47912 m
.46845 .47589 L
s
.46845 .47589 m
.46789 .47198 L
s
.42451 .4739 m
.46233 .46391 L
s
.46789 .47198 m
.46233 .46391 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03L0oooo0P000?mH0?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0<P3oool40000o`80oooo00<0003o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0;P3oool30000o`H0oooo00<0003o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0:@3oool40000o`X0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02H0oooo0P000?l>0?ooo`030000o`3oool0oooo
05@0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool09@3oool00`000?l0oooo0?ooo`070?ooo`@0003oE`3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo02D0oooo2@000?mK0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo03<0oooo0`000?mB0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo02h0oooo10000?mC0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02X0
oooo10000?mC0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`1?0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo04`0oooo0`00
00080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04T0oooo0`00000;
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`040?oo
o`<0003o?`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0;P3oool010000?l0oooo0?ooo`3oool20000ocX0oooo0`00000A0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02/0oooo0P000?l60?ooo`80003o=@3oool3
000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0300oooo0`00000H0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool01`3oool3
0000obd0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`040?ooo`<0003o;03oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02P0
oooo1P000?l[0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool09`3oool20000ob`0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`1A0?ooo`<00000:03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0]
0?ooo`H0003o6P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0V0?oo
o`H0003o0`3oool20000oaP0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo02`0oooo0P000?lG0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0Y0?ooo`80003o0P3oool50000o`l0oooo0`00000d0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool09P3oool60000o`80oooo0P000?l=0?ooo`<00000=`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0:`3oool20000o``0oooo0`00000j0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`0X0?ooo`80003o2`3oool3000003d0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02D0
oooo0P000?l:0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0:03oool60000o`800000
@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool09@3oool20000o`80oooo0`000000103oool0003o0000
o`000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00
00210?ooo`030000003oool0oooo0280oooo0P000?l0103oool000000000000000060?ooo`030000
o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0200oooo00@0003o0000000000000000
2P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`<0000000<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01P0oooo0`0000030?ooo`030000o`3oool0oooo00H0oooo00D0003o
0?ooo`3oool0oooo0000o`130?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000001`3oool0
0`000?l0oooo0?ooo`060?ooo`<0003oA03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool30000
00/0oooo10000?l90?ooo`<0003o?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001L0
oooo10000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000005`3oool40000odD0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00@0oooo0`00000L0?ooo`030000o`3oool0oooo04@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo00<000007P3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool20000
0280oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0V0?ooo`L0003o>P3oool2000005/0
oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=03oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0_0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo02d0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?oo
o`030000o`3oool0oooo00D0oooo0`000?lZ0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool09P3oool70000o`H0oooo0`000?lQ0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
9P3oool30000o`H0oooo10000?lQ0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3o
ool60000oal0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`<0003o1P3oool0
0`000?l0oooo0?ooo`0I0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01D0oooo0`00000R0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo
00<000000?ooo`3oool0:@3oool20000o`D0oooo0P000?lB0?ooo`<00000:P3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:`3oool50000oa00oooo1000000^0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0e
0?ooo`80003o1`3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo0`000?l60?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0;P3oool40000o`H0oooo0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0[0?ooo`<0003o00<0oooo0000o`3oool0103oool3000003h0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02T0oooo0P000?l40?ooo`030000o`3oool0000000<000000`3o
ool20000ocd0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000040?ooo`<0003o@03oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:`3oool3000000<0oooo10000?m30?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0X0?ooo`<000003P3oool30000ocd0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000d0oooo
10000?m10?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
002@0?ooo`030000003oool0oooo0240oooo1000000=0?ooo`<0003oAP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000000`0oooo0`000?l;0?ooo`030000o`3oool0oooo03h0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000403oool00`000?l0oooo0?ooo`070?oo
o`<0003o00@0oooo0000o`000?l0003o?@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0H0?ooo`<000006`3oool20000o`L0oooo00<0003o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000007@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@000008@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03h0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002H0oooo
0`000?m60?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`00
00050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000340oooo0`00
0?ln0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000;`3oool30000o`D0oooo00<0003o
0?ooo`3oool0?03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool400000340oooo00D0003o0?oo
o`3oool0oooo0000o`050?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo
0?ooo`<00000=@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0?@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?oo
o`800000T@3oool4000003T0oooo00<0003o0?ooo`3oool00P3oool40000od40oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000m0?ooo`<0
003oAP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0
?@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08P0oooo100000050?ooo`030000003oool0oooo0400oooo0P000?l20?ooo`80003o@03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08D0oooo0`0000090?ooo`030000003oool0oooo03`0oooo10000?m70?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0>@3oool30000od`0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.53865 .69019 m
.56249 .68776 L
s
.57302 .68766 m
.57102 .6869 L
s
.57444 .68655 m
.57302 .68766 L
s
.57102 .6869 m
.57245 .68578 L
s
.57245 .68578 m
.57444 .68655 L
s
.55329 .68089 m
.54957 .68029 L
s
.54957 .68029 m
.54695 .67761 L
s
.56529 .67966 m
.567 .67949 L
s
.56157 .67906 m
.56529 .67966 L
s
.567 .67949 m
.57015 .67818 L
s
.55926 .67733 m
.56157 .67906 L
s
.57015 .67818 m
.571 .67514 L
s
.54695 .67761 m
.54604 .67474 L
s
.55606 .67272 m
.55926 .67733 L
s
.571 .67514 m
.57013 .67226 L
s
.54604 .67474 m
.54685 .67168 L
s
.55374 .67097 m
.55606 .67272 L
s
.57013 .67226 m
.56753 .66955 L
s
.54685 .67168 m
.54999 .67036 L
s
.54999 .67036 m
.55374 .67097 L
s
.56753 .66955 m
.56379 .66894 L
s
.54816 .66456 m
.54409 .66297 L
s
.56489 .66082 m
.56201 .66313 L
s
.54409 .66297 m
.54174 .66121 L
s
.54174 .66121 m
.54081 .65828 L
s
.56603 .65869 m
.56489 .66082 L
s
.56515 .65575 m
.56603 .65869 L
s
.54081 .65828 m
.54193 .65614 L
s
.54193 .65614 m
.54479 .65381 L
s
.56281 .65396 m
.56515 .65575 L
s
.55873 .65236 m
.56281 .65396 L
s
.54479 .65381 m
.54971 .65228 L
s
.55319 .65192 m
.55873 .65236 L
s
.54971 .65228 m
.55319 .65192 L
s
.52516 .64872 m
.52309 .64791 L
s
.52658 .64754 m
.52516 .64872 L
s
.52309 .64791 m
.52451 .64674 L
s
.52451 .64674 m
.52658 .64754 L
s
.53706 .64645 m
.56157 .64388 L
s
.54155 .63772 m
.55915 .63587 L
s
.53596 .63727 m
.54155 .63772 L
s
.53357 .63545 m
.53596 .63727 L
s
.53261 .63242 m
.53357 .63545 L
s
.53373 .63021 m
.53261 .63242 L
s
.53807 .6266 m
.53373 .63021 L
s
.51863 .62867 m
.55579 .62473 L
s
.53907 .61804 m
.54263 .61766 L
s
.53341 .61758 m
.53907 .61804 L
s
.54263 .61766 m
.54766 .61606 L
s
.5292 .6159 m
.53341 .61758 L
s
.54766 .61606 m
.55059 .61362 L
s
.52677 .61403 m
.5292 .6159 L
s
.52578 .61092 m
.52677 .61403 L
s
.55059 .61362 m
.55176 .61136 L
s
.55176 .61136 m
.55082 .60824 L
s
.52691 .60865 m
.52578 .61092 L
s
.52983 .60618 m
.52691 .60865 L
s
.55082 .60824 m
.54839 .60635 L
s
.52446 .60676 m
.56214 .60271 L
s
.54839 .60635 m
.54417 .60464 L
s
.52213 .59943 m
.54734 .59671 L
s
.52753 .59884 m
.52326 .59713 L
s
.54489 .59479 m
.54193 .59729 L
s
.52326 .59713 m
.52079 .59521 L
s
.52079 .59521 m
.51978 .59203 L
s
.54606 .59247 m
.54489 .59479 L
s
.5451 .58928 m
.54606 .59247 L
s
.51978 .59203 m
.52092 .58971 L
s
.52092 .58971 m
.52386 .58718 L
s
.54264 .58735 m
.5451 .58928 L
s
.53836 .5856 m
.54264 .58735 L
s
.52386 .58718 m
.52896 .58552 L
s
.53259 .58513 m
.53836 .5856 L
s
.52896 .58552 m
.53259 .58513 L
s
.51536 .57811 m
.51639 .58134 L
s
.5165 .57575 m
.51536 .57811 L
s
.51946 .57318 m
.5165 .57575 L
s
.52461 .57149 m
.51946 .57318 L
s
.51364 .5727 m
.53925 .56989 L
s
.5079 .56655 m
.50389 .56586 L
s
.50389 .56586 m
.49951 .56407 L
s
.52086 .55944 m
.52257 .56494 L
s
.52808 .56433 m
.52257 .56494 L
s
.53141 .56283 m
.52808 .56433 L
s
.49951 .56407 m
.49697 .56208 L
s
.53443 .56022 m
.53141 .56283 L
s
.49697 .56208 m
.49553 .55766 L
s
.5356 .55781 m
.53443 .56022 L
s
.53426 .55337 m
.5356 .55781 L
s
.49553 .55766 m
.49665 .55525 L
s
.49665 .55525 m
.49962 .55261 L
s
.53174 .55135 m
.53426 .55337 L
s
.49962 .55261 m
.50296 .55109 L
s
.52736 .54953 m
.53174 .55135 L
s
.50296 .55109 m
.50815 .54936 L
s
.52331 .54883 m
.52736 .54953 L
s
.50815 .54936 m
.51741 .54833 L
s
.51741 .54833 m
.52331 .54883 L
s
.50416 .54283 m
.52884 .53539 L
s
.50129 .53378 m
.52884 .53539 L
s
.50129 .53378 m
.52608 .52626 L
s
.49839 .52463 m
.52608 .52626 L
s
.49582 .51654 m
.52225 .51354 L
s
.50147 .5159 m
.49697 .51401 L
s
.51965 .51143 m
.51658 .51419 L
s
.49697 .51401 m
.49434 .51189 L
s
.49434 .51189 m
.49323 .50838 L
s
.52084 .50887 m
.51965 .51143 L
s
.51978 .50535 m
.52084 .50887 L
s
.49323 .50838 m
.49438 .50582 L
s
.49438 .50582 m
.49743 .50303 L
s
.51716 .50322 m
.51978 .50535 L
s
.51264 .50129 m
.51716 .50322 L
s
.49743 .50303 m
.50276 .5012 L
s
.50657 .50076 m
.51264 .50129 L
s
.50276 .5012 m
.50657 .50076 L
s
.48835 .49302 m
.48948 .49659 L
s
.4895 .49041 m
.48835 .49302 L
s
.49258 .48757 m
.4895 .49041 L
s
.49795 .4857 m
.49258 .48757 L
s
.48645 .48703 m
.51331 .48393 L
s
.48569 .47837 m
.49532 .47725 L
s
.47953 .47782 m
.48569 .47837 L
s
.47529 .47706 m
.47953 .47782 L
s
.49532 .47725 m
.50073 .47536 L
s
.47066 .47507 m
.47529 .47706 L
s
.50073 .47536 m
.50422 .47369 L
s
.46754 .47164 m
.47066 .47507 L
s
.50422 .47369 m
.50735 .4708 L
s
.46475 .46305 m
.46754 .47164 L
s
.50735 .4708 m
.50818 .4669 L
s
.50818 .4669 m
.50557 .45826 L
s
.46475 .46305 m
.50557 .45826 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`170?ooo`@0003oA`3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo03h0oooo20000?l30?ooo`030000o`3oool0oooo04D0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0i0?ooo`@0003o303oool00`000?l0oooo0?ooo`150?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo04D0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
03L0oooo00<0003o0?ooo`3oool02@3oool20000odP0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0g0?ooo`/0003oBP3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00
001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0?P3oool60000odD0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0>03oool6
0000odX0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0>03oool20000od/0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0=`3oool00`000?l0
oooo0?ooo`170?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo
0?ooo`140?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0>P3oool50000ocL0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0=`3oool20000o`D0oooo0P000?lb0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0;03oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0=03oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02T0oooo0`00000D0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03<0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0V0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0c0?ooo`<0003o0`3oool50000ob@0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0<P3oool60000obH0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0300oooo2`000?lF0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0e0?ooo`<0003o5@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0a0?ooo`<0003o5@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0;P3oool50000oa80oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0380oooo1P000?l90?ooo`<00000=03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo0380oooo0`000?l80?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0;P3oool30000o`P0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0[0?ooo`80
003o203oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000100?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0Z0?ooo`T0003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool09P3oool3
0000o`<000001P3oool20000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool300000840oooo00<000000?ooo`3oool0903oool010000?l0000000000000000:
0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0P0000000`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0
oooo100000020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0m0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000001P3oool20000o`L0oooo
00D0003o0?ooo`3oool0oooo0000o`100?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000
2`3oool30000o`D0oooo0`000?m10?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000FP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0303oool3000001T0oooo00<0003o0?ooo`000?l010000?lm
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000603oool60000od80oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo00@0oooo0`00000L0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000O0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008P3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo02H0oooo1@000?ll0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo0P000?l50?oo
o`030000o`3oool0oooo03H0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0<@3oool4000000H0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0^0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo02/0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`<0003o0P3oool5
0000obT0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`D0003o:`3oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo1`000?lM0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0903oool:0000oal0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool06@3oool300000280oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0E
0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?oo
o`800000S`3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04`3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo0`000?l20?ooo`<0
003o4P3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo0P000?lB0?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02h0oooo10000?l60?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool09`3oool70000
o`L0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0S0?ooo`@0003o0P3oool20000o`H0
oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00<0oooo
0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool00000008000000P3o
ool30000odD0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`0000050000odT0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?oo
o`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?oo
o`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000000X0oooo1@000?m70?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<00000103oool00`000?l0oooo0?ooo`020?ooo`D0003o
C@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`0000070?ooo`80003oE@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000503o
ool40000odX0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3
000001D0oooo0P000?l40?ooo`80003oB@3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0140oooo1000000G0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000006`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0;0?ooo`<000007P3oool20000o`D0oooo0`000?m:0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`080?ooo`<000008`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`04
0?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000[0?ooo`80003o0`3oool2
0000odd0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool20000
0940oooo1000000]0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0B`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool30000
02l0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo04X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?oo
o`<000000P3oool00`000000oooo0?ooo`0^0?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool0
0`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0;`3oool20000
o`<0oooo0P000?m@0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo
0`00000<0?ooo`030000003oool0oooo03L0oooo0P000?m?0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0<03oool50000o`<0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo02`0oooo1@000?mI0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.53517 .69089 m
.5335 .68991 L
s
.53695 .68996 m
.53517 .69089 L
s
.53528 .68898 m
.53695 .68996 L
s
.5335 .68991 m
.53528 .68898 L
s
.50068 .68942 m
.52486 .68978 L
s
.53218 .68221 m
.5357 .68129 L
s
.53044 .68218 m
.53218 .68221 L
s
.52702 .68116 m
.53044 .68218 L
s
.51829 .682 m
.51486 .68098 L
s
.5357 .68129 m
.5376 .67842 L
s
.52537 .6792 m
.52702 .68116 L
s
.51486 .68098 m
.51324 .67805 L
s
.52386 .67432 m
.52537 .6792 L
s
.5376 .67842 m
.53776 .6755 L
s
.51324 .67805 m
.51336 .67513 L
s
.53776 .6755 m
.53618 .67255 L
s
.51336 .67513 m
.51522 .67223 L
s
.52221 .67234 m
.52386 .67432 L
s
.53618 .67255 m
.53274 .67152 L
s
.51876 .67131 m
.52221 .67234 L
s
.51522 .67223 m
.51876 .67131 L
s
.53667 .66371 m
.53305 .66563 L
s
.51902 .66542 m
.51559 .66339 L
s
.53853 .66176 m
.53667 .66371 L
s
.51559 .66339 m
.51391 .66138 L
s
.5387 .65878 m
.53853 .66176 L
s
.51391 .66138 m
.51403 .65841 L
s
.53705 .65677 m
.5387 .65878 L
s
.51403 .65841 m
.51588 .65644 L
s
.53362 .65472 m
.53705 .65677 L
s
.51588 .65644 m
.51949 .6545 L
s
.52838 .65364 m
.53362 .65472 L
s
.51949 .6545 m
.52484 .65358 L
s
.52484 .65358 m
.52838 .65364 L
s
.50205 .6472 m
.50031 .64616 L
s
.50386 .64622 m
.50205 .6472 L
s
.51452 .64638 m
.53937 .64677 L
s
.50212 .64518 m
.50386 .64622 L
s
.50031 .64616 m
.50212 .64518 L
s
.52199 .63838 m
.53983 .63866 L
s
.51667 .63728 m
.52199 .63838 L
s
.51497 .6352 m
.51667 .63728 L
s
.5151 .63213 m
.51497 .6352 L
s
.51697 .6301 m
.5151 .63213 L
s
.52249 .62708 m
.51697 .6301 L
s
.50272 .62678 m
.54046 .62737 L
s
.53009 .61888 m
.53556 .61792 L
s
.52648 .61883 m
.53009 .61888 L
s
.5211 .6177 m
.52648 .61883 L
s
.53556 .61792 m
.53929 .61589 L
s
.51758 .61555 m
.5211 .6177 L
s
.53929 .61589 m
.54122 .61382 L
s
.51585 .61342 m
.51758 .61555 L
s
.54122 .61382 m
.54139 .61066 L
s
.51598 .61026 m
.51585 .61342 L
s
.54139 .61066 m
.53969 .60852 L
s
.51788 .60817 m
.51598 .61026 L
s
.53969 .60852 m
.53617 .60634 L
s
.52161 .60611 m
.51788 .60817 L
s
.51615 .60602 m
.55436 .60663 L
s
.51645 .59856 m
.54205 .59897 L
s
.54034 .5968 m
.53656 .59888 L
s
.52194 .59865 m
.51837 .59645 L
s
.54229 .59468 m
.54034 .5968 L
s
.51837 .59645 m
.51663 .59427 L
s
.54247 .59145 m
.54229 .59468 L
s
.51663 .59427 m
.51676 .59103 L
s
.54075 .58925 m
.54247 .59145 L
s
.51676 .59103 m
.51868 .5889 L
s
.53719 .58703 m
.54075 .58925 L
s
.51868 .5889 m
.52246 .58679 L
s
.53172 .58585 m
.53719 .58703 L
s
.52246 .58679 m
.52803 .58579 L
s
.52803 .58579 m
.53172 .58585 L
s
.51733 .57687 m
.5172 .58016 L
s
.51927 .5747 m
.51733 .57687 L
s
.52308 .57255 m
.51927 .5747 L
s
.5287 .57154 m
.52308 .57255 L
s
.51755 .57136 m
.54357 .57178 L
s
.53462 .56496 m
.52902 .56487 L
s
.53841 .56391 m
.53462 .56496 L
s
.52928 .55928 m
.52902 .56487 L
s
.51409 .56463 m
.5104 .56345 L
s
.54226 .56173 m
.53841 .56391 L
s
.5104 .56345 m
.50674 .56116 L
s
.54426 .55952 m
.54226 .56173 L
s
.50674 .56116 m
.50494 .55888 L
s
.54451 .55502 m
.54426 .55952 L
s
.50494 .55888 m
.50509 .55438 L
s
.54275 .55274 m
.54451 .55502 L
s
.50509 .55438 m
.50704 .55215 L
s
.53912 .55041 m
.54275 .55274 L
s
.50704 .55215 m
.51088 .54995 L
s
.53541 .54921 m
.53912 .55041 L
s
.51088 .54995 m
.51469 .54887 L
s
.52981 .54798 m
.53541 .54921 L
s
.51469 .54887 m
.52039 .54783 L
s
.52039 .54783 m
.52981 .54798 L
s
.51878 .54094 m
.54553 .53678 L
s
.51916 .53172 m
.54553 .53678 L
s
.51916 .53172 m
.54605 .52751 L
s
.51953 .5224 m
.54605 .52751 L
s
.51987 .51415 m
.54677 .5146 L
s
.54498 .5122 m
.54101 .51451 L
s
.52563 .51425 m
.52189 .51182 L
s
.54704 .50986 m
.54498 .5122 L
s
.52189 .51182 m
.52006 .50941 L
s
.54724 .50629 m
.54704 .50986 L
s
.52006 .50941 m
.5202 .50583 L
s
.54544 .50386 m
.54724 .50629 L
s
.5202 .50583 m
.52223 .50347 L
s
.5417 .5014 m
.54544 .50386 L
s
.52223 .50347 m
.52621 .50114 L
s
.53595 .5001 m
.5417 .5014 L
s
.52621 .50114 m
.53207 .50004 L
s
.53207 .50004 m
.53595 .5001 L
s
.52084 .49017 m
.52069 .49381 L
s
.52289 .48776 m
.52084 .49017 L
s
.5269 .48539 m
.52289 .48776 L
s
.53282 .48427 m
.5269 .48539 L
s
.52108 .48407 m
.54845 .48453 L
s
.53322 .47565 m
.53918 .47452 L
s
.5234 .47549 m
.53322 .47565 L
s
.51755 .47415 m
.5234 .47549 L
s
.53918 .47452 m
.54317 .47335 L
s
.51366 .47284 m
.51755 .47415 L
s
.54317 .47335 m
.54724 .47093 L
s
.50981 .47029 m
.51366 .47284 L
s
.54724 .47093 m
.54942 .46723 L
s
.50796 .46652 m
.50981 .47029 L
s
.54942 .46723 m
.54991 .45845 L
s
.50825 .45773 m
.50796 .46652 L
s
.50825 .45773 m
.54991 .45845 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1;0?oooa40003o=P3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0d0?oo
o`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo03D0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`180?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0B03o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0503o
ool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0
oooo04P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0
oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0B03oool<0000ocT0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<0
00000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`16
0?ooo`/0003o>03oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`160?ooo`030000o`3oool0
oooo03l0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0n0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04<0
oooo00<0003o0?ooo`3oool0>`3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo07d0oooo
0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00
001Y0?ooo`030000003oool0oooo07X0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`13
0?ooo`L0003o;03oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`110?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool3000000h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo0280oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0O0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0m0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0?03oool;0000oa/0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3000001h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo05T0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0i0?ooo`<0003o6@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo03/0oooo10000?lB0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0l0?ooo`D0003o303oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0e0?ooo`H0003o3P3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0=`3oool50000o`T0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo03/0oooo0`000?l30?ooo`<00000=03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo03D0oooo1@000?l30?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0<@3oool30000o`D0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0<03oool50000ocl0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02/0oooo10000?l00`000000oooo0?ooo`020?ooo`<0003o?03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0:@3oool00`000?l000000000000:0?ooo`030000o`3oool0oooo03T0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?oo
o`3oool09@3oool2000000030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool08@3oool300000080oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0h0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000001@3oool20000o`L0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0H0?ooo`<000002`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80003o
?03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000l0oooo0P000?l40?ooo`@0003o?P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
00`0oooo0`00000G0?ooo`/0003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001X0
oooo10000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007@3oool00`000?l0oooo
0?ooo`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000200oooo00<0003o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08`0oooo0P00001Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool60000ocX0
oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`80003o1P3oool20000oc@0oooo
100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0;`3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0/0?ooo`<000003P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool08@3oool;0000ob/0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<0
00005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0D03oool4000001X0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0240oooo40000?lL0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo0`00000R0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool06@3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01H0
oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0R0?ooo`80003o1P3oool00`000?l0oooo
0?ooo`0C0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool60000oa<0oooo0`00
000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01d0oooo3`000?l90?ooo`<0
0000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool08`3oool20000o``0oooo100000120?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00T0oooo0`0000170?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00H0oooo0`00001:0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0S0?ooo`D0003o0`0000000`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0
oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo
0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0L0?ooo`80003o0`0000000`3oool0003o0000o`080000oe00oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0E0?ooo`<00000303oool60000oe@0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@000003@3oool20000o`H0oooo00<0003o0?ooo`3oool0DP3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000004@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0;0?ooo`<000004`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0580oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00P0oooo0`00000G0?ooo`80003o1@3oool20000oeH0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
01l0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00h0oooo000P0?ooo`800000T@3oool400000240oooo00@0003o0?ooo`000?l0003o0`3oool20000
oeT0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900
oooo0`00000S0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`1G0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0S03oool300000080oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`000?l0FP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo0280
oooo0P000?l20?ooo`050000o`3oool0oooo0?ooo`000?l0F`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`03
0000003oool0oooo02L0oooo0`000?mM0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo01d0oooo2P000?l20?ooo`80003oGP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07`0oooo0`00000A0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00
000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?oo
o`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo
00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00
001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.49702 .68971 m
.49572 .68855 L
s
.49909 .689 m
.49702 .68971 L
s
.4978 .68785 m
.49909 .689 L
s
.49572 .68855 m
.4978 .68785 L
s
.46361 .68428 m
.48729 .68743 L
s
.49714 .68084 m
.50092 .68036 L
s
.49545 .68062 m
.49714 .68084 L
s
.49244 .67922 m
.49545 .68062 L
s
.50092 .68036 m
.50379 .67776 L
s
.49152 .67711 m
.49244 .67922 L
s
.48358 .67903 m
.48056 .67763 L
s
.50379 .67776 m
.50498 .67492 L
s
.48056 .67763 m
.48 .67457 L
s
.49176 .67214 m
.49152 .67711 L
s
.50498 .67492 m
.50447 .67185 L
s
.48 .67457 m
.48115 .67172 L
s
.49083 .67001 m
.49176 .67214 L
s
.50447 .67185 m
.50146 .67044 L
s
.48115 .67172 m
.484 .66909 L
s
.48781 .6686 m
.49083 .67001 L
s
.484 .66909 m
.48781 .6686 L
s
.50806 .66324 m
.50384 .6647 L
s
.51057 .66155 m
.50806 .66324 L
s
.49014 .66285 m
.48749 .66046 L
s
.51178 .65866 m
.51057 .66155 L
s
.48749 .66046 m
.48655 .65829 L
s
.51087 .65649 m
.51178 .65866 L
s
.48655 .65829 m
.48772 .65539 L
s
.50824 .65408 m
.51087 .65649 L
s
.48772 .65539 m
.49022 .65368 L
s
.50348 .6524 m
.50824 .65408 L
s
.49022 .65368 m
.49446 .6522 L
s
.50003 .65193 m
.50348 .6524 L
s
.49446 .6522 m
.50003 .65193 L
s
.49244 .64365 m
.51667 .64697 L
s
.47989 .64298 m
.47854 .64175 L
s
.48202 .64223 m
.47989 .64298 L
s
.48067 .641 m
.48202 .64223 L
s
.47854 .64175 m
.48067 .641 L
s
.50259 .63669 m
.51997 .63909 L
s
.49777 .63498 m
.50259 .63669 L
s
.49682 .63274 m
.49777 .63498 L
s
.49803 .62974 m
.49682 .63274 L
s
.50059 .62798 m
.49803 .62974 L
s
.48776 .62301 m
.52456 .62811 L
s
.50707 .62569 m
.50059 .62798 L
s
.5174 .61857 m
.52309 .61829 L
s
.51388 .61808 m
.5174 .61857 L
s
.52309 .61829 m
.52745 .61675 L
s
.50901 .61633 m
.51388 .61808 L
s
.52745 .61675 m
.53006 .61495 L
s
.50631 .61379 m
.50901 .61633 L
s
.53006 .61495 m
.53134 .61189 L
s
.50537 .6115 m
.50631 .61379 L
s
.53134 .61189 m
.53044 .60959 L
s
.50661 .60842 m
.50537 .6115 L
s
.53044 .60959 m
.52776 .60703 L
s
.50827 .60429 m
.54542 .60951 L
s
.50921 .60661 m
.50661 .60842 L
s
.51359 .60504 m
.50921 .60661 L
s
.51119 .59702 m
.53609 .60054 L
s
.53518 .59821 m
.53076 .59979 L
s
.53783 .59637 m
.53518 .59821 L
s
.51654 .59778 m
.51382 .59519 L
s
.53914 .59324 m
.53783 .59637 L
s
.51382 .59519 m
.51288 .59284 L
s
.53824 .59088 m
.53914 .59324 L
s
.51288 .59284 m
.51414 .58969 L
s
.53554 .58827 m
.53824 .59088 L
s
.51414 .58969 m
.51678 .58784 L
s
.53061 .58645 m
.53554 .58827 L
s
.51678 .58784 m
.52122 .58623 L
s
.52703 .58594 m
.53061 .58645 L
s
.52122 .58623 m
.52703 .58594 L
s
.51969 .57589 m
.5184 .5791 L
s
.52236 .57401 m
.51969 .57589 L
s
.52185 .57053 m
.54712 .57415 L
s
.52684 .57238 m
.52236 .57401 L
s
.5327 .57208 m
.52684 .57238 L
s
.54078 .56639 m
.53535 .56561 L
s
.54485 .56583 m
.54078 .56639 L
s
.54937 .56419 m
.54485 .56583 L
s
.53757 .56018 m
.53535 .56561 L
s
.55209 .56228 m
.54937 .56419 L
s
.52083 .56352 m
.51763 .56191 L
s
.55392 .55792 m
.55209 .56228 L
s
.51763 .56191 m
.51485 .5592 L
s
.51485 .5592 m
.51389 .55675 L
s
.55301 .55546 m
.55392 .55792 L
s
.51389 .55675 m
.51562 .55236 L
s
.55028 .55274 m
.55301 .55546 L
s
.54709 .5511 m
.55028 .55274 L
s
.51562 .55236 m
.51832 .55042 L
s
.54206 .5492 m
.54709 .5511 L
s
.51832 .55042 m
.52286 .54875 L
s
.53291 .54787 m
.54206 .5492 L
s
.52286 .54875 m
.52697 .54818 L
s
.52697 .54818 m
.53291 .54787 L
s
.53376 .54094 m
.56131 .54024 L
s
.53736 .53197 m
.56131 .54024 L
s
.53736 .53197 m
.56506 .53127 L
s
.54101 .52291 m
.56506 .53127 L
s
.54423 .5149 m
.57029 .51877 L
s
.56939 .5162 m
.56472 .51794 L
s
.57221 .51418 m
.56939 .5162 L
s
.54982 .51573 m
.54702 .51287 L
s
.57366 .51072 m
.57221 .51418 L
s
.54702 .51287 m
.54609 .51029 L
s
.57276 .50813 m
.57366 .51072 L
s
.54609 .51029 m
.54748 .50681 L
s
.56998 .50525 m
.57276 .50813 L
s
.54748 .50681 m
.55029 .50477 L
s
.56484 .50324 m
.56998 .50525 L
s
.55029 .50477 m
.55499 .503 L
s
.56109 .50268 m
.56484 .50324 L
s
.55499 .503 m
.56109 .50268 L
s
.5536 .4916 m
.55218 .49513 L
s
.55645 .48952 m
.5536 .4916 L
s
.55599 .48567 m
.58246 .48968 L
s
.56119 .48772 m
.55645 .48952 L
s
.56735 .48739 m
.56119 .48772 L
s
.57076 .47905 m
.57695 .47872 L
s
.56125 .4776 m
.57076 .47905 L
s
.57695 .47872 m
.58124 .4781 L
s
.58124 .4781 m
.58604 .47628 L
s
.55602 .47553 m
.56125 .4776 L
s
.58604 .47628 m
.58945 .47295 L
s
.55269 .47375 m
.55602 .47553 L
s
.54982 .47075 m
.55269 .47375 L
s
.58945 .47295 m
.593 .46447 L
s
.54934 .46683 m
.54982 .47075 L
s
.55271 .45829 m
.54934 .46683 L
s
.55271 .45829 m
.593 .46447 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1L0?ooo`@0003o<P3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo05/0oooo00@0003o0?ooo`3oool0oooo20000?lZ0?ooo`030000003oool0
oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0:0?ooo`@0003o9`3oool00`00
0000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0
oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo02H0oooo00<000000?ooo`3oool04@3oool300000440oooo00<0
00000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1F
0?ooo`80003o2`3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo00h0oooo0`000014
0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0E`3oool30000o`H0oooo0P000?lZ0?ooo`030000003oool0oooo00X0oooo100000170?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0F@3oool60000ob`0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0D`3oool30000oc<0oooo00@000000?ooo`3oool0oooo
0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0E03oool60000obh0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0D03oool30000o`H0oooo0`000?lY
0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0;`3oool300000080oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`03
0000003oool0oooo04h0oooo00<0003o0?ooo`3oool0;03oool3000000D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0
NP3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07H0oooo0`00000;0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0B`3oool60000ob40oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0103oool2
0000oa`0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo04L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0F0?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool04P3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0A@3oool30000o`L0oooo00<0003o0?ooo`3oool0403oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`170?ooo`L0003o403oool30000
01h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo04/0oooo0`000?l;0?ooo`@000008@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0@@3oool20000oa80oooo0`00000U0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`120?ooo`<0003o303oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0A03oool30000o`H0oooo0`00000[
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?03oool<0000o`040?ooo`0000000000
000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`00
0000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?@3oool20000
o`H0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03h0
oooo0P000?l0103oool0000000000000000d0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0?@3oool200000080003o=P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0=`3oool;0000oc@0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a
0?ooo`<000000`000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o
00<0003o0`3oool20000oc/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000000`000?l0
oooo0?ooo`080?ooo`<0003o>03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000000P3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00
00050?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0703oool4000000T0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000>0?oo
o`80003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03H0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo01@0oooo0`00000G0?ooo`L0003o>@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000H0?ooo`D0003o@03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0203oool3000001`0oooo0`000?l00`3oool0003o0000o`04
0000ocX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000N0?ooo`030000o`3oool0oooo
0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<00000803oool00`000?l0oooo0?ooo`130?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
S03oool2000006T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool0I`3oool2000005/0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`P0003o>P3oool3
00000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0c0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0803oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo0300oooo0`00000:0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0P0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;P3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01l0oooo1@000?l40?ooo`80003o;@3oool300000180oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02@0oooo1P000?lZ0?ooo`<000005P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool07P3oool40000obh0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`80
003o00<0oooo0000o`000?l01@000?lT0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0003o00<0003o7@3oool300000280oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0M0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S
0?ooo`800000S`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool06P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01l0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool08@3oool60000oaL0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?ooo`@0003o
7`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0oooo1P000?lF0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool07@3oool20000o`<0oooo10000?l?0?ooo`<00000?P3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0B0?ooo`@00000@P3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0@0?ooo`<00000A`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0=0?ooo`<00000BP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0703oool90000o`<0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo01@0oooo0P000?l?
0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?oo
o`800000T03oool00`000000oooo0?ooo`0E0?ooo`80003o0P3oool50000o`<0oooo1000001F0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000000`000?mH0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0603oool3000000@0003oGP3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0E0?ooo`<0000000<0oooo0000o`3oool0103oool00`000?l0oooo0?oo
o`1L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P000007
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000000<0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00h0oooo0`0000060?ooo`80003o203oool00`000?l0oooo0?ooo`1L0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000000/0oooo00<0003o0?ooo`3o
ool00`3oool20000oel0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000C0?ooo`030000
o`3oool0oooo0600oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000@0?ooo`030000o`3o
ool0oooo06L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<000004P3oool20000o`030?ooo`00
0?l0oooo0080oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`800000T@3oool4000001@0oooo00D0003o0?ooo`3oool0oooo0000
o`040?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool200000900oooo0`00000G0?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool05@3oool2
0000o`80oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool40000
00D0oooo00<000000?ooo`3oool06P3oool40000ofP0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000
oooo0?ooo`0?0?ooo`<0003oM@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo0180oooo
10000?mb0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool05P3oool30000o`80oooo0P00
0?m/0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3
000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo
0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool30000
04D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool30000
06D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool30000
08@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo000000020000
09@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo
0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?oo
o`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo
0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo
0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00
000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J
0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool01000
0000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0
oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo
00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?oo
o`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`33
0?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?oo
o`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00
L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3o
ool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000
oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo
0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?oo
o`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00
000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000
001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<00000
0?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@0
0000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@0
0000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000
I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0
oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<00000
0?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?oo
o`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D0
0000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000
UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool20000
00`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo
0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo
1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00
000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00
000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T
0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D0
0000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?oo
o`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00
003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P000004
0?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.4599 .68414 m
.45903 .68285 L
s
.4622 .68368 m
.4599 .68414 L
s
.46133 .6824 m
.4622 .68368 L
s
.45903 .68285 m
.46133 .6824 L
s
.42879 .67491 m
.4511 .68077 L
s
.46316 .67544 m
.46705 .6754 L
s
.46157 .67502 m
.46316 .67544 L
s
.46705 .6754 m
.47081 .67318 L
s
.4591 .6733 m
.46157 .67502 L
s
.45894 .67111 m
.4591 .6733 L
s
.47081 .67318 m
.47298 .67054 L
s
.45041 .67207 m
.44792 .67035 L
s
.46093 .66626 m
.45894 .67111 L
s
.47298 .67054 m
.47356 .66746 L
s
.44792 .67035 m
.44846 .66726 L
s
.47356 .66746 m
.47109 .66572 L
s
.44846 .66726 m
.4506 .6646 L
s
.46077 .66406 m
.46093 .66626 L
s
.4506 .6646 m
.45435 .66235 L
s
.45828 .66231 m
.46077 .66406 L
s
.45435 .66235 m
.45828 .66231 L
s
.48013 .65943 m
.47546 .66037 L
s
.4832 .65807 m
.48013 .65943 L
s
.48542 .65537 m
.4832 .65807 L
s
.46262 .65693 m
.46085 .65427 L
s
.48529 .65313 m
.48542 .65537 L
s
.46085 .65427 m
.46069 .65203 L
s
.48355 .65046 m
.48529 .65313 L
s
.46069 .65203 m
.46287 .64931 L
s
.47946 .64825 m
.48355 .65046 L
s
.46287 .64931 m
.46595 .64793 L
s
.47623 .64738 m
.47946 .64825 L
s
.46595 .64793 m
.47065 .64698 L
s
.47065 .64698 m
.47623 .64738 L
s
.47167 .63835 m
.49434 .64448 L
s
.48413 .63273 m
.50036 .63715 L
s
.45954 .63618 m
.45864 .63482 L
s
.46191 .6357 m
.45954 .63618 L
s
.46101 .63434 m
.46191 .6357 L
s
.45864 .63482 m
.46101 .63434 L
s
.47999 .63047 m
.48413 .63273 L
s
.47985 .62816 m
.47999 .63047 L
s
.4821 .62536 m
.47985 .62816 L
s
.47437 .61752 m
.50873 .62694 L
s
.48524 .62394 m
.4821 .62536 L
s
.49242 .62247 m
.48524 .62394 L
s
.51075 .61715 m
.51557 .61616 L
s
.50507 .61674 m
.51075 .61715 L
s
.50179 .61583 m
.50507 .61674 L
s
.51557 .61616 m
.51875 .61472 L
s
.49763 .61353 m
.50179 .61583 L
s
.51875 .61472 m
.52109 .61187 L
s
.49587 .61072 m
.49763 .61353 L
s
.52109 .61187 m
.52101 .60951 L
s
.50115 .60164 m
.53568 .61125 L
s
.49576 .60835 m
.49587 .61072 L
s
.52101 .60951 m
.51929 .60669 L
s
.49806 .60548 m
.49576 .60835 L
s
.50125 .60402 m
.49806 .60548 L
s
.5061 .60302 m
.50125 .60402 L
s
.50658 .59488 m
.52972 .60135 L
s
.52965 .59896 m
.52478 .59997 L
s
.53289 .59749 m
.52965 .59896 L
s
.53527 .59458 m
.53289 .59749 L
s
.51155 .59627 m
.5098 .5934 L
s
.53521 .59217 m
.53527 .59458 L
s
.5098 .5934 m
.5097 .59098 L
s
.5335 .58929 m
.53521 .59217 L
s
.5097 .59098 m
.51206 .58805 L
s
.52931 .5869 m
.5335 .58929 L
s
.51206 .58805 m
.5153 .58656 L
s
.52599 .58597 m
.52931 .5869 L
s
.5153 .58656 m
.52021 .58554 L
s
.52021 .58554 m
.52599 .58597 L
s
.52235 .57523 m
.51996 .57821 L
s
.52635 .57025 m
.54976 .57692 L
s
.52562 .57372 m
.52235 .57523 L
s
.53058 .57268 m
.52562 .57372 L
s
.5364 .57311 m
.53058 .57268 L
s
.54629 .56855 m
.54127 .56711 L
s
.55046 .56851 m
.54629 .56855 L
s
.55544 .56746 m
.55046 .56851 L
s
.55876 .56594 m
.55544 .56746 L
s
.54534 .56208 m
.54127 .56711 L
s
.56207 .56191 m
.55876 .56594 L
s
.52782 .56327 m
.52525 .56129 L
s
.56205 .5594 m
.56207 .56191 L
s
.52525 .56129 m
.52348 .5583 L
s
.56034 .5564 m
.56205 .5594 L
s
.52348 .5583 m
.52341 .55578 L
s
.55781 .55441 m
.56034 .5564 L
s
.52341 .55578 m
.52665 .55171 L
s
.55357 .55193 m
.55781 .55441 L
s
.54512 .54948 m
.55357 .55193 L
s
.52665 .55171 m
.52997 .55015 L
s
.52997 .55015 m
.535 .54908 L
s
.53921 .54904 m
.54512 .54948 L
s
.535 .54908 m
.53921 .54904 L
s
.54838 .54282 m
.57544 .5456 L
s
.55504 .53452 m
.57544 .5456 L
s
.55504 .53452 m
.58223 .53732 L
s
.56177 .52613 m
.58223 .53732 L
s
.56772 .51873 m
.59167 .52581 L
s
.59169 .5232 m
.58655 .5243 L
s
.59513 .52159 m
.59169 .5232 L
s
.59774 .51841 m
.59513 .52159 L
s
.57287 .52025 m
.57114 .51711 L
s
.59778 .51577 m
.59774 .51841 L
s
.57114 .51711 m
.57114 .51447 L
s
.59609 .51261 m
.59778 .51577 L
s
.57114 .51447 m
.57371 .51126 L
s
.59181 .51 m
.59609 .51261 L
s
.57371 .51126 m
.57716 .50963 L
s
.58837 .50898 m
.59181 .51 L
s
.57716 .50963 m
.58234 .50851 L
s
.58234 .50851 m
.58837 .50898 L
s
.58498 .49722 m
.58237 .50048 L
s
.58937 .49176 m
.6136 .49907 L
s
.58847 .49557 m
.58498 .49722 L
s
.5937 .49443 m
.58847 .49557 L
s
.59978 .4949 m
.5937 .49443 L
s
.6121 .48771 m
.61647 .48766 L
s
.606 .48723 m
.6121 .48771 L
s
.61647 .48766 m
.62174 .48651 L
s
.5973 .48459 m
.606 .48723 L
s
.62174 .48651 m
.62619 .48373 L
s
.59295 .4819 m
.5973 .48459 L
s
.62619 .48373 m
.63256 .47595 L
s
.59034 .47973 m
.59295 .4819 L
s
.58861 .47644 m
.59034 .47973 L
s
.58952 .47255 m
.58861 .47644 L
s
.59577 .46468 m
.63256 .47595 L
s
.59577 .46468 m
.58952 .47255 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06X0oooo0P000?lU0?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`030000ob80oooo
00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00
001M0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool00`3oool20000ob00oooo00<0
00000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O
0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool01P3oool30000oad0oooo00<00000
0?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo00X0oooo0`000?lJ0?oo
o`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0=0?ooo`80
003o603oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0
2`3oool20000oaT0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`<00000CP3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0680oooo0`000?l70?ooo`030000o`3oool0oooo01X0oooo00@000000?ooo`3oool0oooo0`00
001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0I03oool80000oa`0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0GP3oool20000obD0oooo0`00001H0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0GP3oool40000oal0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1K0?ooo`80003o
0P3oool50000oaT0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo05X0oooo00<0003o0?ooo`3oool01`3o
ool20000oa@0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0
oooo01/0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0LP3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0KP3oool30000
0140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0D`3oool70000
oa00oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
0540oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`1>0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool3000001h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo04`0oooo0`000?l70?ooo`030000o`3oool0oooo00@00000
8@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0CP3oool40000o`80oooo0P000?l2000002D0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d
0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool01`3oool30000obP0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?oo
o`3oool0A`3oool20000o`@0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0B03oool20000o`800000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`120?ooo`D0003o00@000000?ooo`000?l0003o;P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`110?ooo`03000000000?l0003o0080oooo1P000?l/0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000000<0oooo00<0003o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0>@3oool3000000L0oooo00<0003o0?ooo`3oool0<03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0=@3oool3000000<0oooo1@000?l30?ooo`80003o<03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0<@3oool3000000/0oooo1P000?l_0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<000000P3oool80000ocT0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00
00040?ooo`030000o`3oool0oooo00H0oooo0P000?lg0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`000006
0?ooo`030000o`3oool0oooo00T0oooo0P000?le0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?oo
o`<000002@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0380oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo01`0oooo1000000=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool0<`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000180oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo01@0oooo0`00000J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000001d0oooo1P000?lg0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0<0?ooo`<000006P3oool30000od00oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0
oooo0`00000M0?ooo`L0003o?03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001l0oooo
00<0003o0?ooo`3oool01@3oool30000ocT0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008@3o
ool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`110?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo0200oooo0`000?l0103oool0003o0000o`000?lm0?oo
o`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`050?ooo`80
003o=`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0b0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07P3o
ool30000o`L0oooo00<0003o0?ooo`3oool0;`3oool3000000h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0200oooo10000?l20?ooo`<0003o;P3oool300000180oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
01`0oooo0P000?l60?ooo`<0003o;@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0
oooo1@000?l_0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo
0?ooo`030?ooo`@0003o:03oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01X0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0000o`020000ob80oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool2
0000oad0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool0
02<0oooo0P00002?0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0O0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04P3oool20000o`L0
oooo1`000?lN0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05@3oool30000obH0oooo
0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?ooo`@0003o7`3oool3000003H0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01H0oooo0`000?l30?ooo`<0003o6@3oool3000003X0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01`3oool20000oa@0oooo0`00000n0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo100000120?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0F0?ooo`80003o5P3oool3000004L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo00d0oooo0P000?l90?ooo`<0003o403oool3000004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0180oooo0P000?l70?ooo`80003o2`3oool3000004h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0503oool40000
o`d0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240
oooo0P00002@0?ooo`030000003oool0oooo01P0oooo0`000?l60?ooo`@00000EP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0:0?ooo`<00000F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00h0oooo0`000?l00`3oool0003o0000o`020000o`D0oooo0`00
001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0000000200000680oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`<00000IP3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0100000020?oo
o`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool300000080oooo10000?mY0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
2`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`0000030?ooo`050000o`3o
ool0oooo0?ooo`000?l0KP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000000030?ooo`00
0?l0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`1_0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?oo
o`3oool3000000D0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo06h0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo
100000090?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0L03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000000@0oooo
0P000?l:0?ooo`<0003oL`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo00@0oooo1000
0?mm0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0203oool30000og/0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?oo
o`<000002@3oool00`000000oooo0?ooo`0=0?ooo`80003oN03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03o
ool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00
000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42516 .67433 m
.42475 .67297 L
s
.4276 .67416 m
.42516 .67433 L
s
.42719 .67279 m
.4276 .67416 L
s
.42475 .67297 m
.42719 .67279 L
s
.39752 .66157 m
.41762 .66998 L
s
.43535 .66657 m
.43985 .66482 L
s
.43148 .66615 m
.43535 .66657 L
s
.43005 .66555 m
.43148 .66615 L
s
.42821 .66356 m
.43005 .66555 L
s
.43985 .66482 m
.44294 .66247 L
s
.42883 .66139 m
.42821 .66356 L
s
.44294 .66247 m
.44461 .65951 L
s
.43253 .65684 m
.42883 .66139 L
s
.42003 .66133 m
.41817 .65933 L
s
.44461 .65951 m
.44278 .65751 L
s
.41817 .65933 m
.4198 .65636 L
s
.43315 .65465 m
.43253 .65684 L
s
.4198 .65636 m
.42287 .65398 L
s
.43131 .65264 m
.43315 .65465 L
s
.42287 .65398 m
.4274 .65221 L
s
.45395 .65239 m
.449 .65276 L
s
.4274 .65221 m
.43131 .65264 L
s
.45747 .65141 m
.45395 .65239 L
s
.46061 .64902 m
.45747 .65141 L
s
.46127 .64681 m
.46061 .64902 L
s
.43751 .64786 m
.4367 .64503 L
s
.46051 .64398 m
.46127 .64681 L
s
.4367 .64503 m
.43734 .6428 L
s
.45724 .64132 m
.46051 .64398 L
s
.43734 .6428 m
.44047 .64039 L
s
.45436 .64008 m
.45724 .64132 L
s
.44047 .64039 m
.444 .63939 L
s
.44899 .63902 m
.45436 .64008 L
s
.444 .63939 m
.44899 .63902 L
s
.45306 .63065 m
.47326 .63939 L
s
.46735 .62662 m
.48178 .6329 L
s
.44183 .62707 m
.44143 .62561 L
s
.44434 .62688 m
.44183 .62707 L
s
.44394 .62542 m
.44434 .62688 L
s
.46407 .6239 m
.46735 .62662 L
s
.44143 .62561 m
.44394 .62542 L
s
.46475 .62162 m
.46407 .6239 L
s
.46311 .6105 m
.49361 .6239 L
s
.46796 .61914 m
.46475 .62162 L
s
.47156 .61812 m
.46796 .61914 L
s
.47914 .61755 m
.47156 .61812 L
s
.49905 .61454 m
.50412 .61415 L
s
.49361 .61345 m
.49905 .61454 L
s
.50412 .61415 m
.50776 .61313 L
s
.49071 .61217 m
.49361 .61345 L
s
.50776 .61313 m
.51105 .61062 L
s
.48744 .6094 m
.49071 .61217 L
s
.49509 .59817 m
.52555 .61178 L
s
.51105 .61062 m
.5118 .6083 L
s
.4867 .60643 m
.48744 .6094 L
s
.5118 .6083 m
.51111 .60533 L
s
.48742 .6041 m
.4867 .60643 L
s
.4907 .60157 m
.48742 .6041 L
s
.49435 .60052 m
.4907 .60157 L
s
.50281 .59221 m
.5232 .60137 L
s
.49947 .60013 m
.49435 .60052 L
s
.52398 .59902 m
.51885 .59941 L
s
.52766 .59797 m
.52398 .59902 L
s
.53101 .59542 m
.52766 .59797 L
s
.5318 .59306 m
.53101 .59542 L
s
.5072 .59418 m
.50649 .59115 L
s
.53114 .59003 m
.5318 .59306 L
s
.50649 .59115 m
.50725 .58878 L
s
.52789 .58719 m
.53114 .59003 L
s
.50725 .58878 m
.51059 .5862 L
s
.52497 .58586 m
.52789 .58719 L
s
.51059 .5862 m
.51429 .58513 L
s
.51946 .58473 m
.52497 .58586 L
s
.51429 .58513 m
.51946 .58473 L
s
.53085 .57054 m
.55135 .57994 L
s
.52518 .57492 m
.5218 .57753 L
s
.52892 .57384 m
.52518 .57492 L
s
.53966 .57458 m
.53412 .57344 L
s
.53412 .57344 m
.52892 .57384 L
s
.55499 .57182 m
.55091 .57134 L
s
.56021 .57141 m
.55499 .57182 L
s
.56397 .57033 m
.56021 .57141 L
s
.55091 .57134 m
.54651 .56932 L
s
.5686 .56681 m
.56397 .57033 L
s
.55226 .56491 m
.54651 .56932 L
s
.56945 .56436 m
.5686 .56681 L
s
.56885 .56123 m
.56945 .56436 L
s
.53474 .56389 m
.53292 .56164 L
s
.53292 .56164 m
.53225 .5585 L
s
.56708 .55897 m
.56885 .56123 L
s
.56383 .55602 m
.56708 .55897 L
s
.53225 .5585 m
.53306 .55603 L
s
.53306 .55603 m
.53766 .55244 L
s
.55645 .55258 m
.56383 .55602 L
s
.55085 .55141 m
.55645 .55258 L
s
.56197 .54649 m
.58729 .55258 L
s
.57136 .53923 m
.58729 .55258 L
s
.53766 .55244 m
.54145 .55134 L
s
.54673 .55092 m
.55085 .55141 L
s
.54145 .55134 m
.54673 .55092 L
s
.57136 .53923 m
.59676 .54537 L
s
.58083 .53191 m
.59676 .54537 L
s
.58919 .52545 m
.60991 .53536 L
s
.61084 .53282 m
.60549 .53324 L
s
.61473 .53169 m
.61084 .53282 L
s
.61835 .52893 m
.61473 .53169 L
s
.61931 .52637 m
.61835 .52893 L
s
.59365 .52758 m
.59308 .52431 L
s
.61878 .52309 m
.61931 .52637 L
s
.59308 .52431 m
.59399 .52174 L
s
.61556 .52001 m
.61878 .52309 L
s
.59399 .52174 m
.59761 .51894 L
s
.61259 .51858 m
.61556 .52001 L
s
.59761 .51894 m
.60152 .51779 L
s
.60692 .51736 m
.61259 .51858 L
s
.60152 .51779 m
.60692 .51736 L
s
.61955 .50198 m
.64037 .51216 L
s
.61341 .50673 m
.60975 .50956 L
s
.61736 .50556 m
.61341 .50673 L
s
.62851 .50636 m
.6228 .50512 L
s
.6228 .50512 m
.61736 .50556 L
s
.64709 .50147 m
.65256 .50103 L
s
.64288 .50095 m
.64709 .50147 L
s
.65256 .50103 m
.6578 .4989 L
s
.63717 .49971 m
.64288 .50095 L
s
.6297 .49603 m
.63717 .49971 L
s
.6578 .4989 m
.66661 .49219 L
s
.62644 .49286 m
.6297 .49603 L
s
.62468 .49042 m
.62644 .49286 L
s
.63516 .47651 m
.66661 .49219 L
s
.62416 .487 m
.62468 .49042 L
s
.62639 .48334 m
.62416 .487 L
s
.63516 .47651 m
.62639 .48334 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3oool05@3oool00`000000
oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo0740oooo0P000?l00`3oool0003o0000o`0E0?ooo`030000
003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0KP3oool20000o`D0oooo0P000?lC0?ooo`030000003o
ool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo0?ooo`060?ooo`80003o4@3oool0
10000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00P0oooo0P000?l?
0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool02P3oool20000o`/0oooo0`00001H0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo0`0000020?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000
J03oool00`000000oooo0?ooo`1Z0?ooo`80003o2P3oool20000o`D0oooo0`0000050?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003o
ool0oooo06`0oooo0`000?l60?ooo`030000o`3oool0oooo0080oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo00D0oooo1P000?l20?ooo`<000002`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo06H0oooo0P000?l:0?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1R0?ooo`<0003o00@0oooo0000
o`000?l0003o1@3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F
0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool0G`3oool20000o`L0oooo0P000?l3000001@0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0IP3oool300000080003o5P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?ooo`<000006`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo05T0oooo1@000?l3000001h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05L0
oooo00<0003o0?ooo`0000000`0000000`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1D0?ooo`80003o0P0000050?ooo`80003o7P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0D@3o
ool00`000000003o0000o`090?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3
00000080oooo0P000?l70?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`190?ooo`<0000000<0003o0?ooo`3oool0103oool20000o`@0oooo00<0003o0?oo
o`3oool07P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<0
0000103oool00`000?l0oooo0?ooo`050?ooo`@0003o8@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`110?ooo`<00000203oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0200oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<000001P3o
ool30000o`<0oooo0P000?lY0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000002P3oool0
0`000?l0oooo0000o`030000o`030?ooo`000?l0oooo02L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
03D0oooo0`00000>0?ooo`030000o`3oool0oooo0080oooo0`000?lW0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`0a0?ooo`<000002`3oool30000o`@0oooo0P000?l/0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<000004@3oool50000o`030?ooo`000?l0oooo02X0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo02T0oooo0`0000080?ooo`T0003o203oool30000obX0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3
000000X0oooo00<0003o0?ooo`3oool01`3oool20000oc<0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000<0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0<@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0703oool4000000l0oooo00<0003o0?ooo`3oool02P3oool20000oc80
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000D0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000001h0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<000007`3oool20000o`D0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0303oool3000001`0oooo0P000?l50?ooo`H0003o=03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0203oool3000001h0oooo1@000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000
7P3oool30000o`D0oooo0P000?lk0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000002/0oooo0P00
0?li0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08@3oool30000od<0oooo0P00001K0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool07`3oool20000o`<0oooo0`000?lm0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03H0oooo100000060?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0L0?ooo`<0003o203oool00`000?l0oooo0?ooo`0c0?ooo`<000002P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool07P3oool20000o`L0oooo00<0003o0?ooo`3oool0<03oool3
000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo01T0oooo0P000?l50?ooo`<0003o0`3oool00`00
0?l0oooo0?ooo`0^0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0603oool50000o`D0
oooo10000?l^0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`030?ooo`80003o<@3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01H0oooo00<0
003o0?ooo`3oool01P3oool30000ob/0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`000?l0003o9P3oool300000280oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo00h0oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool20000ob40oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo0100oooo0P000?l70?oo
o`H0003o9@3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0180oooo0`000?l[0?ooo`@0
0000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0403oool40000o`030?ooo`000?l0003o02L0oooo
0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo0P00
0?lR0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01P3oool20000o`L0oooo00<0003o
0?ooo`3oool01`3oool20000oad0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?oo
o`80003o1`3oool20000ob<0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00@0oooo0P000?lM0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
303oool20000o`H0oooo0P000?lH0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool03P3o
ool20000oa/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0
oooo00@0oooo0P000?lF0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`060?ooo`<0003o00@0oooo0000
o`000?l0003o1@3oool00`000?l0oooo0?ooo`0@0?ooo`<00000DP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo0P000?lB0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo0`00001K0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00X0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`050000
003oool0oooo0?ooo`000?l02@3oool30000o`X0oooo0`00001R0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`050000003oool0oooo0000o`3oool00P000?l50?ooo`80003o2P3oool3000006H0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo
00<000000?ooo`3oool0S`3oool00`000000003o0000o`030?ooo`050000o`3oool0oooo0?ooo`00
0?l02@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00
603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000000o`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0`00001_0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo08T0oooo0P000?l50?ooo`03000000000?l0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool010000?l0oooo0?ooo`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2;0?ooo`80003o0`3oool00`000000oooo0?oo
o`020?ooo`060000o`3oool0oooo0?ooo`000?l0oooo0`00001f0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0S@3oool30000o`030000
003oool0oooo00<0oooo00<0003o0000000000000P00001j0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool20000o`80oooo0`00
001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A
0?ooo`@0000000<0003o0?ooo`3oool0P03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00h0oooo000O0?ooo`800000T03oool300000080oooo0P000?n20?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<0
00004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0
oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<0
0000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0
oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P00
00190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<00000
0?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@0
0000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0
oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z
0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`09
0?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@0
0000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140
oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00
002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?oo
o`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000
003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3o
ool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0
oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`80
0000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0
L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`03
0000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00
@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0
a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3o
ool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3o
ool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0
oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo
0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo0014
0?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`03
0000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00
F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0
oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0
oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo
000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080
oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<
0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?oo
o`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00
K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3o
ool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0
000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`00
0000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000
000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i
0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?oo
o`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?oo
o`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`04
0000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?oo
o`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@0
0000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000
F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool0
10000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool0
0`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool20000
02H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?oo
o`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<0
00000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D0
0000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000
S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool20000
01H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180
oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo
00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo
001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<0
00000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A
0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?oo
o`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?oo
o`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?oo
o`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool0
00000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80
oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000
aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2
000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo
0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H
0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.3966 .66069 m
.39411 .66058 L
s
.39668 .65929 m
.3966 .66069 L
s
.39411 .66058 m
.39419 .65918 L
s
.39419 .65918 m
.39668 .65929 L
s
.37107 .64468 m
.38815 .65539 L
s
.40702 .65412 m
.41212 .65293 L
s
.40332 .65324 m
.40702 .65412 L
s
.40211 .65248 m
.40332 .65324 L
s
.41212 .65293 m
.41603 .65098 L
s
.40099 .6503 m
.40211 .65248 L
s
.41603 .65098 m
.41874 .64826 L
s
.40238 .64823 m
.40099 .6503 L
s
.41874 .64826 m
.41764 .64607 L
s
.40768 .64419 m
.40238 .64823 L
s
.39363 .64713 m
.3925 .64493 L
s
.3925 .64493 m
.39518 .64219 L
s
.40908 .6421 m
.40768 .64419 L
s
.43054 .64236 m
.4255 .64213 L
s
.43437 .64181 m
.43054 .64236 L
s
.39518 .64219 m
.39909 .64021 L
s
.40796 .63989 m
.40908 .6421 L
s
.43833 .63983 m
.43437 .64181 L
s
.39909 .64021 m
.40422 .639 L
s
.40422 .639 m
.40796 .63989 L
s
.43977 .63773 m
.43833 .63983 L
s
.44002 .63485 m
.43977 .63773 L
s
.41583 .63592 m
.41604 .63303 L
s
.43773 .63184 m
.44002 .63485 L
s
.41604 .63303 m
.41746 .63092 L
s
.43738 .62084 m
.45426 .63187 L
s
.43532 .63027 m
.43773 .63184 L
s
.41746 .63092 m
.42142 .62891 L
s
.43037 .62859 m
.43532 .63027 L
s
.42142 .62891 m
.42529 .62836 L
s
.42529 .62836 m
.43037 .62859 L
s
.45295 .6186 m
.46497 .62651 L
s
.45447 .60223 m
.47981 .61909 L
s
.45066 .61553 m
.45295 .6186 L
s
.43008 .61606 m
.42752 .61595 L
s
.43019 .61458 m
.43008 .61606 L
s
.42752 .61595 m
.42763 .61447 L
s
.45215 .61337 m
.45066 .61553 L
s
.42763 .61447 m
.43019 .61458 L
s
.4562 .61132 m
.45215 .61337 L
s
.46012 .61075 m
.4562 .61132 L
s
.46781 .61111 m
.46012 .61075 L
s
.49036 .59403 m
.51545 .61107 L
s
.49359 .6108 m
.49753 .61024 L
s
.48847 .61057 m
.49359 .6108 L
s
.48351 .60884 m
.48847 .61057 L
s
.49753 .61024 m
.50164 .60818 L
s
.48111 .60723 m
.48351 .60884 L
s
.50164 .60818 m
.5032 .606 L
s
.47886 .60411 m
.48111 .60723 L
s
.5032 .606 m
.50357 .603 L
s
.47918 .60111 m
.47886 .60411 L
s
.48072 .59891 m
.47918 .60111 L
s
.50005 .58913 m
.51682 .60059 L
s
.48484 .59682 m
.48072 .59891 L
s
.51841 .59839 m
.51325 .59815 L
s
.52238 .59781 m
.51841 .59839 L
s
.52655 .59573 m
.52238 .59781 L
s
.4888 .59625 m
.48484 .59682 L
s
.49397 .59649 m
.4888 .59625 L
s
.52816 .59351 m
.52655 .59573 L
s
.52857 .59047 m
.52816 .59351 L
s
.50366 .5916 m
.50403 .58855 L
s
.5264 .58729 m
.52857 .59047 L
s
.50403 .58855 m
.50561 .58631 L
s
.524 .58564 m
.5264 .58729 L
s
.50561 .58631 m
.5098 .5842 L
s
.51901 .58386 m
.524 .58564 L
s
.5098 .5842 m
.5138 .58361 L
s
.5138 .58361 m
.51901 .58386 L
s
.53514 .57137 m
.55185 .58308 L
s
.52806 .57495 m
.52383 .5771 L
s
.54233 .57641 m
.53732 .57461 L
s
.56346 .57585 m
.55823 .5756 L
s
.5675 .57526 m
.56346 .57585 L
s
.55823 .5756 m
.55443 .57464 L
s
.57323 .57239 m
.5675 .57526 L
s
.53209 .57436 m
.52806 .57495 L
s
.55443 .57464 m
.55086 .57212 L
s
.53732 .57461 m
.53209 .57436 L
s
.57491 .57012 m
.57323 .57239 L
s
.558 .56852 m
.55086 .57212 L
s
.57542 .56699 m
.57491 .57012 L
s
.57449 .56457 m
.57542 .56699 L
s
.54127 .56536 m
.54029 .56294 L
s
.57237 .56129 m
.57449 .56457 L
s
.54029 .56294 m
.54074 .55978 L
s
.5664 .55702 m
.57237 .56129 L
s
.5739 .55176 m
.59633 .56084 L
s
.58556 .54586 m
.59633 .56084 L
s
.54074 .55978 m
.5424 .55747 L
s
.5424 .55747 m
.54814 .55454 L
s
.56137 .55518 m
.5664 .55702 L
s
.55752 .55419 m
.56137 .55518 L
s
.58556 .54586 m
.608 .55501 L
s
.5973 .53992 m
.608 .55501 L
s
.54814 .55454 m
.55223 .55394 L
s
.55223 .55394 m
.55752 .55419 L
s
.60764 .53469 m
.62419 .54692 L
s
.62597 .54457 m
.62066 .54431 L
s
.63011 .54396 m
.62597 .54457 L
s
.63457 .54173 m
.63011 .54396 L
s
.63637 .53937 m
.63457 .54173 L
s
.63701 .53612 m
.63637 .53937 L
s
.6112 .53733 m
.61179 .53407 L
s
.63497 .53273 m
.63701 .53612 L
s
.61179 .53407 m
.61357 .53169 L
s
.63261 .53097 m
.63497 .53273 L
s
.61357 .53169 m
.61804 .52943 L
s
.62757 .52907 m
.63261 .53097 L
s
.61804 .52943 m
.62221 .52881 L
s
.62221 .52881 m
.62757 .52907 L
s
.64508 .51575 m
.66155 .52824 L
s
.63753 .51957 m
.63301 .52185 L
s
.65217 .52112 m
.64712 .5192 L
s
.64173 .51894 m
.63753 .51957 L
s
.64712 .5192 m
.64173 .51894 L
s
.67708 .519 m
.68283 .5176 L
s
.6717 .51873 m
.67708 .519 L
s
.66783 .5177 m
.6717 .51873 L
s
.66279 .51578 m
.66783 .5177 L
s
.68283 .5176 m
.69357 .51223 L
s
.6569 .51127 m
.66279 .51578 L
s
.66891 .49307 m
.69357 .51223 L
s
.65488 .50778 m
.6569 .51127 L
s
.65403 .50519 m
.65488 .50778 L
s
.65471 .50181 m
.65403 .50519 L
s
.65812 .49855 m
.65471 .50181 L
s
.66891 .49307 m
.65812 .49855 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo07X0oooo00<0003o0?ooo`3oool0103oool300000080
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0000001X0?ooo`030000003oool0oooo07L0oooo0P000?l0103oool0003o0000o`3oool3000000D0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo
00<000000?ooo`3oool0M@3oool20000o`<0oooo0P0000000`000?l0oooo0?ooo`060?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo00<000000`3oool00`000?l0oooo0?oo
o`050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P000007
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0LP3oool00`000?l0000000000007
0?ooo`80003o1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^
0?ooo`<0000000<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06X0oooo0`0000030?ooo`030000o`3oool0
oooo00X0oooo0P000?l20?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo06H0oooo0`0000070?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool00000F03o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0HP3oool3000000D0oooo00<0003o0?ooo`3oool00`3o
ool20000o`T0oooo0P000?l30?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3
000000T0oooo0P000?l50?ooo`80003o103oool30000o`D0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
05T0oooo100000090?ooo`H0003o1P3oool40000o`P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05D0
oooo0`00000;0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo
0?ooo`1A0?ooo`<000005`3oool20000o`l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3000000d0oooo0`00
0?l<0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`19
0?ooo`<000003@3oool30000o`<0oooo0P000?lI0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo04D0oooo0`00000=0?ooo`030000o`3oool0003o00P0oooo00<0003o0?oo
o`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`03
0000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<0
00004@3oool20000o`P0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo03d0oooo0`00000@0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<00000503o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0=@3oool3000001L0oooo00<0003o0?ooo`3oool0103oool6
0000oaT0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`00000D0?ooo`80003o1@3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0
oooo0`00000H0?ooo`@0003o0`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0Y0?ooo`<000005P3oool20000o`@0oooo00<0003o0?ooo`3oool010000?lS0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo02D0oooo0`00000?0?ooo`H0003o1P3oool20000o`80oooo00<0003o0?ooo`3oool00`3o
ool20000ob80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000@0?ooo`80003o1P3oool2
0000o`H0oooo10000?lX0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000004`3oool00`00
0?l0oooo0?ooo`070?ooo`80003o1`3oool20000obP0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0
oooo0`00000F0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0;`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0503oool3000001X0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000008P3oool20000o`D0oooo00<0
003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001d0oooo00<0003o
0?ooo`3oool00`3oool20000o`L0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool3000001l0oooo10000?l40?ooo`80003o1@3oool20000oc00oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo00@0oooo0`00000O0?ooo`<0003o0`3oool20000o`D0oooo1@000?lb0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`03000002X0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00
000^0?ooo`80003o>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`800000S@3oool00`000000oooo0?ooo`0O0?ooo`@0003o303oool00`000?l0oooo0?ooo`0e
0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo01d0oooo0P000?l40?ooo`<0003o?P3oool300000080oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo01/0oooo00<0003o0?ooo`000?l0203oool00`000?l0oooo0?ooo`0g0?ooo`@0
00001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0703oool20000o`P0oooo00<0003o0?ooo`3oool0
=03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01L0oooo0P000?l50?ooo`80003o1@3o
ool00`000?l0oooo0?ooo`0b0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0503oool3
0000o`040?ooo`000?l0003o0000o`D0oooo1@000?lb0?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0503oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0;`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80003o<P3oool4000001X0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo00/0oooo0P000?l60?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`00
0?l0;P3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00d0oooo0P000?l50?ooo`80003o
1P3oool00`000?l0oooo0?ooo`020000obT0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0;0?ooo`D0003o1P3oool60000o`D0oooo00<0003o0?ooo`3oool08`3oool3000002H0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<00000
0?ooo`3oool00P000?l70?ooo`80003o1@3oool20000oc80oooo0`00000Z0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`020000o`L0oooo00<0003o0?ooo`3oool01P3oool20000ob`0oooo1000000^0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool09P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0/0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01P3o
ool20000o`D0oooo0P000?lY0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00@000000?ooo`3oool0003o1`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02<0oooo0`00000n0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool3
0000o`030?ooo`000?l0003o0080003o103oool20000obH0oooo100000120?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0803oool30000
04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool08P3oool3000004X0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2:0?ooo`050000o`3oool0oooo0?ooo`000000203oool00`000?l0oooo0?ooo`0O0?ooo`<0
0000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000
R03oool20000o`050?ooo`000?l0oooo0?ooo`0000001P3oool20000oal0oooo0`00001B0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P0000280?ooo`80003o
0`3oool010000?l0oooo0?ooo`0000020?ooo`@0003o7@3oool4000005H0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`1n0?ooo`030000
o`3oool0oooo00D0oooo0P000?l30?ooo`060000o`3oool0oooo0?ooo`000000003o7`3oool30000
05/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0O`3oool20000o`T0oooo00<0003o0?ooo`3oool00P3oool00`000000
003o0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0
oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0P@3oool20000o`H0
oooo0P000?l40?ooo`030000o`3oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`230?ooo`80003o1@3oool50000o`030000003oool0oooo01D0oooo0`00001V0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08D0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0Q`3oool20000o`H0oooo00<000000?ooo`3oool03P3oool3
000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool30000
00D0oooo00<000000?ooo`3oool0R@3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo
00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000
O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3o
ool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool2
00000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0
oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3
000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0
oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3o
ool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3
000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>
0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000
003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3
000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo
00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]
0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3
000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo
00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`06
0?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?oo
o`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P00
00090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000
002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000
003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo
0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo
0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3o
ool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03o
ool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000
003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3o
ool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`00
0000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400
oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?oo
o`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003o
ool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool200000003
0?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003o
ool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000
oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool00000
05X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo
0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00
001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?oo
o`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3o
ool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000
oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?oo
o`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3o
ool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool20000
04T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo
0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo
001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P000013
0?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0
^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3o
ool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool0
07<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo
0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000
000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d
0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?oo
o`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo10000017
0?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?oo
o`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000
003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000
003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003o
ool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4
000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool40000
06h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0
oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0
oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo
002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?oo
o`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`00
00006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000
003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4
000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5
000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool40000
0:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0
oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo
001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<0
00000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<00000
0?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?oo
o`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N
0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003o
ool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000
003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3o
ool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z
0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L
0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X
0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L
0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37047 .6437 m
.36802 .64329 L
s
.37105 .64232 m
.37047 .6437 L
s
.36802 .64329 m
.3686 .64191 L
s
.3686 .64191 m
.37105 .64232 L
s
.38323 .63845 m
.38874 .63789 L
s
.37985 .63714 m
.38323 .63845 L
s
.38874 .63789 m
.39333 .63643 L
s
.35063 .62477 m
.36391 .63744 L
s
.37891 .63624 m
.37985 .63714 L
s
.39333 .63643 m
.39701 .63406 L
s
.37857 .63395 m
.37891 .63624 L
s
.39701 .63406 m
.39669 .63177 L
s
.3807 .63207 m
.37857 .63395 L
s
.38743 .62871 m
.3807 .63207 L
s
.37235 .62992 m
.372 .62761 L
s
.41086 .62965 m
.40593 .62882 L
s
.41486 .62958 m
.41086 .62965 L
s
.4195 .6281 m
.41486 .62958 L
s
.38958 .62682 m
.38743 .62871 L
s
.42168 .62621 m
.4195 .6281 L
s
.372 .62761 m
.37566 .62522 L
s
.38925 .6245 m
.38958 .62682 L
s
.42295 .6234 m
.42168 .62621 L
s
.37566 .62522 m
.38028 .62374 L
s
.38584 .62317 m
.38925 .6245 L
s
.38028 .62374 m
.38584 .62317 L
s
.42175 .62016 m
.42295 .6234 L
s
.42531 .60927 m
.43813 .62218 L
s
.39851 .62153 m
.39975 .6187 L
s
.41991 .61832 m
.42175 .62016 L
s
.39975 .6187 m
.40192 .61679 L
s
.41559 .61606 m
.41991 .61832 L
s
.44154 .60896 m
.45063 .6182 L
s
.40192 .61679 m
.40658 .61529 L
s
.41062 .61521 m
.41559 .61606 L
s
.40658 .61529 m
.41062 .61521 L
s
.44886 .59303 m
.46792 .61271 L
s
.48716 .58939 m
.50581 .60915 L
s
.44037 .60566 m
.44154 .60896 L
s
.48443 .60624 m
.48849 .60616 L
s
.47947 .60538 m
.48443 .60624 L
s
.48849 .60616 m
.49327 .60465 L
s
.44261 .60371 m
.44037 .60566 L
s
.47519 .60309 m
.47947 .60538 L
s
.49327 .60465 m
.49557 .6027 L
s
.44735 .60219 m
.44261 .60371 L
s
.41976 .60367 m
.41726 .60324 L
s
.4204 .60223 m
.41976 .60367 L
s
.4589 .6034 m
.45142 .60211 L
s
.41726 .60324 m
.4179 .6018 L
s
.47339 .60121 m
.47519 .60309 L
s
.49557 .6027 m
.49699 .5998 L
s
.4179 .6018 m
.4204 .60223 L
s
.45142 .60211 m
.44735 .60219 L
s
.47228 .59788 m
.47339 .60121 L
s
.49842 .58577 m
.51084 .59906 L
s
.47366 .59497 m
.47228 .59788 L
s
.51317 .59709 m
.5082 .59623 L
s
.51726 .59701 m
.51317 .59709 L
s
.52209 .59548 m
.51726 .59701 L
s
.52443 .59351 m
.52209 .59548 L
s
.47595 .59299 m
.47366 .59497 L
s
.52591 .59058 m
.52443 .59351 L
s
.48075 .59145 m
.47595 .59299 L
s
.48985 .59224 m
.48485 .59137 L
s
.48485 .59137 m
.48075 .59145 L
s
.5249 .58721 m
.52591 .59058 L
s
.5011 .58864 m
.50254 .58569 L
s
.52314 .5853 m
.5249 .58721 L
s
.53904 .57272 m
.55123 .58621 L
s
.50254 .58569 m
.50488 .5837 L
s
.51887 .58294 m
.52314 .5853 L
s
.50488 .5837 m
.50973 .58214 L
s
.51386 .58206 m
.51887 .58294 L
s
.50973 .58214 m
.51386 .58206 L
s
.56507 .58058 m
.56007 .57969 L
s
.5692 .5805 m
.56507 .58058 L
s
.57577 .57841 m
.5692 .5805 L
s
.56007 .57969 m
.55671 .57829 L
s
.54429 .57853 m
.54004 .57615 L
s
.5782 .5764 m
.57577 .57841 L
s
.55671 .57829 m
.55411 .57539 L
s
.53087 .57535 m
.52598 .57692 L
s
.57979 .57341 m
.5782 .5764 L
s
.54004 .57615 m
.53501 .57527 L
s
.56232 .57276 m
.55411 .57539 L
s
.53501 .57527 m
.53087 .57535 L
s
.57974 .57094 m
.57979 .57341 L
s
.57882 .56748 m
.57974 .57094 L
s
.58364 .55839 m
.60219 .57 L
s
.597 .5541 m
.60219 .57 L
s
.54714 .5676 m
.54703 .56512 L
s
.57452 .56258 m
.57882 .56748 L
s
.597 .5541 m
.61551 .56577 L
s
.61042 .54978 m
.61551 .56577 L
s
.54703 .56512 m
.54858 .56209 L
s
.57027 .56016 m
.57452 .56258 L
s
.54858 .56209 m
.551 .56004 L
s
.56688 .55872 m
.57027 .56016 L
s
.551 .56004 m
.55763 .5579 L
s
.62223 .54599 m
.63393 .55991 L
s
.56182 .55781 m
.56688 .55872 L
s
.55763 .5579 m
.56182 .55781 L
s
.63646 .55786 m
.63144 .55695 L
s
.64065 .55777 m
.63646 .55786 L
s
.64571 .55616 m
.64065 .55777 L
s
.64827 .5541 m
.64571 .55616 L
s
.65 .55103 m
.64827 .5541 L
s
.64923 .54749 m
.65 .55103 L
s
.62475 .54899 m
.62645 .54591 L
s
.64757 .54549 m
.64923 .54749 L
s
.66482 .5323 m
.67626 .54645 L
s
.62645 .54591 m
.629 .54381 L
s
.64338 .54302 m
.64757 .54549 L
s
.629 .54381 m
.63409 .54218 L
s
.63832 .54209 m
.64338 .54302 L
s
.63409 .54218 m
.63832 .54209 L
s
.6943 .53945 m
.70027 .53881 L
s
.68926 .53852 m
.6943 .53945 L
s
.70027 .53881 m
.71235 .53497 L
s
.68592 .53704 m
.68926 .53852 L
s
.66975 .53839 m
.66558 .5359 L
s
.68177 .53455 m
.68592 .53704 L
s
.65625 .53506 m
.65112 .5367 L
s
.66558 .5359 m
.6605 .53497 L
s
.6605 .53497 m
.65625 .53506 L
s
.69546 .51337 m
.71235 .53497 L
s
.67769 .52945 m
.68177 .53455 L
s
.67696 .52582 m
.67769 .52945 L
s
.67705 .52321 m
.67696 .52582 L
s
.67887 .52003 m
.67705 .52321 L
s
.68326 .51731 m
.67887 .52003 L
s
.69546 .51337 m
.68326 .51731 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000005`3oool20000o`80oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1N0?ooo`<0
00005`3oool30000o`80oooo00<0003o0?ooo`000000F03oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000H0?ooo`80003o
1P3oool00`000?l000000?ooo`1G0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0E@3oool3000001/0oooo00<0003o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0
000007@0oooo00<000000?ooo`3oool0D@3oool3000001h0oooo00<0003o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`1=0?ooo`<000008@3oool00`000?l0oooo0?ooo`070?ooo`03000000000?l0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0B@3oool3000002D0oooo00<0003o0?ooo`3oool01P3oool00`000000
oooo0000o`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<000008`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00@000000?ooo`3oool0003oEP3oool00`000000
oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0@@3oool300000240oooo1`000?l50?ooo`80003o1@3oool00`000000oooo
0000o`020000oeD0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000002X0oooo0P000?l60?ooo`D0003o00<0
00000000o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo03T0oooo0`00000P0?ooo`<0003o2`3oool00`000?l0oooo0?ooo`09
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<000008@3oool20000o`<0oooo0P000?l:0?oo
o`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`00000R0?ooo`80
003o1`3oool20000o`T0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
;@3oool300000240oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00000T0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0
oooo02D0oooo0`00000Q0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000E0?ooo`D0003o1P3oool010000?l0oooo0?ooo`3oool30000o`<0oooo00<0003o
0?ooo`3oool0103oool70000oa@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000F0?oo
o`80003o1@3oool20000o`D0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`80oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H
0?ooo`<000006@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`3oool0003o0`3oool30000ob40oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000L
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool30000o`D0oooo00<0003o
0?ooo`3oool07`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001l0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`80003o9P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000002h0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0T0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<000008P3oool00`000?l0oooo0?ooo`050?ooo`80003o
1@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000803o
ool70000o`<0oooo0`000?l60?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00<00000:@3oool20000o`<0oooo0`000?l40?ooo`80003o;`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000P0?oo
o`80003o2`3oool00`000?l0oooo0?ooo`040?ooo`@0003o<@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0M0?ooo`80
003o0P3oool40000o`P0oooo00<0003o0?ooo`3oool0=`3oool2000005/0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0K0?ooo`80003o
203oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03<0oooo0`0000020?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0h0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`L0003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo03H0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool20000o`D0oooo00<0003o
0?ooo`3oool0<`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`H0003o<`3oool3
00000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<P3oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2<0?ooo`<0003o1`3oool70000o`D0oooo00<0003o0?ooo`3oool01@3oool20000oc@0
oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool70000o`80oooo00<0003o0?ooo`3oool0;P3oool3000001h0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo02X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool010000000oooo0?ooo`00
0?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=P3oool3000002H0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00D00000
0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<P3o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`280?ooo`H0003o00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo03D0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0Q`3oool00`000?l0oooo0?ooo`030?oo
o`03000000000?l0003o00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0a0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0000o`050?ooo`03
0000o`3oool0oooo03<0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0M@3oool00`000?l0oooo0?ooo`060?ooo`H0003o
2@3oool010000000oooo0?ooo`000?lg0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<000000000o`000?l0
=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`1h0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`D0003o<`3oool400000480oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000o`3oool0
oooo00D0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool3
000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`1j0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool30000
o`H0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo0080
oooo1@000?l90?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
001n0?ooo`80003o403oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.35037 .62372 m
.34806 .62302 L
s
.35145 .62243 m
.35037 .62372 L
s
.34806 .62302 m
.34914 .62173 L
s
.34914 .62173 m
.35145 .62243 L
s
.37077 .62018 m
.37588 .6193 L
s
.36505 .62007 m
.37077 .62018 L
s
.36212 .61836 m
.36505 .62007 L
s
.37588 .6193 m
.3804 .61741 L
s
.36151 .61736 m
.36212 .61836 L
s
.3804 .61741 m
.3809 .6151 L
s
.36199 .61505 m
.36151 .61736 L
s
.33723 .60253 m
.34603 .61672 L
s
.39981 .61515 m
.39579 .61474 L
s
.40495 .61426 m
.39981 .61515 L
s
.36479 .61345 m
.36199 .61505 L
s
.39579 .61474 m
.39117 .61332 L
s
.4078 .61265 m
.40495 .61426 L
s
.37274 .61095 m
.36479 .61345 L
s
.41007 .61003 m
.4078 .61265 L
s
.37556 .60934 m
.37274 .61095 L
s
.41745 .59639 m
.42558 .61068 L
s
.3572 .6103 m
.35767 .60797 L
s
.41003 .60669 m
.41007 .61003 L
s
.37606 .60701 m
.37556 .60934 L
s
.43367 .59807 m
.43939 .60829 L
s
.35767 .60797 m
.3622 .60606 L
s
.37312 .60527 m
.37606 .60701 L
s
.40885 .60465 m
.41003 .60669 L
s
.48566 .58445 m
.49702 .6061 L
s
.3622 .60606 m
.36735 .60515 L
s
.36735 .60515 m
.37312 .60527 L
s
.38638 .6052 m
.38862 .60256 L
s
.44657 .5833 m
.45844 .60499 L
s
.40535 .60189 m
.40885 .60465 L
s
.38862 .60256 m
.39147 .60093 L
s
.40071 .60045 m
.40535 .60189 L
s
.48105 .60107 m
.48628 .60016 L
s
.47701 .60065 m
.48105 .60107 L
s
.39147 .60093 m
.39665 .60003 L
s
.47243 .5992 m
.47701 .60065 L
s
.39665 .60003 m
.40071 .60045 L
s
.48628 .60016 m
.48923 .59853 L
s
.46902 .59642 m
.47243 .5992 L
s
.48923 .59853 m
.49165 .59586 L
s
.43368 .59468 m
.43367 .59807 L
s
.49801 .58228 m
.50552 .59682 L
s
.46791 .59436 m
.46902 .59642 L
s
.51253 .59561 m
.50849 .59518 L
s
.5178 .59469 m
.51253 .59561 L
s
.50849 .59518 m
.50392 .59373 L
s
.45282 .59473 m
.44588 .59254 L
s
.52079 .59305 m
.5178 .59469 L
s
.43659 .59304 m
.43368 .59468 L
s
.468 .59095 m
.46791 .59436 L
s
.52327 .59037 m
.52079 .59305 L
s
.44182 .59212 m
.43659 .59304 L
s
.44588 .59254 m
.44182 .59212 L
s
.47039 .58826 m
.468 .59095 L
s
.52346 .58694 m
.52327 .59037 L
s
.41392 .59018 m
.41158 .58945 L
s
.41507 .58884 m
.41392 .59018 L
s
.41158 .58945 m
.41273 .58811 L
s
.54238 .57452 m
.54953 .58919 L
s
.41273 .58811 m
.41507 .58884 L
s
.47335 .5866 m
.47039 .58826 L
s
.4873 .58757 m
.48269 .58611 L
s
.52242 .58486 m
.52346 .58694 L
s
.47862 .58568 m
.47335 .5866 L
s
.48269 .58611 m
.47862 .58568 L
s
.56902 .58581 m
.56497 .58539 L
s
.57613 .58458 m
.56902 .58581 L
s
.49963 .58542 m
.50208 .58271 L
s
.56497 .58539 m
.56042 .58391 L
s
.51907 .58203 m
.52242 .58486 L
s
.5792 .58292 m
.57613 .58458 L
s
.56042 .58391 m
.55764 .58213 L
s
.58179 .5802 m
.5792 .58292 L
s
.50208 .58271 m
.50508 .58105 L
s
.55764 .58213 m
.55613 .57898 L
s
.51447 .58055 m
.51907 .58203 L
s
.50508 .58105 m
.51039 .58012 L
s
.54546 .58084 m
.54214 .578 L
s
.51039 .58012 m
.51447 .58055 L
s
.58259 .57779 m
.58179 .5802 L
s
.59076 .56605 m
.60467 .57963 L
s
.60519 .56352 m
.60467 .57963 L
s
.56504 .57743 m
.55613 .57898 L
s
.54214 .578 m
.53755 .57651 L
s
.58292 .57431 m
.58259 .57779 L
s
.60519 .56352 m
.619 .57715 L
s
.61966 .56099 m
.619 .57715 L
s
.53347 .57608 m
.52814 .57701 L
s
.53755 .57651 m
.53347 .57608 L
s
.58046 .569 m
.58292 .57431 L
s
.63236 .55877 m
.63878 .57372 L
s
.64599 .57247 m
.64193 .57203 L
s
.65141 .57153 m
.64599 .57247 L
s
.64193 .57203 m
.63742 .57054 L
s
.65458 .56984 m
.65141 .57153 L
s
.55207 .57052 m
.55284 .56808 L
s
.65731 .56708 m
.65458 .56984 L
s
.57718 .56612 m
.58046 .569 L
s
.55284 .56808 m
.5554 .56532 L
s
.65779 .56356 m
.65731 .56708 L
s
.57439 .5643 m
.57718 .56612 L
s
.67799 .55078 m
.68404 .56587 L
s
.5554 .56532 m
.55849 .56361 L
s
.56979 .56279 m
.57439 .5643 L
s
.55849 .56361 m
.56568 .56235 L
s
.6569 .56141 m
.65779 .56356 L
s
.56568 .56235 m
.56979 .56279 L
s
.63375 .56199 m
.63646 .55921 L
s
.70956 .56145 m
.72238 .55923 L
s
.70367 .56132 m
.70956 .56145 L
s
.65374 .5585 m
.6569 .56141 L
s
.69918 .55981 m
.70367 .56132 L
s
.6965 .55797 m
.69918 .55981 L
s
.71376 .5363 m
.72238 .55923 L
s
.63646 .55921 m
.63963 .5575 L
s
.64919 .55698 m
.65374 .5585 L
s
.6934 .55505 m
.6965 .55797 L
s
.63963 .5575 m
.6451 .55654 L
s
.6806 .55728 m
.67747 .55436 L
s
.6451 .55654 m
.64919 .55698 L
s
.69127 .54962 m
.6934 .55505 L
s
.67747 .55436 m
.67293 .55283 L
s
.66883 .55238 m
.66334 .55335 L
s
.67293 .55283 m
.66883 .55238 L
s
.69183 .54603 m
.69127 .54962 L
s
.69282 .54351 m
.69183 .54603 L
s
.69566 .54066 m
.69282 .54351 L
s
.70078 .53859 m
.69566 .54066 L
s
.71376 .5363 m
.70078 .53859 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`000?l00P000?mE0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0oooo0`00000f0?ooo`030000o`000000
003o0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo0`00000g0?ooo`80003o00<0oooo0000
003oool00`3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000W0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000003T0oooo00D0003o0?ooo`3o
ool0oooo000000040?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<00000?03oool01@000?l0
oooo0?ooo`3oool0000000@0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`00000o0?ooo`05
0000o`3oool0oooo0?ooo`0000001@3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000003L0
oooo1@000?l00`3oool0003o0?ooo`030?ooo`050000o`3oool0oooo0?ooo`0000001@3oool00`00
0?l0oooo0?ooo`1B0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000
oooo0?ooo`0U0?ooo`<00000?`3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo000000050?oo
o`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000<P3oool00`000?l0oooo0000o`060000o`T0
oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000000oooo00D0oooo00<0003o0?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo01`0oooo1000000`0?ooo`030000o`3oool0oooo0080oooo0P000?l70?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool20000o`03000000000?l0003o00@0003o
D`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo01P0oooo0`00000M0?ooo`D0003o3@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo0P000?l70?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0503oool3000001l0oooo00<0003o0?ooo`3oool00`3oool3
0000o`@0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0403oool300000240oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0303oool3000002@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`030?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`000?l01P3oool20000
o`<0oooo0P000?lB0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000008`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l0103oool20000o`H0
oooo00<0003o0?ooo`000?l00P000?lD0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000
8@3oool40000o`030?ooo`000?l0oooo00H0oooo0P000?l50?ooo`030000o`3oool0oooo00@0oooo
0P000?l50?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000007@3o
ool00`000?l0oooo0?ooo`080?ooo`<0003o0`3oool30000o`L0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000001`0oooo10000?l0103oool0003o0000o`00
0?l90?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00D0oooo0P000?l80?ooo`030000o`3oool0oooo0080oooo0`000?l2
0?ooo`80003o;P3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0RP3oool00`000?l0oooo0000000:0?ooo`030000o`3oool0oooo00D0oooo20000?l40?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`80003o;@3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`290?ooo`<0003o00<000000?ooo`3oool0203oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0;`3oool4000000H0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo00@0oooo1P000?l50?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03L0oooo
0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P00
0?l40?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool60000ocL0oooo0`00
000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S03oool00`000?l000000?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?ooo`0g
0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08<0oooo10000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`H0003o0P3oool00`000?l0oooo0?ooo`0h0?oo
o`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo06l0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`020?ooo`80
003o103oool00`000000003o0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0d0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0
1@3oool60000o`<0oooo00<0003o0?ooo`3oool01@3oool20000o`80oooo00<000000000o`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0
<03oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo00<0oooo0P000?l50?ooo`030000o`3o
ool0oooo00X0oooo00H0003o0?ooo`3oool000000?ooo`000?l50?ooo`030000o`3oool0oooo0480
oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0LP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
0P000?l=0?ooo`040000o`3oool0oooo00000080oooo00<0003o0?ooo`3oool0A03oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000007<0oooo
00<0003o0?ooo`3oool0103oool30000o`P0oooo0P000?l30?ooo`80003o0`3oool00`000000oooo
0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo07<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo0`000?l50?ooo`030000003oool0oooo0400oooo1000
000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0N@3oool70000o`d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`1d0?oo
o`80003o5`3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3o
ool05P3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
04X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool30000
07H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo
0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00
803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<0
0000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48594 .57941 m
.48945 .60205 L
s
.33735 .60146 m
.33528 .60048 L
s
.3389 .60031 m
.33735 .60146 L
s
.33528 .60048 m
.33683 .59933 L
s
.3591 .60047 m
.36454 .60022 L
s
.35341 .59965 m
.3591 .60047 L
s
.33683 .59933 m
.3389 .60031 L
s
.36454 .60022 m
.36974 .5989 L
s
.35108 .5976 m
.35341 .59965 L
s
.38995 .59906 m
.38608 .59816 L
s
.3954 .59881 m
.38995 .59906 L
s
.36974 .5989 m
.37107 .59668 L
s
.39881 .59758 m
.3954 .59881 L
s
.38608 .59816 m
.38198 .59618 L
s
.41421 .58271 m
.41721 .59781 L
s
.35083 .59653 m
.35108 .5976 L
s
.402 .59527 m
.39881 .59758 L
s
.42972 .58638 m
.43177 .59715 L
s
.35213 .5943 m
.35083 .59653 L
s
.44776 .57344 m
.4518 .59623 L
s
.40315 .59196 m
.402 .59527 L
s
.47551 .59515 m
.48099 .5949 L
s
.47169 .59425 m
.47551 .59515 L
s
.48099 .5949 m
.48447 .59366 L
s
.35552 .59306 m
.35213 .5943 L
s
.46767 .59226 m
.47169 .59425 L
s
.49884 .57881 m
.50108 .59398 L
s
.33174 .57881 m
.3355 .59398 L
s
.48447 .59366 m
.48779 .59134 L
s
.50839 .59365 m
.50458 .59274 L
s
.51387 .5934 m
.50839 .59365 L
s
.51738 .59216 m
.51387 .5934 L
s
.36438 .59156 m
.35552 .59306 L
s
.50458 .59274 m
.5006 .59076 L
s
.4653 .58911 m
.46767 .59226 L
s
.52075 .58984 m
.51738 .59216 L
s
.40271 .58981 m
.40315 .59196 L
s
.545 .57669 m
.54682 .5919 L
s
.36778 .59032 m
.36438 .59156 L
s
.56699 .59098 m
.5632 .59007 L
s
.57432 .59064 m
.56699 .59098 L
s
.57788 .58939 m
.57432 .59064 L
s
.36912 .58808 m
.36778 .59032 L
s
.5632 .59007 m
.55929 .58807 L
s
.52215 .58651 m
.52075 .58984 L
s
.40021 .58665 m
.40271 .58981 L
s
.58134 .58706 m
.57788 .58939 L
s
.59499 .57438 m
.6037 .5893 L
s
.60982 .5737 m
.6037 .5893 L
s
.46494 .58695 m
.4653 .58911 L
s
.34903 .589 m
.35034 .58675 L
s
.60982 .5737 m
.61841 .58863 L
s
.62467 .57302 m
.61841 .58863 L
s
.3668 .58599 m
.36912 .58808 L
s
.55929 .58807 m
.55721 .58599 L
s
.63768 .57242 m
.63866 .5877 L
s
.38008 .58757 m
.38327 .58524 L
s
.64602 .58737 m
.64227 .58645 L
s
.65155 .58711 m
.64602 .58737 L
s
.65518 .58586 m
.65155 .58711 L
s
.58297 .58481 m
.58134 .58706 L
s
.46622 .58361 m
.46494 .58695 L
s
.35034 .58675 m
.35557 .58542 L
s
.39609 .58465 m
.40021 .58665 L
s
.52186 .58434 m
.52215 .58651 L
s
.64227 .58645 m
.63845 .58445 L
s
.43094 .58304 m
.42972 .58638 L
s
.36106 .58516 m
.3668 .58599 L
s
.55721 .58599 m
.55684 .58273 L
s
.65875 .58352 m
.65518 .58586 L
s
.68419 .57027 m
.68475 .5856 L
s
.44989 .58546 m
.4438 .58245 L
s
.35557 .58542 m
.36106 .58516 L
s
.38327 .58524 m
.3867 .58398 L
s
.5845 .58146 m
.58297 .58481 L
s
.3922 .58373 m
.39609 .58465 L
s
.71061 .58442 m
.72356 .58383 L
s
.70504 .58359 m
.71061 .58442 L
s
.51958 .58116 m
.52186 .58434 L
s
.3867 .58398 m
.3922 .58373 L
s
.72326 .56068 m
.72356 .58383 L
s
.46954 .58126 m
.46622 .58361 L
s
.70128 .58158 m
.70504 .58359 L
s
.66043 .58017 m
.65875 .58352 L
s
.54578 .58324 m
.54355 .58005 L
s
.43441 .58178 m
.43094 .58304 L
s
.56605 .58231 m
.55684 .58273 L
s
.48644 .58268 m
.48242 .58067 L
s
.4438 .58245 m
.43992 .58153 L
s
.49932 .58209 m
.50269 .57974 L
s
.43992 .58153 m
.43441 .58178 L
s
.69937 .57948 m
.70128 .58158 L
s
.58397 .57599 m
.5845 .58146 L
s
.47304 .58 m
.46954 .58126 L
s
.51559 .57914 m
.51958 .58116 L
s
.48242 .58067 m
.47857 .57975 L
s
.66032 .57798 m
.66043 .58017 L
s
.54355 .58005 m
.53959 .57804 L
s
.47857 .57975 m
.47304 .58 L
s
.50269 .57974 m
.50622 .57847 L
s
.69743 .57628 m
.69937 .57948 L
s
.51175 .57822 m
.51559 .57914 L
s
.50622 .57847 m
.51175 .57822 L
s
.53959 .57804 m
.53576 .57711 L
s
.6583 .57478 m
.66032 .57798 L
s
.53576 .57711 m
.53022 .57737 L
s
.68443 .57688 m
.68245 .57367 L
s
.69727 .57078 m
.69743 .57628 L
s
.41291 .57616 m
.41084 .57514 L
s
.41453 .57497 m
.41291 .57616 L
s
.5818 .57278 m
.58397 .57599 L
s
.63789 .57572 m
.64146 .57335 L
s
.41084 .57514 m
.41247 .57396 L
s
.41247 .57396 m
.41453 .57497 L
s
.65447 .57275 m
.6583 .57478 L
s
.55585 .57398 m
.55745 .57169 L
s
.68245 .57367 m
.67865 .57164 L
s
.64146 .57335 m
.64511 .57207 L
s
.57973 .57066 m
.5818 .57278 L
s
.65069 .57182 m
.65447 .57275 L
s
.64511 .57207 m
.65069 .57182 L
s
.55745 .57169 m
.56092 .56931 L
s
.67865 .57164 m
.67488 .5707 L
s
.67488 .5707 m
.66929 .57096 L
s
.69904 .56737 m
.69727 .57078 L
s
.57579 .56862 m
.57973 .57066 L
s
.56092 .56931 m
.56452 .56803 L
s
.57196 .56769 m
.57579 .56862 L
s
.56452 .56803 m
.57196 .56769 L
s
.70085 .56507 m
.69904 .56737 L
s
.70453 .56267 m
.70085 .56507 L
s
.71013 .56129 m
.70453 .56267 L
s
.72326 .56068 m
.71013 .56129 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`000?l01@000?mB0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000005@0oooo00<000000000o`3oool0103oool00`000?l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
000005D0oooo0P000?l00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?oo
o`<00000903oool70000obd0oooo00<0003o0?ooo`0000001P3oool00`000?l0oooo0?ooo`1A0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000002H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0E0?ooo`@0
003o1@3oool50000o`030?ooo`000?l0oooo00<0oooo00@0003o0?ooo`3oool000001P3oool00`00
0?l0oooo0?ooo`1A0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0
oooo00<000000000o`3oool0203oool3000000030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool20000o`P0oooo0P000?l40?ooo`04
0000o`3oool0oooo000000H0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`290?ooo`80003o1P3oool3000000<0oooo00<0003o0?ooo`3o
ool0703oool30000o`80oooo00<0003o0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0003o
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo
000000H0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`1/0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool00`0000060?oo
o`030000o`3oool0oooo00H0oooo0`000?l20?ooo`030000o`3oool0oooo0080oooo1`000?l80?oo
o`<0003o3P3oool00`000?l0oooo0?ooo`020?ooo`060000o`3oool0oooo0000o`3oool0003o0`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0000000H0oooo00<0003o0?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0
oooo01/0oooo00@0003o0?ooo`0000000000103oool60000o`L0oooo00@0003o0?ooo`3oool0oooo
0`000?l40?ooo`030000o`3oool0oooo00@0oooo0P000?l80?ooo`030000o`3oool0oooo0080oooo
10000?l60?ooo`030000o`3oool0oooo0080oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`0000001P3oool00`000?l0oooo0?ooo`1A0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000K@3oool00`000?l0oooo0?ooo`050?ooo`@0
003o1`3oool60000o`D0oooo00<0003o0?ooo`000000103oool00`000?l0oooo0?ooo`030?ooo`80
003o1@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`00
0?l01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0103oool2000000L0003oE03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`1/0?ooo`030000o`3oool0oooo00<0oooo0P000?l40?ooo`80003o103oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`0000000`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo
0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo0P000?l70?ooo`P0
003o3@3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0:0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo000000030?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo0P000?l20?ooo`@0003o203oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01H0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo0?ooo`040?ooo`D0
003o3@3oool00`000?l0oooo0?ooo`020?ooo`030000o`000000oooo0080oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool20000o`80oooo0`000?l:0?ooo`030000o`3oool0oooo00@0oooo0P000?lW0?ooo`<0
00002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo06h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l000000?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool80000o`@0oooo00@0003o0?ooo`000?l0
003o>P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`1d0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool20000o`80oooo0`000?l50?ooo`030000o`000000oooo00<0oooo00<0003o0?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0m0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06h0oooo0P000?l50?ooo`H0003o1`3o
ool20000o`T0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0j0?ooo`<000005P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0f0?ooo`@000006P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0
oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?oo
o`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<0
0000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?oo
o`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q
0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<0
0000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<0
0000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000
IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0
oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@0
00000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
3P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo
0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool40000
0440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo
0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.70369 .60671 m
.71621 .60769 L
s
.72389 .58534 m
.71621 .60769 L
s
.69867 .60524 m
.70369 .60671 L
s
.69578 .60285 m
.69867 .60524 L
s
.68337 .58987 m
.67861 .60476 L
s
.69468 .6006 m
.69578 .60285 L
s
.64628 .60224 m
.64088 .60182 L
s
.65019 .60146 m
.64628 .60224 L
s
.64088 .60182 m
.63759 .60048 L
s
.65444 .59962 m
.65019 .60146 L
s
.63804 .58631 m
.63368 .60126 L
s
.69393 .59727 m
.69468 .6006 L
s
.63759 .60048 m
.63461 .59808 L
s
.61075 .58416 m
.61385 .59971 L
s
.62532 .58531 m
.61385 .59971 L
s
.65721 .59658 m
.65444 .59962 L
s
.59617 .58301 m
.5994 .59859 L
s
.61075 .58416 m
.5994 .59859 L
s
.69568 .59194 m
.69393 .59727 L
s
.48798 .5745 m
.48345 .59714 L
s
.65786 .59445 m
.65721 .59658 L
s
.57045 .59633 m
.5632 .59576 L
s
.57434 .59555 m
.57045 .59633 L
s
.68132 .59629 m
.68054 .59294 L
s
.5632 .59576 m
.55983 .59441 L
s
.57852 .5937 m
.57434 .59555 L
s
.65703 .5911 m
.65786 .59445 L
s
.55983 .59441 m
.55672 .59199 L
s
.5468 .57913 m
.54323 .59421 L
s
.58088 .5917 m
.57852 .5937 L
s
.68054 .59294 m
.67761 .59052 L
s
.55672 .59199 m
.55543 .58971 L
s
.69855 .58887 m
.69568 .59194 L
s
.58354 .58862 m
.58088 .5917 L
s
.51049 .59165 m
.50502 .59123 L
s
.51436 .59087 m
.51049 .59165 L
s
.50502 .59123 m
.5016 .58987 L
s
.65406 .58867 m
.65703 .5911 L
s
.51848 .58901 m
.51436 .59087 L
s
.50088 .57552 m
.49772 .59066 L
s
.67761 .59052 m
.67432 .58916 L
s
.5016 .58987 m
.49839 .58744 L
s
.55543 .58971 m
.55621 .58648 L
s
.6371 .58953 m
.64136 .58767 L
s
.67432 .58916 m
.66889 .58873 L
s
.47763 .58909 m
.4815 .5883 L
s
.47215 .58867 m
.47763 .58909 L
s
.52102 .58592 m
.51848 .58901 L
s
.70106 .58686 m
.69855 .58887 L
s
.65076 .58731 m
.65406 .58867 L
s
.4687 .58731 m
.47215 .58867 L
s
.58494 .58323 m
.58354 .58862 L
s
.4815 .5883 m
.48559 .58644 L
s
.64136 .58767 m
.64531 .58688 L
s
.64531 .58688 m
.65076 .58731 L
s
.46544 .58486 m
.4687 .58731 L
s
.56533 .5872 m
.55621 .58648 L
s
.7054 .58499 m
.70106 .58686 L
s
.45243 .56388 m
.44835 .58681 L
s
.5215 .58376 m
.52102 .58592 L
s
.54526 .58562 m
.5442 .58224 L
s
.72389 .58534 m
.7112 .58434 L
s
.42997 .57438 m
.42817 .58524 L
s
.7112 .58434 m
.7054 .58499 L
s
.46421 .58148 m
.46544 .58486 L
s
.41586 .56883 m
.41347 .58409 L
s
.52039 .58037 m
.5215 .58376 L
s
.58395 .57984 m
.58494 .58323 L
s
.39138 .58237 m
.38585 .58194 L
s
.39522 .58157 m
.39138 .58237 L
s
.5442 .58224 m
.54104 .57978 L
s
.38585 .58194 m
.38231 .58057 L
s
.39923 .57969 m
.39522 .58157 L
s
.46462 .5793 m
.46421 .58148 L
s
.38231 .58057 m
.37891 .57811 L
s
.51719 .57791 m
.52039 .58037 L
s
.36001 .57992 m
.36569 .57927 L
s
.35446 .57949 m
.36001 .57992 L
s
.58268 .57752 m
.58395 .57984 L
s
.54104 .57978 m
.53763 .57841 L
s
.40156 .57657 m
.39923 .57969 L
s
.34904 .57797 m
.35446 .57949 L
s
.46707 .57618 m
.46462 .5793 L
s
.36569 .57927 m
.36782 .57724 L
s
.5002 .57878 m
.50433 .5769 L
s
.53763 .57841 m
.53212 .57797 L
s
.34744 .57565 m
.34904 .57797 L
s
.51375 .57653 m
.51719 .57791 L
s
.55832 .57782 m
.56068 .57578 L
s
.48733 .57777 m
.48408 .5753 L
s
.33225 .57776 m
.33051 .57653 L
s
.33422 .57682 m
.33225 .57776 L
s
.57958 .57505 m
.58268 .57752 L
s
.50433 .5769 m
.50824 .57609 L
s
.33248 .57558 m
.33422 .57682 L
s
.40188 .57439 m
.40156 .57657 L
s
.50824 .57609 m
.51375 .57653 L
s
.33051 .57653 m
.33248 .57558 L
s
.47117 .57429 m
.46707 .57618 L
s
.45028 .57597 m
.44532 .57226 L
s
.56068 .57578 m
.56489 .57389 L
s
.34757 .57456 m
.34744 .57565 L
s
.48408 .5753 m
.48061 .57392 L
s
.57618 .57366 m
.57958 .57505 L
s
.34968 .57251 m
.34757 .57456 L
s
.40052 .57096 m
.40188 .57439 L
s
.43236 .57124 m
.42997 .57438 L
s
.47507 .57349 m
.47117 .57429 L
s
.48061 .57392 m
.47507 .57349 L
s
.56489 .57389 m
.56883 .57308 L
s
.56883 .57308 m
.57618 .57366 L
s
.35353 .57171 m
.34968 .57251 L
s
.44532 .57226 m
.44181 .57087 L
s
.36295 .57134 m
.35353 .57171 L
s
.3668 .57053 m
.36295 .57134 L
s
.43625 .57043 m
.43236 .57124 L
s
.39713 .56847 m
.40052 .57096 L
s
.44181 .57087 m
.43625 .57043 L
s
.36894 .56848 m
.3668 .57053 L
s
.33474 .55458 m
.33307 .57011 L
s
.3801 .56935 m
.38412 .56744 L
s
.36737 .56613 m
.36894 .56848 L
s
.39357 .56707 m
.39713 .56847 L
s
.38412 .56744 m
.38799 .56663 L
s
.38799 .56663 m
.39357 .56707 L
s
.34846 .56687 m
.35059 .56481 L
s
.36191 .56458 m
.36737 .56613 L
s
.35059 .56481 m
.35632 .56414 L
s
.35632 .56414 m
.36191 .56458 L
s
.4169 .5622 m
.41521 .56094 L
s
.41894 .56124 m
.4169 .5622 L
s
.41725 .55998 m
.41894 .56124 L
s
.41521 .56094 m
.41725 .55998 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00001/0?ooo`030000o`3oool0oooo
0180oooo00<000000?ooo`3oool09@3oool3000004T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool08@3oool3000004`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo01@0oooo
00<000000?ooo`3oool0103oool20000oaH0oooo1000001@0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00@0oooo0`00001D0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`04
0?ooo`80003o00<0oooo0000o`000?l00P000?l60?ooo`80003o103oool00`000000oooo0?ooo`0@
0?ooo`040000o`3oool0oooo0?ooo`<00000E`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000V0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P000?l20?ooo`<0003o0P3oool0
1@000000oooo0?ooo`3oool0003o00d0oooo00@0003o0000000000000000FP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06/0oooo00<0
003o0?ooo`3oool01@3oool60000o`/0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo
0?ooo`030?ooo`D0003o00@0oooo000000000?l00000G@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo0700oooo0`000?lB0?ooo`060000
o`3oool0oooo0000003oool0003o103oool010000?l0oooo0?ooo`3oool2000000030000o`3oool0
003o00L0oooo10000?l20?ooo`030000o`3oool0oooo01X0oooo1@000?l_0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool20000
o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool010000?l000000000000000030?ooo`80003o1@3oool20000o`@0oooo00<0
003o0?ooo`000?l0103oool50000oa40oooo0P000?l50?ooo`80003o;@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06`0oooo00<0003o
0?ooo`3oool00`3oool70000o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`070000o`000000oooo0?ooo`000000003o000000070?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01@3oool20000o`<0oooo0P000?l40?ooo`80003o103oool50000o`030?oo
o`000?l0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0OP3o
ool70000o`D0oooo00H0003o0?ooo`00000000000?ooo`000?l70?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool20000o`d0oooo00<0003o0?ooo`3oool0:P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000R`3oool00`000?l0oooo
000000020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00`0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool06P3oool2000000L0003oE03oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00P0oooo
00<0003o0?ooo`3oool0103oool20000o`D0oooo00@0003o0?ooo`3oool0oooo0P000?l70?ooo`03
0000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo1@000?l50?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool60000
o`l0oooo0`0000000`000?l0oooo000000050?ooo`030000o`3oool0oooo0580oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0A0?ooo`H0
003o0`3oool00`000?l0oooo0000o`040?ooo`80003o2@3oool01@000?l0oooo0?ooo`3oool0003o
00T0oooo00<0003o0?ooo`3oool00P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?ooo`D0003o00<0
oooo0000000000000P0000000`3oool0003o0?ooo`030?ooo`050000003oool0oooo0?ooo`000?l0
E@3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo01D0oooo00<0003o0?ooo`3oool01@3oool40000o`X0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l00P3o
ool010000?l0oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool3000000050000o`3oool0oooo0?ooo`000?l01@3oool01@000000oooo0?ooo`3oool0003o
05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool40000o`80
oooo0`000?l60?ooo`80003o103oool20000o`H0oooo00<0003o0?ooo`3oool01@3oool010000?l0
oooo0?ooo`3oool300000080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`040000003oool0oooo0000oeD0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01d0oooo0P000?l90?oo
o`030000o`3oool0oooo00<0oooo0P000?l50?ooo`80003o1`3oool010000?l00000000000000005
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000000003o0?ooo`1E
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o00<0oooo00@0003o0000
000000000000203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0500oooo1000000:0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l000000?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0C@3oool3000000h0oooo00<0003o0?ooo`3o
ool0103oool50000o`80oooo00<0003o0?ooo`000000EP3oool00`000000oooo0?ooo`0A0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000M0?ooo`<0003o
0P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0A03oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03P0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e
0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02h0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000
BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3
00000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool20000
0900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0
oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000680oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0
oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P
0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00
000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3o
ool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0
oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool20000
02D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00
001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3o
ool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900
oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool5
00000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P00
00090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo
00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo
0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00
001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`80
0000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo
0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`800000
2`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3o
ool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0
oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0
oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo
00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000
D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03o
ool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?oo
o`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@00000
1@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3o
ool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool0
06X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<0
00000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?oo
o`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000
<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool0
0`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool20000
00d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool50000
0480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo
09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00
000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V
0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?oo
o`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000
003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3o
ool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool4
00000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool40000
08@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo
00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00
000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?oo
o`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0
=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03o
ool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool00000
02<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool40000
0;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`00
0000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`800000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P00
00050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool5
00000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool30000
0080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.6894 .62743 m
.70099 .62985 L
s
.716 .60919 m
.70099 .62985 L
s
.68512 .62541 m
.6894 .62743 L
s
.68319 .62276 m
.68512 .62541 L
s
.68292 .62045 m
.68319 .62276 L
s
.67582 .60873 m
.66611 .62257 L
s
.68335 .61714 m
.68292 .62045 L
s
.68686 .6122 m
.68335 .61714 L
s
.63596 .61628 m
.63091 .61522 L
s
.63999 .61599 m
.63596 .61628 L
s
.64471 .61471 m
.63999 .61599 L
s
.63091 .61522 m
.62821 .61353 L
s
.64843 .61209 m
.64471 .61471 L
s
.67164 .61469 m
.67205 .61136 L
s
.63357 .59983 m
.62417 .61382 L
s
.62821 .61353 m
.62617 .61084 L
s
.69066 .60957 m
.68686 .6122 L
s
.6498 .6101 m
.64843 .61209 L
s
.67205 .61136 m
.67008 .60866 L
s
.65016 .60676 m
.6498 .6101 L
s
.60801 .59444 m
.60557 .60994 L
s
.62166 .59732 m
.60557 .60994 L
s
.69375 .60793 m
.69066 .60957 L
s
.716 .60919 m
.70428 .60671 L
s
.67008 .60866 m
.66741 .60696 L
s
.69853 .60664 m
.69375 .60793 L
s
.5943 .59155 m
.59199 .6071 L
s
.60801 .59444 m
.59199 .6071 L
s
.66741 .60696 m
.66235 .60589 L
s
.64815 .60405 m
.65016 .60676 L
s
.70428 .60671 m
.69853 .60664 L
s
.64545 .60233 m
.64815 .60405 L
s
.63154 .60285 m
.63629 .60155 L
s
.64036 .60126 m
.64545 .60233 L
s
.63629 .60155 m
.64036 .60126 L
s
.56469 .6014 m
.55784 .59997 L
s
.56875 .60111 m
.56469 .6014 L
s
.57345 .59981 m
.56875 .60111 L
s
.55784 .59997 m
.55503 .59825 L
s
.57645 .59816 m
.57345 .59981 L
s
.55503 .59825 m
.55285 .59551 L
s
.5801 .59548 m
.57645 .59816 L
s
.54769 .58173 m
.53892 .59603 L
s
.55285 .59551 m
.55239 .59312 L
s
.58334 .5904 m
.5801 .59548 L
s
.55239 .59312 m
.55429 .59007 L
s
.56291 .59187 m
.55429 .59007 L
s
.49173 .56994 m
.47926 .59159 L
s
.58357 .58697 m
.58334 .5904 L
s
.50778 .58953 m
.50256 .58844 L
s
.51186 .58923 m
.50778 .58953 L
s
.51655 .58792 m
.51186 .58923 L
s
.50256 .58844 m
.49968 .58669 L
s
.52012 .58521 m
.51655 .58792 L
s
.54391 .58789 m
.54407 .58445 L
s
.50404 .57253 m
.4956 .58699 L
s
.58315 .58456 m
.58357 .58697 L
s
.49968 .58669 m
.49739 .58391 L
s
.52135 .58315 m
.52012 .58521 L
s
.581 .58177 m
.58315 .58456 L
s
.54407 .58445 m
.54185 .58166 L
s
.52145 .5797 m
.52135 .58315 L
s
.47639 .58298 m
.48048 .58268 L
s
.47113 .58188 m
.47639 .58298 L
s
.48048 .58268 m
.48516 .58135 L
s
.4682 .58012 m
.47113 .58188 L
s
.55937 .58187 m
.56239 .58017 L
s
.57819 .58001 m
.581 .58177 L
s
.54185 .58166 m
.539 .5799 L
s
.56239 .58017 m
.56714 .57884 L
s
.46586 .57732 m
.4682 .58012 L
s
.57126 .57854 m
.57819 .58001 L
s
.539 .5799 m
.53377 .5788 L
s
.51919 .57689 m
.52145 .5797 L
s
.56714 .57884 m
.57126 .57854 L
s
.46584 .57384 m
.46586 .57732 L
s
.46044 .55508 m
.44827 .57711 L
s
.51631 .57512 m
.51919 .57689 L
s
.50222 .57565 m
.50694 .57431 L
s
.51106 .57401 m
.51631 .57512 L
s
.50694 .57431 m
.51106 .57401 L
s
.46701 .57175 m
.46584 .57384 L
s
.48993 .57307 m
.48761 .57024 L
s
.43448 .56258 m
.42883 .57306 L
s
.47054 .56899 m
.46701 .57175 L
s
.48761 .57024 m
.48468 .56846 L
s
.42245 .55534 m
.41463 .57009 L
s
.47526 .56764 m
.47054 .56899 L
s
.48468 .56846 m
.47938 .56734 L
s
.47938 .56734 m
.47526 .56764 L
s
.45403 .56669 m
.45044 .56242 L
s
.39324 .56563 m
.38787 .56451 L
s
.39736 .56533 m
.39324 .56563 L
s
.40202 .56397 m
.39736 .56533 L
s
.38787 .56451 m
.38483 .56271 L
s
.40546 .56118 m
.40202 .56397 L
s
.38483 .56271 m
.38231 .55985 L
s
.43797 .55979 m
.43448 .56258 L
s
.45044 .56242 m
.44746 .56061 L
s
.40656 .55907 m
.40546 .56118 L
s
.44746 .56061 m
.44211 .55949 L
s
.44211 .55949 m
.43797 .55979 L
s
.36866 .55933 m
.37152 .55759 L
s
.36273 .55926 m
.36866 .55933 L
s
.35733 .55814 m
.36273 .55926 L
s
.40642 .55551 m
.40656 .55907 L
s
.35243 .55595 m
.35733 .55814 L
s
.35166 .55344 m
.35243 .55595 L
s
.40393 .55263 m
.40642 .55551 L
s
.33563 .55361 m
.33432 .55216 L
s
.33795 .55292 m
.33563 .55361 L
s
.35218 .55237 m
.35166 .55344 L
s
.33665 .55148 m
.33795 .55292 L
s
.40089 .5508 m
.40393 .55263 L
s
.35504 .55062 m
.35218 .55237 L
s
.33432 .55216 m
.33665 .55148 L
s
.38663 .55135 m
.39132 .54997 L
s
.36876 .55114 m
.35918 .55031 L
s
.37291 .55083 m
.36876 .55114 L
s
.37579 .54907 m
.37291 .55083 L
s
.39548 .54966 m
.40089 .5508 L
s
.35918 .55031 m
.35504 .55062 L
s
.39132 .54997 m
.39548 .54966 L
s
.37505 .54654 m
.37579 .54907 L
s
.42584 .54894 m
.42461 .54749 L
s
.4282 .54825 m
.42584 .54894 L
s
.42697 .5468 m
.4282 .54825 L
s
.42461 .54749 m
.42697 .5468 L
s
.37014 .54432 m
.37505 .54654 L
s
.34646 .53094 m
.33921 .54612 L
s
.35584 .54488 m
.35871 .5431 L
s
.36469 .54317 m
.37014 .54432 L
s
.35871 .5431 m
.36469 .54317 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool01@3oool00`000000
oooo0?ooo`190?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`070?ooo`030000003oool0oooo04D0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1]0?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0K03oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0K03oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0K03oool00`000?l0oooo0?ooo`030?ooo`L0003o0`3oool00`000000oooo0?ooo`0e0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo06`0oooo00<0003o0?ooo`3oool02P3oool20000o`80oooo00<000000?ooo`3oool0
303oool20000ob<0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0LP3oool40000o`@0oooo00H0003o0?ooo`3oool0oooo
0000003oool20000o`/0oooo00<0003o0?ooo`3oool07P3oool3000004<0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1Z0?ooo`<0003o
103oool00`000?l0oooo0?ooo`020?ooo`@0003o103oool20000o`80oooo0`000?lV0?ooo`<00000
AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000K03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool3000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1b0?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo0`00
001<0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0M@3oool40000o`@0oooo00<0003o0?ooo`3oool00`3oool010000000oooo0?ooo`00
0?l40?ooo`030000o`3oool0oooo00@0oooo1@000?l30?ooo`030000o`3oool0oooo00D0oooo1000
001@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0OP3oool00`000?l0oooo0?ooo`030?ooo`03000000000?l0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0003o00D0oooo0`00001D
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0O`3oool60000o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00@000000?oo
o`3oool0003o1P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000000000000080oooo1`00
0?mA0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0000o`050?ooo`030000o`3oool0oooo00@0oooo00<00000
0000o`000000103oool00`000?l0oooo0?ooo`050?ooo`80003oC`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0103oool010000?l0oooo0?ooo`3oool3000000030?ooo`000?l0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool20000o`@0oooo0`000?m80?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<000000`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool20000o`80oooo0`000?m50?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000000d0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool30000o`P0oooo1P000?l_0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool200000140oooo
0P000?l20?ooo`<0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`000?l00`3oool20000o`H0oooo0P000?l]0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0180oooo0P00
0?l00`3oool0003o0?ooo`030?ooo`80003o1`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0:P3oool2000005/0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo0P000?l50?ooo`80003o2@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo02L0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00D0oooo1@000?l:0?ooo`030000o`3oool0oooo0080oooo0P000?l80?ooo`030000o`3oool0oooo
02<0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01@0
oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01`0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool04`3oool3000000h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo0300oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo0P000?l40?ooo`030000o`3oool0oooo00/0oooo0`00000B0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0a0?ooo`L0003o1P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`020?ooo`@0003o0`3oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03h0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l30?ooo`030000o`3oool0oooo
0080oooo0P000?l20?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool20000o`<0
oooo00@0003o0?ooo`000?l0003o1@3oool010000?l000000000000000030?ooo`030000o`3oool0
oooo0080oooo0`000?l:0?ooo`D0003o103oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool00`00
0?l0oooo0?ooo`020?ooo`80003o1@3oool3000000H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0000o`040?ooo`<0003o1@3oool30000o`80oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo04<0
oooo00@0003o0?ooo`3oool0oooo0`0000020000o`L0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000
oooo0?ooo`140?ooo`<000000`3oool20000o`D0oooo0P000?l80?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`100?ooo`@00000203oool50000o`X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00
000J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000703oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>03oool3000002H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000:P3oool30000o`<0oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000300oooo0`000?l?0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3
000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0
oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo
0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3
000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000
oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool30000
00T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?oo
o`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool30000
02P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?oo
o`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool30000
04P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?oo
o`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo
0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?oo
o`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000
002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0
oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo
000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?oo
o`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`
0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?oo
o`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3o
ool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@00000
0?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`80
0000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`80
0000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003o
ool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2
000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool0
0`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
03d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B
0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool2
00000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool0
0600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?oo
o`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`800000
0P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4
000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0
oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?oo
o`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0
/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool4
00000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0
oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo
0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo
1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo
0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo
001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo0021
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?oo
o`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3o
ool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`00
00009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000
003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo
05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0
oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo
100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B
0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?oo
o`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000
003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003o
ool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0
oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo
1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo
00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?oo
o`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0
oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo
0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.66859 .64578 m
.67884 .64947 L
s
.70028 .63127 m
.67884 .64947 L
s
.66519 .64333 m
.66859 .64578 L
s
.66426 .64053 m
.66519 .64333 L
s
.6648 .63826 m
.66426 .64053 L
s
.66206 .62608 m
.64796 .63834 L
s
.66636 .63512 m
.6648 .63826 L
s
.67143 .63074 m
.66636 .63512 L
s
.65599 .63136 m
.65754 .62818 L
s
.70028 .63127 m
.68997 .62749 L
s
.67597 .62865 m
.67143 .63074 L
s
.62513 .62887 m
.62115 .62867 L
s
.63012 .6282 m
.62513 .62887 L
s
.62115 .62867 m
.61665 .62705 L
s
.67949 .62743 m
.67597 .62865 L
s
.63461 .62609 m
.63012 .6282 L
s
.65754 .62818 m
.65658 .62533 L
s
.68997 .62749 m
.6845 .62675 L
s
.6845 .62675 m
.67949 .62743 L
s
.61665 .62705 m
.61463 .62508 L
s
.63661 .62433 m
.63461 .62609 L
s
.65658 .62533 m
.65461 .62336 L
s
.61463 .62508 m
.6136 .62223 L
s
.62457 .61242 m
.61063 .62488 L
s
.63812 .62112 m
.63661 .62433 L
s
.65461 .62336 m
.65013 .62173 L
s
.63713 .61825 m
.63812 .62112 L
s
.60177 .60411 m
.59401 .61889 L
s
.61396 .60855 m
.59401 .61889 L
s
.63513 .61626 m
.63713 .61825 L
s
.63061 .61462 m
.63513 .61626 L
s
.62156 .6151 m
.62659 .61441 L
s
.62659 .61441 m
.63061 .61462 L
s
.58951 .59964 m
.58184 .6145 L
s
.60177 .60411 m
.58184 .6145 L
s
.56136 .60587 m
.55731 .60566 L
s
.56639 .60517 m
.56136 .60587 L
s
.55731 .60566 m
.55114 .60343 L
s
.56988 .60391 m
.56639 .60517 L
s
.57436 .60175 m
.56988 .60391 L
s
.55114 .60343 m
.54901 .60141 L
s
.57929 .59719 m
.57436 .60175 L
s
.54901 .60141 m
.54785 .59847 L
s
.54785 .59847 m
.54824 .59608 L
s
.54765 .58439 m
.53407 .59728 L
s
.58071 .59388 m
.57929 .59719 L
s
.55892 .59614 m
.55115 .59333 L
s
.54824 .59608 m
.55115 .59333 L
s
.58115 .59148 m
.58071 .59388 L
s
.58003 .5885 m
.58115 .59148 L
s
.5418 .58994 m
.54316 .5866 L
s
.57793 .58644 m
.58003 .5885 L
s
.50997 .58733 m
.50587 .58711 L
s
.51504 .58661 m
.50997 .58733 L
s
.50587 .58711 m
.50114 .58541 L
s
.51949 .5844 m
.51504 .58661 L
s
.54316 .5866 m
.54198 .5836 L
s
.57171 .58416 m
.57793 .58644 L
s
.55898 .58595 m
.56251 .58466 L
s
.49702 .56594 m
.47711 .58563 L
s
.50114 .58541 m
.49892 .58334 L
s
.56251 .58466 m
.5676 .58395 L
s
.52141 .58254 m
.51949 .5844 L
s
.5676 .58395 m
.57171 .58416 L
s
.54198 .5836 m
.53981 .58153 L
s
.49892 .58334 m
.49766 .58033 L
s
.50819 .57001 m
.49481 .58313 L
s
.52273 .57917 m
.52141 .58254 L
s
.53981 .58153 m
.5351 .57981 L
s
.52151 .57615 m
.52273 .57917 L
s
.48145 .57704 m
.48653 .57631 L
s
.47732 .57682 m
.48145 .57704 L
s
.47252 .57509 m
.47732 .57682 L
s
.51931 .57406 m
.52151 .57615 L
s
.47026 .573 m
.47252 .57509 L
s
.51455 .57232 m
.51931 .57406 L
s
.46894 .56995 m
.47026 .573 L
s
.50531 .57284 m
.51041 .57211 L
s
.51041 .57211 m
.51455 .57232 L
s
.47016 .56653 m
.46894 .56995 L
s
.49415 .56878 m
.49286 .56572 L
s
.47147 .54743 m
.45164 .56756 L
s
.47205 .56464 m
.47016 .56653 L
s
.49286 .56572 m
.49062 .5636 L
s
.4765 .56236 m
.47205 .56464 L
s
.49062 .5636 m
.4858 .56185 L
s
.48163 .56163 m
.4765 .56236 L
s
.4858 .56185 m
.48163 .56163 L
s
.44314 .55154 m
.43382 .56114 L
s
.46102 .55804 m
.45899 .55339 L
s
.43378 .54289 m
.42077 .55644 L
s
.45899 .55339 m
.45668 .55124 L
s
.44759 .54923 m
.44314 .55154 L
s
.45668 .55124 m
.45179 .54945 L
s
.40528 .54955 m
.40107 .54933 L
s
.41041 .54881 m
.40528 .54955 L
s
.45179 .54945 m
.44759 .54923 L
s
.40107 .54933 m
.39612 .54755 L
s
.41482 .54649 m
.41041 .54881 L
s
.39612 .54755 m
.39372 .54538 L
s
.41667 .54455 m
.41482 .54649 L
s
.39372 .54538 m
.39223 .54224 L
s
.4178 .54102 m
.41667 .54455 L
s
.41636 .53786 m
.4178 .54102 L
s
.37877 .53999 m
.38226 .53863 L
s
.37287 .53917 m
.37877 .53999 L
s
.36786 .53736 m
.37287 .53917 L
s
.41397 .53567 m
.41636 .53786 L
s
.36373 .53456 m
.36786 .53736 L
s
.43942 .53702 m
.43872 .53543 L
s
.44201 .53664 m
.43942 .53702 L
s
.44131 .53505 m
.44201 .53664 L
s
.409 .53386 m
.41397 .53567 L
s
.43872 .53543 m
.44131 .53505 L
s
.36386 .53199 m
.36373 .53456 L
s
.39957 .53439 m
.40474 .53363 L
s
.40474 .53363 m
.409 .53386 L
s
.38606 .53213 m
.3818 .5319 L
s
.38957 .53076 m
.38606 .53213 L
s
.36476 .531 m
.36386 .53199 L
s
.3818 .5319 m
.37252 .52985 L
s
.36825 .52963 m
.36476 .531 L
s
.38973 .52817 m
.38957 .53076 L
s
.3477 .53009 m
.34691 .52849 L
s
.35028 .52971 m
.3477 .53009 L
s
.37252 .52985 m
.36825 .52963 L
s
.34949 .52811 m
.35028 .52971 L
s
.34691 .52849 m
.34949 .52811 L
s
.38562 .52534 m
.38973 .52817 L
s
.38058 .5235 m
.38562 .52534 L
s
.37111 .52405 m
.37462 .52266 L
s
.37462 .52266 m
.38058 .5235 L
s
.36671 .50905 m
.35399 .52314 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo0680oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0H03oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00D000000?ooo`3oool0oooo0000o`1P0?ooo`<000006`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0003o05h0oooo0`00000N0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000?l0
oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`0000001@3oool30000odl0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`020000o`<0oooo0P000?m:0?ooo`<00000:03o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000K`3oool2
0000o`D0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`140?ooo`<00000:`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`00
0000oooo0?ooo`1^0?ooo`80003o103oool80000o`80oooo00<0003o0?ooo`3oool0@@3oool30000
02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000
oooo0000000P0?ooo`030000003oool0oooo07@0oooo00@0003o0?ooo`3oool00000103oool20000
o`@0oooo10000?li0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0M@3oool20000o`03
0?ooo`000000oooo00`0oooo0P000?l80?ooo`<0003o:@3oool3000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
M`3oool50000o``0oooo00<0003o0?ooo`3oool0;P3oool3000003L0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool08@3oool3000003d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool0403oool300000400oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080
oooo1P000?l50?ooo`030000o`3oool0oooo00@0oooo0P000?l60?ooo`030000o`3oool0oooo00h0
oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo
0P000?l20?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0<0?ooo`<00000AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?oo
o`090?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000
o`0<0?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool3000004`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`@00000D03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`80
00001P000?m?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0@0?ooo`040000o`3oool0oooo0?ooo`80
00000`000?l60?ooo`80003oC@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo
0000000200000080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1<0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`0<0?ooo`<000001@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo0P000?m80?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000203oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0P000?l00`3oool0003o0000o`02
0000od@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000<0?ooo`H0003o1@3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
0000503oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3o
ool0oooo0000o`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0S03oool2000001H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0P000?lm0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo01@0oooo
00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l60?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`000?l01@3oool40000oc00oooo0P00001K0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`070?ooo`H0003o203oool20000o`@0oooo0P000?l40?ooo`80003o:`3oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0T0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:P3oool010000?l0oooo0?ooo`3o
ool20000o`X0oooo00<0003o0?ooo`3oool0803oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02T0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003o1`3oool00`000?l0oooo0?oo
o`0N0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool06`3oool300000180oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01@0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`80
003o1@3oool30000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`@0
00006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0<03oool50000o`L0oooo00<0003o0?ooo`3oool0
0P000?l<0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool01P000?l0oooo0000
o`000?l0oooo0000o`D0oooo00@0003o0?ooo`3oool0oooo0`00000R0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0k0?ooo`80003o0P3oool00`000?l0oooo0?ooo`020?ooo`80003o00@0oooo00000000
000000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`80
0000S`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00P000?l3000000<0oooo0`000?lT0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0n0?ooo`030000
o`3oool0000000<000001@3oool20000o`80oooo0P000?lS0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0n0?ooo`<000001`3oool20000o`D0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0>`3oool3000000T0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3o
ool0003o01l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000;0?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`030?ooo`<0003o7@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool30000
0100oooo00<0003o0?ooo`3oool00P3oool30000o`L0oooo00<0003o0?ooo`000?l01@3oool50000
oa80oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000000D0?ooo`@0003o2P3oool20000o`<0
oooo0`000?l50?ooo`80003o4@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000002D0oooo
0P000?l30?ooo`030000o`3oool0oooo00P0oooo0P000?l@0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0[0?ooo`<000009`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000002T0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`80003o4`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?oo
o`<00000<P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01@0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool08@3oool4000003D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<00000>P3oool20000o`<0oooo0P000?lJ0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000003l0oooo0`000?lL0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3
000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool20000
0940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<0
00003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700
oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<0
0000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool0
01d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580
oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<0
0000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0
oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W
0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<0
0000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool0
0`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0
oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`000027
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?oo
o`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<00000
0?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;
0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003o
ool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool0
0`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool0
03/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo
00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000
J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`00
0000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P00
00000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`00
0000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@0
00000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?oo
o`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo10000003
0?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?oo
o`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000
003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003o
ool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<0
00000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P000000
0`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
0680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo
0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W
0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo10000009
0?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`80
0000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0
oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo
0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0
oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo
001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e
0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?oo
o`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`80
0000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00
J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@0
0000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000
503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool0
0`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool0
0`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740
oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k
0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?oo
o`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00
T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003o
ool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool0
0`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440
oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0
oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo
1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00
002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`
0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`03
0000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00
I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3o
ool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo
00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?oo
o`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@0
0000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.64229 .66114 m
.65084 .6659 L
s
.67767 .65076 m
.65084 .6659 L
s
.63988 .65836 m
.64229 .66114 L
s
.63995 .65555 m
.63988 .65836 L
s
.64126 .65341 m
.63995 .65555 L
s
.64384 .65054 m
.64126 .65341 L
s
.64285 .64127 m
.62503 .65151 L
s
.67767 .65076 m
.66911 .6459 L
s
.65023 .64689 m
.64384 .65054 L
s
.65531 .64539 m
.65023 .64689 L
s
.66911 .6459 m
.66414 .64455 L
s
.63519 .64568 m
.63778 .64278 L
s
.65911 .64462 m
.65531 .64539 L
s
.66414 .64455 m
.65911 .64462 L
s
.63778 .64278 m
.63785 .6399 L
s
.63785 .6399 m
.63664 .63776 L
s
.60632 .63964 m
.60253 .63897 L
s
.61136 .63956 m
.60632 .63964 L
s
.61643 .63805 m
.61136 .63956 L
s
.60253 .63897 m
.59875 .63686 L
s
.61897 .63657 m
.61643 .63805 L
s
.63664 .63776 m
.6329 .63565 L
s
.59875 .63686 m
.59748 .63471 L
s
.62154 .63364 m
.61897 .63657 L
s
.59748 .63471 m
.59749 .63181 L
s
.6115 .62357 m
.59369 .63404 L
s
.62159 .63073 m
.62154 .63364 L
s
.62035 .62856 m
.62159 .63073 L
s
.61657 .62643 m
.62035 .62856 L
s
.61276 .62575 m
.61657 .62643 L
s
.59236 .61276 m
.57968 .62623 L
s
.6026 .61854 m
.57968 .62623 L
s
.60767 .62582 m
.61276 .62575 L
s
.58204 .60694 m
.5694 .6205 L
s
.59236 .61276 m
.5694 .6205 L
s
.55251 .60961 m
.54863 .60892 L
s
.55765 .60954 m
.55251 .60961 L
s
.56149 .60874 m
.55765 .60954 L
s
.54863 .60892 m
.54339 .606 L
s
.5666 .60716 m
.56149 .60874 L
s
.57298 .60331 m
.5666 .60716 L
s
.54339 .606 m
.54203 .60377 L
s
.54203 .60377 m
.54193 .60075 L
s
.57552 .60026 m
.57298 .60331 L
s
.54193 .60075 m
.54315 .59847 L
s
.57678 .59797 m
.57552 .60026 L
s
.55353 .59983 m
.54696 .59613 L
s
.54315 .59847 m
.54696 .59613 L
s
.57674 .59493 m
.57678 .59797 L
s
.54668 .58697 m
.52889 .59792 L
s
.57542 .59267 m
.57674 .59493 L
s
.57017 .58969 m
.57542 .59267 L
s
.53903 .59168 m
.54152 .58858 L
s
.55717 .58988 m
.56106 .58906 L
s
.56626 .58898 m
.57017 .58969 L
s
.56106 .58906 m
.56626 .58898 L
s
.54152 .58858 m
.54142 .58551 L
s
.54142 .58551 m
.54003 .58322 L
s
.5088 .58523 m
.50485 .58452 L
s
.51401 .58515 m
.5088 .58523 L
s
.51916 .58353 m
.51401 .58515 L
s
.50485 .58452 m
.5008 .58226 L
s
.5217 .58195 m
.51916 .58353 L
s
.54003 .58322 m
.53603 .58096 L
s
.5008 .58226 m
.49936 .57996 L
s
.52417 .57881 m
.5217 .58195 L
s
.49936 .57996 m
.49918 .57686 L
s
.50364 .56267 m
.47709 .57952 L
s
.51316 .56805 m
.49539 .57924 L
s
.52404 .57571 m
.52417 .57881 L
s
.52262 .57339 m
.52404 .57571 L
s
.51857 .5711 m
.52262 .57339 L
s
.48441 .57162 m
.48966 .57154 L
s
.48041 .57089 m
.48441 .57162 L
s
.51459 .57038 m
.51857 .5711 L
s
.4763 .5686 m
.48041 .57089 L
s
.50933 .57046 m
.51459 .57038 L
s
.47481 .56626 m
.4763 .5686 L
s
.47458 .56311 m
.47481 .56626 L
s
.49981 .5651 m
.49963 .56194 L
s
.477 .5599 m
.47458 .56311 L
s
.49963 .56194 m
.49817 .55958 L
s
.47953 .55828 m
.477 .5599 L
s
.49817 .55958 m
.49405 .55726 L
s
.48505 .54132 m
.45835 .5586 L
s
.48472 .5566 m
.47953 .55828 L
s
.49405 .55726 m
.49003 .55652 L
s
.49003 .55652 m
.48472 .5566 L
s
.471 .55041 m
.47064 .54559 L
s
.45563 .54177 m
.443 .55004 L
s
.47064 .54559 m
.46912 .54319 L
s
.44944 .53208 m
.43173 .54376 L
s
.46912 .54319 m
.46493 .54082 L
s
.46085 .54007 m
.45563 .54177 L
s
.46493 .54082 m
.46085 .54007 L
s
.41879 .535 m
.41468 .53425 L
s
.42416 .53492 m
.41879 .535 L
s
.42936 .5332 m
.42416 .53492 L
s
.41468 .53425 m
.41039 .53186 L
s
.43189 .53152 m
.42936 .5332 L
s
.41039 .53186 m
.40877 .52941 L
s
.43427 .5282 m
.43189 .53152 L
s
.40877 .52941 m
.40841 .52612 L
s
.43396 .5249 m
.43427 .5282 L
s
.45711 .52702 m
.45697 .52537 L
s
.4598 .52698 m
.45711 .52702 L
s
.45967 .52533 m
.4598 .52698 L
s
.45697 .52537 m
.45967 .52533 L
s
.43237 .52244 m
.43396 .5249 L
s
.42807 .52001 m
.43237 .52244 L
s
.39579 .52217 m
.39975 .52128 L
s
.39019 .5206 m
.39579 .52217 L
s
.38583 .51816 m
.39019 .5206 L
s
.42393 .51924 m
.42807 .52001 L
s
.41851 .51933 m
.42393 .51924 L
s
.38271 .51487 m
.38583 .51816 L
s
.40587 .51535 m
.40171 .51457 L
s
.40985 .51445 m
.40587 .51535 L
s
.38375 .51234 m
.38271 .51487 L
s
.40171 .51457 m
.39317 .51135 L
s
.41094 .51191 m
.40985 .51445 L
s
.38501 .51148 m
.38375 .51234 L
s
.40785 .5086 m
.41094 .51191 L
s
.38899 .51057 m
.38501 .51148 L
s
.39317 .51135 m
.38899 .51057 L
s
.40349 .50613 m
.40785 .5086 L
s
.36826 .50837 m
.36803 .50668 L
s
.37098 .50833 m
.36826 .50837 L
s
.37076 .50664 m
.37098 .50833 L
s
.36803 .50668 m
.37076 .50664 L
s
.39784 .50452 m
.40349 .50613 L
s
.39384 .50543 m
.39784 .50452 L
s
.3948 .49005 m
.37704 .5023 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo06d0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool04P3oool20000ofd0
oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
00<000000?ooo`000000J03oool00`000000oooo0?ooo`0?0?ooo`80003oK03oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool03@3oool20000of/0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo06P0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`1M0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`060?ooo`80003o203oool010000?l0oooo0000o`000?mJ
0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`05
0?ooo`80003o1P3oool00`000?l0oooo0?ooo`030?ooo`80003oE@3oool3000001@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02P3oool20000o`030?ooo`000?l0
003o00D0oooo00<0003o0?ooo`3oool0C`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`H0003oCP3oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo
0580oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo0?oo
o`000?l01P3oool40000od40oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`090?ooo`<0
003o2`3oool20000oc`0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20000obl0oooo0`00000X0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003o
ool0oooo00d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`80003o;03o
ool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0<0?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`0a0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0X0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0=0?ooo`D0003o1@3oool20000obP0oooo0`00000d0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0U0?ooo`<00000=`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool04P3oool20000o`H0oooo10000?l70?ooo`030000o`3oool0oooo0140oooo0`00
000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo0P000?l4
0?ooo`80003o0`3oool20000oa40oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0D0?oo
o`80003o1`3oool010000?l0oooo0000o`000?l@0?ooo`<00000@03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`070?ooo`80003o3`3oool3000004<0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`03
0000003oool0oooo01X0oooo0P000?l=0?ooo`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0G0?ooo`80003o
303oool3000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3o
ool60000o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01/0oooo00<0003o
0000000000000P0000020?ooo`80003oC03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool00`00
0000003o000000070?ooo`030000o`3oool0003o04X0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0
oooo0`0000000`3oool0003o0?ooo`070?ooo`80003oB`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000000@0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo00<0003o0?ooo`3oool0
A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08L0oooo00<000000?ooo`3oool0303oool3000000P0oooo1P000?l50?ooo`D0003oA@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0203oool3000000h0oooo0P000?l50?ooo`030000o`3oool0
oooo00<0oooo0P000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000003`3oool20000
o`D0oooo0P000?l70?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
00004@3oool00`000?l0oooo0?ooo`040?ooo`80003o203oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
S03oool2000001d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool07@3oool60000o`L0oooo0P000?lk0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02/0oooo00<0003o0?ooo`000?l0=P3oool300000080oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02/0oooo0P000?l40?ooo`D0003o:P3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0
oooo0P000?l;0?ooo`80003o9@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo
0P000?l40?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool07`3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`00
0?l0oooo00P0oooo00<0003o0?ooo`3oool0703oool300000180oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02/0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo01X0oooo0`00
000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool05P3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo00<0003o0?oo
o`3oool01`3oool20000o`<0oooo00<0003o0?ooo`3oool0403oool3000001h0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02`0oooo2@000?l40?ooo`030000o`3oool0oooo00h0oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo00`0oooo0`00000V0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003o
ool0oooo03L0oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo0`00000Z0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo00@0003o0P3oool4000002h0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03L0oooo10000?l20?ooo`050000o`00000000000000003oool00P000?l`
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0f0?ooo`80003o0`3oool3000000040?ooo`000?l0003o
0000oc80oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`0000040000o`L0oooo00<0003o0?oo
o`3oool0;03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool300000080oooo0P000?l80?ooo`80
003o00<0oooo0000o`000?l0;@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool4000000d0oooo
0P000?l50?ooo`80003o;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000l0oooo0P00
0?l80?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00000A
0?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0W
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000005P3oool30000o`@0oooo0P000?l50?oo
o`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000001`0oooo10000?l80?ooo`03
0000o`3oool0003o02L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`00
8@3oool200000900oooo00<000000?ooo`3oool08@3oool4000002/0oooo0P000?l80?ooo`030000
o`3oool0oooo01h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000]0?ooo`80003o103o
ool60000o`030?ooo`000?l0oooo01l0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K
0?ooo`<00000;P3oool20000o`D0oooo00<0003o0?ooo`3oool01P3oool20000oah0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000300oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`80003o7@3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000>@3oool00`000?l0oooo0?ooo`090?oo
o`80003o7`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000l0?ooo`03
0000o`3oool0oooo00L0oooo0P000?lR0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00h0oooo0`0000100?ooo`030000o`3oool0oooo00D0oooo0P000?lU0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool02`3oool3000004<0oooo0P000?l40?ooo`80003o9`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0203oool3000004P0oooo10000?lZ0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@0
0000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000
T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4
000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h
0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<00000
7P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4
000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J
0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`03
0000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000
?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo
09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo
00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l
0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?oo
o`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000
GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`00
0000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M
0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?oo
o`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`03
0000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000
O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo
0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0
oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo
0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?oo
o`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool20000
08@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00
001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`80
0000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?oo
o`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`80
0000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003o
ool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool0
1@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0012
0?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3o
ool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo
0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3o
ool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0
oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3o
ool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool20000
00l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0
oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040
oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?oo
o`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F
0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0
oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000
003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`80
0000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3o
ool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool20000
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0
oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo
00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?oo
o`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D0
00008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool20000
03L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0
oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo
00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@0
00000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo
001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00
000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?oo
o`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?oo
o`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3o
ool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000
JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3o
ool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool5
00000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4
000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00
000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I
0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?oo
o`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000
VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000
WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3o
ool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool0
06D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0
oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo
0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@0
00000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo
1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`04
0?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?oo
o`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@0
0000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo
00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo
002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo
1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61164 .673 m
.61823 .67862 L
s
.64927 .66702 m
.61823 .67862 L
s
.61028 .67003 m
.61164 .673 L
s
.61133 .6673 m
.61028 .67003 L
s
.61334 .66537 m
.61133 .6673 L
s
.64927 .66702 m
.64275 .66132 L
s
.61683 .66288 m
.61334 .66537 L
s
.62425 .66008 m
.61683 .66288 L
s
.6191 .65376 m
.59833 .66165 L
s
.64275 .66132 m
.63844 .65942 L
s
.62966 .65921 m
.62425 .66008 L
s
.63844 .65942 m
.63358 .65891 L
s
.63358 .65891 m
.62966 .65921 L
s
.61017 .65715 m
.61368 .65464 L
s
.61368 .65464 m
.61475 .65185 L
s
.61475 .65185 m
.61433 .64963 L
s
.61433 .64963 m
.61145 .64713 L
s
.58927 .64842 m
.58436 .6479 L
s
.5947 .64754 m
.58927 .64842 L
s
.58436 .6479 m
.58092 .6468 L
s
.59768 .6464 m
.5947 .64754 L
s
.58092 .6468 m
.57799 .6443 L
s
.60119 .64385 m
.59768 .6464 L
s
.57799 .6443 m
.57752 .64206 L
s
.60224 .64103 m
.60119 .64385 L
s
.57752 .64206 m
.57853 .63923 L
s
.6018 .63877 m
.60224 .64103 L
s
.59499 .63286 m
.57407 .64096 L
s
.59889 .63625 m
.6018 .63877 L
s
.59544 .63514 m
.59889 .63625 L
s
.59049 .63461 m
.59544 .63514 L
s
.58022 .62006 m
.56319 .63168 L
s
.58812 .62691 m
.56319 .63168 L
s
.57224 .61315 m
.5552 .62487 L
s
.58022 .62006 m
.5552 .62487 L
s
.5476 .61275 m
.54256 .61221 L
s
.55162 .61243 m
.5476 .61275 L
s
.55715 .61151 m
.55162 .61243 L
s
.54256 .61221 m
.53902 .61106 L
s
.5647 .60852 m
.55715 .61151 L
s
.53902 .61106 m
.53493 .60758 L
s
.56824 .60585 m
.5647 .60852 L
s
.53493 .60758 m
.53439 .60523 L
s
.57027 .60377 m
.56824 .60585 L
s
.53439 .60523 m
.53535 .60227 L
s
.5713 .60081 m
.57027 .60377 L
s
.547 .60277 m
.54188 .59836 L
s
.53535 .60227 m
.53734 .60018 L
s
.5708 .59844 m
.5713 .60081 L
s
.53734 .60018 m
.54188 .59836 L
s
.56675 .5949 m
.5708 .59844 L
s
.54482 .58938 m
.5236 .59791 L
s
.56319 .59373 m
.56675 .5949 L
s
.5581 .59317 m
.56319 .59373 L
s
.55403 .5935 m
.5581 .59317 L
s
.5357 .59305 m
.53922 .59032 L
s
.53922 .59032 m
.5402 .58731 L
s
.5402 .58731 m
.53966 .5849 L
s
.53966 .5849 m
.53654 .5822 L
s
.51353 .58359 m
.50839 .58303 L
s
.51914 .58264 m
.51353 .58359 L
s
.50839 .58303 m
.50476 .58184 L
s
.52218 .5814 m
.51914 .58264 L
s
.50476 .58184 m
.50159 .57914 L
s
.5257 .57864 m
.52218 .5814 L
s
.50159 .57914 m
.50098 .5767 L
s
.52666 .57559 m
.5257 .57864 L
s
.50098 .5767 m
.5019 .57364 L
s
.5261 .57314 m
.52666 .57559 L
s
.51871 .56675 m
.49734 .57551 L
s
.51127 .5603 m
.47923 .57351 L
s
.52294 .57041 m
.5261 .57314 L
s
.5193 .56921 m
.52294 .57041 L
s
.51411 .56863 m
.5193 .56921 L
s
.48923 .56667 m
.49443 .56724 L
s
.48556 .56546 m
.48923 .56667 L
s
.48232 .5627 m
.48556 .56546 L
s
.48168 .56022 m
.48232 .5627 L
s
.50667 .5622 m
.5076 .55908 L
s
.48257 .55709 m
.48168 .56022 L
s
.5076 .55908 m
.507 .55659 L
s
.48608 .55425 m
.48257 .55709 L
s
.507 .55659 m
.50378 .5538 L
s
.48915 .55297 m
.48608 .55425 L
s
.50378 .5538 m
.50008 .55257 L
s
.49485 .55199 m
.48915 .55297 L
s
.50008 .55257 m
.49485 .55199 L
s
.50056 .53705 m
.46816 .55063 L
s
.48353 .54419 m
.48488 .53941 L
s
.47144 .53376 m
.45603 .54027 L
s
.48488 .53941 m
.48423 .53686 L
s
.48423 .53686 m
.48094 .534 L
s
.48094 .534 m
.47719 .53275 L
s
.47719 .53275 m
.47144 .53376 L
s
.46876 .52344 m
.44711 .53267 L
s
.44274 .523 m
.43739 .5224 L
s
.44851 .52198 m
.44274 .523 L
s
.43739 .5224 m
.43358 .52113 L
s
.45161 .52065 m
.44851 .52198 L
s
.43358 .52113 m
.43017 .51822 L
s
.45514 .51769 m
.45161 .52065 L
s
.48124 .51813 m
.48079 .51977 L
s
.48079 .51977 m
.47811 .51946 L
s
.47811 .51946 m
.47857 .51783 L
s
.43017 .51822 m
.42943 .5156 L
s
.47857 .51783 m
.48124 .51813 L
s
.456 .5144 m
.45514 .51769 L
s
.42943 .5156 m
.43024 .51231 L
s
.4553 .51178 m
.456 .5144 L
s
.45191 .50884 m
.4553 .51178 L
s
.44808 .50755 m
.45191 .50884 L
s
.44269 .50693 m
.44808 .50755 L
s
.41911 .50679 m
.42336 .50642 L
s
.41409 .50451 m
.41911 .50679 L
s
.41062 .50154 m
.41409 .50451 L
s
.40868 .49788 m
.41062 .50154 L
s
.43155 .50137 m
.42769 .50007 L
s
.43583 .501 m
.43155 .50137 L
s
.43781 .49865 m
.43583 .501 L
s
.42769 .50007 m
.42035 .49578 L
s
.43593 .49498 m
.43781 .49865 L
s
.41063 .49552 m
.40868 .49788 L
s
.42035 .49578 m
.41647 .49447 L
s
.41219 .49484 m
.41063 .49552 L
s
.43247 .49198 m
.43593 .49498 L
s
.41647 .49447 m
.41219 .49484 L
s
.42743 .48966 m
.43247 .49198 L
s
.42313 .49004 m
.42743 .48966 L
s
.39932 .48989 m
.39659 .48958 L
s
.39971 .4882 m
.39932 .48989 L
s
.39659 .48958 m
.39697 .48788 L
s
.39697 .48788 m
.39971 .4882 L
s
.42957 .475 m
.40752 .48475 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`1R0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool09@3oool20000ofD0
oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0R0?ooo`80003oI`3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo01l0oooo0P000?mY0?ooo`030000003oool0oooo00@0oooo0`00
001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0703oool20000of/0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool05`3oool2
0000ofl0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool05P3oool20000o`P0oooo0P000?mS0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01`0
oooo00<0003o0?ooo`3oool00P3oool20000oeh0oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`0I0?ooo`80003o00<0oooo0000o`000?l0103oool00`000?l0oooo0?ooo`1H0?ooo`<00000
1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3o
ool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1D0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`030?ooo`@0003oE03oool3000000/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo05L0oooo0`00000>0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo01P0oooo10000?l60?ooo`<0003oB@3oool30000
0140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0903oool00`00
0?l0oooo0?ooo`130?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00H0oooo0P000?m00?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0>`3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20000oc40
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0I0?ooo`80003o1@3oool20000o`P0oooo
0P000?l]0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06P3oool50000o`L0oooo00<0
003o0?ooo`3oool0;03oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo02<0oooo0P000?l/
0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`800000MP3oool00`000000oooo0?ooo`0P0?ooo`80003o:`3oool3000002/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0M0?ooo`80003o:P3oool3000002h0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool06P3oool20000o`L0oooo10000?lN0?ooo`<00000
<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003o
ool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0P0?ooo`80003o103o
ool00`000?l0oooo0?ooo`030?ooo`80003o4`3oool3000003@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0M0?ooo`80003o1`3oool00`000?l0oooo0?ooo`020000oa80oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0J0?ooo`80003o203oool40000oa40oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0Q0?ooo`<0003o4@3oool3000003d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo01h0oooo0P000?lA0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool06`3o
ool20000oa00oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0R0?ooo`D0003o0P3oool3
000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool30000
0840oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`03000000000?l0003o
04T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00`0000030?ooo`03
0000o`3oool0oooo04H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo00@0003o000000000000
00001P3oool30000odL0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000000`3oool0003o
0?ooo`060?ooo`80003oB@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000D0oooo0P00
0?l30?ooo`80003o1@3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<000002P3oool30000o`D0oooo0`000?m50?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?oo
o`<000002`3oool20000o`H0oooo0P000?l30?ooo`80003o@`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0203oool3000000`0oooo0P000?l60?ooo`80003o1`3oool00`000?l0oooo0?ooo`100?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`040?ooo`<000005@3oool30000o`P0oooo00<0003o0?ooo`3oool0
@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000J0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08`0oooo0P00000N0?ooo`030000o`3oool0oooo0080oooo0`000?l4
0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool07P3oool40000o`P0oooo00<0003o0?oo
o`3oool0>P3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo03L0oooo0`0000020?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0Z0?ooo`<0003o<`3oool4000000H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02T0oooo0P000?l40?ooo`<0003o:`3oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02H0oooo0`000?l90?ooo`<0003o9@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02@0oooo0P000?l50?ooo`030000o`3oool0oooo00L0oooo0P000?lP0?ooo`<000004P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:@3oool20000o`030?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3o
ool06`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01L0oooo1000000J0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool05@3o
ool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0203oool2
0000oaD0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`<0003o1@3oool20000
oa@0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0
oooo0P00002?0?ooo`030000003oool0oooo02`0oooo1@000?l50?ooo`030000o`3oool0oooo00/0
oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0d0?ooo`80003o2P3oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03@0oooo00@0003o0?ooo`3oool0oooo0`000?l30?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0<P3oool60000o`030?ooo`000?l0oooo00<00000=P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0<@3oool30000o`@0oooo0`00000j0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0e0?ooo`<000000`3oool30000ocP0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340
oooo100000000`000?l0oooo0000o`030000oc`0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo
0`0000030?ooo`<0003o203oool20000ocL0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00
000?0?ooo`D0003o=P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000l0oooo0`000?l5
0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000100oooo0`000?l70?oo
o`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?oo
o`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000001@0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000
6@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
<`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000M0?ooo`H0003o1P3o
ool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3o
ool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01P0oooo0`00000/0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool05@3oool3000002l0oooo0`000?ld0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool04@3oool400000300oooo0`000?lg0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000b0?ooo`<0003o103oool70000obl0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000<`3oool20000o`D0oooo
0P000?l70?ooo`80003o;@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000003`0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`04
0?ooo`@00000?P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o;@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?oo
o`3oool0oooo0`0000110?ooo`030000o`3oool0oooo00P0oooo0`000?l`0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000A@3oool00`00
0?l0oooo0?ooo`040?ooo`<0003o=03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`800000T03oool3000004T0oooo00<0003o0?ooo`3oool00`000?lg0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool0B03oool20000oc/0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.57787 .68102 m
.58229 .68725 L
s
.61632 .67952 m
.58229 .68725 L
s
.57758 .67797 m
.57787 .68102 L
s
.61632 .67952 m
.61202 .67323 L
s
.57956 .67543 m
.57758 .67797 L
s
.58217 .67378 m
.57956 .67543 L
s
.58643 .67176 m
.58217 .67378 L
s
.61202 .67323 m
.60853 .6709 L
s
.59458 .66989 m
.58643 .67176 L
s
.60853 .6709 m
.60401 .66983 L
s
.60012 .66967 m
.59458 .66989 L
s
.60401 .66983 m
.60012 .66967 L
s
.5918 .66315 m
.56892 .66841 L
s
.58198 .66541 m
.58625 .66336 L
s
.58625 .66336 m
.58826 .66078 L
s
.58826 .66078 m
.58863 .65856 L
s
.58863 .65856 m
.58672 .6558 L
s
.56475 .65446 m
.56016 .65337 L
s
.57033 .65423 m
.56475 .65446 L
s
.57362 .65347 m
.57033 .65423 L
s
.57792 .6514 m
.57362 .65347 L
s
.56016 .65337 m
.5572 .6519 L
s
.5572 .6519 m
.55523 .64911 L
s
.57993 .64877 m
.57792 .6514 L
s
.55523 .64911 m
.55555 .64687 L
s
.58029 .64652 m
.57993 .64877 L
s
.55555 .64687 m
.55753 .64423 L
s
.57834 .64372 m
.58029 .64652 L
s
.57574 .63996 m
.55258 .64539 L
s
.57539 .64223 m
.57834 .64372 L
s
.57077 .64113 m
.57539 .64223 L
s
.56588 .62573 m
.54524 .63504 L
s
.57116 .63335 m
.54524 .63504 L
s
.56055 .61803 m
.53984 .62743 L
s
.56588 .62573 m
.53984 .62743 L
s
.54071 .61485 m
.53667 .61468 L
s
.54642 .61462 m
.54071 .61485 L
s
.53667 .61468 m
.53194 .61354 L
s
.55483 .61261 m
.54642 .61462 L
s
.53194 .61354 m
.52889 .612 L
s
.55921 .61043 m
.55483 .61261 L
s
.52889 .612 m
.52611 .60809 L
s
.56191 .60864 m
.55921 .61043 L
s
.56395 .60588 m
.56191 .60864 L
s
.52611 .60809 m
.52641 .60573 L
s
.5643 .60351 m
.56395 .60588 L
s
.52641 .60573 m
.52839 .60295 L
s
.53959 .60485 m
.53614 .59993 L
s
.5616 .59956 m
.5643 .60351 L
s
.52839 .60295 m
.53107 .60115 L
s
.53107 .60115 m
.53614 .59993 L
s
.55854 .59799 m
.5616 .59956 L
s
.55378 .59683 m
.55854 .59799 L
s
.54217 .5915 m
.51843 .59726 L
s
.5497 .59665 m
.55378 .59683 L
s
.53197 .59397 m
.53637 .59174 L
s
.53637 .59174 m
.53839 .58892 L
s
.53839 .58892 m
.5387 .5865 L
s
.5387 .5865 m
.53661 .58348 L
s
.5136 .58201 m
.50876 .58082 L
s
.51943 .58177 m
.5136 .58201 L
s
.52284 .58093 m
.51943 .58177 L
s
.52726 .57866 m
.52284 .58093 L
s
.50876 .58082 m
.50562 .57922 L
s
.50562 .57922 m
.50346 .57617 L
s
.52928 .57579 m
.52726 .57866 L
s
.50346 .57617 m
.50373 .57371 L
s
.52958 .57334 m
.52928 .57579 L
s
.50373 .57371 m
.50571 .57082 L
s
.52746 .57027 m
.52958 .57334 L
s
.52461 .56616 m
.50057 .57209 L
s
.52431 .56864 m
.52746 .57027 L
s
.51944 .56744 m
.52431 .56864 L
s
.5196 .55893 m
.48347 .56788 L
s
.49572 .56242 m
.50063 .56363 L
s
.49254 .56077 m
.49572 .56242 L
s
.49033 .55766 m
.49254 .56077 L
s
.51441 .56021 m
.51643 .55728 L
s
.49058 .55515 m
.49033 .55766 L
s
.51643 .55728 m
.51671 .55476 L
s
.49255 .5522 m
.49058 .55515 L
s
.51671 .55476 m
.51454 .55163 L
s
.49701 .54985 m
.49255 .5522 L
s
.51454 .55163 m
.51135 .54996 L
s
.51135 .54996 m
.50642 .54873 L
s
.50048 .54898 m
.49701 .54985 L
s
.50642 .54873 m
.50048 .54898 L
s
.51729 .53482 m
.48066 .54404 L
s
.49805 .53966 m
.50107 .53515 L
s
.50107 .53515 m
.50134 .53257 L
s
.50134 .53257 m
.49911 .52935 L
s
.48985 .5279 m
.47236 .53234 L
s
.49911 .52935 m
.49586 .52764 L
s
.49586 .52764 m
.48985 .5279 L
s
.49086 .51745 m
.46625 .52373 L
s
.50501 .51384 m
.50398 .51538 L
s
.50398 .51538 m
.50146 .51474 L
s
.50146 .51474 m
.50248 .5132 L
s
.50248 .5132 m
.50501 .51384 L
s
.46535 .51367 m
.46028 .51239 L
s
.47141 .51341 m
.46535 .51367 L
s
.47494 .51251 m
.47141 .51341 L
s
.47948 .51005 m
.47494 .51251 L
s
.46028 .51239 m
.45696 .51065 L
s
.45696 .51065 m
.45462 .50734 L
s
.48149 .50694 m
.47948 .51005 L
s
.45462 .50734 m
.45482 .50468 L
s
.48173 .50427 m
.48149 .50694 L
s
.45482 .50468 m
.4568 .50155 L
s
.47943 .50095 m
.48173 .50427 L
s
.47611 .49918 m
.47943 .50095 L
s
.471 .49787 m
.47611 .49918 L
s
.44773 .49467 m
.45208 .49486 L
s
.44357 .49177 m
.44773 .49467 L
s
.44118 .4884 m
.44357 .49177 L
s
.46632 .49116 m
.46197 .49097 L
s
.46912 .48911 m
.46632 .49116 L
s
.46197 .49097 m
.45861 .48918 L
s
.45861 .48918 m
.45287 .484 L
s
.46856 .48526 m
.46912 .48911 L
s
.44056 .48454 m
.44118 .4884 L
s
.4662 .48186 m
.46856 .48526 L
s
.44333 .48248 m
.44056 .48454 L
s
.45287 .484 m
.44949 .4822 L
s
.44512 .48201 m
.44333 .48248 L
s
.44949 .4822 m
.44512 .48201 L
s
.46204 .47892 m
.4662 .48186 L
s
.45766 .47872 m
.46204 .47892 L
s
.43411 .47545 m
.43151 .47477 L
s
.4351 .47383 m
.43411 .47545 L
s
.43151 .47477 m
.43249 .47316 L
s
.43249 .47316 m
.4351 .47383 L
s
.46936 .46479 m
.44408 .47146 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03X0oooo0P000?mE0?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0=P3oool30000oeL0oooo00<000000?ooo`3oool0
5`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003o
ool0oooo0340oooo10000?mJ0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0^0?ooo`80003oGP3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02T0oooo0P000?mR0?ooo`030000003oool0oooo
00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0300oooo
0`000?mH0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0:P3oool30000o`D0oooo0P00
0?mF0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0?ooo`3o
ool20000o`D0oooo00<0003o0?ooo`3oool0D`3oool010000000oooo0?ooo`3oool300000580oooo
00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1C0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool00`3oool40000oe@0oooo0`00001H
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1G0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3o
ool09`3oool20000oe@0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02l0oooo0`000?m80?ooo`<00000
203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`050?ooo`80003o@`3o
ool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0?P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo03/0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo02D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0h0?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0U0?ooo`80003o1@3oool2
0000o`P0oooo00<0003o0?ooo`3oool0;@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool09P3oool50000o`X0oooo0P000?l[0?ooo`<000006`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo02h0oooo0`000?l]0?ooo`<000007P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0:@3oool40000ob`0oooo1000000Q0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`0U0?ooo`<0003o;@3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00
000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f
0?ooo`030000003oool0oooo02/0oooo10000?lN0?ooo`<00000:`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo02H0oooo10000?l40?ooo`030000o`3oool0oooo01P0oooo0`00000^0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`00
0000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02<0oooo0P000?l90?ooo`03
0000o`3oool0oooo01@0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo02d0oooo00@0003o0?ooo`3oool0oooo0`000?l=0?ooo`<00000=03oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo02/0oooo1@000?l=0?ooo`<00000=`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool09P3oool50000o`h0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0R
0?ooo`<0003o403oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000100?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`0V0?ooo`L0003o0`0000130?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo0080oooo0`0000000`000?l0oooo0?ooo`130?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo0280oooo00<0003o0?ooo`3oool00`0000040?ooo`030000o`3oool0oooo0480oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0240oooo00<0003o0000000000001P3oool00`000?l0oooo0?ooo`13
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@0000000<0oooo0000o`3oool01P3oool30000
od@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000060?ooo`L0003oA`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0503oool3000000L0oooo1@000?l60?ooo`80003o@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0403oool3000000L0oooo0`000?l70?ooo`H0003o@`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0303oool300000140oooo0`000?l60?ooo`80003o@@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool3000001D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0o0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<00000603oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000006`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007`3oool70000od<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0k0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo00<0003o0?oo
o`3oool0=`3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3o
ool0<`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo0`000?la0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09@3oool40000oc40oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0R0?ooo`<0003o2@3oool40000obD0oooo0`00000B0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0W0?ooo`<0003o203oool00`000?l0oooo0?ooo`0O0?ooo`<000005P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?l90?ooo`030000o`3oool0oooo
01X0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0G0?ooo`<000007P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01D0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool04`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool09`3oool:0000oa<0oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0<P3oool20000o`X0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0`0?ooo`80003o
2@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo0`000?l00`3oool0003o0000
o`030000o`80oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`H0003o0P3oool2
0000o`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02h0oooo0`0000020?ooo`D0003o@03oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
:`3oool3000000D0003oA@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<00000
0?ooo`3oool09@3oool3000000l0oooo0`000?m00?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000=0?oo
o`D0003o00@0oooo0000o`000?l0003o@03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
00l0oooo0`000?l70?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0K0?ooo`<000004`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03l0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000001L0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000K0?ooo`H0003oA@3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo0140oooo1000000X0?ooo`030000o`3oool0oooo03l0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002`0oooo00<0003o
0?ooo`3oool0@03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?oo
o`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000_0?oo
o`<0003o@03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000002h0oooo10000?m40?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`040?ooo`@00000;P3oool30000odT0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003o
ool0oooo0?ooo`<00000>`3oool70000ocd0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0>0?ooo`00803oool200000940oooo1000000j0?ooo`@0003o1`3oool00`000?l0oooo0?oo
o`0k0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@
0?ooo`<00000?03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo03X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?oo
o`<000000P3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3oool0>`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3o
ool02@3oool40000ocd0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0j0?ooo`030000
o`3oool0oooo0080oooo1P000?m20?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0>`3o
ool40000odT0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool30000
0140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?oo
o`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0
IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool30000
0340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?oo
o`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000
B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool40000
0540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<0
00000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?oo
o`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3o
ool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3o
ool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool40000
0700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I
0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?oo
o`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo
0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000
U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2
000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000
oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo
1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?oo
o`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool20000
0800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`04
0?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0
oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0
oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04
0?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`00
0000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440
oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`39
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo
00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?oo
o`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`80
0000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03o
ool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0
oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?oo
o`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`00
00000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J
0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?oo
o`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03o
ool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool0
06`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo
0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000
000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<00000
0?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000
=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3o
ool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool0
06P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool0
0`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5
000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool40000
05@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0
oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<0
00000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V
0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool0
00007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000
003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool50000
08P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0
oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F
0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B
0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?oo
o`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`03
0000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool0
00003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00
IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000
003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3o
ool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool0
0`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0
oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2
000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo0000
00000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?oo
o`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0
oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P00
00040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3o
ool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03o
ool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.54223 .68496 m
.54436 .69155 L
s
.58013 .68791 m
.54436 .69155 L
s
.58013 .68791 m
.57815 .68129 L
s
.54303 .68194 m
.54223 .68496 L
s
.54584 .67969 m
.54303 .68194 L
s
.57815 .68129 m
.57558 .67861 L
s
.54897 .67838 m
.54584 .67969 L
s
.57558 .67861 m
.57157 .67705 L
s
.55381 .6769 m
.54897 .67838 L
s
.57157 .67705 m
.56785 .67645 L
s
.5624 .67602 m
.55381 .6769 L
s
.56785 .67645 m
.5624 .67602 L
s
.56206 .66912 m
.53793 .6716 L
s
.55171 .67018 m
.55658 .66869 L
s
.55658 .66869 m
.55944 .66639 L
s
.55944 .66639 m
.56058 .66428 L
s
.56058 .66428 m
.55968 .66136 L
s
.54429 .65791 m
.53877 .65748 L
s
.54776 .65755 m
.54429 .65791 L
s
.55267 .65603 m
.54776 .65755 L
s
.53877 .65748 m
.53467 .65588 L
s
.55554 .6537 m
.55267 .65603 L
s
.53467 .65588 m
.5323 .65409 L
s
.5323 .65409 m
.53135 .65114 L
s
.55668 .65155 m
.55554 .6537 L
s
.55577 .64859 m
.55668 .65155 L
s
.53135 .65114 m
.53245 .64898 L
s
.53245 .64898 m
.53531 .64663 L
s
.55342 .64679 m
.55577 .64859 L
s
.55456 .64461 m
.53007 .64718 L
s
.5493 .64516 m
.55342 .64679 L
s
.55241 .63762 m
.52653 .63619 L
s
.54994 .62955 m
.52653 .63619 L
s
.54994 .62955 m
.52393 .6281 L
s
.54745 .62139 m
.52393 .6281 L
s
.53487 .61636 m
.5292 .6159 L
s
.54377 .61541 m
.53487 .61636 L
s
.5292 .6159 m
.52531 .61525 L
s
.54881 .61381 m
.54377 .61541 L
s
.52531 .61525 m
.52109 .61356 L
s
.55207 .61239 m
.54881 .61381 L
s
.52109 .61356 m
.51864 .61168 L
s
.55502 .60994 m
.55207 .61239 L
s
.51864 .61168 m
.5173 .60753 L
s
.55619 .60766 m
.55502 .60994 L
s
.55494 .60349 m
.55619 .60766 L
s
.5173 .60753 m
.51842 .60525 L
s
.53162 .60599 m
.52998 .60075 L
s
.51842 .60525 m
.52134 .60277 L
s
.55252 .60158 m
.55494 .60349 L
s
.52134 .60277 m
.52459 .60134 L
s
.54829 .59987 m
.55252 .60158 L
s
.52459 .60134 m
.52998 .60075 L
s
.54437 .5992 m
.54829 .59987 L
s
.53883 .59326 m
.51359 .59599 L
s
.528 .59443 m
.53309 .59278 L
s
.53309 .59278 m
.53605 .59027 L
s
.53605 .59027 m
.5372 .58794 L
s
.5372 .58794 m
.53622 .58473 L
s
.52002 .58095 m
.51423 .58047 L
s
.52366 .58055 m
.52002 .58095 L
s
.52878 .57888 m
.52366 .58055 L
s
.51423 .58047 m
.50991 .57871 L
s
.53176 .57632 m
.52878 .57888 L
s
.50991 .57871 m
.50739 .57675 L
s
.50739 .57675 m
.50635 .5735 L
s
.53292 .57395 m
.53176 .57632 L
s
.53192 .57069 m
.53292 .57395 L
s
.50635 .5735 m
.50747 .57112 L
s
.50747 .57112 m
.51043 .56854 L
s
.52942 .56871 m
.53192 .57069 L
s
.53058 .56632 m
.50494 .56914 L
s
.52508 .56693 m
.52942 .56871 L
s
.52823 .55862 m
.48963 .56289 L
s
.5036 .55906 m
.50798 .56086 L
s
.5227 .55923 m
.5257 .55661 L
s
.50105 .55705 m
.5036 .55906 L
s
.49998 .55373 m
.50105 .55705 L
s
.5257 .55661 m
.52687 .55419 L
s
.52687 .55419 m
.52585 .55085 L
s
.50111 .55129 m
.49998 .55373 L
s
.50409 .54865 m
.50111 .55129 L
s
.52585 .55085 m
.52331 .54883 L
s
.52331 .54883 m
.51891 .547 L
s
.5093 .54691 m
.50409 .54865 L
s
.51891 .547 m
.513 .5465 L
s
.513 .5465 m
.5093 .54691 L
s
.53445 .53477 m
.49529 .53915 L
s
.51391 .53707 m
.51846 .53303 L
s
.51846 .53303 m
.51963 .53054 L
s
.51963 .53054 m
.51858 .52711 L
s
.51858 .52711 m
.516 .52502 L
s
.51001 .52451 m
.49125 .52663 L
s
.516 .52502 m
.51001 .52451 L
s
.51469 .5144 m
.48828 .5174 L
s
.52982 .51269 m
.52827 .51406 L
s
.52827 .51406 m
.52603 .51311 L
s
.52603 .51311 m
.52757 .51173 L
s
.52757 .51173 m
.52982 .51269 L
s
.49701 .50795 m
.49096 .50743 L
s
.5008 .50752 m
.49701 .50795 L
s
.50613 .50569 m
.5008 .50752 L
s
.49096 .50743 m
.48642 .50551 L
s
.5092 .50291 m
.50613 .50569 L
s
.48642 .50551 m
.48377 .50337 L
s
.48377 .50337 m
.48263 .49983 L
s
.51038 .50033 m
.5092 .50291 L
s
.50929 .49677 m
.51038 .50033 L
s
.48263 .49983 m
.48377 .49724 L
s
.48377 .49724 m
.48682 .49443 L
s
.50665 .49461 m
.50929 .49677 L
s
.50209 .49267 m
.50665 .49461 L
s
.48032 .4865 m
.48453 .48725 L
s
.47724 .48311 m
.48032 .4865 L
s
.49987 .48548 m
.49566 .48472 L
s
.50334 .48384 m
.49987 .48548 L
s
.49566 .48472 m
.49298 .48253 L
s
.50415 .47999 m
.50334 .48384 L
s
.47608 .47948 m
.47724 .48311 L
s
.49298 .48253 m
.48916 .4767 L
s
.50304 .47635 m
.50415 .47999 L
s
.47683 .47562 m
.47608 .47948 L
s
.48916 .4767 m
.48647 .4745 L
s
.49998 .47292 m
.50304 .47635 L
s
.4803 .47395 m
.47683 .47562 L
s
.48647 .4745 m
.48223 .47373 L
s
.48223 .47373 m
.4803 .47395 L
s
.49574 .47215 m
.49998 .47292 L
s
.47369 .46583 m
.47136 .46483 L
s
.47523 .46438 m
.47369 .46583 L
s
.47136 .46483 m
.4729 .46337 L
s
.4729 .46337 m
.47523 .46438 L
s
.51216 .46005 m
.48493 .46324 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0B03oool50000od@0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0l0?ooo`80
003o0`3oool60000odX0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000
o`3oool0oooo0580oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0503o
ool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0
oooo0480oooo0P000?m:0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0>P3oool40000
o`@0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03P0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04L0
oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0
B03oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0103o
ool40000odP0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo
000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0=P3oool30000odl0oooo1000
001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0Q@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0@P3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3o
ool01@3oool30000och0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0i0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03H0oooo0`00000;0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo03<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo0380oooo0`000?l30?ooo`<0003o<`3oool300000140oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0=03oool30000oc<0oooo0`00000D0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03l0oooo0P000?lU0?ooo`<00000603oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0f0?ooo`D0003o103oool0
0`000?l0oooo0?ooo`0P0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
02l0oooo1P000?lY0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0F@3oool400000240
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo05D0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`0]0?ooo`X0003o6P3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0D
0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?oo
o`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03H0oooo00<0003o0?oo
o`3oool0403oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0=03oool00`000?l0oooo0?ooo`0>0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0a0?ooo`T0003o1`3oool3000003@0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`0Z0?ooo`P0003o2`3oool3000003L0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo03T0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0;03oool40000o`040?ooo`000000000000000400oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo02T0oooo0P000?l20?ooo`8000000P000?m20?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0000000800000103oool00`000?l0oooo0?ooo`0o0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo02D0oooo00<0003o0000000000001`3oool00`000?l0oooo0?ooo`0o0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`0Q0?ooo`<0000000<0oooo0000o`3oool01@3oool40000od00oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo01`0oooo100000030?ooo`P0003o00<0oooo0000o`3oool0@P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0603oool3000000<0oooo10000?m=0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`0D0?ooo`<000004P3oool50000od00oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00
000?0?ooo`H0003o0P3oool20000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000C
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool3000001H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0m0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<000006@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000007@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008@3oool60000od80oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0k0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo00<0003o0?oo
o`3oool0>03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3o
ool0=03oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0oooo1@000?lb0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0803oool80000oc80oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`1G0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool30000
o`D0oooo10000?lT0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool010000?l0
oooo0?ooo`000?l90?ooo`030000o`3oool0oooo01d0oooo1000000J0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0J0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo01L0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo00X0oooo0P000?lF0?ooo`<000009P3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04`3oool3000002X0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02@0oooo2P000?lB0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo0`000?l<0?ooo`<00000
=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:03oool40000o``0oooo0`00000j0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0U0?ooo`D0003o2`3oool3000003h0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02X0oooo1P000?l00`3oool000000000000200000480oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02T0
oooo10000?l0103oool000000000000000170?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`D0
003o0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000001P000?m80?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003o
ool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0N0?ooo`<000001`3oool:0000odX0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0K0?ooo`<000002P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo04P0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000000d0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000@0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo
000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000
000D0?ooo`P0003oCP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>
0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?oo
o`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000U0?oo
o`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000X0?ooo`03
0000o`3oool0oooo04/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000Z0?ooo`030000
o`3oool0oooo04d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000:`3oool50000odl0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000
000Y0?ooo`D0003oE@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`800000T03oool3000003D0oooo10000?m=0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?oo
o`3oool0;`3oool40000o`@0oooo0`000?m;0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3o
ool0;03oool30000o`X0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000
003oool0oooo02`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1;0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3o
ool3000000`0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo04/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo00D0oooo1`000?m>0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0;P3oool70000
oeD0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`
0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3
000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo
000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B
0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3
000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c
0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3
000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E
0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000
Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3o
ool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo0000
06/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo0017
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80
000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@00000
0`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3o
ool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool01000
0000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000
oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`03
0000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`800000
00<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?oo
o`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00
I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@00000
2@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2
000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo
0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?oo
o`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?oo
o`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00
M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003o
ool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2
000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool0
06P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4
000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool20000
01@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo
00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo
00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<0
00000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a
0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?oo
o`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3o
ool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000
N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03o
ool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool0
0900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo
00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`11
0?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l
0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?oo
o`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D0
0000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000
/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool0
0`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool0
06D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0
oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo
00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3o
ool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool4
00000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.54202 .69195 m
.54242 .68525 L
s
.54202 .69195 m
.50579 .69141 L
s
.50603 .6847 m
.50579 .69141 L
s
.54242 .68525 m
.54085 .68234 L
s
.50787 .68184 m
.50603 .6847 L
s
.54085 .68234 m
.53749 .68035 L
s
.51142 .67996 m
.50787 .68184 L
s
.53749 .68035 m
.53407 .67933 L
s
.51494 .67904 m
.51142 .67996 L
s
.53407 .67933 m
.5289 .67829 L
s
.5202 .67815 m
.51494 .67904 L
s
.5289 .67829 m
.5202 .67815 L
s
.53099 .67149 m
.50652 .67112 L
s
.52051 .67134 m
.5258 .67044 L
s
.5258 .67044 m
.52939 .66853 L
s
.52939 .66853 m
.53124 .66659 L
s
.53124 .66659 m
.5314 .66363 L
s
.52108 .65851 m
.51756 .65846 L
s
.52642 .6576 m
.52108 .65851 L
s
.51756 .65846 m
.51231 .65738 L
s
.53004 .65566 m
.52642 .6576 L
s
.51231 .65738 m
.50886 .65534 L
s
.53191 .65369 m
.53004 .65566 L
s
.50886 .65534 m
.50716 .65331 L
s
.53206 .65068 m
.53191 .65369 L
s
.50716 .65331 m
.50727 .6503 L
s
.5304 .64865 m
.53206 .65068 L
s
.50727 .6503 m
.50912 .64832 L
s
.52695 .64658 m
.5304 .64865 L
s
.50912 .64832 m
.51274 .64636 L
s
.53227 .64666 m
.50742 .64627 L
s
.53264 .63956 m
.50782 .63509 L
s
.53306 .63138 m
.50782 .63509 L
s
.53306 .63138 m
.50811 .62686 L
s
.53349 .62311 m
.50811 .62686 L
s
.532 .61682 m
.52296 .61668 L
s
.53748 .61586 m
.532 .61682 L
s
.52296 .61668 m
.51758 .61555 L
s
.54116 .61487 m
.53748 .61586 L
s
.51758 .61555 m
.514 .61444 L
s
.5449 .61282 m
.54116 .61487 L
s
.514 .61444 m
.51045 .61228 L
s
.54684 .61074 m
.5449 .61282 L
s
.51045 .61228 m
.50872 .61014 L
s
.54709 .60651 m
.54684 .61074 L
s
.50872 .61014 m
.50887 .60591 L
s
.54539 .60436 m
.54709 .60651 L
s
.52343 .60614 m
.52367 .60082 L
s
.50887 .60591 m
.51077 .60381 L
s
.54187 .60217 m
.54539 .60436 L
s
.51077 .60381 m
.5145 .60174 L
s
.53828 .60105 m
.54187 .60217 L
s
.5145 .60174 m
.51819 .60073 L
s
.51819 .60073 m
.52367 .60082 L
s
.53496 .59456 m
.50929 .59415 L
s
.52396 .59439 m
.52951 .5934 L
s
.52951 .5934 m
.53329 .5913 L
s
.53329 .5913 m
.53524 .58916 L
s
.53524 .58916 m
.5354 .58591 L
s
.52459 .58028 m
.5209 .58022 L
s
.53019 .57927 m
.52459 .58028 L
s
.5209 .58022 m
.51539 .57903 L
s
.534 .57714 m
.53019 .57927 L
s
.51539 .57903 m
.51177 .57678 L
s
.53597 .57497 m
.534 .57714 L
s
.51177 .57678 m
.51 .57455 L
s
.53614 .57166 m
.53597 .57497 L
s
.51 .57455 m
.51012 .57123 L
s
.53439 .56941 m
.53614 .57166 L
s
.51012 .57123 m
.51206 .56905 L
s
.53078 .56713 m
.53439 .56941 L
s
.51206 .56905 m
.51587 .56689 L
s
.53637 .56722 m
.51028 .5668 L
s
.53677 .5594 m
.49745 .55876 L
s
.53115 .55931 m
.53501 .55712 L
s
.51251 .55676 m
.51618 .55907 L
s
.53501 .55712 m
.537 .5549 L
s
.51072 .55447 m
.51251 .55676 L
s
.537 .5549 m
.53718 .55151 L
s
.51084 .55108 m
.51072 .55447 L
s
.53718 .55151 m
.53541 .54921 L
s
.51281 .54884 m
.51084 .55108 L
s
.53541 .54921 m
.53175 .54688 L
s
.51667 .54663 m
.51281 .54884 L
s
.53175 .54688 m
.52615 .54564 L
s
.52237 .54558 m
.51667 .54663 L
s
.52615 .54564 m
.52237 .54558 L
s
.55122 .53688 m
.51138 .53622 L
s
.53035 .53653 m
.53622 .53316 L
s
.53622 .53316 m
.53824 .53088 L
s
.53824 .53088 m
.53842 .52739 L
s
.53842 .52739 m
.53663 .52502 L
s
.53663 .52502 m
.53095 .52376 L
s
.53095 .52376 m
.51184 .52344 L
s
.55445 .51473 m
.55246 .51588 L
s
.55246 .51588 m
.55061 .51467 L
s
.5526 .51352 m
.55445 .51473 L
s
.55061 .51467 m
.5526 .51352 L
s
.53908 .51448 m
.51218 .51403 L
s
.52793 .50596 m
.52407 .5059 L
s
.53378 .50487 m
.52793 .50596 L
s
.52407 .5059 m
.51832 .50461 L
s
.53776 .50254 m
.53378 .50487 L
s
.51832 .50461 m
.51454 .50215 L
s
.53982 .50017 m
.53776 .50254 L
s
.51454 .50215 m
.51269 .49971 L
s
.54001 .49655 m
.53982 .50017 L
s
.51269 .49971 m
.51282 .49609 L
s
.53819 .4941 m
.54001 .49655 L
s
.51282 .49609 m
.51485 .49371 L
s
.53442 .49161 m
.53819 .4941 L
s
.51485 .49371 m
.51884 .49135 L
s
.53477 .4843 m
.53092 .48301 L
s
.53874 .48314 m
.53477 .4843 L
s
.51526 .48274 m
.51913 .48403 L
s
.54089 .47949 m
.53874 .48314 L
s
.53092 .48301 m
.52907 .48052 L
s
.51344 .47902 m
.51526 .48274 L
s
.52907 .48052 m
.52738 .47432 L
s
.54108 .47579 m
.54089 .47949 L
s
.51357 .47532 m
.51344 .47902 L
s
.5393 .47204 m
.54108 .47579 L
s
.51567 .47163 m
.51357 .47532 L
s
.52738 .47432 m
.52552 .4718 L
s
.53542 .47073 m
.5393 .47204 L
s
.52552 .4718 m
.52163 .47049 L
s
.51966 .47046 m
.51567 .47163 L
s
.52163 .47049 m
.51966 .47046 L
s
.51604 .46164 m
.51411 .46035 L
s
.51807 .46042 m
.51604 .46164 L
s
.55571 .46107 m
.52798 .46059 L
s
.51614 .45913 m
.51807 .46042 L
s
.51411 .46035 m
.51614 .45913 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo0440oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1=0?ooo`80003o0`3oool;0000oc@0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0B@3oool5
0000o`<0oooo0P000?lk0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0>`3oool00`000000oooo0?ooo`0>
0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`150?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0h0?ooo`03
0000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`030?ooo`040000
o`3oool0oooo0000oc/0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`150?ooo`030000
o`3oool0oooo00<0oooo0P000?ll0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000
oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo08P0oooo
1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`050?ooo`80003o=P3oool300000080oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?oo
o`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0a0?oo
o`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`80
0000J@3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0;P3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0
1@3oool20000obd0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02X0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03l0oooo1@000?lZ0?ooo`<000004@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?ooo`<00000503o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?ooo`<00000603o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0i0?ooo`/0003o0`3o
ool30000oaP0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3
000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000Q0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`0f0?ooo`P0003o5`3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo03d0oooo
0P000?lB0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
000X0?ooo`800000MP3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo00`0oooo0`00
000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`09
0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?oo
o`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0k0?oo
o`030000o`3oool0oooo00L0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0340oooo3`000?l0103oool0000000000000000d0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0?@3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo
0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000?@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0;`3oool60000ocl0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02`0oooo0P000?l20000
00@0oooo0P000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0000000P0
oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<0000000<0oooo0000o`3oool0
203oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`8000002000
0?l60?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo10000009
0?ooo`T0003o?P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000005@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo01@0oooo0`00000>0?ooo`D0003oA03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool300000180oooo0P000?l20?ooo`H0003o?P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303o
ool3000001@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`080?ooo`<000005`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000K0?ooo`030000o`3oool0oooo
00D0oooo0P000?ln0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000001l0oooo0`000?l20?ooo`80
003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08`0oooo0P00000U0?ooo`80003o@P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool0>03oool300000080oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02P0oooo00<0003o0?ooo`3oool0=@3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0
oooo0`000?ld0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool:0000oc40oooo
0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`1G0?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool08P3oool30000o`D0oooo00<0003o0?ooo`3oool09`3oool3000001H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01l0oooo0`000?l20?ooo`030000o`3oool0oooo00@0oooo0P000?lS0?oo
o`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool3000001h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo01l0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0J0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo01L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo0200oooo0P000?l90?ooo`80003o5`3oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0280oooo2@000?lE0?ooo`@00000;P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo
0`000?lA0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool50000oa40oooo0`00
000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0O0?ooo`<0003o4`3oool3000003h0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0280oooo1@000?l:0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool09@3oool50000o`@0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0O0?ooo`H0003o
1P3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0280oooo10000?l20?ooo`<00000CP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool0
0`000000oooo0?ooo`0U0?ooo`<0000000<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?oo
o`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000000P0003oD`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`0000020?ooo`030000o`3oool0oooo00@0oooo
0P000?mC0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo
0`0000040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000001`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A
0?ooo`@000002`3oool20000o`@0oooo0`000?mF0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00h0oooo0`00000A0?ooo`@0003oFP3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
7@3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000007`3o
ool20000oeT0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<000006`3oool80000oe`0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000S
0?ooo`D0003oF`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0R0?ooo`P0
003oF`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo01l0oooo0`000?l80?ooo`030000
o`3oool0oooo05T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00T0oooo0P000?mJ0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`00
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0
oooo0`00000A0?ooo`030000003oool0oooo01l0oooo3`000?mL0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<0
0000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3o
ool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3
000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D
0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000
A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3
000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f
0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000
I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo
00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H
0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000
Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000
U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool20000
00@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo
0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003o
ool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2
000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000
oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo
0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`800000
00<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0
oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo
00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3o
ool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000
003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0
oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool30000
0140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0
oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo
0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000
003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<0
00000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3o
ool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool0
0`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo
0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0
oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo
1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`
0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?oo
o`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003o
ool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0
oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo
09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo0000
00l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000
oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool40000
04/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`00
0000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000
oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000
001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000
001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U
0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`800000
0`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3o
ool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03o
ool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000
oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo
0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00
002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F
0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`04
0000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`03
0000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000
303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903o
ool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303o
ool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0
oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool5
00000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool20000
00/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo0000
02<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0
oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo
0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00
003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?oo
o`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo
000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool20000
0=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0
oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.50336 .69153 m
.50611 .68501 L
s
.50336 .69153 m
.46795 .68682 L
s
.47056 .68026 m
.46795 .68682 L
s
.50611 .68501 m
.5056 .68198 L
s
.5056 .68198 m
.50301 .67964 L
s
.47338 .67767 m
.47056 .68026 L
s
.50301 .67964 m
.50001 .67825 L
s
.50001 .67825 m
.49531 .67662 L
s
.47754 .67623 m
.47338 .67767 L
s
.49531 .67662 m
.48681 .67548 L
s
.48132 .67574 m
.47754 .67623 L
s
.48681 .67548 m
.48132 .67574 L
s
.49975 .67021 m
.47584 .66698 L
s
.48952 .66883 m
.49503 .66856 L
s
.49503 .66856 m
.49923 .66711 L
s
.49923 .66711 m
.50173 .66543 L
s
.50173 .66543 m
.50292 .66255 L
s
.4946 .65632 m
.49116 .65586 L
s
.50016 .65605 m
.4946 .65632 L
s
.5044 .65458 m
.50016 .65605 L
s
.49116 .65586 m
.48638 .65418 L
s
.50692 .65287 m
.5044 .65458 L
s
.48638 .65418 m
.48371 .65176 L
s
.50814 .64994 m
.50692 .65287 L
s
.48371 .65176 m
.48276 .64958 L
s
.50722 .64775 m
.50814 .64994 L
s
.48276 .64958 m
.48393 .64664 L
s
.50457 .64531 m
.50722 .64775 L
s
.48393 .64664 m
.48644 .64491 L
s
.50976 .64603 m
.48549 .6427 L
s
.48644 .64491 m
.4907 .64342 L
s
.51261 .63912 m
.48984 .63178 L
s
.51591 .63116 m
.48984 .63178 L
s
.51591 .63116 m
.49303 .62374 L
s
.51923 .62311 m
.49303 .62374 L
s
.51999 .61678 m
.51119 .61555 L
s
.52569 .6165 m
.51999 .61678 L
s
.52964 .61597 m
.52569 .6165 L
s
.53401 .61442 m
.52964 .61597 L
s
.51119 .61555 m
.50631 .61379 L
s
.53663 .61263 m
.53401 .61442 L
s
.50631 .61379 m
.50319 .61228 L
s
.53836 .60852 m
.53663 .61263 L
s
.50319 .61228 m
.50048 .60973 L
s
.50048 .60973 m
.49952 .60743 L
s
.53746 .60621 m
.53836 .60852 L
s
.49952 .60743 m
.50117 .6033 L
s
.53479 .60365 m
.53746 .60621 L
s
.51536 .60529 m
.51747 .60011 L
s
.53168 .60211 m
.53479 .60365 L
s
.50117 .6033 m
.50377 .60147 L
s
.50377 .60147 m
.50816 .5999 L
s
.51214 .59936 m
.51747 .60011 L
s
.50816 .5999 m
.51214 .59936 L
s
.53071 .59537 m
.50573 .59183 L
s
.52002 .59385 m
.5258 .59356 L
s
.5258 .59356 m
.53023 .59197 L
s
.53023 .59197 m
.53288 .59012 L
s
.53288 .59012 m
.53419 .58696 L
s
.5256 .58013 m
.522 .57961 L
s
.53143 .57983 m
.5256 .58013 L
s
.5359 .57821 m
.53143 .57983 L
s
.522 .57961 m
.51703 .57777 L
s
.53859 .57633 m
.5359 .57821 L
s
.51703 .57777 m
.51428 .57512 L
s
.53992 .57312 m
.53859 .57633 L
s
.51428 .57512 m
.51333 .57272 L
s
.539 .57071 m
.53992 .57312 L
s
.51333 .57272 m
.51461 .56949 L
s
.53627 .56803 m
.539 .57071 L
s
.51461 .56949 m
.51728 .56759 L
s
.5417 .56881 m
.51633 .56516 L
s
.51728 .56759 m
.52178 .56595 L
s
.54484 .56123 m
.50658 .5557 L
s
.53939 .56044 m
.54392 .55878 L
s
.54392 .55878 m
.54664 .55686 L
s
.52206 .55562 m
.52483 .55833 L
s
.54664 .55686 m
.548 .55357 L
s
.52111 .55316 m
.52206 .55562 L
s
.548 .55357 m
.54709 .5511 L
s
.52242 .54985 m
.52111 .55316 L
s
.54709 .5511 m
.54434 .54836 L
s
.52513 .54791 m
.52242 .54985 L
s
.54434 .54836 m
.5393 .54646 L
s
.52969 .54623 m
.52513 .54791 L
s
.5393 .54646 m
.53563 .54592 L
s
.53563 .54592 m
.52969 .54623 L
s
.56681 .54105 m
.52818 .53538 L
s
.54661 .53809 m
.55351 .53553 L
s
.55351 .53553 m
.55628 .53356 L
s
.55628 .53356 m
.55768 .53018 L
s
.55768 .53018 m
.55677 .52764 L
s
.55677 .52764 m
.55168 .52569 L
s
.55168 .52569 m
.53312 .52295 L
s
.57771 .51987 m
.57538 .52074 L
s
.57538 .52074 m
.574 .51932 L
s
.57634 .51845 m
.57771 .51987 L
s
.574 .51932 m
.57634 .51845 L
s
.56286 .51766 m
.53676 .51379 L
s
.55497 .50793 m
.55123 .50737 L
s
.56106 .50761 m
.55497 .50793 L
s
.56576 .50585 m
.56106 .50761 L
s
.55123 .50737 m
.54607 .50537 L
s
.56859 .5038 m
.56576 .50585 L
s
.54607 .50537 m
.54325 .50248 L
s
.57004 .5003 m
.56859 .5038 L
s
.54325 .50248 m
.5423 .49986 L
s
.56913 .49768 m
.57004 .5003 L
s
.5423 .49986 m
.5437 .49635 L
s
.56633 .49476 m
.56913 .49768 L
s
.5437 .49635 m
.54652 .49428 L
s
.54652 .49428 m
.55124 .49249 L
s
.56924 .48768 m
.56594 .48592 L
s
.57351 .48706 m
.56924 .48768 L
s
.57687 .48378 m
.57351 .48706 L
s
.56594 .48592 m
.56501 .48325 L
s
.55077 .48362 m
.55409 .48539 L
s
.57835 .4802 m
.57687 .48378 L
s
.5503 .47975 m
.55077 .48362 L
s
.56501 .48325 m
.56554 .47698 L
s
.57794 .47632 m
.57835 .4802 L
s
.55173 .47616 m
.5503 .47975 L
s
.56554 .47698 m
.56461 .47429 L
s
.57463 .47454 m
.57794 .47632 L
s
.55508 .47284 m
.55173 .47616 L
s
.56461 .47429 m
.56128 .4725 L
s
.55938 .47221 m
.55508 .47284 L
s
.56128 .4725 m
.55938 .47221 L
s
.59771 .46778 m
.57094 .46368 L
s
.55894 .46313 m
.55751 .46162 L
s
.56135 .46221 m
.55894 .46313 L
s
.55992 .46069 m
.56135 .46221 L
s
.55751 .46162 m
.55992 .46069 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0G@3oool20000oc80oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1L0?ooo`03
0000o`3oool0oooo0080oooo0`000?l]0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
H`3oool50000obP0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo06L0oooo0`000?lU0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`1H0?ooo`<0003o<`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
05H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo02`0oooo00<00000
0?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0000o`0]0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0D`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:P3oool00`00
0000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0003o02d0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1B0?ooo`03
0000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o;P3oool010000000oooo0?ooo`3oool3
00000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`1G0?ooo`<0003o;P3oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`250?ooo`<00000F03oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04d0oooo
0P000?lb0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo02L0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo04X0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0S0?ooo`<00000203oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0B@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0200oooo0`00000;0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo01d0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo04P0oooo0`000?l30?ooo`<0003o7@3oool300000140oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool0BP3oool30000oad0oooo0`00000D0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06H0oooo0`00000H0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0480oooo1@000?lK0?ooo`<0
00006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`800000
1P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04H0oooo1P000?l40?ooo`030000
o`3oool0oooo00/0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1>0?ooo`80003o2@3o
ool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03h0oooo10000?lC0?ooo`<000009@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool00000
07@0oooo00<000000?ooo`3oool0@@3oool40000o``0oooo0`00000X0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo04@0
oooo00<0003o0?ooo`3oool01P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`140?ooo`030000o`3oool0oooo0080oooo0`00000^0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool00`00000a0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03L0oooo10000?l50?ooo`040000o`000000
0000000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0j0?ooo`L0003o=P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0>@3oool3000000@0oooo10000?lb0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0e0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool00`000000003o
0000o`040000oc`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000000`000?l0oooo0?oo
o`040?ooo`80003o>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool300000080oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000040000
o`80oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`0Q0?ooo`<000001`3oool70000o`<0oooo0P000?li0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`0L0?ooo`@000004@3oool40000oc/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000403oool50000od80oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0100oooo0`00000C0?ooo`80003o0`3oool60000oc`0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00`0oooo0`00000E0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001P0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000703o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00<00000803oool80000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool0>@3oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02P0oooo00<0003o0?ooo`3oool0=@3oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01d0oooo1@000?l30?ooo`<0003o=@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
0280oooo1P000?lb0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0E`3oool300000180
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01d0oooo1P000?la0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0703oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0P00
0?lW0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool08@3oool3000001h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0M0?oo
o`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool06`3oool20000o``0oooo00<0003o0?ooo`3o
ool06`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool2000008l0oooo00<000000?ooo`3oool07@3oool20000o`T0oooo0P000?lJ0?ooo`<00000
:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool07`3oool90000oaP0oooo1000000^0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool50000
oaL0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0J0?ooo`D0003o6@3oool3000003X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo01`0oooo0P000?lG0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool07P3oool30000oa00oooo100000120?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0I
0?ooo`X0003o2`3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01/0oooo10000?l<0?oo
o`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool07`3oool30000o`H0oooo0`00001>0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000
003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
403oool00240oooo0P00002@0?ooo`030000003oool0oooo01L0oooo1@000?l50?ooo`@00000EP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool05P3oool30000o`<0oooo0P000?l3000005/0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0080oooo0`0000000`3o
ool0003o0?ooo`1K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01H0oooo00<0003o0?ooo`0000000P0000040?ooo`030000o`3oool0oooo05/0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000000H0oooo0P000?mN0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000000<0oooo1P000?mQ0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool3000000l0oooo00<0003o0?ooo`3oool0H03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0203oool300000180oooo00<0003o0?ooo`3oool0H@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0103oool4000000/0oooo1@000?l20?ooo`<0003oI@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00000D0?ooo`D0003oIP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000F0?ooo`P0003oJ03o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08`0oooo0`0000020?ooo`030000003oool0oooo0180oooo0P000?l80?ooo`030000o`3oool0
oooo06H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00T0oooo0P000?mW0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`0@0?ooo`@0003o2`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0503oool70000o`<0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo01`0oooo10000?mZ0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.46551 .68666 m
.47052 .68058 L
s
.46551 .68666 m
.43218 .67792 L
s
.47052 .68058 m
.4711 .67754 L
s
.43709 .67177 m
.43218 .67792 L
s
.4711 .67754 m
.46936 .67494 L
s
.46936 .67494 m
.4669 .67322 L
s
.4669 .67322 m
.46284 .67107 L
s
.44081 .66954 m
.43709 .67177 L
s
.46284 .67107 m
.45486 .66896 L
s
.44543 .66861 m
.44081 .66954 L
s
.45486 .66896 m
.44935 .66858 L
s
.44935 .66858 m
.44543 .66861 L
s
.46949 .66529 m
.44703 .65932 L
s
.46542 .66313 m
.47007 .66219 L
s
.45989 .66274 m
.46542 .66313 L
s
.47007 .66219 m
.47313 .66083 L
s
.47313 .66083 m
.47532 .65814 L
s
.4749 .65144 m
.46933 .65105 L
s
.47959 .6505 m
.4749 .65144 L
s
.46933 .65105 m
.4661 .65018 L
s
.48268 .64912 m
.47959 .6505 L
s
.4661 .65018 m
.46198 .64797 L
s
.48491 .64639 m
.48268 .64912 L
s
.46198 .64797 m
.4602 .64528 L
s
.48478 .64413 m
.48491 .64639 L
s
.4602 .64528 m
.46004 .64302 L
s
.48303 .64142 m
.48478 .64413 L
s
.46004 .64302 m
.46223 .64027 L
s
.48788 .64274 m
.46517 .63659 L
s
.46223 .64027 m
.46532 .63887 L
s
.46532 .63887 m
.47005 .63791 L
s
.49313 .6363 m
.47331 .62638 L
s
.49917 .62889 m
.4793 .61887 L
s
.49917 .62889 m
.47331 .62638 L
s
.50527 .62141 m
.4793 .61887 L
s
.51393 .61571 m
.50824 .6153 L
s
.51798 .61567 m
.51393 .61571 L
s
.5228 .61468 m
.51798 .61567 L
s
.50824 .6153 m
.50004 .61303 L
s
.526 .61324 m
.5228 .61468 L
s
.52913 .60943 m
.526 .61324 L
s
.50004 .61303 m
.49587 .61072 L
s
.49587 .61072 m
.49334 .60885 L
s
.52907 .60706 m
.52913 .60943 L
s
.49334 .60885 m
.49157 .60603 L
s
.52735 .60423 m
.52907 .60706 L
s
.49157 .60603 m
.49145 .60365 L
s
.52485 .60235 m
.52735 .60423 L
s
.49145 .60365 m
.49452 .5998 L
s
.50776 .60348 m
.51165 .59866 L
s
.49452 .5998 m
.49772 .59833 L
s
.50668 .59728 m
.51165 .59866 L
s
.49772 .59833 m
.50259 .59732 L
s
.50259 .59732 m
.50668 .59728 L
s
.52628 .59563 m
.50305 .58912 L
s
.52211 .59327 m
.527 .59225 L
s
.51635 .59285 m
.52211 .59327 L
s
.527 .59225 m
.53025 .59077 L
s
.53025 .59077 m
.53263 .58784 L
s
.53244 .58053 m
.52664 .5801 L
s
.53738 .5795 m
.53244 .58053 L
s
.52664 .5801 m
.5233 .57916 L
s
.54066 .57799 m
.53738 .5795 L
s
.5233 .57916 m
.51908 .57674 L
s
.54309 .57502 m
.54066 .57799 L
s
.51908 .57674 m
.51732 .57381 L
s
.54304 .57255 m
.54309 .57502 L
s
.51732 .57381 m
.51724 .57134 L
s
.54132 .5696 m
.54304 .57255 L
s
.51724 .57134 m
.51963 .56834 L
s
.54634 .57103 m
.52284 .56432 L
s
.51963 .56834 m
.52291 .56681 L
s
.52291 .56681 m
.52789 .56576 L
s
.55206 .56401 m
.51662 .55384 L
s
.54702 .56256 m
.55203 .56151 L
s
.55203 .56151 m
.55535 .55997 L
s
.55535 .55997 m
.55783 .55693 L
s
.5318 .55569 m
.53355 .5587 L
s
.55783 .55693 m
.55781 .55441 L
s
.53173 .55317 m
.5318 .55569 L
s
.55781 .55441 m
.55609 .55139 L
s
.53418 .5501 m
.53173 .55317 L
s
.55609 .55139 m
.55185 .5489 L
s
.53751 .54854 m
.53418 .5501 L
s
.55185 .5489 m
.54846 .54792 L
s
.54255 .54747 m
.53751 .54854 L
s
.54846 .54792 m
.54255 .54747 L
s
.58051 .54707 m
.54488 .53669 L
s
.5619 .54165 m
.56951 .54003 L
s
.56951 .54003 m
.5729 .53845 L
s
.5729 .53845 m
.57544 .53533 L
s
.57544 .53533 m
.57544 .53274 L
s
.57544 .53274 m
.57118 .5302 L
s
.57118 .5302 m
.55408 .52517 L
s
.59848 .52782 m
.59591 .52837 L
s
.59591 .52837 m
.59508 .52682 L
s
.59764 .52627 m
.59848 .52782 L
s
.59508 .52682 m
.59764 .52627 L
s
.58485 .52379 m
.56084 .5167 L
s
.58662 .51377 m
.5806 .51331 L
s
.59179 .51266 m
.58662 .51377 L
s
.5806 .51331 m
.57716 .51229 L
s
.59525 .51103 m
.59179 .51266 L
s
.57716 .51229 m
.57285 .50968 L
s
.59788 .50781 m
.59525 .51103 L
s
.57285 .50968 m
.57112 .5065 L
s
.59791 .50514 m
.59788 .50781 L
s
.57112 .5065 m
.57111 .50383 L
s
.59622 .50194 m
.59791 .50514 L
s
.57111 .50383 m
.5737 .50058 L
s
.5737 .50058 m
.57717 .49893 L
s
.57717 .49893 m
.58238 .49779 L
s
.60151 .49542 m
.59893 .49329 L
s
.60586 .49538 m
.60151 .49542 L
s
.61026 .49262 m
.60586 .49538 L
s
.59893 .49329 m
.59897 .49057 L
s
.61294 .48933 m
.61026 .49262 L
s
.58503 .48909 m
.58763 .49124 L
s
.59897 .49057 m
.60167 .48454 L
s
.6139 .4855 m
.61294 .48933 L
s
.58592 .48526 m
.58503 .48909 L
s
.61132 .48334 m
.6139 .4855 L
s
.58857 .48195 m
.58592 .48526 L
s
.60167 .48454 m
.60171 .4818 L
s
.59298 .47915 m
.58857 .48195 L
s
.60171 .4818 m
.59911 .47963 L
s
.63595 .47977 m
.61154 .47231 L
s
.59911 .47963 m
.59736 .4791 L
s
.59736 .4791 m
.59298 .47915 L
s
.60012 .47021 m
.59926 .46855 L
s
.60277 .46963 m
.60012 .47021 L
s
.60191 .46797 m
.60277 .46963 L
s
.59926 .46855 m
.60191 .46797 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1Y0?ooo`<0003o8`3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0K@3oool20000oal0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`1^0?ooo`<0003o703oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0700
oooo0`000?lI0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H`3oool30000o``0oooo
0P000?lG0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0H03oool20000o`<0oooo00D0
003o0?ooo`3oool0oooo0000o`0P0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0GP3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool07@3o
ool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0N0?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo05d0oooo00D0003o
0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo01`0oooo0`00001H0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0H03oool0
1@000?l0oooo0?ooo`3oool0003o01`0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1P
0?ooo`<0003o6P3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0E`3oool30000ob00oooo0`0000080?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool05P3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
8@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1C0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool04P3oool3000000h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00l0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo0540oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?ooo`<00000
503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1A0?ooo`80003o
1@3oool20000o``0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0580oooo1@000?l;0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo04X0oooo0`000?lA0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0C03oool4
0000o`T0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
02T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1?0?ooo`<0003o0`3oool30000
02D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000
oooo0000001d0?ooo`030000003oool0oooo04@0oooo0P000?l;0?ooo`<0000000<0oooo0000o`3o
ool09@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000
MP3oool00`000000oooo0?ooo`150?ooo`@0003o103oool3000000<0oooo0P000?lV0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0B03oool20000o`800000;P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<0000000<0oooo0000o`3oool0;P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool00000
0240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0m0?ooo`80003o0P3oool30000
00@0oooo00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0
oooo00@000000000o`000?l0003o0`3oool40000obl0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0
oooo0`0000040?ooo`@0003o<P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000000/0oooo
0`000?l_0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<00000103oool30000o`X0oooo0P00
0?l]0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<00000103oool30000o`<0oooo0P000?lg
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<000001P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000<0oooo0`000?l30?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
8@3oool3000000T0oooo1@000?l80?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo01`0oooo1000000@0?ooo`D0003o0`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`0H0?ooo`<000006@3oool30000ocP0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo
01@0oooo0`00000C0?ooo`<0003o@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001D0
oooo00@0003o0?ooo`3oool0oooo10000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<0
00005`3oool00`000?l0oooo0?ooo`060?ooo`<0003o>P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
203oool3000001X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`040?ooo`<000007@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo03X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008@3oool30000o`<0oooo0P000?lm
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0S03oool2000002L0oooo0`000?lo0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0j0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0703o
ool30000o`P0oooo00<0003o0?ooo`3oool0=P3oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01l0oooo20000?lf0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool30000
oc@0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0J0?ooo`L0003o=P3oool300000180
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0b0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo0P000?lY0?ooo`@000006P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo02@0oooo0`00000N
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool08@3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0O0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0K0?ooo`80003o
1`3oool20000oah0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0M0?ooo`L0003o703o
ool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01D0oooo1@000?lT0?ooo`<00000<`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool05P3oool20000o`80oooo1@000?lL0?ooo`<00000=P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0603oool20000oah0oooo0`00000j0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0B0?ooo`D0003o0`3oool20000oaT0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0D0?ooo`80003o00<0oooo0000o`000?l010000?lD0?ooo`@00000@P3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool05P3oool30000oaD0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0I0?oo
o`80003o403oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00l0oooo0`000?lF0?ooo`<0
0000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000
SP3oool00`000000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0?ooo`D0003o3P3oool300000580
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo
00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`<0003o203oool4000005H0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`040?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`<00000GP3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0?0?ooo`L0003o0P3oool300000680oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`090?ooo`80003o0`3oool300000080oooo00<0003o0?ooo`3oool0
JP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`0000050000ofd0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00P0oooo0`0000040?ooo`<0003oK`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool400000080003oN03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`0000020?oo
o`80003o0P3oool50000og@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo100000040?ooo`030000o`3oool0oooo00L0oooo0P000?mc0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000
1P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`030?ooo`80003o3@3oool00`000?l0oooo0?ooo`1`0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4
000000D0oooo00<000000?ooo`3oool01@3oool40000o`P0oooo00<0003o0?ooo`3oool0LP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo00T0oooo10000?l30?ooo`030000o`3oool0oooo
07@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0=0?ooo`<0003oN03oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo
0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0
oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo
0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?oo
o`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`00
0000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo
0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool30000
06L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo
0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?oo
o`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?oo
o`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
5@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool30000
08L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080
oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`03
0000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000
oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo
0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`00
0000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?oo
o`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@00000
0?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`31
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?oo
o`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103o
ool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00
001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`03
0000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00
A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2
000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`03
0000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00
CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool0
10000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0
oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool40000
00<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0
oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@0
00000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<00000
0?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool0
0`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool20000
00030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?oo
o`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00
H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03o
ool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool0
06L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool40000
00T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo
0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?oo
o`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3o
ool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000
:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03o
ool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool0
07D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000
oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo
0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?oo
o`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo
001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo
100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00
000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?oo
o`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?oo
o`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`03
0000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0
L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3o
ool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0
oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool50000
07/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800
oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo
002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<00000
0?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?oo
o`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0
@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0
?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03o
ool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool5
00000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool40000
0;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo
00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo
001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo
0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo
0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?oo
o`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3o
ool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0
oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo
1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42982 .67748 m
.43695 .67207 L
s
.42982 .67748 m
.39983 .66495 L
s
.43695 .67207 m
.4386 .66914 L
s
.4386 .66914 m
.4378 .66639 L
s
.4378 .66639 m
.43597 .6644 L
s
.40691 .65946 m
.39983 .66495 L
s
.43597 .6644 m
.43272 .66181 L
s
.43272 .66181 m
.42555 .65879 L
s
.4114 .6577 m
.40691 .65946 L
s
.42555 .65879 m
.42022 .65776 L
s
.42022 .65776 m
.41632 .65733 L
s
.41632 .65733 m
.4114 .6577 L
s
.44135 .6569 m
.42121 .64835 L
s
.43809 .65429 m
.44303 .65392 L
s
.43275 .65325 m
.43809 .65429 L
s
.44303 .65392 m
.44653 .65294 L
s
.44653 .65294 m
.44965 .65056 L
s
.45161 .64392 m
.44624 .64287 L
s
.45658 .64354 m
.45161 .64392 L
s
.46012 .64255 m
.45658 .64354 L
s
.44624 .64287 m
.44336 .64163 L
s
.46328 .64014 m
.46012 .64255 L
s
.44336 .64163 m
.44006 .63896 L
s
.46396 .6379 m
.46328 .64014 L
s
.44006 .63896 m
.43925 .6361 L
s
.46319 .63503 m
.46396 .6379 L
s
.46751 .6369 m
.44725 .62814 L
s
.43925 .6361 m
.4399 .63385 L
s
.4399 .63385 m
.44304 .63141 L
s
.44304 .63141 m
.4466 .6304 L
s
.47495 .63121 m
.45892 .61908 L
s
.4466 .6304 m
.45161 .63002 L
s
.48352 .62466 m
.46749 .61243 L
s
.48352 .62466 m
.45892 .61908 L
s
.49216 .61805 m
.46749 .61243 L
s
.50666 .61396 m
.50268 .61351 L
s
.51174 .61358 m
.50666 .61396 L
s
.51538 .61255 m
.51174 .61358 L
s
.50268 .61351 m
.49724 .61242 L
s
.51979 .6092 m
.51538 .61255 L
s
.49724 .61242 m
.48998 .60921 L
s
.48998 .60921 m
.4867 .60643 L
s
.52055 .60688 m
.51979 .6092 L
s
.51988 .6039 m
.52055 .60688 L
s
.4867 .60643 m
.48487 .60429 L
s
.48487 .60429 m
.48412 .60131 L
s
.51809 .60176 m
.51988 .6039 L
s
.48412 .60131 m
.48484 .59896 L
s
.50093 .60078 m
.50644 .59654 L
s
.48484 .59896 m
.48923 .59556 L
s
.50206 .59457 m
.50644 .59654 L
s
.48923 .59556 m
.49289 .59451 L
s
.52185 .59536 m
.50137 .58613 L
s
.49803 .59411 m
.50206 .59457 L
s
.49289 .59451 m
.49803 .59411 L
s
.5186 .59253 m
.52374 .59214 L
s
.5131 .59142 m
.5186 .59253 L
s
.52374 .59214 m
.52744 .59108 L
s
.52744 .59108 m
.53081 .58851 L
s
.53319 .58134 m
.52767 .58021 L
s
.53838 .58094 m
.53319 .58134 L
s
.54211 .57987 m
.53838 .58094 L
s
.52767 .58021 m
.52473 .57887 L
s
.54552 .57726 m
.54211 .57987 L
s
.52473 .57887 m
.52145 .57599 L
s
.54634 .57485 m
.54552 .57726 L
s
.52145 .57599 m
.52076 .5729 L
s
.54569 .57175 m
.54634 .57485 L
s
.55008 .57377 m
.5295 .5643 L
s
.52076 .5729 m
.52155 .57047 L
s
.52155 .57047 m
.52495 .56783 L
s
.52495 .56783 m
.5287 .56675 L
s
.55812 .56762 m
.52711 .55327 L
s
.5287 .56675 m
.53393 .56634 L
s
.55372 .56559 m
.55897 .56518 L
s
.55897 .56518 m
.56274 .56409 L
s
.56274 .56409 m
.56622 .56143 L
s
.56622 .56143 m
.56708 .55897 L
s
.54128 .55699 m
.54194 .56014 L
s
.56708 .55897 m
.56647 .55582 L
s
.54211 .55451 m
.54128 .55699 L
s
.56647 .55582 m
.56321 .55285 L
s
.59168 .55464 m
.56071 .54007 L
s
.54557 .55182 m
.54211 .55451 L
s
.56321 .55285 m
.56026 .55147 L
s
.54937 .55072 m
.54557 .55182 L
s
.56026 .55147 m
.55466 .5503 L
s
.55466 .5503 m
.54937 .55072 L
s
.57553 .54704 m
.58348 .54641 L
s
.58348 .54641 m
.58732 .5453 L
s
.58732 .5453 m
.59088 .54258 L
s
.59088 .54258 m
.59178 .54006 L
s
.59178 .54006 m
.58854 .53705 L
s
.61578 .53817 m
.61311 .53838 L
s
.61311 .53838 m
.61285 .53677 L
s
.61552 .53655 m
.61578 .53817 L
s
.58854 .53705 m
.57369 .53 L
s
.61285 .53677 m
.61552 .53655 L
s
.60401 .53254 m
.58323 .52259 L
s
.60922 .52302 m
.60356 .52181 L
s
.61461 .52259 m
.60922 .52302 L
s
.61852 .52145 m
.61461 .52259 L
s
.60356 .52181 m
.60059 .52037 L
s
.62218 .51865 m
.61852 .52145 L
s
.60059 .52037 m
.59732 .51729 L
s
.62314 .51606 m
.62218 .51865 L
s
.59732 .51729 m
.59676 .51398 L
s
.62262 .51274 m
.62314 .51606 L
s
.59676 .51398 m
.59768 .51137 L
s
.59768 .51137 m
.60133 .50854 L
s
.60133 .50854 m
.60526 .50738 L
s
.6342 .5076 m
.62999 .50709 L
s
.6394 .50548 m
.6342 .5076 L
s
.60526 .50738 m
.6107 .50694 L
s
.62999 .50709 m
.62825 .50468 L
s
.64312 .50264 m
.6394 .50548 L
s
.62825 .50468 m
.62923 .50205 L
s
.64537 .49905 m
.64312 .50264 L
s
.62923 .50205 m
.63393 .49655 L
s
.61629 .49883 m
.61806 .50125 L
s
.64364 .49662 m
.64537 .49905 L
s
.61849 .49522 m
.61629 .49883 L
s
.63393 .49655 m
.63493 .49389 L
s
.66853 .49632 m
.64769 .48595 L
s
.6222 .49234 m
.61849 .49522 L
s
.63493 .49389 m
.63318 .49145 L
s
.62743 .49019 m
.6222 .49234 L
s
.63318 .49145 m
.63168 .49071 L
s
.63168 .49071 m
.62743 .49019 L
s
.63742 .48245 m
.63717 .48072 L
s
.64018 .48222 m
.63742 .48245 L
s
.63993 .4805 m
.64018 .48222 L
s
.63717 .48072 m
.63993 .4805 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`1c0?ooo`<0003o5@3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo07<0oooo0P00
0?lE0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0M@3oool00`000?l0oooo0?ooo`0A
0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo07D0oooo0P000?lA0?ooo`@00000E@3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
06`0oooo0`000?l70?ooo`80003o3@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1Y0?ooo`80003o0`3oool00`000?l0
oooo0?ooo`060?ooo`80003o203oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo06L0oooo
00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo0P000?l30?ooo`<0
00001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000
J@3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`060?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0I@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0
oooo00<0oooo00@0003o0?ooo`3oool0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo05l0oooo0`000?l60?ooo`D0003o00@0oooo0000000000000000
4@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1L0?ooo`80003o
303oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
FP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<00000603oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0000000000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05P0oooo00<0
003o0?ooo`3oool00`3oool3000000030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo05P0oooo00<0003o0000000000000P0000030?ooo`030000o`3oool0oooo01/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo0500oooo00<0003o0?ooo`3oool00P3oool3000000L0003o7P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0
oooo00<000000?ooo`3oool0D03oool20000o`800000:03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=0?ooo`<00000
00<0oooo0000o`000?l0:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04T0oooo00<0
00000000o`000?l01P3oool20000obH0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0A@3oool3000000<0oooo0P000?l60?ooo`80003o903oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000203oool20000o`P0oooo0P000?lP0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000000d0oooo00<0003o0?ooo`3o
ool01P3oool20000oal0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo0`0000050?ooo`80003o
2@3oool20000obP0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000:0?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<000003`3oool6
0000ob/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`00000:0?ooo`<0003o1`3oool30000
ob`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000040?ooo`030000o`3oool0oooo00@0
oooo0P000?l30?ooo`<0003o1`3oool20000obX0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000P0oooo
0P000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool20000obP0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0240oooo0`00000=0?ooo`80003o00<0oooo0000o`3oool01`3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000004P3oool2
0000o`P0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool30000
01P0oooo0P000?l50?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0
oooo0`00000E0?ooo`<0003o1@3oool50000ocD0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo
0`00000G0?ooo`030000o`3oool0oooo0080003o1P3oool20000ocH0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo00`0oooo0`00000H0?ooo`80003o1@3oool30000oc/0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo00P0oooo0`00000K0?ooo`030000o`3oool0oooo00L0oooo0P000?li0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`040?ooo`<000007P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool30000o`@0oooo00<0003o0?ooo`3o
ool0>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08`0oooo0P00000X0?ooo`@0003o?@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01`0oooo0P000?m60?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07P3oool20000
o`L0oooo00<0003o0?ooo`3oool0=P3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0200
oooo1`000?lf0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05`3oool60000o`D0oooo
0P000?lf0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?oo
o`040?ooo`80003o>03oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01D0oooo00<0003o
0?ooo`3oool0103oool20000ocH0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo00T0oooo0P000?l/0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02L0oooo0`00000N0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0G0?ooo`80003o2P3oool00`000?l0oooo0?ooo`0T0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0280oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo00l0oooo0`000?l80?ooo`P0003o8P3oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0100oooo1P000?lZ0?ooo`@00000;P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool03@3oool30000o`<0oooo00@0003o0?ooo`3oool0oooo0`000?lT0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0000o`050000obD0
oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo
0`000?lQ0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`040?ooo`80003o8`3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00P0oooo10000?l6
0?ooo`030000o`3oool0oooo01`0oooo100000120?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo0P000?l50?ooo`030000o`3oool0oooo01P0oooo0`0000170?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo0P000?lK0?ooo`<0
0000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80003o
5`3oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool3000008h0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo01<0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00240oooo0P00002@0?ooo`030000003oool0oooo00P0oooo1`000?lB0?ooo`@00000EP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool010000000
oooo0000o`000?lJ0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool01000
0000oooo0?ooo`3oool20000o`L0oooo00<0003o0?ooo`3oool02`3oool300000680oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool00`3oool70000o`/0oooo0`00001V0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`03
0000003oool0oooo08d0oooo1@000?l50?ooo`80003o2P3oool4000006X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08`0oooo00@0003o0?ooo`3oool000000P3oool20000o``0oooo0`00001_0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000
003oool0oooo08/0oooo0P000?l30?ooo`030000003oool0oooo0080oooo0P000?l70?ooo`<00000
LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo08X0oooo0P000?l40?ooo`030000003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo
0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<0
00000?ooo`3oool0S03oool20000o`80oooo00<000000?ooo`3oool0103oool4000007X0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2>
0?ooo`80003o00@000000?ooo`3oool0oooo0`0000000`3oool0003o0?ooo`1l0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`040000o`000000
0000000000@0oooo00<0003o0?ooo`3oool0O03oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`800000T03oool3000000030?ooo`000?l0003o0080oooo0P000?mo
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0S03oool300000080oooo00@000000?ooo`3oool0oooo0P000?n20?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool40000
00D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?oo
o`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool40000
02@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?oo
o`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000
003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?oo
o`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3o
ool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000
oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<0
00000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?oo
o`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00
002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo
0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`06
0?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`03
0000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l
0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000
NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
03P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3o
ool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000
L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@00
0000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<00000
0?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?oo
o`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0
b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000
003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0
c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo
00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo
00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00
001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?oo
o`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo
0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003o
ool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000
B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool0
0`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo
0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<0
00000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@0
00007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D00000
8`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0
oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo
00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<0
00000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@00000
0?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000
000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]
0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3o
ool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3o
ool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0
M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3o
ool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool0
08T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool50000
0780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool40000
07L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L
0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?oo
o`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3o
ool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3o
ool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3o
ool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool0
08`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0
oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo
00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?oo
o`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@00000
0?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00
002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?oo
o`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3o
ool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000
c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@0
00000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]
0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@00
00020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y
0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.39764 .66423 m
.40665 .65974 L
s
.39764 .66423 m
.37217 .64829 L
s
.40665 .65974 m
.40933 .65705 L
s
.40933 .65705 m
.40952 .65423 L
s
.40952 .65423 m
.40842 .65206 L
s
.40842 .65206 m
.4061 .64911 L
s
.4061 .64911 m
.40004 .64527 L
s
.38121 .64371 m
.37217 .64829 L
s
.41643 .6453 m
.39944 .63445 L
s
.40004 .64527 m
.3951 .64362 L
s
.38632 .64251 m
.38121 .64371 L
s
.3951 .64362 m
.39136 .64273 L
s
.39136 .64273 m
.38632 .64251 L
s
.41915 .64256 m
.42298 .64201 L
s
.41412 .64233 m
.41915 .64256 L
s
.40918 .64067 m
.41412 .64233 L
s
.42298 .64201 m
.42693 .64003 L
s
.43629 .63395 m
.43123 .63372 L
s
.44014 .6334 m
.43629 .63395 L
s
.43123 .63372 m
.42628 .63205 L
s
.44413 .6314 m
.44014 .6334 L
s
.42628 .63205 m
.42385 .63048 L
s
.44559 .62928 m
.44413 .6314 L
s
.42385 .63048 m
.42153 .62745 L
s
.44585 .62637 m
.44559 .62928 L
s
.44946 .62873 m
.43252 .61766 L
s
.42153 .62745 m
.42175 .62453 L
s
.42175 .62453 m
.42318 .6224 L
s
.45883 .62403 m
.44729 .61016 L
s
.42318 .6224 m
.42718 .62037 L
s
.42718 .62037 m
.43106 .61981 L
s
.43106 .61981 m
.43617 .62004 L
s
.46961 .61862 m
.45812 .60466 L
s
.46961 .61862 m
.44729 .61016 L
s
.48046 .61318 m
.45812 .60466 L
s
.50128 .61116 m
.49616 .61092 L
s
.50521 .61059 m
.50128 .61116 L
s
.49616 .61092 m
.4924 .61 L
s
.51071 .60785 m
.50521 .61059 L
s
.4924 .61 m
.48744 .60827 L
s
.48744 .60827 m
.48143 .60423 L
s
.51228 .60567 m
.51071 .60785 L
s
.51267 .60267 m
.51228 .60567 L
s
.48143 .60423 m
.47918 .60111 L
s
.51167 .60035 m
.51267 .60267 L
s
.47918 .60111 m
.47814 .59879 L
s
.47814 .59879 m
.47846 .59576 L
s
.49518 .59731 m
.50209 .59382 L
s
.47846 .59576 m
.48 .59355 L
s
.51761 .59454 m
.50078 .583 L
s
.49848 .59136 m
.50209 .59382 L
s
.48 .59355 m
.48551 .59075 L
s
.5206 .59163 m
.52458 .59105 L
s
.51542 .59138 m
.5206 .59163 L
s
.51043 .58962 m
.51542 .59138 L
s
.49468 .59041 m
.49848 .59136 L
s
.52458 .59105 m
.52878 .58894 L
s
.48551 .59075 m
.48949 .59017 L
s
.48949 .59017 m
.49468 .59041 L
s
.53884 .58247 m
.53363 .58222 L
s
.54285 .58188 m
.53884 .58247 L
s
.53363 .58222 m
.52863 .58043 L
s
.5471 .57975 m
.54285 .58188 L
s
.52863 .58043 m
.52624 .57877 L
s
.54875 .57749 m
.5471 .57975 L
s
.52624 .57877 m
.52404 .57554 L
s
.5492 .57439 m
.54875 .57749 L
s
.55278 .5769 m
.53601 .56511 L
s
.52404 .57554 m
.52445 .57243 L
s
.52445 .57243 m
.52607 .57016 L
s
.56276 .5719 m
.53756 .55403 L
s
.52607 .57016 m
.53033 .568 L
s
.56443 .56962 m
.56849 .56902 L
s
.55919 .56937 m
.56443 .56962 L
s
.56849 .56902 m
.5728 .56686 L
s
.53033 .568 m
.53437 .5674 L
s
.53437 .5674 m
.53963 .56765 L
s
.5728 .56686 m
.57449 .56457 L
s
.57449 .56457 m
.575 .56142 L
s
.59986 .5634 m
.57493 .54535 L
s
.55009 .55943 m
.54962 .56259 L
s
.575 .56142 m
.57288 .55813 L
s
.55176 .55712 m
.55009 .55943 L
s
.57288 .55813 m
.57049 .55641 L
s
.55608 .55492 m
.55176 .55712 L
s
.57049 .55641 m
.56546 .55457 L
s
.56017 .55432 m
.55608 .55492 L
s
.56546 .55457 m
.56017 .55432 L
s
.5948 .55437 m
.5989 .55377 L
s
.58687 .55399 m
.5948 .55437 L
s
.5989 .55377 m
.60329 .55157 L
s
.60329 .55157 m
.60504 .54923 L
s
.62887 .55038 m
.62623 .55025 L
s
.62918 .54878 m
.62887 .55038 L
s
.62623 .55025 m
.62653 .54865 L
s
.60504 .54923 m
.60296 .54589 L
s
.62653 .54865 m
.62918 .54878 L
s
.60296 .54589 m
.59104 .53717 L
s
.61948 .54344 m
.60286 .53117 L
s
.63316 .53511 m
.62782 .53485 L
s
.63732 .53449 m
.63316 .53511 L
s
.62782 .53485 m
.62278 .53296 L
s
.64182 .53224 m
.63732 .53449 L
s
.62278 .53296 m
.62041 .5312 L
s
.64364 .52985 m
.64182 .53224 L
s
.62041 .5312 m
.61834 .52779 L
s
.64429 .52657 m
.64364 .52985 L
s
.61834 .52779 m
.61895 .5245 L
s
.61895 .5245 m
.62075 .52209 L
s
.65721 .52304 m
.65335 .52202 L
s
.66293 .52165 m
.65721 .52304 L
s
.62075 .52209 m
.62525 .5198 L
s
.65335 .52202 m
.65251 .51947 L
s
.66748 .51936 m
.66293 .52165 L
s
.62525 .5198 m
.62945 .51917 L
s
.65251 .51947 m
.65436 .51704 L
s
.62945 .51917 m
.63483 .51944 L
s
.67088 .51617 m
.66748 .51936 L
s
.65436 .51704 m
.66078 .51231 L
s
.69398 .51647 m
.67764 .5038 L
s
.67007 .51361 m
.67088 .51617 L
s
.64304 .51227 m
.6439 .51485 L
s
.66078 .51231 m
.66266 .50986 L
s
.64641 .50906 m
.64304 .51227 L
s
.66266 .50986 m
.66183 .50727 L
s
.65098 .50674 m
.64641 .50906 L
s
.66183 .50727 m
.66064 .50637 L
s
.65675 .50532 m
.65098 .50674 L
s
.66064 .50637 m
.65675 .50532 L
s
.6721 .49753 m
.67174 .49923 L
s
.67174 .49923 m
.66902 .4991 L
s
.66902 .4991 m
.66938 .4974 L
s
.66938 .4974 m
.6721 .49753 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1i0?ooo`<0003o00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`1b0?ooo`<000001P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo06h0oooo0P0000050000o`H0oooo00<0003o0?oo
o`3oool0103oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<000000P000?l40?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?ooo`<000000P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P000?l40?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0680oooo0`0000050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo
0?ooo`000000F03oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`1N0?ooo`<00000303oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool00000F03oool00`000000oooo0?ooo`0F
0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo100000040?oo
o`D0003o1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo05D0oooo0`0000060?ooo`80003o2`3oool50000o`d0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000
003oool0oooo0540oooo0`0000090?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3o
ool00`000000oooo0?ooo`1=0?ooo`<000002`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo01<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`190?ooo`<000002@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool00000
0200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<000003@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P000?lF0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo0440oooo0`00000:0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool50000oaP0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`0m0?ooo`<000003P3oool00`000?l0oooo0?ooo`040?ooo`80003o803oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0>@3oool300000180oooo0P000?l60?ooo`030000o`3oool0oooo01d0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo03D0oooo0`00000=0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?oo
o`<000004@3oool20000o`P0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0;@3oool3000001H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`<0
003o6P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000001X0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000;0?ooo`030000o`3o
ool0oooo00@0oooo1@000?l70?ooo`H0003o9@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3
000000l0oooo0P000?l30?ooo`030000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0
oooo02H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`00
0000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000D0?ooo`<0003o203oool00`00
0?l0oooo0?ooo`050?ooo`80003o9`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000001X0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02@0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000H0?ooo`030000o`3oool0oooo00<0oooo
0P000?l60?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00
000I0?ooo`D0003o1@3oool20000o`80oooo0P000?la0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<
0?ooo`<000006P3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool30000oc<0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000L0?ooo`030000o`3oool0oooo00H0oooo0P000?li0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<000007`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0003o03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009`3oool70000oc/0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0703oool00`000?l0oooo0?ooo`180?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01d0oooo0P000?m50?oo
o`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool05P3oool40000o`D0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0g0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
503oool20000o`@0oooo0P000?l40?ooo`H0003o=`3oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo01<0oooo00<0003o0?ooo`3oool01@3oool20000o`D0oooo00<0003o0?ooo`3oool0=@3o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool2
0000oc`0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0<@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0]0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0303oool20000o`L0oooo0P000?l90?ooo`030000o`3oool0oooo02X0oooo
0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0=0?ooo`<0003o1`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo02P0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`08
0?ooo`80003o103oool00`000?l0oooo0000o`020000o`D0oooo1`000?lX0?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`090?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?ooo`80003o;`3oool30000
02X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0000o`030000oc00oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool010000000oooo0?ooo`3oool40000o`H0
oooo00<0003o0?ooo`3oool00P3oool20000ob`0oooo0`00000c0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool010000000oooo
0?ooo`000?l40?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0;03oool3000003H0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0003o00H0oooo0P000?l50?ooo`030000o`3oool0oooo02P0oooo
0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0000o`080?ooo`030000o`3oool0oooo02X0oooo0`00
000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool010000000oooo0?ooo`000?l70?ooo`80003o9`3oool400000480oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`040000003oool0oooo0?ooo`<0003o0P3oool20000obH0oooo0`0000170?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0R03oool0
0`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P000?lU0?ooo`<00000BP3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08T0oooo0P000?l30?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002;0?ooo`040000o`3oool0oooo0000
00<0oooo00<0003o0?ooo`3oool08@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool2000008<0oooo1P000?l50?ooo`H0003o803oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`200?ooo`80003o1P3oool20000o`D0oooo00<0003o0?ooo`3oool07P3oool3000005/0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<0
00000?ooo`3oool0O`3oool00`000?l0oooo0?ooo`080?ooo`80003o0`3oool00`000000oooo0?oo
o`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0P03oool20000o`X0oooo00@0
003o0?ooo`3oool000006P3oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0880oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0000000G0?ooo`<00000IP3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`23
0?ooo`80003o1`3oool010000?l0oooo0?ooo`00000C0?ooo`@00000JP3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0Q@3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000000403o
ool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0Q`3oool20000o`030?ooo`000?l0003o00@0oooo00<00000
0?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?
0?ooo`00803oool00`000000oooo0?ooo`290?ooo`030000o`3oool0oooo00@0oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In the following the normal vector to the text plane is rotated ",
  Cell[BoxData[
      \(90  \[Degree]\)]],
  " from the North pole. The text is then rotated in the resulting text \
plane."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Psi]frame[\[Pi]/2, 0]\)[\[Psi]], {\[Psi], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.5363 .44671 m
.52464 .43285 L
s
.52967 .45101 m
.53051 .45608 L
s
.52799 .44767 m
.52967 .45101 L
s
.53051 .45608 m
.53052 .46018 L
s
.51959 .4255 m
.52043 .42785 L
s
.52043 .42785 m
.51958 .4282 L
s
.51874 .42584 m
.51959 .4255 L
s
.53052 .46018 m
.52969 .4633 L
s
.51958 .4282 m
.51874 .42584 L
s
.52379 .44406 m
.5221 .44071 L
s
.52463 .44779 m
.52379 .44406 L
s
.52969 .4633 m
.528 .4627 L
s
.52547 .45562 m
.52463 .44779 L
s
.5221 .44071 m
.52126 .43971 L
s
.52126 .43971 m
.51956 .43907 L
s
.528 .4627 m
.52632 .45935 L
s
.52632 .45935 m
.52547 .45562 L
s
.51956 .43907 m
.5187 .44217 L
s
.5297 .4757 m
.53055 .47945 L
s
.52801 .47097 m
.5297 .4757 L
s
.5187 .44217 m
.51869 .44628 L
s
.53055 .47945 m
.53055 .48361 L
s
.51869 .44628 m
.51953 .4514 L
s
.53055 .48361 m
.52971 .48541 L
s
.51953 .4514 m
.52123 .45477 L
s
.53734 .50815 m
.53651 .50858 L
s
.5365 .50578 m
.53734 .50815 L
s
.53566 .50621 m
.5365 .50578 L
s
.52971 .48541 m
.52802 .48624 L
s
.53651 .50858 m
.53566 .50621 L
s
.5195 .46383 m
.52122 .46305 L
s
.52802 .48624 m
.52546 .48468 L
s
.51864 .46561 m
.5195 .46383 L
s
.53058 .50037 m
.51859 .4866 L
s
.52546 .48468 m
.52376 .48271 L
s
.51863 .46978 m
.51864 .46561 L
s
.52376 .48271 m
.52119 .47835 L
s
.51948 .47357 m
.51863 .46978 L
s
.52119 .47835 m
.51948 .47357 L
s
.52974 .5121 m
.52717 .50775 L
s
.5306 .5159 m
.52974 .5121 L
s
.53659 .53406 m
.51852 .51362 L
s
.5306 .52017 m
.5306 .5159 L
s
.52717 .50775 m
.51856 .49792 L
s
.52975 .52205 m
.5306 .52017 L
s
.52718 .52341 m
.52975 .52205 L
s
.52977 .54215 m
.52805 .53732 L
s
.53064 .546 m
.52977 .54215 L
s
.52805 .53732 m
.52545 .53296 L
s
.53065 .55035 m
.53064 .546 L
s
.52545 .53296 m
.52371 .53102 L
s
.52979 .5523 m
.53065 .55035 L
s
.52371 .53102 m
.5211 .52953 L
s
.52805 .55328 m
.52979 .5523 L
s
.53066 .55617 m
.51226 .53572 L
s
.5211 .52953 m
.51935 .53047 L
s
.51935 .53047 m
.51847 .53239 L
s
.53067 .56641 m
.51842 .55286 L
s
.51847 .53239 m
.51846 .53675 L
s
.5298 .56838 m
.53068 .57228 L
s
.52806 .56352 m
.5298 .56838 L
s
.53068 .57228 m
.53068 .57671 L
s
.51846 .53675 m
.51933 .54065 L
s
.51933 .54065 m
.52108 .54552 L
s
.53068 .57671 m
.52982 .57871 L
s
.52982 .57871 m
.52807 .57975 L
s
.51929 .55678 m
.52106 .55578 L
s
.52807 .57975 m
.52544 .57836 L
s
.53071 .59603 m
.53071 .59155 L
s
.5184 .55876 m
.51929 .55678 L
s
.52544 .57836 m
.52368 .57643 L
s
.52984 .59807 m
.53071 .59603 L
s
.51839 .5632 m
.5184 .55876 L
s
.52368 .57643 m
.52103 .57205 L
s
.52808 .59916 m
.52984 .59807 L
s
.51927 .56714 m
.51839 .5632 L
s
.52103 .57205 m
.51927 .56714 L
s
.53072 .60352 m
.51832 .59011 L
s
.53602 .62276 m
.5369 .62672 L
s
.53426 .61785 m
.53602 .62276 L
s
.5325 .61445 m
.53426 .61785 L
s
.52543 .5978 m
.52808 .59916 L
s
.5369 .62672 m
.53693 .6328 L
s
.53693 .6328 m
.53606 .63491 L
s
.53606 .63491 m
.5343 .63609 L
s
.52543 .61444 m
.52543 .60686 L
s
.52276 .60399 m
.52543 .60686 L
s
.5343 .63609 m
.53254 .63574 L
s
.52098 .60359 m
.52276 .60399 L
s
.53254 .63574 m
.52988 .63445 L
s
.51918 .60471 m
.52098 .60359 L
s
.52988 .63445 m
.52542 .62973 L
s
.51828 .60679 m
.51918 .60471 L
s
.53078 .64462 m
.5182 .63758 L
s
.51826 .6129 m
.51828 .60679 L
s
.52542 .62973 m
.52274 .62534 L
s
.52274 .62534 m
.52094 .6219 L
s
.51915 .61692 m
.51826 .6129 L
s
.52094 .6219 m
.51915 .61692 L
s
.5308 .657 m
.5182 .63758 L
s
.5308 .657 m
.51817 .65007 L
s
.53082 .66949 m
.51817 .65007 L
s
.53083 .68049 m
.51812 .6674 L
s
.52993 .68272 m
.53084 .68681 L
s
.52813 .6777 m
.52993 .68272 L
s
.53084 .68681 m
.53085 .69157 L
s
.53085 .69157 m
.52995 .69383 L
s
.52995 .69383 m
.52813 .69517 L
s
.51903 .67151 m
.52086 .67022 L
s
.52813 .69517 m
.5254 .69398 L
s
.53088 .71236 m
.53087 .70754 L
s
.5181 .67375 m
.51903 .67151 L
s
.5254 .69398 m
.52358 .69212 L
s
.52997 .71466 m
.53088 .71236 L
s
.51809 .67852 m
.5181 .67375 L
s
.52358 .69212 m
.52083 .68773 L
s
.52815 .71605 m
.52997 .71466 L
s
.519 .68266 m
.51809 .67852 L
s
.52083 .68773 m
.519 .68266 L
s
.53089 .72042 m
.51802 .7075 L
s
.5254 .71491 m
.52815 .71605 L
s
.53639 .74374 m
.53456 .73867 L
s
.53732 .74955 m
.53639 .74374 L
s
.53456 .73867 m
.53273 .73523 L
s
.53273 .73523 m
.52999 .73087 L
s
.53736 .76104 m
.53732 .74955 L
s
.52999 .73087 m
.52539 .72629 L
s
.53736 .76104 m
.51793 .74197 L
s
.52539 .72629 m
.52262 .72516 L
s
.52262 .72516 m
.52077 .72496 L
s
.52077 .72496 m
.5189 .72639 L
s
.5189 .72639 m
.51796 .7304 L
s
.51796 .7304 m
.51793 .74197 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 4}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0F`3oool20000od40oooo00<000000?ooo`3oool0AP3oool3000000/0oooo
00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`1K0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0@`3oool3000000h0oooo00<0
00000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1K
0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0@03oool300000140oooo00<00000
0?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1K0?oo
o`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo00<000000?oo
o`3oool06P3oool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1K0?ooo`03
0000o`3oool0oooo03`0oooo00<000000?ooo`3oool0>@3oool4000001L0oooo00<000000?ooo`3o
ool06P3oool002h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1G0?ooo`80003o
00<0oooo0000o`3oool0?@3oool00`000000oooo0?ooo`0f0?ooo`<000006`3oool00`000000oooo
0?ooo`0J0?ooo`00;@3oool200000580oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0000
o`020?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0<`3oool3000001h0oooo00<0
00000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1D
0?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`0`
0?ooo`<000008@3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo05<0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0
oooo03T0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool0
02d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1C0?ooo`80003o00<0oooo0000
o`3oool0?@3oool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000oooo0?ooo`0I0?oo
o`00;@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0580oooo00@0003o0?ooo`00
0?l0003o?P3oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?oo
o`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0540oooo00D0003o0?ooo`00
0?l0oooo0000o`0m0?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000003oool0oooo
01T0oooo000/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0DP3oool00`000?l0
oooo0000o`0m0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0
oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo
0000o`0m0?ooo`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo
000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0CP3oool010000?l0oooo0?oo
o`000?lo0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo
000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/
0?ooo`800000G@3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo0440oooo00<00000
0?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?oo
o`030000003oool0oooo04X0oooo00D0003o0?ooo`3oool0oooo0000o`0o0?ooo`030000003oool0
oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0BP3oool010000?l0oooo0?ooo`000?lo0?ooo`030000003oool0
oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0B@3oool010000?l0oooo0?ooo`000?lo0?ooo`030000003oool0
oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo
0640oooo00<000000?ooo`3oool0B03oool01@000?l0oooo0?ooo`3oool0003o03h0oooo00<00000
0?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?oo
o`3oool0HP3oool00`000000oooo0?ooo`180?ooo`040000o`3oool0oooo0000och0oooo00<00000
0?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?oo
o`3oool0H`3oool00`000000oooo0?ooo`180?ooo`80003o?`3oool010000000oooo0?ooo`3oool3
00000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`140?ooo`030000o`3oool0oooo0440oooo1000001E0?ooo`030000003oool0oooo
01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0A03oool00`000?l0
oooo0?ooo`0n0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0>P3oool300000080oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000
001X0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0=P3oool3000000D0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<00000
0?ooo`3oool0@@3oool01@000?l0oooo0?ooo`3oool0003o03@0oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`110?ooo`050000o`3oool0oooo0?ooo`000?l0<03oool3000000/0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo02h0oooo0`00000>
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0440oooo00D0003o
0?ooo`3oool0oooo0000o`0X0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`100?ooo`050000o`3oool0oooo0?ooo`000?l09@3oool3000001@0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo
0?ooo`0S0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`0k0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool07`3oool3000001/0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`0k0?ooo`050000o`3oool0oooo0?ooo`000?l0
7P3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo03/0oooo00@0003o0?ooo`3oool0003o
6P3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03/0oooo0P000?lH0?ooo`<000009@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0
000007@0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0C0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0k0?ooo`030000o`3oool0oooo00l0oooo0`00000[0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0=P3oool20000o`<0oooo00<0003o0?ooo`3oool02`3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0=03oool010000?l0oooo
0?ooo`000?l30?ooo`030000o`3oool0oooo00L0oooo0`00000a0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo
0?ooo`1h0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo
0?ooo`070?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0340oooo0P00
0?l30?ooo`030000o`3oool0oooo00@0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0a
0?ooo`80003o0P3oool010000?l0oooo0?ooo`3oool3000003X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo0340oooo00@0003o0?ooo`3oool0003o0`00000m0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0`
0?ooo`050000o`0000000000000000000?l0?`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3
000000040000o`3oool0oooo0000ocl0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`000000
103oool0003o0?ooo`3oool20000od00oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000D0oooo00@0003o
0?ooo`3oool0003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000L0oooo00<0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?oo
o`@000002P3oool010000?l0oooo0?ooo`000?m20?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?oo
o`<000003P3oool01@000?l0oooo0?ooo`3oool0003o0440oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo
01@0oooo0`00000A0?ooo`040000o`3oool0oooo0?ooo`80003o@03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000001@0oooo00D0003o0?ooo`3oool0oooo0000o`110?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0<0?ooo`<00000603oool010000?l0oooo0?ooo`000?m10?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`080?ooo`<000006`3oool01@000?l0oooo0?ooo`3oool0003o0400oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo00@0oooo0`00000O0?ooo`040000o`3oool0oooo0000od00oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo00<000008`3oool20000od40oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000J@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo
0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo06@0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo03/0oooo100000060?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?oo
o`050000o`3oool0oooo0?ooo`000?l0=@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02@0oooo00@0003o0?ooo`3oool0003o<P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02D0oooo0P000?l`0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`0[0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool20000o`80oooo
00<0003o0?ooo`3oool09P3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo00@0
003o0?ooo`3oool0003o9`3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo00@0
003o0?ooo`3oool0003o903oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0280oooo00@0
003o0?ooo`3oool0003o8@3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool08P3oool01P000?l0oooo0?oo
o`000?l0oooo0000oa`0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0R0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool05P3oool4000002h0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0B0?ooo`<00000<`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00h0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool02`3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02D0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`<00000?P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo100000120?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool3000004L0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02L0oooo10000?l3000004X0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0903oool0
10000?l0000000000000001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo100000000`3oool0003o0000o`1C
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000103oool010000?l0oooo0?ooo`000?mC
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000000P0oooo00<0003o0?oo
o`3oool0D`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000203oool20000o`80oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000303oool40000oeH0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0A0?ooo`@000003`3oool00`000?l0oooo0?ooo`020000oeH0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000001@0oooo00<0
003o0?ooo`3oool0F03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H
0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000H
0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000L0?oo
o`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000K0?ooo`05
0000o`3oool0oooo0?ooo`000?l0FP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000P0?oo
o`050000o`3oool0oooo0?ooo`000?l0FP3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo00h0oooo000P0?ooo`800000T@3oool400000280oooo00<0003o0?ooo`000?l0GP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000002D0
oooo00@0003o0?ooo`3oool0003oG@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo02<0
oooo00D0003o0?ooo`3oool0oooo0000o`1M0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3o
ool08`3oool010000?l0oooo0?ooo`3oool20000oed0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000
oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l0G`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1M0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O`3oool3000000l0oooo00<000000?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0003o0600
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0oooo0000of00
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`0W0?ooo`80003oHP3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool09@3o
ool01@000?l0oooo0?ooo`3oool0003o06H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`0V0?ooo`040000o`3oool0oooo0000ofL0oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`0W0?ooo`80003oJ@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo02P0oooo00<0003o
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo02T0oooo00<0003o0?oo
o`3oool0I`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`0T0?ooo`@0003oK@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo02@0oooo00@0003o0?ooo`3oool0003oKP3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003o
ool0oooo02@0oooo00D0003o0?ooo`3oool0oooo0000o`1]0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<0
00000?ooo`3oool0903oool00`000?l0oooo0?ooo`020?ooo`80003oK03oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<00000
0?ooo`3oool0903oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo06/0oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?oo
o`<00000B`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0K03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo06d0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3o
ool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03T0oooo0`00001H0?ooo`030000003oool0oooo02L0oooo00D0003o0?ooo`3oool0oooo0000
o`1`0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0?ooo`00
0?ma0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0000o`1b
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;`3oool400000640oooo00<000000?ooo`3oool0:P3oool20000og<0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<0
0000I@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0740oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3
000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E
0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000
Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3o
ool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo0000
06/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo0017
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80
000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@00000
0`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3o
ool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool01000
0000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000
oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`03
0000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`800000
00<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?oo
o`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00
I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@00000
2@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2
000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo
0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?oo
o`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?oo
o`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00
M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003o
ool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2
000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool0
06P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4
000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool20000
01@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo
00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo
00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<0
00000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a
0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?oo
o`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3o
ool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000
N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03o
ool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool0
0900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo
00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`11
0?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l
0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?oo
o`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D0
0000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000
/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool0
0`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool0
06D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0
oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo
00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3o
ool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool4
00000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.55389 .47396 m
.54271 .45682 L
s
.53804 .44829 m
.53868 .45064 L
s
.53706 .44817 m
.53804 .44829 L
s
.53868 .45064 m
.5377 .45052 L
s
.54607 .47429 m
.54639 .4789 L
s
.54462 .4707 m
.54607 .47429 L
s
.5377 .45052 m
.53706 .44817 L
s
.54639 .4789 m
.5459 .4823 L
s
.5459 .4823 m
.5446 .48449 L
s
.54042 .46567 m
.53897 .46207 L
s
.5409 .46916 m
.54042 .46567 L
s
.53897 .46207 m
.53816 .46084 L
s
.54088 .47606 m
.5409 .46916 L
s
.53816 .46084 m
.53637 .45948 L
s
.5446 .48449 m
.54282 .48317 L
s
.53637 .45948 m
.53505 .46162 L
s
.54136 .47956 m
.54088 .47606 L
s
.54282 .48317 m
.54136 .47956 L
s
.53505 .46162 m
.53454 .46501 L
s
.53454 .46501 m
.53485 .46966 L
s
.54183 .49003 m
.54313 .49479 L
s
.53485 .46966 m
.53631 .47328 L
s
.54313 .49479 m
.54361 .49832 L
s
.54361 .49832 m
.54311 .50179 L
s
.54311 .50179 m
.54197 .50288 L
s
.53331 .47994 m
.53529 .48013 L
s
.54197 .50288 m
.54 .50273 L
s
.53214 .481 m
.53331 .47994 L
s
.54702 .5232 m
.54767 .5256 L
s
.54604 .52315 m
.54702 .5232 L
s
.54767 .5256 m
.54669 .52555 L
s
.54 .50273 m
.53736 .50018 L
s
.54669 .52555 m
.54604 .52315 L
s
.53162 .48446 m
.53214 .481 L
s
.53736 .50018 m
.53572 .49771 L
s
.53211 .48801 m
.53162 .48446 L
s
.53572 .49771 m
.53341 .49282 L
s
.54112 .51577 m
.52953 .49841 L
s
.53341 .49282 m
.53211 .48801 L
s
.53877 .52515 m
.53646 .52025 L
s
.53926 .52876 m
.53877 .52515 L
s
.53875 .53233 m
.53926 .52876 L
s
.53646 .52025 m
.52812 .50781 L
s
.5437 .54693 m
.52616 .52089 L
s
.53758 .53348 m
.53875 .53233 L
s
.53456 .53335 m
.53758 .53348 L
s
.53383 .54543 m
.53148 .54049 L
s
.53516 .55033 m
.53383 .54543 L
s
.53565 .554 m
.53516 .55033 L
s
.53148 .54049 m
.5298 .538 L
s
.53513 .55766 m
.53565 .554 L
s
.5298 .538 m
.52708 .53547 L
s
.53393 .55887 m
.53513 .55766 L
s
.52708 .53547 m
.52503 .53539 L
s
.53189 .55883 m
.53393 .55887 L
s
.53443 .56256 m
.51654 .53628 L
s
.52503 .53539 m
.52382 .53656 L
s
.52382 .53656 m
.52327 .54021 L
s
.53319 .57118 m
.52125 .5537 L
s
.52327 .54021 m
.52376 .5439 L
s
.52376 .5439 m
.5251 .54886 L
s
.53065 .56745 m
.53199 .57241 L
s
.53199 .57241 m
.53248 .57614 L
s
.53248 .57614 m
.53195 .57987 L
s
.53195 .57987 m
.53074 .58113 L
s
.52174 .55743 m
.52382 .55747 L
s
.53074 .58113 m
.52867 .58114 L
s
.52051 .55865 m
.52174 .55743 L
s
.52867 .58114 m
.52591 .57865 L
s
.51995 .56238 m
.52051 .55865 L
s
.52591 .57865 m
.52419 .57615 L
s
.52961 .59621 m
.53016 .59242 L
s
.52044 .56613 m
.51995 .56238 L
s
.52419 .57615 m
.52179 .57114 L
s
.52179 .57114 m
.52044 .56613 L
s
.52839 .5975 m
.52961 .59621 L
s
.5263 .59755 m
.52839 .5975 L
s
.52871 .60256 m
.51655 .58503 L
s
.52352 .59507 m
.5263 .59755 L
s
.53089 .61648 m
.53225 .62153 L
s
.52934 .61271 m
.53089 .61648 L
s
.53225 .62153 m
.53275 .62535 L
s
.53275 .62535 m
.53203 .63053 L
s
.53203 .63053 m
.5308 .63189 L
s
.52146 .60917 m
.5224 .60274 L
s
.51978 .59898 m
.5224 .60274 L
s
.5308 .63189 m
.5287 .63201 L
s
.51784 .59774 m
.51978 .59898 L
s
.51571 .59779 m
.51784 .59774 L
s
.5287 .63201 m
.52677 .63083 L
s
.52677 .63083 m
.52396 .62839 L
s
.51444 .59911 m
.51571 .59779 L
s
.52396 .62839 m
.51957 .62214 L
s
.51367 .60427 m
.51444 .59911 L
s
.51957 .62214 m
.51712 .61707 L
s
.51416 .60813 m
.51367 .60427 L
s
.52371 .63751 m
.51053 .62519 L
s
.51712 .61707 m
.51554 .61325 L
s
.51554 .61325 m
.51416 .60813 L
s
.5222 .64808 m
.51053 .62519 L
s
.5222 .64808 m
.50894 .6358 L
s
.52067 .65876 m
.50894 .6358 L
s
.51932 .66819 m
.50673 .65056 L
s
.51664 .66443 m
.51804 .66964 L
s
.51804 .66964 m
.51855 .67361 L
s
.51855 .67361 m
.51796 .67769 L
s
.51796 .67769 m
.51667 .67917 L
s
.50723 .65453 m
.50944 .65436 L
s
.51667 .67917 m
.51448 .6794 L
s
.50592 .65598 m
.50723 .65453 L
s
.51448 .6794 m
.51156 .677 L
s
.50531 .66006 m
.50592 .65598 L
s
.51156 .677 m
.50975 .67448 L
s
.51541 .69557 m
.516 .69142 L
s
.50581 .66406 m
.50531 .66006 L
s
.50975 .67448 m
.50722 .66932 L
s
.50722 .66932 m
.50581 .66406 L
s
.5141 .69709 m
.51541 .69557 L
s
.51188 .69737 m
.5141 .69709 L
s
.51441 .70252 m
.50159 .68486 L
s
.50894 .69498 m
.51188 .69737 L
s
.51626 .72015 m
.51464 .71624 L
s
.51769 .72548 m
.51626 .72015 L
s
.518 .73097 m
.51769 .72548 L
s
.51464 .71624 m
.51209 .71108 L
s
.51209 .71108 m
.50751 .70479 L
s
.51661 .74096 m
.518 .73097 L
s
.50751 .70479 m
.50454 .7024 L
s
.50454 .7024 m
.50248 .70128 L
s
.51661 .74096 m
.49715 .71451 L
s
.50248 .70128 m
.50021 .70157 L
s
.50021 .70157 m
.49864 .70454 L
s
.49864 .70454 m
.49715 .71451 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
05X0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`0]0?ooo`<000009@3oool00`00
0000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05T0
oooo0P000?lj0?ooo`030000003oool0oooo02X0oooo0`00000X0?ooo`030000003oool0oooo01T0
oooo000]0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo05T0oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?oo
o`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo05H0oooo00@0003o0?ooo`3oool0003o>03oool00`000000oooo0?oo
o`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo05@0oooo00D0003o0?ooo`000?l0oooo0000o`0h0?ooo`030000003o
ool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0D`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0
oooo03H0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool0
02`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0003o
0080oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`00
0000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0D@3oool010000?l0
oooo0?ooo`000?l20?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0503oool30000
03h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0oooo0500
oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o0?ooo`0f0?ooo`030000003oool0oooo0140
oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0D03oool010000?l0oooo0000o`000?l20?ooo`030000o`3oool0oooo03@0
oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1A0?ooo`80003o>@3oool00`000000oooo
0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo04`0oooo0P000?l20?ooo`030000o`3oool0003o03P0oooo00<0
00000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`1;0?ooo`040000o`3oool0oooo0?ooo`80003o>@3o
ool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0g0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo04T0oooo00<0003o
0?ooo`3oool0?03oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`180?ooo`050000o`3oool0oooo0?ooo`000?l0>03oool3
000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`180?ooo`040000o`3oool0oooo0000ocD0oooo0`0000020?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`00
0000oooo0?ooo`170?ooo`040000o`3oool0oooo0000oc80oooo0`0000050?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo
04D0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0/0?ooo`<00000203oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0A@3oool01@000?l0oooo0000o`3oool0003o02`0oooo0`00000;
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0A@3oool010000?l0oooo0000o`000?lY
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`12
0?ooo`030000o`3oool0003o02T0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]
0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`000?l09@3oool3000001@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@@3oool010000?l0oooo0?ooo`00
0?lQ0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`110?ooo`040000o`3oool0oooo0000oad0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0K0?ooo`<000007P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<00000
0?ooo`3oool0?03oool01@000?l0oooo0?ooo`3oool0003o01P0oooo1000000Q0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0l0?ooo`040000o`3oool0oooo0000o`80oooo0P000?lA0?ooo`<000009@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0
000007@0oooo00<000000?ooo`3oool0>`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0
003o0?ooo`3oool0303oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0>`3oool010000?l0oooo0?ooo`00
0?l>0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0004
0?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03/0oooo00<0003o
0?ooo`000?l02`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0>P3oool30000o`P0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0380oooo00<0003o0?ooo`3oool00P000?l30?ooo`030000o`3oool0oooo00@0
oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<P3oool01@000?l0oooo
0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool00`00000g0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0a0?ooo`030000o`3oool0003o0080oooo00H0003o0?ooo`3oool000000000o`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0a0?ooo`80003o0P3oool01@000?l000000000003oool0003o
03/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo00D0003o000000000000oooo0000o`030?oo
o`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000020000o`80
oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000000@0oooo
00@0003o0?ooo`3oool0003o?P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000001@3oool010000?l0oooo
0?ooo`000?l20?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo
0`0000080?ooo`80003o0P3oool20000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000
000;0?ooo`040000o`3oool0003o0?ooo`80003o?`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000000l0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0D0?ooo`<000004P3oool010000?l0oooo0?ooo`000?m10?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0@0?ooo`<000005@3oool01@000?l0oooo0?ooo`3oool0003o0400oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000H0?ooo`040000o`3oool0oooo0?ooo`80003o?`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0203oool3000001/0oooo00D0003o0?ooo`3oool0oooo0000
o`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007`3oool010000?l0oooo0?ooo`00
0?m00?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`03000002<0oooo00<0003o0?ooo`000?l0@03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo
08`0oooo0P00000W0?ooo`80003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo04<0
oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0o0?ooo`<000000P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`0k0?ooo`@000001P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool08`3oool01@000?l0oooo0?ooo`3oool0003o03D0oooo0`00000:0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0003o03<0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0Q0?ooo`<0003o00<0oooo0000o`000?l0<03oool300000180oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo0240oooo00D0003o0?ooo`000?l0oooo0000o`0^0?ooo`<000005P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0803oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0:@3oool4
000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0200oooo00@0003o0?ooo`3oool0003o:@3oool3
000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`000?l09P3oool30000
0280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool08`3oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo
00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo
0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool05P3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0C0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0903oool01@000?l0oooo0?ooo`3oool0003o0180oooo0`00000f0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0P0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`0<
0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool08@3oool01@000?l0oooo0?ooo`3oool0
003o0080oooo00<0003o0?ooo`3oool02P3oool3000003h0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0240oooo0P000?l30?ooo`030000o`3oool0003o00P0oooo100000120?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0R0?ooo`80003o0`3oool20000o`D0oooo0`0000170?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0P0?ooo`050000o`3oool0003o0?ooo`000?l01P3oool3000004X0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo0200oooo0P000?l0103oool0003o0?ooo`000?l20?ooo`<00000CP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0Q0?ooo`<0003o00@0oooo0000000000000000DP3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000
EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000000040?ooo`000?l0oooo0000oeL0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000103oool010000?l0oooo0?oo
o`000?mF0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo
0`0000040?ooo`050000o`3oool0oooo0?ooo`000?l0F@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0E0?ooo`<000001`3oool20000o`80oooo00<0003o0?ooo`3oool0
F03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000:0?ooo`030000o`3o
ool0003o0080oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0>0?ooo`<000003@3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3o
ool0oooo05T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000403oool0
1@000?l0oooo0?ooo`3oool0003o05d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000C
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool4000001H0oooo00<0003o0?ooo`3oool00P3oool20000oed0oooo00<000000?oo
o`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`04
0000003oool0oooo0?ooo`<000006`3oool01@000?l0oooo0?ooo`3oool0003o05l0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000N0?oo
o`050000o`3oool0oooo0?ooo`000?l0H03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00h0oooo000O0?ooo`800000T03oool300000280oooo00@0003o0?ooo`3oool0003oH03oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08`0oooo0`0000020?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`000?l0H@3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0
oooo100000050?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0H@3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo
0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?oo
o`0M0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0N
0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`0P0?oo
o`040000o`3oool0oooo0000ofH0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`0P0?oo
o`80003o00<0oooo0000o`3oool0IP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo0240
oooo0`000?mX0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo
0?ooo`1X0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool07@3oool30000o`<0oooo00<0
003o0?ooo`3oool0J03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool07@3oool010000?l0oooo0?ooo`00
0?m]0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool07@3oool01@000?l0oooo0?ooo`3o
ool0003o06d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo
01`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0
oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo06`0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0K03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo01h0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<00000
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06h0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?oo
o`<00000>`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0KP3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3o
ool0oooo0000o`1a0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool08@3oool010000?l0
oooo0?ooo`000?ma0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool08@3oool010000?l0
oooo0?ooo`000?mb0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`0R0?ooo`80003oM03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0L`3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00
001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3o
ool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0
oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00
001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3o
ool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0
oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo
0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo
0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?oo
o`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo
100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0
oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo
000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?oo
o`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00
=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`03
0000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00
>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool0
0`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool0
0400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[
0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000
003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool20000
00030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000
003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool01000
0000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo
0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0
oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo
0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@00000
0?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?oo
o`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`00
0000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool200000003
0?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00
HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2
000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0
oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0
oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P00
00130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3o
ool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0
]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03o
ool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool0
07@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0
oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo
0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00
000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00
000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X
0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo1000
00170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<0
00000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D
0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`03
0000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`03
0000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000
003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3o
ool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4
000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo
06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0
oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo
002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@
0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?oo
o`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`03
0000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3o
ool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03o
ool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool4
00000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool50000
0:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00
oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo
00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<0
00000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U
0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?oo
o`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`03
0000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool0
3@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo
002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000
003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.57008 .50522 m
.55976 .48548 L
s
.55562 .47613 m
.55605 .47839 L
s
.55456 .47555 m
.55562 .47613 L
s
.55605 .47839 m
.55499 .47781 L
s
.55499 .47781 m
.55456 .47555 L
s
.56021 .49796 m
.56139 .50165 L
s
.56139 .50165 m
.56119 .50565 L
s
.56119 .50565 m
.56024 .50824 L
s
.555 .48801 m
.55425 .48659 L
s
.55617 .49171 m
.555 .48801 L
s
.55629 .49485 m
.55617 .49171 L
s
.55425 .48659 m
.55244 .48459 L
s
.55544 .50057 m
.55629 .49485 L
s
.56024 .50824 m
.55855 .50942 L
s
.55244 .48459 m
.55072 .48572 L
s
.55855 .50942 m
.55673 .50745 L
s
.55072 .48572 m
.54976 .48829 L
s
.55555 .50373 m
.55544 .50057 L
s
.55673 .50745 m
.55555 .50373 L
s
.54976 .48829 m
.54954 .4923 L
s
.54954 .4923 m
.55072 .49602 L
s
.55481 .51268 m
.55568 .51729 L
s
.55568 .51729 m
.55579 .52048 L
s
.55579 .52048 m
.55483 .52313 L
s
.5466 .50009 m
.54877 .50122 L
s
.55483 .52313 m
.55342 .52347 L
s
.54519 .5004 m
.5466 .50009 L
s
.55342 .52347 m
.55126 .52238 L
s
.5442 .50302 m
.54519 .5004 L
s
.55126 .52238 m
.54865 .51895 L
s
.5443 .50622 m
.5442 .50302 L
s
.55658 .54297 m
.55702 .54531 L
s
.5555 .54244 m
.55658 .54297 L
s
.54865 .51895 m
.54712 .51607 L
s
.55702 .54531 m
.55593 .54478 L
s
.54516 .51087 m
.5443 .50622 L
s
.54712 .51607 m
.54516 .51087 L
s
.55593 .54478 m
.5555 .54244 L
s
.55093 .53383 m
.5402 .51362 L
s
.5472 .54053 m
.54522 .53529 L
s
.5473 .5438 m
.5472 .54053 L
s
.54522 .53529 m
.5375 .52077 L
s
.54631 .54654 m
.5473 .5438 L
s
.54487 .54692 m
.54631 .54654 L
s
.55004 .56126 m
.53374 .53074 L
s
.54153 .54532 m
.54487 .54692 L
s
.53926 .5551 m
.53725 .54979 L
s
.54014 .55988 m
.53926 .5551 L
s
.53725 .54979 m
.53569 .54687 L
s
.54024 .56321 m
.54014 .55988 L
s
.53569 .54687 m
.53299 .5434 L
s
.53921 .56603 m
.54024 .56321 L
s
.53299 .5434 m
.53072 .54232 L
s
.53774 .56645 m
.53921 .56603 L
s
.53072 .54232 m
.52923 .5427 L
s
.53547 .56541 m
.53774 .56645 L
s
.52923 .5427 m
.52818 .54549 L
s
.53784 .5698 m
.5212 .53887 L
s
.52818 .54549 m
.52827 .54883 L
s
.52827 .54883 m
.52915 .55365 L
s
.53542 .57646 m
.52429 .55581 L
s
.53304 .57205 m
.53393 .5769 L
s
.53393 .5769 m
.53402 .58029 L
s
.53402 .58029 m
.53297 .58317 L
s
.52437 .55919 m
.52668 .56025 L
s
.53297 .58317 m
.53147 .58363 L
s
.52286 .55961 m
.52437 .55919 L
s
.53147 .58363 m
.52917 .58261 L
s
.52178 .56246 m
.52286 .55961 L
s
.52917 .58261 m
.52641 .57914 L
s
.52186 .56586 m
.52178 .56246 L
s
.52641 .57914 m
.5248 .57617 L
s
.52275 .57075 m
.52186 .56586 L
s
.5248 .57617 m
.52275 .57075 L
s
.52837 .59581 m
.52944 .59288 L
s
.52685 .5963 m
.52837 .59581 L
s
.52451 .59529 m
.52685 .5963 L
s
.52658 .60073 m
.51522 .57985 L
s
.52172 .59181 m
.52451 .59529 L
s
.52604 .60966 m
.5273 .61363 L
s
.5273 .61363 m
.5282 .6186 L
s
.5282 .6186 m
.52829 .6221 L
s
.52829 .6221 m
.52684 .62614 L
s
.51769 .60271 m
.51953 .59773 L
s
.51709 .59325 m
.51953 .59773 L
s
.51508 .59124 m
.51709 .59325 L
s
.52684 .62614 m
.5253 .62668 L
s
.5127 .59021 m
.51508 .59124 L
s
.5253 .62668 m
.52294 .62572 L
s
.51113 .59069 m
.5127 .59021 L
s
.52294 .62572 m
.52093 .62375 L
s
.50963 .59467 m
.51113 .59069 L
s
.52093 .62375 m
.5181 .62027 L
s
.5181 .62027 m
.51398 .61276 L
s
.5097 .59818 m
.50963 .59467 L
s
.5106 .60321 m
.5097 .59818 L
s
.51398 .61276 m
.51188 .60723 L
s
.51188 .60723 m
.5106 .60321 L
s
.51669 .62789 m
.50354 .61082 L
s
.51369 .63614 m
.50354 .61082 L
s
.51369 .63614 m
.50044 .61903 L
s
.51066 .64447 m
.50044 .61903 L
s
.50798 .65184 m
.49613 .63047 L
s
.50545 .64728 m
.50636 .65244 L
s
.50636 .65244 m
.50643 .65609 L
s
.50643 .65609 m
.50527 .65928 L
s
.49619 .63411 m
.49868 .63507 L
s
.50527 .65928 m
.50364 .6599 L
s
.49454 .63468 m
.49619 .63411 L
s
.50364 .6599 m
.50115 .65898 L
s
.49335 .63785 m
.49454 .63468 L
s
.50115 .65898 m
.4982 .65546 L
s
.4934 .64151 m
.49335 .63785 L
s
.4982 .65546 m
.49649 .65239 L
s
.49432 .64671 m
.4934 .64151 L
s
.49649 .65239 m
.49432 .64671 L
s
.50017 .6733 m
.50135 .67004 L
s
.49851 .67395 m
.50017 .6733 L
s
.49599 .67305 m
.49851 .67395 L
s
.49818 .67876 m
.48607 .65714 L
s
.493 .66952 m
.49599 .67305 L
s
.4967 .69066 m
.4945 .68493 L
s
.49803 .69485 m
.4967 .69066 L
s
.49896 .70016 m
.49803 .69485 L
s
.4945 .68493 m
.49016 .6772 L
s
.49862 .70506 m
.49896 .70016 L
s
.49016 .6772 m
.48714 .67366 L
s
.4958 .71296 m
.49862 .70506 L
s
.48714 .67366 m
.48498 .67165 L
s
.48498 .67165 m
.4824 .67074 L
s
.4824 .67074 m
.48027 .6725 L
s
.4958 .71296 m
.47733 .6803 L
s
.48027 .6725 m
.47733 .6803 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0E`3oool00`00
0?l0oooo0?ooo`0c0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0EP3oool00`000?l0
oooo0?ooo`0c0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<0
00000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1A
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0a0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo0500oooo00D0003o0?ooo`000?l0oooo0000o`0c0?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo04l0oooo00<0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0^0?ooo`<00000F03oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04h0oooo00<0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`0[0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3o
ool0C@3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo02L0oooo0`0000050?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000
003oool0oooo04l0oooo00D0003o0?ooo`000?l0oooo0000o`0V0?ooo`<00000203oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0BP3oool20000o`80oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo
0?ooo`0P0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04T0oooo00L0
003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool07@3oool3000000h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0B03oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`000?l07`3oool300000140oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`020?ooo`80003o703oool3
000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0AP3oool0
1@000?l0oooo0?ooo`3oool0003o01/0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`0F0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q
0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04<0oooo00<0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0C0?ooo`<000007P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool0@03oool01@000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool03`3oool4
00000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`00
0000oooo0?ooo`1b0?ooo`030000003oool0oooo03l0oooo00D0003o0?ooo`3oool0003o0?ooo`03
0000o`h0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
02P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0003o
00l0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0
oooo0P00001f0?ooo`030000003oool0oooo03h0oooo00@0003o0?ooo`3oool0003o2`3oool30000
02/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0k0?ooo`060000o`3oool0oooo0000
o`3oool0003o203oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0>`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0080oooo0`00000a0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03X0oooo00@0003o0?ooo`3o
ool0003o0`3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0c0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l00`00000g0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`0b0?ooo`030000o`3oool0oooo0080003o0P3oool010000?l00000000000000?l20?ooo`03
0000o`3oool0oooo03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
9`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0380oooo00X0003o0?ooo`000?l0
00000000o`000000oooo0000o`3oool0003o0P3oool20000ocD0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0
oooo0340oooo00<0003o000000000?l00P3oool00`000?l0oooo0000o`020000ocT0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo02d0oooo0`0000000`3oool0003o0000o`020?ooo`040000o`3oool0oooo
0000ocX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000040?ooo`80003o0P3oool01000
0?l0oooo0?ooo`000?lj0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000060?ooo`030000o`3oool0003o
00<0oooo00@0003o0?ooo`3oool0003o>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool30000
00X0oooo0P000?l30?ooo`040000o`3oool0oooo0000ocT0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo
01`0oooo1000000<0?ooo`80003o00D0oooo0000o`3oool0oooo0000o`030?ooo`030000o`3oool0
oooo03L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000?0?ooo`030000o`3oool0oooo
0080003o0P3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<0
00004P3oool01@000?l0oooo0?ooo`000?l0oooo00<0003o?@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0403oool3000001D0oooo00@0003o0?ooo`3oool0oooo0P000?lo0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0<0?ooo`<000006@3oool010000?l0oooo0?ooo`3oool20000och0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo00P0oooo0`00000L0?ooo`050000o`3oool0oooo0?ooo`000?l0?`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0103oool300000200oooo00<0003o0?ooo`3oool00P000?ln0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`03000001l0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03
0000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`8000008P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0003o03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`80003o?P3o
ool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo03l0oooo0`0000020?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0O0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0j0?ooo`@000001P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0000o`020000o`80oooo00<0003o0?ooo`3o
ool0=03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01l0oooo00D0003o0?ooo`3oool0
003o0?ooo`030000oc<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`040000
o`3oool0oooo0?ooo`80003o<P3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01l0oooo
00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0/0?ooo`<000005P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool07`3oool010000?l0oooo0?ooo`000?l]0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0[0?ooo`<000007P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0280oooo0`00
000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0M0?ooo`040000o`3oool0oooo0000o`@0oooo00<0
003o0?ooo`3oool07`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool07@3oool20000o`80oooo00D0003o
0?ooo`3oool0oooo0000o`0N0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07P3oool2
0000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool0603oool4000002h0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool00P000?l20?ooo`050000o`3oool0oooo
0?ooo`000?l05P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0oooo0P000?l01P3o
ool0003o0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool04@3oool3000003H0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01d0oooo0P000?l01@3oool0003o0?ooo`000?l0oooo00<0003o4@3o
ool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01d0oooo0P000?l01@3oool0003o0?ooo`3o
ool0003o0080oooo00<0003o0?ooo`3oool0303oool3000003h0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo01/0oooo00<0003o0?ooo`3oool00`000?l@0?ooo`@00000@P3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool06`3oool01@000?l0oooo0?ooo`000?l0oooo0080003o303oool3000004L0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo01X0oooo0`000?l20?ooo`030000o`3oool0003o00T0oooo0`00001:0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool01P3oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool3000008h0oooo00<000000?ooo`3oool06P3oool010000?l0oooo0?ooo`000?l20?ooo`03
0000o`3oool0oooo0080oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo01X0oooo00@0003o0?ooo`3oool0
003o0P3oool00`000?l0000000000002000005H0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01X0oooo
00@0003o0?ooo`3oool0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
6P3oool01@000?l00000000000000000003o05d0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0603oool3000000050000o`3oool0oooo0?ooo`000?l0G@3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000000`3oool01@000?l0
oooo0?ooo`3oool0003o05h0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@0
00000P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000oel0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000000L0oooo00<0003o0?ooo`3o
ool00P3oool20000of40oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
2P3oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<000003P3o
ool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000004@3oool0
0`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool300000180oooo00D0003o
0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000D0?ooo`030000o`3oool0
003o00<0oooo0P000?mW0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo0P00002@0?ooo`<000005`3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0
oooo06H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`3oool0003oJ03oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo
01@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0
oooo00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06X0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo01H0oooo00D0
003o0?ooo`3oool0oooo0000o`1^0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06/0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool0
0`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0J`3oool0
0`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo
07H0oooo0`00000H0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`1/0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool06@3oool01@000?l0
oooo0?ooo`3oool0003o06l0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`04
0000o`3oool0oooo0000og00oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo00@0003o0?ooo`3o
ool0003oL03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`03
0000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`00
0?l0L@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo01/0oooo0P000?mc0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03o
ool3000002/0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`1b0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3
000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo
000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B
0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3
000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c
0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3
000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E
0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000
Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3o
ool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo0000
06/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo0017
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80
000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@00000
0`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3o
ool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool01000
0000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000
oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`03
0000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`800000
00<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?oo
o`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00
I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@00000
2@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2
000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo
0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?oo
o`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?oo
o`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00
M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003o
ool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2
000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool0
06P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4
000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool20000
01@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo
00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo
00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<0
00000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a
0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?oo
o`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3o
ool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000
N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03o
ool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool0
0900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo
00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`11
0?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l
0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?oo
o`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D0
0000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000
/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool0
0`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool0
06D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0
oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo
00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3o
ool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool4
00000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.58433 .53931 m
.57521 .51771 L
s
.57174 .50787 m
.57194 .50997 L
s
.57063 .50687 m
.57174 .50787 L
s
.57194 .50997 m
.57084 .50896 L
s
.57084 .50896 m
.57063 .50687 L
s
.57424 .52836 m
.5751 .53202 L
s
.5751 .53202 m
.57441 .53527 L
s
.56964 .51748 m
.56898 .51592 L
s
.5705 .52115 m
.56964 .51748 L
s
.56898 .51592 m
.56721 .51336 L
s
.57025 .52382 m
.5705 .52115 L
s
.57441 .53527 m
.57305 .53698 L
s
.56721 .51336 m
.56517 .51346 L
s
.56863 .52819 m
.57025 .52382 L
s
.57305 .53698 m
.57103 .53713 L
s
.56517 .51346 m
.5638 .51512 L
s
.56838 .53089 m
.56863 .52819 L
s
.57103 .53713 m
.56925 .53458 L
s
.5638 .51512 m
.56308 .51836 L
s
.56925 .53458 m
.56838 .53089 L
s
.56308 .51836 m
.56394 .52206 L
s
.56649 .53801 m
.5669 .5423 L
s
.5669 .5423 m
.56665 .54503 L
s
.55889 .52343 m
.56116 .52545 L
s
.56665 .54503 m
.56526 .54678 L
s
.55729 .52299 m
.55889 .52343 L
s
.56526 .54678 m
.56366 .54637 L
s
.55588 .52469 m
.55729 .52299 L
s
.56366 .54637 m
.56139 .54438 L
s
.55561 .52741 m
.55588 .52469 L
s
.56139 .54438 m
.5589 .54022 L
s
.55601 .53173 m
.55561 .52741 L
s
.5589 .54022 m
.55755 .53706 L
s
.55755 .53706 m
.55601 .53173 L
s
.56483 .56432 m
.56504 .56651 L
s
.56369 .56334 m
.56483 .56432 L
s
.56504 .56651 m
.5639 .56552 L
s
.5639 .56552 m
.56369 .56334 L
s
.55965 .55384 m
.55017 .53158 L
s
.55313 .55223 m
.54632 .53624 L
s
.5547 .55761 m
.55313 .55223 L
s
.55442 .56041 m
.5547 .55761 L
s
.55298 .56222 m
.55442 .56041 L
s
.55133 .56183 m
.55298 .56222 L
s
.54782 .55883 m
.55133 .56183 L
s
.55536 .57648 m
.54095 .54273 L
s
.54253 .56046 m
.54114 .55723 L
s
.54411 .56593 m
.54253 .56046 L
s
.54451 .57039 m
.54411 .56593 L
s
.54114 .55723 m
.53857 .55298 L
s
.54422 .57324 m
.54451 .57039 L
s
.53857 .55298 m
.53619 .55094 L
s
.54273 .57511 m
.54422 .57324 L
s
.53619 .55094 m
.53449 .55053 L
s
.54105 .57473 m
.54273 .57511 L
s
.53449 .55053 m
.53298 .55235 L
s
.53865 .57273 m
.54105 .57473 L
s
.53298 .55235 m
.53267 .5552 L
s
.54075 .57761 m
.52605 .54334 L
s
.53267 .5552 m
.53306 .55969 L
s
.53724 .58202 m
.5274 .55909 L
s
.53514 .57711 m
.53553 .58165 L
s
.53553 .58165 m
.53522 .58456 L
s
.52708 .56198 m
.52951 .56402 L
s
.53522 .58456 m
.5337 .58647 L
s
.52535 .56157 m
.52708 .56198 L
s
.5337 .58647 m
.53198 .58611 L
s
.5238 .56344 m
.52535 .56157 L
s
.53198 .58611 m
.52954 .5841 L
s
.52347 .56634 m
.5238 .56344 L
s
.52954 .5841 m
.5269 .57979 L
s
.52386 .5709 m
.52347 .56634 L
s
.5269 .57979 m
.52547 .57649 L
s
.52547 .57649 m
.52386 .5709 L
s
.52703 .59486 m
.52858 .59291 L
s
.52528 .59451 m
.52703 .59486 L
s
.52281 .59249 m
.52528 .59451 L
s
.52013 .58816 m
.52281 .59249 L
s
.52443 .59813 m
.51437 .57483 L
s
.52273 .60542 m
.52364 .60941 L
s
.52364 .60941 m
.52403 .61408 L
s
.52403 .61408 m
.5237 .6171 L
s
.5143 .59536 m
.51696 .59207 L
s
.51479 .58706 m
.51696 .59207 L
s
.51281 .58436 m
.51479 .58706 L
s
.5237 .6171 m
.5216 .6198 L
s
.51029 .58231 m
.51281 .58436 L
s
.50849 .58193 m
.51029 .58231 L
s
.5216 .6198 m
.51981 .61949 L
s
.50633 .58455 m
.50849 .58193 L
s
.51981 .61949 m
.51729 .61749 L
s
.51729 .61749 m
.5153 .61481 L
s
.50597 .58755 m
.50633 .58455 L
s
.5153 .61481 m
.51257 .61044 L
s
.50635 .59224 m
.50597 .58755 L
s
.51257 .61044 m
.50892 .60201 L
s
.50727 .59628 m
.50635 .59224 L
s
.50892 .60201 m
.50727 .59628 L
s
.51006 .6162 m
.49755 .59516 L
s
.50569 .6217 m
.49755 .59516 L
s
.50569 .6217 m
.49307 .60056 L
s
.50127 .62726 m
.49307 .60056 L
s
.49735 .63219 m
.48684 .60809 L
s
.4951 .62704 m
.49548 .63189 L
s
.49548 .63189 m
.4951 .63503 L
s
.48645 .6112 m
.4891 .61327 L
s
.4951 .63503 m
.4934 .63716 L
s
.48454 .61086 m
.48645 .6112 L
s
.4934 .63716 m
.4915 .63687 L
s
.48281 .61295 m
.48454 .61086 L
s
.4915 .63687 m
.48885 .63484 L
s
.48242 .61609 m
.48281 .61295 L
s
.48885 .63484 m
.486 .63035 L
s
.48278 .62097 m
.48242 .61609 L
s
.486 .63035 m
.48448 .62688 L
s
.48448 .62688 m
.48278 .62097 L
s
.48594 .64655 m
.48767 .64437 L
s
.48401 .64627 m
.48594 .64655 L
s
.48131 .64424 m
.48401 .64627 L
s
.47842 .63972 m
.48131 .64424 L
s
.48303 .65021 m
.47227 .62569 L
s
.47814 .65362 m
.47428 .64484 L
s
.47987 .65963 m
.47814 .65362 L
s
.48082 .66389 m
.47987 .65963 L
s
.48118 .66891 m
.48082 .66389 L
s
.47428 .64484 m
.47136 .64029 L
s
.48019 .67293 m
.48118 .66891 L
s
.47136 .64029 m
.46921 .63749 L
s
.46921 .63749 m
.46645 .63542 L
s
.47602 .67828 m
.48019 .67293 L
s
.46645 .63542 m
.46386 .63585 L
s
.46386 .63585 m
.45958 .64101 L
s
.47602 .67828 m
.45958 .64101 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1B0?oo
o`030000o`3oool0oooo01T0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo0540oooo00<0003o0?ooo`3oool05P3oool3000001@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool0IP3oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0C03oool30000oa<0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0B`3oool01@000?l0oooo0000o`3oool0003o
00h0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo0080
003o2P3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`000?l0
0P3oool00`000?l0oooo0000o`060?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0A@3o
ool00`000?l0oooo0000o`020?ooo`040000o`3oool0oooo0000o`<0oooo0`00000X0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003o
ool0oooo04@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0000o`3oool0003o00800000
:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`000?l0103o
ool01@000?l000000000o`000000003o02d0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0@03oool00`000?l0oooo0000o`020?ooo`80000000<0003o0?ooo`000?l00P3o
ool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo03h0oooo00H0003o0?ooo`000?l000000000o`0000030?ooo`80003o0P3oool00`000?l0oooo
0?ooo`0Z0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000
000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool01@000?l000000000
o`3oool0003o0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0Y0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`0i0?ooo`06000000000?l000000?ooo`000?l0oooo0P000?l20?ooo`03
0000o`3oool0oooo0300oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
9`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`000000
0P0000002`3oool0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0380oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo0340oooo00<000000000o`0000001@3oool00`000?l0oooo0000o`02
0?ooo`040000o`3oool0003o0000oc80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`000002
0?ooo`030000o`3oool0003o00<0oooo00H0003o0?ooo`3oool0003o0?ooo`000?le0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`0Y0?ooo`<000001@3oool00`000?l0oooo0000o`020000o`80oooo00<0
003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`000009
0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?oo
o`0b0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000303oool01`000?l0oooo0?ooo`3o
ool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?oo
o`0L0?ooo`@000003P3oool00`000?l0oooo0000o`020?ooo`060000o`3oool0003o0000o`3oool0
003o=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000100oooo0`000?l01@3oool0003o
0?ooo`3oool0003o0080oooo0P000?l30?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo01@0oooo0`00000C0?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool00`00
0?l0oooo0000o`040?ooo`80003o<`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001H0
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`040000o`3oool0oooo0000ocP0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000I0?ooo`040000o`3oool0oooo0000o`80oooo00<0
003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`08
0?ooo`<000006@3oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0003o0080003o0`3o
ool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000703oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo
0?ooo`0e0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000200oooo00@0003o0?ooo`3oool0003o
0P3oool20000o`030?ooo`000?l0oooo03/0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007`3oool20000o`80oooo00@0
003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo01h0oooo00D0
003o0?ooo`000?l0oooo0000o`030?ooo`030000o`3oool0003o03h0oooo0P00001K0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07P3o
ool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo0P000?lk0?ooo`<000000P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool07P3oool01P000?l0oooo0?ooo`000?l0oooo0000oc`0oooo100000060?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0N0?ooo`040000o`3oool0oooo0?ooo`<0003o00<0oooo0000
o`3oool0=@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01X0oooo00D0003o0?ooo`3o
ool0oooo0000o`020?ooo`030000o`3oool0oooo0080003o=03oool3000000h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo01X0oooo0P000?l20?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0<03oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`0b0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06@3o
ool010000?l0oooo0000o`000?l20?ooo`030000o`3oool0oooo02h0oooo1000000J0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0J0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo02H0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0F0?ooo`040000o`3oool0
oooo0?ooo`80003o00D0oooo0000o`3oool0oooo0000o`030?ooo`030000o`3oool0oooo02<0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0F0?ooo`040000o`3oool0oooo0?ooo`<0003o
00@0oooo0000o`3oool0003o0`3oool00`000?l0oooo0?ooo`0P0?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo
0?ooo`0E0?ooo`030000o`3oool0003o0080oooo0`000?l01@3oool0003o0?ooo`3oool0003o0080
oooo00<0003o0?ooo`3oool07@3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01D0oooo
00<0003o0?ooo`000?l00`3oool20000o`80oooo00H0003o0?ooo`3oool0003o0?ooo`000?lK0?oo
o`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool05P3oool010000?l0oooo0?ooo`000?l20?oo
o`<0003o1@3oool00`000?l0oooo0?ooo`0G0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool05P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0003o01`0oooo0`00000f0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0B0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool01000
0?l0oooo0?ooo`000?lJ0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04P3oool00`00
0?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool05@3oool3
000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo01<0oooo00D0003o0?ooo`3oool0oooo0000o`02
0?ooo`80003o5@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01<0oooo00D0003o0?oo
o`3oool0oooo0000o`030?ooo`030000o`3oool0oooo0100oooo0`0000170?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0?0?ooo`80003o0`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0403o
ool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00h0oooo00@0003o0?ooo`3oool0003o0P3o
ool00`000?l0oooo0?ooo`020?ooo`80003o3@3oool3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool03@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o0100oooo0`00001B0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo
00d0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0
oooo00H0oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool0
0240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`000?l00P000?l60?ooo`<00000F`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00h0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l40?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0?0?oo
o`030000o`3oool0oooo0080oooo00@0003o0?ooo`000?l0oooo0`00001R0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool01000
0?l0000000000000001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0403oool00`00
0?l0000000000002000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000000@0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00/0oooo0`0000020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
J03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0203oool3000000H0oooo00D0003o0?ooo`3oool0oooo
0000o`1[0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000002@3oool01@000?l0oooo0?oo
o`3oool0003o06`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<000003P3oool010000?l0oooo
0?ooo`000?m]0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo
0P00002A0?ooo`@000004@3oool010000?l0oooo0?ooo`000?m^0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<000005@3oool20000ofl0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo06l0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`28
0?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.58586 .54235 m
.58584 .54421 L
s
.58475 .54096 m
.58586 .54235 L
s
.59617 .57503 m
.58856 .55232 L
s
.58584 .54421 m
.58473 .54282 L
s
.58473 .54282 m
.58475 .54096 L
s
.58622 .56079 m
.58675 .56431 L
s
.58239 .54937 m
.58184 .54774 L
s
.58291 .55288 m
.58239 .54937 L
s
.58184 .54774 m
.58017 .54471 L
s
.58675 .56431 m
.58559 .5667 L
s
.58232 .555 m
.58291 .55288 L
s
.58017 .54471 m
.57791 .54379 L
s
.58 .55787 m
.58232 .555 L
s
.58559 .5667 m
.58388 .56746 L
s
.57791 .54379 m
.57618 .54451 L
s
.58388 .56746 m
.58161 .56658 L
s
.57618 .54451 m
.57499 .54687 L
s
.5794 .56001 m
.58 .55787 L
s
.58161 .56658 m
.57993 .56355 L
s
.57993 .56355 m
.5794 .56001 L
s
.57499 .54687 m
.57552 .5504 L
s
.57646 .56507 m
.5764 .56889 L
s
.56974 .54905 m
.57202 .55186 L
s
.5764 .56889 m
.57579 .57106 L
s
.56801 .54788 m
.56974 .54905 L
s
.57579 .57106 m
.57404 .57184 L
s
.56624 .54861 m
.56801 .54788 L
s
.57404 .57184 m
.57231 .5707 L
s
.56561 .55076 m
.56624 .54861 L
s
.57231 .5707 m
.57001 .5679 L
s
.56554 .55459 m
.56561 .55076 L
s
.57001 .5679 m
.56774 .56316 L
s
.56663 .55983 m
.56554 .55459 L
s
.56774 .56316 m
.56663 .55983 L
s
.57147 .58644 m
.57144 .58838 L
s
.57032 .58504 m
.57147 .58644 L
s
.57144 .58838 m
.57028 .58698 L
s
.57028 .58698 m
.57032 .58504 L
s
.56695 .575 m
.55908 .55157 L
s
.55989 .5704 m
.55424 .55357 L
s
.56098 .57572 m
.55989 .5704 L
s
.56034 .57794 m
.56098 .57572 L
s
.55852 .57875 m
.56034 .57794 L
s
.55673 .5776 m
.55852 .57875 L
s
.55319 .57333 m
.55673 .5776 L
s
.55946 .59198 m
.54749 .55636 L
s
.5471 .57207 m
.54595 .56866 L
s
.5482 .57746 m
.5471 .57207 L
s
.54595 .56866 m
.54361 .5638 L
s
.5481 .58143 m
.5482 .57746 L
s
.54361 .5638 m
.5412 .5609 L
s
.54743 .58369 m
.5481 .58143 L
s
.5412 .5609 m
.53937 .55971 L
s
.54555 .58453 m
.54743 .58369 L
s
.53937 .55971 m
.53747 .5605 L
s
.54372 .58337 m
.54555 .58453 L
s
.53747 .5605 m
.53678 .56274 L
s
.5413 .58048 m
.54372 .58337 L
s
.53678 .56274 m
.53667 .56671 L
s
.54304 .58565 m
.53088 .54949 L
s
.5386 .58762 m
.53045 .5634 L
s
.53685 .58243 m
.53674 .58646 L
s
.52975 .56566 m
.5322 .56859 L
s
.53674 .58646 m
.53604 .58876 L
s
.52787 .56446 m
.52975 .56566 L
s
.53604 .58876 m
.53411 .58962 L
s
.52592 .56527 m
.52787 .56446 L
s
.53411 .58962 m
.53224 .58845 L
s
.52521 .56755 m
.52592 .56527 L
s
.53224 .58845 m
.52977 .58554 L
s
.52508 .57158 m
.52521 .56755 L
s
.52977 .58554 m
.52736 .58059 L
s
.52618 .57709 m
.52508 .57158 L
s
.52736 .58059 m
.52618 .57709 L
s
.52566 .59338 m
.52763 .59251 L
s
.52375 .59221 m
.52566 .59338 L
s
.52125 .58927 m
.52375 .59221 L
s
.51881 .58428 m
.52125 .58927 L
s
.52237 .59485 m
.51406 .57017 L
s
.51957 .60017 m
.5201 .60401 L
s
.51144 .58746 m
.5148 .586 L
s
.51301 .58069 m
.5148 .586 L
s
.51115 .57743 m
.51301 .58069 L
s
.5201 .60401 m
.51995 .60816 L
s
.5086 .57445 m
.51115 .57743 L
s
.51995 .60816 m
.51921 .61055 L
s
.50665 .57323 m
.5086 .57445 L
s
.51921 .61055 m
.51653 .61179 L
s
.50392 .57436 m
.50665 .57323 L
s
.51653 .61179 m
.51458 .61063 L
s
.50315 .57671 m
.50392 .57436 L
s
.51458 .61063 m
.51202 .60768 L
s
.50299 .58086 m
.50315 .57671 L
s
.51202 .60768 m
.51014 .60441 L
s
.50351 .58473 m
.50299 .58086 L
s
.51014 .60441 m
.50765 .59935 L
s
.50463 .59039 m
.50351 .58473 L
s
.50765 .59935 m
.50463 .59039 L
s
.50413 .60297 m
.49285 .57893 L
s
.49858 .60544 m
.49285 .57893 L
s
.49858 .60544 m
.48721 .58126 L
s
.49296 .60794 m
.48721 .58126 L
s
.48799 .61016 m
.47934 .58452 L
s
.48613 .60467 m
.48594 .60896 L
s
.47851 .58695 m
.48119 .59001 L
s
.48594 .60896 m
.48512 .61144 L
s
.47644 .58571 m
.47851 .58695 L
s
.48512 .61144 m
.48296 .6124 L
s
.47426 .58661 m
.47644 .58571 L
s
.48296 .6124 m
.48089 .6112 L
s
.47342 .58906 m
.47426 .58661 L
s
.48089 .6112 m
.47819 .60815 L
s
.4732 .59337 m
.47342 .58906 L
s
.47819 .60815 m
.47559 .60292 L
s
.47434 .59922 m
.4732 .59337 L
s
.47559 .60292 m
.47434 .59922 L
s
.47347 .61662 m
.47568 .61564 L
s
.47136 .61542 m
.47347 .61662 L
s
.46862 .61234 m
.47136 .61542 L
s
.46598 .60707 m
.46862 .61234 L
s
.46977 .61827 m
.46094 .59212 L
s
.4639 .61873 m
.46073 .60933 L
s
.46505 .6247 m
.4639 .61873 L
s
.46073 .60933 m
.45807 .60402 L
s
.46557 .6288 m
.46505 .6247 L
s
.45807 .60402 m
.45604 .60058 L
s
.46533 .63325 m
.46557 .6288 L
s
.45604 .60058 m
.45324 .59745 L
s
.4637 .63618 m
.46533 .63325 L
s
.45324 .59745 m
.45031 .59651 L
s
.45838 .63863 m
.4637 .63618 L
s
.45031 .59651 m
.4449 .59875 L
s
.45838 .63863 m
.4449 .59875 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000000h0oooo00<0003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool0=@3oool3000000h0oooo0P000?l00`3oool0003o0?ooo`0Z0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0a0?ooo`<000003P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo02X0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo02d0oooo0`0000030?ooo`030000o`3oool0oooo00X0oooo0P00
0?l01@3oool0003o0?ooo`3oool0003o02`0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00
00060?ooo`030000o`3oool0oooo00L0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l30?ooo`03
0000o`3oool0003o02X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000X0oooo00<0003o0?ooo`3oool0
1@3oool20000o`80oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000o`0Z0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`0Q0?ooo`<000003@3oool00`000?l0oooo0?ooo`020?ooo`080000o`3o
ool0oooo0000o`3oool0003o0?ooo`000?l40?ooo`050000o`3oool0oooo0?ooo`000?l0:@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0703oool400000100oooo10000?l00`3oool0003o0?ooo`020?oo
o`80003o00<0oooo0000o`3oool00`3oool01@000?l0oooo0000o`3oool0003o02X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo01P0oooo0`00000C0?ooo`<0003o0P3oool00`000?l0oooo0000o`020?oo
o`80003o0P3oool02@000?l0oooo0?ooo`3oool0003o0?ooo`000?l0oooo0000o`0Z0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`0D0?ooo`<00000503oool30000o`070?ooo`000?l0oooo0?ooo`000?l0
oooo0000o`020?ooo`050000o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`020000
o`030?ooo`000?l0oooo02P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000G0?ooo`03
0000o`3oool0003o0080003o0P3oool00`000?l0oooo0000o`030?ooo`80003o00D0oooo0000o`3o
ool0oooo0000o`020?ooo`040000o`3oool0oooo0000obT0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
00`0oooo0`00000F0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool20000o`<0oooo00<0003o
0?ooo`000?l00P3oool20000o`80oooo0`000?l50?ooo`030000o`3oool0oooo02L0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000E0?ooo`<0003o00<0oooo0000o`3oool00P3oool01P00
0?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000
o`0:0?ooo`030000o`3oool0oooo02H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000G
0?ooo`040000o`3oool0oooo0000o`80oooo00@0003o0?ooo`3oool0003o0`3oool20000o`80oooo
00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`0:0?ooo`030000o`3oool0oooo02H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo00<000005`3oool010000?l0oooo0?ooo`000?l20?ooo`040000
o`3oool0oooo0000o`80oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`030000o`3oool0003o
00<0003o=@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo08`0oooo0P00000H0?ooo`030000o`3oool0003o0080oooo00L0003o0?ooo`3o
ool0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool00`000?l01@3oool0003o0?ooo`3o
ool0003o03L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2
000008d0oooo00<000000?ooo`3oool0503oool01@000?l0oooo0?ooo`000?l0oooo0080003o0P3o
ool01@000?l0oooo0?ooo`000?l0oooo0080003o0P3oool00`000?l0oooo0?ooo`050000o`80oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0^0?ooo`800000F`3oool00`000000oooo
0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0180oooo0`00
0?l20?ooo`80003o00D0oooo0000o`3oool0oooo0000o`020?ooo`@0003o0P3oool00`000?l0oooo
0?ooo`030000o`@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0[0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`020000o`80oooo00H0
003o0?ooo`000?l0003o0?ooo`000?l50?ooo`040000o`3oool0oooo0?ooo`<0003o1`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02L0oooo100000060?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`040000
o`030?ooo`000?l0oooo00D0oooo0`000?l:0?ooo`030000o`3oool0oooo02T0oooo0`00000:0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`030000o`030?ooo`000?l0003o00H0oooo00<0003o0?ooo`3oool0<`3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo00L0oooo10000?l30?ooo`050000o`3oool0oooo0?oo
o`000?l00P3oool02P000?l0oooo0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?lh0?ooo`<0
00004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040000o`3oool0003o0?ooo`80003o00<0oooo
0000o`000?l0103oool00`000?l0oooo0?ooo`0^0?ooo`<000005P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0203oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3oool01@000?l0oooo0?oo
o`3oool0003o0080oooo00@0003o0?ooo`000?l0oooo0P000?l40?ooo`030000o`3oool0oooo02X0
oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`080?ooo`070000o`3oool0oooo0?ooo`00
0?l0oooo0000o`030?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0000o`03
0?ooo`050000o`3oool0oooo0?ooo`000?l0:@3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0
oooo0080003o00<0oooo0000o`3oool01@3oool010000?l0oooo0?ooo`000?lV0?ooo`<000008P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool02@3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`80003o
0`3oool40000o`T0oooo0P000?lT0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`090?ooo`060000o`3o
ool0oooo0?ooo`000?l0oooo0P000?lc0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o0080003o;@3oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo00/0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o02`0
oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0;0?ooo`050000o`3oool0oooo0?ooo`00
0?l0:`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00/0oooo00D0003o0?ooo`3oool0
oooo0000o`0X0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0303oool010000?l0oooo
0?ooo`000?lU0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0303oool010000?l0oooo
0?ooo`000?lQ0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0303oool010000?l0oooo
0?ooo`000?lN0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool03@3oool00`000?l0oooo
0000o`0K0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool03@3oool20000oaT0oooo0`00
001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>
0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3o
ool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4
000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool30000
06l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000
001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<00000
0?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0
oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo
0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3
000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0
oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<0
00000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[
0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3
000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo
00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3
000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo
09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W
0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3
000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`08
0?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?oo
o`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000
S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
1P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?oo
o`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P000004
0?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3o
ool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000
O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?oo
o`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0
oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`00
0000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3o
ool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3o
ool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0
oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000
oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo
0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`80
0000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0
oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo
0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo
00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0
oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<00000
0?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?oo
o`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D0
00005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@00000
6`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool0
0`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool20000
03`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?oo
o`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q
0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?oo
o`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?oo
o`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?oo
o`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?oo
o`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3o
ool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3o
ool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3o
ool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool0
08H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@0
00000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00
000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3o
ool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0
CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3o
ool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool0
09H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000
oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000
oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo
0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo
1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00
000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R
0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d
0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?oo
o`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?oo
o`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0
000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0
oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0
5P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3o
ool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@00
0000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`000006
0?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`80
0000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59752 .57836 m
.59728 .57992 L
s
.59644 .57664 m
.59752 .57836 L
s
.5962 .57819 m
.59644 .57664 L
s
.59728 .57992 m
.5962 .57819 L
s
.6052 .61117 m
.59936 .58813 L
s
.5924 .58091 m
.5909 .57752 L
s
.59282 .58256 m
.5924 .58091 L
s
.59299 .58578 m
.59282 .58256 L
s
.5909 .57752 m
.58848 .57562 L
s
.59575 .59412 m
.59593 .59736 L
s
.59208 .58728 m
.59299 .58578 L
s
.59593 .59736 m
.59435 .59881 L
s
.58848 .57562 m
.58647 .57536 L
s
.58916 .58855 m
.59208 .58728 L
s
.59435 .59881 m
.59235 .5986 L
s
.58647 .57536 m
.58487 .57676 L
s
.58823 .59006 m
.58916 .58855 L
s
.59235 .5986 m
.58992 .59672 L
s
.58487 .57676 m
.58504 .58 L
s
.5884 .59331 m
.58823 .59006 L
s
.58992 .59672 m
.5884 .59331 L
s
.57876 .57599 m
.58097 .5795 L
s
.58434 .59287 m
.58383 .59607 L
s
.57697 .57414 m
.57876 .57599 L
s
.57491 .57387 m
.57697 .57414 L
s
.58383 .59607 m
.58289 .5976 L
s
.58289 .5976 m
.58084 .59739 L
s
.57396 .57538 m
.57491 .57387 L
s
.57342 .57857 m
.57396 .57538 L
s
.58084 .59739 m
.57904 .59556 L
s
.57904 .59556 m
.57682 .59204 L
s
.574 .58353 m
.57342 .57857 L
s
.57682 .59204 m
.57485 .5869 L
s
.57485 .5869 m
.574 .58353 L
s
.57255 .59652 m
.56659 .57281 L
s
.57624 .60847 m
.57597 .6101 L
s
.57511 .6067 m
.57624 .60847 L
s
.57485 .60834 m
.57511 .6067 L
s
.57597 .6101 m
.57485 .60834 L
s
.56523 .58911 m
.56096 .57208 L
s
.56581 .59415 m
.56523 .58911 L
s
.56483 .59571 m
.56581 .59415 L
s
.5627 .59548 m
.56483 .59571 L
s
.56085 .59362 m
.5627 .59548 L
s
.55741 .58823 m
.56085 .59362 L
s
.56215 .60715 m
.55311 .57108 L
s
.54992 .58068 m
.54789 .57542 L
s
.55078 .58413 m
.54992 .58068 L
s
.55135 .58924 m
.55078 .58413 L
s
.54789 .57542 m
.54557 .57178 L
s
.55076 .59254 m
.55135 .58924 L
s
.54557 .57178 m
.54368 .56987 L
s
.54368 .56987 m
.54148 .56958 L
s
.54974 .59412 m
.55076 .59254 L
s
.54755 .59389 m
.54974 .59412 L
s
.54148 .56958 m
.54044 .57113 L
s
.54044 .57113 m
.53983 .57442 L
s
.54565 .592 m
.54755 .59389 L
s
.54461 .59358 m
.53549 .55705 L
s
.5433 .58835 m
.54565 .592 L
s
.53942 .59304 m
.53332 .56854 L
s
.53226 .57009 m
.53462 .57378 L
s
.53811 .58778 m
.5375 .59113 L
s
.53032 .56815 m
.53226 .57009 L
s
.52806 .56786 m
.53032 .56815 L
s
.5375 .59113 m
.53644 .59272 L
s
.53644 .59272 m
.53419 .59249 L
s
.52698 .56943 m
.52806 .56786 L
s
.52634 .57276 m
.52698 .56943 L
s
.53419 .59249 m
.53224 .59057 L
s
.53224 .59057 m
.52985 .58687 L
s
.5269 .57796 m
.52634 .57276 L
s
.52985 .58687 m
.52778 .58149 L
s
.52778 .58149 m
.5269 .57796 L
s
.52432 .59145 m
.52661 .59169 L
s
.52234 .58951 m
.52432 .59145 L
s
.51991 .58578 m
.52234 .58951 L
s
.52047 .59105 m
.51428 .56609 L
s
.51781 .58034 m
.51991 .58578 L
s
.51182 .57444 m
.51315 .57981 L
s
.51015 .57076 m
.51182 .57444 L
s
.50923 .57936 m
.51315 .57981 L
s
.5077 .56698 m
.51015 .57076 L
s
.5167 .59415 m
.51681 .59766 L
s
.50568 .56499 m
.5077 .56698 L
s
.51681 .59766 m
.51614 .60111 L
s
.50252 .56458 m
.50568 .56499 L
s
.51614 .60111 m
.51502 .60276 L
s
.51502 .60276 m
.51188 .60247 L
s
.50137 .56618 m
.50252 .56458 L
s
.50067 .56959 m
.50137 .56618 L
s
.51188 .60247 m
.50985 .60051 L
s
.50077 .57311 m
.50067 .56959 L
s
.50985 .60051 m
.50737 .59673 L
s
.50131 .57844 m
.50077 .57311 L
s
.50737 .59673 m
.50568 .59303 L
s
.50354 .5875 m
.50131 .57844 L
s
.50568 .59303 m
.50354 .5875 L
s
.49919 .58881 m
.48967 .56294 L
s
.49271 .58813 m
.48967 .56294 L
s
.49271 .58813 m
.48313 .5621 L
s
.48616 .58744 m
.48313 .5621 L
s
.48035 .58684 m
.474 .56093 L
s
.47278 .56256 m
.47536 .56647 L
s
.47899 .58128 m
.47823 .5848 L
s
.47065 .56049 m
.47278 .56256 L
s
.46811 .56017 m
.47065 .56049 L
s
.47823 .5848 m
.47701 .58648 L
s
.47701 .58648 m
.47449 .58622 L
s
.46688 .56181 m
.46811 .56017 L
s
.46609 .56533 m
.46688 .56181 L
s
.47449 .58622 m
.47234 .58418 L
s
.47234 .58418 m
.46974 .58026 L
s
.4666 .57082 m
.46609 .56533 L
s
.46974 .58026 m
.46752 .57456 L
s
.46752 .57456 m
.4666 .57082 L
s
.46342 .58506 m
.466 .58533 L
s
.46124 .58299 m
.46342 .58506 L
s
.45859 .57903 m
.46124 .58299 L
s
.45911 .5846 m
.45267 .55819 L
s
.45635 .57327 m
.45859 .57903 L
s
.45024 .57257 m
.44797 .56677 L
s
.45255 .58206 m
.45024 .57257 L
s
.44797 .56677 m
.44617 .56287 L
s
.45306 .58768 m
.45255 .58206 L
s
.44617 .56287 m
.44348 .55885 L
s
.45311 .5914 m
.45306 .58768 L
s
.44348 .55885 m
.44036 .55661 L
s
.45227 .59505 m
.45311 .5914 L
s
.44036 .55661 m
.4341 .5558 L
s
.45009 .59671 m
.45227 .59505 L
s
.44387 .59613 m
.45009 .59671 L
s
.44387 .59613 m
.4341 .5558 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
00d0oooo00<0003o0?ooo`3oool05@3oool3000004T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00`0
oooo0`000?l40?ooo`030000o`3oool0oooo00/0oooo0`00000>0?ooo`030000o`3oool0oooo03/0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo00/0oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0
oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool01000000A0?ooo`030000o`3oool0oooo03`0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo00/0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0
oooo0?ooo`020?ooo`090000o`3oool0003o0000o`000000oooo0000o`3oool0003o0140oooo00<0
003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool02P3oool01@000?l0oooo0?ooo`3o
ool0003o0080oooo00P0003o0?ooo`3oool000000000o`000000oooo0000o`80oooo00<0003o0?oo
o`000?l0103oool20000o`<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0k0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool01@00
0?l000000000003oool0003o00<0oooo00<0003o0?ooo`000?l00`000?l30?ooo`030000o`3oool0
003o0080oooo00@0003o0?ooo`3oool0oooo10000?l00`3oool0003o0?ooo`0l0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`080?ooo`080000o`3oool0oooo0?ooo`000000003o000000000?l30?ooo`06
0000o`3oool0oooo0?ooo`000?l0oooo0P000?l00`3oool0003o0?ooo`020?ooo`060000o`3oool0
oooo0000o`3oool0003o0`3oool01@000?l0oooo0000o`000?l0oooo00<0003o0P3oool010000?l0
oooo0?ooo`000?le0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`070?ooo`080000o`00000000000000
003oool0003o0?ooo`000?l30?ooo`080000o`3oool0oooo0?ooo`000?l0oooo0000o`3oool30000
o`80oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00P0003o0?ooo`3oool0003o
0?ooo`000?l0oooo0000o`80oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`80003o;`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0103oool3000000070000o`3oool0oooo0?ooo`000?l0oooo
0000o`030?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool40000o`80oooo00L0003o0?ooo`3o
ool0oooo0000o`3oool0003o0080oooo00/0003o0?ooo`3oool0oooo0000o`3oool0003o0?ooo`00
0?l0oooo0000o`030?ooo`80003o0P3oool010000?l0oooo0000o`3oool30000o`030?ooo`000?l0
oooo02L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000000`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0003o00<0oooo00@0003o0?ooo`3oool0003o0P3oool010000?l0oooo0000o`00
0?l20?ooo`030000o`3oool0oooo0080003o00D0oooo0000o`3oool0oooo0000o`030?ooo`050000
o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020000o`80oooo00<0003o0?ooo`3o
ool00P000?l00`3oool0003o0?ooo`020000obL0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000001P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o
0?ooo`030000o`030?ooo`000?l0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`03
0000o`3oool0003o0080oooo00<0003o0?ooo`000?l00P3oool01@000?l0oooo0000o`3oool0003o
00H0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`000?l00`000?l00`3oool0003o0?ooo`020000o`040?ooo`000?l0oooo0?oo
o`80003o0P3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`000?l0oooo0000o`020?ooo`030000o`3oool0003o0080oooo00D0003o0?ooo`000?l0oooo0000
o`060?ooo`030000o`3oool0oooo02H0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00D0oooo0`000?l02@3oool0003o0?ooo`3oool0003o0?ooo`000?l0
oooo0000o`050?ooo`040000o`3oool0oooo0000o`<0oooo00H0003o0?ooo`000?l0oooo0000o`3o
ool20000o`80oooo0P000?l00`3oool0003o0?ooo`050?ooo`030000o`3oool0003o02<0oooo0`00
00020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0403o
ool00`000?l0oooo0000o`050?ooo`80003o0P3oool00`000?l0oooo0000o`030000o`030?ooo`00
0?l0oooo0080003o0P3oool20000o`030?ooo`000?l0oooo00<0oooo0P000?l20?ooo`030000o`3o
ool0oooo01d0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`060?ooo`050000o`3oool0
oooo0?ooo`000?l04P3oool00`000?l0oooo0?ooo`030?ooo`<0003o0P3oool30000o`040?ooo`00
0?l0oooo0000o`80oooo0P000?l01P3oool0003o0?ooo`000?l0oooo0000o`80oooo0P000?l40?oo
o`030000o`3oool0oooo01T0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`060?ooo`80
003o00<0oooo0000o`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0
oooo0P000?l20?ooo`060000o`3oool0003o0000o`3oool0003o0P3oool010000?l0oooo0000o`00
0?l20?ooo`030000o`3oool0003o01P0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`08
0?ooo`80003o503oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`020000o`80oooo0`000?l00`3oool0003o0?ooo`0D0?ooo`<000004P3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0000o`0?0?ooo`030000o`3oool0
oooo00h0oooo00<0003o0?ooo`3oool03`3oool3000001H0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
0200oooo0P000?l@0?ooo`030000o`3oool0oooo00d0oooo00<0003o0?ooo`3oool02`3oool40000
01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo00P0oooo0`00000N0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0b0?ooo`030000o`3oool0oooo0080oooo0P000?l:0?ooo`030000o`3oool0oooo00@0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo00P0oooo00@0
003o0?ooo`3oool0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
4@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool30000
03<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?oo
o`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0
oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool0
0240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?oo
o`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
3P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000
00230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@
0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@0
00001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0
oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@0
0000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0
oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo
0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<0
00000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0
V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool0
0`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0
oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo
0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N
0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000
003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool0
0`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0
oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo
0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<0
00000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m
0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000
003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3o
ool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3
000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo
0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000
oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3o
ool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?oo
o`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3o
ool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3o
ool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0
]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo
00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo
000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000
Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool0
0`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`00
0000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo0000
07`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo
0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00
001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?oo
o`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo
0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00
001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?oo
o`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`05
0000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`00
0000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480
oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?oo
o`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<00000
0?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<00000
0?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool0
00000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?oo
o`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3o
ool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?oo
o`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`800000
3`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3o
ool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3o
ool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo
00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0
oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3o
ool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool00000
0?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00
001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?oo
o`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`800000
0P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3o
ool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool0
0`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo
1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00
000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000
=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03o
ool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool0
0`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool01000
0000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool0
06P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0
000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool20000
02d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo
0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo
0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?oo
o`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z
0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?oo
o`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D0
0000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@0
0000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool20000
01`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0
oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo
0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J
0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N
0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?oo
o`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00
I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3o
ool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003o
ool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0
oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool01000
0000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool5
00000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0
oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo
0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000
003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool0
10000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool0
0:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool5
00000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L
0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool0
0:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60632 .61467 m
.60587 .61587 L
s
.60532 .61266 m
.60632 .61467 L
s
.60487 .61386 m
.60532 .61266 L
s
.60587 .61587 m
.60487 .61386 L
s
.61109 .64646 m
.60723 .62389 L
s
.6003 .61426 m
.59901 .61064 L
s
.60057 .61588 m
.6003 .61426 L
s
.59901 .61064 m
.59653 .60781 L
s
.60038 .6187 m
.60057 .61588 L
s
.59918 .61951 m
.60038 .6187 L
s
.59653 .60781 m
.59431 .60658 L
s
.60249 .62718 m
.6023 .63002 L
s
.59576 .61913 m
.59918 .61951 L
s
.6023 .63002 m
.60037 .63046 L
s
.59431 .60658 m
.59236 .60697 L
s
.60037 .63046 m
.59815 .62927 L
s
.59236 .60697 m
.59216 .6098 L
s
.59455 .61995 m
.59576 .61913 L
s
.59815 .62927 m
.59565 .62645 L
s
.59435 .6228 m
.59455 .61995 L
s
.59565 .62645 m
.59435 .6228 L
s
.58562 .60326 m
.58767 .60734 L
s
.58384 .6008 m
.58562 .60326 L
s
.58158 .59954 m
.58384 .6008 L
s
.58986 .62038 m
.58891 .62285 L
s
.58033 .60034 m
.58158 .59954 L
s
.58891 .62285 m
.58768 .62368 L
s
.57936 .60277 m
.58033 .60034 L
s
.58768 .62368 m
.58541 .62246 L
s
.57941 .60728 m
.57936 .60277 L
s
.58541 .62246 m
.58361 .62001 L
s
.58361 .62001 m
.58154 .6159 L
s
.57996 .61056 m
.57941 .60728 L
s
.58154 .6159 m
.57996 .61056 L
s
.57624 .61757 m
.57241 .59448 L
s
.57893 .62958 m
.57844 .63084 L
s
.57789 .62751 m
.57893 .62958 L
s
.56895 .60761 m
.56622 .59106 L
s
.57739 .62877 m
.57789 .62751 L
s
.57844 .63084 m
.57739 .62877 L
s
.56899 .61218 m
.56895 .60761 L
s
.5677 .613 m
.56899 .61218 L
s
.56535 .61175 m
.5677 .613 L
s
.56334 .62139 m
.5576 .58629 L
s
.56351 .60924 m
.56535 .61175 L
s
.56032 .60296 m
.56351 .60924 L
s
.55126 .58736 m
.54912 .58313 L
s
.55288 .59282 m
.55126 .58736 L
s
.55342 .59617 m
.55288 .59282 L
s
.55344 .60078 m
.55342 .59617 L
s
.54912 .58313 m
.54724 .58057 L
s
.54724 .58057 m
.54482 .57924 L
s
.55239 .60328 m
.55344 .60078 L
s
.54482 .57924 m
.54348 .58002 L
s
.55105 .60411 m
.55239 .60328 L
s
.5454 .60108 m
.53969 .56569 L
s
.54348 .58002 m
.5424 .5825 L
s
.54864 .60282 m
.55105 .60411 L
s
.54675 .60026 m
.54864 .60282 L
s
.54458 .596 m
.54675 .60026 L
s
.53969 .59803 m
.53588 .57429 L
s
.53451 .57508 m
.53669 .57936 L
s
.53259 .57248 m
.53451 .57508 L
s
.53011 .57111 m
.53259 .57248 L
s
.53887 .59293 m
.53777 .59545 L
s
.52873 .57189 m
.53011 .57111 L
s
.53777 .59545 m
.5364 .59628 L
s
.52761 .57438 m
.52873 .57189 L
s
.5364 .59628 m
.53392 .59495 L
s
.52759 .57904 m
.52761 .57438 L
s
.53392 .59495 m
.53199 .59235 L
s
.53199 .59235 m
.52978 .58804 L
s
.52813 .58246 m
.52759 .57904 L
s
.52978 .58804 m
.52813 .58246 L
s
.52306 .58915 m
.52558 .5905 L
s
.51883 .58689 m
.51503 .56278 L
s
.5211 .58652 m
.52306 .58915 L
s
.51886 .58216 m
.5211 .58652 L
s
.5172 .57653 m
.51886 .58216 L
s
.51127 .56857 m
.51208 .57376 L
s
.50988 .56465 m
.51127 .56857 L
s
.50762 .56026 m
.50988 .56465 L
s
.50779 .57143 m
.51208 .57376 L
s
.50563 .55758 m
.50762 .56026 L
s
.50217 .55567 m
.50563 .55758 L
s
.51426 .58763 m
.51394 .59065 L
s
.51394 .59065 m
.51277 .59323 L
s
.50071 .55644 m
.50217 .55567 L
s
.51277 .59323 m
.51132 .59407 L
s
.49951 .55896 m
.50071 .55644 L
s
.51132 .59407 m
.50786 .59225 L
s
.49917 .56197 m
.49951 .55896 L
s
.49911 .56672 m
.49917 .56197 L
s
.50786 .59225 m
.50585 .58959 L
s
.50046 .57547 m
.49911 .56672 L
s
.50585 .58959 m
.50356 .58516 L
s
.50215 .58119 m
.50046 .57547 L
s
.50356 .58516 m
.50215 .58119 L
s
.49546 .5744 m
.48815 .54792 L
s
.48836 .57061 m
.48815 .54792 L
s
.48836 .57061 m
.48102 .54398 L
s
.48118 .56677 m
.48102 .54398 L
s
.47483 .56338 m
.47108 .53849 L
s
.46952 .53925 m
.47188 .5438 L
s
.46743 .53647 m
.46952 .53925 L
s
.46467 .53495 m
.46743 .53647 L
s
.47403 .55803 m
.47274 .56062 L
s
.4631 .53571 m
.46467 .53495 L
s
.47274 .56062 m
.47118 .56142 L
s
.46178 .53826 m
.4631 .53571 L
s
.47118 .56142 m
.46842 .55995 L
s
.46165 .54312 m
.46178 .53826 L
s
.46842 .55995 m
.4663 .55717 L
s
.4663 .55717 m
.46392 .55259 L
s
.46219 .5467 m
.46165 .54312 L
s
.46392 .55259 m
.46219 .5467 L
s
.45633 .55349 m
.45914 .55499 L
s
.45161 .55097 m
.44789 .52567 L
s
.45418 .55067 m
.45633 .55349 L
s
.45176 .54604 m
.45418 .55067 L
s
.45001 .5401 m
.45176 .54604 L
s
.44161 .53053 m
.44012 .52638 L
s
.44336 .5365 m
.44161 .53053 L
s
.44012 .52638 m
.43767 .52169 L
s
.44469 .54559 m
.44336 .5365 L
s
.43767 .52169 m
.43452 .51829 L
s
.44453 .55055 m
.44469 .54559 L
s
.43452 .51829 m
.42773 .51453 L
s
.44411 .5537 m
.44453 .55055 L
s
.44272 .55635 m
.44411 .5537 L
s
.4401 .55667 m
.44272 .55635 L
s
.43329 .55309 m
.42773 .51453 L
s
.43329 .55309 m
.4401 .55667 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0I0?oo
o`80003oA`3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0H0?ooo`04
0000o`3oool0003o0000od80oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0G0?ooo`04
0000o`3oool0oooo0000och0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0F0?ooo`05
0000o`3oool0oooo0?ooo`000?l0>P3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo01H0
oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo0340oooo0`00000X0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`03
0000003oool0oooo01D0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo
02h0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0503oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0003o02d0oooo0`00000^0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0000o`0Z0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`0B0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l01@3oool20000ob00oooo0`00
000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0003o00@0oooo00<0003o0?ooo`3oool00P000?lK0?ooo`<00000=`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo
0000o`<0oooo00<0003o0?ooo`3oool00P000?lH0?ooo`<00000>P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool0403oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00<0oooo00D0003o0?oo
o`3oool0oooo0000o`020?ooo`030000o`3oool0oooo0100oooo0`00000m0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l00`3oool01@00
0?l0oooo0?ooo`3oool0003o0080oooo00@0003o0?ooo`3oool0003o303oool300000400oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`00
0?l20?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool20000o`030?ooo`000?l0oooo00P0oooo
0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`0=0?ooo`050000o`3oool0oooo0?ooo`000?l0
0P3oool20000o`<0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`030?ooo`000?l0003o
00D0oooo0`0000160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo0`0000210?ooo`030000003oool0oooo00d0oooo0P000?l00`3oool0003o0?ooo`030?ooo`80
003o00<0oooo0000o`3oool00P3oool01@000?l0oooo0000o`000?l0oooo0080003o0P3oool00`00
0000003o000000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0>0?ooo`80003o203oool01@000?l0
oooo0?ooo`000?l0oooo0080003o00<0oooo0000o`000?l00P0000000`3oool0003o0000o`190?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0H0?ooo`<0003o00<0oooo0000o`0000000`000?l20?ooo`04
0000o`3oool0oooo0000odT0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo00D000000000o`00
0000003o0?ooo`020000o`040?ooo`000?l0oooo0000o`80oooo00@0003o0?ooo`3oool0003oAP3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0503oool3000000<0oooo00P0003o0?ooo`000?l0003o0?oo
o`000?l0oooo0000o`<0oooo00<0003o0?ooo`000?l0203oool00`000?l0oooo0?ooo`0k0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`0@0?ooo`<000002@3oool01@000?l0oooo0000o`3oool0003o00@0
oooo0P000?l80?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo
0`00000<0?ooo`030000o`3oool0oooo0080003o0P3oool010000?l0oooo0000o`000?l40?ooo`80
003o0P3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000
4P3oool20000o`<0oooo0`000?l40?ooo`80003o00<0oooo0000o`000?l0?@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0103oool3000001H0oooo00<0003o0?ooo`3oool0103oool01P000?l0oooo0?oo
o`3oool0003o0?ooo`80003o00<0oooo0000o`3oool0>`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000I0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`04
0000o`3oool0003o0000oc/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007@3oool00`000?l0oooo0?ooo`030?ooo`05
0000o`3oool0oooo0?ooo`000?l00P3oool01@000?l0oooo0000o`3oool0003o03X0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?oo
o`3oool07@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03H0oooo0P00001K0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07@3oool01000
0?l0oooo0?ooo`3oool30000o`80oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`040000o`3o
ool0oooo0000oc80oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0M0?ooo`040000o`3o
ool0oooo0000o`<0oooo0`000?l30?ooo`80003o0P3oool010000?l0oooo0?ooo`000?l^0?ooo`@0
00001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0000o`060?ooo`060000
o`3oool0oooo0000o`3oool0003o0P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo
02H0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`80003o1`3oool30000o`07
0?ooo`000?l0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0003o02<0oooo0`00000>
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0003o0080oooo00P0003o0?oo
o`3oool0003o0?ooo`000?l0oooo0000ob00oooo0`00000B0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0/0?ooo`80003o00T0oooo0000o`3oool0oooo0000o`3oool0003o0?ooo`000?l00P3oool30000
oaP0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0]0?ooo`<0003o0P3oool02P000?l0
oooo0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?lD0?ooo`@000006P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0<P3oool02P000?l0oooo0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?l2
0?ooo`030000o`3oool0oooo00`0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?oo
o`80003o00H0oooo0000o`3oool0003o0?ooo`000?l20?ooo`040000o`3oool0003o0000o`X0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0b0?ooo`080000o`3oool0003o0000o`3oool0
003o0?ooo`000?l40?ooo`030000o`3oool0003o00H0oooo0`00000V0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo03<0
oooo00<0003o0?ooo`000?l00P3oool20000o`L0oooo0`000?l3000002X0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`050?ooo`@00000
;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<000000P000?la0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0
oooo00@0oooo0`0000020?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03P0oooo0`0000020?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0;P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0=@3oool3000000030?ooo`000?l0oooo00D0oooo00<0003o0?oo
o`3oool00P000?la0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000103oool20000o`H0
oooo0P000?l00`3oool0003o0?ooo`0a0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000
503oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000005`3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000006P3oool0
0`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000M0?ooo`030000o`3oool0oooo
0380oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900
oooo00<000000?ooo`3oool08@3oool400000240oooo00<0003o0?ooo`3oool0<P3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool07P3oool3000002D0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61193 .65001 m
.61128 .65081 L
s
.61104 .6478 m
.61193 .65001 L
s
.61039 .6486 m
.61104 .6478 L
s
.61128 .65081 m
.61039 .6486 L
s
.61356 .67966 m
.61188 .65836 L
s
.6042 .64289 m
.60175 .63923 L
s
.60522 .64663 m
.6042 .64289 L
s
.60533 .64815 m
.60522 .64663 L
s
.60479 .65047 m
.60533 .64815 L
s
.60175 .63923 m
.59941 .63707 L
s
.60335 .65056 m
.60479 .65047 L
s
.59941 .63707 m
.59717 .63641 L
s
.60616 .65878 m
.60562 .66112 L
s
.59955 .6485 m
.60335 .65056 L
s
.60562 .66112 m
.60339 .66051 L
s
.59717 .63641 m
.59662 .63873 L
s
.5981 .64859 m
.59955 .6485 L
s
.60339 .66051 m
.60104 .65838 L
s
.59754 .65092 m
.5981 .64859 L
s
.60104 .65838 m
.59856 .6547 L
s
.59856 .6547 m
.59754 .65092 L
s
.59007 .62986 m
.59188 .63437 L
s
.58836 .62687 m
.59007 .62986 L
s
.58597 .62467 m
.58836 .62687 L
s
.58449 .62472 m
.58597 .62467 L
s
.59279 .6466 m
.59143 .64822 L
s
.5831 .6263 m
.58449 .62472 L
s
.59143 .64822 m
.58994 .64831 L
s
.58263 .63016 m
.5831 .6263 L
s
.58994 .64831 m
.58754 .64613 L
s
.58285 .63323 m
.58263 .63016 L
s
.58754 .64613 m
.58582 .64313 L
s
.58399 .63858 m
.58285 .63323 L
s
.58582 .64313 m
.58399 .63858 L
s
.57785 .63733 m
.57633 .61577 L
s
.57088 .62519 m
.56982 .60976 L
s
.57943 .64894 m
.57873 .64976 L
s
.57851 .64665 m
.57943 .64894 L
s
.5778 .64747 m
.57851 .64665 L
s
.57038 .62909 m
.57088 .62519 L
s
.57873 .64976 m
.5778 .64747 L
s
.56884 .62915 m
.57038 .62909 L
s
.56295 .63409 m
.56076 .6014 L
s
.56637 .6269 m
.56884 .62915 L
s
.5646 .62384 m
.56637 .6269 L
s
.5618 .6169 m
.5646 .62384 L
s
.55357 .59914 m
.55169 .59449 L
s
.55471 .60457 m
.55357 .59914 L
s
.55169 .59449 m
.54991 .59139 L
s
.55491 .60769 m
.55471 .60457 L
s
.54991 .59139 m
.54738 .58905 L
s
.55438 .6116 m
.55491 .60769 L
s
.54536 .60784 m
.54331 .57507 L
s
.54738 .58905 m
.54578 .58905 L
s
.5529 .6132 m
.55438 .6116 L
s
.54578 .58905 m
.54428 .5906 L
s
.55131 .61323 m
.5529 .6132 L
s
.54877 .61093 m
.55131 .61323 L
s
.54697 .60781 m
.54877 .61093 L
s
.54507 .60312 m
.54697 .60781 L
s
.53937 .60239 m
.53802 .58042 L
s
.5364 .5804 m
.53831 .58511 L
s
.53459 .57725 m
.5364 .5804 L
s
.532 .57486 m
.53459 .57725 L
s
.53036 .57484 m
.532 .57486 L
s
.53908 .59766 m
.53755 .59925 L
s
.52881 .57638 m
.53036 .57484 L
s
.53755 .59925 m
.53592 .59926 L
s
.52822 .5803 m
.52881 .57638 L
s
.53592 .59926 m
.53332 .5969 L
s
.52841 .58345 m
.52822 .5803 L
s
.53332 .5969 m
.53148 .59374 L
s
.52956 .58899 m
.52841 .58345 L
s
.53148 .59374 m
.52956 .58899 L
s
.51752 .58256 m
.51628 .56036 L
s
.52194 .58657 m
.52458 .58897 L
s
.52008 .58338 m
.52194 .58657 L
s
.51698 .57301 m
.51814 .57858 L
s
.51814 .57858 m
.52008 .58338 L
s
.51032 .55938 m
.51139 .56337 L
s
.50837 .55456 m
.51032 .55938 L
s
.51139 .56337 m
.51165 .56813 L
s
.50649 .55133 m
.50837 .55456 L
s
.5029 .54802 m
.50649 .55133 L
s
.50717 .56404 m
.51165 .56813 L
s
.50118 .54794 m
.5029 .54802 L
s
.51234 .5809 m
.51162 .5833 L
s
.49954 .54946 m
.50118 .54794 L
s
.51162 .5833 m
.51 .58489 L
s
.4988 .55181 m
.49954 .54946 L
s
.51 .58489 m
.50828 .58488 L
s
.49813 .55578 m
.4988 .55181 L
s
.50828 .58488 m
.50466 .58162 L
s
.49854 .5638 m
.49813 .55578 L
s
.50466 .58162 m
.50276 .57837 L
s
.4997 .56945 m
.49854 .5638 L
s
.50276 .57837 m
.50078 .5735 L
s
.50078 .5735 m
.4997 .56945 L
s
.49313 .56042 m
.48835 .53459 L
s
.48575 .55372 m
.48835 .53459 L
s
.48575 .55372 m
.48097 .52778 L
s
.47828 .54694 m
.48097 .52778 L
s
.47169 .54095 m
.47069 .51829 L
s
.46887 .51816 m
.4709 .52312 L
s
.46691 .51481 m
.46887 .51816 L
s
.46407 .51218 m
.46691 .51481 L
s
.46224 .51204 m
.46407 .51218 L
s
.47147 .53607 m
.46972 .5376 L
s
.46046 .51352 m
.46224 .51204 L
s
.46972 .5376 m
.46789 .53751 L
s
.45971 .51751 m
.46046 .51352 L
s
.46789 .53751 m
.46504 .53491 L
s
.45984 .52077 m
.45971 .51751 L
s
.46504 .53491 m
.46305 .53154 L
s
.461 .52653 m
.45984 .52077 L
s
.46305 .53154 m
.461 .52653 L
s
.44764 .51912 m
.44677 .49622 L
s
.45251 .52355 m
.45542 .52619 L
s
.45051 .52014 m
.45251 .52355 L
s
.44727 .50927 m
.44843 .51508 L
s
.44843 .51508 m
.45051 .52014 L
s
.43814 .493 m
.43606 .48791 L
s
.43925 .49718 m
.43814 .493 L
s
.44041 .503 m
.43925 .49718 L
s
.43606 .48791 m
.43303 .48354 L
s
.44071 .51123 m
.44041 .503 L
s
.43303 .48354 m
.42607 .47712 L
s
.4399 .51529 m
.44071 .51123 L
s
.43903 .51771 m
.4399 .51529 L
s
.4272 .51188 m
.42607 .47712 L
s
.43716 .51924 m
.43903 .51771 L
s
.43422 .51821 m
.43716 .51924 L
s
.4272 .51188 m
.43422 .51821 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0H`3oool00`000000
oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo0P000?mT0?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0903oool00`000?l0oooo0000o`1S0?ooo`030000003oool0oooo00@0oooo0`00
001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool08`3oool00`000?l0oooo0000o`1S0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo0280oooo00@0003o0?ooo`3oool0003oHP3oool4000005D0oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`040000o`3oool0
oooo0000of00oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0803oool01@000?l0oooo0?ooo`3oool0003o05`0oooo0`00
00020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`000000J03oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`000?l0EP3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0003o05<0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0N0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`000?l0D03oool3000000/0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l0
C@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803o
ool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0
703oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o04X0oooo0`00000A0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0
0P3oool010000?l0oooo0?ooo`000?m60?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0KP3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3o
ool0003o103oool20000ocd0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?oo
o`030000003oool0oooo01X0oooo0P000?l20?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o
0?ooo`000?l0>@3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0K0?oo
o`030000o`3oool0003o0080oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0
oooo03<0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
02T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0K0?ooo`040000o`3oool0oooo
0?ooo`80003o0P3oool01@000?l0oooo0?ooo`3oool0003o0340oooo1000000Q0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0P0?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0;03oool3
000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`00
0000oooo0000001d0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`0Y0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0Q0?ooo`040000o`3oool0oooo0000
o`<0oooo00<0003o0?ooo`3oool08P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0Q0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool07`3oool30000
02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000
oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0803oool010000?l0
oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0000oa/0oooo0`00000a0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo01l0oooo00@0003o0?ooo`3oool0003o0P3oool2
0000o`030?ooo`000?l0oooo01L0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool07`3oool30000o`060?ooo`000?l0oooo0000o`3oool0003o5@3oool3000003L0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo0200oooo00H0003o0?ooo`000?l0oooo0000o`3oool20000oa40oooo
0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`0Q0?ooo`060000o`3oool0003o0000o`3oool0
003o3P3oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0200oooo00H0003o0?ooo`000?l0
003o0?ooo`000?l30?ooo`030000o`3oool0oooo00D0oooo0`0000100?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l00`3oool3000004<0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`000?l00P3oool010000?l0oooo
0?ooo`000?l2000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool300000840oooo00<000000?ooo`3oool0803oool01P000?l0oooo0?ooo`000?l0oooo0000
o`80000000<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool010000000
003o000000000?l20?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0
oooo10000000103oool0003o0?ooo`000?l30?ooo`030000o`3oool0003o04H0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`03
0000003oool0oooo01P0oooo0`0000070?ooo`050000o`3oool0oooo0000o`3oool00P000?m60?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000002P3oool010000?l0oooo0?ooo`3oool30000
odH0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000
oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000=0?ooo`030000o`3oool0oooo0080
oooo0P000?m60?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<00000403oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00
000D0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000005`3oool00`000?l0oooo0?ooo`03
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03X0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo00<000006P3oool00`000?l0oooo0?ooo`030?ooo`070000o`3o
ool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000
7P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00H0003o0?ooo`3oool0003o0?ooo`00
0?ll0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo01h0oooo0`000?l20?ooo`040000o`3oool0oooo0000o`80oooo0`00
0?lk0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000
o`0h0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0000o`02
0?ooo`030000o`3oool0003o0080003o<P3oool4000000H0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02H0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo02`0oooo0`00
000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`060000o`3oool0oooo0000o`3oool0003o
0P3oool00`000?l0oooo0?ooo`0X0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03o
ool01@000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool09@3oool300000180oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02T0oooo0P000?l01@3oool0003o0?ooo`3oool0003o0080oooo
00<0003o0?ooo`3oool07`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo00<0
003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?lM0?ooo`@000006P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0;03oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l06P3oool3000001h0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02`0oooo0P000?l20?ooo`030000o`3oool0003o01L0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0]0?ooo`060000o`3oool0oooo0000o`3oool0
003o0P3oool00`000?l0oooo0?ooo`0?0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0^0?ooo`80003o
0P3oool010000?l0oooo0?ooo`000?l>0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
<P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00D0oooo1000000^0?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0c0?ooo`80003o0P3oool00`000?l0oooo0000o`040?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0=03oool01`000?l0oooo0?ooo`000?l0oooo0000o`3o
ool00`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`040000o`3oool0oooo0000o`<0
000000<0oooo0000o`3oool0=`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=03oool02P000?l00000
000000000000oooo0000o`3oool0003o0?ooo`000?lh0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a
0?ooo`@0000000L0oooo0000o`000?l0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool0
=P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02/0oooo0`0000060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l00`3oool0
0`000?l0oooo0000o`0f0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000003P3oool01000
0?l0oooo0?ooo`000?l30?ooo`80003o=`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000503oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000001L0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0N0?ooo`<000006@3oool01P000?l0oooo0?ooo`000?l0oooo0000o`@0oooo00<0003o0?oo
o`3oool0=@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000K0?ooo`80
003o0`3oool010000?l0oooo0?ooo`000?l20?ooo`<0003o=@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<000009P3oool30000o`80oooo00<0003o0?oo
o`3oool0=03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000:@3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
4@3oool4000002`0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0>0?ooo`<00000<@3oool30000o`030?ooo`000?l0oooo03P0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000=P3oool00`000?l0oooo0000o`0i
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000>`3oool00`000?l0oooo0?ooo`0h0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`040?ooo`@00000?P3oool00`000?l0oooo0?ooo`0i0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool300000480oooo00<0003o0?ooo`3oool0>P3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000004H0oooo
00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`800000T03oool3000004T0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?oo
o`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3o
ool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3o
ool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0
oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3o
ool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0
oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<0
0000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3o
ool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?oo
o`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<0
0000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D00000
0P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`00
3@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool01000
0000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`
0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo
000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo
00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?oo
o`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?oo
o`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@0
00000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool0
3`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool0
10000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`00
0000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?oo
o`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80
000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T
0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?oo
o`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@0
00002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3o
ool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000
oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo
0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000
000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/
0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?oo
o`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000
003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3o
ool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3o
ool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03o
ool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2
000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0
oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0
oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo
00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?oo
o`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]
0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D0
0000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000
P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03o
ool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`00
0000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0
oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?oo
o`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?oo
o`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h
0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?oo
o`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@0
0000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3o
ool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3o
ool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003o
ool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0
oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo
0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000
d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3o
ool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61336 .68079 m
.6141 .68314 L
s
.61253 .68114 m
.61336 .68079 L
s
.6141 .68314 m
.61327 .6835 L
s
.61327 .6835 m
.61253 .68114 L
s
.61245 .70951 m
.61306 .69029 L
s
.60624 .67311 m
.60391 .66872 L
s
.60693 .67683 m
.60624 .67311 L
s
.60689 .67819 m
.60693 .67683 L
s
.60391 .66872 m
.60153 .66569 L
s
.606 .67991 m
.60689 .67819 L
s
.60153 .66569 m
.5991 .664 L
s
.60437 .67925 m
.606 .67991 L
s
.60034 .67556 m
.60437 .67925 L
s
.5991 .664 m
.5982 .66569 L
s
.60656 .68774 m
.60568 .68948 L
s
.60568 .68948 m
.60324 .68783 L
s
.59869 .6749 m
.60034 .67556 L
s
.60324 .68783 m
.60084 .6848 L
s
.59779 .67662 m
.59869 .6749 L
s
.59189 .6548 m
.59339 .65957 L
s
.59034 .65139 m
.59189 .6548 L
s
.58792 .64829 m
.59034 .65139 L
s
.60084 .6848 m
.59849 .68038 L
s
.59849 .68038 m
.59779 .67662 L
s
.58624 .64759 m
.58792 .64829 L
s
.5845 .64824 m
.58624 .64759 L
s
.59296 .6705 m
.59124 .6712 L
s
.58351 .6513 m
.5845 .64824 L
s
.59124 .6712 m
.58956 .67053 L
s
.5834 .65404 m
.58351 .6513 L
s
.58956 .67053 m
.58712 .66744 L
s
.57729 .65501 m
.57816 .63584 L
s
.58403 .65919 m
.5834 .65404 L
s
.58712 .66744 m
.58555 .66401 L
s
.58555 .66401 m
.58403 .65919 L
s
.57094 .64113 m
.5716 .62745 L
s
.56991 .64421 m
.57094 .64113 L
s
.56098 .64473 m
.56248 .61581 L
s
.57691 .66332 m
.57768 .66575 L
s
.57602 .66367 m
.57691 .66332 L
s
.57768 .66575 m
.57679 .6661 L
s
.56818 .64349 m
.56991 .64421 L
s
.57679 .6661 m
.57602 .66367 L
s
.56567 .64032 m
.56818 .64349 L
s
.56407 .63682 m
.56567 .64032 L
s
.56177 .6295 m
.56407 .63682 L
s
.55318 .60539 m
.55157 .60187 L
s
.55472 .61028 m
.55318 .60539 L
s
.55533 .61546 m
.55472 .61028 L
s
.5445 .61355 m
.5462 .58478 L
s
.55157 .60187 m
.54903 .59863 L
s
.55518 .61821 m
.55533 .61546 L
s
.54903 .59863 m
.54726 .59783 L
s
.55411 .62127 m
.55518 .61821 L
s
.54726 .59783 m
.54539 .5984 L
s
.55226 .62188 m
.55411 .62127 L
s
.55049 .62111 m
.55226 .62188 L
s
.53848 .60593 m
.53966 .58666 L
s
.54793 .61788 m
.55049 .62111 L
s
.53786 .58584 m
.53941 .59077 L
s
.53622 .58227 m
.53786 .58584 L
s
.5463 .61433 m
.54793 .61788 L
s
.53364 .57897 m
.53622 .58227 L
s
.54475 .6094 m
.5463 .61433 L
s
.53182 .57813 m
.53364 .57897 L
s
.52991 .57866 m
.53182 .57813 L
s
.53873 .60177 m
.53683 .60235 L
s
.52877 .58168 m
.52991 .57866 L
s
.53683 .60235 m
.53501 .60155 L
s
.52859 .58443 m
.52877 .58168 L
s
.53501 .60155 m
.53241 .59825 L
s
.52919 .58968 m
.52859 .58443 L
s
.53241 .59825 m
.53076 .59466 L
s
.53076 .59466 m
.52919 .58968 L
s
.51659 .57825 m
.51795 .55894 L
s
.52102 .58384 m
.52366 .58719 L
s
.51718 .56994 m
.51777 .57521 L
s
.51935 .58022 m
.52102 .58384 L
s
.5099 .55015 m
.51147 .55516 L
s
.50822 .54651 m
.5099 .55015 L
s
.51147 .55516 m
.51216 .55905 L
s
.51777 .57521 m
.51935 .58022 L
s
.50466 .54196 m
.50822 .54651 L
s
.51216 .55905 m
.51186 .56318 L
s
.5074 .55752 m
.51186 .56318 L
s
.50276 .54104 m
.50466 .54196 L
s
.50076 .5415 m
.50276 .54104 L
s
.49964 .54311 m
.50076 .5415 L
s
.51105 .57428 m
.50995 .57594 L
s
.49841 .5461 m
.49964 .54311 L
s
.50995 .57594 m
.50795 .57648 L
s
.49787 .55304 m
.49841 .5461 L
s
.50795 .57648 m
.50605 .57561 L
s
.4923 .54753 m
.49024 .52354 L
s
.48497 .53825 m
.49024 .52354 L
s
.50605 .57561 m
.50244 .57107 L
s
.49845 .55836 m
.49787 .55304 L
s
.49914 .5623 m
.49845 .55836 L
s
.50244 .57107 m
.50073 .56739 L
s
.50073 .56739 m
.49914 .5623 L
s
.48497 .53825 m
.48294 .51422 L
s
.47757 .5289 m
.48294 .51422 L
s
.47105 .52065 m
.4728 .50127 L
s
.47082 .50027 m
.47242 .50539 L
s
.46908 .49652 m
.47082 .50027 L
s
.46628 .49294 m
.46908 .49652 L
s
.46428 .49193 m
.46628 .49294 L
s
.46214 .49229 m
.46428 .49193 L
s
.47142 .51647 m
.4693 .51688 L
s
.46081 .49523 m
.46214 .49229 L
s
.4693 .51688 m
.4673 .5159 L
s
.46054 .49801 m
.46081 .49523 L
s
.4673 .5159 m
.46447 .51233 L
s
.46109 .50337 m
.46054 .49801 L
s
.46447 .51233 m
.46272 .50855 L
s
.46272 .50855 m
.46109 .50337 L
s
.44734 .49066 m
.4493 .47125 L
s
.45213 .49672 m
.45499 .50034 L
s
.44818 .4823 m
.44872 .48769 L
s
.45035 .49291 m
.45213 .49672 L
s
.44872 .48769 m
.45035 .49291 L
s
.43861 .45916 m
.43585 .45408 L
s
.44024 .46438 m
.43861 .45916 L
s
.44092 .46837 m
.44024 .46438 L
s
.44145 .47376 m
.44092 .46837 L
s
.43585 .45408 m
.42905 .4454 L
s
.44073 .48072 m
.44145 .47376 L
s
.43932 .48369 m
.44073 .48072 L
s
.42582 .47466 m
.42905 .4454 L
s
.43805 .48527 m
.43932 .48369 L
s
.4358 .48562 m
.43805 .48527 L
s
.43272 .48333 m
.4358 .48562 L
s
.42582 .47466 m
.43272 .48333 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0
oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0<P3oool20000of80oooo00<000000?ooo`3oool0;@3oool30000
02D0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0a0?ooo`80003oHP3oool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000
oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0300oooo
00<0003o0?ooo`000?l0H@3oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02l0oooo00<0
003o0?ooo`000?l0H@3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02h0oooo00@0003o
0?ooo`3oool0003oH03oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02`0oooo00D0003o
0?ooo`3oool0oooo0000o`1P0?ooo`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003o
ool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool06P3oool3
000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0
oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05h0
oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo
0P00001O0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo
0?ooo`000?mM0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0
oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0?ooo`020?ooo`040000o`3oool0oooo0000oed0oooo00<000000?ooo`3oool03P3oool3000004@0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000oooo
0?ooo`0W0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`1K0?ooo`03
0000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000
003oool0oooo0640oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o0080
oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02H0oooo
00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo00@0
oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool09P3oool20000o`<0oooo00<0003o0?ooo`3oool0F`3oool010000000oooo
0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo05/0oooo1000001E0?ooo`030000
003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`1I0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02T0oooo00@0003o0?ooo`3oool0oooo0`00
0?mA0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0:03oool01@000?l0oooo0?ooo`3o
ool0003o0080oooo00<0003o0?ooo`3oool0B`3oool3000000D0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0:03oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0B03oool3000000P0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo02P0oooo00@0003o0?ooo`3oool0003o0P3oool20000odH0oooo0`00
000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P000007
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`02
0000od<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo02T0oooo00D0003o0?ooo`3oool0oooo0000o`100?ooo`<000004@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`000?l0
?@3oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
:03oool00`000?l0oooo0000o`0k0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0X0?ooo`80003o103oool00`000?l0oooo0?ooo`0a0?ooo`<00000
6`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02P0oooo0P000?l30?ooo`030000o`3o
ool0oooo02h0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0W0?ooo`040000o`3oool0
oooo0?ooo`80003o;03oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo02X0oooo0P000?l2
0?ooo`030000o`3oool0oooo02@0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0X0?oo
o`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool08@3oool3000002P0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`030000ob00oooo0`00000[0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0:@3oool30000oad0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo02P0oooo0`000?lJ0?ooo`<00000<@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0003o01L0oooo0`00000d
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0000o`0D0?oo
o`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool09`3oool010000?l0oooo0?ooo`3oool20000
o``0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0V0?ooo`060000o`3oool0oooo0000
o`3oool0003o2@3oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02D0oooo00@0003o0?oo
o`3oool0003o0P3oool00`000?l0oooo0?ooo`030?ooo`<00000@03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool09`3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`<00000@`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool09P3oool01P000?l0oooo0?ooo`000000003o000004H0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3o
ool00`000?l00000000000020?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0240oooo0`0000001P000?l0oooo0?ooo`000?l0oooo0000odH0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo01`0oooo100000030?ooo`040000o`3oool0oooo0?ooo`80003o00<0oooo0000o`3oool0
A03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0603oool3000000L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0000o`150?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000002P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0100oooo0`00000>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0@`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0303oool300000140oooo00<0003o0?ooo`3oool00P3oool20000odD0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000E0?ooo`040000o`3oool0003o0?ooo`80
003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001T0oooo0P000?l00`3oool0003o
0000o`150?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000001l0oooo00<0003o0?ooo`000?l00P3o
ool30000ocl0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`800000903oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3o
ool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2
000008d0oooo00<000000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?l20?ooo`050000o`3o
ool0oooo0?ooo`000?l0>@3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0003o0080oooo0P00
0?l20?ooo`030000o`3oool0oooo03@0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0V
0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0`0?ooo`@000001P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0
003o0?ooo`3oool0;@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00@0003o
0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0Z0?ooo`<000003P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool09`3oool01@000?l0oooo0?ooo`000?l0oooo00<0003o:03oool300000180oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02P0oooo00L0003o0?ooo`000?l0oooo0000o`3oool0003o02D0oooo
0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`80003o00D0oooo0000o`3oool0oooo
0000o`0P0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0000
o`020?ooo`030000o`3oool0oooo01/0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0/
0?ooo`040000o`3oool0oooo0000oaX0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/
0?ooo`050000o`3oool0oooo0?ooo`000?l05P3oool3000002H0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0;03oool2
0000o`80oooo00<0003o0?ooo`3oool04@3oool3000002X0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02d0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0:0?ooo`@00000;P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0;P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0
oooo00L0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0_0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`040?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool010000?l0
oooo0?ooo`3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03@0oooo00@0003o00000000
00000000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000080oooo00<0003o0?ooo`3o
ool0?@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool300000080oooo00D0003o0?ooo`3oool0
oooo0000o`100?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000001@3oool20000o`80oooo
00<0003o0?ooo`000?l0?P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000P0oooo0P00
0?l20?ooo`030000o`3oool0003o03l0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000/0oooo00L0003o
0?ooo`000?l0oooo0000o`3oool0003o0400oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000000h0oooo00@0
003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0N0?ooo`<000004P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<000006`3oool00`000?l0oooo0?ooo`02
0000och0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3
000001h0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000Q0?ooo`030000o`3oool0003o
00<0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140
oooo1000000V0?ooo`050000o`3oool0oooo0?ooo`000?l0?`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000:`3oool010000?l0oooo0?ooo`000?m00?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000002h0oooo00<0003o0?ooo`3o
ool0@@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000002h0oooo00@0003o0?ooo`3oool0
003o103oool20000och0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000a0?ooo`050000
o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo
0?ooo`3oool3000003X0oooo0P000?l30?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000130?ooo`030000
o`3oool0oooo03d0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool200000900oooo0`0000130?ooo`80003o00<0oooo0000o`3oool0?P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo0440oooo00@0003o0?ooo`000?l0003o@03oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo10000005
0?ooo`030000003oool0oooo0440oooo00D0003o0?ooo`3oool0003o0?ooo`020000och0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`25
0?ooo`<000002@3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0?@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo0480oooo00<0003o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo04<0oooo0P000?m40?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O03oool300000140oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`100?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03o
ool4000001@0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`110?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3
000001P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool30000
01/0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0
oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo
0?ooo`170?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?oo
o`170?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`17
0?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3
000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`000018
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3
000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z
0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`80
00009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3
000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;
0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000
T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?oo
o`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
0980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`00
8P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2
000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`24
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000
003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03o
ool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2
000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo
0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003o
ool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool20000
06T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool20000
0680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00
000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m
0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?oo
o`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3o
ool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00
001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P
0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080
oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo1000
00050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A
0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?oo
o`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool0
0`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80
oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo
1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000
000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?oo
o`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`80
00003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D0
0000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3o
ool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00
J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2
000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo
000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool00000
02H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000
oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<0
00000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O
0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?oo
o`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@0
0000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3o
ool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2
000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000
oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/
0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`00
00008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@0
0000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`03
0000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2
000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<0
00000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61209 .71037 m
.61264 .71278 L
s
.61111 .71026 m
.61209 .71037 L
s
.61264 .71278 m
.61167 .71267 L
s
.61167 .71267 m
.61111 .71026 L
s
.60496 .70012 m
.60286 .69516 L
s
.60531 .70368 m
.60496 .70012 L
s
.60767 .73476 m
.61063 .71843 L
s
.60286 .69516 m
.60053 .69133 L
s
.60509 .70483 m
.60531 .70368 L
s
.60389 .70586 m
.60509 .70483 L
s
.60053 .69133 m
.59799 .68864 L
s
.60213 .70447 m
.60389 .70586 L
s
.59799 .68864 m
.59678 .68965 L
s
.59802 .69923 m
.60213 .70447 L
s
.6036 .71291 m
.60239 .71396 L
s
.59097 .67708 m
.59209 .68194 L
s
.58963 .67337 m
.59097 .67708 L
s
.59624 .69782 m
.59802 .69923 L
s
.58728 .66949 m
.58963 .67337 L
s
.60239 .71396 m
.59983 .71129 L
s
.58548 .66804 m
.58728 .66949 L
s
.59502 .69884 m
.59624 .69782 L
s
.59983 .71129 m
.59749 .70745 L
s
.58345 .66772 m
.58548 .66804 L
s
.59536 .70244 m
.59502 .69884 L
s
.59749 .70745 m
.59536 .70244 L
s
.58198 .66984 m
.58345 .66772 L
s
.59031 .69112 m
.58828 .69085 L
s
.57454 .66987 m
.57782 .6539 L
s
.58152 .67212 m
.58198 .66984 L
s
.58828 .69085 m
.58648 .68941 L
s
.58162 .67687 m
.58152 .67212 L
s
.58648 .68941 m
.5841 .68552 L
s
.56908 .65477 m
.57146 .64342 L
s
.58274 .68177 m
.58162 .67687 L
s
.5841 .68552 m
.58274 .68177 L
s
.55748 .65282 m
.56266 .62891 L
s
.56756 .65689 m
.56908 .65477 L
s
.54285 .61797 m
.54823 .59442 L
s
.5657 .65539 m
.56756 .65689 L
s
.55353 .61539 m
.55216 .6116 L
s
.55465 .62031 m
.55353 .61539 L
s
.57312 .6768 m
.57369 .67927 L
s
.57208 .67665 m
.57312 .6768 L
s
.55216 .6116 m
.54972 .60758 L
s
.57369 .67927 m
.57264 .67912 L
s
.55471 .62503 m
.55465 .62031 L
s
.56328 .65142 m
.5657 .65539 L
s
.57264 .67912 m
.57208 .67665 L
s
.56021 .64022 m
.5619 .64762 L
s
.54972 .60758 m
.54783 .60601 L
s
.5619 .64762 m
.56328 .65142 L
s
.55421 .62729 m
.55471 .62503 L
s
.54783 .60601 m
.54569 .60556 L
s
.55264 .62935 m
.55421 .62729 L
s
.5505 .62895 m
.55264 .62935 L
s
.53706 .60848 m
.54072 .59275 L
s
.53882 .59116 m
.53994 .5961 L
s
.53743 .58733 m
.53882 .59116 L
s
.53496 .58325 m
.53743 .58733 L
s
.54861 .6274 m
.5505 .62895 L
s
.53304 .58164 m
.53496 .58325 L
s
.54614 .62336 m
.54861 .6274 L
s
.54363 .61456 m
.54476 .61953 L
s
.53085 .58113 m
.53304 .58164 L
s
.54476 .61953 m
.54614 .62336 L
s
.52921 .58311 m
.53085 .58113 L
s
.53785 .60509 m
.53566 .60463 L
s
.52867 .58535 m
.52921 .58311 L
s
.53566 .60463 m
.53373 .60303 L
s
.5287 .59008 m
.52867 .58535 L
s
.5161 .57416 m
.51999 .55858 L
s
.53373 .60303 m
.53123 .59894 L
s
.52983 .59507 m
.5287 .59008 L
s
.53123 .59894 m
.52983 .59507 L
s
.51214 .54721 m
.51327 .5522 L
s
.51074 .54333 m
.51214 .54721 L
s
.50735 .53775 m
.51074 .54333 L
s
.51327 .5522 m
.51355 .5558 L
s
.51778 .56745 m
.51778 .57218 L
s
.51355 .5558 m
.51271 .55912 L
s
.52032 .58108 m
.52285 .58522 L
s
.50537 .53605 m
.50735 .53775 L
s
.51778 .57218 m
.51892 .57719 L
s
.51892 .57719 m
.52032 .58108 L
s
.50309 .53544 m
.50537 .53605 L
s
.50846 .55216 m
.51271 .55912 L
s
.50166 .53624 m
.50309 .53544 L
s
.49993 .53814 m
.50166 .53624 L
s
.49299 .53631 m
.4937 .51525 L
s
.48604 .52493 m
.4937 .51525 L
s
.51044 .56806 m
.50901 .56891 L
s
.49846 .54368 m
.49993 .53814 L
s
.50901 .56891 m
.50673 .56837 L
s
.48604 .52493 m
.48681 .50389 L
s
.47905 .51348 m
.48681 .50389 L
s
.50673 .56837 m
.50472 .5667 L
s
.49844 .54843 m
.49846 .54368 L
s
.50472 .5667 m
.50128 .56108 L
s
.49871 .55208 m
.49844 .54843 L
s
.49985 .55714 m
.49871 .55208 L
s
.50128 .56108 m
.49985 .55714 L
s
.4729 .5034 m
.47726 .48815 L
s
.4752 .48635 m
.47633 .4914 L
s
.47376 .48239 m
.4752 .48635 L
s
.47113 .47806 m
.47376 .48239 L
s
.46906 .47624 m
.47113 .47806 L
s
.46667 .4755 m
.46906 .47624 L
s
.46483 .47729 m
.46667 .4755 L
s
.47384 .50011 m
.47145 .49942 L
s
.46419 .47945 m
.46483 .47729 L
s
.47145 .49942 m
.46936 .49762 L
s
.46412 .48417 m
.46419 .47945 L
s
.45062 .46692 m
.45523 .45185 L
s
.46936 .49762 m
.46671 .49327 L
s
.46525 .48926 m
.46412 .48417 L
s
.46671 .49327 m
.46525 .48926 L
s
.44506 .4367 m
.4427 .43119 L
s
.44619 .44179 m
.44506 .4367 L
s
.45261 .46043 m
.45251 .46514 L
s
.44642 .4454 m
.44619 .44179 L
s
.4427 .43119 m
.43638 .42077 L
s
.45511 .47428 m
.4578 .47868 L
s
.44632 .4501 m
.44642 .4454 L
s
.45251 .46514 m
.45365 .47025 L
s
.45365 .47025 m
.45511 .47428 L
s
.44464 .45549 m
.44632 .4501 L
s
.4291 .44326 m
.43638 .42077 L
s
.44272 .45726 m
.44464 .45549 L
s
.44113 .45795 m
.44272 .45726 L
s
.43862 .45714 m
.44113 .45795 L
s
.43554 .45375 m
.43862 .45714 L
s
.4291 .44326 m
.43554 .45375 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
03l0oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03h0
oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`000000
oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03`0oooo
00<0003o0?ooo`000?l0G`3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03/0oooo00<0
003o0?ooo`000?l0G`3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo0?oo
o`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03T0oooo00D0003o
0?ooo`3oool0oooo0000o`1N0?ooo`030000003oool0oooo0400oooo0`00000A0?ooo`030000003o
ool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0>03oool0
1@000?l0oooo0?ooo`3oool0003o05h0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo00<0
00000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0g
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0i
0?ooo`@000005`3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo03D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1K0?oo
o`030000003oool0oooo03H0oooo0`00000K0?ooo`030000003oool0oooo01X0oooo000]0?ooo`80
0000DP3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0c0?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`00
;@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo0300oooo0`00000Q0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0;@3o
ool3000002D0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0380oooo00D0003o0?ooo`3oool0oooo0000o`03
0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool09`3oool3000002/0oooo00<00000
0?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0a0?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0
oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0<@3oool30000o`<0oooo00<0003o0?ooo`3oool0F03oool00`00
0000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000
oooo0?ooo`1I0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0F03oool00`000000
oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo
0?ooo`1J0?ooo`030000003oool0oooo03@0oooo0P000?mK0?ooo`030000003oool0oooo01X0oooo
0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<0
00000?ooo`3oool0<`3oool20000oe/0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<0
00000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo03<0oooo00<0003o
0?ooo`3oool0F@3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H
0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`1I0?oo
o`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0<P3oool01@000?l0oooo0?ooo`3oool0003o
05H0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0a0?ooo`050000o`3oool0oooo0000
o`3oool00P000?mD0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0<@3oool00`000?l0
oooo0000o`020?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool01`3oool3000004/0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0b0?ooo`050000o`3oool0oooo0?ooo`000?l0D`3oool00`000000oooo0?ooo`040?ooo`<0
0000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo0340oooo00D0003o0?ooo`3oool0oooo0000o`1C0?ooo`040000003oool0oooo0?oo
o`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`03
0000003oool0oooo0300oooo00@0003o0?ooo`3oool0oooo0P000?mB0?ooo`@00000E@3oool00`00
0000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02l0
oooo00@0003o0?ooo`3oool0oooo0P000?m@0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02l0oooo00@0003o0?ooo`3o
ool0003oCP3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo02h0oooo00@0003o0?ooo`3o
ool0003oB`3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool2000006T0oooo00<000000?ooo`3oool0;`3oool30000odP0oooo0`0000080?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`0_0?ooo`80003oA@3oool3000000/0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0?03o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0<@3o
ool20000oc/0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo02l0oooo00<0003o0?ooo`000?l0>03oool3000001@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0000o`0e0?ooo`<00000603o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0/0?ooo`040000o`3o
ool0oooo0000o`80oooo00<0003o0?ooo`3oool0;@3oool3000001/0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`0^0?ooo`040000o`3oool0003o0000ob`0oooo0`00000N0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3o
ool00`000000oooo0?ooo`0]0?ooo`80003o00<0oooo0000o`3oool09`3oool400000240oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo02`0oooo0P000?l00`3oool0003o0?ooo`0T0?ooo`<000009@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool00000
07@0oooo00<000000?ooo`3oool0:`3oool010000?l0oooo0?ooo`000?lR0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo01d0oooo0`00000[0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0J0?ooo`<00000;P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo01L0oooo
0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02X0oooo00<0
003o0?ooo`3oool00P000?lB0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo02/0oooo00@0003o0?ooo`3oool0003o3P3oool3000003L0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo02X0oooo00@0003o0?ooo`3oool0003o2`3oool3000003X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo02T0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`<00000?@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`<00000@03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`020?ooo`040000o`000000
0000000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02H0oooo00H0003o0?ooo`3oool0003o0000
00000?m60?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00
00210?ooo`030000003oool0oooo02D0oooo00@0003o000000000000oooo0P000?m60?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`0Q0?ooo`<0000000@0003o0?ooo`3oool0oooo0P000?l20?ooo`030000
o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo100000040?ooo`050000o`3o
ool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0H0?ooo`<00000203oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04<0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo01@0oooo0`00000<0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool300000100oooo0P000?l20?oo
o`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000F0?ooo`80
003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001T0oooo0P000?m50?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`040?ooo`<000007@3oool00`000?l0oooo0?ooo`130?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`0300000200oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000T0?oo
o`040000o`3oool0oooo0?ooo`80003o?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0T0?ooo`050000o`3oool0003o
0?ooo`000?l0?P3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0oooo0000ocX0oooo0`000002
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0oooo0000ocH0oooo10000006
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l0<P3oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00D0003o0?ooo`3oool0oooo0000o`02
0?ooo`030000o`3oool0oooo02X0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?oo
o`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool09`3oool300000180oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0T0?oo
o`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool20000o`80oooo00<0003o0?ooo`3o
ool08@3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool0
0P000?lO0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool01P000?l0oooo0?oo
o`000?l0oooo0000oa/0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`040000
o`3oool0oooo0000oaL0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo02/0oooo0P000?l20?ooo`030000
o`3oool0oooo0180oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`80003o0P3o
ool00`000?l0oooo0?ooo`0>0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;03oool2
0000o`<0oooo00<0003o0?ooo`3oool02P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02d0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`<00000=P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0;P3oool010000?l0oooo0?ooo`000?l60?ooo`<00000>P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0;P3oool010000?l0oooo0?ooo`000?l30?ooo`<00000?P3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0;`3oool20000o`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000<0
oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000H0oooo
00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000P0oooo00<0
003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R
0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000002`3oool00`000?l0oooo0?ooo`14
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?oo
o`030000003oool0oooo0240oooo1000000>0?ooo`050000o`3oool0oooo0?ooo`000?l0@`3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool07P3oool300000180oooo00D0003o0?ooo`3oool0oooo0000o`14
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000001@0oooo0P000?l20?oo
o`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool3000001L0oooo00D0003o0?ooo`000?l0oooo0000o`160?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000J0?ooo`050000o`3oool0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool04@3oool400000200oooo0P000?l20?ooo`030000o`3oool0oooo04<0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002P0oooo00<0003o0?ooo`3o
ool0A03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000Z0?ooo`030000
o`3oool0oooo04D0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000]0?ooo`030000o`3o
ool0oooo04H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000`0?ooo`030000o`3oool0
oooo0080003oA@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000d0?ooo`060000o`3oool0
oooo0000o`3oool0003oA@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo
000P0?ooo`800000T@3oool4000003X0oooo00@0003o0?ooo`3oool0003oA@3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000003T0oooo00D0
003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`0g0?ooo`80003o0P3oool010000?l0oooo0?ooo`000?m60?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03o
ool4000000D0oooo00<000000?ooo`3oool0>`3oool01@000?l0oooo0?ooo`3oool0003o04H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`250?ooo`<000002@3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo04T0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`22
0?ooo`<00000303oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo04T0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?oo
o`<000003`3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo0080003oA`3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0
oooo0`00000A0?ooo`030000003oool0oooo03h0oooo0P000?l30?ooo`030000o`3oool0oooo04@0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo04@0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1f0?ooo`<00000603oool00`000000oooo0?ooo`110?ooo`040000o`3oool0oooo0000odL0oooo
00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1c0?ooo`<000006`3oool00`000000oooo0?ooo`110?ooo`80003o00<0oooo0000o`3oool0A`3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo0700oooo0`00000N0?ooo`030000003oool0oooo0440oooo0P000?l00`3oool0003o0?ooo`18
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?oo
o`<000008@3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0003o0080003oB03oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0
oooo1000000T0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool0BP3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo04<0oooo00D0003o0?ooo`3oool0oooo0000o`180?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<000000?ooo`3oool0A03oool010000?l0oooo0?ooo`000?m90?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003o
ool0oooo04L0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo04L0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo
04H0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo04H0
oooo00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo04H0oooo
00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo04D0oooo00<0
003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo04D0oooo00<0003o
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60716 .73532 m
.6075 .7377 L
s
.60607 .73472 m
.60716 .73532 L
s
.6075 .7377 m
.60642 .7371 L
s
.60642 .7371 m
.60607 .73472 L
s
.60032 .72279 m
.59853 .71743 L
s
.60028 .72605 m
.60032 .72279 L
s
.59853 .71743 m
.59637 .71294 L
s
.59637 .71294 m
.59382 .70931 L
s
.59991 .72694 m
.60028 .72605 L
s
.59843 .72722 m
.59991 .72694 L
s
.59927 .75423 m
.60455 .74156 L
s
.59382 .70931 m
.59233 .70956 L
s
.5966 .7251 m
.59843 .72722 L
s
.58622 .69189 m
.58729 .69578 L
s
.58404 .68737 m
.58622 .69189 L
s
.58729 .69578 m
.58797 .70053 L
s
.59259 .71848 m
.5966 .7251 L
s
.58219 .6852 m
.58404 .68737 L
s
.57994 .6839 m
.58219 .6852 L
s
.59075 .71635 m
.59259 .71848 L
s
.59725 .73317 m
.59576 .73346 L
s
.58925 .71661 m
.59075 .71635 L
s
.56967 .68122 m
.57527 .66918 L
s
.57803 .68497 m
.57994 .6839 L
s
.59576 .73346 m
.5932 .72984 L
s
.5892 .71989 m
.58925 .71661 L
s
.5932 .72984 m
.59101 .72531 L
s
.56536 .66551 m
.5694 .657 L
s
.59101 .72531 m
.5892 .71989 L
s
.57724 .6867 m
.57803 .68497 L
s
.58486 .70754 m
.58261 .70627 L
s
.57678 .69083 m
.57724 .6867 L
s
.58261 .70627 m
.58074 .70411 L
s
.55258 .65798 m
.56128 .64016 L
s
.54046 .62089 m
.54934 .60361 L
s
.57746 .69563 m
.57678 .69083 L
s
.58074 .70411 m
.57853 .69955 L
s
.57853 .69955 m
.57746 .69563 L
s
.55163 .62015 m
.54939 .61551 L
s
.5527 .62406 m
.55163 .62015 L
s
.55336 .62881 m
.5527 .62406 L
s
.54939 .61551 m
.54748 .61323 L
s
.56339 .66655 m
.56536 .66551 L
s
.55286 .63286 m
.55336 .62881 L
s
.54748 .61323 m
.54514 .61177 L
s
.55203 .63453 m
.55286 .63286 L
s
.56149 .66433 m
.56339 .66655 L
s
.53516 .60993 m
.54117 .59844 L
s
.55717 .64858 m
.55817 .65576 L
s
.55002 .6355 m
.55203 .63453 L
s
.55925 .6597 m
.56149 .66433 L
s
.53816 .59221 m
.53924 .59614 L
s
.53591 .58753 m
.53816 .59221 L
s
.53924 .59614 m
.53989 .60088 L
s
.55817 .65576 m
.55925 .6597 L
s
.53397 .58521 m
.53591 .58753 L
s
.56723 .68646 m
.56757 .68887 L
s
.56608 .6858 m
.56723 .68646 L
s
.56757 .68887 m
.56641 .68821 L
s
.53159 .58369 m
.53397 .58521 L
s
.54768 .63408 m
.55002 .6355 L
s
.56641 .68821 m
.56608 .6858 L
s
.52953 .58454 m
.53159 .58369 L
s
.54575 .63181 m
.54768 .63408 L
s
.54175 .61839 m
.5424 .62318 L
s
.54348 .62713 m
.54575 .63181 L
s
.51606 .57047 m
.52229 .55929 L
s
.5424 .62318 m
.54348 .62713 L
s
.52866 .58616 m
.52953 .58454 L
s
.53646 .60745 m
.53407 .60597 L
s
.5281 .59018 m
.52866 .58616 L
s
.51391 .5419 m
.51499 .54586 L
s
.51085 .53556 m
.51391 .5419 L
s
.51499 .54586 m
.51562 .55059 L
s
.53407 .60597 m
.53212 .60365 L
s
.50886 .53315 m
.51085 .53556 L
s
.51562 .55059 m
.51549 .55376 L
s
.52875 .59496 m
.5281 .59018 L
s
.53212 .60365 m
.52983 .59893 L
s
.52983 .59893 m
.52875 .59496 L
s
.51549 .55376 m
.51415 .55613 L
s
.50642 .53152 m
.50886 .53315 L
s
.51874 .56565 m
.51817 .56964 L
s
.50474 .53148 m
.50642 .53152 L
s
.5103 .54818 m
.51415 .55613 L
s
.51817 .56964 m
.51881 .57442 L
s
.5199 .5784 m
.5222 .58315 L
s
.49515 .52726 m
.49855 .51004 L
s
.48889 .51434 m
.49855 .51004 L
s
.51881 .57442 m
.5199 .5784 L
s
.50259 .53222 m
.50474 .53148 L
s
.48889 .51434 m
.49236 .4972 L
s
.48261 .50137 m
.49236 .4972 L
s
.50028 .53613 m
.50259 .53222 L
s
.51053 .56252 m
.50884 .56253 L
s
.4771 .48997 m
.4838 .47945 L
s
.48068 .47298 m
.48176 .47696 L
s
.47833 .46811 m
.48068 .47298 L
s
.48176 .47696 m
.48238 .48169 L
s
.50884 .56253 m
.50637 .56094 L
s
.49967 .5401 m
.50028 .53613 L
s
.47629 .4656 m
.47833 .46811 L
s
.47375 .46381 m
.47629 .4656 L
s
.50637 .56094 m
.50436 .55854 L
s
.49952 .54329 m
.49967 .5401 L
s
.50015 .5481 m
.49952 .54329 L
s
.50436 .55854 m
.50124 .55211 L
s
.47151 .4644 m
.47375 .46381 L
s
.50124 .55211 m
.50015 .5481 L
s
.45723 .44893 m
.46418 .43875 L
s
.47053 .46588 m
.47151 .4644 L
s
.47855 .4877 m
.476 .48595 L
s
.46986 .46974 m
.47053 .46588 L
s
.476 .48595 m
.47394 .48344 L
s
.45496 .42138 m
.45307 .41572 L
s
.45555 .4261 m
.45496 .42138 L
s
.45307 .41572 m
.44749 .40414 L
s
.47047 .47451 m
.46986 .46974 L
s
.47394 .48344 m
.47156 .47854 L
s
.45535 .42918 m
.45555 .4261 L
s
.47156 .47854 m
.47047 .47451 L
s
.4367 .41904 m
.44749 .40414 L
s
.45464 .43299 m
.45535 .42918 L
s
.46022 .44454 m
.45953 .44838 L
s
.45213 .43661 m
.45464 .43299 L
s
.45953 .44838 m
.46013 .45314 L
s
.46122 .45718 m
.46362 .46212 L
s
.46013 .45314 m
.46122 .45718 L
s
.4498 .43713 m
.45213 .43661 L
s
.44798 .43693 m
.4498 .43713 L
s
.44534 .43505 m
.44798 .43693 L
s
.44239 .43077 m
.44534 .43505 L
s
.4367 .41904 m
.44239 .43077 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`190?ooo`030000o`3oool0
oooo05T0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo04L0oooo0P000?mK0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`150?ooo`040000o`3oool0oooo0000oeX0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04@0
oooo00@0003o0?ooo`3oool0003oFP3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01`0oooo000_0?ooo`800000AP3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`1B0?ooo`8000007@3oool002h0oooo
0P0000180?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`1H0?ooo`030000003oool0oooo04l0oooo0`0000000`3oool000000?ooo`0L0?ooo`00;`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo04`0oooo0`0000040?ooo`030000003o
ool0oooo01/0oooo000_0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0?`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0B@3oool3
000000L0oooo00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0n0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0E`3oool00`00
0000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`1G0?ooo`030000003oool0oooo04<0oooo0`00000>0?ooo`030000003oool0oooo01X0
oooo000^0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0?@3oool01@000?l0oooo
0?ooo`3oool0003o05X0oooo00<000000?ooo`3oool0@03oool300000140oooo00<000000?ooo`3o
ool06P3oool002h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0m0?ooo`040000
o`3oool0oooo0000oeX0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo00<000000?ooo`3o
ool06P3oool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0m0?ooo`80003o
F`3oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`000000oooo0?ooo`0J0?ooo`00;P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool0E03o
ool00`000000oooo0?ooo`0f0?ooo`<000006`3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool2
00000580oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0
oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo
0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0?03oool20000oeP0oooo00<000000?ooo`3oool0;@3oool3000002D0
oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0l0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0:P3oool3000002P0oooo
00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0k0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool09`3oool3000002/0oooo00<0
00000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0j
0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool0903oool3000002h0oooo00<00000
0?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0j0?oo
o`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool08@3oool300000340oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0j0?ooo`03
0000o`3oool0oooo05@0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0l0?ooo`030000
o`3oool0oooo0580oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3oool0
6@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3o
ool0003o05<0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0603o
ool002`0oooo0P00001M0?ooo`030000003oool0oooo03T0oooo00@0003o0?ooo`3oool0003oDP3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0>03oool01@000?l0oooo0?ooo`3oool0003o0540oooo00<0
00000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`0g0?ooo`050000o`3oool0oooo0?ooo`000?l0D@3o
ool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03H0oooo00D0003o0?ooo`3oool0oooo0000
o`1A0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`02
0000oe00oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool0
02/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0f0?ooo`040000o`3oool0003o
0000oe00oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool0
02/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0003o
0540oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`1@0?oo
o`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo03@0oooo00<0003o0?ooo`3oool0CP3oool3000005P0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`210?ooo`<00000
0P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003o
ool0000006P0oooo00<000000?ooo`3oool0O@3oool3000000D0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0=P3oool2
0000od80oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
02X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0c0?ooo`80003o00<0oooo0000
o`3oool0?P3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo03X0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo03<0oooo00<0003o0?ooo`3oool0>03oool300000140oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool0<P3oool01@000?l0oooo0?ooo`3oool0003o
03<0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
0340oooo00<0003o0?ooo`000?l00P000?l`0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0`0?ooo`80003o00<0oooo0000o`3oool0;@3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo02T0
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo02D0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo0280oooo0`00
000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<00000
0?ooo`000000M03oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo0200oooo0`00000X
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?oo
o`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool07@3oool3000002/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0`0?ooo`80003o5`3oool3000002h0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0;P3oool010000?l0oooo0?ooo`000?lC0?ooo`<0
0000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000
003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0/0?ooo`050000
o`3oool0oooo0?ooo`000?l0403oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`0[0?ooo`050000o`3oool0oooo0?ooo`000?l03@3oool3000003L0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo02X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`<00000
>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003o
ool0oooo07`0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`0000100?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0W0?oo
o`070000o`3oool0oooo0?ooo`000?l0oooo0000o`02000004<0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo02L0oooo00@0003o0?ooo`00000000000P000?m50?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo00<00000
0000o`0000000`3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?oo
o`<000000P3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@0
00001P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo01P0oooo0`00000;0?ooo`050000o`3oool0oooo0?ooo`000?l0A03oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0503oool300000140oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0403oool3000001@0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0303oool3000001H0oooo0P000?m50?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?oo
o`<000006P3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<0
00007@3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000240oooo
00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000U0?ooo`030000003oool0oooo08`0oooo0P00000T0?ooo`030000o`3oool0oooo0480oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0903oool00`000?l0oooo0000o`020000och0oooo0P00001K0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3oool01000
0?l0oooo0?ooo`000?lj0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3oool01000
0?l0oooo0?ooo`000?lf0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3oool01@00
0?l0oooo0?ooo`3oool0003o0380oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?oo
o`050000o`3oool0oooo0?ooo`000?l0;`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02H0oooo00@0003o0?ooo`3oool0oooo0P000?l[0?ooo`<000004P3oool00`000000oooo0?ooo`1E
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o02T0oooo0`00000F0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0W0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool07`3oool4
000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo0P000?l30?ooo`030000o`3oool0oooo
01d0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`050000o`3oool0oooo0?oo
o`000?l0703oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo00D0003o0?ooo`3o
ool0oooo0000o`0J0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0/0?ooo`80003o5P3oool3000002X0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02/0oooo00@0003o0?ooo`3oool0003o4@3oool4000002h0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02`0oooo00D0003o0?ooo`3oool0oooo0000o`0=0?ooo`<0
0000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool20000o`<0oooo00<0003o0?ooo`3oool0
203oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo00D0003o0?ooo`3oool0oooo
0000o`070?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;@3oool010000?l0oooo0?oo
o`000?l40?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;@3oool010000?l0oooo0?oo
o`000?l400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02d0oooo00@0003o0000000000000000
A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000<0003oA`3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000/0oooo00<0003o0?oo
o`3oool0A03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000T03oool00`000000oooo0?ooo`0Q0?ooo`@000003P3oool00`000?l0oooo0?ooo`150?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<000004@3oool00`000?l0oooo0?ooo`170?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000001@0oooo00<0003o0?ooo`3oool0A`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<000005P3o
ool20000odX0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3
000001T0oooo0P000?m;0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool40000
01/0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000O0?ooo`030000o`3oool0003o00<0
oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo
0`00000T0?ooo`040000o`3oool0oooo0000odX0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo
0`00000X0?ooo`030000o`3oool0003o04/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000
000/0?ooo`030000o`3oool0oooo04/0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000=03o
ool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3o
ool00200oooo0P00002A0?ooo`@00000=P3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000>@3oool00`00
0?l0oooo0?ooo`1:0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0=P3oool00`000?l0
oooo0?ooo`1<0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo
0?ooo`1=0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?oo
o`1:0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0=@3oool01P000?l0oooo0?ooo`3o
ool0003o0?ooo`80003oB`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo03D0oooo0P00
0?l20?ooo`040000o`3oool0oooo0000od`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?oo
o`0j0?ooo`040000o`3oool0oooo0000od`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?oo
o`0j0?ooo`040000o`3oool0oooo0000odd0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?oo
o`0j0?ooo`050000o`3oool0oooo0?ooo`000?l0C@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003o
ool0oooo03/0oooo00@0003o0?ooo`3oool0003oCP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo03/0oooo00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0>`3oool0
0`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0?03oool20000
oe40oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo04d0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo04d0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0003o0500oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`0o0?ooo`80003o00<0oooo0000o`3oool0CP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo03l0oooo0P000?l00`3oool0003o0?ooo`1?0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0?`3oool01@000?l0oooo0000o`3oool0003o
0500oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000
oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0003o0080
003oD@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0
D`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04h0oooo100000110?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0D`3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04/0oooo0`0000150?ooo`030000003oool0oooo0440oooo0P000?l20?ooo`030000o`3oool0
oooo04l0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool20000
04T0oooo0`0000180?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0
oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo
0?ooo`140?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?oo
o`130?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`13
0?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`120?oo
o`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`120?ooo`03
0000o`3oool0oooo05P0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3o
ool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000
001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3o
ool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool20000
09L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo
0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P00
00200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2
000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0
oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K
0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3o
ool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3o
ool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0
oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo
001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?oo
o`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000
003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool40000
03D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0
oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo
001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo
00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo
1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000
001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H
0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`04
0000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`03
0000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`800000
9P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo
000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`00
0000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@00
00280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=
0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`800000
5P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool0
0`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool0
06H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo
00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo
0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo
0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`00
0000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3o
ool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo10000036
0?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`80
0000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0
oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59861 .75445 m
.59872 .7567 L
s
.59745 .75337 m
.59861 .75445 L
s
.59872 .7567 m
.59756 .75562 L
s
.59756 .75562 m
.59745 .75337 L
s
.59099 .73449 m
.58908 .72949 L
s
.59237 .74006 m
.59099 .73449 L
s
.58908 .72949 m
.58664 .72505 L
s
.59194 .74287 m
.59237 .74006 L
s
.58664 .72505 m
.58492 .7245 L
s
.59141 .74345 m
.59194 .74287 L
s
.58016 .70612 m
.58089 .71001 L
s
.57824 .7011 m
.58016 .70612 L
s
.57642 .6983 m
.57824 .7011 L
s
.58089 .71001 m
.58109 .71447 L
s
.53744 .62218 m
.54945 .61195 L
s
.5897 .74293 m
.59141 .74345 L
s
.57405 .69603 m
.57642 .6983 L
s
.56281 .68851 m
.57057 .681 L
s
.58741 .76686 m
.59492 .75855 L
s
.58789 .74016 m
.5897 .74293 L
s
.55987 .67282 m
.56544 .66757 L
s
.57176 .69598 m
.57405 .69603 L
s
.58415 .73235 m
.58789 .74016 L
s
.54647 .65991 m
.55838 .64907 L
s
.58233 .72957 m
.58415 .73235 L
s
.55001 .62715 m
.54807 .62209 L
s
.55073 .63102 m
.55001 .62715 L
s
.57066 .69707 m
.57176 .69598 L
s
.54807 .62209 m
.54621 .61919 L
s
.5806 .72903 m
.58233 .72957 L
s
.55089 .6354 m
.55073 .63102 L
s
.58766 .7475 m
.58594 .74698 L
s
.54621 .61919 m
.54378 .61678 L
s
.53286 .61021 m
.54097 .60348 L
s
.56965 .70039 m
.57066 .69707 L
s
.54984 .6386 m
.55089 .6354 L
s
.53838 .5967 m
.5391 .60056 L
s
.53644 .59161 m
.53838 .5967 L
s
.58015 .73185 m
.5806 .72903 L
s
.53456 .58869 m
.53644 .59161 L
s
.5391 .60056 m
.53924 .60491 L
s
.58594 .74698 m
.58347 .74252 L
s
.57674 .71893 m
.57435 .71669 L
s
.53211 .58622 m
.53456 .58869 L
s
.58154 .73747 m
.58015 .73185 L
s
.58347 .74252 m
.58154 .73747 L
s
.56984 .70487 m
.56965 .70039 L
s
.5487 .6396 m
.54984 .6386 L
s
.51646 .56734 m
.52476 .56103 L
s
.57435 .71669 m
.57251 .71387 L
s
.55754 .67272 m
.55987 .67282 L
s
.52971 .58591 m
.53211 .58622 L
s
.57057 .7088 m
.56984 .70487 L
s
.5176 .54228 m
.51831 .54613 L
s
.51499 .53545 m
.5176 .54228 L
s
.57251 .71387 m
.57057 .7088 L
s
.54634 .63942 m
.5487 .6396 L
s
.51309 .53246 m
.51499 .53545 L
s
.51831 .54613 m
.51843 .55042 L
s
.55275 .65419 m
.553 .66084 L
s
.51059 .52989 m
.51309 .53246 L
s
.51843 .55042 m
.5179 .55301 L
s
.55568 .66985 m
.55754 .67272 L
s
.52854 .58684 m
.52971 .58591 L
s
.49865 .52077 m
.50454 .50807 L
s
.49336 .50692 m
.50454 .50807 L
s
.54389 .63703 m
.54634 .63942 L
s
.553 .66084 m
.55373 .66476 L
s
.55373 .66476 m
.55568 .66985 L
s
.49336 .50692 m
.4993 .49435 L
s
.48805 .49305 m
.4993 .49435 L
s
.50873 .52902 m
.51059 .52989 L
s
.5179 .55301 m
.51611 .55434 L
s
.52743 .58996 m
.52854 .58684 L
s
.53918 .6207 m
.53933 .62509 L
s
.54201 .63412 m
.54389 .63703 L
s
.4834 .48089 m
.49208 .47545 L
s
.53461 .60876 m
.53214 .60631 L
s
.48945 .46856 m
.49015 .47239 L
s
.48748 .46339 m
.48945 .46856 L
s
.50627 .52858 m
.50873 .52902 L
s
.52004 .56462 m
.51891 .56769 L
s
.53933 .62509 m
.54005 .629 L
s
.48554 .46032 m
.48748 .46339 L
s
.54005 .629 m
.54201 .63412 L
s
.49015 .47239 m
.49024 .4766 L
s
.51283 .54576 m
.51611 .55434 L
s
.52756 .59433 m
.52743 .58996 L
s
.48298 .45761 m
.48554 .46032 L
s
.53214 .60631 m
.53025 .60337 L
s
.55944 .69177 m
.55952 .69402 L
s
.55822 .69061 m
.55944 .69177 L
s
.55952 .69402 m
.55831 .69286 L
s
.52828 .59823 m
.52756 .59433 L
s
.46673 .43731 m
.47561 .43231 L
s
.51891 .56769 m
.51903 .57203 L
s
.55831 .69286 m
.55822 .69061 L
s
.53025 .60337 m
.52828 .59823 L
s
.50323 .53071 m
.50627 .52858 L
s
.48045 .457 m
.48298 .45761 L
s
.51903 .57203 m
.51975 .57593 L
s
.46635 .40805 m
.46171 .3959 L
s
.4677 .4136 m
.46635 .40805 L
s
.51975 .57593 m
.52172 .58108 L
s
.46776 .41775 m
.4677 .4136 L
s
.44807 .40288 m
.46171 .3959 L
s
.47919 .45775 m
.48045 .457 L
s
.46715 .42018 m
.46776 .41775 L
s
.50206 .53373 m
.50323 .53071 L
s
.51131 .55791 m
.50944 .55708 L
s
.47797 .46061 m
.47919 .45775 L
s
.4659 .42297 m
.46715 .42018 L
s
.48527 .47971 m
.4827 .47702 L
s
.47056 .43516 m
.46932 .43798 L
s
.5015 .53633 m
.50206 .53373 L
s
.50944 .55708 m
.5069 .55452 L
s
.47804 .46485 m
.47797 .46061 L
s
.46269 .42472 m
.4659 .42297 L
s
.4827 .47702 m
.48074 .47393 L
s
.5016 .54066 m
.5015 .53633 L
s
.5069 .55452 m
.50496 .5515 L
s
.47874 .46871 m
.47804 .46485 L
s
.46932 .43798 m
.46938 .44219 L
s
.48074 .47393 m
.47874 .46871 L
s
.50231 .54457 m
.5016 .54066 L
s
.50496 .5515 m
.50231 .54457 L
s
.46938 .44219 m
.47007 .44605 L
s
.47007 .44605 m
.47208 .45128 L
s
.46009 .42402 m
.46269 .42472 L
s
.45812 .42297 m
.46009 .42402 L
s
.45547 .42016 m
.45812 .42297 L
s
.45279 .41522 m
.45547 .42016 L
s
.44807 .40288 m
.45279 .41522 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`1@0?ooo`80003oEP3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo01l0oooo000`0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
C@3oool20000o`030?ooo`000?l0oooo05D0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0O0?ooo`00<03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo04X0oooo0P00
0?l40?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0N0?ooo`00<03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo04T0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`190?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool0B03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo04P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1B0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P0000160?ooo`030000003o
ool0oooo04L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003o
ool0oooo0580oooo0P00000M0?ooo`00;P3oool2000004P0oooo00<000000?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0C`3oool3
000000030?ooo`000000oooo01`0oooo000_0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0AP3oool01@000?l0oooo0?ooo`3oool0003o05D0oooo00<000000?ooo`3oool0C03oool3
000000@0oooo00<000000?ooo`3oool06`3oool002l0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`160?ooo`@0003oE@3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`00
0000oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0AP3oool3000000/0oooo00<000000?ooo`3oool06P3oool002h0oooo
00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo04<0oooo
0`00000>0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo0400oooo0`00
000A0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0AP3oool20000oe<0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo00<00000
0?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`140?oo
o`80003oE03oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0f0?ooo`<000006`3oool00`000000oooo0?ooo`0J0?ooo`00
;@3oool200000580oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`1B0?ooo`030000
003oool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`1B0?ooo`030000003o
ool0oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0
oooo02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`1A0?ooo`030000003oool0oooo
02X0oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000
oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`110?ooo`80003oC`3oool00`000000oooo0?oo
o`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo03l0oooo00@0003o0?ooo`3oool0003oCP3oool00`000000oooo0?oo
o`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J
0?ooo`030000003oool0oooo03h0oooo00D0003o0?ooo`3oool0oooo0000o`1>0?ooo`030000003o
ool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool0?@3oool01@000?l0oooo0?ooo`3oool0003o04h0oooo00<0
00000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M
0?ooo`030000003oool0oooo03`0oooo00D0003o0?ooo`3oool0oooo0000o`1>0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo03/0oooo00D0003o0?ooo`3oool0oooo0000o`1=
0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0>`3oool40000odd0oooo00<000000?oo
o`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`0j0?ooo`80003oC`3oool00`000000oooo0?ooo`070?ooo`<0
0000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`290?ooo`040000003o
ool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo08P0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0Q@3oool3000005P0oooo00<00000
0?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0g0?oo
o`D0003oA@3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3o
ool0@03oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool2000006T0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`0n0?ooo`<00000
203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0k0?ooo`<000002`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0>@3oool3
000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0=@3oool2
0000ocL0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo03H0oooo0`000?la0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo02d0oooo0`00000H0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3oool0:P3oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo
02P0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo02@0
oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1E0?ooo`<000009@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<0
00000?ooo`3oool0D@3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0<P3oool20000oaT0oooo0`00000[
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0000o`0F0?oo
o`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0^0?ooo`05
0000o`3oool0oooo0?ooo`000?l04P3oool300000340oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0
oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00`0
oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00T0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool3000003X0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool0:@3oool020000?l0oooo0?ooo`3oool0
003o0?ooo`000?l0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0Y0?ooo`070000o`3o
ool0oooo0000o`000000003o000000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0X0?ooo`040000
o`000000000000000080003oA03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<0000000@0003o0?ooo`3oool0
003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000@0oooo0P000?m60?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3o
ool00`000000oooo0?ooo`0L0?ooo`@000003@3oool00`000?l0oooo0?ooo`100?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`0H0?ooo`<00000403oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`0D0?ooo`<000004@3oool20000od@0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100
oooo0`00000C0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001L0oooo
00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001X0oooo00<0
003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001h0oooo00<0003o
0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000Q0?ooo`030000o`3oool0oooo
0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`800000903oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo
0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool09P3oool20000oc`0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0V
0?ooo`030000o`3oool0003o03L0oooo100000060?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0V0?oo
o`040000o`3oool0oooo0000oc<0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?oo
o`040000o`3oool0oooo0000oc00oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?oo
o`050000o`3oool0oooo0?ooo`000?l0;03oool300000180oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02H0oooo00D0003o0?ooo`3oool0oooo0000o`0Y0?ooo`<000005P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`020000ob@0oooo1000000J0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0W0?ooo`040000o`3oool0oooo0000ob80oooo0`00000N0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0X0?ooo`80003o803oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0F0?ooo`<000009P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?oo
o`0]0?ooo`030000o`3oool0oooo01@0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[
0?ooo`80003o4`3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo00@0003o0?oo
o`3oool0003o3`3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo0P000?l20?oo
o`030000o`3oool0oooo00X0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`04
0000o`3oool0oooo0000o`T0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`05
0000o`3oool0oooo0?ooo`000?l01@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo00H0003o0?ooo`3oool0oooo0000o`3oool400000480oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo00<0003o0?ooo`3oool00`0000170?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<0
000000<0oooo0000o`3oool0A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool300000080oooo
00<0003o0?ooo`000?l0B@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo
000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000001P3oool00`000?l0oooo0?oo
o`190?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@
0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?oo
o`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000D0?ooo`03
0000o`3oool0oooo04L0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00
5`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0603oool3000001H0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0E0?ooo`<00000603oool00`000?l0oooo0?ooo`1;0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000001X0oooo0P000?m>0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000M0?ooo`030000o`3oool0
003o04l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool30000
00D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<000008P3oool00`00
0?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<000009@3oool00`000?l0
oooo0?ooo`1>0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000:03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000
;@3oool010000?l0oooo0?ooo`000?m>0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000<@3oool20000oe00oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool3
00000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo
03L0oooo00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo03H0
oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo03D0oooo
00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo03@0oooo00<0
003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo03<0oooo00<0003o
0?ooo`3oool0E03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo03<0oooo0P000?mF0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0>03oool20000oe80oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`0g0?ooo`040000o`3oool0oooo0000oe80oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<00000
7P3oool00`000000oooo0?ooo`0g0?ooo`040000o`3oool0oooo0000oe<0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000
003oool0oooo03L0oooo00D0003o0?ooo`3oool0oooo0000o`1B0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo
00<000000?ooo`3oool0>03oool010000?l0oooo0?ooo`000?mC0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo
00<000000?ooo`3oool0>03oool010000?l0oooo0?ooo`000?mD0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0>03oool010000?l0oooo0?ooo`000?mE0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo
00<000000?ooo`3oool0>@3oool010000?l0oooo0?ooo`000?mE0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo
00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo03d0oooo00<0003o
0?ooo`3oool0E03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?oo
o`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo03h0oooo00<0003o0?oo
o`3oool0E03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo03/0oooo0P000?l20?ooo`03
0000o`3oool0oooo05@0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`0k0?ooo`050000
o`3oool0003o0?ooo`000?l0EP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo03/0oooo
00D0003o0?ooo`000?l0oooo0000o`1G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`0l0?ooo`040000
o`3oool0003o0000oeP0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`0l0?ooo`050000
o`3oool0003o0?ooo`000?l0F03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo03`0oooo
00<0003o0?ooo`3oool00P000?mI0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0?03o
ool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0?@3oool2
0000oe`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo
00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<0
00000?ooo`3oool0@@3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0@03oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?oo
o`3oool0@03oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3o
ool0?`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48181 .40819 m
.47825 .39601 L
s
.46249 .39515 m
.47825 .39601 L
s
.4826 .41338 m
.48181 .40819 L
s
.47859 .43237 m
.48894 .43256 L
s
.53391 .62175 m
.54857 .61909 L
s
.48214 .41681 m
.4826 .41338 L
s
.49811 .46395 m
.49964 .46919 L
s
.49637 .46047 m
.49811 .46395 L
s
.49964 .46919 m
.49994 .47269 L
s
.49146 .47644 m
.50169 .47617 L
s
.49389 .45698 m
.49637 .46047 L
s
.4992 .50293 m
.50731 .49539 L
s
.49507 .4888 m
.50731 .49539 L
s
.48118 .41851 m
.48214 .41681 L
s
.49994 .47269 m
.49951 .47623 L
s
.50333 .51708 m
.5114 .50939 L
s
.4992 .50293 m
.5114 .50939 L
s
.49118 .45524 m
.49389 .45698 L
s
.51959 .53741 m
.52164 .54442 L
s
.51786 .53396 m
.51959 .53741 L
s
.52164 .54442 m
.52196 .548 L
s
.47947 .42019 m
.48118 .41851 L
s
.5154 .53057 m
.51786 .53396 L
s
.5173 .5649 m
.52728 .56371 L
s
.52196 .548 m
.52156 .55166 L
s
.53653 .59534 m
.53807 .60061 L
s
.5348 .59192 m
.53653 .59534 L
s
.53807 .60061 m
.5384 .60424 L
s
.53027 .6093 m
.54013 .60765 L
s
.51345 .52894 m
.5154 .53057 L
s
.48971 .45525 m
.49118 .45524 L
s
.53237 .58861 m
.5348 .59192 L
s
.54579 .62701 m
.54407 .62362 L
s
.54734 .6323 m
.54579 .62701 L
s
.5384 .60424 m
.53804 .608 L
s
.52156 .55166 m
.52065 .55357 L
s
.47574 .42007 m
.47947 .42019 L
s
.54768 .63596 m
.54734 .6323 L
s
.48305 .43245 m
.48134 .43417 L
s
.54407 .62362 m
.54165 .62035 L
s
.53937 .65847 m
.55404 .65522 L
s
.51078 .52735 m
.51345 .52894 L
s
.54732 .63977 m
.54768 .63596 L
s
.48801 .45702 m
.48971 .45525 L
s
.52974 .58716 m
.53237 .58861 L
s
.55283 .67632 m
.55972 .67464 L
s
.52065 .55357 m
.51851 .5538 L
s
.55422 .69129 m
.56385 .68877 L
s
.57006 .71 m
.57161 .71531 L
s
.56834 .70665 m
.57006 .71 L
s
.57161 .71531 m
.57197 .71905 L
s
.54575 .64197 m
.54732 .63977 L
s
.48134 .43417 m
.48088 .43766 L
s
.56595 .70348 m
.56834 .70665 L
s
.50716 .52764 m
.51078 .52735 L
s
.57886 .74011 m
.57663 .735 L
s
.58042 .74543 m
.57886 .74011 L
s
.5813 .75097 m
.58042 .74543 L
s
.57197 .71905 m
.57165 .723 L
s
.52832 .58736 m
.52974 .58716 L
s
.48756 .46055 m
.48801 .45702 L
s
.51593 .54498 m
.51851 .5538 L
s
.57663 .735 m
.57477 .73365 L
s
.47298 .41824 m
.47574 .42007 L
s
.58664 .76672 m
.5865 .76873 L
s
.58546 .76518 m
.58664 .76672 L
s
.49367 .47638 m
.49117 .47289 L
s
.52161 .56439 m
.51998 .56642 L
s
.58048 .7532 m
.5813 .75097 L
s
.48088 .43766 m
.48116 .44117 L
s
.56338 .70228 m
.56595 .70348 L
s
.58531 .76719 m
.58546 .76518 L
s
.5865 .76873 m
.58531 .76719 L
s
.5267 .58944 m
.52832 .58736 L
s
.54436 .64225 m
.54575 .64197 L
s
.48785 .46409 m
.48756 .46055 L
s
.48116 .44117 m
.4827 .44646 L
s
.49117 .47289 m
.4894 .46938 L
s
.57981 .75342 m
.58048 .7532 L
s
.4894 .46938 m
.48785 .46409 L
s
.47095 .41643 m
.47298 .41824 L
s
.54174 .64091 m
.54436 .64225 L
s
.51998 .56642 m
.51958 .57013 L
s
.57794 .7521 m
.57981 .75342 L
s
.56201 .70265 m
.56338 .70228 L
s
.50549 .52958 m
.50716 .52764 L
s
.52631 .5932 m
.5267 .58944 L
s
.46841 .41285 m
.47095 .41643 L
s
.5324 .60894 m
.52994 .60563 L
s
.57623 .74876 m
.57794 .7521 L
s
.53603 .62137 m
.53566 .62518 L
s
.56047 .70501 m
.56201 .70265 L
s
.51958 .57013 m
.51989 .57377 L
s
.54711 .65676 m
.54658 .66257 L
s
.53929 .63763 m
.54174 .64091 L
s
.57294 .74006 m
.57623 .74876 L
s
.52664 .59686 m
.52631 .5932 L
s
.55022 .67505 m
.55283 .67632 L
s
.46611 .40751 m
.46841 .41285 L
s
.51989 .57377 m
.52145 .5791 L
s
.52994 .60563 m
.52819 .60219 L
s
.57122 .73671 m
.57294 .74006 L
s
.46249 .39515 m
.46611 .40751 L
s
.57245 .77176 m
.58196 .76838 L
s
.50455 .53148 m
.50549 .52958 L
s
.52819 .60219 m
.52664 .59686 L
s
.53566 .62518 m
.53599 .62887 L
s
.56933 .73536 m
.57122 .73671 L
s
.51275 .55442 m
.51078 .5528 L
s
.53755 .63421 m
.53929 .63763 L
s
.56013 .70896 m
.56047 .70501 L
s
.53599 .62887 m
.53755 .63421 L
s
.54658 .66257 m
.54692 .66629 L
s
.50412 .53516 m
.50455 .53148 L
s
.5662 .72464 m
.56379 .72148 L
s
.54848 .67165 m
.55022 .67505 L
s
.56849 .73757 m
.56933 .73536 L
s
.51078 .5528 m
.50828 .54939 L
s
.54692 .66629 m
.54848 .67165 L
s
.57508 .75502 m
.5732 .75369 L
s
.56048 .71273 m
.56013 .70896 L
s
.56379 .72148 m
.56205 .7181 L
s
.50443 .53878 m
.50412 .53516 L
s
.50828 .54939 m
.50651 .5459 L
s
.56937 .74317 m
.56849 .73757 L
s
.56205 .7181 m
.56048 .71273 L
s
.50651 .5459 m
.50443 .53878 L
s
.5732 .75369 m
.57094 .74854 L
s
.57094 .74854 m
.56937 .74317 L
s
.55003 .69238 m
.54985 .69436 L
s
.5488 .69077 m
.55003 .69238 L
s
.54862 .69274 m
.5488 .69077 L
s
.54985 .69436 m
.54862 .69274 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`1B0?oo
o`<0003oE03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0200oooo000`0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`040000oe00
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0O0?ooo`00<03oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1>0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<0
00000?ooo`3oool0?`3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01h0oooo000`
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0D03oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0M
0?ooo`00;`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04l0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool07@3oool002l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1>0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0C03oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01`0oooo000_0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
CP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0L0?ooo`00;`3oool2000004H0oooo00<000000?ooo`3oool0C@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3oool0DP3o
ool2000001d0oooo000^0?ooo`800000B03oool00`000000oooo0?ooo`1=0?ooo`030000o`3oool0
oooo0080003oC`3oool00`000000oooo0?ooo`1?0?ooo`<0000000<0oooo0000003oool0703oool0
02l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1=0?ooo`<0003oD03oool00`00
0000oooo0?ooo`1<0?ooo`<00000103oool00`000000oooo0?ooo`0K0?ooo`00;`3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0B@3oool3000000L0
oooo00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo04H0oooo0`00000;0?ooo`030000003oool0oooo01X0oooo
000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?oo
o`130?ooo`<000003P3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo04X0oooo1@000?m=0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0BP3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo03d0oooo0`00000D0?oo
o`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0B@3oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo03T0oooo1000000G0?ooo`03
0000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
B03oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`170?ooo`030000o`3o
ool0oooo04h0oooo00<000000?ooo`3oool0<`3oool3000001h0oooo00<000000?ooo`3oool06P3o
ool002d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0
oooo04h0oooo00<000000?ooo`3oool0<03oool300000240oooo00<000000?ooo`3oool06P3oool0
02d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo
04d0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo04D0oooo0`00
0?m;0?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0000o`1;
0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0@`3oool010000?l0oooo0?ooo`000?m:
0?ooo`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05X0oooo00<000000?ooo`3oool0@P3oool01@000?l0oooo0?ooo`3oool0
003o04X0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool0
02`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`110?ooo`050000o`3oool0oooo
0?ooo`000?l0BP3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H
0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0@03oool01@000?l0oooo0?ooo`3oool0
003o04X0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool0
02/0oooo0P00001O0?ooo`030000003oool0oooo0400oooo00@0003o0?ooo`3oool0003oBP3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo03l0oooo00@0003o0?ooo`3oool0003oBP3oool0
0`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo03h0oooo1@000?m90?ooo`030000003oool0oooo
00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0H`3oool00`000000oooo0?ooo`290?ooo`040000003oool0oooo0?ooo`<00000
DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo03/0oooo00<0003o0?ooo`3oool0BP3oool4000005D0oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0k0?ooo`80003oB03oool3
000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0l0?ooo`80003o@`3oool300000080oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo03d0
oooo00<0003o0?ooo`3oool0?@3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo
0?ooo`0k0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?oo
o`0i0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q
0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03P0oooo0P000?lh
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0i
0?ooo`80003o<`3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F
0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool0>P3oool20000obh0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool0:P3oool3000001P0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`0X
0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?oo
o`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo03D0oooo00<0003o0?oo
o`3oool09P3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000Q0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`1E0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0D@3o
ool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2
000007H0oooo00<000000?ooo`3oool0<P3oool30000oaP0oooo0`00000[0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0<03oool01@000?l0oooo0?ooo`3oool0003o01@0oooo0`00000^
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?oo
o`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02l0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool02`3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0]0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool3000003L0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo02`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`<00000>P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0;03oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo
0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0[0?ooo`060000o`3oool0oooo0000o`3oool0
003o0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0Z0?ooo`060000o`3oool0oooo0000o`00
0000003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool010000000003o0000003oool20000
od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840
oooo00<000000?ooo`3oool09@3oool300000080oooo00@0003o0?ooo`000?l0003o@`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool08@3oool3000004`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
1000001@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000403oool20000od80oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo01@0oooo0`00000A0?ooo`80003oA03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000001D0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000001P0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
203oool3000001/0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103o
ool3000001h0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000Q
0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02H0oooo00<0003o0?ooo`3oool0>`3oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02D0oooo00<0003o0?ooo`000?l0>03oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02D0oooo00@0003o0?ooo`3oool0003o=03oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02D0oooo00D0003o0?ooo`3oool0oooo0000o`0`0?ooo`<000003P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0003o02d0oooo0`00000B0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool09`3oool3
000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00D0003o0?ooo`3oool0oooo0000o`0U
0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?lS
0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool09`3oool40000oal0oooo0`00000R0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?ooo`<00000
:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02`0oooo0`000?l?0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool40000
o`h0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`040000o`3oool0oooo0000
o`X0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`040000o`3oool0oooo0000
o`L0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`040000o`3oool0oooo0000
o`<0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`040000o`3oool0oooo0?oo
o`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:P3oool01@000?l00000000000000000003o
04T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00000010000?l0oooo0?ooo`000?m:0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`03
0000003oool0oooo02D0oooo0`0000040?ooo`030000o`3oool0003o04/0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool0
8@3oool4000000P0oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3o
ool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2
000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000005`3oool20000
odd0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000603oool20000oe00
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000001X0oooo
0P000?l00`3oool0003o0?ooo`1@0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3o
ool300000200oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3
000002<0oooo00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool40000
02H0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000Z0?oo
o`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo1000000]0?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000a0?ooo`D0003o
D03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880
oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo
0?ooo`0c0?ooo`80003oE03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo02l0oooo0P00
0?l00`3oool0003o0000o`1F0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0<03oool0
0`000?l0oooo0?ooo`1H0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0
oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo
0?ooo`0d0?ooo`<0003oE`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0000
o`1G0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0=03oool010000?l0oooo0?ooo`00
0?mG0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0=03oool010000?l0oooo0?ooo`00
0?mH0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0=03oool010000?l0oooo0?ooo`00
0?mI0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0=03oool01@000?l0oooo0?ooo`3o
ool0003o05T0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`0d0?ooo`050000o`3oool0
oooo0?ooo`000?l0F@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo03D0oooo00@0003o
0?ooo`3oool0003oFP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo03H0oooo00<0003o
0?ooo`000?l0F`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?oo
o`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<0
0000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0
UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo03L0oooo00@0003o0?ooo`000?l0003o
G03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3o
ool3000004P0oooo00<000000?ooo`3oool0=`3oool20000o`030?ooo`000?l0oooo05`0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`15
0?ooo`<00000B`3oool00`000000oooo0?ooo`0g0?ooo`050000o`3oool0003o0?ooo`000?l0G@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo0480oooo0`00001>0?ooo`030000003oool0oooo03L0oooo00D0003o0?ooo`000?l0oooo0000
o`1N0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`02
0000oel0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`0h0?ooo`040000o`3oool0003o
0000oel0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`0h0?ooo`050000o`3oool0003o
0?ooo`000?l0G`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo03T0oooo0`000?mQ0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0<`3oool3000005h0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1R0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool30000
06X0oooo00<000000?ooo`3oool0?P3oool20000of80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo03`0
oooo0P000?l00`3oool0003o0?ooo`1R0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
>@3oool30000ofP0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3
000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;
0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000
T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?oo
o`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
0980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`00
8P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2
000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`24
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000
003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03o
ool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2
000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo
0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003o
ool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool20000
06T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool20000
0680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00
000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m
0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?oo
o`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3o
ool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00
001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P
0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080
oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo1000
00050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A
0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?oo
o`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool0
0`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80
oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo
1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000
000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?oo
o`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`80
00003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D0
0000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3o
ool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00
J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2
000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo
000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool00000
02H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000
oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<0
00000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O
0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?oo
o`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@0
0000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3o
ool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2
000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000
oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/
0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`00
00008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@0
0000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`03
0000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2
000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<0
00000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.4987 .41575 m
.4963 .40407 L
s
.4792 .39578 m
.4963 .40407 L
s
.49893 .42039 m
.4987 .41575 L
s
.498 .42299 m
.49893 .42039 L
s
.49219 .43405 m
.50351 .43923 L
s
.49674 .42392 m
.498 .42299 L
s
.49466 .42447 m
.49674 .42392 L
s
.50974 .4696 m
.51078 .47468 L
s
.50825 .46586 m
.50974 .4696 L
s
.50595 .46177 m
.50825 .46586 L
s
.51078 .47468 m
.51068 .47773 L
s
.49059 .42257 m
.49466 .42447 L
s
.50319 .45902 m
.50595 .46177 L
s
.50088 .47669 m
.51217 .48147 L
s
.51068 .47773 m
.50977 .48045 L
s
.49707 .43628 m
.49498 .43686 L
s
.50157 .45831 m
.50319 .45902 L
s
.50614 .50248 m
.51601 .50019 L
s
.50333 .4887 m
.51601 .50019 L
s
.48779 .41973 m
.49059 .42257 L
s
.49498 .43686 m
.49404 .43952 L
s
.49949 .45895 m
.50157 .45831 L
s
.50896 .5163 m
.51881 .51385 L
s
.50614 .50248 m
.51881 .51385 L
s
.4858 .41727 m
.48779 .41973 L
s
.49404 .43952 m
.49392 .44254 L
s
.49856 .46164 m
.49949 .45895 L
s
.4792 .39578 m
.48161 .40763 L
s
.49392 .44254 m
.49496 .44765 L
s
.48347 .4131 m
.4858 .41727 L
s
.48161 .40763 m
.48347 .4131 L
s
.52445 .54132 m
.52586 .54821 L
s
.52294 .53758 m
.52445 .54132 L
s
.52064 .53353 m
.52294 .53758 L
s
.49844 .46471 m
.49856 .46164 L
s
.50332 .47772 m
.501 .47361 L
s
.52586 .54821 m
.52577 .55137 L
s
.51869 .53119 m
.52064 .53353 L
s
.49949 .46984 m
.49844 .46471 L
s
.501 .47361 m
.49949 .46984 L
s
.52577 .55137 m
.52489 .55425 L
s
.51593 .52855 m
.51869 .53119 L
s
.51853 .56327 m
.52976 .56723 L
s
.52489 .55425 m
.52364 .55541 L
s
.51189 .527 m
.51593 .52855 L
s
.53002 .61962 m
.54671 .62472 L
s
.52364 .55541 m
.52124 .55454 L
s
.51946 .54586 m
.52124 .55454 L
s
.53618 .59853 m
.53725 .60377 L
s
.53467 .59478 m
.53618 .59853 L
s
.53237 .59076 m
.53467 .59478 L
s
.53725 .60377 m
.53718 .60701 L
s
.52961 .58822 m
.53237 .59076 L
s
.5098 .52781 m
.51189 .527 L
s
.52749 .60723 m
.53869 .61077 L
s
.53718 .60701 m
.53631 .61001 L
s
.52337 .56498 m
.52131 .56587 L
s
.52801 .58769 m
.52961 .58822 L
s
.54265 .63006 m
.54113 .62631 L
s
.54373 .63534 m
.54265 .63006 L
s
.50853 .52893 m
.5098 .52781 L
s
.54113 .62631 m
.53883 .62231 L
s
.54366 .63863 m
.54373 .63534 L
s
.52131 .56587 m
.52041 .56881 L
s
.52596 .58864 m
.52801 .58769 L
s
.5428 .6417 m
.54366 .63863 L
s
.5076 .53179 m
.50853 .52893 L
s
.52041 .56881 m
.52032 .57203 L
s
.51477 .5522 m
.51279 .54986 L
s
.53161 .65366 m
.54843 .65829 L
s
.52506 .59162 m
.52596 .58864 L
s
.54078 .64279 m
.5428 .6417 L
s
.50749 .53498 m
.5076 .53179 L
s
.52032 .57203 m
.52139 .57729 L
s
.51279 .54986 m
.51044 .54577 L
s
.50891 .54197 m
.50749 .53498 L
s
.51044 .54577 m
.50891 .54197 L
s
.52497 .59488 m
.52506 .59162 L
s
.5445 .67575 m
.55243 .6778 L
s
.52991 .60799 m
.52758 .60396 L
s
.53918 .64233 m
.54078 .64279 L
s
.52605 .60017 m
.52497 .59488 L
s
.52758 .60396 m
.52605 .60017 L
s
.53243 .62036 m
.53155 .62341 L
s
.54422 .68931 m
.55536 .69204 L
s
.53642 .63986 m
.53918 .64233 L
s
.53155 .62341 m
.53147 .62672 L
s
.53408 .63584 m
.53642 .63986 L
s
.55976 .7135 m
.56086 .71888 L
s
.55823 .70974 m
.55976 .7135 L
s
.55592 .70578 m
.55823 .70974 L
s
.53147 .62672 m
.53255 .63205 L
s
.56086 .71888 m
.56081 .7223 L
s
.53255 .63205 m
.53408 .63584 L
s
.54049 .6561 m
.53917 .6608 L
s
.55318 .70343 m
.55592 .70578 L
s
.56081 .7223 m
.55997 .72556 L
s
.54173 .67334 m
.5445 .67575 L
s
.55159 .70306 m
.55318 .70343 L
s
.56603 .74408 m
.56413 .73851 L
s
.56714 .7495 m
.56603 .74408 L
s
.56413 .73851 m
.56219 .73638 L
s
.53917 .6608 m
.5391 .66416 L
s
.56747 .75477 m
.56714 .7495 L
s
.54957 .7043 m
.55159 .70306 L
s
.5391 .66416 m
.54019 .66954 L
s
.54019 .66954 m
.54173 .67334 L
s
.56627 .75629 m
.56747 .75477 L
s
.5716 .77124 m
.57119 .77292 L
s
.57044 .76928 m
.5716 .77124 L
s
.57003 .77096 m
.57044 .76928 L
s
.56548 .75614 m
.56627 .75629 L
s
.54871 .70754 m
.54957 .7043 L
s
.57119 .77292 m
.57003 .77096 L
s
.56353 .75403 m
.56548 .75614 L
s
.54864 .71098 m
.54871 .70754 L
s
.562 .75024 m
.56353 .75403 L
s
.55935 .741 m
.562 .75024 L
s
.55781 .73721 m
.55935 .741 L
s
.55585 .73507 m
.55781 .73721 L
s
.55363 .72419 m
.55129 .72022 L
s
.54975 .71641 m
.54864 .71098 L
s
.55129 .72022 m
.54975 .71641 L
s
.55462 .73656 m
.55585 .73507 L
s
.55491 .76832 m
.56609 .77027 L
s
.53938 .68812 m
.53894 .68973 L
s
.5382 .68611 m
.53938 .68812 L
s
.55494 .74187 m
.55462 .73656 L
s
.53776 .68772 m
.5382 .68611 L
s
.55994 .7551 m
.55797 .75297 L
s
.53894 .68973 m
.53776 .68772 L
s
.55605 .74734 m
.55494 .74187 L
s
.55797 .75297 m
.55605 .74734 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo04d0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0O0?ooo`00<03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo05L0oooo0`000?m=0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
7`3oool00300oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1F0?ooo`030000o`3o
ool0oooo0080003oB`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01h0oooo000`
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`02
0?ooo`80003oB@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01d0oooo000_0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0M0?oo
o`00;`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1C0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo01`0oooo000_0?ooo`800000AP3oool00`000000oooo0?ooo`1B0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`1B0?ooo`8000007@3o
ool002h0oooo0P0000180?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`170?ooo`030000003oool0oooo04l0oooo0`0000000`3oool000000?ooo`0L
0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo0580oooo00D0003o0?oo
o`3oool0oooo0000o`190?ooo`030000003oool0oooo04`0oooo0`0000040?ooo`030000003oool0
oooo01/0oooo000_0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0DP3oool40000
odT0oooo00<000000?ooo`3oool0B@3oool3000000L0oooo00<000000?ooo`3oool06`3oool002h0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo04H0
oooo0`00000;0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo09`0oooo00<0
00000?ooo`3oool0@03oool300000140oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`1>0?ooo`80003oB`3oool00`000000oooo0?ooo`0m
0?ooo`<00000503oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo04h0oooo0`000?m90?ooo`030000003oool0oooo03T0oooo1000000G0?oo
o`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0C@3oool00`000?l0oooo0?ooo`020000odL0oooo00<000000?ooo`3oool0=P3oool3000001/0
oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000003oool0oooo04`0oooo
00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`0c0?ooo`<000007P3oool00`000000oooo
0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04/0oooo00<0
003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo0?oo
o`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo04X0oooo00<0003o
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0]0?ooo`<000009@3oool00`000000oooo0?ooo`0I
0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo09D0oooo00<000000?oo
o`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo02L0oooo0`00000[0?ooo`03
0000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo04P0oooo0P000?m80?ooo`030000003o
ool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0
oooo05T0oooo00<000000?ooo`3oool0A`3oool010000?l0oooo0000o`000?m60?ooo`030000003o
ool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0AP3oool010000?l0oooo0?ooo`000?m70?ooo`030000003o
ool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool0A@3oool010000?l0oooo0?ooo`000?m70?ooo`030000003o
ool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`800000G@3oool0
0`000000oooo0?ooo`140?ooo`050000o`3oool0oooo0?ooo`000?l0AP3oool00`000000oooo0?oo
o`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<00000
0?ooo`3oool0@`3oool01@000?l0oooo0?ooo`3oool0003o04H0oooo00<000000?ooo`3oool04@3o
ool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`130?ooo`040000o`3oool0oooo0000odH0oooo00<000000?ooo`3oool03P3o
ool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`120?ooo`80003o00<0oooo0000o`3oool0A@3oool00`000000oooo0?ooo`0:
0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo0480oooo0`000?m60?ooo`030000003oool0oooo00L0oooo0`00001;0?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0@`3oool20000odD0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`290?ooo`040000
003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0AP3oool4000005D0oooo
00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`0o0?ooo`030000o`3oool0oooo04<0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0o
0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?oo
o`030000003oool0000006P0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0l0?oo
o`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`80
0000J@3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo03P0oooo0`0000080?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0
J@3oool00`000000oooo0?ooo`0l0?ooo`@0003o=P3oool3000000/0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo03<0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0;`3o
ool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0>`3o
ool00`000?l0oooo0?ooo`0/0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo02P0oooo0`00000H0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo03X0oooo0P000?lV0?ooo`<000006`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo03L0oooo0P000?lU0?ooo`<000007P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool0F@3oool400000240oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05D0
oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo
00<000000?ooo`000000M03oool00`000000oooo0?ooo`1A0?ooo`<00000:03oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?oo
o`0b0?ooo`@0003o5`3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0a
0?ooo`050000o`3oool0oooo0?ooo`000?l04`3oool3000002h0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00d0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
00@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo
02l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`<00000=03oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`060?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`0]0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`00000m0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool0
0`000000oooo0?ooo`0/0?ooo`080000o`3oool0oooo0?ooo`000?l000000000o`0000100?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`0/0?ooo`060000o`00000000000000o`3oool0003o@@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0:@3oool3000000050000o`3oool0003o0?ooo`000?l0@@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000
oooo0?ooo`0U0?ooo`<000001@3oool30000od40oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo
0`00001<0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000D03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<00000
0?ooo`3oool0603oool3000000h0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0503oool300000180oooo0P000?m30?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<0
00005@3oool010000?l0oooo0000o`000?m10?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<0
0000603oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000
6`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007P3o
ool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000006H0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`800000J@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`80
0000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0
>`3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`000?l0>03o
ool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`000?l0=@3oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00@0003o0?ooo`3oool0003o<@3oool3
000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00D0003o0?ooo`3oool0oooo0000o`0]
0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0
003o02X0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0oooo
0000obH0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0oooo
0000ob<0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`80003o00<0oooo0000
o`3oool07`3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`000?lL0?ooo`<0
00009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000
S`3oool00`000000oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03o
ool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo0P000?lE0?ooo`<00000<`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0:03oool50000o`h0oooo0`00000f0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0X0?ooo`050000o`3oool0oooo0000o`3oool00P000?l90?ooo`<00000>P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0:03oool01@000?l0oooo0?ooo`3oool0003o00P0oooo0`00000n0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool40000
0480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo00H0003o0?ooo`3oool0oooo0000o`3oool3
000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`0000000P00001:0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000000P3oool00`000?l0oooo0?ooo`190?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000
003oool0oooo02D0oooo0`0000020?ooo`030000o`3oool0003o04d0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool4000000H0oooo0P000?m>0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3o
ool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000@0?ooo`80003oE03oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000E0?ooo`<0003oDP3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000006P3oool010000?l0oooo0000
o`000?mA0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`00
00050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000001d0oooo00<0
003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool300000200oooo00<0003o
0?ooo`3oool0D`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000002<0oooo00<0003o0?oo
o`3oool0E03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000W0?ooo`030000o`3oool0oooo
05D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo1000000[0?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000_0?ooo`80003oE@3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`00
00020?ooo`030000003oool0oooo02l0oooo0P000?mD0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<0
0000303oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`0Z0?ooo`80003o00<0oooo0000o`000?l0FP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00
000A0?ooo`030000003oool0oooo0300oooo0`000?mG0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<0
00006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0
<@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`0`0?ooo`030000o`3o
ool0003o05/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`0_0?ooo`040000o`3oool0
oooo0000oe`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0_0?ooo`050000o`3oool0
oooo0?ooo`000?l0G03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo02l0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?oo
o`3oool0<03oool01@000?l0oooo0?ooo`3oool0003o05d0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`00
0000oooo0?ooo`0`0?ooo`050000o`3oool0oooo0?ooo`000?l0G@3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo0300oooo00D0003o0?ooo`3oool0oooo0000o`1N0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool30000
03P0oooo00<000000?ooo`3oool0<@3oool010000?l0oooo0?ooo`000?mO0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool30000
03/0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0
oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo0680oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`000018
0?ooo`030000003oool0oooo0380oooo0P000?l00`3oool0003o0?ooo`1Q0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool30000
04/0oooo00<000000?ooo`3oool0<P3oool20000o`030?ooo`000?l0oooo0680oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<0
0000CP3oool00`000000oooo0?ooo`0b0?ooo`80003o00<0oooo0000o`3oool0H`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo
1000001A0?ooo`030000003oool0oooo0380oooo0P000?l20?ooo`030000o`3oool0oooo0680oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`0b0?ooo`050000o`3oool0003o0?ooo`000?l0
I03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo0380oooo00D0003o0?ooo`000?l0oooo
0000o`1U0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0<`3oool010000?l0oooo0000
o`000?mV0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0000
o`1W0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
9`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0<`3o
ool50000o`030?ooo`000?l0oooo06P0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`0h
0?ooo`80003oJP3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.51627 .43014 m
.51507 .41938 L
s
.49737 .40434 m
.51507 .41938 L
s
.51596 .43406 m
.51627 .43014 L
s
.51463 .43575 m
.51596 .43406 L
s
.51313 .4359 m
.51463 .43575 L
s
.5069 .44203 m
.5187 .4518 L
s
.51078 .43534 m
.51313 .4359 L
s
.50655 .43181 m
.51078 .43534 L
s
.51198 .44624 m
.50962 .4457 L
s
.50383 .42812 m
.50655 .43181 L
s
.52066 .47613 m
.52185 .47995 L
s
.51863 .47162 m
.52066 .47613 L
s
.52185 .47995 m
.52238 .48468 L
s
.49737 .40434 m
.49855 .4152 L
s
.51593 .46799 m
.51863 .47162 L
s
.52238 .48468 m
.52189 .48716 L
s
.50962 .4457 m
.50826 .44744 L
s
.50196 .42514 m
.50383 .42812 L
s
.51423 .46662 m
.51593 .46799 L
s
.52189 .48716 m
.52056 .48897 L
s
.51122 .4815 m
.52308 .49099 L
s
.49991 .42059 m
.50196 .42514 L
s
.49855 .4152 m
.49991 .42059 L
s
.50826 .44744 m
.50776 .44987 L
s
.51187 .46613 m
.51423 .46662 L
s
.50776 .44987 m
.50827 .45459 L
s
.51051 .46791 m
.51187 .46613 L
s
.51385 .50551 m
.52504 .50845 L
s
.51245 .49268 m
.52504 .50845 L
s
.51 .47038 m
.51051 .46791 L
s
.51527 .51842 m
.52647 .52123 L
s
.51385 .50551 m
.52647 .52123 L
s
.51053 .47514 m
.51 .47038 L
s
.51378 .48355 m
.51173 .479 L
s
.51173 .479 m
.51053 .47514 L
s
.52814 .54312 m
.52935 .547 L
s
.52609 .53859 m
.52814 .54312 L
s
.52935 .547 m
.53008 .55349 L
s
.52421 .53567 m
.52609 .53859 L
s
.53008 .55349 m
.52959 .5561 L
s
.52147 .53209 m
.52421 .53567 L
s
.52959 .5561 m
.52826 .55808 L
s
.51719 .5288 m
.52147 .53209 L
s
.52826 .55808 m
.52674 .55843 L
s
.5201 .56251 m
.53208 .57142 L
s
.52674 .55843 m
.52417 .55651 L
s
.51479 .52845 m
.51719 .5288 L
s
.52327 .54834 m
.52417 .55651 L
s
.51324 .52875 m
.51479 .52845 L
s
.51186 .53069 m
.51324 .52875 L
s
.52526 .56635 m
.52287 .56608 L
s
.53418 .59713 m
.5354 .60106 L
s
.5321 .59258 m
.53418 .59713 L
s
.5354 .60106 m
.53595 .60604 L
s
.52594 .61586 m
.54395 .62857 L
s
.52935 .58906 m
.5321 .59258 L
s
.51135 .5333 m
.51186 .53069 L
s
.53595 .60604 m
.53547 .60875 L
s
.52287 .56608 m
.5215 .5681 L
s
.51729 .55134 m
.51538 .5484 L
s
.52763 .58781 m
.52935 .58906 L
s
.51206 .53986 m
.51135 .5333 L
s
.53547 .60875 m
.53414 .61086 L
s
.52465 .60409 m
.5367 .61269 L
s
.51538 .5484 m
.51328 .5438 L
s
.5215 .5681 m
.521 .57077 L
s
.52523 .58759 m
.52763 .58781 L
s
.51328 .5438 m
.51206 .53986 L
s
.521 .57077 m
.52155 .57574 L
s
.52387 .58966 m
.52523 .58759 L
s
.53753 .62712 m
.53544 .62256 L
s
.53876 .63108 m
.53753 .62712 L
s
.53932 .63612 m
.53876 .63108 L
s
.53884 .63889 m
.53932 .63612 L
s
.52337 .59237 m
.52387 .58966 L
s
.5375 .64107 m
.53884 .63889 L
s
.52392 .59739 m
.52337 .59237 L
s
.52725 .60594 m
.52515 .60136 L
s
.52515 .60136 m
.52392 .59739 L
s
.53511 .64098 m
.5375 .64107 L
s
.52352 .64564 m
.54178 .65808 L
s
.52855 .6177 m
.52718 .61985 L
s
.53338 .63978 m
.53511 .64098 L
s
.52718 .61985 m
.52668 .62261 L
s
.53059 .63629 m
.53338 .63978 L
s
.52668 .62261 m
.52724 .62769 L
s
.53522 .67104 m
.54387 .67682 L
s
.52848 .63169 m
.53059 .63629 L
s
.52724 .62769 m
.52848 .63169 L
s
.53315 .6522 m
.5311 .65555 L
s
.53325 .68254 m
.54541 .69054 L
s
.5311 .65555 m
.5306 .65839 L
s
.53242 .66757 m
.53522 .67104 L
s
.54648 .70724 m
.54773 .71127 L
s
.54436 .70266 m
.54648 .70724 L
s
.54773 .71127 m
.54831 .71648 L
s
.5306 .65839 m
.53117 .66354 L
s
.54157 .69924 m
.54436 .70266 L
s
.54831 .71648 m
.54784 .71941 L
s
.53117 .66354 m
.53242 .66757 L
s
.53983 .69811 m
.54157 .69924 L
s
.54784 .71941 m
.54649 .7218 L
s
.5374 .69815 m
.53983 .69811 L
s
.54959 .73514 m
.54766 .7323 L
s
.55105 .74094 m
.54959 .73514 L
s
.53603 .7005 m
.5374 .69815 L
s
.55164 .74621 m
.55105 .74094 L
s
.55136 .75097 m
.55164 .74621 L
s
.53554 .70343 m
.53603 .7005 L
s
.54982 .75167 m
.55136 .75097 L
s
.52796 .67906 m
.52727 .68022 L
s
.52689 .67674 m
.52796 .67906 L
s
.53611 .70868 m
.53554 .70343 L
s
.52619 .6779 m
.52689 .67674 L
s
.53952 .71737 m
.53737 .71275 L
s
.52727 .68022 m
.52619 .6779 L
s
.53737 .71275 m
.53611 .70868 L
s
.54895 .75114 m
.54982 .75167 L
s
.54262 .73078 m
.54389 .73485 L
s
.54068 .72792 m
.54262 .73078 L
s
.54389 .73485 m
.54574 .74422 L
s
.54701 .7483 m
.54895 .75114 L
s
.55401 .76742 m
.55334 .76868 L
s
.55294 .76513 m
.55401 .76742 L
s
.55227 .76638 m
.55294 .76513 L
s
.53911 .72859 m
.54068 .72792 L
s
.54574 .74422 m
.54701 .7483 L
s
.55334 .76868 m
.55227 .76638 L
s
.53881 .73334 m
.53911 .72859 L
s
.53939 .73866 m
.53881 .73334 L
s
.54282 .74738 m
.54086 .74453 L
s
.53551 .75629 m
.5479 .76375 L
s
.54086 .74453 m
.53939 .73866 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0
oooo04L0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo05X0oooo0`000?m70?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`1I0?ooo`040000o`3oool0oooo0000odH0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo05T0
oooo00@0003o0?ooo`3oool0003oA@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
01`0oooo000_0?ooo`800000AP3oool00`000000oooo0?ooo`1H0?ooo`040000o`3oool0oooo0?oo
o`80003oA03oool00`000000oooo0?ooo`1B0?ooo`8000007@3oool002h0oooo0P0000180?ooo`03
0000003oool0oooo05L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo04l0oooo0`0000000`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`110?ooo`030000003oool0oooo04`0oooo0`0000040?ooo`030000003oool0oooo01/0oooo
000_0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0B@3oool3000000L0oooo00<0
00000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1E
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`16
0?ooo`<000002`3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0oooo05D0oooo00D0003o0?ooo`3oool0oooo0000o`130?ooo`030000003oool0
oooo04<0oooo0`00000>0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0E@3oool010000?l0oooo0?ooo`000?m30?ooo`030000003oool0
oooo0400oooo0`00000A0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0000o`130?ooo`030000003oool0oooo
03d0oooo0`00000D0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool0E@3oool20000od<0oooo00<000000?ooo`3oool0>@3oool4000001L0
oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000003oool0oooo01X0oooo
000]0?ooo`800000DP3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo04@0oooo00<0
00000?ooo`3oool0<`3oool3000001h0oooo00<000000?ooo`3oool06P3oool002d0oooo00<00000
0?ooo`3oool0DP3oool00`000000oooo0?ooo`1A0?ooo`80003oA03oool00`000000oooo0?ooo`0`
0?ooo`<000008@3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo04l0oooo00<0003o0?ooo`000?l0A03oool00`000000oooo0?ooo`0]0?oo
o`<000009@3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo04h0oooo00@0003o0?ooo`3oool0003o@`3oool00`000000oooo0?ooo`0Z0?oo
o`<00000:03oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo04d0oooo00D0003o0?ooo`3oool0oooo0000o`120?ooo`030000003oool0oooo
02L0oooo0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo02@0
oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo
0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0940oooo00<0
00000?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0FP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01X0oooo0`00000g
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?oo
o`3oool0BP3oool20000od@0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?oo
o`3oool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`00
0?l0A03oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool2000005l0oooo00<000000?ooo`3oool0A`3oool010000?l0oooo0?ooo`000?m30?ooo`03
0000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0AP3oool010000?l0oooo0?ooo`000?m30?ooo`03
0000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000
003oool0oooo0600oooo00<000000?ooo`3oool0A@3oool01@000?l0oooo0?ooo`3oool0003o0480
oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`150?ooo`040000o`3oool0oooo0000od80
oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`130?ooo`80003o0P3oool00`000?l0oooo
0?ooo`100?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0@`3oool20000o`80oooo00<0
003o0?ooo`3oool0?`3oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool0
5`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`140?ooo`80003o@P3o
ool4000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`150?ooo`030000o`3oool0oooo03d0oooo0`00001H0?ooo`030000003oool0
oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0@03oool00`00
0?l0oooo0?ooo`0n0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0@03oool00`000?l0
oooo0?ooo`0j0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo03H0oooo
0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo03<0oooo0`00
000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P000007
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0_
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0l
0?ooo`<0003o00<0oooo0000o`3oool0;03oool300000140oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0000o`020000obT0oooo0`00000D
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03`0oooo00<0003o
0?ooo`3oool09`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<00000
0?ooo`3oool0?03oool00`000?l0oooo0?ooo`0S0?ooo`<000006`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo03T0oooo0P000?l00`3oool0003o0?ooo`0P0?ooo`<000007P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0>P3oool30000oa`0oooo1000000Q0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1E0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0D@3oool3000002P0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<00000
0?ooo`3oool0=03oool30000oaH0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0<`3oool00`000?l0oooo0000o`0C0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0b0?ooo`040000o`3oool0oooo0000o`l0oooo0`00000a0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0340oooo00D0003o0?ooo`3o
ool0oooo0000o`0;0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0300
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`<00000=`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00<0oooo00@0
003o0000000000000000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0;@3oool010000?l0oooo0?oo
o`3oool2000000030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo00H0
003o000000000000003o0?ooo`000?m00?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<00000
00@0oooo0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo
0`0000060?ooo`040000o`3oool0003o0000ocl0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo
0`0000090?ooo`<0003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool400000500oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01P0oooo0`00000?0?ooo`030000o`3oool0oooo0480oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo01@0oooo0`00000C0?ooo`80003o@P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0403oool3000001D0oooo00@0003o0?ooo`000?l0003o@@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000001P0oooo00D0003o0?ooo`3oool0oooo0000o`100?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`080?ooo`<000006`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`040?ooo`<000007P3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`03000006H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02D0
oooo0P000?lm0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo
0000o`0i0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?oo
o`000?le0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?oo
o`000?lb0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool01@000?l0oooo0?oo
o`3oool0003o02h0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`050000o`3o
ool0oooo0?ooo`000?l0:P3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02@0oooo0P00
0?l30?ooo`030000o`3oool0oooo02@0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U
0?ooo`050000o`3oool0oooo0?ooo`000?l08`3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02H0oooo0P000?l00`3oool0003o0?ooo`0O0?ooo`<000008P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`0L0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000o`3oool0oooo01P0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0U0?ooo`80003o
6@3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo0`000?lE0?ooo`<00000<`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`020000oa00oooo0`00000f
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l03@3oool3
000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3oool0oooo0`000?l8
0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0003o00<0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0W0?ooo`05
0000o`3oool0oooo0?ooo`000?l00P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0
oooo00<0003o0?ooo`3oool00`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000
00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo
000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<0000000<0oooo0000o`000?l0C`3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool0
0`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
00@0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0
oooo0`0000080?ooo`80003oE03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0
oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0H0?ooo`<000003@3oool20000oe<0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool05@3oool300000100oooo0P000?mD0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool04@3oool4000001<0oooo00@0003o0?ooo`000?l0003oD`3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000005`3oool01@000?l0oooo0?oo
o`3oool0003o05<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<000006P3o
ool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<000007@3oool0
0`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000803oool00`00
0?l0oooo0?ooo`1G0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000002D0oooo00<0003o0?oo
o`3oool0E`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`80
0000T@3oool4000002T0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000002d0oooo0P000?mG0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03o
ool300000080oooo00<000000?ooo`3oool09P3oool20000o`D0oooo00<0003o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08P0oooo100000050?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool0F`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880
oooo0`00000<0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0F`3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo
0`00000?0?ooo`030000003oool0oooo02/0oooo0P000?mL0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<0
00000?ooo`3oool0;P3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo02`0oooo00<0003o0?oo
o`3oool0G@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`00
0?l0G`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo02/0oooo00@0003o0?ooo`3oool0
003oG`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0:`3oool010000?l0oooo0?ooo`000?mO0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0
J@3oool4000002@0oooo00<000000?ooo`3oool0:`3oool01@000?l0oooo0?ooo`3oool0003o05l0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo
0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0[0?ooo`050000o`3oool0oooo0?ooo`00
0?l0H03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo02/0oooo00D0003o0?ooo`3oool0
oooo0000o`1Q0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0:`3oool01@000?l0oooo
0?ooo`3oool0003o0680oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`0/0?ooo`040000
o`3oool0oooo0000of80oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`0_0?ooo`030000
o`3oool0oooo0640oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3
000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo
02`0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo02`0
oooo0P000?l00`3oool0003o0?ooo`1U0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0
;03oool01@000?l0oooo0000o`3oool0003o06H0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo02`0oooo
00D0003o0?ooo`000?l0oooo0000o`1W0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0
;03oool01@000?l0oooo0000o`3oool0003o06P0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo
0?ooo`0/0?ooo`050000o`3oool0003o0?ooo`000?l0J@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000
003oool0oooo02d0oooo0P000?l20?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3o
ool00`000000oooo0?ooo`0]0?ooo`040000o`3oool0003o0000ofX0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03o
ool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0:`3oool00`00
0?l0oooo0?ooo`1`0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`1`0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0;@3oool20000og00oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0003o06h0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W
0?ooo`<00000JP3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo06d0oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?oo
o`030000003oool0oooo0380oooo00<0003o0?ooo`3oool0KP3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`03
0000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3o
ool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`00
0000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@0
0000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0007
0?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
00000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?oo
o`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3o
ool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?oo
o`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00
<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0
_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000
003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3o
ool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0
oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000
003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2
000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool2
00000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000
oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo
0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo
00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<00000
0?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?oo
o`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000
DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo
0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo
001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool20000
0080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo
100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=
0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3o
ool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool0
0`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo
0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0
oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo
1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g
0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?oo
o`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`04
0000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?oo
o`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?oo
o`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3o
ool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?oo
o`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00
P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3o
ool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0
oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0
000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`00
0000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo
00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?oo
o`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K
0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?oo
o`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00
TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3o
ool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`00
0000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000
oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo
0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?oo
o`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?oo
o`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?oo
o`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?oo
o`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo
0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3o
ool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool0
0`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?oo
o`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.53383 .45051 m
.53381 .44106 L
s
.51621 .42012 m
.53381 .44106 L
s
.53301 .45359 m
.53383 .45051 L
s
.53135 .45434 m
.53301 .45359 L
s
.52967 .45373 m
.53135 .45434 L
s
.52716 .45213 m
.52967 .45373 L
s
.52208 .45576 m
.53388 .46959 L
s
.52294 .44716 m
.52716 .45213 L
s
.51621 .42012 m
.51618 .42961 L
s
.5204 .4428 m
.52294 .44716 L
s
.52716 .46171 m
.52462 .46012 L
s
.51871 .43944 m
.5204 .4428 L
s
.51618 .42961 m
.51701 .4347 L
s
.51701 .4347 m
.51871 .43944 L
s
.52462 .46012 m
.52292 .46089 L
s
.53309 .49072 m
.53394 .49448 L
s
.5314 .48598 m
.53309 .49072 L
s
.52886 .48165 m
.5314 .48598 L
s
.53394 .49448 m
.53395 .49867 L
s
.52292 .46089 m
.52207 .46266 L
s
.52717 .47968 m
.52886 .48165 L
s
.53395 .49867 m
.53312 .50049 L
s
.52207 .46266 m
.52206 .46681 L
s
.52461 .47812 m
.52717 .47968 L
s
.53312 .50049 m
.53143 .50135 L
s
.52203 .49056 m
.53397 .50427 L
s
.5229 .47893 m
.52461 .47812 L
s
.52205 .48073 m
.5229 .47893 L
s
.52204 .48494 m
.52205 .48073 L
s
.522 .51183 m
.53401 .51979 L
s
.52202 .50045 m
.53401 .51979 L
s
.52289 .48873 m
.52204 .48494 L
s
.5246 .49351 m
.52289 .48873 L
s
.52198 .5233 m
.53404 .53117 L
s
.522 .51183 m
.53404 .53117 L
s
.53323 .55034 m
.53409 .5542 L
s
.5315 .54552 m
.53323 .55034 L
s
.52977 .54215 m
.5315 .54552 L
s
.53409 .5542 m
.53411 .56001 L
s
.52718 .5378 m
.52977 .54215 L
s
.52284 .53293 m
.52718 .5378 L
s
.53411 .56001 m
.53325 .56197 L
s
.53325 .56197 m
.53153 .56297 L
s
.52022 .53145 m
.52284 .53293 L
s
.53153 .56297 m
.5298 .56251 L
s
.52719 .55231 m
.52719 .55962 L
s
.51847 .53094 m
.52022 .53145 L
s
.52193 .56265 m
.53415 .57611 L
s
.5298 .56251 m
.52719 .55962 L
s
.51671 .53188 m
.51847 .53094 L
s
.51582 .53381 m
.51671 .53188 L
s
.52719 .56844 m
.52456 .56703 L
s
.5158 .53965 m
.51582 .53381 L
s
.52018 .55187 m
.51843 .54845 L
s
.51667 .54356 m
.5158 .53965 L
s
.52456 .56703 m
.5228 .56805 L
s
.51843 .54845 m
.51667 .54356 L
s
.53334 .59888 m
.53422 .60281 L
s
.53158 .59399 m
.53334 .59888 L
s
.52895 .58964 m
.53158 .59399 L
s
.53422 .60281 m
.53423 .60731 L
s
.5228 .56805 m
.52192 .57005 L
s
.5272 .58772 m
.52895 .58964 L
s
.53423 .60731 m
.53336 .60937 L
s
.52192 .57005 m
.52191 .5745 L
s
.52455 .58634 m
.5272 .58772 L
s
.52186 .61063 m
.5404 .63047 L
s
.53336 .60937 m
.53161 .61049 L
s
.52188 .6 m
.53424 .61332 L
s
.52278 .58741 m
.52455 .58634 L
s
.52189 .58945 m
.52278 .58741 L
s
.52188 .59397 m
.52189 .58945 L
s
.5334 .626 m
.53163 .62108 L
s
.53429 .62998 m
.5334 .626 L
s
.5343 .63456 m
.53429 .62998 L
s
.52277 .59794 m
.52188 .59397 L
s
.52454 .60288 m
.52277 .59794 L
s
.53342 .63668 m
.5343 .63456 L
s
.53166 .63787 m
.53342 .63668 L
s
.52454 .61349 m
.52275 .61463 L
s
.52899 .63658 m
.53166 .63787 L
s
.52275 .61463 m
.52185 .61673 L
s
.52721 .63469 m
.52899 .63658 L
s
.51547 .63472 m
.53435 .65454 L
s
.52185 .61673 m
.52184 .62132 L
s
.52453 .63032 m
.52721 .63469 L
s
.52184 .62132 m
.52274 .62534 L
s
.52274 .62534 m
.52453 .63032 L
s
.52541 .66231 m
.53439 .67164 L
s
.52542 .64516 m
.52271 .64699 L
s
.52271 .64699 m
.52181 .64916 L
s
.52177 .67116 m
.53442 .68419 L
s
.52181 .64916 m
.5218 .65385 L
s
.5227 .65793 m
.52541 .66231 L
s
.5218 .65385 m
.5227 .65793 L
s
.53356 .69911 m
.53447 .70321 L
s
.53175 .69409 m
.53356 .69911 L
s
.52904 .68972 m
.53175 .69409 L
s
.53447 .70321 m
.53448 .708 L
s
.52722 .68787 m
.52904 .68972 L
s
.53448 .708 m
.53359 .71029 L
s
.5245 .68667 m
.52722 .68787 L
s
.53359 .71029 m
.53178 .71167 L
s
.52267 .68799 m
.5245 .68667 L
s
.51629 .66551 m
.51536 .66615 L
s
.51537 .66298 m
.51629 .66551 L
s
.51445 .66361 m
.51537 .66298 L
s
.52175 .69026 m
.52267 .68799 L
s
.51536 .66615 m
.51445 .66361 L
s
.53362 .72478 m
.5318 .72134 L
s
.53454 .73055 m
.53362 .72478 L
s
.52174 .69507 m
.52175 .69026 L
s
.53455 .73542 m
.53454 .73055 L
s
.52265 .69922 m
.52174 .69507 L
s
.53365 .7394 m
.53455 .73542 L
s
.52448 .70429 m
.52265 .69922 L
s
.53183 .73922 m
.53365 .7394 L
s
.52632 .71745 m
.52723 .72162 L
s
.52448 .71399 m
.52632 .71745 L
s
.52723 .72162 m
.52816 .73067 L
s
.52264 .71376 m
.52448 .71399 L
s
.53091 .73831 m
.53183 .73922 L
s
.52908 .73485 m
.53091 .73831 L
s
.52816 .73067 m
.52908 .73485 L
s
.52171 .71771 m
.52264 .71376 L
s
.5346 .75505 m
.53369 .7558 L
s
.53368 .7525 m
.5346 .75505 L
s
.53277 .75325 m
.53368 .7525 L
s
.5217 .72261 m
.52171 .71771 L
s
.53369 .7558 m
.53277 .75325 L
s
.52262 .72844 m
.5217 .72261 L
s
.52447 .73191 m
.52262 .72844 L
s
.51512 .73589 m
.52817 .74872 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
05`0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05/0
oooo0P000?m20?ooo`030000003oool0oooo04T0oooo0`0000070?ooo`030000003oool0oooo01/0
oooo000^0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0FP3oool00`000?l0oooo
0000o`110?ooo`030000003oool0oooo04H0oooo0`00000;0?ooo`030000003oool0oooo01X0oooo
000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0F@3oool010000?l0oooo0?oo
o`000?m00?ooo`030000003oool0oooo04<0oooo0`00000>0?ooo`030000003oool0oooo01X0oooo
000^0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0F03oool010000?l0oooo0?oo
o`000?m00?ooo`030000003oool0oooo0400oooo0`00000A0?ooo`030000003oool0oooo01X0oooo
000^0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0F03oool010000?l0oooo0?oo
o`000?lo0?ooo`030000003oool0oooo03d0oooo0`00000D0?ooo`030000003oool0oooo01X0oooo
000^0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0E`3oool01@000?l0oooo0?oo
o`3oool0003o03h0oooo00<000000?ooo`3oool0>@3oool4000001L0oooo00<000000?ooo`3oool0
6P3oool002h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1F0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`0f0?ooo`<000006`3o
ool00`000000oooo0?ooo`0J0?ooo`00;@3oool200000580oooo00<000000?ooo`3oool0EP3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0<`3oool3
000001h0oooo00<000000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`1E0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo05D0oooo00D0003o0?ooo`3oool0oooo0000o`0l0?oo
o`030000003oool0oooo02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0E03oool01@000?l0oooo0?ooo`3oool0003o
03`0oooo00<000000?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1D0?ooo`80003o00<0oooo0000o`3o
ool0>`3oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00
;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0580oooo00@0003o0?ooo`3oool0
003o?@3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0
?@3oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03o
ool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0500oooo0`000?ln0?ooo`030000003o
ool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0
oooo05X0oooo00<000000?ooo`3oool0C`3oool00`000?l0oooo0000o`0o0?ooo`030000003oool0
oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0CP3oool010000?l0oooo0?ooo`000?ln0?ooo`030000003oool0
oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`00
0000oooo0?ooo`1A0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0503oool30000
03h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00h0oooo
0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<0
00000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo00X0oooo1000
00170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool0B@3oool20000od00oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<00000
0?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`180?oo
o`030000o`3oool0003o03l0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`170?ooo`04
0000o`3oool0oooo0000och0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0
oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0AP3oool01000
0?l0oooo0?ooo`000?ln0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo04D0oooo00D0003o0?ooo`3oool0oooo0000o`0k
0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo04@0oooo0P000?l20?ooo`030000o`3oool0oooo03H0oooo0`0000020?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`00
0000J03oool00`000000oooo0?ooo`150?ooo`030000o`3oool0003o03D0oooo0`0000050?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000
003oool0oooo04D0oooo00<0003o0?ooo`000?l0<P3oool3000000P0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo0480oooo00<0003o0?ooo`3oool00P000?l_0?ooo`<000002`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo0480oooo00@0003o0?ooo`3oool0003o;03oool3000000h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?oo
o`0Z0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`110?ooo`030000o`3oool0oooo02H0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`1^0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`000?l09@3oool3000001P0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0000
o`0Q0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q
0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo03d0oooo0`000?lN
0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0000o`0I0?oo
o`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool0>@3oool010000?l0oooo0?ooo`000?lH0?oo
o`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`03
0000003oool0000007@0oooo00<000000?ooo`3oool0>@3oool20000o`030?ooo`000?l0oooo01<0
oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo
0P00001f0?ooo`030000003oool0oooo03X0oooo0P000?lA0?ooo`<00000:`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo03D0oooo0P000?l40?ooo`030000o`3oool0oooo00/0oooo0`00
000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<00000
0?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03<0oooo00@0003o
0?ooo`3oool0003o3P3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool0<P3oool010000?l0oooo0?ooo`000?l;0?ooo`<00000=03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo0340oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`<00000=`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
oooo0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0<03oool01@000?l0oooo0?ooo`3o
ool0003o00<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo00000002
000000030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo00<000000000
o`000000103oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<0
00000P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool0
9@3oool3000000L0oooo00@0003o0?ooo`3oool0003o?P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
8@3oool3000000X0oooo00@0003o0?ooo`3oool0003o?P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0
703oool4000000d0oooo00@0003o0?ooo`3oool0003o?`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
603oool3000000l0oooo00<0003o0?ooo`3oool00`000?lo0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`0D0?ooo`<000004`3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<000005P3oool20000od80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000H0?oo
o`040000o`3oool0oooo0000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000K0?oo
o`050000o`3oool0oooo0?ooo`000?l0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool30000
02<0oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00001V0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
S03oool2000006T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool0I`3oool2000005/0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0T0?ooo`80003o?P3oool3
00000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o>@3oool4
000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o=P3oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0oooo00D0003o0?ooo`3oool0oooo0000o`0b
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0
003o02h0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`0Y0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool01@000?l0
oooo0?ooo`3oool0003o02L0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`04
0000o`3oool0oooo0000ob@0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`03
0000o`3oool0003o0240oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0S0?ooo`050000
o`3oool0oooo0?ooo`000?l07`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0903oool01@000?l0oooo
0?ooo`3oool0003o01/0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0S0?ooo`030000
o`3oool0003o01X0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`040000o`3o
ool0oooo0000oaH0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`050000o`3o
ool0oooo0?ooo`000?l04P3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00<0
003o0?ooo`3oool00P000?l>0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool09@3oool0
10000?l0oooo0?ooo`3oool20000o`X0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0U
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`050?ooo`@00000@P3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo0`0000170?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo
00000002000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02<0oooo00D0003o0?ooo`3oool0oooo
0000o`03000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool3000008h0oooo00<000000?ooo`3oool0903oool010000?l0000000000000001B0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003o
ool0oooo0240oooo100000000`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<00000103oool20000oeD0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<000001P3oool010000?l0oooo0?ooo`000?mD0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01P0oooo0`0000090?ooo`050000o`3oool0oooo0?ooo`000?l0E03o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000303oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0A0?ooo`@00000403oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000D0?ooo`030000o`3oool0oooo05P0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000503oool01@000?l0oooo
0?ooo`3oool0003o05T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000G0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103o
ool4000001X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1H0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
10000000oooo0?ooo`3oool300000200oooo00D0003o0?ooo`3oool0oooo0000o`1J0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000903o
ool01@000?l0oooo0?ooo`3oool0003o05X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool200000900oooo0`00000X0?ooo`030000o`3oool0oooo05/0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<
0?ooo`<000000P3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo05/0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?oo
o`@000001@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo05/0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<0
00002@3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000
303oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3o
ool00`000000oooo0?ooo`0U0?ooo`<0003oH@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0
oooo02D0oooo00@0003o0?ooo`3oool0003oH@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo02D0oooo00D0003o0?ooo`3oool0oooo0000o`1Q0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<00000
0?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0003o0680oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool0
0`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l0HP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N
0?ooo`030000003oool0oooo02H0oooo00D0003o0?ooo`3oool0oooo0000o`1S0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l0H`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T
0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?oo
o`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo02H0oooo00@0003o0?ooo`3oool0003oI`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`03
0000003oool0oooo02D0oooo0P000?m[0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0000o`1Z0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool09@3o
ool01@000?l0oooo0000o`3oool0003o06T0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?oo
o`0U0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`1X
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0000o`3oool0
003o06/0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0003o
0?ooo`000?l0J`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo02P0oooo00<0003o0?oo
o`000?l0K03oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`030?ooo`80
003oK@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0
0P3oool20000ofh0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`0U0?ooo`80003oL`3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03l0oooo1000001A0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0L@3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0L03oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0
oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo
0?ooo`0Z0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?oo
o`0Z0?ooo`030000o`3oool0oooo0740oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.55072 .47591 m
.55182 .46807 L
s
.53497 .44222 m
.55182 .46807 L
s
.54944 .47806 m
.55072 .47591 L
s
.54751 .47787 m
.54944 .47806 L
s
.54574 .47655 m
.54751 .47787 L
s
.53497 .44222 m
.53379 .45003 L
s
.54316 .47399 m
.54574 .47655 L
s
.53911 .46782 m
.54316 .47399 L
s
.53713 .47452 m
.54848 .49176 L
s
.53379 .45003 m
.53409 .45463 L
s
.53684 .46298 m
.53911 .46782 L
s
.53538 .45937 m
.53684 .46298 L
s
.53409 .45463 m
.53538 .45937 L
s
.54201 .48193 m
.5394 .47937 L
s
.5394 .47937 m
.53744 .47918 L
s
.53744 .47918 m
.53628 .48023 L
s
.53628 .48023 m
.53577 .48367 L
s
.54377 .50418 m
.54507 .50896 L
s
.54148 .49933 m
.54377 .50418 L
s
.54507 .50896 m
.54555 .51251 L
s
.53985 .49686 m
.54148 .49933 L
s
.54555 .51251 m
.54506 .51601 L
s
.53722 .49431 m
.53985 .49686 L
s
.54506 .51601 m
.54391 .51712 L
s
.53523 .49414 m
.53722 .49431 L
s
.54391 .51712 m
.54194 .517 L
s
.53286 .50339 m
.5444 .52069 L
s
.53407 .49522 m
.53523 .49414 L
s
.53355 .49872 m
.53407 .49522 L
s
.53403 .50229 m
.53355 .49872 L
s
.53534 .50712 m
.53403 .50229 L
s
.53024 .52111 m
.54257 .53368 L
s
.53164 .51162 m
.54257 .53368 L
s
.52882 .53069 m
.54122 .54324 L
s
.53024 .52111 m
.54122 .54324 L
s
.53666 .55402 m
.53799 .55893 L
s
.53516 .55033 m
.53666 .55402 L
s
.53799 .55893 m
.53849 .56261 L
s
.53281 .5454 m
.53516 .55033 L
s
.53849 .56261 m
.53779 .5675 L
s
.5286 .53918 m
.53281 .5454 L
s
.53779 .5675 m
.53661 .56873 L
s
.52588 .53664 m
.5286 .53918 L
s
.53661 .56873 m
.53457 .56871 L
s
.524 .53535 m
.52588 .53664 L
s
.52193 .53526 m
.524 .53535 L
s
.53104 .55759 m
.53015 .56374 L
s
.53457 .56871 m
.5327 .56747 L
s
.5327 .56747 m
.53015 .56374 L
s
.52071 .53644 m
.52193 .53526 L
s
.52394 .56367 m
.53588 .58109 L
s
.51997 .54133 m
.52071 .53644 L
s
.52046 .54503 m
.51997 .54133 L
s
.52908 .57117 m
.52633 .56867 L
s
.52333 .55375 m
.5218 .55001 L
s
.5218 .55001 m
.52046 .54503 L
s
.52633 .56867 m
.52425 .56865 L
s
.52425 .56865 m
.52302 .5699 L
s
.52302 .5699 m
.52247 .57365 L
s
.53083 .59492 m
.53219 .59993 L
s
.52844 .58993 m
.53083 .59492 L
s
.53219 .59993 m
.53269 .60371 L
s
.52672 .58744 m
.52844 .58993 L
s
.53269 .60371 m
.53215 .60752 L
s
.52395 .58495 m
.52672 .58744 L
s
.53215 .60752 m
.53093 .60884 L
s
.52185 .58497 m
.52395 .58495 L
s
.53093 .60884 m
.52884 .60891 L
s
.51929 .59516 m
.53143 .61263 L
s
.52061 .58625 m
.52185 .58497 L
s
.51796 .60415 m
.5362 .63029 L
s
.52004 .59006 m
.52061 .58625 L
s
.52054 .59386 m
.52004 .59006 L
s
.5219 .59892 m
.52054 .59386 L
s
.52893 .62298 m
.52756 .61791 L
s
.52943 .62681 m
.52893 .62298 L
s
.52888 .63071 m
.52943 .62681 L
s
.52764 .63207 m
.52888 .63071 L
s
.52059 .60791 m
.51845 .60798 L
s
.52552 .6322 m
.52764 .63207 L
s
.51845 .60798 m
.51719 .60931 L
s
.52271 .62976 m
.52552 .6322 L
s
.51719 .60931 m
.51662 .61321 L
s
.52095 .62726 m
.52271 .62976 L
s
.51662 .61321 m
.51712 .61707 L
s
.5185 .62219 m
.52095 .62726 L
s
.51712 .61707 m
.5185 .62219 L
s
.50785 .62139 m
.52647 .64776 L
s
.51765 .63527 m
.5144 .63547 L
s
.51552 .6499 m
.52441 .66241 L
s
.5144 .63547 m
.51312 .63686 L
s
.51312 .63686 m
.51253 .64085 L
s
.51303 .64479 m
.51552 .6499 L
s
.51035 .65562 m
.52289 .67318 L
s
.51253 .64085 m
.51303 .64479 L
s
.51866 .68031 m
.52007 .68554 L
s
.51617 .67519 m
.51866 .68031 L
s
.52007 .68554 m
.52058 .68953 L
s
.51436 .67268 m
.51617 .67519 L
s
.52058 .68953 m
.52 .69366 L
s
.51146 .67027 m
.51436 .67268 L
s
.52 .69366 m
.51871 .69517 L
s
.5031 .64548 m
.50422 .6454 L
s
.50422 .6454 m
.50492 .64802 L
s
.50492 .64802 m
.50381 .6481 L
s
.50924 .67048 m
.51146 .67027 L
s
.50381 .6481 m
.5031 .64548 L
s
.51871 .69517 m
.51651 .69544 L
s
.50793 .67196 m
.50924 .67048 L
s
.50732 .67608 m
.50793 .67196 L
s
.50783 .6801 m
.50732 .67608 L
s
.51694 .70767 m
.51532 .70378 L
s
.51725 .71312 m
.51694 .70767 L
s
.50924 .68539 m
.50783 .6801 L
s
.51666 .71734 m
.51725 .71312 L
s
.51515 .72032 m
.51666 .71734 L
s
.50965 .69764 m
.51016 .70169 L
s
.50802 .69372 m
.50965 .69764 L
s
.50599 .69259 m
.50802 .69372 L
s
.51016 .70169 m
.51006 .70997 L
s
.51312 .71923 m
.51515 .72032 L
s
.50445 .69552 m
.50599 .69259 L
s
.5122 .71797 m
.51312 .71923 L
s
.51006 .70997 m
.51057 .71405 L
s
.51057 .71405 m
.5122 .71797 L
s
.50382 .69973 m
.50445 .69552 L
s
.50412 .70522 m
.50382 .69973 L
s
.51354 .73167 m
.51426 .73435 L
s
.51242 .73185 m
.51354 .73167 L
s
.51426 .73435 m
.51314 .73453 L
s
.50576 .70916 m
.50412 .70522 L
s
.51314 .73453 m
.51242 .73185 L
s
.49477 .70783 m
.50781 .72557 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`1K0?ooo`030000o`3o
ool0oooo03X0oooo00<000000?ooo`3oool0<`3oool3000001h0oooo00<000000?ooo`3oool06P3o
ool002d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1J0?ooo`80003o>`3oool0
0`000000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo05T0oooo0P000?lk0?ooo`030000003oool0oooo
02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0000o`0j0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0E`3oool010000?l0oooo0?ooo`000?li0?ooo`030000003oool0oooo02L0
oooo0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool0EP3oool010000?l0oooo0?ooo`000?li0?ooo`030000003oool0oooo02@0
oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0EP3oool010000?l0oooo0?ooo`000?lh0?ooo`030000003oool0oooo0240
oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0E@3oool01@000?l0oooo0?ooo`3oool0003o03L0oooo00<000000?ooo`3o
ool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1D0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
=@3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03o
ool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003o
ool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool0
0`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0DP3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool04@3oool30000
0440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`1@0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0=@3oool00`000000
oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1P0?ooo`030000003oool0oooo0500oooo00<0003o0?ooo`000?l00P000?lg0?ooo`030000
003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo0640oooo00<000000?ooo`3oool0CP3oool20000oc/0oooo00<000000?ooo`3oool01`3o
ool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`1=0?ooo`030000o`3oool0003o03X0oooo00<000000?ooo`3oool0103oool3
000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`00
0000oooo0?ooo`1?0?ooo`030000o`3oool0oooo03L0oooo00@000000?ooo`3oool0oooo0`00001B
0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0CP3oool00`000?l0oooo0?ooo`0g0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?oo
o`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3o
ool0=03oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0
I`3oool00`000000oooo0?ooo`180?ooo`80003o=`3oool300000080oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003o
ool0oooo04L0oooo00<0003o0?ooo`000?l0<`3oool3000000D0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0A`3oool0
10000?l0oooo0?ooo`000?l_0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0AP3oool0
10000?l0oooo0?ooo`000?l/0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo04D0oooo00D0003o0?ooo`3oool0oooo0000o`0X0?ooo`<000003P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`140?ooo`80003o0P3oool00`000?l0oooo0?oo
o`0S0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`140?ooo`040000o`3oool0oooo0000ob80oooo0`00000D0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo0440oooo00H0003o0?ooo`3oool0003o0?ooo`000?lO0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`100?oo
o`040000o`3oool0oooo0?ooo`80003o703oool3000001/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`100?ooo`030000o`3oool0oooo0080003o6@3oool3000001h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`03
0000003oool0oooo03h0oooo0P000?l30?ooo`030000o`3oool0oooo01<0oooo1000000Q0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`0m0?ooo`<0003o5@3oool3000002D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003o
ool0oooo03d0oooo0P000?lB0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0l0?ooo`<0003o3P3oool3
000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool40000
0200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo
0080003o2`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0>@3oool01@000?l0oooo0000o`3oool0003o00L0oooo0`00000a0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo03@0oooo0`000?l20?ooo`030000o`3oool0003o00D0
oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0<`3oool010000?l0oooo
0?ooo`000?l20?ooo`80003o0P3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0380oooo
00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003o00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool0<@3oool02@000?l0oooo0?ooo`3oool000000000o`000000oooo0000o`0k
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?oo
o`3oool0O@3oool00`000000oooo0?ooo`0`0?ooo`060000o`00000000000000003oool0003o?P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool0;@3oool2000000030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool300000080oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000060?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
8@3oool3000000`0oooo00<0003o0?ooo`000?l0?@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703o
ool4000000l0oooo00<0003o0?ooo`000?l0?P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3
00000100oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0k0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0D0?ooo`<00000503oool01@000?l0oooo0000o`3oool0003o03h0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0100oooo0`00000F0?ooo`80003o00@0oooo0000o`000?l0003o?P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0303oool3000001T0oooo00<0003o0?ooo`000?l0@@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool0203oool3000001`0oooo00@0003o0?ooo`3oool0003o@03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0103oool3000002<0oooo00<0003o0?ooo`3oool0?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool00`00000V0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000
:P3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo02<0oooo0P000?m20?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02<0oooo00<0003o0?ooo`000?l0?P3oool300000080oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02<0oooo00@0003o0?ooo`3oool0003o>@3oool4000000H0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02<0oooo00@0003o0?ooo`3oool0003o=P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
0280oooo0P000?l30?ooo`030000o`3oool0oooo0300oooo0`00000>0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l0;`3oool300000180oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02<0oooo00D0003o0?ooo`3oool0oooo0000o`0/0?ooo`<000005P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo02H0
oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S0?ooo`050000o`3oool0003o0?ooo`00
0?l09@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo0P000?l20?ooo`80003o
8P3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0240oooo00H0003o0?ooo`3oool0003o
0?ooo`000?lP0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140
oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0Q0?ooo`070000o`3oool0oooo0?ooo`00
0?l0oooo0000o`0L0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08P3oool010000?l0
oooo0?ooo`000?lJ0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool01@000?l0
oooo0?ooo`3oool0003o01H0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`05
0000o`3oool0oooo0?ooo`000?l00`3oool20000oa80oooo0`00000f0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0P0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`000?l03P3oool30000
03X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000o`020?oo
o`030000o`3oool0003o00/0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Q0?ooo`07
0000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00@0oooo10000012
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo0?ooo`80003o1P3oool3
000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0280oooo0P000?l70?ooo`<00000BP3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0000o`040?ooo`<00000CP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0Q0?ooo`040000o`3oool0oooo0000o`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000
00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo
000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07@3oool01@000?l000000000
00000000003o00<0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01/0oooo0`0000001@000?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0
D`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000
203oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01D0oooo0`00000;0?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0A`3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0A0?ooo`@000002`3oool01@000?l0oooo0?ooo`3oool0003o05X0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool300000100oooo00@0003o
0?ooo`3oool0003oF`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H
0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000D
0?ooo`040000o`3oool0oooo0000oeX0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000G
0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000K0?oo
o`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000703oool20000
o`80oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00h0oooo000P0?ooo`800000T@3oool4000001h0oooo00@0003o0?ooo`3oool0003o0P3oool00`00
0?l0oooo0?ooo`1L0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo0P00002@0?ooo`<000008@3oool010000?l0oooo0?ooo`000?mQ0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080
oooo00<000000?ooo`3oool07`3oool010000?l0oooo0?ooo`000?mR0?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0
oooo00<000000?ooo`3oool07`3oool01@000?l0oooo0?ooo`3oool0003o0680oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<0
00002@3oool00`000000oooo0?ooo`0O0?ooo`050000o`3oool0oooo0?ooo`000?l0H`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880
oooo0`00000<0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000o`1S0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0O`3oool3000000l0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`1R0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O03oool300000140oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0680oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`0O0?ooo`80003o0P3o
ool30000ofD0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0
003o06X0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0003o
06/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0003o06`0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo
0`00000Q0?ooo`030000003oool0oooo01l0oooo00D0003o0?ooo`000?l0oooo0000o`1Z0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0
J@3oool4000002@0oooo00<000000?ooo`3oool06`3oool01`000?l0oooo0?ooo`3oool0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0703oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool00P3oool01000
0?l0oooo0?ooo`000?m/0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool07@3oool01@00
0?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0J`3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo01h0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o06d0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J
0?ooo`@00000=03oool00`000000oooo0?ooo`0O0?ooo`050000o`3oool0oooo0?ooo`000?l0K`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05L0oooo0`00000h0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0LP3oool0
0`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo
05@0oooo0`00000k0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0LP3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580
oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo
0?ooo`0R0?ooo`030000o`3oool0oooo0740oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?oo
o`0R0?ooo`80003oL`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?oo
o`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool30000
05/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?oo
o`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool30000
07X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?oo
o`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H
0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?oo
o`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`80
0000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03o
ool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3o
ool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2
000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?oo
o`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0
_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3o
ool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo
0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`00
0000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo
0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000
J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2
000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2
000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo
0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo
0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?oo
o`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`01
0?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000
D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?oo
o`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo
0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?oo
o`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@0
00004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D00000
5P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3o
ool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`00
0000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0
oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V
0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?oo
o`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@0
0000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`80
0000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00
J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3o
ool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0
Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3o
ool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool0
08@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool0
08D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0
oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@00000
0?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O
0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0
DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3o
ool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool0
09D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0
oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo
0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo
0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00
000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000
002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>
0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?oo
o`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?oo
o`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`03
0000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<0
00004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<00000
00<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3o
ool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool0
0:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000
oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?oo
o`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000
g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56633 .50528 m
.56849 .4993 L
s
.55296 .4696 m
.56849 .4993 L
s
.56467 .50645 m
.56633 .50528 L
s
.55296 .4696 m
.55073 .47549 L
s
.56256 .50534 m
.56467 .50645 L
s
.56076 .50337 m
.56256 .50534 L
s
.55821 .49997 m
.56076 .50337 L
s
.55073 .47549 m
.55051 .47945 L
s
.55447 .49286 m
.55821 .49997 L
s
.55051 .47945 m
.55137 .48401 L
s
.55254 .48772 m
.55447 .49286 L
s
.55137 .48401 m
.55254 .48772 L
s
.55147 .49745 m
.56197 .5174 L
s
.55598 .50602 m
.55341 .50261 L
s
.55341 .50261 m
.55126 .50148 L
s
.55126 .50148 m
.54986 .50179 L
s
.54986 .50179 m
.54888 .5044 L
s
.55526 .52545 m
.55613 .53008 L
s
.55331 .52027 m
.55526 .52545 L
s
.5518 .5174 m
.55331 .52027 L
s
.55613 .53008 m
.55624 .5333 L
s
.5492 .51398 m
.5518 .5174 L
s
.55624 .5333 m
.55527 .53598 L
s
.54702 .51287 m
.5492 .51398 L
s
.55527 .53598 m
.55387 .53634 L
s
.5456 .51319 m
.54702 .51287 L
s
.55387 .53634 m
.55169 .53527 L
s
.54461 .51585 m
.5456 .51319 L
s
.54328 .51941 m
.55398 .53958 L
s
.54471 .51907 m
.54461 .51585 L
s
.54558 .52375 m
.54471 .51907 L
s
.53823 .53293 m
.55038 .54957 L
s
.54093 .52569 m
.55038 .54957 L
s
.5355 .54025 m
.54773 .55692 L
s
.53823 .53293 m
.54773 .55692 L
s
.54014 .55988 m
.54136 .56373 L
s
.53813 .55457 m
.54014 .55988 L
s
.54136 .56373 m
.54224 .56852 L
s
.53421 .54726 m
.53813 .55457 L
s
.54224 .56852 m
.54234 .57186 L
s
.54234 .57186 m
.54098 .57565 L
s
.53151 .54378 m
.53421 .54726 L
s
.52958 .54177 m
.53151 .54378 L
s
.54098 .57565 m
.53951 .57609 L
s
.5273 .54068 m
.52958 .54177 L
s
.53951 .57609 m
.53724 .57506 L
s
.5258 .54106 m
.5273 .54068 L
s
.53469 .56394 m
.53295 .56868 L
s
.53724 .57506 m
.53532 .57308 L
s
.52439 .54479 m
.5258 .54106 L
s
.53532 .57308 m
.53295 .56868 L
s
.52447 .54814 m
.52439 .54479 L
s
.52606 .56553 m
.53719 .58616 L
s
.52535 .55298 m
.52447 .54814 L
s
.52659 .55688 m
.52535 .55298 L
s
.53084 .5744 m
.5281 .57093 L
s
.5281 .57093 m
.52579 .56988 L
s
.52579 .56988 m
.52427 .57032 L
s
.52427 .57032 m
.52319 .5732 L
s
.52989 .59533 m
.53078 .60025 L
s
.52783 .58992 m
.52989 .59533 L
s
.52622 .58695 m
.52783 .58992 L
s
.53078 .60025 m
.53087 .6037 L
s
.52345 .58347 m
.52622 .58695 L
s
.53087 .6037 m
.5298 .60667 L
s
.52111 .58244 m
.52345 .58347 L
s
.5298 .60667 m
.52828 .60717 L
s
.51957 .5829 m
.52111 .58244 L
s
.52828 .60717 m
.52595 .60618 L
s
.51847 .58584 m
.51957 .5829 L
s
.51701 .58977 m
.52837 .61064 L
s
.51856 .5893 m
.51847 .58584 L
s
.51442 .59671 m
.53153 .62803 L
s
.51945 .59426 m
.51856 .5893 L
s
.52431 .61816 m
.52341 .61317 L
s
.5244 .62167 m
.52431 .61816 L
s
.5233 .62471 m
.5244 .62167 L
s
.51688 .60121 m
.51449 .60021 L
s
.52175 .62525 m
.5233 .62471 L
s
.51449 .60021 m
.51293 .6007 L
s
.51937 .62429 m
.52175 .62525 L
s
.51293 .6007 m
.5118 .60371 L
s
.51653 .6208 m
.51937 .62429 L
s
.5118 .60371 m
.51188 .60723 L
s
.51488 .6178 m
.51653 .6208 L
s
.51188 .60723 m
.51278 .61227 L
s
.51278 .61227 m
.51488 .6178 L
s
.50102 .60626 m
.51851 .63802 L
s
.51021 .62295 m
.50657 .62149 L
s
.50657 .62149 m
.50496 .62203 L
s
.50601 .63433 m
.51438 .64947 L
s
.50496 .62203 m
.50381 .62513 L
s
.50381 .62513 m
.50387 .62872 L
s
.50387 .62872 m
.50601 .63433 L
s
.49952 .6366 m
.51134 .65791 L
s
.49272 .62433 m
.49397 .62482 L
s
.49397 .62482 m
.49442 .6274 L
s
.50573 .66188 m
.50664 .66707 L
s
.50357 .65623 m
.50573 .66188 L
s
.49442 .6274 m
.49317 .62691 L
s
.50187 .65318 m
.50357 .65623 L
s
.50664 .66707 m
.50672 .67075 L
s
.49317 .62691 m
.49272 .62433 L
s
.49893 .64965 m
.50187 .65318 L
s
.50672 .67075 m
.50555 .67399 L
s
.49643 .64872 m
.49893 .64965 L
s
.50555 .67399 m
.50391 .67463 L
s
.49478 .64932 m
.49643 .64872 L
s
.50391 .67463 m
.50142 .67375 L
s
.49358 .65253 m
.49478 .64932 L
s
.49363 .65622 m
.49358 .65253 L
s
.49455 .66146 m
.49363 .65622 L
s
.50036 .68447 m
.49904 .6803 L
s
.50003 .68931 m
.50036 .68447 L
s
.49883 .69263 m
.50003 .68931 L
s
.49214 .66798 m
.49346 .67216 L
s
.49 .66598 m
.49214 .66798 L
s
.49346 .67216 m
.49352 .67589 L
s
.49352 .67589 m
.49236 .68295 L
s
.49676 .69443 m
.49883 .69263 L
s
.48791 .66771 m
.49 .66598 L
s
.49462 .69246 m
.49676 .69443 L
s
.48668 .671 m
.48791 .66771 L
s
.49236 .68295 m
.49242 .68671 L
s
.49375 .69091 m
.49462 .69246 L
s
.49242 .68671 m
.49375 .69091 L
s
.48632 .67586 m
.48668 .671 L
s
.48766 .68008 m
.48632 .67586 L
s
.49352 .70339 m
.49399 .70606 L
s
.49224 .70297 m
.49352 .70339 L
s
.49399 .70606 m
.49271 .70565 L
s
.49271 .70565 m
.49224 .70297 L
s
.47552 .67336 m
.48787 .69522 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1H0?ooo`030000o`3o
ool0oooo03@0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`000?l0=@3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`000?l0=@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo05@0oooo00@0003o0?ooo`3oool0003o=03oool00`00
0000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo05<0oooo00@0003o0?ooo`3oool0003o=03oool00`00
0000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo0580oooo00D0003o0?ooo`3oool0oooo0000o`0c0?oo
o`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0D@3oool01@000?l0oooo0?ooo`3oool0003o
03<0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?oo
o`030000003oool0oooo06@0oooo00<000000?ooo`3oool0D@3oool01@000?l0oooo0?ooo`3oool0
003o0380oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0D03oool01@000?l0oooo0?ooo`3oool0003o0300oooo0`00001H
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0D03oool01@000?l0oooo0?ooo`3oool0003o02`0oooo0`0000020?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`00
0000oooo0?ooo`1?0?ooo`050000o`3oool0oooo0?ooo`000?l0:@3oool3000000D0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?oo
o`3oool0CP3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo02<0oooo0`0000080?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`1<0?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0
oooo0?ooo`0P0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04/0oooo
0`000?l0103oool0003o0?ooo`000?lP0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0J`3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo0080003o7@3oool300000140
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`0K0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0
oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000
oooo0?ooo`160?ooo`80003o0`3oool00`000?l0oooo0?ooo`0H0?ooo`<00000603oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0003o00<0
oooo00<0003o0?ooo`3oool0503oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`140?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool04@3oool3000001h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo0480oooo0P000?l20?ooo`030000o`3oool0oooo0100oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`120?ooo`040000o`3oool0oooo0000o`l0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`100?ooo`80003o0`3oool00`000?l0oooo0?oo
o`090?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X
0?ooo`800000MP3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0003o0080oooo00<0003o
0?ooo`3oool01P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0o0?oo
o`80003o0P3oool00`000?l0oooo0?ooo`030?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`0l0?ooo`070000o`3oool0003o0?ooo`000?l0oooo0000o`02
0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?oo
o`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0k0?oo
o`<0003o00@0oooo0000o`000?l0003o0P00000d0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?oo
o`3oool0>`3oool01@000?l0oooo0000o`000000003o03L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
03@0oooo0P000?l20?ooo`030000o`000000003o0080003o>@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool0<P3oool010000?l0oooo0?ooo`000?l200000080003o00<0oooo0000o`3oool0>03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0<@3oool020000?l000000000003oool0003o0?ooo`000?l0oooo0`00
0?lh0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<0000000<0003o0?ooo`3oool00P3oool0
1P000?l0oooo0000o`000?l0oooo0000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00
00040?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0h0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo02D0oooo0`0000070?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`000?l0003o
>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000X0oooo00<0003o0?ooo`3oool00P3o
ool010000?l0oooo0?ooo`000?li0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000004P3o
ool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000503oool0
10000?l0oooo0?ooo`000?ll0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000503oool0
10000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo0100oooo0`00000G0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0>P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0303oool3000001T0oooo0`000?l01@3oool0003o0?ooo`3o
ool0003o03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000L0?ooo`030000o`3oool0
003o0080003o0P3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<000008P3oool00`000?l0oooo0000o`020000oc`0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
00009@3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000002@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`0l0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0280oooo00@0003o0?ooo`3oool0003o0`3o
ool00`000?l0oooo0?ooo`0h0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08P3oool0
1@000?l0oooo0?ooo`3oool0003o03T0oooo100000060?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R
0?ooo`050000o`3oool0oooo0?ooo`000?l0=P3oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02<0oooo00@0003o0?ooo`3oool0003o<`3oool3000000h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0^0?ooo`<000004P3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0803oool30000o`050?ooo`000?l0oooo0?ooo`000?l0;03oool3
000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`000?l0oooo0000o`02
0?ooo`030000o`3oool0oooo02H0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0L0?oo
o`050000o`3oool0oooo0?ooo`000?l00P3oool010000?l0oooo0000o`000?lV0?ooo`<000007P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0703oool01@000?l0oooo0?ooo`3oool0003o0080oooo00@0
003o0?ooo`000?l0003o8`3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01d0oooo00@0
003o0?ooo`3oool0003o0`3oool00`000?l0oooo0000o`0P0?ooo`<000009P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?oo
o`0M0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool07@3oool3000002X0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo01h0oooo00@0003o0?ooo`3oool0003o0P3oool20000oaX0oooo
1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`040000o`3oool0oooo0000o`80oooo
0P000?lG0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07P3oool30000o`070?ooo`00
0?l0oooo0?ooo`000?l0oooo0000o`0C0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
6P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool30000o`030?ooo`000?l0oooo
00l0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0J0?ooo`050000o`3oool0oooo0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00X0oooo0`00000n0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0N0?ooo`040000o`3oool0oooo0000o`l0oooo100000120?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0N0?ooo`050000o`3oool0oooo0?ooo`000?l02`3oool30000
04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo01l0oooo00@0003o0?ooo`3oool0003o203oool30000
04X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo01`0oooo00D0003o0?ooo`3oool0oooo0000o`020?oo
o`030000o`3oool0oooo0080oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo01d0oooo00@0003o0?ooo`3o
ool0003o103oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?oo
o`008@3oool200000900oooo00<000000?ooo`3oool07@3oool010000?l0oooo0?ooo`3oool40000
05H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`0000000`000?l0oooo0?ooo`1H0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool06P3oool01P000?l00000000000000000oooo0000
o`80oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0H0?ooo`<0000000<0oooo0000o`3oool00P3oool00`000?l0oooo0?ooo`1J0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`0000020?ooo`04
0000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0140oooo100000050?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`1K0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0
oooo0`0000090?ooo`050000o`3oool0oooo0?ooo`000?l0H@3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00000<0?ooo`050000o`3oool0oooo0?ooo`000?l0H@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0203oool3000000h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`1P0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000403oool20000o`D0oooo
00<0003o0?ooo`3oool0H03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000C0?ooo`030000
o`3oool0003o00D0oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo00h0oooo000P0?ooo`800000T@3oool400000180oooo00D0003o0?ooo`3oool0oooo
0000o`020?ooo`030000o`3oool0oooo0080003oI@3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000001H0oooo00@0003o0?ooo`3oool0003o
0P3oool01@000?l0oooo0?ooo`3oool0003o06D0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo
0?ooo`0D0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0J03oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo
100000050?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool00P000?l20?ooo`030000
o`3oool0oooo06L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0E0?ooo`050000o`3o
ool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<0
00000?ooo`3oool05P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo06T0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0003o0080oooo00<0
003o0?ooo`3oool0JP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo01P0oooo00H0003o
0?ooo`3oool0003o0?ooo`000?m/0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool06@3o
ool010000?l0oooo0?ooo`000?m^0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`00
0000oooo0?ooo`0J0?ooo`80003oLP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool06`3oool00`000?l0
oooo0?ooo`1`0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo
00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00
000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3o
ool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440
oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`00
00180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3o
ool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<00000
0?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`03
0000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3o
ool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`00
0000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@0
0000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0007
0?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
00000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?oo
o`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3o
ool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?oo
o`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00
<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0
_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000
003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3o
ool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0
oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000
003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2
000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool2
00000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000
oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo
0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo
00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<00000
0?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?oo
o`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000
DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo
0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo
001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool20000
0080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo
100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=
0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3o
ool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool0
0`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo
0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0
oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo
1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g
0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?oo
o`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`04
0000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?oo
o`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?oo
o`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3o
ool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?oo
o`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00
P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3o
ool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0
oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0
000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`00
0000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo
00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?oo
o`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K
0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?oo
o`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00
TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3o
ool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`00
0000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000
oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo
0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?oo
o`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?oo
o`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?oo
o`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?oo
o`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo
0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3o
ool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool0
0`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?oo
o`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.58016 .53751 m
.58326 .53357 L
s
.56957 .50113 m
.58326 .53357 L
s
.56957 .50113 m
.5664 .50493 L
s
.57817 .53766 m
.58016 .53751 L
s
.57596 .53569 m
.57817 .53766 L
s
.5664 .50493 m
.56569 .50813 L
s
.5742 .53315 m
.57596 .53569 L
s
.57177 .52905 m
.5742 .53315 L
s
.56569 .50813 m
.56609 .51235 L
s
.56848 .52126 m
.57177 .52905 L
s
.56609 .51235 m
.56695 .51603 L
s
.56695 .51603 m
.56848 .52126 L
s
.56461 .52363 m
.57388 .54551 L
s
.56858 .53302 m
.56614 .52889 L
s
.56614 .52889 m
.56389 .52689 L
s
.56389 .52689 m
.56229 .52645 L
s
.56229 .52645 m
.5609 .52816 L
s
.56392 .54363 m
.56546 .54894 L
s
.56258 .54048 m
.56392 .54363 L
s
.56546 .54894 m
.56587 .55326 L
s
.56011 .53633 m
.56258 .54048 L
s
.56587 .55326 m
.56561 .55602 L
s
.55782 .53432 m
.56011 .53633 L
s
.56561 .55602 m
.56422 .55779 L
s
.55621 .53389 m
.55782 .53432 L
s
.56422 .55779 m
.56261 .5574 L
s
.55479 .53563 m
.55621 .53389 L
s
.56261 .5574 m
.56032 .55542 L
s
.55451 .53838 m
.55479 .53563 L
s
.55289 .53795 m
.56235 .56018 L
s
.55492 .54272 m
.55451 .53838 L
s
.54953 .54205 m
.55714 .56679 L
s
.54565 .54679 m
.55714 .56679 L
s
.54565 .54679 m
.55331 .57167 L
s
.54174 .55158 m
.55331 .57167 L
s
.54293 .56492 m
.54451 .57039 L
s
.53946 .55683 m
.54293 .56492 L
s
.54451 .57039 m
.5454 .57424 L
s
.5454 .57424 m
.5458 .57872 L
s
.53688 .55257 m
.53946 .55683 L
s
.5458 .57872 m
.54551 .58159 L
s
.53499 .54992 m
.53688 .55257 L
s
.54551 .58159 m
.54353 .58411 L
s
.53259 .54788 m
.53499 .54992 L
s
.53088 .54746 m
.53259 .54788 L
s
.54353 .58411 m
.54184 .58374 L
s
.52886 .54989 m
.53088 .54746 L
s
.53796 .5711 m
.53544 .57422 L
s
.54184 .58374 m
.53945 .58175 L
s
.53945 .58175 m
.53755 .57912 L
s
.52854 .55274 m
.52886 .54989 L
s
.53755 .57912 m
.53544 .57422 L
s
.52893 .55724 m
.52854 .55274 L
s
.52983 .56114 m
.52893 .55724 L
s
.52817 .56815 m
.53804 .5911 L
s
.53241 .578 m
.52978 .57371 L
s
.52978 .57371 m
.52734 .57168 L
s
.52734 .57168 m
.5256 .57129 L
s
.5256 .57129 m
.52405 .57319 L
s
.52716 .5896 m
.52878 .59521 L
s
.52573 .5863 m
.52716 .5896 L
s
.52878 .59521 m
.52917 .59982 L
s
.52307 .58198 m
.52573 .5863 L
s
.52917 .59982 m
.52885 .60279 L
s
.5206 .57994 m
.52307 .58198 L
s
.52885 .60279 m
.5273 .60476 L
s
.51883 .57956 m
.5206 .57994 L
s
.5273 .60476 m
.52554 .60443 L
s
.51725 .5815 m
.51883 .57956 L
s
.52554 .60443 m
.52306 .60243 L
s
.51692 .58446 m
.51725 .5815 L
s
.51514 .58409 m
.52521 .60741 L
s
.5173 .58909 m
.51692 .58446 L
s
.5114 .58865 m
.52659 .62376 L
s
.51976 .61176 m
.51937 .60708 L
s
.51942 .61478 m
.51976 .61176 L
s
.51358 .59368 m
.51105 .59165 L
s
.51783 .61681 m
.51942 .61478 L
s
.51105 .59165 m
.50925 .59128 L
s
.51603 .61649 m
.51783 .61681 L
s
.50925 .59128 m
.50762 .59327 L
s
.5135 .61449 m
.51603 .61649 L
s
.50762 .59327 m
.50727 .59628 L
s
.51076 .61011 m
.5135 .61449 L
s
.50727 .59628 m
.50765 .601 L
s
.5093 .60673 m
.51076 .61011 L
s
.50765 .601 m
.5093 .60673 L
s
.49532 .59004 m
.51083 .62572 L
s
.50346 .60876 m
.49958 .6057 L
s
.49958 .6057 m
.49773 .60536 L
s
.49773 .60536 m
.49606 .6074 L
s
.49736 .61631 m
.5048 .63339 L
s
.49606 .6074 m
.49568 .61049 L
s
.49568 .61049 m
.49736 .61631 L
s
.48985 .61499 m
.50035 .63905 L
s
.48382 .60118 m
.48515 .60222 L
s
.48515 .60222 m
.48533 .60464 L
s
.48533 .60464 m
.484 .6036 L
s
.484 .6036 m
.48382 .60118 L
s
.49189 .63371 m
.49358 .63961 L
s
.49038 .63026 m
.49189 .63371 L
s
.49358 .63961 m
.49395 .6445 L
s
.48754 .62578 m
.49038 .63026 L
s
.49395 .6445 m
.49357 .64767 L
s
.48487 .62373 m
.48754 .62578 L
s
.49357 .64767 m
.49186 .64985 L
s
.48296 .62341 m
.48487 .62373 L
s
.49186 .64985 m
.48995 .64957 L
s
.48121 .62554 m
.48296 .62341 L
s
.48995 .64957 m
.48728 .64756 L
s
.48081 .62871 m
.48121 .62554 L
s
.48117 .63363 m
.48081 .62871 L
s
.48474 .65618 m
.48379 .65195 L
s
.48376 .66016 m
.48474 .65618 L
s
.47765 .63797 m
.4786 .6422 L
s
.47553 .63519 m
.47765 .63797 L
s
.4786 .6422 m
.47819 .64541 L
s
.482 .66239 m
.48376 .66016 L
s
.47298 .63561 m
.47553 .63519 L
s
.47819 .64541 m
.47601 .65085 L
s
.47946 .66289 m
.482 .66239 L
s
.47119 .6378 m
.47298 .63561 L
s
.47601 .65085 m
.47559 .65409 L
s
.47732 .66012 m
.47946 .66289 L
s
.47016 .64176 m
.47119 .6378 L
s
.47559 .65409 m
.47655 .65836 L
s
.47655 .65836 m
.47732 .66012 L
s
.47112 .64602 m
.47016 .64176 L
s
.4747 .66892 m
.47488 .67145 L
s
.47332 .66791 m
.4747 .66892 L
s
.47488 .67145 m
.4735 .67044 L
s
.4735 .67044 m
.47332 .66791 L
s
.45846 .63419 m
.46942 .65906 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0P0?ooo`<000002`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0540oooo0P000?lO0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0003o01/0oooo0`00000A0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo04l0oooo00<0003o0?oo
o`000?l0603oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?oo
o`3oool0CP3oool010000?l0oooo0?ooo`000?lD0?ooo`<00000603oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`1=0?ooo`040000o`3oool0oooo0000oa40oooo0`00
000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P000006
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0C03oool010000?l0oooo0?ooo`00
0?l>0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0C03oool010000?l0oooo0?ooo`00
0?l90?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0000o`02
0?ooo`030000o`3oool0oooo00@0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`180?oo
o`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool00`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04H0oooo0`000?l01@3oool0003o0?ooo`3oool0003o00800000:`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo04L0oooo00<0003o0?ooo`000?l00P0000000`3oool0003o0?ooo`0[0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`00
0000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0480oooo0P000?l01P3oool0
0000000000000?l0oooo0000o`80oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`110?ooo`030000o`000000003o0080oooo00<0003o0?oo
o`3oool00P000?l]0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool200000080
003o00<0oooo0000o`3oool00P3oool010000?l0oooo0000o`000?l]0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0i0?ooo`<0000000@0oooo0000o`000?l0003o0P3oool010000?l0oooo0?ooo`000?l`
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000103oool00`000?l0oooo0000o`020?oo
o`050000o`3oool0oooo0?ooo`000?l0;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool30000
00030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P000?l20?ooo`050000o`3oool0oooo
0?ooo`000?l0;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool300000080oooo00<0003o0?oo
o`000?l00`3oool20000o`040?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool0<03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool0:@3oool3000000D0oooo00`0003o0?ooo`3oool0003o0?ooo`00
0?l0oooo0000o`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo0300oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3o
ool09@3oool3000000P0oooo00@0003o0?ooo`3oool0003o0P3oool30000o`060?ooo`000?l0oooo
0000o`3oool0003o<P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000/0oooo00H0003o
0?ooo`3oool0oooo0000o`3oool20000o`040?ooo`000?l0003o0?ooo`80003o<`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool4000000h0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80
003o00D0oooo0000o`3oool0oooo0000o`0d0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<0
00005`3oool01@000?l0oooo0000o`000?l0oooo0080003o=P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0503oool3000001X0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0d0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000603oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080003o>03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001X0oooo
0P000?l20?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0=P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0203oool3000001`0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l20?oo
o`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000Q0?ooo`80
003o00D0oooo0000o`3oool0oooo0000o`0k0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000200
oooo0P000?l30?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0>@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo
0P00000S0?ooo`030000o`3oool0003o00<0oooo00D0003o0?ooo`000?l0oooo0000o`0k0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000
003oool0oooo0240oooo0P000?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo0080003o
>P3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0Q0?ooo`80003o0P3oool010000?l0oooo0?ooo`000?lk0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0003o0080oooo00D0003o0?ooo`3oool0oooo0000o`0f0?ooo`@000001P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool06P3oool010000?l0oooo0?ooo`3oool30000o`050?ooo`000?l0oooo0?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`0a0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
6`3oool01@000?l0oooo0?ooo`000?l0oooo0080003o00D0oooo0000o`3oool0oooo0000o`0c0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool06`3oool010000?l0oooo0?ooo`000?l20?oo
o`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0;P3oool300000180oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo01D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000o`030?ooo`05
0000o`3oool0003o0?ooo`000?l0;@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01D0
oooo0P000?l50?ooo`030000o`3oool0003o00<0oooo00D0003o0?ooo`000?l0oooo0000o`0Y0?oo
o`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool05P3oool010000?l0oooo0?ooo`3oool30000
o`80oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0U0?ooo`<000007P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool06P3oool01P000?l0oooo0000o`000?l0oooo0000o`<0oooo00<0
003o0?ooo`000?l0903oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01X0oooo00H0003o
0?ooo`3oool0003o0?ooo`000?l30?ooo`030000o`3oool0oooo0240oooo0`00000V0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003o
ool0oooo01P0oooo00<0003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l20?ooo`030000
o`3oool0oooo01h0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0H0?ooo`030000o`3o
ool0003o00<0oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o0?ooo`0J0?ooo`@00000;P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool06P3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0F0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06P3oool00`00
0?l0oooo0000o`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool04P3oool30000
03H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo01D0oooo10000?l0103oool0003o0?ooo`000?l30?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03`3oool3000003X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo01D0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`0G0?oo
o`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool05@3oool02@000?l0oooo0?ooo`3oool0003o
0?ooo`000?l0oooo0000o`0C0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool05@3oool0
1`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0=0?ooo`<00000
A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`020?ooo`80003o1@3o
ool010000?l0oooo0?ooo`000?l>0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`000?l02`3o
ool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3
000008h0oooo00<000000?ooo`3oool03P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0203oool300000580oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool03P3oool0
10000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103o
ool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00l0oooo00H0003o0?ooo`3oool0003o0?oo
o`000?l50?ooo`040000o`3oool0oooo0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00l0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`<0003o0`00001N0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool0
00001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0100oooo00@0003o0?ooo`3o
ool0003o0P3oool00`000?l0oooo0000000200000680oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0403oool01@000?l0oooo0?ooo`000?l0oooo00<00000IP3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo100000020?ooo`030000o`3oool0oooo06D0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000000060000
o`3oool0oooo0000o`3oool0003oJ@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0
oooo0`0000070?ooo`80003oJ@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00@0oooo1000000:0?ooo`030000o`3oool0oooo06d0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`040000003oool0oooo0?ooo`<000003P3oool20000ofl0oooo00<000000?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000B0?ooo`030000o`3oool0
oooo06h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool20000
0900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo
100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool30000
01h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo
1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool0
0`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool30000
03h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?oo
o`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003o
ool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool30000
05h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?oo
o`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
7@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003o
ool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool30000
07d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<0
00000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?oo
o`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3o
ool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P000009
0?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?oo
o`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P00
00240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?oo
o`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool0
0000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2
000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003o
ool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2
000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000
oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo
00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`03
0000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00
@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0
oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?oo
o`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo
0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0
oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00
000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G
0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`01
0?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3o
ool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0
eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo
0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`00
0000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2
000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0
oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P00
00020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y
0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?oo
o`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3o
ool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5
000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00
000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d
0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?oo
o`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`04
0000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?oo
o`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`80
0000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003o
ool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003o
ool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0
oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool40000
06X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0
oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo
1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo
1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`80
0000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`000000
6@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003o
ool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool40000
09X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool50000
09h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0
oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo
001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W
0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<00000
0?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?oo
o`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`04
0000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?oo
o`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0
103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003o
ool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool4
00000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?oo
o`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?oo
o`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?oo
o`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59174 .57144 m
.59566 .56966 L
s
.58425 .53563 m
.59566 .56966 L
s
.58425 .53563 m
.58027 .53725 L
s
.5895 .57058 m
.59174 .57144 L
s
.58027 .53725 m
.5791 .53958 L
s
.58727 .56783 m
.5895 .57058 L
s
.5791 .53958 m
.57905 .54332 L
s
.58561 .56481 m
.58727 .56783 L
s
.57905 .54332 m
.57958 .54683 L
s
.58339 .56016 m
.58561 .56481 L
s
.57958 .54683 m
.58065 .55197 L
s
.58065 .55197 m
.58339 .56016 L
s
.57607 .55204 m
.58379 .57506 L
s
.57938 .56191 m
.57714 .55722 L
s
.57714 .55722 m
.57488 .55443 L
s
.57488 .55443 m
.57316 .55327 L
s
.57316 .55327 m
.57141 .55401 L
s
.57292 .56853 m
.57401 .57376 L
s
.57181 .56521 m
.57292 .56853 L
s
.56955 .56048 m
.57181 .56521 L
s
.57401 .57376 m
.57395 .57761 L
s
.56725 .55766 m
.56955 .56048 L
s
.57395 .57761 m
.57333 .57981 L
s
.56551 .5565 m
.56725 .55766 L
s
.57333 .57981 m
.57156 .58061 L
s
.56372 .55726 m
.56551 .5565 L
s
.57156 .58061 m
.56982 .57948 L
s
.56309 .55943 m
.56372 .55726 L
s
.56982 .57948 m
.56751 .57667 L
s
.56301 .56329 m
.56309 .55943 L
s
.56133 .55827 m
.56919 .58169 L
s
.55711 .56005 m
.5626 .58469 L
s
.55223 .56211 m
.5626 .58469 L
s
.55223 .56211 m
.55775 .58689 L
s
.54729 .56419 m
.55775 .58689 L
s
.547 .57602 m
.5481 .58143 L
s
.54413 .56748 m
.547 .57602 L
s
.54178 .56261 m
.54413 .56748 L
s
.5481 .58143 m
.54863 .58512 L
s
.54 .55945 m
.54178 .56261 L
s
.54863 .58512 m
.54853 .58911 L
s
.53759 .55654 m
.54 .55945 L
s
.54853 .58911 m
.54786 .59139 L
s
.53574 .55534 m
.53759 .55654 L
s
.54786 .59139 m
.54535 .59253 L
s
.5332 .55638 m
.53574 .55534 L
s
.54535 .59253 m
.54351 .59138 L
s
.54072 .57876 m
.53755 .58015 L
s
.5325 .55862 m
.5332 .55638 L
s
.54351 .59138 m
.54109 .5885 L
s
.53238 .5626 m
.5325 .55862 L
s
.54109 .5885 m
.53929 .58533 L
s
.5329 .56632 m
.53238 .5626 L
s
.53929 .58533 m
.53755 .58015 L
s
.53021 .57141 m
.53838 .5957 L
s
.53371 .58182 m
.53131 .57689 L
s
.53131 .57689 m
.52885 .57397 L
s
.52885 .57397 m
.52697 .57278 L
s
.52697 .57278 m
.52501 .5736 L
s
.52645 .58901 m
.52756 .59455 L
s
.52527 .5855 m
.52645 .58901 L
s
.52284 .58053 m
.52527 .5855 L
s
.52756 .59455 m
.52743 .59865 L
s
.52034 .57758 m
.52284 .58053 L
s
.52743 .59865 m
.52671 .601 L
s
.51843 .57638 m
.52034 .57758 L
s
.52671 .601 m
.52474 .6019 L
s
.51643 .57722 m
.51843 .57638 L
s
.52474 .6019 m
.52282 .60074 L
s
.51569 .57955 m
.51643 .57722 L
s
.52282 .60074 m
.52031 .5978 L
s
.51555 .58366 m
.51569 .57955 L
s
.51376 .57835 m
.52209 .6031 L
s
.50904 .58035 m
.52161 .61766 L
s
.51548 .60406 m
.51563 .5999 L
s
.51084 .58568 m
.50828 .5827 L
s
.51473 .60645 m
.51548 .60406 L
s
.50828 .5827 m
.50632 .58149 L
s
.5127 .60737 m
.51473 .60645 L
s
.50632 .58149 m
.50427 .58236 L
s
.51074 .6062 m
.5127 .60737 L
s
.50427 .58236 m
.50351 .58473 L
s
.50817 .60323 m
.51074 .6062 L
s
.50351 .58473 m
.50334 .5889 L
s
.50567 .59816 m
.50817 .60323 L
s
.50334 .5889 m
.50446 .59457 L
s
.50446 .59457 m
.50567 .59816 L
s
.49102 .57352 m
.5038 .61142 L
s
.49772 .59338 m
.49379 .58885 L
s
.49379 .58885 m
.49178 .58764 L
s
.49178 .58764 m
.48966 .58853 L
s
.48966 .58853 m
.48886 .59095 L
s
.48886 .59095 m
.48999 .59671 L
s
.48999 .59671 m
.49612 .61491 L
s
.47687 .57719 m
.47821 .57872 L
s
.47821 .57872 m
.4781 .58085 L
s
.48181 .59184 m
.49046 .61748 L
s
.4781 .58085 m
.47676 .57931 L
s
.47676 .57931 m
.47687 .57719 L
s
.48172 .60872 m
.48286 .61456 L
s
.48047 .60503 m
.48172 .60872 L
s
.47788 .59982 m
.48047 .60503 L
s
.48286 .61456 m
.48265 .6189 L
s
.47518 .59675 m
.47788 .59982 L
s
.48265 .6189 m
.48182 .62141 L
s
.47309 .59553 m
.47518 .59675 L
s
.48182 .62141 m
.47964 .6224 L
s
.47089 .59646 m
.47309 .59553 L
s
.47964 .6224 m
.47755 .62121 L
s
.47004 .59894 m
.47089 .59646 L
s
.47755 .62121 m
.47483 .61815 L
s
.46981 .60328 m
.47004 .59894 L
s
.47091 .62421 m
.4704 .62014 L
s
.46535 .6052 m
.46587 .60926 L
s
.46334 .60178 m
.46535 .6052 L
s
.46931 .62709 m
.47091 .62421 L
s
.46587 .60926 m
.465 .61178 L
s
.46046 .60086 m
.46334 .60178 L
s
.465 .61178 m
.46188 .6153 L
s
.46707 .62811 m
.46931 .62709 L
s
.45819 .60182 m
.46046 .60086 L
s
.46418 .62726 m
.46707 .62811 L
s
.45655 .60466 m
.45819 .60182 L
s
.46188 .6153 m
.461 .61785 L
s
.46215 .62383 m
.46418 .62726 L
s
.461 .61785 m
.46151 .62195 L
s
.45706 .60876 m
.45655 .60466 L
s
.46151 .62195 m
.46215 .62383 L
s
.45811 .63 m
.45798 .63224 L
s
.4567 .62845 m
.45811 .63 L
s
.45798 .63224 m
.45658 .63069 L
s
.45658 .63069 m
.4567 .62845 L
s
.44453 .59241 m
.4535 .61897 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000000H0oooo0`00
0?l[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000000T0oooo00<0003o
0?ooo`000?l0:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool3000000`0oooo00@0003o0?oo
o`3oool0003o:P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000000l0oooo00@0003o0?oo
o`3oool0003o:P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool300000180oooo00@0003o0?oo
o`3oool0003o:P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3000001D0oooo00D0003o0?oo
o`3oool0oooo0000o`0Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<000005P3oool30000
o`<0oooo00<0003o0?ooo`3oool09`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000002`3oool00`000?l0
oooo0?ooo`0:0?ooo`@0003o0`3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`0Q0?ooo`<00000303oool30000o`P0oooo0`000?l30?ooo`<0003o0P3oool00`000?l0oooo
0?ooo`0W0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000003`3oool010000?l0oooo0?oo
o`000?l60?ooo`<0003o00@0oooo0000o`3oool0oooo0`000?l30?ooo`030000o`3oool0oooo02L0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000C0?ooo`050000o`3oool0oooo0?ooo`00
0?l00`3oool01`000?l0oooo0000o`3oool0003o0?ooo`000?l00`3oool20000o`<0oooo00<0003o
0?ooo`3oool09`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000001L0oooo00`0003o0?oo
o`3oool0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`000?l20?ooo`040000o`3oool0oooo
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?oo
o`<000007P3oool20000o`040?ooo`000?l0003o0?ooo`80003o0`3oool01P000?l0oooo0?ooo`00
0?l0oooo0000o`80oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303o
ool3000001`0oooo00<0003o0?ooo`3oool00P3oool02@000?l0oooo0000o`3oool0003o0?ooo`00
0?l0oooo0000o`020?ooo`040000o`3oool0oooo0000o`80oooo0`000?lX0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`080?ooo`<00000403oool00`000?l0oooo0?ooo`0:0?ooo`<0003o1@3oool20000
o`060?ooo`000?l0003o0000o`3oool0003o0P3oool01@000?l0oooo0?ooo`3oool0003o02`0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00@0oooo0`00000>0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01P3oool20000o`@0oooo0P000?l40?ooo`030000o`3oool0003o00<0003o00D0
oooo0000o`3oool0oooo0000o`030?ooo`030000o`3oool0oooo02X0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo00<000004@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo0P00
0?l00`3oool0003o0?ooo`020?ooo`@0003o0P3oool01@000?l0oooo0000o`000?l0oooo0080003o
00@0oooo0000o`3oool0003o<03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000D0?ooo`030000o`3oool0oooo00<0oooo
00@0003o0?ooo`3oool0oooo1@000?l20?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`040000o`030?ooo`000?l0003o0340oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool06@3oool010000?l0
oooo0?ooo`3oool30000o`030?ooo`000?l0oooo0080oooo00@0003o0?ooo`3oool0oooo0P000?l2
0?ooo`030000o`3oool0oooo0080003o00<0oooo0000o`3oool0<P3oool2000005/0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0H0?oo
o`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l00P000?l30?ooo`040000o`3oool0oooo
0?ooo`80003o0P3oool01@000?l0oooo0?ooo`3oool0003o0380oooo0`0000020?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0G0?ooo`040000o`3oool0003o0000o`80oooo00H0003o0?ooo`3oool0003o
0?ooo`000?l20?ooo`090000o`3oool0oooo0?ooo`000?l0oooo0000o`3oool0003o0380oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0003o0080oooo00<0
003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l_0?ooo`<000002P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool01`3oool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0
0P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`000?l00P3oool01@00
0?l0oooo0?ooo`3oool0003o02l0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`080?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0000o`020?oo
o`030000o`3oool0003o00<0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0^0?oo
o`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`04
0000o`3oool0oooo0000o`80oooo00H0003o0?ooo`3oool0003o0?ooo`000?l30?ooo`80003o0`3o
ool00`000?l0oooo0?ooo`020000obh0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`08
0?ooo`090000o`3oool0oooo0?ooo`000?l0oooo0000o`3oool0003o0080oooo00@0003o0?ooo`3o
ool0003o0P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool00P00
0?lZ0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0203oool010000?l0oooo0?ooo`00
0?l20?ooo`030000o`3oool0oooo00<0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`05
0000o`3oool0oooo0000o`3oool00P000?lZ0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool02@3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo0080oooo00H0003o0?ooo`3o
ool0003o0?ooo`000?l30?ooo`060000o`3oool0oooo0000o`3oool0003o9`3oool300000280oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`040000o`3oool0oooo0000o`80oooo00@0003o0?ooo`3oool0003o103oool00`000?l0
oooo0?ooo`0R0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140
oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo0?ooo`00
0?l01`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`P0oooo00<0003o0?ooo`3oool07P3oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo00X0oooo00@0003o0?ooo`3oool0003o1`3oool0
10000?l0oooo0?ooo`000?l:0?ooo`030000o`3oool0oooo01X0oooo1000000^0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0;0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`000?l00P3o
ool00`000?l0oooo0?ooo`0U0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool03P3oool0
10000?l0oooo0?ooo`000?l20?ooo`<0003o903oool3000003H0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo00h0oooo00@0003o0?ooo`3oool0003o9P3oool3000003X0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo00`0oooo00<0003o0?ooo`3oool00`000?lS0?ooo`<00000?P3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0303oool20000ob<0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo01h0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000
BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3
00000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool20000
0900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0
oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000680oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0
oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P
0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00
000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3o
ool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0
oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool20000
02D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00
001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3o
ool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900
oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool5
00000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P00
00090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo
00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo
0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00
001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`80
0000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo
0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`800000
2`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3o
ool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0
oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0
oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo
00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000
D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03o
ool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?oo
o`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@00000
1@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3o
ool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool0
06X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<0
00000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?oo
o`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000
<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool0
0`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool20000
00d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool50000
0480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo
09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00
000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V
0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?oo
o`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000
003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3o
ool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool4
00000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool40000
08@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo
00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00
000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?oo
o`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0
=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03o
ool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool00000
02<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool40000
0;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`00
0000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`800000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P00
00050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool5
00000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool30000
0080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59651 .57189 m
.59189 .57128 L
s
.59651 .57189 m
.60526 .60635 L
s
.60067 .6059 m
.60526 .60635 L
s
.59189 .57128 m
.59031 .57266 L
s
.59031 .57266 m
.58982 .57579 L
s
.59827 .60405 m
.60067 .6059 L
s
.58982 .57579 m
.58999 .57901 L
s
.5961 .6006 m
.59827 .60405 L
s
.58999 .57901 m
.59057 .58389 L
s
.5946 .59722 m
.5961 .6006 L
s
.59057 .58389 m
.59267 .59217 L
s
.59267 .59217 m
.5946 .59722 L
s
.58546 .58166 m
.59135 .60499 L
s
.58798 .59165 m
.58604 .58657 L
s
.58604 .58657 m
.58385 .58308 L
s
.58385 .58308 m
.58207 .58125 L
s
.58207 .58125 m
.58003 .581 L
s
.57914 .59066 m
.57999 .59402 L
s
.57719 .58554 m
.57914 .59066 L
s
.57999 .59402 m
.58058 .599 L
s
.57496 .58201 m
.57719 .58554 L
s
.58058 .599 m
.58006 .60223 L
s
.57316 .58016 m
.57496 .58201 L
s
.57108 .57991 m
.57316 .58016 L
s
.58006 .60223 m
.57911 .60378 L
s
.57911 .60378 m
.57703 .60358 L
s
.57011 .58143 m
.57108 .57991 L
s
.56957 .58465 m
.57011 .58143 L
s
.57703 .60358 m
.57522 .60175 L
s
.56829 .57957 m
.57426 .60331 L
s
.57522 .60175 m
.57298 .59821 L
s
.56337 .57897 m
.56654 .60255 L
s
.55769 .57828 m
.56654 .60255 L
s
.55769 .57828 m
.56086 .60199 L
s
.55195 .57758 m
.56086 .60199 L
s
.54803 .57878 m
.55019 .58743 L
s
.546 .57351 m
.54803 .57878 L
s
.54441 .56996 m
.546 .57351 L
s
.55019 .58743 m
.55076 .59254 L
s
.54208 .56631 m
.54441 .56996 L
s
.55076 .59254 m
.5509 .59593 L
s
.54018 .56439 m
.54208 .56631 L
s
.5509 .59593 m
.55031 .59926 L
s
.53722 .56399 m
.54018 .56439 L
s
.55031 .59926 m
.54929 .60085 L
s
.54929 .60085 m
.54635 .60056 L
s
.53617 .56553 m
.53722 .56399 L
s
.53556 .56882 m
.53617 .56553 L
s
.54287 .58661 m
.53917 .5862 L
s
.54635 .60056 m
.54444 .59867 L
s
.53568 .57222 m
.53556 .56882 L
s
.54444 .59867 m
.54209 .59502 L
s
.54209 .59502 m
.54048 .59144 L
s
.54048 .59144 m
.53917 .5862 L
s
.53207 .57516 m
.53819 .59976 L
s
.53469 .5857 m
.53263 .58034 L
s
.53263 .58034 m
.53025 .57665 L
s
.53025 .57665 m
.5283 .57471 L
s
.5283 .57471 m
.52602 .57443 L
s
.52485 .5846 m
.52573 .58814 L
s
.52276 .57919 m
.52485 .5846 L
s
.52573 .58814 m
.52629 .59339 L
s
.52035 .57546 m
.52276 .57919 L
s
.52629 .59339 m
.52564 .59679 L
s
.51837 .5735 m
.52035 .57546 L
s
.51605 .57321 m
.51837 .5735 L
s
.52564 .59679 m
.52455 .59842 L
s
.52455 .59842 m
.52224 .59819 L
s
.51494 .57481 m
.51605 .57321 L
s
.51427 .5782 m
.51494 .57481 L
s
.52224 .59819 m
.52025 .59625 L
s
.51294 .57284 m
.51915 .59789 L
s
.52025 .59625 m
.51781 .59251 L
s
.50746 .57217 m
.51681 .60998 L
s
.50879 .57756 m
.50632 .57378 L
s
.51167 .59539 m
.51235 .59195 L
s
.50632 .57378 m
.5043 .57178 L
s
.5043 .57178 m
.50191 .57149 L
s
.51054 .59704 m
.51167 .59539 L
s
.50816 .59681 m
.51054 .59704 L
s
.50191 .57149 m
.50077 .57311 L
s
.50077 .57311 m
.50006 .57654 L
s
.50613 .59484 m
.50816 .59681 L
s
.50364 .59105 m
.50613 .59484 L
s
.50006 .57654 m
.5006 .58189 L
s
.5015 .58552 m
.50364 .59105 L
s
.5006 .58189 m
.5015 .58552 L
s
.48833 .55748 m
.49776 .59579 L
s
.49326 .57752 m
.48947 .57175 L
s
.48947 .57175 m
.48739 .56973 L
s
.48739 .56973 m
.48493 .56943 L
s
.48493 .56943 m
.48374 .57106 L
s
.48374 .57106 m
.48427 .57648 L
s
.48427 .57648 m
.48879 .59491 L
s
.47219 .55354 m
.47348 .5555 L
s
.47348 .5555 m
.4731 .55723 L
s
.47181 .55527 m
.47219 .55354 L
s
.4731 .55723 m
.47181 .55527 L
s
.47582 .56832 m
.48217 .59426 L
s
.47266 .57877 m
.47358 .58249 L
s
.47045 .57308 m
.47266 .57877 L
s
.47358 .58249 m
.4741 .588 L
s
.46785 .56916 m
.47045 .57308 L
s
.4741 .588 m
.47333 .59156 L
s
.46569 .56709 m
.46785 .56916 L
s
.46313 .56677 m
.46569 .56709 L
s
.47333 .59156 m
.47209 .59327 L
s
.47209 .59327 m
.46954 .59301 L
s
.46188 .56844 m
.46313 .56677 L
s
.46107 .57199 m
.46188 .56844 L
s
.46954 .59301 m
.46737 .59097 L
s
.46737 .59097 m
.46474 .58703 L
s
.45589 .57138 m
.45594 .57506 L
s
.4541 .56751 m
.45589 .57138 L
s
.45102 .5653 m
.4541 .56751 L
s
.45594 .57506 m
.45466 .57676 L
s
.45962 .59019 m
.45957 .5865 L
s
.45748 .59183 m
.45962 .59019 L
s
.44839 .56498 m
.45102 .5653 L
s
.45466 .57676 m
.45074 .57817 L
s
.45486 .59157 m
.45748 .59183 L
s
.44621 .56656 m
.44839 .56498 L
s
.45074 .57817 m
.44945 .57988 L
s
.45176 .58941 m
.45486 .59157 L
s
.44625 .57026 m
.44621 .56656 L
s
.44945 .57988 m
.44949 .58359 L
s
.44996 .5855 m
.45176 .58941 L
s
.44949 .58359 m
.44996 .5855 L
s
.4345 .5503 m
.441 .57709 L
s
.44468 .5887 m
.44425 .59053 L
s
.44332 .58669 m
.44468 .5887 L
s
.4429 .58852 m
.44332 .58669 L
s
.44425 .59053 m
.4429 .58852 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool03`3o
ool00`000?l0oooo0?ooo`0K0?ooo`<00000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`0H0?ooo`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0oooo
00/0oooo00<0003o0?ooo`3oool01`3oool3000004T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo00d0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`040000o`00000000000000
04`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool03@3oool300000003
0000o`3oool0oooo04h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0
2P3oool3000000<0oooo00<0003o0?ooo`3oool03`3oool00`000?l0oooo0?ooo`0l0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0003o103oool00`000?l000000000
00070?ooo`030000o`3oool0oooo00h0oooo0`000?ll0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`09
0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0000000000000`000?l20?ooo`070000o`3o
ool0oooo0?ooo`000?l0oooo0000o`0@0?ooo`030000o`3oool0003o03`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00T0oooo00<0003o0?ooo`000?l00`0000001@000?l0oooo0000o`3oool0003o0080
oooo00D0003o0?ooo`3oool0003o0?ooo`020000o`<0oooo0`000?l:0?ooo`040000o`3oool0oooo
0000oa40oooo0P000?lX0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`030000o`0000000000
00<0oooo00<0003o0?ooo`3oool00P3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00P0
003o0?ooo`3oool0oooo0000o`3oool0003o0?ooo`<0003o0P3oool20000o`80oooo00@0003o0?oo
o`3oool0003o403oool00`000?l0oooo0000o`0X0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<0000000<0003o0?ooo`3oool00P3oool20000o`@0oooo00H0003o0?ooo`3oool0003o0?ooo`00
0?l20?ooo`80003o00<0oooo0000o`3oool00P3oool30000o`030?ooo`000?l0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?ooo`040000o`3oool0oooo0000obL0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo00<000001P3oool20000o`L0oooo00D0003o0?ooo`000?l0oooo
0000o`030?ooo`030000o`3oool0003o00<0oooo0`000?l20?ooo`040000o`3oool0oooo0000o`D0
oooo00P0003o0?ooo`000?l0oooo0000o`3oool0003o0?ooo`<0003o1@3oool010000?l0oooo0?oo
o`000?lW0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0S03oool2000000T0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0000
o`020?ooo`040000o`3oool0oooo0000o`80oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?oo
o`030000o`3oool0oooo0080003o103oool030000?l0oooo0000o`3oool0003o0?ooo`000?l0oooo
0000o`3oool0003o0?ooo`<0003o00D0oooo0000o`3oool0oooo0000o`0W0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo
00P0oooo0P000?l70?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool010000?l0oooo0?oo
o`000?l20?ooo`030000o`3oool0003o00<0oooo00@0003o0?ooo`000?l0003o1@3oool00`000?l0
oooo0000o`030000o`050?ooo`000?l0oooo0?ooo`000?l00P3oool00`000?l0oooo0000o`030?oo
o`030000o`3oool0oooo02<0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool01P3oool010000?l0oooo0?ooo`000?l20?oo
o`030000o`3oool0003o00<0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`040000o`3oool0
oooo0000o`<0oooo0P000?l30?ooo`050000o`3oool0oooo0000o`3oool00P000?l20?ooo`030000
o`3oool0003o00<0003o0P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0003o00<0oooo
00<0003o0?ooo`3oool0803oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00H0oooo0P00
0?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l00P3oool01P000?l0oooo0?ooo`000?l0oooo
0000o`<0oooo00@0003o0?ooo`3oool0003o0P3oool20000o`<0oooo00@0003o0?ooo`3oool0oooo
0P000?l30?ooo`030000o`3oool0003o00<0003o0P3oool01@000?l0oooo0?ooo`000?l0oooo0080
003o00D0oooo0000o`3oool0oooo0000o`0N0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool02P3oool20000o`<0oooo0`000?l30?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3o
ool0003o0P3oool00`000?l0oooo0000o`020?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`040000o`050?ooo`000?l0oooo0?ooo`000?l00P3oool00`000?l0oooo0000
o`020?ooo`030000o`3oool0oooo01T0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0E
0?ooo`030000o`3oool0003o0080oooo00P0003o0?ooo`3oool0oooo0000o`3oool0003o0?ooo`80
003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00@0
003o00D0oooo0000o`3oool0oooo0000o`020?ooo`030000o`3oool0003o00<0oooo00<0003o0?oo
o`3oool05@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01h0oooo0P000?l0103oool0
003o0000o`3oool20000o`@0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`@0003o0P3oool0
0`000?l0oooo0000o`020?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool04P3o
ool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`020000o`<0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`03
0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool03`3oool3000001H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0240oooo00<0003o0?ooo`3oool03P3oool00`000?l0oooo0000o`020?oo
o`<0003o0`3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00X0oooo1000000J
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo01T0oooo00@0003o0?oo
o`3oool0oooo0`000?l90?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool00`00
0?l0oooo0?ooo`0U0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`0R0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140
oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00000c
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00000n0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3
000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100
oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?oo
o`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
3`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3
00000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0
oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000
P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03o
ool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool40000
00D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?oo
o`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool40000
02@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?oo
o`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000
003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?oo
o`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3o
ool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000
oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<0
00000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?oo
o`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00
002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo
0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`06
0?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`03
0000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l
0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000
NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
03P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3o
ool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000
L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@00
0000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<00000
0?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?oo
o`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0
b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000
003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0
c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo
00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo
00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00
001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?oo
o`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo
0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003o
ool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000
B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool0
0`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo
0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<0
00000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@0
00007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D00000
8`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0
oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo
00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<0
00000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@00000
0?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000
000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]
0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3o
ool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3o
ool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0
M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3o
ool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool0
08T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool50000
0780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool40000
07L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L
0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?oo
o`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3o
ool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3o
ool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3o
ool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool0
08`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0
oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo
00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?oo
o`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@00000
0?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00
002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?oo
o`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3o
ool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000
c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@0
00000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]
0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@00
00020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y
0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60595 .60867 m
.60086 .60584 L
s
.60595 .60867 m
.61171 .64238 L
s
.60086 .60584 m
.59893 .60622 L
s
.60661 .63968 m
.61171 .64238 L
s
.59893 .60622 m
.59801 .60862 L
s
.59801 .60862 m
.59782 .61144 L
s
.59782 .61144 m
.5979 .61588 L
s
.60414 .6369 m
.60661 .63968 L
s
.5979 .61588 m
.59927 .62397 L
s
.60212 .63287 m
.60414 .6369 L
s
.59927 .62397 m
.60083 .62923 L
s
.60083 .62923 m
.60212 .63287 L
s
.59243 .61142 m
.59628 .63421 L
s
.59251 .61589 m
.59047 .61182 L
s
.59408 .62117 m
.59251 .61589 L
s
.59047 .61182 m
.5887 .60938 L
s
.5887 .60938 m
.58644 .60814 L
s
.58273 .61057 m
.58431 .6159 L
s
.58066 .60647 m
.58273 .61057 L
s
.58431 .6159 m
.58486 .61918 L
s
.58486 .61918 m
.58492 .6237 L
s
.57887 .604 m
.58066 .60647 L
s
.57657 .60274 m
.57887 .604 L
s
.58492 .6237 m
.58395 .62619 L
s
.57531 .60355 m
.57657 .60274 L
s
.58395 .62619 m
.5827 .62703 L
s
.57432 .606 m
.57531 .60355 L
s
.5827 .62703 m
.58041 .62582 L
s
.5735 .60106 m
.57734 .62419 L
s
.58041 .62582 m
.5786 .62335 L
s
.5786 .62335 m
.57651 .61922 L
s
.56809 .59809 m
.5688 .61968 L
s
.56184 .59467 m
.56251 .61635 L
s
.56184 .59467 m
.5688 .61968 L
s
.55552 .59121 m
.56251 .61635 L
s
.54939 .5848 m
.551 .59027 L
s
.54804 .58101 m
.54939 .5848 L
s
.54589 .57678 m
.54804 .58101 L
s
.551 .59027 m
.55237 .59866 L
s
.54401 .57421 m
.54589 .57678 L
s
.55237 .59866 m
.55239 .60328 L
s
.54077 .5724 m
.54401 .57421 L
s
.55239 .60328 m
.55213 .60622 L
s
.55213 .60622 m
.55107 .60875 L
s
.53942 .57318 m
.54077 .5724 L
s
.55107 .60875 m
.54973 .60959 L
s
.53833 .57565 m
.53942 .57318 L
s
.54973 .60959 m
.54649 .60787 L
s
.53806 .57857 m
.53833 .57565 L
s
.5443 .59431 m
.54023 .59211 L
s
.54649 .60787 m
.54459 .60531 L
s
.54459 .60531 m
.54241 .60104 L
s
.54105 .59721 m
.54023 .59211 L
s
.54241 .60104 m
.54105 .59721 L
s
.53367 .57926 m
.53749 .60311 L
s
.53366 .5839 m
.53147 .5796 L
s
.53531 .58946 m
.53366 .5839 L
s
.53147 .5796 m
.52954 .57699 L
s
.52954 .57699 m
.52705 .57563 L
s
.52284 .57802 m
.52449 .58362 L
s
.52061 .57367 m
.52284 .57802 L
s
.52449 .58362 m
.52504 .58706 L
s
.52504 .58706 m
.52501 .59177 L
s
.51866 .57104 m
.52061 .57367 L
s
.51612 .56965 m
.51866 .57104 L
s
.52501 .59177 m
.52388 .59432 L
s
.51469 .57044 m
.51612 .56965 L
s
.52388 .59432 m
.52246 .59516 L
s
.51352 .57296 m
.51469 .57044 L
s
.52246 .59516 m
.51992 .59381 L
s
.51271 .56778 m
.51651 .59201 L
s
.51992 .59381 m
.51794 .59118 L
s
.51794 .59118 m
.51569 .5868 L
s
.50671 .5645 m
.51241 .60107 L
s
.50752 .56969 m
.50525 .56529 L
s
.50525 .56529 m
.50325 .5626 L
s
.50325 .5626 m
.50065 .56118 L
s
.5085 .58617 m
.50969 .5836 L
s
.50065 .56118 m
.49917 .56197 L
s
.50704 .587 m
.5085 .58617 L
s
.49917 .56197 m
.49796 .5645 L
s
.50444 .58562 m
.50704 .587 L
s
.49796 .5645 m
.4979 .56927 L
s
.50242 .58294 m
.50444 .58562 L
s
.50013 .5785 m
.50242 .58294 L
s
.4979 .56927 m
.49844 .57278 L
s
.49844 .57278 m
.50013 .5785 L
s
.48735 .54268 m
.49301 .57957 L
s
.4903 .56195 m
.48683 .55523 L
s
.48683 .55523 m
.48478 .55249 L
s
.48478 .55249 m
.48209 .55102 L
s
.48209 .55102 m
.48057 .5518 L
s
.48057 .5518 m
.48047 .55662 L
s
.48047 .55662 m
.48317 .57437 L
s
.47002 .53141 m
.47119 .53369 L
s
.47119 .53369 m
.47055 .53495 L
s
.46937 .53267 m
.47002 .53141 L
s
.47055 .53495 m
.46937 .53267 L
s
.47215 .54558 m
.47591 .57053 L
s
.46562 .54692 m
.46734 .55279 L
s
.46324 .54234 m
.46562 .54692 L
s
.46734 .55279 m
.46788 .55637 L
s
.46788 .55637 m
.46776 .56125 L
s
.46112 .53954 m
.46324 .54234 L
s
.45833 .53801 m
.46112 .53954 L
s
.46776 .56125 m
.46645 .56387 L
s
.45673 .53879 m
.45833 .53801 L
s
.46645 .56387 m
.46487 .56469 L
s
.45539 .54136 m
.45673 .53879 L
s
.46487 .56469 m
.46208 .56321 L
s
.46208 .56321 m
.45994 .56041 L
s
.45994 .56041 m
.45753 .5558 L
s
.44975 .5383 m
.44933 .5414 L
s
.44827 .53417 m
.44975 .5383 L
s
.44516 .5308 m
.44827 .53417 L
s
.44933 .5414 m
.4477 .54219 L
s
.4423 .52924 m
.44516 .5308 L
s
.45147 .55592 m
.45188 .55279 L
s
.4477 .54219 m
.4432 .54143 L
s
.44889 .55623 m
.45147 .55592 L
s
.43969 .52948 m
.4423 .52924 L
s
.44602 .55471 m
.44889 .55623 L
s
.43926 .5326 m
.43969 .52948 L
s
.4432 .54143 m
.44155 .54223 L
s
.44288 .55136 m
.44602 .55471 L
s
.44155 .54223 m
.44112 .54536 L
s
.44112 .54536 m
.44139 .54719 L
s
.44139 .54719 m
.44288 .55136 L
s
.42889 .51015 m
.43259 .53572 L
s
.43515 .54726 m
.43444 .54859 L
s
.43391 .54491 m
.43515 .54726 L
s
.4332 .54623 m
.43391 .54491 L
s
.43444 .54859 m
.4332 .54623 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0L0?oo
o`030000o`3oool0oooo04/0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0B03oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`150?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3o
ool0@P3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
?P3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3o
ool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0>`3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool0=`3oool3
000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool20000
07H0oooo00<000000?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0003o0380oooo0`00000[
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool05@3oool01P000?l0oooo0?ooo`000?l0
oooo0000o`P0oooo00<0003o0?ooo`3oool08`3oool3000002h0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0503oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3o
ool0oooo00D0oooo0P000?lQ0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool0
0`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0M0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
01T0oooo00<0003o0?ooo`000?l00P000?lO0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0503oool40000o`80oooo00@0003o0?ooo`3oool0003o203oool00`000?l0oooo0?ooo`0@0?oo
o`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0000o`080?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03@3oool3000003d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo00l0oooo0P000?l00`3oool0003o0?ooo`070?ooo`040000o`3oool0oooo0000o`D0
oooo00<0003o0?ooo`3oool02P3oool300000400oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo00l0oooo
00<0003o0?ooo`000?l0203oool010000?l0oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00L0
oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0A0?ooo`040000o`3oool0oooo0000o`D0
oooo00<0003o0?ooo`000?l00P3oool30000o`030?ooo`000?l0oooo00@0oooo0`0000160?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000
003oool0oooo0140oooo00D0003o0?ooo`000?l0oooo0000o`030?ooo`030000o`3oool0003o0080
oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool04@3oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0003o0080oooo00<0003o0?oo
o`3oool00P000?l2000004`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01@0oooo00@0003o0?ooo`3o
ool0003o0P3oool00`000?l0oooo0000o`0200000080003o0`3oool00`000?l0oooo0?ooo`190?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`0D0?ooo`080000o`3oool0003o0?ooo`000000003o00000000
0?l30?ooo`060000o`3oool0oooo0000o`3oool0003oBP3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
503oool01`000?l000000000003oool0003o0?ooo`000?l00`3oool01@000?l0oooo0?ooo`000?l0
oooo0080003oB@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000000@0oooo00@0003o0?oo
o`3oool0003o0P3oool01@000?l0oooo0?ooo`000?l0oooo0080003o00<0oooo0000o`3oool0AP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0303oool3000000L0oooo00@0003o0?ooo`3oool0003o0`3o
ool00`000?l0oooo0000o`020?ooo`030000o`3oool0003o0080003oA@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0203oool3000000d0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo
00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`040?ooo`<0003o>`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0103oool3000001@0oooo00<0003o0?ooo`000?l00`3oool20000o`80oooo00@0
003o0?ooo`000?l0003o0`3oool00`000?l0oooo0000o`0k0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`03000001L0oooo00<0003o0?ooo`000?l00`3oool20000o`<0oooo00<0003o0?ooo`3oool00P00
0?l0103oool0003o0?ooo`000?lk0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001`0oooo00L0003o0?ooo`3oool0oooo
0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P000?l40?ooo`030000o`3oool0oooo03P0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo
00<000000?ooo`3oool0703oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00D0003o0?oo
o`3oool0oooo0000o`050?ooo`030000o`3oool0oooo03H0oooo0P00001K0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07@3oool30000
o`030?ooo`000?l0oooo0080oooo00@0003o0?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0c
0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0000o`030?oo
o`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0;`3oool4000000H0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0200oooo0`000?l20?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool0
0`000?l0oooo0000o`0/0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0803oool00`00
0?l0oooo0?ooo`020000o`@0oooo10000?l20?ooo`80003o00<0oooo0000o`3oool09P3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0000o`030?ooo`040000o`3oool0003o0000o`80oooo00<0003o0?ooo`3oool07`3oool30000
0180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0000o`030?ooo`030000o`3oool0003o0080003o00@0oooo0000o`3oool0003o703oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`000?l00`3oool00`000?l0
oooo0000o`020000o`030?ooo`000?l0oooo00<0003o5P3oool4000001X0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02`0oooo00@0003o0?ooo`3oool0003o0P3oool20000o`060?ooo`000?l0oooo0000
o`3oool0003o1P3oool20000o`/0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0]0?oo
o`80003o0`3oool40000o`040?ooo`000?l0oooo0000o`80oooo00H0003o0?ooo`3oool0oooo0000
o`3oool20000o`H0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0b0?ooo`@0003o00D0
oooo0000o`3oool0oooo0000o`020?ooo`80003o00D0oooo0000o`3oool0oooo0000o`030?ooo`<0
00009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000
S`3oool00`000000oooo0?ooo`0c0?ooo`<0003o0P3oool00`000?l0oooo0000o`020?ooo`80003o
00D0oooo0000o`3oool0oooo0000o`03000002X0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03<0oooo
00<0003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0000000<0
0000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0=P3oool010000?l0oooo0?ooo`000?l20?ooo`03
0000o`3oool000000080000000D0003o0?ooo`3oool0oooo0000o`0^0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0i0?ooo`030000o`3oool000000080000000@0oooo0000o`3oool0003o0`3oool00`00
0?l0oooo0?ooo`0/0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0h0?ooo`<0000000<0oooo0000o`3o
ool00P3oool20000o`<0oooo00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
=@3oool300000080oooo0`000?l30?ooo`80003o0`3oool00`000?l0oooo0?ooo`0^0?ooo`030000
003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0a0?ooo`@000002`3oool00`000?l0oooo0000o`020?ooo`030000o`3o
ool0oooo02l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00000?0?ooo`030000o`3oool0
003o0080oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
0180oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0X0?ooo`<00000603oool010000?l0oooo0?ooo`000?lb0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0
oooo0`00000L0?ooo`030000o`3oool0003o03<0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool400000200oooo
0P000?ld0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00
603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
3P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000
QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880
oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo
0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=
0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0
oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3o
ool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3
000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0
oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo
0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?oo
o`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000
003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3
000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo
0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo
0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3o
ool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000
003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3o
ool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3
000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo
0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo
00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002
000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0
oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo
0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S
0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?oo
o`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`00
0000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0
oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo
0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<0
00000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a
0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00
=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003o
ool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2
000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`03
0000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00
?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0
oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?oo
o`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/
0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0
IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
0`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R
0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`03
0?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
0P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3o
ool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003o
ool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool0
0`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000
oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo
0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo
00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo
001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D00000
0?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool0
10000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003o
ool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0
oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo
0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o
0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?oo
o`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00
L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`00
0000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000
oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo
0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?oo
o`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@0
00000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo
1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo
00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<0
00000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?oo
o`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?oo
o`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D0
0000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2
000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool0
08/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool0
08`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<0
00000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<00000
0?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?oo
o`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@0
0000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3o
ool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2
000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool20000
02@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000
oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0
oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo
0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?oo
o`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo
001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<00000
0?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?oo
o`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00
Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo
0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00
003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo
0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P00
00040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61222 .64471 m
.60683 .63973 L
s
.61222 .64471 m
.61475 .67647 L
s
.60683 .63973 m
.60463 .63908 L
s
.60463 .63908 m
.60331 .64067 L
s
.60331 .64067 m
.60276 .64297 L
s
.60933 .67158 m
.61475 .67647 L
s
.60276 .64297 m
.60233 .6468 L
s
.60233 .6468 m
.60292 .65441 L
s
.60687 .66793 m
.60933 .67158 L
s
.60292 .65441 m
.60405 .6597 L
s
.60507 .66346 m
.60687 .66793 L
s
.60405 .6597 m
.60507 .66346 L
s
.59673 .64025 m
.59835 .66166 L
s
.59629 .64409 m
.59448 .6396 L
s
.59742 .64939 m
.59629 .64409 L
s
.59448 .6396 m
.59278 .63662 L
s
.59278 .63662 m
.5904 .63444 L
s
.58596 .63464 m
.58709 .63997 L
s
.58413 .6301 m
.58596 .63464 L
s
.58241 .62709 m
.58413 .6301 L
s
.58709 .63997 m
.58732 .64305 L
s
.58 .62487 m
.58241 .62709 L
s
.58732 .64305 m
.58685 .64694 L
s
.57849 .62493 m
.58 .62487 L
s
.58685 .64694 m
.58547 .64858 L
s
.57709 .62652 m
.57849 .62493 L
s
.58547 .64858 m
.58397 .64866 L
s
.57676 .6219 m
.57829 .64354 L
s
.58397 .64866 m
.58154 .64647 L
s
.58154 .64647 m
.57981 .64345 L
s
.57981 .64345 m
.57796 .63888 L
s
.57106 .61667 m
.56927 .63539 L
s
.56449 .61063 m
.56263 .62939 L
s
.56449 .61063 m
.56927 .63539 L
s
.55785 .60453 m
.56263 .62939 L
s
.55075 .59216 m
.55179 .59604 L
s
.54887 .58751 m
.55075 .59216 L
s
.55179 .59604 m
.55293 .60148 L
s
.54708 .5844 m
.54887 .58751 L
s
.55293 .60148 m
.55344 .60927 L
s
.5437 .58126 m
.54708 .5844 L
s
.55344 .60927 m
.5529 .6132 L
s
.54209 .58125 m
.5437 .58126 L
s
.5529 .6132 m
.55226 .61557 L
s
.54058 .58279 m
.54209 .58125 L
s
.55226 .61557 m
.55076 .61718 L
s
.53992 .58512 m
.54058 .58279 L
s
.55076 .61718 m
.54917 .61722 L
s
.54497 .60155 m
.5407 .59765 L
s
.54917 .61722 m
.54576 .61414 L
s
.54099 .60238 m
.5407 .59765 L
s
.54576 .61414 m
.54395 .61102 L
s
.54395 .61102 m
.54204 .60631 L
s
.53496 .58351 m
.5363 .6056 L
s
.54204 .60631 m
.54099 .60238 L
s
.53439 .58743 m
.53247 .58271 L
s
.53553 .59295 m
.53439 .58743 L
s
.53247 .58271 m
.53064 .57954 L
s
.53064 .57954 m
.52804 .57715 L
s
.52307 .57707 m
.52422 .58262 L
s
.52113 .5723 m
.52307 .57707 L
s
.51928 .56911 m
.52113 .5723 L
s
.52422 .58262 m
.5244 .58579 L
s
.51663 .56667 m
.51928 .56911 L
s
.5244 .58579 m
.52379 .58976 L
s
.51495 .56663 m
.51663 .56667 L
s
.52379 .58976 m
.52221 .59135 L
s
.51334 .56817 m
.51495 .56663 L
s
.52221 .59135 m
.52054 .59135 L
s
.51308 .56342 m
.51431 .58573 L
s
.52054 .59135 m
.51787 .58895 L
s
.51787 .58895 m
.516 .58574 L
s
.516 .58574 m
.51404 .58092 L
s
.50683 .55767 m
.50863 .59134 L
s
.50709 .56245 m
.50512 .55762 L
s
.50512 .55762 m
.50324 .55437 L
s
.50324 .55437 m
.50053 .55188 L
s
.50053 .55188 m
.4988 .55181 L
s
.50614 .57681 m
.50777 .57523 L
s
.4988 .55181 m
.49714 .55334 L
s
.50441 .57678 m
.50614 .57681 L
s
.49714 .55334 m
.49647 .55732 L
s
.50169 .57432 m
.50441 .57678 L
s
.48812 .52981 m
.48977 .56355 L
s
.49647 .55732 m
.49664 .56053 L
s
.49978 .57106 m
.50169 .57432 L
s
.49664 .56053 m
.49779 .56619 L
s
.49779 .56619 m
.49978 .57106 L
s
.48898 .54741 m
.48598 .54005 L
s
.48598 .54005 m
.48405 .53675 L
s
.48405 .53675 m
.48127 .53419 L
s
.48127 .53419 m
.47948 .53409 L
s
.47948 .53409 m
.47877 .53808 L
s
.4704 .51186 m
.47141 .51434 L
s
.47141 .51434 m
.47055 .51507 L
s
.46953 .5126 m
.4704 .51186 L
s
.47877 .53808 m
.47952 .5543 L
s
.47055 .51507 m
.46953 .5126 L
s
.47097 .52474 m
.47198 .54748 L
s
.4636 .52264 m
.46476 .52839 L
s
.46155 .51764 m
.4636 .52264 L
s
.45957 .51427 m
.46155 .51764 L
s
.46476 .52839 m
.4649 .53165 L
s
.45669 .51162 m
.45957 .51427 L
s
.4649 .53165 m
.46415 .53568 L
s
.45483 .51148 m
.45669 .51162 L
s
.46415 .53568 m
.46237 .53722 L
s
.45303 .51297 m
.45483 .51148 L
s
.46237 .53722 m
.46052 .53712 L
s
.46052 .53712 m
.45762 .53451 L
s
.45762 .53451 m
.45562 .53111 L
s
.45562 .53111 m
.45355 .52607 L
s
.44611 .50347 m
.44721 .50764 L
s
.44311 .49915 m
.44611 .50347 L
s
.44721 .50764 m
.44635 .51002 L
s
.44017 .49644 m
.44311 .49915 L
s
.44635 .51002 m
.44446 .50987 L
s
.43727 .49537 m
.44017 .49644 L
s
.44446 .50987 m
.4396 .50704 L
s
.44685 .52318 m
.4477 .52077 L
s
.44396 .52217 m
.44685 .52318 L
s
.4364 .49775 m
.43727 .49537 L
s
.4396 .50704 m
.43768 .50688 L
s
.441 .5195 m
.44396 .52217 L
s
.4279 .47405 m
.42866 .49707 L
s
.43768 .50688 m
.43681 .50929 L
s
.43797 .51515 m
.441 .5195 L
s
.43681 .50929 m
.43687 .51094 L
s
.43687 .51094 m
.43797 .51515 L
s
.43 .50794 m
.42905 .50869 L
s
.42894 .50536 m
.43 .50794 L
s
.42799 .50612 m
.42894 .50536 L
s
.42905 .50869 m
.42799 .50612 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`1S0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool09P3oool00`000?l0
oooo0?ooo`1S0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`1S0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?oo
o`1S0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`1S
0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0HP3oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0600oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`1M0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0803oool00`000?l0oooo
0?ooo`020000oeP0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`000?l0E03o
ool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool0
0`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0C`3oool3
000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool20000
00L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
04/0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
01`0oooo0P000?l20?ooo`80003o0P3oool00`000?l0oooo0?ooo`170?ooo`<000004@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0L0?ooo`050000o`3oool0oooo
0000o`3oool00P000?m70?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00<0oooo0P000?l40?ooo`030000o`3oool0
oooo03T0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo01d0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool20000ocL0oooo0`00
000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P000006
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo03H0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0L0?oo
o`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0<P3oool400000240oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo01`0oooo0P000?l60?ooo`030000o`3oool0oooo02h0oooo0`00000U0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`00
0000M03oool00`000000oooo0?ooo`0O0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0[
0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`800000MP3oool00`000000oooo0?ooo`0N0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000
o`0X0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0004
0?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo01h0oooo00H0003o
0?ooo`3oool0003o0?ooo`000?l60?ooo`030000o`3oool0oooo01`0oooo0`00000^0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01d0oooo00H0003o0?ooo`3oool0003o
0?ooo`000?l30?ooo`040000o`3oool0oooo0000oa/0oooo0`00000a0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo01d0oooo0`000?l02@3oool0003o0?ooo`3oool0003o
0?ooo`000?l0oooo0000o`0H0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`000?l00P3oool20000oaD0oooo0`00000g0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0P0?ooo`030000o`3oool0003o0080oooo0P000?lB0?ooo`<00000>P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0
oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo00d0
oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0003o00<0oooo
00<0003o0?ooo`3oool02P3oool300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0200oooo00@0
003o0?ooo`3oool0003o2@3oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01l0oooo00@0
003o0?ooo`3oool0003o0P3oool20000o`80oooo0`0000160?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo01h0oooo00@0
003o0?ooo`3oool0003o0P3oool010000?l000000000o`000?m90?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`0P0?ooo`040000o`00000000000000o`80oooo0P000?m80?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`0L0?ooo`<0000000@0003o0?ooo`3oool0003o0P3oool20000odT0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo01P0oooo0`0000030?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`00
0?l0A`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000T0oooo00H0003o0?ooo`3oool0
oooo0000o`3oool30000odD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000<0?ooo`09
0000o`3oool0oooo0?ooo`000?l0oooo0000o`3oool0003o04D0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo00`0oooo0`00000@0?ooo`080000o`3oool0oooo0000o`3oool0003o0?ooo`000?m50?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000503oool01@000?l0oooo0000o`3oool0003o0080
oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001P0oooo
0`000?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l0@@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool00`00000M0?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3oool0003o@03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0
oooo0P00000P0?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3oool0003o0P3oool30000
oc/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0
oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0080
003o00D0oooo0000o`3oool0oooo0000o`0i0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`00
0?l00P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0<`3oool30000
0080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo01l0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l3
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0;`3oool4000000H0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo01l0oooo00@0003o0?ooo`3oool0oooo0P000?l30?ooo`80003o103oool0
0`000?l0oooo0?ooo`0/0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02P0oooo0`00000>0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0Y0?ooo`80003o103oool00`000?l0oooo0?ooo`0U0?ooo`<000004P3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0:@3oool40000o`80oooo00<0003o0?ooo`3oool08P3oool3000001H0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`0N0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0000o`03
0?ooo`030000o`3oool0003o01/0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?oo
o`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0H0?ooo`<000008P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0;03oool020000?l0oooo0?ooo`000?l0oooo0000o`3oool0003o4`3oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo
00<000000?ooo`3oool0;03oool010000?l0oooo0?ooo`000?l20?ooo`80003o403oool3000002X0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02d0oooo0`000?l20?ooo`80003o0P3oool00`000?l0oooo
0?ooo`070?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool30000o`030?ooo`00
0?l0oooo00D0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0c0?ooo`<0003o00D0oooo
0000o`3oool0003o0?ooo`03000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03@0oooo0P000?l0
0`3oool0003o00000002000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03@0oooo00P0003o0000
0000000000000?ooo`000?l0oooo0000ocX0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000
00001@3oool0003o0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0>03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0;P3oool3000000D0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo
0?ooo`0i0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000203oool02@000?l0oooo0?oo
o`3oool0003o0?ooo`000?l0oooo0000o`0i0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<0
00003P3oool20000o`050?ooo`000?l0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0c0?oo
o`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`03
0000003oool0oooo02D0oooo0`00000A0?ooo`80003o0P3oool010000?l0oooo0?ooo`000?l20?oo
o`80003o=@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000T03oool00`000000oooo0?ooo`0Q0?ooo`@000005@3oool010000?l0oooo0?ooo`000?l20?oo
o`060000o`3oool0oooo0000o`3oool0003o=@3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3
000001X0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0
oooo03<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool20000
00L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<000007P3oool01000
0?l0oooo0?ooo`3oool30000o`<0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<000009@3oool010000?l0oooo0?ooo`00
0?l20?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool05@3oool3000002T0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0e
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000002`0oooo00<0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00h0oooo0`00000`0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool0=`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000c0?ooo`030000
o`3oool0003o00<0oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203o
ool3000003T0oooo00@0003o0?ooo`3oool0003o>@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103o
ool4000003`0oooo00@0003o0?ooo`3oool0003o>P3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo
0`0000100?ooo`040000o`3oool0oooo0000oc/0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000140?ooo`030000o`3oool0003o03`0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00180?ooo`80003o?03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?oo
o`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00
000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?oo
o`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo
00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00
001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61505 .67873 m
.60957 .67172 L
s
.61505 .67873 m
.61416 .70736 L
s
.60957 .67172 m
.60716 .67006 L
s
.60716 .67006 m
.60549 .67075 L
s
.60549 .67075 m
.60461 .67245 L
s
.60461 .67245 m
.60367 .67552 L
s
.60862 .70037 m
.61416 .70736 L
s
.60367 .67552 m
.60343 .68234 L
s
.60343 .68234 m
.60408 .68746 L
s
.59815 .66706 m
.59743 .68625 L
s
.60628 .69599 m
.60862 .70037 L
s
.60408 .68746 m
.60479 .69122 L
s
.60479 .69122 m
.60628 .69599 L
s
.59569 .66536 m
.59414 .66195 L
s
.59719 .67013 m
.59569 .66536 L
s
.59784 .67525 m
.59719 .67013 L
s
.59414 .66195 m
.59173 .65888 L
s
.5852 .652 m
.58671 .6568 L
s
.58363 .64857 m
.5852 .652 L
s
.58671 .6568 m
.58735 .66194 L
s
.58119 .64546 m
.58363 .64857 L
s
.58735 .66194 m
.58723 .66469 L
s
.57949 .64474 m
.58119 .64546 L
s
.58723 .66469 m
.58625 .66779 L
s
.57773 .64539 m
.57949 .64474 L
s
.57792 .64129 m
.57704 .66054 L
s
.58625 .66779 m
.5845 .66849 L
s
.5845 .66849 m
.5828 .66781 L
s
.57216 .63396 m
.5679 .64902 L
s
.5828 .66781 m
.58034 .6647 L
s
.58034 .6647 m
.57875 .66124 L
s
.57875 .66124 m
.57723 .65639 L
s
.56553 .62551 m
.56119 .64056 L
s
.56553 .62551 m
.5679 .64902 L
s
.55885 .617 m
.56119 .64056 L
s
.55088 .59807 m
.55241 .60295 L
s
.54927 .59455 m
.55088 .59807 L
s
.55241 .60295 m
.55311 .60676 L
s
.54588 .59021 m
.54927 .59455 L
s
.55311 .60676 m
.55372 .61194 L
s
.55372 .61194 m
.55334 .61881 L
s
.54409 .58939 m
.54588 .59021 L
s
.54223 .58994 m
.54409 .58939 L
s
.55334 .61881 m
.55226 .62188 L
s
.54121 .59158 m
.54223 .58994 L
s
.55226 .62188 m
.55126 .62357 L
s
.55126 .62357 m
.5494 .6242 L
s
.54483 .60802 m
.54054 .60258 L
s
.5494 .6242 m
.54761 .62343 L
s
.54761 .62343 m
.54418 .6191 L
s
.53588 .58775 m
.53467 .60711 L
s
.54029 .60672 m
.54054 .60258 L
s
.54098 .61059 m
.54029 .60672 L
s
.54418 .6191 m
.54254 .61554 L
s
.5332 .58582 m
.53156 .58224 L
s
.53476 .59078 m
.5332 .58582 L
s
.53536 .59601 m
.53476 .59078 L
s
.54254 .61554 m
.54098 .61059 L
s
.53156 .58224 m
.52895 .57893 L
s
.52187 .5714 m
.52344 .57639 L
s
.52021 .56779 m
.52187 .5714 L
s
.52344 .57639 m
.52403 .58164 L
s
.51757 .56443 m
.52021 .56779 L
s
.52403 .58164 m
.52385 .58441 L
s
.5157 .56356 m
.51757 .56443 L
s
.52385 .58441 m
.52268 .58746 L
s
.51374 .56406 m
.5157 .56356 L
s
.51403 .55993 m
.51264 .57933 L
s
.52268 .58746 m
.52073 .58802 L
s
.52073 .58802 m
.51886 .58718 L
s
.50781 .552 m
.50563 .58123 L
s
.51886 .58718 m
.5162 .58382 L
s
.50592 .55111 m
.50424 .54745 L
s
.50751 .55614 m
.50592 .55111 L
s
.5162 .58382 m
.51452 .58018 L
s
.50424 .54745 m
.50155 .54402 L
s
.51452 .58018 m
.51294 .57514 L
s
.50155 .54402 m
.49964 .54311 L
s
.49964 .54311 m
.49762 .54357 L
s
.50467 .56775 m
.50668 .56723 L
s
.49058 .51943 m
.48818 .54849 L
s
.49762 .54357 m
.49639 .54658 L
s
.50276 .56687 m
.50467 .56775 L
s
.49639 .54658 m
.49616 .54935 L
s
.50004 .56345 m
.50276 .56687 L
s
.49616 .54935 m
.49674 .55468 L
s
.49834 .55976 m
.50004 .56345 L
s
.49674 .55468 m
.49834 .55976 L
s
.48693 .52694 m
.48522 .52323 L
s
.48933 .53457 m
.48693 .52694 L
s
.48522 .52323 m
.48247 .51972 L
s
.48247 .51972 m
.48051 .51876 L
s
.47329 .49578 m
.47409 .49834 L
s
.47224 .49597 m
.47329 .49578 L
s
.47409 .49834 m
.47304 .49852 L
s
.48051 .51876 m
.47922 .52173 L
s
.47304 .49852 m
.47224 .49597 L
s
.47922 .52173 m
.47801 .53566 L
s
.4723 .50677 m
.47054 .52624 L
s
.46282 .49625 m
.46444 .50141 L
s
.46107 .49247 m
.46282 .49625 L
s
.46444 .50141 m
.46499 .50676 L
s
.45824 .48887 m
.46107 .49247 L
s
.46499 .50676 m
.46473 .50954 L
s
.45621 .48784 m
.45824 .48887 L
s
.46473 .50954 m
.4634 .51254 L
s
.45404 .48819 m
.45621 .48784 L
s
.4634 .51254 m
.46124 .51295 L
s
.46124 .51295 m
.45921 .51195 L
s
.45921 .51195 m
.45636 .50835 L
s
.44764 .47693 m
.44832 .48092 L
s
.44491 .47189 m
.44764 .47693 L
s
.44832 .48092 m
.44708 .48248 L
s
.44203 .46821 m
.44491 .47189 L
s
.45636 .50835 m
.45458 .50454 L
s
.45458 .50454 m
.45295 .49933 L
s
.44708 .48248 m
.44502 .48143 L
s
.43899 .46591 m
.44203 .46821 L
s
.44502 .48143 m
.44005 .4767 L
s
.43773 .46745 m
.43899 .46591 L
s
.44595 .49364 m
.44719 .49206 L
s
.43145 .44376 m
.42933 .46312 L
s
.44291 .49139 m
.44595 .49364 L
s
.44005 .4767 m
.43796 .47564 L
s
.43796 .47564 m
.4367 .4772 L
s
.44 .48772 m
.44291 .49139 L
s
.4367 .4772 m
.43655 .4786 L
s
.43723 .48263 m
.44 .48772 L
s
.43655 .4786 m
.43723 .48263 L
s
.42743 .47027 m
.42857 .47011 L
s
.42857 .47011 m
.4294 .47276 L
s
.4294 .47276 m
.42826 .47292 L
s
.42826 .47292 m
.42743 .47027 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0
oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo
02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo02L0oooo
0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo02@0oooo0`00
000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0;03oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;P3oool20000of00oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo02T0oooo0P000?l40?ooo`030000o`3o
ool0oooo05d0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0:`3oool01000
0?l0oooo0?ooo`000?mN0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0:P3oool20000
o`80oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02T0
oooo00D0003o0?ooo`000?l0oooo0000o`1M0?ooo`030000003oool0oooo00L0oooo0`00001;0?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`020000oed0oooo00<000000?ooo`3oool0103oool3000004h0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0oooo05l0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`03
0000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`020?ooo`<0003oF@3oool4000005D0oooo00<000000?ooo`3oool0
5`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0E@3oool3000005P0oooo00<000000?ooo`3oool05`3o
ool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0W0?ooo`80003o103oool0
0`000?l0oooo0?ooo`1A0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0;03oool01@00
0?l0oooo0?ooo`3oool0003o04`0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02T0oooo00@0003o0?oo
o`3oool0003o0`3oool20000odP0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0X0?oo
o`050000o`3oool0oooo0?ooo`000?l0B@3oool3000000/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`0W0?ooo`050000o`3oool0oooo0?ooo`000?l0AP3oool3000000h0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3o
ool0003o0080oooo00<0003o0?ooo`3oool0?P3oool300000140oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?l20?ooo`030000
o`3oool0oooo03/0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo02H0oooo0`000?l20?ooo`030000o`3oool0oooo03P0oooo0`00000H0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0
=@3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3o
ool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0W0?ooo`040000o`3oool0
oooo0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0W0?ooo`@000008@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool09P3oool02@000?l0oooo0?ooo`3oool0003o0?ooo`000?l0oooo0000o`0V0?ooo`<0
00009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000
003oool0000007@0oooo00<000000?ooo`3oool09@3oool02@000?l0oooo0?ooo`3oool0003o0?oo
o`000?l0oooo0000o`0S0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0X0?ooo`050000o`3oool0003o
0?ooo`000?l0803oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0V0?oo
o`060000o`3oool0oooo0000o`3oool0003o7@3oool3000002h0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool09@3oool010000?l0oooo0?ooo`3oool20000oaX0oooo0`00
000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<00000
0?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02@0oooo00D0003o
0?ooo`3oool0oooo0000o`0H0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo02L0oooo00<0003o0?ooo`3oool04`3oool3000003L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
02H0oooo00<0003o0?ooo`3oool0403oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02D0
oooo00<0003o0?ooo`3oool00`000?l:0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
903oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo00@0oooo0`0000100?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`80oooo00@0003o0?ooo`3o
ool0oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0U0?ooo`050000o`3oool0oooo0?oo
o`000?l00P0000160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo0`0000210?ooo`030000003oool0oooo02@0oooo00D0003o00000000000000000000o`180?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0Q0?ooo`80000000D0003o0?ooo`3oool0oooo0000o`180?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000000`3oool010000?l0oooo0?ooo`000?l20?oo
o`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000070?ooo`05
0000o`3oool0oooo0000o`3oool00P000?m60?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<0
00002P3oool010000?l0oooo0?ooo`000?l20?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0403oool3000000h0oooo0`000?l20?ooo`030000o`3oool0003o04@0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00`0oooo0`00000B0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3o
ool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001D0oooo00@0003o0?ooo`3oool0
003o0P3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000
603oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo00<000006`3oool00`000?l0oooo0?ooo`020000o`80oooo00<0003o0?ooo`000?l0
@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08`0oooo0P00000N0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool010000?l0oooo
0?ooo`000?m00?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo
0P00002=0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0
oooo0?ooo`0m0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0280oooo0`000?l30?ooo`80003o>P3oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02P0oooo0P000?l00`3oool0003o0000o`0c0?ooo`@000001P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0:03oool20000o`040?ooo`000?l0oooo0000obl0oooo0`00
000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`80003o103oool00`000?l0oooo0?ooo`0Y
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo02H0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool08`3oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`0N0?ooo`@00000
6P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0000o`000?l30?ooo`030000
o`3oool0oooo01/0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`050000o`3o
ool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0H0?ooo`<000008P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:`3oool01@000?l0oooo0?ooo`3oool0003o01L0oooo0`00000V0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003o
ool0oooo02/0oooo00D0003o0?ooo`3oool0oooo0000o`0D0?ooo`<00000:P3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l03P3oool4000002h0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02d0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l;0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0;@3oool01P000?l0oooo0?ooo`000?l0oooo
0000o`P0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`80003o0P3oool01000
0?l0oooo0?ooo`000?l20?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`03000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000000`000?l0
oooo0?ooo`0o0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<000000P3oool30000od80oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02/0oooo0`0000050?ooo`<0003o00<0oooo0000o`3oool0?`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0:03oool3000000P0oooo00<0003o0?ooo`3oool00P000?m1
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?oo
o`030000003oool0oooo02D0oooo0`00000;0?ooo`030000o`3oool0oooo0080003o00<0oooo0000
o`3oool0?`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000T03oool00`000000oooo0?ooo`0Q0?ooo`@000004@3oool010000?l0oooo0?ooo`000?m10?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000005@3oool00`000?l0oooo0?ooo`030000od00
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000603oool010000?l0oooo
0?ooo`000?l20?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0603oool3000001h0oooo00@0003o0?ooo`3oool0003o@03oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000008@3oool010000?l0
oooo0?ooo`000?m10?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0
oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000002@0
oooo00D0003o0?ooo`3oool0oooo0000o`110?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00h0oooo0`00000X0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`10
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000002`0oooo00H0003o0?oo
o`3oool0003o0?ooo`000?m00?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000;`3oool0
10000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000000c0?ooo`80003o0`3oool20000od00oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo
0?ooo`<00000?@3oool010000?l0oooo0?ooo`000?ln0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000@03oool01@000?l0oooo0000o`3o
ool0003o03h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool2
00000900oooo0`0000130?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08`0oooo0`0000020?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0@@3oool00`000?l0
oooo0000o`030?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo
0?ooo`110?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00
000<0?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`0n0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0@`3oool01@000?l0oooo0?ooo`3o
ool0003o0440oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`140?ooo`050000o`3oool0
oooo0?ooo`000?l0@@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo04@0oooo00D0003o
0?ooo`3oool0oooo0000o`120?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3o
ool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0A@3oool0
10000?l0oooo0?ooo`000?m30?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3o
ool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0AP3oool0
0`000?l0oooo0000o`140?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0A`3oool20000
odD0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0
oooo0`00000Q0?ooo`030000003oool0oooo04L0oooo0P000?m50?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo
00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?oo
o`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3o
ool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<0
00000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?oo
o`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00
001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?oo
o`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3o
ool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo
01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`00
00270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00
603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@000002
0?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?oo
o`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<0
00000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3o
ool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000
003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103o
ool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700
oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool0
0000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool0
0`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
04L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo
0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool0
0`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
04h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo
00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo
0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo1000
00030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?
0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`04
0000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000
003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo
00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P00
00000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3o
ool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
06<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0
oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo
001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo1000
00090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?oo
o`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003o
ool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0
oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool40000
02P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0
oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo
001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<00000
0?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?oo
o`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3o
ool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?oo
o`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?oo
o`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?oo
o`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`80
0000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3o
ool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3o
ool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool0
0`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo
0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0
oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo
0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00
001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo10000020
0?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?oo
o`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000
003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3o
ool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo
0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo
03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0
oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo
1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000
002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;
0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?oo
o`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?oo
o`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?oo
o`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3o
ool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0
oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C
0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?oo
o`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61423 .70946 m
.60888 .70062 L
s
.61423 .70946 m
.60986 .73377 L
s
.60888 .70062 m
.60637 .69796 L
s
.60637 .69796 m
.6044 .69771 L
s
.6044 .69771 m
.6032 .69872 L
s
.6032 .69872 m
.60178 .70089 L
s
.60178 .70089 m
.6007 .70665 L
s
.59656 .69079 m
.59347 .70697 L
s
.60443 .72488 m
.60986 .73377 L
s
.6007 .70665 m
.60083 .71141 L
s
.594 .68809 m
.59265 .68437 L
s
.59512 .69295 m
.594 .68809 L
s
.59265 .68437 m
.59031 .6805 L
s
.59524 .69769 m
.59512 .69295 L
s
.60083 .71141 m
.60118 .71501 L
s
.6023 .71989 m
.60443 .72488 L
s
.60118 .71501 m
.6023 .71989 L
s
.58379 .67129 m
.58491 .67618 L
s
.58244 .66756 m
.58379 .67129 L
s
.58006 .66365 m
.58244 .66756 L
s
.58491 .67618 m
.58502 .68091 L
s
.57825 .66218 m
.58006 .66365 L
s
.58502 .68091 m
.58456 .68322 L
s
.57619 .66185 m
.57825 .66218 L
s
.57689 .65843 m
.5736 .67449 L
s
.58456 .68322 m
.58308 .68538 L
s
.58308 .68538 m
.58103 .68509 L
s
.57131 .64926 m
.56473 .65999 L
s
.58103 .68509 m
.5792 .68364 L
s
.5649 .63871 m
.55823 .64937 L
s
.5649 .63871 m
.56473 .65999 L
s
.5792 .68364 m
.5768 .67973 L
s
.57544 .67595 m
.57431 .67102 L
s
.5768 .67973 m
.57544 .67595 L
s
.55845 .6281 m
.55823 .64937 L
s
.55185 .60802 m
.55297 .61294 L
s
.55047 .60423 m
.55185 .60802 L
s
.54722 .59886 m
.55047 .60423 L
s
.55297 .61294 m
.55328 .61651 L
s
.55328 .61651 m
.55334 .62123 L
s
.54533 .59728 m
.54722 .59886 L
s
.55334 .62123 m
.55208 .62688 L
s
.54318 .59681 m
.54533 .59728 L
s
.54185 .59769 m
.54318 .59681 L
s
.55208 .62688 m
.5505 .62895 L
s
.5505 .62895 m
.54918 .62988 L
s
.54918 .62988 m
.54702 .62948 L
s
.54389 .61343 m
.53976 .60667 L
s
.53638 .59179 m
.53266 .60757 L
s
.53898 .61006 m
.53976 .60667 L
s
.54702 .62948 m
.54511 .62792 L
s
.53363 .58882 m
.53224 .58498 L
s
.53476 .59379 m
.53363 .58882 L
s
.53224 .58498 m
.52975 .58088 L
s
.5348 .59852 m
.53476 .59379 L
s
.54511 .62792 m
.54181 .62252 L
s
.53928 .61369 m
.53898 .61006 L
s
.54041 .61867 m
.53928 .61369 L
s
.54181 .62252 m
.54041 .61867 L
s
.5228 .57101 m
.52393 .57599 L
s
.5214 .56715 m
.5228 .57101 L
s
.51889 .563 m
.5214 .56715 L
s
.52393 .57599 m
.52395 .58072 L
s
.51693 .56135 m
.51889 .563 L
s
.52395 .58072 m
.5234 .58297 L
s
.51468 .56079 m
.51693 .56135 L
s
.51552 .55747 m
.51157 .5731 L
s
.5234 .58297 m
.52173 .58496 L
s
.52173 .58496 m
.51949 .58446 L
s
.5096 .54773 m
.50356 .57122 L
s
.50762 .54604 m
.50621 .54215 L
s
.50875 .55105 m
.50762 .54604 L
s
.50621 .54215 m
.50365 .53794 L
s
.51949 .58446 m
.51752 .58282 L
s
.50365 .53794 m
.50166 .53624 L
s
.51752 .58282 m
.51498 .57866 L
s
.49458 .51199 m
.48831 .53508 L
s
.51356 .57475 m
.51242 .56972 L
s
.50166 .53624 m
.49936 .53563 L
s
.51498 .57866 m
.51356 .57475 L
s
.49936 .53563 m
.49762 .53753 L
s
.50417 .55939 m
.50646 .55996 L
s
.49762 .53753 m
.49703 .53975 L
s
.50216 .55771 m
.50417 .55939 L
s
.48963 .51645 m
.4882 .51252 L
s
.49132 .524 m
.48963 .51645 L
s
.49703 .53975 m
.49701 .54449 L
s
.4882 .51252 m
.4856 .50824 L
s
.49958 .55349 m
.50216 .55771 L
s
.47849 .48384 m
.47905 .48635 L
s
.47731 .48348 m
.47849 .48384 L
s
.47905 .48635 m
.47787 .48599 L
s
.4856 .50824 m
.48356 .50648 L
s
.49701 .54449 m
.49815 .54955 L
s
.47787 .48599 m
.47731 .48348 L
s
.49815 .54955 m
.49958 .55349 L
s
.48356 .50648 m
.48177 .50832 L
s
.48177 .50832 m
.47869 .51934 L
s
.47602 .49248 m
.47164 .50781 L
s
.46692 .47911 m
.46805 .48418 L
s
.46547 .47512 m
.46692 .47911 L
s
.46282 .47076 m
.46547 .47512 L
s
.46805 .48418 m
.46798 .48889 L
s
.46072 .46892 m
.46282 .47076 L
s
.46798 .48889 m
.46734 .49108 L
s
.45829 .46815 m
.46072 .46892 L
s
.46734 .49108 m
.4655 .49291 L
s
.4655 .49291 m
.46308 .49219 L
s
.4527 .45573 m
.45294 .45935 L
s
.45034 .45024 m
.4527 .45573 L
s
.44765 .44581 m
.45034 .45024 L
s
.45294 .45935 m
.45138 .46004 L
s
.46308 .49219 m
.46097 .49037 L
s
.44462 .44244 m
.44765 .44581 L
s
.4392 .42059 m
.43442 .43547 L
s
.45138 .46004 m
.44925 .45817 L
s
.46097 .49037 m
.45828 .48599 L
s
.45682 .48196 m
.45568 .47684 L
s
.44305 .4431 m
.44462 .44244 L
s
.45828 .48599 m
.45682 .48196 L
s
.44925 .45817 m
.44441 .45185 L
s
.44872 .46871 m
.45029 .46801 L
s
.44441 .45185 m
.44226 .44996 L
s
.44567 .46537 m
.44872 .46871 L
s
.44226 .44996 m
.44067 .45063 L
s
.44295 .46092 m
.44567 .46537 L
s
.44067 .45063 m
.44033 .45171 L
s
.44033 .45171 m
.44056 .45537 L
s
.44056 .45537 m
.44295 .46092 L
s
.43142 .44043 m
.43269 .44085 L
s
.43269 .44085 m
.43326 .44342 L
s
.43326 .44342 m
.43199 .44301 L
s
.43199 .44301 m
.43142 .44043 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0400oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo03l0
oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`000000
oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03d0oooo
00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo03`0oooo00<0
003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo0?oo
o`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo03X0oooo00<0003o
0?ooo`3oool0G`3oool00`000000oooo0?ooo`100?ooo`<000004@3oool00`000000oooo0?ooo`0J
0?ooo`00;P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo03T0oooo00<0003o0?oo
o`3oool0G`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0
=P3oool3000001/0oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000003o
ool0oooo03D0oooo00@0003o0?ooo`3oool0oooo0P000?mM0?ooo`030000003oool0oooo03<0oooo
0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo0300oooo0`00
000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo02d0oooo0`00000U
0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0=@3oool20000o`80oooo00<0003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`0Z0?oo
o`<00000:03oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo03@0oooo00D0003o0?ooo`000?l0oooo0000o`1K0?ooo`030000003oool0oooo
02L0oooo0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo05P0
oooo00<000000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0b0?ooo`060000o`3oool0oooo0000o`3o
ool0003oFP3oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0380oooo00@0003o0?ooo`3o
ool0003oF`3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0
G03oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0<@3oool20000o`80oooo0P000?mH0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo05H0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0e0?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0a0?ooo`040000o`3oool0oooo0000oeL0oooo00<000000?ooo`3oool02P3oool40000
04L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`0`0?ooo`050000o`3oool0oooo0?ooo`000?l0EP3oool00`000000oooo0?ooo`070?oo
o`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo02l0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
0500oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0_0?ooo`040000o`3oool0oooo0000
o`<0oooo00<0003o0?ooo`3oool0D03oool010000000oooo0?ooo`3oool300000580oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0^0?oo
o`040000o`3oool0oooo0000oeH0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0;P3oool00`000?l0oooo0000o`1D0?oo
o`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo02h0oooo00D0003o0?ooo`3oool0oooo0000o`1>0?ooo`<000000P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0
oooo00<000000?ooo`3oool0<@3oool00`000?l0oooo0?ooo`190?ooo`<000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo
0?ooo`0a0?ooo`030000o`3oool0oooo04H0oooo0`0000080?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`0_0?ooo`030000o`3oool0oooo04@0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`110?ooo`<000003P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0]0?ooo`050000o`3oool0oooo0?ooo`000?l0?03o
ool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0;`3o
ool00`000?l0oooo0000o`0h0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`0^0?ooo`060000o`3oool0oooo0000o`3oool0003o<P3oool3000001P0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo
0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0;03oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`000?l0;`3oool3000001/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`0[0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0/0?ooo`<000007P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0
oooo0740oooo00<000000?ooo`3oool0:P3oool010000?l0oooo0?ooo`3oool20000obT0oooo1000
000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<00000
0?ooo`3oool0LP3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo02@0oooo0`00000U
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?oo
o`000000M03oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0240oooo0`00000X0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`03
0000003oool0oooo02`0oooo00<0003o0?ooo`3oool07P3oool3000002/0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo01`0oooo0`00000^0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool06@3o
ool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool0
0`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0:03oool0
10000?l0oooo0?ooo`3oool20000oa<0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool0:P3oool010000?l0oooo0?ooo`000?l?0?ooo`<00000=`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool0:@3oool01@000?l0oooo0?ooo`3oool0003o00/0oooo0`00000j0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`000?l0203oool3000003d0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo02L0oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`<00000@03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0
oooo07h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`020000o`040?ooo`000000
0000000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02H0oooo00H0003o0?ooo`3oool000000000
o`0000160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00
00210?ooo`030000003oool0oooo02D0oooo00@0003o000000000000003oB03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool08@3oool3000000040?ooo`000?l0oooo0000o`80oooo00<0003o0?ooo`3oool0
@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000D0oooo0P000?l20?ooo`80003oA@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08@0oooo00<000000?ooo`3oool0603oool3000000X0oooo00<0003o0?ooo`3oool00P000?m5
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000303oool01P000?l0oooo0?ooo`000?l0
oooo0000odD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000?0?ooo`040000o`3oool0
oooo0000o`80oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3
00000180oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`110?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`080?ooo`<00000603oool01@000?l0oooo0?ooo`3oool0003o04<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo00@0oooo0`00000K0?ooo`050000o`3oool0oooo0?ooo`000?l0@`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool00`00000O0?ooo`040000o`3oool0oooo0000od<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`8000008`3oool01@000?l0oooo0000o`3oool0003o0440oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08`3oool2
0000o`80oooo00<0003o0?ooo`3oool0?@3oool2000005/0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
03X0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo03D0
oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0X0?ooo`80003o<`3oool3000000X0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02P0oooo0P000?l`0?ooo`<000003P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`030000obT0oooo0`00000B0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0903oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0O0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09`3oool010000?l0oooo
0?ooo`000?l30?ooo`030000o`3oool0oooo01`0oooo0`00000N0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0oooo0080003o0`3oool00`000?l0oooo0?ooo`0H0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:P3oool20000o`<0oooo00<0003o0?ooo`3oool05@3o
ool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2
000008l0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0
oooo0180oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool03P3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`<00000<`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0;03oool01@000?l0oooo0?ooo`3oool0003o00X0oooo0`00000f0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0/0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool3000003X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02d0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?oo
o`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool20000o`030?ooo`00000000000080
0000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000030?ooo`000?l0oooo04@0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02/0oooo0`0000040?ooo`030000o`3oool0oooo04<0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02P0oooo0`0000070?ooo`040000o`3oool0oooo0000od<0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<00000
0?ooo`3oool09@3oool3000000X0oooo00@0003o0?ooo`000?l0003oA03oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q
0?ooo`@000003@3oool20000o`030?ooo`000?l0oooo04@0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01h0oooo0`00000A0?ooo`80003o00<0oooo0000o`3oool0A@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01/0oooo0`00000D0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool0@P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<0
00006@3oool00`000?l0oooo0000o`160?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3o
ool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo01D0oooo0`00000L0?ooo`80003oB03oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0140oooo1000000O0?ooo`80003oB@3oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0>0?ooo`<000008`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool30000
00D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000:`3oool00`00
0?l0oooo0?ooo`140?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000;P3oool20000odH0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000`0?ooo`040000o`3oool0oooo0000odH0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000=03oool01@000?l0oooo0?ooo`3oool0003o
04H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo1000000g0?ooo`050000o`3oool0oooo0?ooo`000?l0A`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000003X0oooo00D0003o0?ooo`3o
ool0oooo0000o`170?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0>03oool01@000?l0
oooo0?ooo`3oool0003o04P0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`0i0?ooo`06
0000o`3oool0oooo0000o`3oool0003oA`3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo
03X0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0
oooo00<000000?ooo`3oool0>`3oool01@000?l0oooo0?ooo`3oool0003o04P0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<0
00003`3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo04L0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<00000
4@3oool00`000000oooo0?ooo`100?ooo`80003oB03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003o
ool0oooo0440oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0
oooo0440oooo00<0003o0?ooo`3oool00P000?m60?ooo`030000003oool0oooo03`0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?oo
o`3oool0@03oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0AP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N
0?ooo`030000003oool0oooo0400oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?oo
o`150?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^
0?ooo`<000008@3oool00`000000oooo0?ooo`100?ooo`040000o`3oool0oooo0000o`<0oooo00<0
003o0?ooo`3oool0A03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N
0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo0400oooo00@0003o
0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<00000
0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04D0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?oo
o`<00000:`3oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0AP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`170?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
@`3oool01@000?l0oooo0?ooo`3oool0003o04X0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo
0?ooo`130?ooo`050000o`3oool0oooo0?ooo`000?l0B`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000
003oool0oooo04@0oooo00@0003o0?ooo`3oool0003oC03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo04@0oooo00@0003o0?ooo`3oool0003oC@3oool00`000000oooo0?ooo`0e0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000
003oool0oooo04D0oooo0P000?m?0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0A@3o
ool20000odl0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0
oooo04h0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool20000
04T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000
001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3o
ool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000
001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3o
ool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool20000
09L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo
0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P00
00200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2
000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0
oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K
0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3o
ool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3o
ool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0
oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo
001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?oo
o`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000
003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool40000
03D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0
oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo
001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo
00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo
1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000
001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H
0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`04
0000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`03
0000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`800000
9P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo
000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`00
0000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@00
00280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=
0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`800000
5P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool0
0`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool0
06H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo
00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo
0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo
0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`00
0000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3o
ool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo10000036
0?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`80
0000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0
oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60969 .73563 m
.60469 .72523 L
s
.60969 .73563 m
.60186 .7545 L
s
.60469 .72523 m
.60216 .72164 L
s
.60216 .72164 m
.59997 .72042 L
s
.59997 .72042 m
.5985 .72068 L
s
.5985 .72068 m
.59664 .72183 L
s
.59664 .72183 m
.59473 .72627 L
s
.59194 .71044 m
.58652 .72284 L
s
.58831 .70291 m
.58612 .69838 L
s
.58938 .7068 m
.58831 .70291 L
s
.59006 .71157 m
.58938 .7068 L
s
.58963 .71572 m
.59006 .71157 L
s
.59473 .72627 m
.59431 .73045 L
s
.59431 .73045 m
.59427 .73375 L
s
.59677 .74398 m
.60186 .7545 L
s
.57882 .68324 m
.57989 .68714 L
s
.57662 .67869 m
.57882 .68324 L
s
.57989 .68714 m
.58057 .69191 L
s
.59427 .73375 m
.59496 .73856 L
s
.57475 .6765 m
.57662 .67869 L
s
.58057 .69191 m
.58012 .69604 L
s
.59496 .73856 m
.59677 .74398 L
s
.57368 .6726 m
.56804 .68471 L
s
.57248 .67517 m
.57475 .6765 L
s
.58012 .69604 m
.57933 .69779 L
s
.56852 .66192 m
.55984 .66778 L
s
.57933 .69779 m
.5774 .6989 L
s
.56261 .64966 m
.55384 .6554 L
s
.56261 .64966 m
.55984 .66778 L
s
.55065 .61305 m
.55172 .61696 L
s
.54767 .60686 m
.55065 .61305 L
s
.55172 .61696 m
.55238 .62169 L
s
.5774 .6989 m
.57512 .69761 L
s
.54575 .60458 m
.54767 .60686 L
s
.55238 .62169 m
.55229 .62489 L
s
.55667 .63736 m
.55384 .6554 L
s
.55229 .62489 m
.55178 .62893 L
s
.54341 .60311 m
.54575 .60458 L
s
.57512 .69761 m
.57324 .69543 L
s
.56994 .6869 m
.56926 .68209 L
s
.57324 .69543 m
.57102 .69084 L
s
.55178 .62893 m
.54969 .63311 L
s
.54182 .60318 m
.54341 .60311 L
s
.57102 .69084 m
.56994 .6869 L
s
.54969 .63311 m
.54768 .63408 L
s
.53645 .59546 m
.53037 .60696 L
s
.54768 .63408 m
.54608 .63421 L
s
.53267 .58763 m
.5304 .58293 L
s
.53375 .59158 m
.53267 .58763 L
s
.54217 .61756 m
.5384 .60975 L
s
.5344 .59634 m
.53375 .59158 L
s
.53386 .60036 m
.5344 .59634 L
s
.53711 .61224 m
.5384 .60975 L
s
.54608 .63421 m
.54372 .63278 L
s
.52281 .5672 m
.52389 .57115 L
s
.52052 .56246 m
.52281 .5672 L
s
.54372 .63278 m
.54177 .6305 L
s
.537 .61546 m
.53711 .61224 L
s
.52389 .57115 m
.52453 .57591 L
s
.51855 .56009 m
.52052 .56246 L
s
.52453 .57591 m
.52397 .57991 L
s
.53766 .62027 m
.537 .61546 L
s
.54177 .6305 m
.53874 .62424 L
s
.51747 .55614 m
.51116 .56732 L
s
.51613 .55851 m
.51855 .56009 L
s
.53874 .62424 m
.53766 .62027 L
s
.52397 .57991 m
.52308 .58153 L
s
.51211 .54503 m
.50251 .56176 L
s
.49993 .50776 m
.49014 .52393 L
s
.52308 .58153 m
.52098 .58238 L
s
.50904 .53867 m
.50673 .53389 L
s
.51012 .54264 m
.50904 .53867 L
s
.51076 .54739 m
.51012 .54264 L
s
.50673 .53389 m
.50474 .53148 L
s
.50474 .53148 m
.50228 .52984 L
s
.52098 .58238 m
.51855 .58084 L
s
.48569 .47649 m
.486 .47884 L
s
.48444 .47561 m
.48569 .47649 L
s
.486 .47884 m
.48475 .47797 L
s
.50228 .52984 m
.50012 .53057 L
s
.51855 .58084 m
.51657 .57847 L
s
.48475 .47797 m
.48444 .47561 L
s
.51316 .56971 m
.51252 .56491 L
s
.51657 .57847 m
.51425 .5737 L
s
.49282 .50506 m
.49048 .50022 L
s
.4939 .50904 m
.49282 .50506 L
s
.49483 .51617 m
.4939 .50904 L
s
.51425 .5737 m
.51316 .56971 L
s
.49048 .50022 m
.48846 .49775 L
s
.50012 .53057 m
.49919 .53213 L
s
.50465 .55213 m
.50712 .55374 L
s
.48846 .49775 m
.48626 .49842 L
s
.49919 .53213 m
.49858 .5361 L
s
.50263 .54972 m
.50465 .55213 L
s
.4819 .48244 m
.47516 .49302 L
s
.49858 .5361 m
.4992 .54089 L
s
.48626 .49842 m
.48148 .50607 L
s
.5003 .5449 m
.50263 .54972 L
s
.4992 .54089 m
.5003 .5449 L
s
.47248 .46292 m
.47357 .46692 L
s
.47011 .45802 m
.47248 .46292 L
s
.47357 .46692 m
.47418 .47167 L
s
.46805 .45548 m
.47011 .45802 L
s
.47418 .47167 m
.47351 .47554 L
s
.46548 .45367 m
.46805 .45548 L
s
.47351 .47554 m
.47254 .47703 L
s
.4506 .40535 m
.44349 .41522 L
s
.46092 .44072 m
.46072 .44381 L
s
.45903 .43506 m
.46092 .44072 L
s
.47254 .47703 m
.47028 .47765 L
s
.45664 .43011 m
.45903 .43506 L
s
.45375 .42588 m
.45664 .43011 L
s
.46072 .44381 m
.45893 .44362 L
s
.45195 .42565 m
.45375 .42588 L
s
.47028 .47765 m
.46771 .47587 L
s
.45893 .44362 m
.45684 .44105 L
s
.45684 .44105 m
.45233 .4335 L
s
.46771 .47587 m
.46562 .47334 L
s
.46213 .46435 m
.46152 .45957 L
s
.46562 .47334 m
.46323 .4684 L
s
.45233 .4335 m
.45022 .43091 L
s
.46323 .4684 m
.46213 .46435 L
s
.45492 .44948 m
.45673 .44966 L
s
.45022 .43091 m
.4484 .43069 L
s
.452 .44524 m
.45492 .44948 L
s
.4484 .43069 m
.44789 .43142 L
s
.44789 .43142 m
.44768 .43453 L
s
.44959 .44025 m
.452 .44524 L
s
.44768 .43453 m
.44959 .44025 L
s
.43959 .41784 m
.44092 .4188 L
s
.44092 .4188 m
.44121 .42119 L
s
.44121 .42119 m
.43989 .42023 L
s
.43989 .42023 m
.43959 .41784 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0
oooo05P0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0M0?ooo`00;`3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0F@3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo01d0oooo000_0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`150?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0L0?ooo`00;`3oool2000004H0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?oo
o`1L0?ooo`030000003oool0oooo0580oooo0P00000M0?ooo`00;P3oool2000004P0oooo00<00000
0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0400oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0B@3oool3000000L0oooo00<000000?ooo`3oool06`3oool002h0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`120?ooo`80003oFP3oool00`000000oooo
0?ooo`160?ooo`<000002`3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?oo
o`130?ooo`<000003P3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo03l0oooo0P000?l00`3oool0003o0?ooo`1H0?ooo`030000003oool0
oooo0400oooo0`00000A0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0?P3oool01@000?l0oooo0000o`3oool0003o05P0oooo00<00000
0?ooo`3oool0?@3oool3000001@0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0m0?ooo`050000o`3oool0003o0?ooo`000?l0F03oool0
0`000000oooo0?ooo`0i0?ooo`@000005`3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo03`0oooo00H0003o0?ooo`3oool0003o0?ooo`00
0?mG0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000003oool0oooo01X0oooo000]
0?ooo`800000DP3oool00`000000oooo0?ooo`0k0?ooo`060000o`3oool0oooo0000o`3oool0003o
E`3oool00`000000oooo0?ooo`0c0?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`00;@3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool00P00
0?mG0?ooo`030000003oool0oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`1I
0?ooo`030000003oool0oooo02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0>P3oool20000oeT0oooo00<000000?oo
o`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3o
ool09`3oool3000002/0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0
903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0j0?ooo`040000o`3oool0oooo0000oe@0oooo00<000000?ooo`3oool0
8@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F@3o
ool00`000000oooo0?ooo`0i0?ooo`040000o`3oool0oooo0000oe@0oooo00<000000?ooo`3oool0
7P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`0h0?ooo`050000o`3oool0oooo0?ooo`000?l0E03oool00`000000oooo
0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?oo
o`1K0?ooo`030000003oool0oooo03L0oooo00D0003o0?ooo`3oool0oooo0000o`1D0?ooo`030000
003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`800000G@3o
ool00`000000oooo0?ooo`0g0?ooo`040000o`3oool0oooo0000oe@0oooo00<000000?ooo`3oool0
503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003o
ool0oooo03H0oooo00D0003o0?ooo`3oool0oooo0000o`1C0?ooo`030000003oool0oooo0140oooo
0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0=@3oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0oooo04h0oooo
00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0e0?ooo`<0003o103oool00`000?l0oooo0?oo
o`1=0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`1=
0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0680oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`1>0?oo
o`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo06<0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`1?0?ooo`04
0000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000
oooo0?ooo`1T0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3oool0D03oool4000005D0
oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`0d0?ooo`030000o`3oool0oooo04h0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?oo
o`1<0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0O@3oool3000000D0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?oo
o`3oool0=@3oool20000od<0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0c0?ooo`04
0000o`3oool0oooo0000ocl0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3o
ool0<P3oool01@000?l0oooo0?ooo`3oool0003o03/0oooo0`00000>0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0000o`0f0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0d0?ooo`80003o=03oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool0<`3oool20000oc40oooo0`00000H0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3oool0;@3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo02X0
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo02L0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo02@0oooo0`00
000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<00000
0?ooo`000000M03oool00`000000oooo0?ooo`1A0?ooo`<00000:03oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=0?oo
o`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@0
0000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02h0oooo0`000?lH0?ooo`<0
0000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000
003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0]0?ooo`040000
o`3oool0oooo0000oa@0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo02`0oooo00@0003o0?ooo`3oool0003o4@3oool3000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0[0?ooo`050000o`3oool0oooo0?ooo`000?l03@3oool3000003L0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo02X0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`<0
0000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000
003oool0oooo07`0oooo00<000000?ooo`3oool0:@3oool010000?l0oooo0?ooo`3oool20000o`H0
oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`00
0?l0103oool300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02P0oooo00D0003o0?ooo`3oool0
003o0?ooo`03000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02P0oooo0P000?l2000004H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<0
00000?ooo`3oool09@3oool3000000030000o`3oool0oooo04H0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0240oooo0`0000020?ooo`040000o`3oool0oooo0?ooo`80003oA03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0703oool4000000D0oooo00@0003o0?ooo`3oool0oooo0P000?m50?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`0H0?ooo`<00000203oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0
003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000l0oooo00@0003o
0?ooo`3oool0003oA03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool300000140oooo0P000?l3
0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000E0?oo
o`050000o`3oool0oooo0?ooo`000?l0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool30000
01T0oooo00@0003o0?ooo`3oool0003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool30000
01`0oooo00@0003o0?ooo`3oool0003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000O0?oo
o`040000o`3oool0oooo0000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008`3oool30000od<0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`0m0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0
>P3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0=P3o
ool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0<P3oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo0P000?l`0?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0/0?ooo`<000004P3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0Y0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool09`3oool01@000?l0oooo0?ooo`3oool0003o02@0oooo1000000J0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0080oooo0P000?lO0?ooo`<000007P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0J0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:@3oool20000o`<0oooo00<0003o0?ooo`3oool05P3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool0:@3oool20000o`<0oooo00<0003o0?ooo`3oool04`3oool3000002X0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo
0?ooo`0>0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00/0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool3000003H0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`050000
o`3oool0oooo0?ooo`000?l0100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0]0?ooo`040000
o`0000000000000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000000`000?l0oooo
0?ooo`170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000001P3oool00`000?l0oooo0?oo
o`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>
0?ooo`030000003oool0oooo02D0oooo0`0000090?ooo`030000o`3oool0oooo04H0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?oo
o`3oool08@3oool4000000`0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool07P3oool300000100oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo01/0oooo0`00000B0?ooo`050000o`3oool0oooo0?ooo`000?l0A`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<000005@3oool00`000?l0
oooo0?ooo`020000odP0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`00
6P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
5@3oool3000001P0oooo0`000?l00`3oool0003o0?ooo`180?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool04@3oool4000001/0oooo00D0003o0?ooo`3oool0oooo0000o`1:0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000R0?ooo`030000o`3o
ool0oooo04X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<000009@3oool0
10000?l0oooo0?ooo`000?m90?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000:03oool3
0000od/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000[0?ooo`030000o`3oool0oooo
04`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000003L0oooo00<0003o0?ooo`3o
ool0B@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000
T03oool3000003T0oooo0P000?m;0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0=`3o
ool00`000?l0oooo0000o`1;0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0=P3oool0
10000?l0oooo0?ooo`000?m<0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0=P3oool0
1@000?l0oooo0?ooo`3oool0003o04`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0f
0?ooo`050000o`3oool0oooo0?ooo`000?l0C@3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0
oooo03H0oooo00D0003o0?ooo`3oool0oooo0000o`1>0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool0>03oool010000?l0oooo0?ooo`000?m>0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<00000
0?ooo`3oool0>@3oool00`000?l0oooo0000o`1?0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?oo
o`3oool0>@3oool00`000?l0oooo0000o`1@0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3o
ool0>P3oool010000?l0oooo0?ooo`000?m?0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`1=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`0n0?ooo`030000
o`3oool0oooo04d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3o
ool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`0o0?ooo`030000o`3o
ool0oooo04d0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0o0?ooo`80003oC`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo03l0oooo0P000?m@0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0
oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo
00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`030000odl0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool0
0`000000oooo0?ooo`0n0?ooo`060000o`3oool0oooo0000o`3oool0003oD03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00
000k0?ooo`030000003oool0oooo0440oooo00@0003o0?ooo`3oool0003oD03oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1>0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`100?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0@03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000
B`3oool00`000000oooo0?ooo`110?ooo`050000o`3oool0oooo0?ooo`000?l0D`3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo
0`00001>0?ooo`030000003oool0oooo0440oooo00D0003o0?ooo`3oool0oooo0000o`1D0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
?`3oool400000540oooo00<000000?ooo`3oool0@@3oool010000?l0oooo0?ooo`000?mF0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
?03oool3000005D0oooo00<000000?ooo`3oool0@@3oool010000?l0oooo0?ooo`000?mF0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0000o`1G0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3o
ool3000005/0oooo00<000000?ooo`3oool0@P3oool20000oeT0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool0
0`000000oooo0?ooo`130?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo
0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?oo
o`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U
0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000
M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0
oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo
0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?oo
o`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?oo
o`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@00
00020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3o
ool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<00000
0?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`800000
2@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo
00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo
000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?oo
o`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`04
0000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3o
ool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000
M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0
oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool20000
0700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3o
ool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0
a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3o
ool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3o
ool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0
oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3o
ool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3o
ool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo
0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0
oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`00
0000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000
oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo
100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?oo
o`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?oo
o`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`03
0000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500
oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo
0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3o
ool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool0
06@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0
oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo
100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z
0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000
003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003o
ool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4
000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool50000
02`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340
oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<0
00000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=
0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?oo
o`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@000012
0?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D
0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B
0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?oo
o`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000
:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool00000
9P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3o
ool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0
oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000
oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo
1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo1000
00200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo10000024
0?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`03
0000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`800000
6@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0
oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0
oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo
03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0
oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo
1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000
000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S
0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i
0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<00000
0?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool200000003
0?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`800000
1@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003o
ool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00
003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`000002
0?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60145 .75603 m
.59702 .74442 L
s
.60145 .75603 m
.59032 .76843 L
s
.59702 .74442 m
.59459 .74001 L
s
.59459 .74001 m
.59226 .73782 L
s
.59226 .73782 m
.59056 .73729 L
s
.59056 .73729 m
.58832 .73734 L
s
.58832 .73734 m
.58563 .74021 L
s
.58439 .72506 m
.57677 .73303 L
s
.58119 .7167 m
.57927 .71167 L
s
.58193 .7206 m
.58119 .7167 L
s
.58213 .72508 m
.58193 .7206 L
s
.54977 .62062 m
.55049 .62448 L
s
.54719 .61387 m
.54977 .62062 L
s
.54534 .61098 m
.54719 .61387 L
s
.55049 .62448 m
.55065 .62884 L
s
.57286 .69489 m
.5736 .6988 L
s
.57094 .68985 m
.57286 .69489 L
s
.5691 .68703 m
.57094 .68985 L
s
.58114 .72846 m
.58213 .72508 L
s
.5736 .6988 m
.57379 .70325 L
s
.54291 .60856 m
.54534 .61098 L
s
.56837 .68313 m
.56056 .69068 L
s
.55065 .62884 m
.55017 .63152 L
s
.56671 .68473 m
.5691 .68703 L
s
.56387 .67135 m
.55341 .67197 L
s
.58563 .74021 m
.58466 .74362 L
s
.57379 .70325 m
.57278 .70659 L
s
.55871 .65786 m
.54819 .65834 L
s
.55871 .65786 m
.55341 .67197 L
s
.54111 .60782 m
.54291 .60856 L
s
.55017 .63152 m
.54911 .63471 L
s
.55355 .64435 m
.54819 .65834 L
s
.58466 .74362 m
.58422 .74647 L
s
.57278 .70659 m
.57168 .70769 L
s
.54911 .63471 m
.54626 .63722 L
s
.58422 .74647 m
.58442 .751 L
s
.57168 .70769 m
.56937 .70767 L
s
.53607 .59859 m
.52789 .6053 L
s
.58581 .75665 m
.59032 .76843 L
s
.50635 .50685 m
.49353 .51552 L
s
.58442 .751 m
.58581 .75665 L
s
.53282 .59009 m
.53087 .58498 L
s
.53354 .59396 m
.53282 .59009 L
s
.53368 .59831 m
.53354 .59396 L
s
.56937 .70767 m
.56697 .7054 L
s
.49453 .47391 m
.49457 .47601 L
s
.49326 .47258 m
.49453 .47391 L
s
.52436 .56794 m
.52508 .5718 L
s
.52241 .56282 m
.52436 .56794 L
s
.54626 .63722 m
.54389 .63703 L
s
.52051 .55985 m
.52241 .56282 L
s
.49457 .47601 m
.49331 .47468 L
s
.53259 .60145 m
.53368 .59831 L
s
.52508 .5718 m
.52521 .57613 L
s
.49331 .47468 m
.49326 .47258 L
s
.5198 .55598 m
.51142 .56226 L
s
.56243 .69353 m
.56225 .68905 L
s
.51802 .55732 m
.52051 .55985 L
s
.53976 .6202 m
.5365 .61168 L
s
.56697 .7054 m
.56511 .70256 L
s
.51522 .54401 m
.50251 .5533 L
s
.52521 .57613 m
.52409 .57923 L
s
.53476 .61314 m
.5365 .61168 L
s
.51261 .53716 m
.51064 .53202 L
s
.51332 .54102 m
.51261 .53716 L
s
.56316 .69747 m
.56243 .69353 L
s
.51064 .53202 m
.50873 .52902 L
s
.56511 .70256 m
.56316 .69747 L
s
.51343 .54532 m
.51332 .54102 L
s
.54389 .63703 m
.54208 .63633 L
s
.50873 .52902 m
.50621 .52643 L
s
.52409 .57923 m
.52291 .58015 L
s
.53424 .61583 m
.53476 .61314 L
s
.49883 .50111 m
.49686 .49595 L
s
.49954 .50496 m
.49883 .50111 L
s
.54208 .63633 m
.53962 .63392 L
s
.49686 .49595 m
.49493 .4929 L
s
.49969 .51136 m
.49954 .50496 L
s
.50621 .52643 m
.50374 .52598 L
s
.46495 .39839 m
.45596 .40303 L
s
.52291 .58015 m
.52047 .57983 L
s
.49493 .4929 m
.49243 .49238 L
s
.53438 .62024 m
.53424 .61583 L
s
.48962 .47699 m
.48088 .48246 L
s
.53962 .63392 m
.53773 .63101 L
s
.53511 .62416 m
.53438 .62024 L
s
.53773 .63101 m
.53511 .62416 L
s
.4817 .45625 m
.4824 .46009 L
s
.47971 .45106 m
.4817 .45625 L
s
.50374 .52598 m
.50252 .52683 L
s
.47776 .44796 m
.47971 .45106 L
s
.4824 .46009 m
.48247 .46431 L
s
.52047 .57983 m
.51796 .57732 L
s
.49243 .49238 m
.48622 .4964 L
s
.47518 .44523 m
.47776 .44796 L
s
.50252 .52683 m
.50135 .52984 L
s
.48247 .46431 m
.48126 .46718 L
s
.47044 .42679 m
.4718 .43235 L
s
.46845 .42157 m
.47044 .42679 L
s
.51335 .56526 m
.51323 .5609 L
s
.46582 .4167 m
.46845 .42157 L
s
.4718 .43235 m
.4712 .4348 L
s
.51796 .57732 m
.51604 .57433 L
s
.50608 .54627 m
.50862 .54884 L
s
.46388 .41565 m
.46582 .4167 L
s
.51406 .56916 m
.51335 .56526 L
s
.51604 .57433 m
.51406 .56916 L
s
.4712 .4348 m
.46926 .43377 L
s
.50135 .52984 m
.50145 .53416 L
s
.48126 .46718 m
.48 .46794 L
s
.50415 .54325 m
.50608 .54627 L
s
.50145 .53416 m
.50216 .53806 L
s
.46926 .43377 m
.46729 .43064 L
s
.50216 .53806 m
.50415 .54325 L
s
.48 .46794 m
.47744 .46735 L
s
.46729 .43064 m
.46331 .42227 L
s
.46331 .42227 m
.46133 .41912 L
s
.47744 .46735 m
.47484 .46463 L
s
.46133 .41912 m
.45937 .41807 L
s
.47016 .4524 m
.4701 .44816 L
s
.47484 .46463 m
.47287 .46152 L
s
.46413 .43665 m
.46609 .43768 L
s
.45937 .41807 m
.45872 .41841 L
s
.47086 .45627 m
.47016 .4524 L
s
.47287 .46152 m
.47086 .45627 L
s
.45872 .41841 m
.4581 .42087 L
s
.46148 .43175 m
.46413 .43665 L
s
.4581 .42087 m
.45946 .42648 L
s
.45946 .42648 m
.46148 .43175 L
s
.45137 .40329 m
.4527 .40471 L
s
.4527 .40471 m
.45272 .40681 L
s
.45272 .40681 m
.45139 .40539 L
s
.45139 .40539 m
.45137 .40329 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1@0?ooo`80003o
E@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01l0oooo000`0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0B`3oool010000?l0oooo0000o`000?mG0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool07P3oool00300oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`1:0?ooo`80003oF@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo01d0oooo000_0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0BP3oool0
0`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool0
02l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo
0P0000160?ooo`030000003oool0oooo04/0oooo0P000?mE0?ooo`030000003oool0oooo0580oooo
0P00000M0?ooo`00;P3oool2000004P0oooo00<000000?ooo`3oool0B03oool20000o`030?ooo`00
0?l0oooo05@0oooo00<000000?ooo`3oool0C`3oool3000000030?ooo`000000oooo01`0oooo000_
0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0A`3oool20000o`80oooo00<0003o
0?ooo`3oool0DP3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`000000oooo0?ooo`0K
0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04H0oooo00D0003o0?oo
o`000?l0oooo0000o`1D0?ooo`030000003oool0oooo04T0oooo0`0000070?ooo`030000003oool0
oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0A@3oool01@00
0?l0oooo0000o`3oool0003o05@0oooo00<000000?ooo`3oool0AP3oool3000000/0oooo00<00000
0?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`140?oo
o`030000o`3oool0oooo0080003oE03oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`00
0000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo04@0
oooo00D0003o0?ooo`000?l0oooo0000o`1C0?ooo`030000003oool0oooo0400oooo0`00000A0?oo
o`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0@`3oool00`000?l0oooo0?ooo`020000oe<0oooo00<000000?ooo`3oool0?@3oool3000001@0
oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`130?ooo`80003oE@3oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo09T0oooo00<0
00000?ooo`3oool0=P3oool3000001/0oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<`3oool3000001h0oooo00<00000
0?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`140?oo
o`030000o`3oool0oooo0500oooo00<000000?ooo`3oool0<03oool300000240oooo00<000000?oo
o`3oool06P3oool002d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`110?ooo`04
0000o`3oool0oooo0000oe40oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?oo
o`3oool06@3oool002d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`100?ooo`05
0000o`3oool0oooo0?ooo`000?l0D03oool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`00
0000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03l0
oooo00D0003o0?ooo`3oool0oooo0000o`1@0?ooo`030000003oool0oooo02L0oooo0`00000[0?oo
o`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool0?P3oool01@000?l0oooo0?ooo`3oool0003o0500oooo00<000000?ooo`3oool0903oool30000
02h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0m0?ooo`050000o`3oool0oooo0?ooo`000?l0D03oool00`000000oooo0?ooo`0Q0?oo
o`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo03d0oooo00D0003o0?ooo`3oool0oooo0000o`1?0?ooo`030000003oool0oooo
01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0
oooo00<000000?ooo`3oool0?@3oool010000?l0oooo0?ooo`000?m@0?ooo`030000003oool0oooo
01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0
oooo00<000000?ooo`3oool0?@3oool20000oe40oooo00<000000?ooo`3oool05`3oool3000003/0
oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo03d0oooo
00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0?oo
o`1:0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`1:
0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0000o`1<0?oo
o`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0>P3oool20000odl0oooo00<000000?ooo`3o
ool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0
103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`290?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo
0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo08P0oooo1000
001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0Q@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0h0?ooo`80003oA`3oool300000080oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`03
0000003oool0oooo03D0oooo0P000?l20?ooo`030000o`3oool0oooo0440oooo0`0000050?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000
003oool0oooo03T0oooo00<0003o0?ooo`3oool0?P3oool3000000P0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo03T0oooo00<0003o0?ooo`3oool0>P3oool3000000/0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo03L0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03L0oooo00@0003o0?ooo`3oool0003o<`3o
ool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0=P3o
ool30000oc40oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo03@0oooo0P000?l`0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo02d0oooo0`00000K0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0GP3oool3000001h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
05T0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1E0?ooo`<000009@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo
00<000000?ooo`3oool0<P3oool20000oad0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo0300oooo00@0
003o0?ooo`3oool0003o6@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`0_0?ooo`040000o`3oool0oooo0000oaH0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo02h0oooo00@0003o0?ooo`3oool0003o4`3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0;@3oool01@000?l0oooo0?oo
o`3oool0003o00l0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;03o
ool01@000?l0oooo0?ooo`3oool0003o00`0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`0[0?ooo`050000o`3oool0oooo0?ooo`000?l02@3oool3000003X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo02/0oooo00<0003o0?ooo`3oool00P000?l50?ooo`<00000?@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0:`3oool30000o`<0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0Y0?oo
o`<0003o00@0oooo0000000000000000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo00000002000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000D0oooo00<0003o0?ooo`3o
ool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000L0oooo00<0003o0?ooo`3oool0
@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000P0oooo0P000?l00`3oool0003o0?oo
o`130?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000303oool01@000?l0oooo0?ooo`3o
ool0003o04<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000?0?ooo`050000o`3oool0
oooo0?ooo`000?l0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001<0oooo00@0003o
0?ooo`3oool0003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001H0oooo00D0003o
0?ooo`3oool0oooo0000o`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000006@3oool0
1@000?l0oooo0?ooo`3oool0003o0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000M
0?ooo`040000o`3oool0oooo0000od80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008@3oool2
0000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03d0
oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`0j0?ooo`<000000P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0e0?ooo`@000001P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`0b0?ooo`<000002P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`0_0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0:03oool20000obd0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`80003o
:`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool09P3o
ool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0903oool3
000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0703oool30000
0280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02T0oooo00@0003o0?ooo`3oool0003o6P3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool0:03oool20000o`<0oooo00<0003o0?ooo`3oool0503oool3000002X0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo
0?ooo`0@0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0000
o`030?ooo`030000o`3oool0oooo00`0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool3000003H0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?oo
o`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`0000000`0000120?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0Z0?ooo`040000o`3oool0oooo0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3o
ool3000000030?ooo`000?l0oooo04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`000002
0?ooo`80003oBP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?oo
o`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@0
00002`3oool00`000?l0oooo0?ooo`180?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000
3`3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3o
ool300000140oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0H0?ooo`<00000503oool00`000?l0oooo0?ooo`1;0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000G0?ooo`030000o`3oool0
oooo04`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool20000
00L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@000006@3oool00`00
0?l0oooo0?ooo`020000od`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000001d0oooo0`000?l00`3oool0003o0?ooo`1<0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool02`3oool3000002<0oooo00<0003o0?ooo`3oool0C03oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0203oool3000002H0oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0103oool4000002T0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?oo
o`3oool0oooo0`00000/0?ooo`030000o`3oool0oooo0080003oCP3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000002l0oooo0`000?mA0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0=@3oool2
0000oe00oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0e0?ooo`80003oD@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0
oooo0`00000?0?ooo`030000003oool0oooo03@0oooo00@0003o0?ooo`3oool0003oD@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0
oooo0`00000A0?ooo`030000003oool0oooo03@0oooo0P000?l20?ooo`030000o`3oool0oooo04l0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`0e0?ooo`040000o`3oool0oooo0000oe80
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`0e0?ooo`040000o`3oool0oooo0000oe<0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`0e0?ooo`050000o`3oool0oooo0?ooo`00
0?l0D`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo03H0oooo00@0003o0?ooo`3oool0
003oE03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0000o`1E0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3o
ool4000002@0oooo00<000000?ooo`3oool0=`3oool20000oeH0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0>`3oool00`00
0?l0oooo0?ooo`1C0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0?03oool00`000?l0
oooo0?ooo`1C0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0?03oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`1E
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0?03oool20000oeL0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<0
0000?P3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000
@@3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo05P0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3o
ool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0
oooo03h0oooo0`000?mG0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0?@3oool01@00
0?l0oooo0?ooo`3oool0003o05L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`0m0?oo
o`050000o`3oool0oooo0?ooo`000?l0F03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo
03d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0
oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05H0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo03d0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<00000
0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05P0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?oo
o`@00000H@3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0FP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo03h0oooo00@0003o0?ooo`3o
ool0003oG@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo03l0oooo00@0003o0?ooo`3o
ool0003oGP3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0400oooo0P000?mP0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03o
ool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000
oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo1000
00200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`03
0000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00
603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3o
ool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?oo
o`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000
S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
1`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0
oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool50000
0080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000
003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?oo
o`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03o
ool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3o
ool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0
oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo
000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool0
0`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool0
03X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003o
ool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool0
10000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`00
0000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0
oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?oo
o`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`00
0000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0
oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<0
00000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo0014
0?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00
000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J
0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02
0?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`03
0000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003o
ool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool2
00000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M
0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo00000003
0?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo
0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E
0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D0
00003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool20000
03l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0
oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo
0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z
0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?oo
o`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00
J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03o
ool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000
003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003o
ool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000
C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03o
ool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool0
0880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000
oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000
oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo
00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O
0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?oo
o`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03o
ool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool0
09<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo
00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<0
00000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<00000
0?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?oo
o`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`03
0000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000
003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool0
8`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`800000
2P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000
000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T
0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool0
0:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0
oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`00
00002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00
Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48147 .3996 m
.47108 .39907 L
s
.50457 .47609 m
.50436 .47786 L
s
.50334 .47437 m
.50457 .47609 L
s
.50313 .47613 m
.50334 .47437 L
s
.50436 .47786 m
.50313 .47613 L
s
.51354 .50926 m
.49833 .51018 L
s
.48243 .42028 m
.48396 .42552 L
s
.48016 .41501 m
.48243 .42028 L
s
.48396 .42552 m
.48475 .43074 L
s
.54581 .61959 m
.54787 .62662 L
s
.54409 .6162 m
.54581 .61959 L
s
.47816 .41321 m
.48016 .41501 L
s
.54787 .62662 m
.54821 .63027 L
s
.49111 .44999 m
.49265 .45524 L
s
.48936 .44649 m
.49111 .44999 L
s
.49265 .45524 m
.49294 .45874 L
s
.48475 .43074 m
.48379 .43247 L
s
.54167 .61293 m
.54409 .6162 L
s
.54821 .63027 m
.54785 .63406 L
s
.48686 .44298 m
.48936 .44649 L
s
.49879 .47625 m
.4885 .47652 L
s
.49294 .45874 m
.4925 .46226 L
s
.50442 .49553 m
.50267 .49205 L
s
.50596 .50079 m
.50442 .49553 L
s
.50626 .50434 m
.50596 .50079 L
s
.53977 .61141 m
.54167 .61293 L
s
.48379 .43247 m
.4818 .43068 L
s
.50267 .49205 m
.49998 .49038 L
s
.54785 .63406 m
.54698 .6361 L
s
.50563 .50974 m
.50626 .50434 L
s
.5152 .53239 m
.51345 .52894 L
s
.51674 .53766 m
.5152 .53239 L
s
.51705 .54125 m
.51674 .53766 L
s
.4925 .46226 m
.49081 .46405 L
s
.5188 .5447 m
.50357 .54619 L
s
.51345 .52894 m
.51099 .52553 L
s
.5224 .55701 m
.51233 .55813 L
s
.4818 .43068 m
.48003 .42716 L
s
.52445 .56405 m
.526 .56933 L
s
.52271 .56061 m
.52445 .56405 L
s
.51665 .54491 m
.51705 .54125 L
s
.526 .56933 m
.52632 .57295 L
s
.58604 .75716 m
.58382 .75207 L
s
.58967 .76955 m
.58604 .75716 L
s
.54698 .6361 m
.54542 .63828 L
s
.58967 .76955 m
.57555 .77463 L
s
.48003 .42716 m
.47672 .41836 L
s
.53269 .59224 m
.53115 .58695 L
s
.52026 .55725 m
.52271 .56061 L
s
.53302 .59588 m
.53269 .59224 L
s
.58382 .75207 m
.58145 .74897 L
s
.49998 .49038 m
.49264 .49068 L
s
.52632 .57295 m
.52593 .57666 L
s
.53527 .60106 m
.52533 .60265 L
s
.47672 .41836 m
.47495 .41483 L
s
.51099 .52553 m
.50831 .52393 L
s
.53264 .59963 m
.53302 .59588 L
s
.49081 .46405 m
.48933 .46407 L
s
.47495 .41483 m
.47294 .41302 L
s
.58145 .74897 m
.57959 .74764 L
s
.54921 .64875 m
.5415 .658 L
s
.52593 .57666 m
.52431 .57871 L
s
.55335 .66291 m
.5415 .658 L
s
.55335 .66291 m
.54568 .67231 L
s
.54542 .63828 m
.54192 .63899 L
s
.48933 .46407 m
.4866 .46233 L
s
.55749 .67708 m
.54568 .67231 L
s
.47294 .41302 m
.47218 .41299 L
s
.53104 .60174 m
.53264 .59963 L
s
.50831 .52393 m
.50685 .52404 L
s
.56112 .68949 m
.55143 .69201 L
s
.57959 .74764 m
.57706 .74653 L
s
.56319 .69658 m
.56475 .7019 L
s
.56147 .69321 m
.56319 .69658 L
s
.56475 .7019 m
.5651 .70564 L
s
.47218 .41299 m
.47119 .41469 L
s
.46605 .39707 m
.46732 .39887 L
s
.46732 .39887 m
.46708 .4006 L
s
.57149 .72498 m
.56994 .71965 L
s
.55906 .69002 m
.56147 .69321 L
s
.47583 .43056 m
.47784 .43236 L
s
.57186 .72874 m
.57149 .72498 L
s
.5651 .70564 m
.56478 .70958 L
s
.57409 .73386 m
.56453 .73686 L
s
.48047 .44645 m
.48093 .44293 L
s
.50685 .52404 m
.50519 .52598 L
s
.52431 .57871 m
.52288 .57891 L
s
.4658 .3988 m
.46605 .39707 L
s
.46708 .4006 m
.4658 .3988 L
s
.4866 .46233 m
.48408 .45882 L
s
.57154 .73272 m
.57186 .72874 L
s
.47119 .41469 m
.47198 .41996 L
s
.53674 .62124 m
.53415 .61237 L
s
.53202 .61274 m
.53415 .61237 L
s
.57706 .74653 m
.57367 .74764 L
s
.47353 .42525 m
.47583 .43056 L
s
.56478 .70958 m
.56324 .71195 L
s
.52288 .57891 m
.52021 .57742 L
s
.48075 .44998 m
.48047 .44645 L
s
.47198 .41996 m
.47353 .42525 L
s
.54192 .63899 m
.53929 .63763 L
s
.48408 .45882 m
.4823 .45529 L
s
.57002 .73514 m
.57154 .73272 L
s
.50519 .52598 m
.50476 .52964 L
s
.4823 .45529 m
.48075 .44998 L
s
.50839 .54207 m
.51088 .54547 L
s
.5141 .56161 m
.51451 .55789 L
s
.53112 .61476 m
.53202 .61274 L
s
.52021 .57742 m
.51773 .57405 L
s
.56324 .71195 m
.56186 .71234 L
s
.50476 .52964 m
.50507 .53325 L
s
.53929 .63763 m
.53736 .63613 L
s
.50662 .53858 m
.50839 .54207 L
s
.50507 .53325 m
.50662 .53858 L
s
.57367 .74764 m
.57215 .75011 L
s
.53073 .61857 m
.53112 .61476 L
s
.51441 .56525 m
.5141 .56161 L
s
.51773 .57405 m
.51597 .57058 L
s
.56186 .71234 m
.55927 .71114 L
s
.53736 .63613 m
.5349 .63284 L
s
.51597 .57058 m
.51441 .56525 L
s
.53106 .62227 m
.53073 .61857 L
s
.5349 .63284 m
.53315 .62941 L
s
.55317 .69541 m
.55352 .69147 L
s
.57215 .75011 m
.57131 .75235 L
s
.53315 .62941 m
.53106 .62227 L
s
.55927 .71114 m
.55684 .70795 L
s
.55352 .69918 m
.55317 .69541 L
s
.57131 .75235 m
.57099 .7564 L
s
.55684 .70795 m
.55509 .70456 L
s
.55509 .70456 m
.55352 .69918 L
s
.57099 .7564 m
.57188 .76203 L
s
.57188 .76203 m
.57555 .77463 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0O0?ooo`00<03oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo0580oooo00<0003o0?ooo`000?l00`000?m?0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3oool00300oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1?0?ooo`030000
o`3oool0003o0500oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0L0?ooo`00;`3o
ool2000004H0oooo00<000000?ooo`3oool0CP3oool20000o`030?ooo`000?l0oooo04l0oooo00<0
00000?ooo`3oool0DP3oool2000001d0oooo000^0?ooo`800000B03oool00`000000oooo0?ooo`1=
0?ooo`040000o`3oool0003o0000oe00oooo00<000000?ooo`3oool0C`3oool3000000030?ooo`00
0000oooo01`0oooo000_0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0C03oool0
1@000?l0oooo0000o`3oool0003o04l0oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<0
00000?ooo`3oool06`3oool002l0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1;
0?ooo`030000o`3oool0oooo0080003oC`3oool00`000000oooo0?ooo`190?ooo`<000001`3oool0
0`000000oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
04X0oooo00<0003o0?ooo`3oool00P000?m?0?ooo`030000003oool0oooo04H0oooo0`00000;0?oo
o`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0B@3oool00`000?l0oooo0?ooo`020000odl0oooo00<000000?ooo`3oool0@`3oool3000000h0
oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`190?ooo`80003o00<0oooo0000o`000?l0CP3oool00`000000oooo0?ooo`100?ooo`<00000
4@3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo00<000000?ooo`3oool06P3o
ool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo03T0oooo1000000G0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0f0?ooo`<000006`3oool00`00
0000oooo0?ooo`0J0?ooo`00;@3oool200000580oooo00<000000?ooo`3oool0A`3oool00`000?l0
oooo0000o`1>0?ooo`030000003oool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0
oooo000]0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo
0000o`1>0?ooo`030000003oool0oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo
000]0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0A@3oool010000?l0oooo0?oo
o`000?m=0?ooo`030000003oool0oooo02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo
000]0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0A03oool01@000?l0oooo0?oo
o`3oool0003o04`0oooo00<000000?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool0
6@3oool002d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`130?ooo`050000o`3o
ool0oooo0?ooo`000?l0C03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo04<0oooo00D0
003o0?ooo`3oool0oooo0000o`1;0?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000
003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0@P3o
ool01@000?l0oooo0?ooo`3oool0003o04/0oooo00<000000?ooo`3oool08@3oool300000340oooo
00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?oo
o`120?ooo`030000o`3oool0003o04`0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<0
00000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`12
0?ooo`80003oC@3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I
0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3o
ool0603oool002/0oooo0P00001O0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
4@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo04H0oooo00<000000?ooo`3oool03P3o
ool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool0
0`000000oooo0?ooo`0m0?ooo`L0003oB03oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool0
0`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0
oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo
00<000000?ooo`3oool0R@3oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3o
ool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`280?ooo`@00000
E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo03X0oooo0`000?m80?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0@P3oool3
00000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`00
0000oooo0000001X0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0?P3oool30000
00D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0
oooo00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`0k0?ooo`<00000203oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0?03oool00`000?l0oooo0?ooo`0g0?ooo`<000002`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?oo
o`1Z0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool0=03oool3000000h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?oo
o`0b0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?oo
o`0f0?ooo`H0003o;P3oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0IP3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0HP3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1N
0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?oo
o`030000003oool0oooo0740oooo00<000000?ooo`3oool0F@3oool400000240oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo03@0oooo00<0003o0?ooo`3oool07P3oool3000002D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000
003oool0oooo0380oooo0`000?lL0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0a0?ooo`040000o`3o
ool0oooo0000oaP0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<03o
ool010000?l0oooo0?ooo`000?lE0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`0_0?ooo`050000o`3oool0oooo0?ooo`000?l04@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0;P3oool01@000?l0oooo0?oo
o`3oool0003o00h0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0;P3o
ool01@000?l0oooo0?ooo`3oool0003o00X0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`0]0?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool3000003X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo02`0oooo00<0003o0?ooo`000?l00P000?l40?ooo`<00000?@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0:P3oool30000o`@0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?oo
o`<00000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000004H0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool0
9@3oool3000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`0000050?ooo`D0003o@P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`3oool0703oool4000000T0oooo00@0003o0?ooo`3oool0003o@`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08@0oooo00<000000?ooo`3oool0603oool3000000d0oooo00@0003o0?ooo`3oool0003o@`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0503oool300000100oooo00@0003o0?ooo`3oool0003o@`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000001<0oooo00D0003o0?ooo`3oool0oooo0000
o`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000005P3oool01@000?l0oooo0?ooo`3o
ool0003o0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000J0?ooo`040000o`3oool0
oooo0000od80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000N0?ooo`030000o`3oool0
003o0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool00`000?l0oooo0?ooo`110?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool2000008d0oooo00<000000?ooo`3oool0I`3oool2000005/0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`030000o`3o
ool0oooo03X0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo03H0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
03<0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo02l0
oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02d0oooo
0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`80003o:`3oool3000001H0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02D0oooo0`000?lX0?ooo`@000006P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0003o01`0oooo0`00000V0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003o
ool0oooo02L0oooo0P000?l20?ooo`030000o`3oool0oooo01H0oooo0`00000Z0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0W0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0A0?ooo`@00000;P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo
00h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0003o0080
oooo00<0003o0?ooo`3oool02`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`<00000>P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo0`00
000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo
0080oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`050000o`00000000000000
00000?l0B@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000<0003oB`3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo
000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<000004@3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01P0oooo0`00000C0?ooo`030000o`3oool0oooo04`0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000001D0oooo00<0003o0?ooo`3o
ool0CP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000H0?ooo`030000
o`3oool0oooo04l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3o
ool3000001/0oooo0P000?mB0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3
00000200oooo0`000?m?0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool0
0200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000903oool00`00
0?l0oooo0?ooo`1?0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000009P3oool00`000?l0
oooo0?ooo`1A0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000002X0oooo00<0003o0?ooo`3o
ool0DP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000
T@3oool4000002`0oooo0P000?mE0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo0P00002@0?ooo`<00000<@3oool20000oe<0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`0a0?ooo`80003oDP3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000
oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo0380oooo0P00
0?mE0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0<03oool40000oeH0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?oo
o`@00000503oool00`000000oooo0?ooo`0a0?ooo`040000o`3oool0oooo0000oeH0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?oo
o`<00000603oool00`000000oooo0?ooo`0a0?ooo`050000o`3oool0oooo0?ooo`000?l0EP3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo
07<0oooo0`00000K0?ooo`030000003oool0oooo0340oooo00D0003o0?ooo`3oool0oooo0000o`1G
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0<@3oool01@000?l0oooo0?ooo`3oool0
003o05P0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool30000
06h0oooo0`00000Q0?ooo`030000003oool0oooo0380oooo00D0003o0?ooo`3oool0oooo0000o`1G
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0000o`1I0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0000o`1J0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<000000?ooo`3oool0=03oool20000oe/0oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool0F@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0
oooo0`00000h0?ooo`030000003oool0oooo03L0oooo00<0003o0?ooo`3oool0FP3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo
0`00000k0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo10000011
0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?oo
o`030000003oool0oooo03L0oooo0`000?mM0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`0e0?ooo`<0
003oH03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo03T0oooo10000?mN0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0
oooo00<000000?ooo`3oool0>03oool01@000?l0oooo0?ooo`3oool0003o05l0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<0
0000F`3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0G@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0>03o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool0
0`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0G`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02X0oooo0`00001W0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`1O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0>@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo03X0oooo
00<0003o0?ooo`3oool00P3oool20000of80oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?oo
o`0j0?ooo`030000o`3oool0003o0080003oI@3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo03X0oooo0P000?mX0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0
oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo
0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`000024
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000
003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000
103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2
000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo
0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`80
0000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003o
ool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3
000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P000000
0`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3o
ool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo
00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
04/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0013
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<00000
0?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<00000
4@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3o
ool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0
oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@00000
0?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`00
0000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000
oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?oo
o`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`03
0000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0
b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3o
ool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4
000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700
oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo
0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?oo
o`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3o
ool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0
W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool00000
3`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000
B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000
003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003o
ool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool40000
05d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool40000
0640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0
oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P000003
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?oo
o`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?oo
o`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003o
ool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0
oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool50000
0940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0
oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<0
00000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<
0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`
0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?oo
o`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3o
ool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D0
0000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`800000
2`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool00000
8`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03o
ool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool50000
0<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool0
00001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000
g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103o
ool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.49939 .40856 m
.48809 .40312 L
s
.49789 .42597 m
.49892 .43102 L
s
.49605 .42056 m
.49789 .42597 L
s
.49409 .41811 m
.49605 .42056 L
s
.49892 .43102 m
.49915 .4357 L
s
.51536 .48281 m
.51491 .48417 L
s
.51422 .48078 m
.51536 .48281 L
s
.51377 .48214 m
.51422 .48078 L
s
.51491 .48417 m
.51377 .48214 L
s
.49915 .4357 m
.49788 .43665 L
s
.50376 .45465 m
.5048 .45973 L
s
.50226 .45091 m
.50376 .45465 L
s
.49788 .43665 m
.49591 .43422 L
s
.49995 .4468 m
.50226 .45091 L
s
.5048 .45973 m
.50469 .46277 L
s
.49591 .43422 m
.49441 .43047 L
s
.49187 .42164 m
.49037 .41789 L
s
.49441 .43047 m
.49187 .42164 L
s
.49037 .41789 m
.48839 .41543 L
s
.50469 .46277 m
.50377 .46546 L
s
.5212 .5148 m
.50429 .50809 L
s
.48284 .39906 m
.484 .40114 L
s
.484 .40114 m
.48353 .40244 L
s
.48839 .41543 m
.48758 .41504 L
s
.50897 .48011 m
.49761 .47531 L
s
.48236 .40035 m
.48284 .39906 L
s
.50377 .46546 m
.50169 .46611 L
s
.48758 .41504 m
.48628 .41596 L
s
.48353 .40244 m
.48236 .40035 L
s
.48628 .41596 m
.48649 .42066 L
s
.51281 .49888 m
.51131 .49513 L
s
.51386 .50401 m
.51281 .49888 L
s
.51131 .49513 m
.50854 .49243 L
s
.48939 .43123 m
.49137 .43368 L
s
.51376 .50712 m
.51386 .50401 L
s
.50169 .46611 m
.50007 .46541 L
s
.48649 .42066 m
.48753 .42575 L
s
.5124 .51131 m
.51376 .50712 L
s
.49251 .44655 m
.49345 .44388 L
s
.48753 .42575 m
.48939 .43123 L
s
.50007 .46541 m
.49728 .46264 L
s
.50854 .49243 m
.50042 .48908 L
s
.49238 .4496 m
.49251 .44655 L
s
.49728 .46264 m
.49494 .45851 L
s
.5202 .53495 m
.51869 .53119 L
s
.52126 .54012 m
.5202 .53495 L
s
.51869 .53119 m
.51638 .52713 L
s
.49343 .45473 m
.49238 .4496 L
s
.52116 .54328 m
.52126 .54012 L
s
.49494 .45851 m
.49343 .45473 L
s
.51638 .52713 m
.51361 .52447 L
s
.52267 .54704 m
.50562 .54076 L
s
.52027 .54615 m
.52116 .54328 L
s
.52515 .55916 m
.51386 .55512 L
s
.51361 .52447 m
.51199 .52385 L
s
.52658 .56611 m
.52764 .57132 L
s
.52507 .56235 m
.52658 .56611 L
s
.52275 .5583 m
.52507 .56235 L
s
.52764 .57132 m
.52756 .57453 L
s
.51199 .52385 m
.50991 .52465 L
s
.54357 .62376 m
.54501 .63077 L
s
.54207 .62001 m
.54357 .62376 L
s
.52756 .57453 m
.52667 .57746 L
s
.53977 .61602 m
.54207 .62001 L
s
.54501 .63077 m
.54495 .63405 L
s
.53228 .594 m
.53121 .58875 L
s
.53782 .61377 m
.53977 .61602 L
s
.5322 .59723 m
.53228 .594 L
s
.54495 .63405 m
.54409 .6371 L
s
.50991 .52465 m
.50899 .5275 L
s
.52667 .57746 m
.52462 .57839 L
s
.53408 .60275 m
.52281 .59912 L
s
.53132 .60022 m
.5322 .59723 L
s
.54409 .6371 m
.54287 .6384 L
s
.50899 .5275 m
.50888 .53067 L
s
.51147 .53968 m
.51381 .54377 L
s
.52462 .57839 m
.52301 .57784 L
s
.52928 .6012 m
.53132 .60022 L
s
.50888 .53067 m
.50994 .53589 L
s
.50994 .53589 m
.51147 .53968 L
s
.54287 .6384 m
.54085 .63947 L
s
.51538 .55891 m
.5163 .55599 L
s
.52301 .57784 m
.52022 .57526 L
s
.51528 .56213 m
.51538 .55891 L
s
.54085 .63947 m
.53685 .63832 L
s
.52022 .57526 m
.51788 .57119 L
s
.54382 .65032 m
.53405 .65433 L
s
.53324 .6206 m
.53144 .61178 L
s
.52902 .61102 m
.53144 .61178 L
s
.51635 .56739 m
.51528 .56213 L
s
.51788 .57119 m
.51635 .56739 L
s
.54672 .66452 m
.53405 .65433 L
s
.54672 .66452 m
.53697 .66869 L
s
.52777 .61229 m
.52902 .61102 L
s
.53685 .63832 m
.53408 .63584 L
s
.54964 .67877 m
.53697 .66869 L
s
.52687 .61533 m
.52777 .61229 L
s
.5522 .69127 m
.541 .68852 L
s
.53408 .63584 m
.53211 .63359 L
s
.55366 .69843 m
.55477 .70381 L
s
.55214 .69465 m
.55366 .69843 L
s
.52678 .61863 m
.52687 .61533 L
s
.54982 .69068 m
.55214 .69465 L
s
.55477 .70381 m
.55471 .70721 L
s
.53211 .63359 m
.52976 .62955 L
s
.52823 .62575 m
.52678 .61863 L
s
.55471 .70721 m
.55386 .71045 L
s
.52976 .62955 m
.52823 .62575 L
s
.57208 .7626 m
.57019 .75703 L
s
.57468 .77527 m
.57208 .7626 L
s
.57019 .75703 m
.56788 .75311 L
s
.55955 .72719 m
.55845 .72178 L
s
.56788 .75311 m
.56594 .751 L
s
.5595 .73063 m
.55955 .72719 L
s
.57468 .77527 m
.55808 .77242 L
s
.55386 .71045 m
.55184 .71171 L
s
.5614 .73622 m
.55024 .73392 L
s
.55866 .73392 m
.5595 .73063 L
s
.56594 .751 m
.56321 .74873 L
s
.55184 .71171 m
.55024 .71134 L
s
.55665 .73524 m
.55866 .73392 L
s
.56321 .74873 m
.55924 .74796 L
s
.54254 .69233 m
.54342 .68911 L
s
.55024 .71134 m
.54747 .70899 L
s
.54247 .69575 m
.54254 .69233 L
s
.54747 .70899 m
.54512 .70499 L
s
.55924 .74796 m
.55723 .74932 L
s
.54358 .70118 m
.54247 .69575 L
s
.54512 .70499 m
.54358 .70118 L
s
.55723 .74932 m
.556 .75084 L
s
.556 .75084 m
.55514 .75419 L
s
.55514 .75419 m
.55546 .75955 L
s
.55546 .75955 m
.55808 .77242 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`1H0?ooo`030000
o`3oool0oooo04`0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0O0?ooo`00<03o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`000?l0C03o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo01h0oooo000`0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0F@3oool20000odX0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0M0?ooo`00;`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
05X0oooo0P000?m80?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo05<0oooo0P000?m=0?ooo`030000003oool0oooo0580oooo0P00
000M0?ooo`00;P3oool2000004P0oooo00<000000?ooo`3oool0DP3oool010000?l0oooo0000o`00
0?m;0?ooo`030000003oool0oooo04l0oooo0`0000000`3oool000000?ooo`0L0?ooo`00;`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo0540oooo00D0003o0?ooo`000?l0oooo0000
o`1:0?ooo`030000003oool0oooo04`0oooo0`0000040?ooo`030000003oool0oooo01/0oooo000_
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0D03oool01@000?l0oooo0000o`3o
ool0003o04X0oooo00<000000?ooo`3oool0B@3oool3000000L0oooo00<000000?ooo`3oool06`3o
ool002h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`1@0?ooo`80003o0P3oool0
0`000?l0oooo0?ooo`170?ooo`030000003oool0oooo04H0oooo0`00000;0?ooo`030000003oool0
oooo01X0oooo000^0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0C`3oool01@00
0?l0oooo0000o`3oool0003o04T0oooo00<000000?ooo`3oool0@`3oool3000000h0oooo00<00000
0?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1>0?oo
o`050000o`3oool0003o0?ooo`000?l0B@3oool00`000000oooo0?ooo`100?ooo`<000004@3oool0
0`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
04h0oooo00@0003o0?ooo`000?l0003oB@3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool0
0`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
0500oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`00
0000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0=P3oool3000001/0oooo00<000000?ooo`3oool06P3oool002d0oooo
0P00001B0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<`3oool3000001h0oooo
00<000000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`1;0?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0<03oool300000240oooo00<0
00000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`1:
0?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<00000
0?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`180?oo
o`050000o`3oool0oooo0?ooo`000?l0B03oool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool0
0`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
04L0oooo00D0003o0?ooo`3oool0oooo0000o`180?ooo`030000003oool0oooo02L0oooo0`00000[
0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool0A`3oool01@000?l0oooo0?ooo`3oool0003o04L0oooo00<000000?ooo`3oool0903oool3
000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`160?ooo`050000o`3oool0oooo0?ooo`000?l0A`3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo04D0oooo00D0003o0?ooo`3oool0oooo0000o`170?ooo`030000003oool0
oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0A@3oool010000?l0oooo0?ooo`000?m80?ooo`030000003oool0
oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05/0oooo00<000000?ooo`3oool0A@3oool30000odP0oooo00<000000?ooo`3oool05`3oool30000
03/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo
0P00001O0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04@3oool300000440oooo
00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`110?ooo`80003oBP3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0480oooo0P000?m8
0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0@`3oool20000o`030?ooo`000?l0oooo
04<0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`140?ooo`80003oA03oool00`000000
oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0@P3oool010000000oooo
0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0
I03oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo04P0oooo1000001E0?ooo`030000
003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0?@3o
ool20000odH0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`100?ooo`<000000P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool00000
06P0oooo00<000000?ooo`3oool0?P3oool20000ocd0oooo0`0000050?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo03l0
oooo00<0003o0?ooo`3oool0>03oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03h0oooo
00<0003o0?ooo`3oool0=@3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?oo
o`0m0?ooo`030000o`3oool0oooo0380oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool0;`3oool300000140oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0>03oool20000o`030?ooo`00
0?l0oooo02d0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003o
ool0oooo03T0oooo0`000?lZ0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`0k0?ooo`80003o9@3oool3000001/0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`1N0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0F@3oool40000
0240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0703oool3000002D0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo
0000001d0?ooo`030000003oool0oooo03@0oooo0P000?lK0?ooo`<00000:03oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?oo
o`0c0?ooo`030000o`3oool0003o01L0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0<P3oool010000?l0oooo0?ooo`000?lC0?ooo`<00000;P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`0a0?ooo`040000o`3oool0oooo0000oa00oooo0`00
000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<00000
0?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0300oooo00D0003o
0?ooo`3oool0oooo0000o`0<0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo0300oooo00@0003o0?ooo`3oool0003o2@3oool3000003L0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo02`0oooo0P000?l01@3oool0003o0?ooo`3oool0003o00H0oooo0`00000j0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0]0?ooo`D0003o0`3oool3000003d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0300oooo0P000?l200000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000130?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0Y0?ooo`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000000P3o
ool20000odD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`0000060?ooo`@0003o@P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0703oool4000000T0oooo00<0003o0?ooo`3oool00P000?m20?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000003@3oool01@000?l0oooo0?ooo`3oool0003o
0480oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000@0?ooo`050000o`3oool0oooo0?oo
o`000?l0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001<0oooo00D0003o0?ooo`3o
ool0oooo0000o`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000005`3oool01@000?l0
oooo0?ooo`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000J0?ooo`05
0000o`3oool0oooo0?ooo`000?l0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001h0
oooo00<0003o0?ooo`000?l0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000R0?ooo`030000
o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
06@0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03H0
oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03<0oooo
0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0300oooo0`00
000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo02d0oooo0`00000B
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`@0003o;03oool3000001H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02H0oooo0`000?lW0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0V0?ooo`80003o7`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool09@3oool01@00
0?l0oooo0000o`3oool0003o01X0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0U0?oo
o`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool04`3oool4000002h0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02H0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0?0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?l20?oo
o`030000o`3oool0oooo00`0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool3000003X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo02L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`<00000
?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3o
ool0oooo0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?oo
o`020?ooo`040000o`0000000000000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02T0oooo00<0
003o0?ooo`0000000P00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<0000000<0oooo
0000o`000?l0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?oo
o`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000000`3oool20000odd0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`00
8@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0603oool300000140oooo0P000?m?0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000A0?ooo`<0003oDP3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000E0?ooo`030000o`3oool0oooo
0580oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000001X0
oooo0P000?mC0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo
0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000001l0oooo
00<0003o0?ooo`3oool0D03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000002<0oooo00<0
003o0?ooo`3oool0D03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000002@0oooo0P000?mD
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0T03oool010000000oooo0?ooo`3oool3000002H0oooo0P000?mG0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000:P3oool20000
oeL0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900
oooo0`00000_0?ooo`80003oE@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo02l0oooo
00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`25
0?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo02`0oooo0P000?mK0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O03oool300000140oooo00<000000?ooo`3oool0;@3oool00`000?l0oooo0000o`020000oeP0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1h0?ooo`@00000503oool00`000000oooo0?ooo`0]0?ooo`050000o`3oool0oooo0?ooo`000?l0
F@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo02d0oooo00D0003o0?ooo`3oool0oooo
0000o`1J0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0;@3oool01@000?l0oooo0?oo
o`3oool0003o05/0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`0^0?ooo`040000o`3o
ool0oooo0000oe`0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo02h0oooo00D0003o0?ooo`3oool0oooo
0000o`1K0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<0
00000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0;P3oool01@000?l0oooo0?oo
o`3oool0003o05`0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3o
ool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0_0?ooo`<0003oGP3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo
0?ooo`1M0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?oo
o`1N0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<00000
0?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1N
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1O0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0CP3oool400000440oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`1O0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
B`3oool3000004D0oooo00<000000?ooo`3oool0<03oool40000of<0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003o
ool0oooo0380oooo0`000?mS0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0<`3oool30000ofD0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0i0?ooo`<00000F03oool00`000000oooo0?ooo`0b0?ooo`80003o0P3oool00`000?l0oooo0?oo
o`1S0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`0b0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`03
0000003oool0oooo0380oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1U0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;03oool3000006D0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo06@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`0c0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0I@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0
oooo03@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`00
0000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200
oooo1000001`0?ooo`030000003oool0oooo03@0oooo0`000?l30?ooo`030000o`3oool0oooo06L0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`0g0?ooo`@0003oJ@3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00
001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3o
ool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900
oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool5
00000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P00
00090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo
00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo
0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00
001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`80
0000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo
0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`800000
2`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3o
ool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0
oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0
oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo
00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000
D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03o
ool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?oo
o`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@00000
1@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3o
ool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool0
06X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<0
00000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?oo
o`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000
<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool0
0`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool20000
00d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool50000
0480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo
09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00
000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V
0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?oo
o`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000
003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3o
ool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool4
00000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool40000
08@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo
00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00
000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?oo
o`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0
=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03o
ool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool00000
02<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool40000
0;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`00
0000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`800000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P00
00050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool5
00000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool30000
0080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.51791 .42456 m
.5062 .41464 L
s
.51278 .4328 m
.51414 .43815 L
s
.51093 .42984 m
.51278 .4328 L
s
.51414 .43815 m
.51466 .4428 L
s
.51466 .4428 m
.51434 .44677 L
s
.51434 .44677 m
.51283 .44694 L
s
.50095 .40878 m
.50197 .41105 L
s
.50197 .41105 m
.50128 .41187 L
s
.50027 .4096 m
.50095 .40878 L
s
.50689 .42785 m
.50502 .42488 L
s
.50807 .43167 m
.50689 .42785 L
s
.50978 .44016 m
.50807 .43167 L
s
.51283 .44694 m
.51097 .44398 L
s
.50128 .41187 m
.50027 .4096 L
s
.50502 .42488 m
.50417 .42417 L
s
.51097 .44398 m
.50978 .44016 L
s
.52643 .49367 m
.52577 .49458 L
s
.52542 .49143 m
.52643 .49367 L
s
.50417 .42417 m
.50264 .4243 L
s
.5159 .46083 m
.51709 .46466 L
s
.51386 .45632 m
.5159 .46083 L
s
.51709 .46466 m
.51761 .46936 L
s
.52476 .49234 m
.52542 .49143 L
s
.52577 .49458 m
.52476 .49234 L
s
.51761 .46936 m
.51712 .47183 L
s
.50264 .4243 m
.5023 .42826 L
s
.51712 .47183 m
.51578 .47361 L
s
.5023 .42826 m
.50281 .43295 L
s
.50417 .43835 m
.50605 .44133 L
s
.50281 .43295 m
.50417 .43835 L
s
.51578 .47361 m
.51341 .47313 L
s
.51972 .4883 m
.50779 .47876 L
s
.50571 .45249 m
.50708 .45074 L
s
.51341 .47313 m
.51171 .47176 L
s
.52899 .5232 m
.51112 .50927 L
s
.5052 .45495 m
.50571 .45249 L
s
.51171 .47176 m
.50898 .46811 L
s
.52046 .50193 m
.51774 .49833 L
s
.52166 .50579 m
.52046 .50193 L
s
.5222 .51059 m
.52166 .50579 L
s
.50572 .45969 m
.5052 .45495 L
s
.50898 .46811 m
.50692 .46355 L
s
.5217 .51312 m
.5222 .51059 L
s
.50692 .46355 m
.50572 .45969 L
s
.51774 .49833 m
.50919 .49156 L
s
.51969 .51595 m
.5217 .51312 L
s
.52421 .53567 m
.52215 .53113 L
s
.52542 .53956 m
.52421 .53567 L
s
.52596 .54442 m
.52542 .53956 L
s
.52215 .53113 m
.51941 .52754 L
s
.52547 .54702 m
.52596 .54442 L
s
.51941 .52754 m
.51769 .52622 L
s
.52412 .54899 m
.52547 .54702 L
s
.52668 .55092 m
.50857 .53722 L
s
.51769 .52622 m
.51529 .52586 L
s
.52795 .56234 m
.51591 .55334 L
s
.51529 .52586 m
.51392 .52779 L
s
.52746 .56498 m
.52868 .56889 L
s
.52539 .56043 m
.52746 .56498 L
s
.52868 .56889 m
.52923 .57382 L
s
.52923 .57382 m
.52874 .57648 L
s
.51392 .52779 m
.51342 .53039 L
s
.52874 .57648 m
.52739 .57851 L
s
.51342 .53039 m
.51395 .53528 L
s
.51517 .53921 m
.51726 .54379 L
s
.51395 .53528 m
.51517 .53921 L
s
.52739 .57851 m
.525 .57827 L
s
.53161 .59528 m
.53106 .59031 L
s
.53113 .59798 m
.53161 .59528 L
s
.51714 .55728 m
.51851 .55528 L
s
.53934 .62224 m
.54056 .62618 L
s
.53726 .61769 m
.53934 .62224 L
s
.54056 .62618 m
.54131 .63287 L
s
.525 .57827 m
.52327 .577 L
s
.52978 .60007 m
.53113 .59798 L
s
.53536 .61481 m
.53726 .61769 L
s
.53254 .60358 m
.52044 .59488 L
s
.51663 .55993 m
.51714 .55728 L
s
.54131 .63287 m
.54084 .63563 L
s
.52327 .577 m
.5205 .57344 L
s
.52738 .59987 m
.52978 .60007 L
s
.51717 .5649 m
.51663 .55993 L
s
.54084 .63563 m
.53951 .6378 L
s
.5205 .57344 m
.5184 .56885 L
s
.5184 .56885 m
.51717 .5649 L
s
.53951 .6378 m
.53798 .63829 L
s
.53798 .63829 m
.53559 .63819 L
s
.52941 .61831 m
.52849 .60991 L
s
.52589 .60806 m
.52849 .60991 L
s
.53559 .63819 m
.53127 .63519 L
s
.52433 .60851 m
.52589 .60806 L
s
.53758 .64894 m
.52616 .64743 L
s
.52296 .61064 m
.52433 .60851 L
s
.53127 .63519 m
.52848 .63169 L
s
.52245 .6134 m
.52296 .61064 L
s
.5391 .66255 m
.52616 .64743 L
s
.5391 .66255 m
.52766 .66119 L
s
.52848 .63169 m
.52655 .62878 L
s
.52319 .62017 m
.52245 .6134 L
s
.52655 .62878 m
.52443 .62417 L
s
.52443 .62417 m
.52319 .62017 L
s
.54062 .67623 m
.52766 .66119 L
s
.54196 .68827 m
.52973 .68022 L
s
.54148 .69115 m
.54273 .69517 L
s
.53936 .68656 m
.54148 .69115 L
s
.54273 .69517 m
.5433 .70037 L
s
.5433 .70037 m
.54282 .70327 L
s
.54282 .70327 m
.54147 .70563 L
s
.54147 .70563 m
.53904 .70568 L
s
.54582 .72299 m
.54524 .71775 L
s
.54534 .72595 m
.54582 .72299 L
s
.53099 .68428 m
.53237 .68196 L
s
.53904 .70568 m
.53729 .70456 L
s
.54398 .72836 m
.54534 .72595 L
s
.55416 .75432 m
.55203 .74974 L
s
.55562 .76014 m
.55416 .75432 L
s
.54679 .73175 m
.5345 .72405 L
s
.55701 .77254 m
.55562 .76014 L
s
.55203 .74974 m
.5501 .74691 L
s
.53049 .68718 m
.53099 .68428 L
s
.53729 .70456 m
.53446 .70112 L
s
.5501 .74691 m
.54729 .74353 L
s
.54155 .72847 m
.54398 .72836 L
s
.53106 .69242 m
.53049 .68718 L
s
.53446 .70112 m
.53232 .69648 L
s
.55701 .77254 m
.53858 .76149 L
s
.53232 .69648 m
.53106 .69242 L
s
.54729 .74353 m
.54292 .74083 L
s
.54292 .74083 m
.54047 .74097 L
s
.54047 .74097 m
.5389 .74166 L
s
.5389 .74166 m
.53752 .74414 L
s
.53752 .74414 m
.53721 .74895 L
s
.53721 .74895 m
.53858 .76149 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1J0?ooo`80003oA`3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo01`0oooo000_0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0FP3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0703oool002l0oooo0P0000160?ooo`030000003oool0oooo05/0oooo00<0
003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1B0?ooo`8000007@3oool002h0oooo0P000018
0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1?
0?ooo`<0000000<0oooo0000003oool0703oool002l0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`1K0?ooo`80003o@`3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo05H0
oooo0P000?l40?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0B@3oool3000000L0
oooo00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`1E0?ooo`80003oA`3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05@0oooo00@0
003o0?ooo`000?l0003oA@3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo05<0oooo00D0
003o0?ooo`000?l0oooo0000o`140?ooo`030000003oool0oooo0400oooo0`00000A0?ooo`030000
003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0DP3o
ool01@000?l0oooo0000o`3oool0003o04@0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo
00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`1A0?ooo`060000o`3oool0oooo0000o`3oool0003o@`3oool00`000000oooo0?ooo`0i0?ooo`@0
00005`3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0540oooo00D0003o0?ooo`000?l0oooo0000o`130?ooo`030000003oool0oooo03H0
oooo0`00000K0?ooo`030000003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo
0?ooo`1A0?ooo`80003o00<0oooo0000o`3oool0@P3oool00`000000oooo0?ooo`0c0?ooo`<00000
7P3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1B0?ooo`030000003o
ool0oooo0540oooo00<0003o0?ooo`000?l0@`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3o
ool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0540oooo0P000?m30?ooo`030000003oool0oooo02d0oooo0`00000U0?ooo`030000003oool0
oooo01T0oooo000]0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0CP3oool00`00
0?l0oooo0?ooo`140?ooo`030000003oool0oooo02X0oooo0`00000X0?ooo`030000003oool0oooo
01T0oooo000]0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0?ooo`150?ooo`030000003oool0oooo02L0oooo0`00000[0?ooo`030000003oool0oooo01T0
oooo000]0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0B`3oool010000?l0oooo
0?ooo`000?m40?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0
oooo000/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0BP3oool010000?l0oooo
0?ooo`000?m40?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0
oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0B@3oool01@000?l0oooo
0?ooo`3oool0003o04<0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`190?ooo`050000
o`3oool0oooo0?ooo`000?l0@`3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000
oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo04P0oooo
00D0003o0?ooo`3oool0oooo0000o`130?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`03
0000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`180?ooo`040000
o`3oool0oooo0000od<0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3o
ool0603oool002/0oooo0P00001O0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`000?l0
@`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo04L0oooo0P000?m40?ooo`030000003o
ool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0
oooo0600oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool0
0`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
04<0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04<0
oooo0P000?m50?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0A03oool20000od<0oooo
00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`100?ooo`@00000
E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0400oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0l0?ooo`<00000F03o
ool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0
oooo0400oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0i0?ooo`<000000P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool00000
06P0oooo00<000000?ooo`3oool0@03oool01@000?l0oooo0?ooo`3oool0003o03P0oooo0`000005
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?oo
o`030000003oool0oooo0440oooo00<0003o0?ooo`3oool0=P3oool3000000P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo0440oooo00<0003o0?ooo`3oool0<P3oool3000000/0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0
JP3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo02l0oooo0`00000>0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0
;03oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
>P3oool01@000?l0oooo0?ooo`3oool0003o02/0oooo0`00000D0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`1^0?ooo`030000003oool0oooo03X0oooo0P000?l00`3oool0003o0000o`0W0?ooo`<0
0000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0k0?ooo`80
003o9@3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
8@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0k0?ooo`030000
o`3oool0oooo0200oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0k0?ooo`80003o703o
ool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool05P3oool3
000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`00
0000oooo0000001d0?ooo`030000003oool0oooo03H0oooo0P000?lI0?ooo`<00000:03oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000
oooo0?ooo`0d0?ooo`040000o`3oool0oooo0000oaD0oooo0`00000[0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0<`3oool01@000?l0oooo0?ooo`3oool0003o0140oooo0`00000^0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`00
0000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0380oooo00D0003o0?ooo`3o
ool0oooo0000o`0>0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0_0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool02@3oool30000
03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0003o00<0
oooo00<0003o0?ooo`3oool01@3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo02l0oooo
0P000?l30?ooo`030000o`3oool0oooo0080oooo0`00000j0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?oo
o`0_0?ooo`80003o0P3oool00`000?l0oooo00000002000003d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0
oooo0300oooo00@0003o000000000?l00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3
000000030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000001@00
0?l0oooo0?ooo`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000@0oooo00<0003o0?oo
o`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000L0oooo0`000?m20?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0L0?ooo`@000002P3oool010000?l0oooo0?ooo`000?m20?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`0H0?ooo`<000003P3oool00`000?l0oooo0?ooo`020000od40oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?oo
o`250?ooo`030000003oool0oooo01@0oooo0`00000A0?ooo`050000o`3oool0oooo0?ooo`000?l0
@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001@0oooo00D0003o0?ooo`3oool0oooo
0000o`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000005`3oool01@000?l0oooo0?oo
o`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000K0?ooo`040000o`3o
ool0oooo0000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000O0?ooo`030000o`3o
ool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008`3oool20000od40oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`800000J@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`80
0000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo06@0oooo0`0000020?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03H0oooo100000060?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo03<0oooo0`00000:0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l0<P3oool3000000h0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02@0oooo00@0003o0?ooo`3oool0003o;`3oool300000180oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02D0oooo0P000?l]0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool09`3oool00`000?l0oooo0?ooo`0V0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02@0oooo0P000?lT0?ooo`<000008P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0000o`0P0?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`0T0?ooo`050000o`3oool0003o0?ooo`000?l06`3oool3000002X0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02@0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0D0?oo
o`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0000o`020?ooo`03
0000o`3oool0oooo0140oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03@3oool3000003H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00L0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool400000480oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo00000002000004L0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool00`00001:0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0X0?ooo`<0000000<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`00
0000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000005/0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000203oool50000oe40oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000000`0oooo
00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo
000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0E0?ooo`<00000403oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool04@3oool4000001@0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000006@3oool00`000?l0oooo0?ooo`1C0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000001T0oooo1@000?mD0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`080?ooo`<000007@3oool00`000?l0oooo0?ooo`1F0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`040?ooo`@000008@3oool00`000?l0oooo0?ooo`1F0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
10000000oooo0?ooo`3oool3000002D0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000002T0oooo00<0003o
0?ooo`3oool0E`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`800000T03oool3000002d0oooo00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`0W0?ooo`80003o
G@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo02P0oooo0P000?mM0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3
000000`0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0000o`000?mL0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3
000000l0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`020000oe`0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?oo
o`<000004@3oool00`000000oooo0?ooo`0Y0?ooo`050000o`3oool0oooo0?ooo`000?l0G03oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07P0oooo1000000D0?ooo`030000003oool0oooo02T0oooo00D0003o0?ooo`3oool0oooo0000o`1M
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0:@3oool01@000?l0oooo0?ooo`3oool0
003o05h0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`0Y0?ooo`050000o`3oool0oooo
0?ooo`000?l0G`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo02X0oooo00@0003o0?oo
o`3oool0003oH03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`<00000KP3oool300000240oooo00<000000?ooo`3oool0:`3oool30000of00oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@0
0000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0;P3oool00`00
0?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0;P3oool00`000?l0
oooo0?ooo`1R0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0:P3oool01@000?l0oooo
0?ooo`3oool0003o06D0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`00
7@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`0[0?ooo`80003o
00<0oooo0000o`3oool0I@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo02d0oooo0P00
0?mW0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1T
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo02`0oooo0P000?m[0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3o
ool3000004h0oooo00<000000?ooo`3oool0;03oool010000?l0oooo0000o`000?mZ0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0:`3oool01@000?l0oooo0?ooo`3oool0003o06/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0J03oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo02/0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1X0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?oo
o`3oool0:`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo06P0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<0
0000GP3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0J@3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo02`0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo06X0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool0
0`000000oooo0?ooo`0^0?ooo`80003o0`3oool00`000?l0oooo0?ooo`1[0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool30000
06X0oooo00<000000?ooo`3oool0<03oool20000o`030?ooo`000?l0oooo06d0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`03
0000003oool0oooo0380oooo0`000?m^0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
=03oool00`000?l0oooo0?ooo`1]0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo
100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
0P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`80
0000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003o
ool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool5
00000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo
0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000
P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0
oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
04`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo
00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00
001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?oo
o`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3o
ool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo
001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo
001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo0000
00030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0
oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo
001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?oo
o`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00
K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2
000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool00000
03`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000
oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e
0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?oo
o`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00
J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`03
0000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D0
0000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000
E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03o
ool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool01000
0000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`00
0000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0
oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00
000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<00000
0?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000
R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3o
ool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0
oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo
00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<0
00000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<00000
0?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`03
0000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3o
ool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`80
00002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool00000
0000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo
002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3o
ool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool20000
00@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?oo
o`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?oo
o`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "In the following the normal vector to the text plane is rotated ",
  Cell[BoxData[
      \(45  \[Degree]\)]],
  " from the North pole and then ",
  Cell[BoxData[
      \(90  \[Degree]\)]],
  " West from the ",
  Cell[BoxData[
      \(y \[Equal] 0\)]],
  " meridian. The text is then rotated in the resulting text plane."
}], "Text"],

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Psi]frame[\[Pi]/4, \(-\[Pi]\)/2]\)[\[Psi]], {\[Psi], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\[Phi] Variation - Changing the Colatitude\
\>", "Subsection"],

Cell["\<\
The following routine produces one frame for a \[Phi] variation animation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[Phi]frame[\[Theta]_, \[Psi]_]\)[\[Phi]_] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{AbsoluteThickness[1], 
            Blue, \[IndentingNewLine]Text3D["\<DrawGraphics!\>", {0, 0, 
                0}, {1, 1}, {\[Phi], \[Theta], \[Psi]}, 
              Font3D \[Rule] FuturaFont3D]}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                  1}, {\(-1\), 1}} 10, \[IndentingNewLine]ImageSize \[Rule] 
            400];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(\[Phi]frame\\)\\\" is similar to existing \
symbol \\\"\\!\\(\[Psi]frame\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\
\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[TextData[{
  "The following shows the effect of varying ",
  Cell[BoxData[
      \(\[Phi]\)]],
  " starting with the normal text position. Usually we would only vary ",
  Cell[BoxData[
      \(\[Phi]\)]],
  " between ",
  Cell[BoxData[
      \(0\)]],
  " and ",
  Cell[BoxData[
      \(\[Pi]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Phi]frame[0, 0]\)[\[Phi]], {\[Phi], 0, 2  \[Pi] - del, 
        del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37024 .64733 m
.38086 .64396 L
s
.37024 .64733 m
.35044 .62848 L
s
.38086 .64396 m
.3845 .64162 L
s
.3845 .64162 m
.38569 .63886 L
s
.38569 .63886 m
.38536 .63658 L
s
.38536 .63658 m
.3841 .63339 L
s
.3841 .63339 m
.37942 .62886 L
s
.39577 .63086 m
.38268 .61809 L
s
.37942 .62886 m
.37507 .62663 L
s
.39946 .62848 m
.40346 .62841 L
s
.39452 .62765 m
.39946 .62848 L
s
.36114 .62503 m
.35044 .62848 L
s
.40346 .62841 m
.40809 .62693 L
s
.39018 .62541 m
.39452 .62765 L
s
.37507 .62663 m
.37165 .6253 L
s
.37165 .6253 m
.36669 .62446 L
s
.36669 .62446 m
.36114 .62503 L
s
.41956 .62206 m
.41462 .62123 L
s
.42359 .62199 m
.41956 .62206 L
s
.42826 .6205 m
.42359 .62199 L
s
.41462 .62123 m
.41029 .61897 L
s
.43046 .61859 m
.42826 .6205 L
s
.41029 .61897 m
.40844 .61713 L
s
.43175 .61575 m
.43046 .61859 L
s
.43449 .61851 m
.42162 .60554 L
s
.40844 .61713 m
.40721 .61386 L
s
.44544 .61502 m
.43894 .59996 L
s
.40721 .61386 m
.40846 .61101 L
s
.45801 .61101 m
.45161 .59587 L
s
.45801 .61101 m
.43894 .59996 L
s
.40846 .61101 m
.41065 .60907 L
s
.41065 .60907 m
.41535 .60756 L
s
.41941 .60748 m
.42439 .60834 L
s
.41535 .60756 m
.41941 .60748 L
s
.49186 .60752 m
.4869 .60667 L
s
.49592 .60744 m
.49186 .60752 L
s
.50229 .60542 m
.49592 .60744 L
s
.47064 .60698 m
.45161 .59587 L
s
.4869 .60667 m
.48354 .60531 L
s
.5046 .60348 m
.50229 .60542 L
s
.48354 .60531 m
.47926 .60301 L
s
.50604 .60058 m
.5046 .60348 L
s
.47926 .60301 m
.47477 .59831 L
s
.50587 .59819 m
.50604 .60058 L
s
.47477 .59831 m
.47366 .59497 L
s
.47366 .59497 m
.47345 .59256 L
s
.51374 .59323 m
.50131 .57985 L
s
.49075 .59319 m
.49877 .59062 L
s
.47345 .59256 m
.47484 .58963 L
s
.5177 .59074 m
.5218 .59066 L
s
.51271 .58987 m
.5177 .59074 L
s
.5218 .59066 m
.52665 .58911 L
s
.4961 .58776 m
.49877 .59062 L
s
.50844 .58752 m
.51271 .58987 L
s
.47484 .58963 m
.47714 .58764 L
s
.4927 .58637 m
.4961 .58776 L
s
.47714 .58764 m
.48356 .58557 L
s
.48768 .58549 m
.4927 .58637 L
s
.48356 .58557 m
.48768 .58549 L
s
.53876 .58402 m
.53376 .58314 L
s
.54288 .58394 m
.53876 .58402 L
s
.54777 .58238 m
.54288 .58394 L
s
.53376 .58314 m
.5295 .58078 L
s
.55016 .58038 m
.54777 .58238 L
s
.5295 .58078 m
.52774 .57885 L
s
.5517 .5774 m
.55016 .58038 L
s
.5543 .5803 m
.5421 .56671 L
s
.52774 .57885 m
.52672 .57543 L
s
.56577 .57664 m
.54749 .55608 L
s
.52672 .57543 m
.52822 .57244 L
s
.5682 .57462 m
.57235 .57454 L
s
.56318 .57373 m
.5682 .57462 L
s
.57235 .57454 m
.57729 .57296 L
s
.57729 .57296 m
.57974 .57094 L
s
.60472 .57292 m
.58687 .55227 L
s
.52822 .57244 m
.53061 .57041 L
s
.57974 .57094 m
.58133 .56793 L
s
.53061 .57041 m
.53553 .56883 L
s
.53969 .56874 m
.54473 .56964 L
s
.53553 .56883 m
.53969 .56874 L
s
.58133 .56793 m
.58042 .56446 L
s
.55781 .56291 m
.55625 .56593 L
s
.58042 .56446 m
.5787 .5625 L
s
.63723 .56385 m
.63473 .5634 L
s
.63809 .56233 m
.63723 .56385 L
s
.60297 .56352 m
.60715 .56344 L
s
.59543 .56217 m
.60297 .56352 L
s
.60715 .56344 m
.61215 .56184 L
s
.63473 .5634 m
.63558 .56188 L
s
.56025 .56086 m
.55781 .56291 L
s
.5787 .5625 m
.57446 .56008 L
s
.63558 .56188 m
.63809 .56233 L
s
.61215 .56184 m
.61466 .55979 L
s
.56522 .55925 m
.56025 .56086 L
s
.57446 .56008 m
.56941 .55917 L
s
.61466 .55979 m
.61381 .55629 L
s
.56941 .55917 m
.56522 .55925 L
s
.61381 .55629 m
.60534 .54632 L
s
.6306 .55596 m
.61885 .54197 L
s
.64666 .54957 m
.64162 .54866 L
s
.65088 .54949 m
.64666 .54957 L
s
.65597 .54787 m
.65088 .54949 L
s
.64162 .54866 m
.63743 .5462 L
s
.65855 .54578 m
.65597 .54787 L
s
.63743 .5462 m
.63576 .54419 L
s
.66031 .54268 m
.65855 .54578 L
s
.63576 .54419 m
.63495 .54062 L
s
.67391 .54088 m
.67057 .5394 L
s
.67986 .54025 m
.67391 .54088 L
s
.63495 .54062 m
.63667 .53751 L
s
.68501 .5386 m
.67986 .54025 L
s
.67057 .5394 m
.67065 .53683 L
s
.71128 .53911 m
.70008 .52484 L
s
.68936 .53594 m
.68501 .5386 L
s
.63667 .53751 m
.63925 .53539 L
s
.67065 .53683 m
.67326 .53472 L
s
.68947 .53336 m
.68936 .53594 L
s
.63925 .53539 m
.64437 .53374 L
s
.67326 .53472 m
.68105 .53094 L
s
.64862 .53366 m
.65371 .53459 L
s
.64437 .53374 m
.64862 .53366 L
s
.66407 .52868 m
.664 .53128 L
s
.68105 .53094 m
.68368 .52881 L
s
.68368 .52881 m
.68378 .52621 L
s
.66841 .52599 m
.66407 .52868 L
s
.68378 .52621 m
.68297 .52518 L
s
.67359 .52432 m
.66841 .52599 L
s
.68297 .52518 m
.6796 .52368 L
s
.6796 .52368 m
.67359 .52432 L
s
.69697 .51809 m
.69604 .51968 L
s
.69604 .51968 m
.69348 .51921 L
s
.69348 .51921 m
.69441 .51761 L
s
.69441 .51761 m
.69697 .51809 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000K0?ooo`80
003o00<0oooo0000003oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000N0?ooo`040000o`3oool0oooo000005P0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1E0?ooo`<00000703oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`1A0?ooo`<000006`3oool40000o`030?ooo`000?l0003o00D0oooo00<0003o0000003oool0F03o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3
000001d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0B@3oool300000200oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`03000000000?l0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0
oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04D0
oooo0`00000K0?ooo`D0003o1`3oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000000
003o0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000703oool20000o`X0oooo
0P000?l50?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`000?l0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0m0?ooo`<000007P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo0P00
0?l50?ooo`040000003oool0oooo0000oeH0oooo00<000000?ooo`3oool05@3oool002P0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000006`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool40000o`L0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo03D0oooo0`00000O0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?oo
o`<00000703oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<0
0000803oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1P000?lA0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0Y0?ooo`<000006`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000003`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<000004`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0703oool4000001L0oooo00<0003o0?ooo`3oool01P000?l60?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0603oool3000001`0oooo0P000?l60?ooo`80003o1@3oool70000o`P0oooo0P000?lH0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0D0?ooo`<000006P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0@0?ooo`<000006`3oool20000o`030?ooo`000?l0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02D0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000L0?ooo`80003o0P3oool30000o`@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02@0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000N0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool60000o`T0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool300000200oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo00<0003o0?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool00`00000J0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool20000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo0P000?l00`3oool0003o0?ooo`0f0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0
oooo01D0oooo0`000?l60?ooo`030000o`3oool0oooo00H0oooo1P000?lj0?ooo`800000F`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
01<0oooo0P000?l30?ooo`<0003o0`3oool00`000?l0oooo0?ooo`130?ooo`<000000P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`80003o0`3oool70000ocX0
oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo
0P000?l60?ooo`030000o`3oool0oooo03X0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`090?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0AP3oool3000000h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo00T0oooo0`000?l60?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0=`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0000o`000?l50?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0<`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo0`000?l20?oo
o`040000o`3oool0oooo0?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0300oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000003o0?ooo`060?ooo`060000o`3oool0003o
0000o`3oool0003o103oool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?oo
o`0^0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo08X0oooo1P000?l60?ooo`040000o`3oool0oooo0?ooo`80003o2`3o
ool50000obh0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0RP3oool01@000?l0oooo0?ooo`3oool000000080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03P0oooo0`00
000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002;
0?ooo`050000o`3oool0oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo03X0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0RP3oool01@000?l0oooo0?ooo`3oool0000000@0oooo00<0
003o0?ooo`3oool0>`3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`210?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`000000103oool00`000?l0oooo0000o`0i0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo0880oooo00<0003o0?oo
o`3oool01`3oool70000ocP0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0M`3oool60000o`H0oooo00<0003o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07D0oooo0`000?l60?ooo`80003o
1@3oool70000o`80oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1f0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000003o
ool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`070?ooo`80003o2`3oool0
0`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo07P0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0N@3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0:03oool3000004h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000007X0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
001m0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q
0?ooo`030000003oool0oooo07d0oooo00<0003o0?ooo`3oool00P000?l=0?ooo`030000003oool0
oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo07h0oooo0P000?l?0?ooo`030000003oool0oooo
01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0
oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37219 .67892 m
.38279 .67348 L
s
.37219 .67892 m
.35219 .66024 L
s
.38279 .67348 m
.38641 .67025 L
s
.38641 .67025 m
.38758 .66692 L
s
.38758 .66692 m
.38723 .66435 L
s
.38723 .66435 m
.38594 .66089 L
s
.38594 .66089 m
.38122 .6564 L
s
.39757 .65628 m
.38438 .6436 L
s
.40523 .65234 m
.40983 .64998 L
s
.40123 .65302 m
.40523 .65234 L
s
.3963 .65279 m
.40123 .65302 L
s
.39195 .65087 m
.3963 .65279 L
s
.38122 .6564 m
.37685 .65448 L
s
.37685 .65448 m
.37341 .65346 L
s
.42522 .64207 m
.42121 .64274 L
s
.42984 .63969 m
.42522 .64207 L
s
.36289 .65471 m
.35219 .66024 L
s
.42121 .64274 m
.41628 .64251 L
s
.43201 .63719 m
.42984 .63969 L
s
.37341 .65346 m
.36844 .65324 L
s
.41628 .64251 m
.41194 .64056 L
s
.43602 .63651 m
.42307 .6236 L
s
.36844 .65324 m
.36289 .65471 L
s
.43326 .63376 m
.43201 .63719 L
s
.41194 .64056 m
.41008 .63874 L
s
.44686 .63094 m
.44022 .61474 L
s
.41008 .63874 m
.40882 .63519 L
s
.45928 .62455 m
.45274 .60827 L
s
.45928 .62455 m
.44022 .61474 L
s
.49673 .61503 m
.49272 .6157 L
s
.50299 .61182 m
.49673 .61503 L
s
.49272 .6157 m
.48782 .61544 L
s
.50524 .60927 m
.50299 .61182 L
s
.48782 .61544 m
.48447 .61438 L
s
.40882 .63519 m
.41004 .63175 L
s
.47174 .61814 m
.45274 .60827 L
s
.50661 .60579 m
.50524 .60927 L
s
.48447 .61438 m
.48022 .61239 L
s
.41004 .63175 m
.4122 .62922 L
s
.4209 .62614 m
.42587 .62639 L
s
.50642 .60311 m
.50661 .60579 L
s
.48022 .61239 m
.47571 .6077 L
s
.4122 .62922 m
.41686 .62681 L
s
.41686 .62681 m
.4209 .62614 L
s
.47571 .6077 m
.47457 .60407 L
s
.5141 .59636 m
.50165 .58299 L
s
.522 .5923 m
.52674 .58986 L
s
.51796 .59297 m
.522 .5923 L
s
.47457 .60407 m
.47433 .60137 L
s
.51303 .5927 m
.51796 .59297 L
s
.49143 .5996 m
.49931 .59554 L
s
.50879 .59066 m
.51303 .5927 L
s
.49663 .59269 m
.49931 .59554 L
s
.47433 .60137 m
.47566 .59784 L
s
.5426 .5817 m
.53855 .58238 L
s
.54737 .57925 m
.5426 .5817 L
s
.53855 .58238 m
.53363 .5821 L
s
.49325 .5916 m
.49663 .59269 L
s
.47566 .59784 m
.47791 .59526 L
s
.54969 .57665 m
.54737 .57925 L
s
.53363 .5821 m
.52941 .58003 L
s
.48829 .59132 m
.49325 .5916 L
s
.47791 .59526 m
.48423 .592 L
s
.55374 .57597 m
.54155 .56237 L
s
.55115 .57308 m
.54969 .57665 L
s
.48423 .592 m
.48829 .59132 L
s
.52941 .58003 m
.52765 .5781 L
s
.56491 .57023 m
.54667 .54964 L
s
.60289 .56057 m
.58511 .53986 L
s
.52765 .5781 m
.5266 .57438 L
s
.57131 .56694 m
.57612 .56447 L
s
.56725 .56761 m
.57131 .56694 L
s
.56233 .56732 m
.56725 .56761 L
s
.57612 .56447 m
.57847 .56184 L
s
.57847 .56184 m
.57998 .55823 L
s
.5266 .57438 m
.52802 .57079 L
s
.63436 .54584 m
.63192 .54568 L
s
.63515 .54402 m
.63436 .54584 L
s
.63192 .54568 m
.63271 .54386 L
s
.57998 .55823 m
.57903 .55446 L
s
.63271 .54386 m
.63515 .54402 L
s
.52802 .57079 m
.53034 .56817 L
s
.53922 .56501 m
.54418 .56531 L
s
.60508 .54957 m
.60993 .54708 L
s
.60101 .55025 m
.60508 .54957 L
s
.53034 .56817 m
.53514 .56569 L
s
.59363 .54978 m
.60101 .55025 L
s
.53514 .56569 m
.53922 .56501 L
s
.60993 .54708 m
.61233 .54443 L
s
.57903 .55446 m
.57732 .55249 L
s
.55689 .55588 m
.55541 .55951 L
s
.61233 .54443 m
.61144 .54062 L
s
.57732 .55249 m
.57312 .55036 L
s
.55924 .55323 m
.55689 .55588 L
s
.62776 .53791 m
.61606 .52387 L
s
.57312 .55036 m
.56817 .55005 L
s
.61144 .54062 m
.603 .53062 L
s
.56408 .55073 m
.55924 .55323 L
s
.56817 .55005 m
.56408 .55073 L
s
.6473 .52786 m
.64321 .52854 L
s
.6522 .52534 m
.6473 .52786 L
s
.64321 .52854 m
.6383 .52821 L
s
.65465 .52266 m
.6522 .52534 L
s
.6383 .52821 m
.63419 .52604 L
s
.6563 .51895 m
.65465 .52266 L
s
.63419 .52604 m
.63253 .52402 L
s
.70542 .50797 m
.69431 .49361 L
s
.66941 .51506 m
.66615 .51388 L
s
.67515 .51354 m
.66941 .51506 L
s
.68008 .511 m
.67515 .51354 L
s
.63253 .52402 m
.63167 .52014 L
s
.68422 .50744 m
.68008 .511 L
s
.66615 .51388 m
.66616 .511 L
s
.68427 .50455 m
.68422 .50744 L
s
.63167 .52014 m
.63328 .51642 L
s
.66616 .511 m
.66865 .50828 L
s
.66865 .50828 m
.67609 .503 L
s
.63328 .51642 m
.63573 .5137 L
s
.64478 .51047 m
.64973 .51082 L
s
.63573 .5137 m
.64066 .51115 L
s
.67609 .503 m
.67858 .50027 L
s
.64066 .51115 m
.64478 .51047 L
s
.65963 .5028 m
.65962 .50571 L
s
.67858 .50027 m
.67862 .49735 L
s
.66377 .49921 m
.65963 .5028 L
s
.67862 .49735 m
.67781 .49632 L
s
.67781 .49632 m
.67453 .49511 L
s
.66874 .49664 m
.66377 .49921 L
s
.67453 .49511 m
.66874 .49664 L
s
.69115 .48652 m
.69029 .48842 L
s
.69029 .48842 m
.68782 .48824 L
s
.68782 .48824 m
.68868 .48634 L
s
.68868 .48634 m
.69115 .48652 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08D0oooo00D0003o0?ooo`3oool0oooo000000030?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo08<0oooo0`000?l20?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo08D0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0P@3oool300000003
0000o`3oool0000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000
J03oool00`000000oooo0?ooo`1i0?ooo`D0003o0P0000040?ooo`030000o`000000oooo05L0oooo
00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo07L0oooo0P00
0?l01@3oool00000000000000000003o00H0oooo00<0003o0000003oool0E`3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07D0oooo00@0
003o00000000000000000`3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0LP3oool2000000030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0003o
1@3oool00`000000003o0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?ooo`<00000
0P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool00`000000
003o0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?ooo`80000000<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`00
0?l0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06h0oooo00<000000?ooo`3oool0IP3oool3000000030?ooo`000?l0oooo0080
003o1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0HP3oool300000080oooo0P000?l90?ooo`H0
003o203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`800000
1P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`0000040?ooo`030000
o`3oool0oooo01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo100000060?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3oool3
000000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00l0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`00
0000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`0000090?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo04d0
oooo0`00000<0?ooo`030000o`3oool0oooo00<0oooo1P000?lC0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0B@3oool3000000T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0K0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<0
00000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04D0oooo0`00
000=0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000403oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?oo
o`<000002`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool06@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool3000000l0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000
4`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo0P000?lH0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3o
ool00`000000oooo0?ooo`0a0?ooo`<000005`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3
000000T0oooo00<0003o0?ooo`3oool00`3oool50000o`H0oooo1P000?lS0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo0?ooo`0Y0?ooo`<000003@3oool00`000?l0oooo0?ooo`020000o`D0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000A0?ooo`03
0000o`3oool0003o00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0T0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0Q0?ooo`<000005@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703o
ool4000001P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo02<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000G0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`0D0?ooo`<000005`3oool50000o`D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0]0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000006@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1@000?l`0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0<0?ooo`<000006`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001d0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`04
0?ooo`<00000803oool00`000?l0oooo0?ooo`060?ooo`80003o>03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool00`00000T0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0
oooo0P00000X0?ooo`H0003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo04P0oooo
0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool07@3oool00`000?l0oooo0?ooo`140?ooo`<000000P3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool07P3oool20000o`D0oooo00<0003o0?ooo`3oool0>03oool4000000H0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo01D0oooo1P000?l40?ooo`H0003o>03oool3000000X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo01<0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0=`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool0
103oool20000o`H0oooo00<0003o0?ooo`3oool0<`3oool300000180oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0180oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0i0?ooo`<000005P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0
oooo02l0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0;03oool3000001h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo02X0
oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0:0?ooo`<0003o1P3oool20000o`L0oooo
00<0003o0?ooo`3oool0:03oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`040000o`3oool0003o0000o`H0oooo0P000?l30?ooo`80003o:03oool3000002X0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo00D0oooo0`000?l30?ooo`040000o`3oool0oooo0?ooo`80003o
1P3oool30000obH0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`070?ooo`060000o`3o
ool0003o0000o`3oool0003o1@3oool00`000?l0oooo0?ooo`0Y0?ooo`<00000<`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool01`3oool010000?l0oooo0?ooo`3oool30000obd0oooo0`00000f0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
S@3oool010000000oooo0?ooo`000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0:03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`D0003o1P3oool00`000?l0oooo0?ooo`0Z0?ooo`<00000
?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08d0oooo00<0003o0000003oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo02H0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0S03oool00`000?l0oooo000000050?ooo`030000o`3oool0
oooo02P0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0R`3oool010000?l0oooo0?ooo`0000050?ooo`80003o9P3oool3
000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000o`3oool0000000D0oooo00<0003o0?ooo`3oool08P3oool30000
04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008`0
oooo00<0003o0?ooo`000000103oool00`000?l0oooo0?ooo`0P0?ooo`<00000DP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000Q03oool00`000?l0oooo
0?ooo`080?ooo`H0003o7`3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`240?ooo`030000o`3oool0oooo00P0oooo00<0
00000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0Q@3oool00`000?l0oooo0?ooo`07
0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`26
0?ooo`030000o`3oool0oooo0080oooo0`000?l00`3oool000000?ooo`0I0?ooo`<00000HP3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0N`3oool60000o`H0oooo10000?l40?ooo`030000003oool0oooo
01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0
oooo0P0000070?ooo`030000003oool0oooo07T0oooo0P000?l60?ooo`80003o1@3oool00`000?l0
oooo0?ooo`040?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`1g0?ooo`80003o2P3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo
0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`00
00050?ooo`030000003oool0oooo07T0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?oo
o`080?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0NP3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0203oool3000007H0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`1k0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`040?oo
o`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo07`0oooo0P000?l70?ooo`030000o`3oool0oooo00P0oooo00@000000?ooo`3o
ool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200
oooo0P00001o0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02@3oool4000008<0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000840oooo
00<0003o0?ooo`3oool00P000?l:0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo0840oooo0P000?l90?ooo`<000000P3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00
000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo
06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00
000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3o
ool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0
oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool20000
04T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000
001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3o
ool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000
001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3o
ool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool20000
09L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo
0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P00
00200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2
000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0
oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K
0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3o
ool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3o
ool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0
oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo
001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?oo
o`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000
003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool40000
03D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0
oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo
001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo
00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo
1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000
001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H
0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`04
0000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`03
0000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`800000
9P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo
000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`00
0000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@00
00280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=
0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`800000
5P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool0
0`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool0
06H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo
00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo
0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo
0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`00
0000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3o
ool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo10000036
0?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`80
0000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0
oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.38131 .70758 m
.39144 .70021 L
s
.38131 .70758 m
.36117 .68902 L
s
.39144 .70021 m
.39484 .69617 L
s
.39484 .69617 m
.39586 .6923 L
s
.39586 .6923 m
.39543 .68947 L
s
.39543 .68947 m
.39405 .68574 L
s
.39405 .68574 m
.38931 .68127 L
s
.40519 .67921 m
.39193 .66659 L
s
.41247 .67391 m
.41685 .67072 L
s
.40862 .67513 m
.41247 .67391 L
s
.40382 .67546 m
.40862 .67513 L
s
.4993 .62175 m
.49547 .62296 L
s
.50517 .61748 m
.4993 .62175 L
s
.43145 .66009 m
.4276 .66131 L
s
.43584 .65689 m
.43145 .66009 L
s
.50722 .61441 m
.50517 .61748 L
s
.49547 .62296 m
.49076 .62324 L
s
.39953 .67383 m
.40382 .67546 L
s
.43784 .65385 m
.43584 .65689 L
s
.4276 .66131 m
.42282 .66163 L
s
.44169 .65263 m
.4287 .63976 L
s
.5084 .6104 m
.50722 .61441 L
s
.43892 .64989 m
.43784 .65385 L
s
.49076 .62324 m
.4875 .62245 L
s
.38931 .68127 m
.38499 .67965 L
s
.45194 .64517 m
.44493 .62793 L
s
.42282 .66163 m
.41855 .65997 L
s
.46367 .63663 m
.45675 .6193 L
s
.46367 .63663 m
.44493 .62793 L
s
.4875 .62245 m
.48334 .62072 L
s
.5081 .60745 m
.5084 .6104 L
s
.47541 .62808 m
.45675 .6193 L
s
.38499 .67965 m
.38161 .67892 L
s
.41855 .65997 m
.41668 .65814 L
s
.48334 .62072 m
.47882 .61604 L
s
.38161 .67892 m
.37677 .67925 L
s
.41668 .65814 m
.41533 .65433 L
s
.37141 .68155 m
.36117 .68902 L
s
.37677 .67925 m
.37141 .68155 L
s
.51518 .59912 m
.50273 .58576 L
s
.52257 .59374 m
.527 .59052 L
s
.51873 .59495 m
.52257 .59374 L
s
.59819 .54982 m
.58043 .52908 L
s
.51401 .5952 m
.51873 .59495 L
s
.41533 .65433 m
.41638 .65035 L
s
.47882 .61604 m
.47758 .61215 L
s
.5418 .57974 m
.53797 .58094 L
s
.54625 .5765 m
.5418 .57974 L
s
.62727 .53025 m
.62496 .53034 L
s
.62794 .52817 m
.62727 .53025 L
s
.50987 .59342 m
.51401 .5952 L
s
.42669 .64284 m
.4315 .64254 L
s
.54835 .57338 m
.54625 .5765 L
s
.53797 .58094 m
.53326 .58118 L
s
.41638 .65035 m
.41838 .64729 L
s
.55218 .57219 m
.54 .55858 L
s
.62496 .53034 m
.62563 .52827 L
s
.62563 .52827 m
.62794 .52817 L
s
.49359 .60528 m
.50099 .59989 L
s
.54958 .56929 m
.54835 .57338 L
s
.4228 .64406 m
.42669 .64284 L
s
.56257 .56462 m
.54433 .54402 L
s
.4983 .59704 m
.50099 .59989 L
s
.41838 .64729 m
.4228 .64406 L
s
.53326 .58118 m
.52915 .57938 L
s
.56851 .5603 m
.57297 .55705 L
s
.56468 .56149 m
.56851 .5603 L
s
.47758 .61215 m
.47725 .60918 L
s
.57297 .55705 m
.57509 .55391 L
s
.55999 .56171 m
.56468 .56149 L
s
.57509 .55391 m
.57636 .54978 L
s
.52915 .57938 m
.52739 .57745 L
s
.47725 .60918 m
.47839 .60513 L
s
.49503 .59622 m
.4983 .59704 L
s
.59977 .53753 m
.60425 .53427 L
s
.59595 .53872 m
.59977 .53753 L
s
.60425 .53427 m
.6064 .53111 L
s
.58894 .53902 m
.59595 .53872 L
s
.57636 .54978 m
.5753 .54575 L
s
.49026 .59647 m
.49503 .59622 L
s
.52739 .57745 m
.52623 .57346 L
s
.47839 .60513 m
.48045 .60201 L
s
.6064 .53111 m
.60539 .52704 L
s
.69227 .48138 m
.68118 .46697 L
s
.62068 .52231 m
.60901 .50823 L
s
.48638 .59768 m
.49026 .59647 L
s
.48045 .60201 m
.48638 .59768 L
s
.5753 .54575 m
.57359 .54377 L
s
.63865 .50923 m
.63483 .5104 L
s
.64314 .50595 m
.63865 .50923 L
s
.52623 .57346 m
.52744 .56935 L
s
.64533 .50276 m
.64314 .50595 L
s
.63483 .5104 m
.63019 .51058 L
s
.60539 .52704 m
.59697 .51702 L
s
.6467 .49854 m
.64533 .50276 L
s
.57359 .54377 m
.56952 .5419 L
s
.53789 .56173 m
.54262 .56151 L
s
.63019 .51058 m
.62621 .50865 L
s
.52744 .56935 m
.52954 .5662 L
s
.66416 .49065 m
.65885 .49291 L
s
.66867 .48736 m
.66416 .49065 L
s
.55432 .54974 m
.55307 .55389 L
s
.67239 .48305 m
.66867 .48736 L
s
.65885 .49291 m
.65573 .49197 L
s
.53402 .56293 m
.53789 .56173 L
s
.52954 .5662 m
.53402 .56293 L
s
.67229 .47991 m
.67239 .48305 L
s
.56952 .5419 m
.5648 .5421 L
s
.65573 .49197 m
.65561 .48884 L
s
.62621 .50865 m
.62455 .50662 L
s
.55645 .54658 m
.55432 .54974 L
s
.5648 .5421 m
.56094 .5433 L
s
.56094 .5433 m
.55645 .54658 L
s
.65561 .48884 m
.65781 .48562 L
s
.62455 .50662 m
.62357 .50249 L
s
.65781 .48562 m
.66455 .47909 L
s
.66455 .47909 m
.66676 .47586 L
s
.62357 .50249 m
.62492 .49825 L
s
.66676 .47586 m
.66666 .47269 L
s
.63549 .49055 m
.64016 .49039 L
s
.62492 .49825 m
.62711 .49503 L
s
.64909 .48062 m
.64922 .48379 L
s
.66666 .47269 m
.66585 .47165 L
s
.63164 .49172 m
.63549 .49055 L
s
.62711 .49503 m
.63164 .49172 L
s
.66585 .47165 m
.66272 .47068 L
s
.65281 .47628 m
.64909 .48062 L
s
.66272 .47068 m
.65736 .47296 L
s
.65736 .47296 m
.65281 .47628 L
s
.67789 .45962 m
.67717 .46177 L
s
.67717 .46177 m
.67485 .46183 L
s
.67485 .46183 m
.67556 .45968 L
s
.67556 .45968 m
.67789 .45962 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2;0?ooo`030000o`3oool0oooo00@0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`290?ooo`030000o`3oool0oooo00D0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
R@3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`290?ooo`030000o`3o
ool0oooo00<0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo07h0oooo10000?l60?ooo`030000o`3oool0
oooo00<0oooo00<000000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool0
02`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1l0?ooo`050000o`3oool0oooo
0?ooo`000?l01`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00h0oooo0`000014
0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0NP3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00D0003o0?oo
o`3oool0oooo0000000<0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo07P0oooo00<0003o0?ooo`3oool00`3oool01000
0?l0oooo0?ooo`000?l50?ooo`050000o`3oool0oooo0?ooo`0000002@3oool3000004/0oooo00<0
00000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1g
0?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3o
ool0oooo000000H0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0MP3oool010000?l0oooo0?ooo`000?l40?ooo`030000
o`3oool0oooo00P0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0
oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00T0oooo1000001E0?ooo`030000003oool0oooo01L0oooo
000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0K@3oool50000o`@0oooo00D0
003o0?ooo`3oool0oooo0000o`0:0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3o
ool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01`3o
ool40000o`P0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0
oooo0100oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
02X0oooo0P00001Y0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`060?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0I`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0`00000;0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo
00<000000?ooo`3oool0IP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<00000
3P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1V0?ooo`030000
o`3oool0oooo00@0oooo00@0003o00000000000000004@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`1O0?ooo`030000o`3oool0oooo00<0oooo1`000?l00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo05l0
oooo00<0003o0?ooo`3oool0103oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0
oooo00<000000?ooo`3oool0G`3oool00`000?l0oooo0?ooo`03000001/0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo00@0oooo00<0003o000000000000
7P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0E`3oool00`000?l0oooo00000003000000030?ooo`00
0?l0oooo01h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05D0oooo0P0000000`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`0000030?oo
o`030000o`3oool0oooo0280oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool00`000?l00000000000070?ooo`03
0000o`3oool0oooo00@0oooo0P000?lK0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
B@3oool3000000030?ooo`000?l0oooo00L0oooo00<0003o0?ooo`3oool0103oool20000oa/0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000
000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool3000000D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h
0?ooo`030000003oool0oooo0440oooo0`0000090?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool08`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?oo
o`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0oooo0`00000<0?oo
o`H0003o9@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0>@3oool3000000H0oooo0`000?l70?ooo`03
0000o`3oool0oooo02L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
9`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`0000020?ooo`030000
o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0P000?l60?ooo`030000o`3oool0oooo02H0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000060?ooo`030000o`3oool0oooo0080003o
1@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02D0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02d0oooo0`00000:0?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<000003P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool30000
0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`0Q0?ooo`<000003`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4000001<0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000o`030000oc40oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo01P0oooo0`00000D0?ooo`D0003o1@3oool00`000?l0oooo0?ooo`0c0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0D0?ooo`<000005@3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000603oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0
oooo0`00000J0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l0>03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0203oool3000001d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0h0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000008@3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<00000903oool0
0`000?l0oooo0?ooo`020?ooo`80003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000X0?ooo`@0003o?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000
oooo0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0A@3oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0h0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07P3oool20000o`@0oooo00<0003o
0?ooo`3oool0=P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01T0oooo00<0003o0?oo
o`3oool00`3oool60000ocD0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0F0?ooo`<0
003o00<0oooo0000o`000?l0103oool00`000?l0oooo0?ooo`0d0?ooo`<000004P3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0<03oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01@0oooo00<0
003o0?ooo`3oool00`3oool20000oc@0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0C
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0<@3oool3000001h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0Y0?oo
o`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`080?ooo`03
0000o`3oool0oooo02H0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0
203oool00`000?l0oooo0?ooo`0S0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0200oooo1000000^0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0<0?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo01h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0<0?ooo`040000o`3oool0003o
0000o`H0oooo0`000?l20?ooo`80003o7P3oool3000003H0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
00d0oooo00<0003o0?ooo`3oool00P000?l70?ooo`80003o7@3oool3000003X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`80
003o8@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00P0oooo0`000?l30?ooo`030000
o`3oool0oooo0200oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`090?ooo`060000o`3o
ool0003o0000o`3oool0003o7`3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00T0oooo
00@0003o0?ooo`3oool0oooo0`000?lK0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
2@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01H0oooo0`00001>0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0I0?ooo`<00000DP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool0
0`000000oooo0000o`040000o`H0oooo00<0003o0?ooo`3oool0503oool4000005H0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?oo
o`03000000000?l0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0A0?oo
o`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`03000000000?l0oooo00D0oooo0P000?lD0?ooo`<0
0000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000?l0oooo0?ooo`050?ooo`80
003o4@3oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`00
6P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0000o`0=0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool4000006X0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo08l0oooo0P000?l40?ooo`030000o`3oool0oooo00P0oooo0`00001_0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo
0900oooo00<000000?ooo`000?l00`000?l80?ooo`<00000LP3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`270?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0
103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`280?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo
0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00
002:0?ooo`80003o103oool00`000?l0000000000002000008<0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool2000008d0oooo0`000?l3000008H0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`220?oo
o`<0003o1`3oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo0800oooo0P000?l30?ooo`<0
003o100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo00<0oooo
0`0000000`000?l0oooo0?ooo`060?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1m0?ooo`80003o0`3o
ool3000000@0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool0
0`000?l0oooo0?ooo`03000000L0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?oo
o`3oool0O03oool3000000X0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0N03oool400000080oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`040?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1f0?ooo`<000001`3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00@0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000;0?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<00000403oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool30000
01@0oooo00@0003o0?ooo`000?l0003o2@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool40000
01P0oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.67265 .46036 m
.66155 .44597 L
s
.61637 .51772 m
.61425 .51801 L
s
.61685 .51545 m
.61637 .51772 L
s
.61473 .51574 m
.61685 .51545 L
s
.61425 .51801 m
.61473 .51574 L
s
.59085 .54112 m
.57309 .52038 L
s
.50874 .62217 m
.50352 .62733 L
s
.51047 .61866 m
.50874 .62217 L
s
.50352 .62733 m
.50002 .62898 L
s
.51132 .61421 m
.51047 .61866 L
s
.6515 .46861 m
.64759 .47247 L
s
.65461 .46373 m
.6515 .46861 L
s
.64759 .47247 m
.64288 .47531 L
s
.50002 .62898 m
.49562 .6297 L
s
.65431 .4604 m
.65461 .46373 L
s
.62935 .49047 m
.62544 .49433 L
s
.63114 .48689 m
.62935 .49047 L
s
.62544 .49433 m
.62201 .4959 L
s
.64288 .47531 m
.63995 .47456 L
s
.60978 .50978 m
.59811 .4957 L
s
.51085 .61104 m
.51132 .61421 L
s
.63212 .48229 m
.63114 .48689 L
s
.62201 .4959 m
.61775 .49647 L
s
.59543 .52395 m
.5972 .52038 L
s
.59151 .52781 m
.59543 .52395 L
s
.49562 .6297 m
.49252 .62914 L
s
.58806 .5294 m
.59151 .52781 L
s
.40666 .72294 m
.40965 .71818 L
s
.39747 .73201 m
.40666 .72294 L
s
.5972 .52038 m
.596 .51611 L
s
.39747 .73201 m
.37728 .71351 L
s
.56799 .55102 m
.56975 .54747 L
s
.56407 .55489 m
.56799 .55102 L
s
.63995 .47456 m
.63964 .47123 L
s
.5606 .5565 m
.56407 .55489 L
s
.5816 .53031 m
.58806 .5294 L
s
.55884 .56006 m
.54061 .53945 L
s
.40965 .71818 m
.41039 .71383 L
s
.54968 .56909 m
.5375 .55548 L
s
.56975 .54747 m
.57067 .54293 L
s
.54445 .57426 m
.54052 .57813 L
s
.5462 .57071 m
.54445 .57426 L
s
.61775 .49647 m
.61397 .49473 L
s
.49252 .62914 m
.48851 .62764 L
s
.54052 .57813 m
.53703 .57976 L
s
.55626 .55714 m
.5606 .5565 L
s
.5235 .59493 m
.52743 .59105 L
s
.52 .59657 m
.5235 .59493 L
s
.54709 .56619 m
.5462 .57071 L
s
.63964 .47123 m
.64144 .46763 L
s
.51695 .6014 m
.50449 .58804 L
s
.53703 .57976 m
.53266 .58043 L
s
.41039 .71383 m
.40981 .71076 L
s
.596 .51611 m
.58758 .50609 L
s
.57067 .54293 m
.56942 .53869 L
s
.51561 .59726 m
.52 .59657 L
s
.64144 .46763 m
.64717 .46015 L
s
.48154 .63634 m
.46349 .62847 L
s
.64717 .46015 m
.64897 .45654 L
s
.47104 .6467 m
.46349 .62847 L
s
.47104 .6467 m
.4529 .63892 L
s
.61397 .49473 m
.61231 .49271 L
s
.48851 .62764 m
.484 .62296 L
s
.46053 .65707 m
.4529 .63892 L
s
.53266 .58043 m
.52872 .57884 L
s
.40981 .71076 m
.40829 .7068 L
s
.64897 .45654 m
.64867 .45318 L
s
.45133 .66615 m
.43832 .6533 L
s
.44607 .67134 m
.44213 .67523 L
s
.44778 .66783 m
.44607 .67134 L
s
.44213 .67523 m
.43857 .67692 L
s
.51163 .5957 m
.51561 .59726 L
s
.42503 .6921 m
.42898 .68821 L
s
.42146 .69381 m
.42503 .6921 L
s
.44856 .66341 m
.44778 .66783 L
s
.56942 .53869 m
.56771 .53671 L
s
.41845 .6986 m
.40517 .686 L
s
.61231 .49271 m
.61113 .48838 L
s
.43857 .67692 m
.43407 .67771 L
s
.64867 .45318 m
.64786 .45215 L
s
.41694 .69461 m
.42146 .69381 L
s
.40829 .7068 m
.40354 .70235 L
s
.52872 .57884 m
.52696 .57691 L
s
.64786 .45215 m
.64492 .45137 L
s
.56771 .53671 m
.56382 .53505 L
s
.63311 .46302 m
.63344 .46638 L
s
.65804 .43843 m
.65753 .44077 L
s
.65753 .44077 m
.65542 .44102 L
s
.43407 .67771 m
.42995 .67629 L
s
.49716 .60997 m
.50374 .60348 L
s
.50106 .60063 m
.50374 .60348 L
s
.62129 .47468 m
.62557 .47414 L
s
.41278 .69322 m
.41694 .69461 L
s
.61113 .48838 m
.61209 .48375 L
s
.65592 .43868 m
.65804 .43843 L
s
.484 .62296 m
.4826 .61884 L
s
.65542 .44102 m
.65592 .43868 L
s
.52696 .57691 m
.52563 .57271 L
s
.64492 .45137 m
.64017 .45422 L
s
.63623 .4581 m
.63311 .46302 L
s
.61783 .47625 m
.62129 .47468 L
s
.64017 .45422 m
.63623 .4581 L
s
.56382 .53505 m
.55946 .53566 L
s
.61209 .48375 m
.61389 .48014 L
s
.42995 .67629 m
.42807 .67447 L
s
.49794 .60003 m
.50106 .60063 L
s
.55024 .54476 m
.54934 .54932 L
s
.61389 .48014 m
.61783 .47625 L
s
.53574 .55906 m
.54013 .55842 L
s
.4826 .61884 m
.4821 .61565 L
s
.40354 .70235 m
.39935 .70097 L
s
.52563 .57271 m
.52651 .56817 L
s
.55946 .53566 m
.55596 .53727 L
s
.42807 .67447 m
.42657 .67043 L
s
.55201 .54117 m
.55024 .54476 L
s
.4935 .60072 m
.49794 .60003 L
s
.53222 .56069 m
.53574 .55906 L
s
.4821 .61565 m
.48293 .61115 L
s
.55596 .53727 m
.55201 .54117 L
s
.52651 .56817 m
.52826 .56459 L
s
.52826 .56459 m
.53222 .56069 L
s
.39935 .70097 m
.3961 .70048 L
s
.48995 .60238 m
.4935 .60072 L
s
.43661 .65683 m
.44113 .65607 L
s
.48293 .61115 m
.48466 .60759 L
s
.42657 .67043 m
.42734 .66598 L
s
.48466 .60759 m
.48995 .60238 L
s
.3961 .70048 m
.39153 .7013 L
s
.43302 .65853 m
.43661 .65683 L
s
.42734 .66598 m
.42905 .66245 L
s
.42905 .66245 m
.43302 .65853 L
s
.39153 .7013 m
.38658 .70433 L
s
.38658 .70433 m
.37728 .71351 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`290?ooo`80003o3P3oool00`000000oooo0?ooo`0f0?ooo`<00000
6`3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool200000580oooo00<000000?ooo`3oool0R03o
ool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo03<0oooo0`00000N0?ooo`030000003o
ool0oooo01X0oooo000]0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0RP3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo0300oooo0`00000Q0?ooo`030000003oool0
oooo01X0oooo000]0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0RP3oool00`00
0?l0oooo0?ooo`090?ooo`030000003oool0oooo02d0oooo0`00000U0?ooo`030000003oool0oooo
01T0oooo000]0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0P@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool3000002P0
oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`1o0?ooo`040000o`3oool0003o0000o`H0oooo00<0003o0?ooo`3oool0203oool00`000000
oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo07d0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`03
0000o`3oool0oooo00L0oooo00<000000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1k0?ooo`050000
o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo0240
oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo
00<000000?ooo`3oool0N@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`H0
oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000
oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07P0oooo
00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`1g0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3o
ool03`3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00
;03oool2000005d0oooo00<000000?ooo`3oool0N03oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00l0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0
603oool002/0oooo0P00001O0?ooo`030000003oool0oooo07L0oooo00<0003o0?ooo`3oool00P00
0?lB0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0L03oool20000o`D0oooo0P000?lD
0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool0K@3oool20000oad0oooo00<000000?oo
o`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3o
ool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5P3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06P0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0G0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo
0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo06L0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06H0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0E0?ooo`<00000F03oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06D0oooo00<0003o0?oo
o`3oool00P3oool20000oaD0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1O0?ooo`03
0000o`3oool0oooo00<0oooo10000?lD0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1P0?ooo`030000
o`3oool0oooo01L0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1P0?ooo`030000o`3o
ool0oooo01<0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0G`3oool0
0`000?l0oooo0?ooo`0@0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool0
0`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0303oool3
00000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0F03oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00P0oooo0`00000D0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool0303oool3
000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0E`3oool0
0`000?l0oooo0?ooo`050?ooo`80003o00@0oooo00000000000000006`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool0103oool20000o`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0000000300000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04h0oooo00<0003o0?ooo`3o
ool0103oool00`000?l000000000000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`1=0?ooo`040000
o`3oool0oooo0?ooo`80000000<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=0?ooo`050000
o`00000000000?ooo`000?l0:@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04T0oooo
0`000000103oool0003o0000o`000?lZ0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo04D0oooo0`0000050?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0@@3oool60000o`D0oooo00<0003o0?ooo`3oool0:@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool00P000000
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0>@3oool00`000000003o000000020?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0e0?ooo`<000000P3oool00`000?l0oooo0000o`070?ooo`030000o`3oool0oooo02h0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000060?ooo`80003o1P3oool00`000?l0oooo
0?ooo`0_0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<000002@3oool20000o`H0oooo00<0
003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000000d0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000;0?oo
o`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo0P000?lb0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`0Q0?ooo`<000003`3oool00`000?l0oooo0?ooo`030?ooo`<0003o=03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0703oool4000000l0oooo0`000?l00`3oool0003o0?ooo`040?ooo`03
0000o`3oool0oooo03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000B0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503o
ool3000001D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0h0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`0@0?ooo`<000005`3oool00`000?l0oooo0?ooo`050?ooo`80003o>@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0303oool3000001X0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0h0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000007@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo
0`00000P0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool00`00000T0?ooo`030000o`3oool0oooo0080003o?@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000X
0?ooo`80003o?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3o
ool0A03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0
?`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0d0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0803oool0
10000?l0oooo0?ooo`3oool20000oc@0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q
0?ooo`<0003o<`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01T0oooo10000?l50?oo
o`030000o`3oool0oooo02l0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<03oool4000001X0oooo00<000000?ooo`3o
ool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo01L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0^0?ooo`<00000
7P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo02`0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0U0?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool08@3oool30000
02X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0N0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo01/0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0603oool3000003H0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0F
0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0503oool3000003h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00l0oooo0`000?l70?ooo`D0003o4`3oool400000480oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo0100oooo00@0003o0?ooo`000?l0003o6P3oool3000004L0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo0100oooo00@0003o0?ooo`3oool0oooo0P000?lE0?ooo`<00000BP3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01D0oooo
0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00
002>0?ooo`030000003oool0oooo00/0oooo0`000?l20?ooo`030000o`3oool0oooo0180oooo0`00
001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@
0?ooo`030000003oool0oooo00`0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l?0?ooo`@00000
EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0303oool010000?l0oooo0?ooo`3oool20000o``0oooo
0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P00
00070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?oo
o`0;0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0=0?ooo`030000o`3oool0oooo00P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`04
0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00D0oooo0P000?l70?oo
o`030000o`3oool0oooo00@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`030?ooo`80003o0P3oool00`000?l0oooo0?ooo`040?ooo`<00000K`3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`050000003oool0oooo0?ooo`000?l01P3oool3000007H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`050000003oool0oooo0?ooo`000?l00P3oool4000000030?ooo`000?l0003o07L0oooo
00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`040000003oool0oooo0?ooo`<00000103oool00`000?l0oooo0?ooo`1h0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@0000000<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<000000`3oool20000o`@0oooo00<0003o
0?ooo`3oool0NP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo00<0oooo10000?mn0?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`220?ooo`<00000203oool01@000?l0oooo0?ooo`3oool0000008X0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<00000303oool010000?l0oooo0?ooo`0000040?ooo`030000o`3oool0oooo08@0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1l0?ooo`<00000403oool00`000?l000000?ooo`020?ooo`80003oQ`3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D
0?ooo`@0003oRP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo07H0oooo0`00000H0?ooo`03000000000?l0oooo08`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<0
00005@3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0003o08d0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<00000
5P3oool20000o`030?ooo`000?l0003o00<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3000001L0oooo0P00
0?l50?ooo`040000o`3oool0oooo00000900oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@000006@3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool000000940oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<000006`3oool20000o`X0oooo00<0003o
0000003oool0T@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo06@0oooo0`00000M0?ooo`030000o`3oool0oooo00X0oooo00<0003o0000
003oool0TP3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo0640oooo0`00000Q0?ooo`030000o`3oool0oooo00T0oooo00<0003o0000003o
ool0T`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo05h0oooo0`00000U0?ooo`030000o`3oool0oooo00P0oooo00<0003o0000003oool0
T`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05X0oooo1000000Y0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`000000U@3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05L0oooo0`00000^0?ooo`80003o1@3oool010000?l0oooo0?ooo`00002F0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3
000003<0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B
0?ooo`<00000=`3oool00`000?l0oooo0000o`040?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?oo
o`@00000>`3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo09H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<0
0000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3o
ool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3o
ool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0
oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo
00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<00000
0?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<0
0000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0
X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0
oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo
00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?oo
o`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<00000
0?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<0
0000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0
Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003o
ool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool0
0`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool000000080
0000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3o
ool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2
000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0
oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo
000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000
003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo
0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000
003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503o
ool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0
oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`00
0000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340
oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<0
00000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80
000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<0
00000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m
0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3o
ool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo
0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V
0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`02
0?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?oo
o`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?oo
o`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?oo
o`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`03
0000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003o
ool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool3
00000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000
oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`04
0000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<0
00000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?oo
o`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03o
ool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0
oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0
oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo
001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a
0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000
003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003o
ool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0
oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo
000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool01000
0000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4
000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool0
0`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`00
0000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo
1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo
1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00
001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`80
00000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00
R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00
S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`00
0000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000
oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo
1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000
002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?oo
o`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?oo
o`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`80
0000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000
903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003o
ool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3o
ool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2
000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo
000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool0
06@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000
oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo
1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y
0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0
oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool30000
0>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool2
00000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L
0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool20000
00@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.64767 .44563 m
.6365 .43129 L
s
.62949 .4554 m
.62633 .45964 L
s
.63184 .45015 m
.62949 .4554 L
s
.60222 .50873 m
.60034 .50917 L
s
.60246 .50633 m
.60222 .50873 L
s
.63128 .4467 m
.63184 .45015 L
s
.62633 .45964 m
.62235 .46287 L
s
.60058 .50676 m
.60246 .50633 L
s
.60034 .50917 m
.60058 .50676 L
s
.62235 .46287 m
.61967 .46226 L
s
.61153 .47947 m
.60835 .48373 L
s
.61283 .47563 m
.61153 .47947 L
s
.61967 .46226 m
.61909 .45881 L
s
.61331 .47077 m
.61283 .47563 L
s
.60835 .48373 m
.60541 .48557 L
s
.58123 .53482 m
.56345 .5141 L
s
.61909 .45881 m
.6204 .45495 L
s
.60541 .48557 m
.60164 .48641 L
s
.62488 .44685 m
.62618 .44299 L
s
.6204 .45495 m
.62488 .44685 L
s
.62618 .44299 m
.62562 .43951 L
s
.59561 .50081 m
.58391 .48676 L
s
.63272 .42366 m
.63247 .42611 L
s
.63247 .42611 m
.6306 .42649 L
s
.62562 .43951 m
.6248 .43848 L
s
.60164 .48641 m
.59809 .48482 L
s
.63085 .42403 m
.63272 .42366 L
s
.6248 .43848 m
.62211 .43783 L
s
.6306 .42649 m
.63085 .42403 L
s
.5839 .51651 m
.58519 .51267 L
s
.5807 .52081 m
.5839 .51651 L
s
.58519 .51267 m
.58375 .50826 L
s
.57772 .52269 m
.5807 .52081 L
s
.62211 .43783 m
.61811 .44106 L
s
.59809 .48482 m
.59643 .4828 L
s
.61254 .45063 m
.61312 .4541 L
s
.57197 .52403 m
.57772 .52269 L
s
.61811 .44106 m
.61491 .44533 L
s
.58375 .50826 m
.57531 .49826 L
s
.60294 .46345 m
.60673 .46264 L
s
.59643 .4828 m
.59499 .47834 L
s
.61491 .44533 m
.61254 .45063 L
s
.56142 .54664 m
.56272 .54279 L
s
.5582 .55096 m
.56142 .54664 L
s
.59998 .46529 m
.60294 .46345 L
s
.56272 .54279 m
.56316 .53795 L
s
.59499 .47834 m
.59546 .47345 L
s
.55519 .55287 m
.5582 .55096 L
s
.5539 .55672 m
.53566 .53613 L
s
.59677 .46958 m
.59998 .46529 L
s
.56316 .53795 m
.56167 .53357 L
s
.59546 .47345 m
.59677 .46958 L
s
.55132 .55381 m
.55519 .55287 L
s
.54636 .56683 m
.53418 .55322 L
s
.54205 .57261 m
.53881 .57695 L
s
.54334 .56875 m
.54205 .57261 L
s
.56167 .53357 m
.55996 .5316 L
s
.54377 .56393 m
.54334 .56875 L
s
.53881 .57695 m
.53578 .57889 L
s
.51356 .62567 m
.50922 .63149 L
s
.51485 .62182 m
.51356 .62567 L
s
.51525 .61704 m
.51485 .62182 L
s
.55996 .5316 m
.5563 .53008 L
s
.50922 .63149 m
.50616 .63348 L
s
.53578 .57889 m
.53187 .57987 L
s
.51457 .61371 m
.51525 .61704 L
s
.52474 .59581 m
.52799 .59145 L
s
.50616 .63348 m
.5022 .63454 L
s
.52169 .59777 m
.52474 .59581 L
s
.53187 .57987 m
.52815 .57844 L
s
.5563 .53008 m
.55242 .53099 L
s
.51932 .60308 m
.50686 .58972 L
s
.51775 .59878 m
.52169 .59777 L
s
.5022 .63454 m
.49933 .63415 L
s
.55242 .53099 m
.54938 .5329 L
s
.52815 .57844 m
.52639 .57652 L
s
.514 .59738 m
.51775 .59878 L
s
.54483 .54113 m
.5444 .546 L
s
.49933 .63415 m
.49554 .63281 L
s
.54938 .5329 m
.54613 .53725 L
s
.54613 .53725 m
.54483 .54113 L
s
.53288 .55711 m
.5368 .55616 L
s
.52639 .57652 m
.52484 .57216 L
s
.49554 .63281 m
.49103 .62814 L
s
.48988 .64254 m
.47271 .63536 L
s
.52982 .55904 m
.53288 .55711 L
s
.52484 .57216 m
.52525 .5673 L
s
.50199 .61347 m
.50746 .60615 L
s
.50477 .6033 m
.50746 .60615 L
s
.52655 .56341 m
.52982 .55904 L
s
.52525 .5673 m
.52655 .56341 L
s
.48111 .65429 m
.47271 .63536 L
s
.48111 .65429 m
.46385 .64721 L
s
.50188 .60286 m
.50477 .6033 L
s
.47232 .66608 m
.46385 .64721 L
s
.49103 .62814 m
.48941 .62384 L
s
.49788 .60388 m
.50188 .60286 L
s
.46462 .67641 m
.45162 .66354 L
s
.4602 .68232 m
.45689 .68676 L
s
.46149 .67845 m
.4602 .68232 L
s
.48941 .62384 m
.4887 .62048 L
s
.46185 .67367 m
.46149 .67845 L
s
.45689 .68676 m
.45375 .68882 L
s
.49478 .60587 m
.49788 .60388 L
s
.42801 .74051 m
.4304 .73517 L
s
.42024 .75095 m
.42801 .74051 L
s
.4887 .62048 m
.48908 .61565 L
s
.4304 .73517 m
.43073 .73043 L
s
.45375 .68882 m
.44968 .68997 L
s
.49038 .61175 m
.49478 .60587 L
s
.44251 .70604 m
.44583 .70159 L
s
.48908 .61565 m
.49038 .61175 L
s
.43073 .73043 m
.42996 .72717 L
s
.42024 .75095 m
.40006 .73245 L
s
.43935 .70812 m
.44251 .70604 L
s
.44968 .68997 m
.44577 .68873 L
s
.43696 .71348 m
.42369 .70087 L
s
.42996 .72717 m
.42823 .72302 L
s
.43525 .7093 m
.43935 .70812 L
s
.44577 .68873 m
.44389 .68691 L
s
.4313 .7081 m
.43525 .7093 L
s
.42823 .72302 m
.42348 .71856 L
s
.45033 .66744 m
.45442 .66632 L
s
.44389 .68691 m
.44219 .68268 L
s
.44717 .6695 m
.45033 .66744 L
s
.44219 .68268 m
.44253 .67787 L
s
.42348 .71856 m
.4195 .71737 L
s
.44382 .67397 m
.44717 .6695 L
s
.44253 .67787 m
.44382 .67397 L
s
.4195 .71737 m
.41647 .71708 L
s
.41647 .71708 m
.4123 .71829 L
s
.4123 .71829 m
.40795 .7219 L
s
.40795 .7219 m
.40006 .73245 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`260?ooo`80003o5`3oool00`000000
oooo0?ooo`190?ooo`<000001`3oool00`000000oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo08D0oooo0P000?lG0?ooo`030000003oool0oooo04H0oooo
0`00000;0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0W@3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo0?oo
o`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo08D0oooo00<0003o
0?ooo`3oool0503oool00`000000oooo0?ooo`100?ooo`<000004@3oool00`000000oooo0?ooo`0J
0?ooo`00;P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo08D0oooo00<0003o0?oo
o`3oool04`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo03T0oooo1000000G0?ooo`03
0000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
O03oool00`000?l0oooo0000o`050?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0
=P3oool3000001/0oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000003o
ool0oooo07X0oooo00@0003o0?ooo`3oool0003o1P3oool00`000?l0oooo0?ooo`0A0?ooo`030000
003oool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0N03oool01@000?l0oooo0?ooo`3oool0003o00L0oooo
00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo
0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo07H0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0000o`0H0?ooo`030000003oool0oooo02d0oooo0`00
000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool0M@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool05P3o
ool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000oooo0?ooo`0I0?ooo`00;@3oool0
0`000000oooo0?ooo`1E0?ooo`030000003oool0oooo07D0oooo00@0003o0?ooo`3oool0003o0P3o
ool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo02L0oooo0`00000[0?ooo`030000003o
ool0oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0MP3oool0
1@000?l0oooo0?ooo`3oool0003o01P0oooo00<000000?ooo`3oool0903oool3000002h0oooo00<0
00000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1e
0?ooo`040000o`3oool0003o0000oaT0oooo00<000000?ooo`3oool08@3oool300000340oooo00<0
00000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1d
0?ooo`80003o6`3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I
0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06d0oooo0P000?l50?oo
o`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1[0?ooo`03
0000o`3oool0oooo0280oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3o
ool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo06P0oooo0P000?lU0?ooo`030000
003oool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3o
ool00`000000oooo0?ooo`1W0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool07@3o
ool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo06H0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0I@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3oool02P3oool40000
04L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`1T0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool07P3oool00`000000
oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0O0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool40000ob80oooo00@0
00000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003o
ool0oooo06@0oooo00<000000?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0X0?ooo`@00000E@3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo05d0oooo00<0003o0?ooo`3oool09@3oool3000005P0oooo00<000000?ooo`3oool05`3oool0
02X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo
0240oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0
oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1L0?ooo`030000o`3oool0oooo01h0
oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
0P00001Y0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0J0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo01H0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0I0?ooo`<000003P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`1F0?ooo`030000o`3oool0oooo00@0oooo0P000?l?
0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1F
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02`3oool3000001@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0>
0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1<
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool02`3oool3000001/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0203oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo04`0oooo00@0003o0?ooo`3o
ool0oooo0P000?l70?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0C03oool00`000?l0
oooo0000o`060?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0B`3oool20000o`@0oooo
0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00
001f0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`0000000P00000[0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0@P3oool40000o`<0oooo0P0000000`000?l0oooo0?ooo`0/
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?oo
o`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0400oooo00D0003o0?oo
o`3oool0oooo0000o`03000000<0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`0j0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool2
000000030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?oo
o`030000003oool0oooo03X0oooo00<0003o0?ooo`000?l00`0000030?ooo`030000o`3oool0oooo
0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo00<0003o000000000?l01P3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo
00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<0000000<0oooo0000o`000?l0
1P3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<000001@3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0
oooo02d0oooo0`0000090?ooo`050000o`3oool0oooo0?ooo`000?l0=@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0:@3oool3000000L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`02
0000ocD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool30000
0840oooo00<000000?ooo`3oool09@3oool3000000/0oooo00<0003o0?ooo`3oool00P3oool20000
ocL0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000=0?ooo`<0003o103oool00`000?l0
oooo0?ooo`0e0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000003P3oool20000o`<0oooo
00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000140oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D
0?ooo`<00000503oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0003o03X0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0100oooo0`00000G0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001X0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000
7@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00@0oooo0`00000P0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool00`00000T0?ooo`@0003o?P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00001Y0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`03
0000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0I03oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo01h0oooo00<0003o0?ooo`3oool0?`3oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0d0?ooo`<000002P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0380oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q0?ooo`@0003o<P3oool300000180
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0;`3oool3000001H0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01/0oooo0`000?l50?ooo`030000o`3oool0oooo02X0oooo1000
000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0I0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0/
0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo02X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0H0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool09`3oool3000002H0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0
5`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
803oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0L0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01T0oooo0`00000c0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool05P3oool30000
03H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0D0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0140oooo0`00000n0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03P3oool400000480oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo01/0oooo00@0003o0?ooo`3oool0oooo0P000?l=0?ooo`<00000A`3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool04P3oool20000o`P0oooo0`000?l<0?ooo`<00000BP3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool04P3oool010000?l0oooo0000o`000?lB0?ooo`<00000CP3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`00
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0080003o3@3oool300000580oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool04`3oool00`000?l0oooo0?ooo`020?ooo`80003o1`3oool4000005H0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`<00000
F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00l0oooo0`000?l20?ooo`030000o`3o
ool0oooo00@0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3o
ool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0100oooo00H0003o0?ooo`000?l0003o0?ooo`000?l20?ooo`<00000HP3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0@0?ooo`050000o`3oool0oooo0?ooo`00
0?l00`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0403oool00`000?l00000
00000002000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3o
ool3000000030000o`3oool0oooo06`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;
0?ooo`<000000`3oool00`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?oo
o`<000001`3oool00`000?l0oooo0?ooo`1/0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@0
00000P3oool20000o`H0oooo00<0003o0?ooo`3oool0K@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0
oooo0`0000050?ooo`030000o`3oool0oooo0080003oM@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000000H0oooo0P000?l50?ooo`030000
o`3oool0oooo07<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool200000900oooo0`0000090?ooo`030000o`3oool0oooo00@0oooo0P000?md0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool3
00000080oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo07@0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0MP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo00L0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1g0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo
00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo07T0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`080?ooo`@0003oO@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool01@000000oooo0?ooo`3oool0003o00L0oooo
00<0003o0?ooo`3oool0PP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo08<0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`03
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`250?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool01@3oool20000ohT0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`060?ooo`03
0000o`3oool0oooo08P0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo1@000?n@0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0FP3oool400000380oooo0P000?l00`000000oooo0?ooo`02
0?ooo`030000o`3oool0oooo08h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000=@3oool010000?l0oooo0?ooo`000005
0?ooo`030000o`3oool0oooo08h0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;
0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000=`3oool01@000?l0oooo0?ooo`3oool0
000000D0oooo00<0003o0?ooo`3oool0S`3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000j0?ooo`050000o`3oool0oooo
0?ooo`0000001@3oool00`000?l0oooo0?ooo`2@0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4000003`0oooo00<0003o0?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0900oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<0
0000@@3oool01@000?l0oooo0?ooo`3oool0000000D0oooo00<0003o0?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004D0
oooo00@0003o0?ooo`3oool00000103oool00`000?l0oooo0?ooo`2C0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004T0
oooo00<0003o0?ooo`000000103oool00`000?l0oooo0?ooo`2D0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004d0oooo
0P000?l30?ooo`030000o`3oool0oooo09H0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool01@000000003o0?oo
o`3oool0003o09T0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool010000000oooo0000o`000?nJ0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3o
ool3000005P0oooo00@000000?ooo`3oool0003oV`3oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61855 .43757 m
.60728 .42333 L
s
.60521 .44269 m
.60372 .44812 L
s
.60436 .43919 m
.60521 .44269 L
s
.60372 .44812 m
.6014 .45255 L
s
.6014 .45255 m
.59827 .45598 L
s
.59827 .45598 m
.59585 .45544 L
s
.59585 .45544 m
.59499 .45194 L
s
.58548 .5036 m
.58388 .50411 L
s
.58544 .50112 m
.58548 .5036 L
s
.59878 .43955 m
.59951 .43557 L
s
.59572 .44796 m
.59878 .43955 L
s
.60317 .41569 m
.60321 .41819 L
s
.60321 .41819 m
.60162 .41863 L
s
.59951 .43557 m
.59865 .43205 L
s
.58383 .50163 m
.58544 .50112 L
s
.60157 .41613 m
.60317 .41569 L
s
.59055 .47331 m
.58822 .47777 L
s
.59129 .46933 m
.59055 .47331 L
s
.59499 .45194 m
.59572 .44796 L
s
.59119 .46435 m
.59129 .46933 L
s
.58388 .50411 m
.58383 .50163 L
s
.60162 .41863 m
.60157 .41613 L
s
.59865 .43205 m
.59783 .43102 L
s
.58822 .47777 m
.58583 .47976 L
s
.59783 .43102 m
.59541 .43045 L
s
.58583 .47976 m
.58261 .48074 L
s
.59541 .43045 m
.59224 .43387 L
s
.58261 .48074 m
.57933 .47924 L
s
.59224 .43387 m
.5899 .43832 L
s
.58839 .4438 m
.58926 .44733 L
s
.57885 .49571 m
.56708 .48171 L
s
.5899 .43832 m
.58839 .4438 L
s
.56979 .53116 m
.55195 .5105 L
s
.58134 .45722 m
.58457 .45626 L
s
.57933 .47924 m
.57766 .47723 L
s
.57766 .47723 m
.57593 .47271 L
s
.5702 .51224 m
.57094 .50824 L
s
.56784 .51677 m
.5702 .51224 L
s
.57094 .50824 m
.5692 .50377 L
s
.57893 .45919 m
.58134 .45722 L
s
.56541 .51881 m
.56784 .51677 L
s
.57657 .46368 m
.57893 .45919 L
s
.57593 .47271 m
.57583 .46769 L
s
.5692 .50377 m
.56073 .4938 L
s
.56049 .5204 m
.56541 .51881 L
s
.57583 .46769 m
.57657 .46368 L
s
.55357 .54407 m
.55431 .54005 L
s
.55118 .54865 m
.55357 .54407 L
s
.55431 .54005 m
.55419 .53505 L
s
.55419 .53505 m
.55242 .53059 L
s
.54872 .55073 m
.55118 .54865 L
s
.54798 .55476 m
.52971 .53419 L
s
.5454 .55185 m
.54872 .55073 L
s
.55242 .53059 m
.5507 .52863 L
s
.5507 .52863 m
.54732 .5272 L
s
.54238 .56548 m
.53018 .55189 L
s
.53916 .57163 m
.53675 .57625 L
s
.5399 .56759 m
.53916 .57163 L
s
.53978 .56259 m
.5399 .56759 L
s
.54732 .5272 m
.54398 .52828 L
s
.53675 .57625 m
.53427 .57837 L
s
.53427 .57837 m
.53091 .57954 L
s
.54398 .52828 m
.5415 .53035 L
s
.52625 .59634 m
.52868 .59169 L
s
.5415 .53035 m
.53908 .53496 L
s
.53834 .53901 m
.53847 .54405 L
s
.53091 .57954 m
.52747 .57821 L
s
.53908 .53496 m
.53834 .53901 L
s
.52375 .59849 m
.52625 .59634 L
s
.51943 .62781 m
.51617 .63406 L
s
.52017 .62376 m
.51943 .62781 L
s
.52003 .61877 m
.52017 .62376 L
s
.51908 .61533 m
.52003 .61877 L
s
.52036 .5997 m
.52375 .59849 L
s
.52943 .55595 m
.53281 .55482 L
s
.51617 .63406 m
.51366 .63625 L
s
.52219 .60411 m
.50975 .59074 L
s
.52747 .57821 m
.52571 .57628 L
s
.51366 .63625 m
.51024 .63753 L
s
.52571 .57628 m
.52387 .57183 L
s
.51688 .5984 m
.52036 .5997 L
s
.52693 .55807 m
.52943 .55595 L
s
.52448 .56271 m
.52693 .55807 L
s
.51024 .63753 m
.50764 .63723 L
s
.52387 .57183 m
.52374 .56679 L
s
.52374 .56679 m
.52448 .56271 L
s
.50764 .63723 m
.50413 .636 L
s
.50787 .6156 m
.51197 .60777 L
s
.50929 .60491 m
.51197 .60777 L
s
.50413 .636 m
.49963 .63132 L
s
.50668 .60457 m
.50929 .60491 L
s
.50009 .64638 m
.48404 .63962 L
s
.50323 .6058 m
.50668 .60457 L
s
.49963 .63132 m
.49775 .62692 L
s
.49348 .65903 m
.48404 .63962 L
s
.49348 .65903 m
.47734 .65236 L
s
.50067 .60799 m
.50323 .6058 L
s
.49775 .62692 m
.49676 .62345 L
s
.49736 .61429 m
.50067 .60799 L
s
.48685 .67172 m
.47734 .65236 L
s
.49676 .62345 m
.49661 .61839 L
s
.49661 .61839 m
.49736 .61429 L
s
.48102 .68287 m
.46807 .66998 L
s
.47768 .68927 m
.47517 .69407 L
s
.47843 .68516 m
.47768 .68927 L
s
.47826 .68013 m
.47843 .68516 L
s
.47517 .69407 m
.47257 .69637 L
s
.47257 .69637 m
.46904 .69776 L
s
.46425 .71497 m
.46678 .71013 L
s
.46904 .69776 m
.4654 .69664 L
s
.46163 .71729 m
.46425 .71497 L
s
.45634 .7462 m
.45616 .74118 L
s
.45474 .75195 m
.45634 .7462 L
s
.44881 .76334 m
.45474 .75195 L
s
.45806 .71873 m
.46163 .71729 L
s
.46732 .67412 m
.47087 .67276 L
s
.46003 .72304 m
.44682 .71039 L
s
.45616 .74118 m
.45513 .73779 L
s
.4654 .69664 m
.46353 .69481 L
s
.45513 .73779 m
.45316 .73349 L
s
.46353 .69481 m
.46157 .69045 L
s
.44881 .76334 m
.42874 .74476 L
s
.45439 .71765 m
.45806 .71873 L
s
.46469 .67641 m
.46732 .67412 L
s
.45316 .73349 m
.44843 .72902 L
s
.46215 .68124 m
.46469 .67641 L
s
.46157 .69045 m
.46139 .68539 L
s
.46139 .68539 m
.46215 .68124 L
s
.44843 .72902 m
.44473 .72795 L
s
.44473 .72795 m
.44197 .72778 L
s
.44197 .72778 m
.43834 .72925 L
s
.43834 .72925 m
.43479 .73326 L
s
.43479 .73326 m
.42874 .74476 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo07h0oooo0P000?lR0?ooo`030000003oool0oooo0580oooo0P00
000M0?ooo`00;P3oool2000004P0oooo00<000000?ooo`3oool0O@3oool20000ob80oooo00<00000
0?ooo`3oool0C`3oool3000000030?ooo`000000oooo01`0oooo000_0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07d0
oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`000000
oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo07d0oooo
00<0003o0?ooo`3oool07P3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07d0oooo00<0
003o0?ooo`3oool07@3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo0?oo
o`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo07H0oooo0P000?l5
0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0@03oool300000140oooo00<00000
0?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`1d0?oo
o`030000o`3oool0003o00H0oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0m0?oo
o`<00000503oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0780oooo00@0003o0?ooo`3oool0003o1`3oool00`000?l0oooo0?ooo`0J0?oo
o`030000003oool0oooo03T0oooo1000000G0?ooo`030000003oool0oooo01X0oooo000^0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0L@3oool01P000?l0oooo0?ooo`000?l0oooo
0000ob80oooo00<000000?ooo`3oool0=P3oool3000001/0oooo00<000000?ooo`3oool06P3oool0
02d0oooo0P00001B0?ooo`030000003oool0oooo06l0oooo00D0003o0?ooo`3oool0oooo0000o`02
0?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0<`3oool3000001h0oooo00<00000
0?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`1^0?oo
o`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`0`
0?ooo`<000008@3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo06h0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0P0?oo
o`030000003oool0oooo02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0K`3oool00`000?l0oooo0000o`0S0?ooo`03
0000003oool0oooo02X0oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool0KP3oool00`000?l0oooo0000o`0S0?ooo`030000
003oool0oooo02L0oooo0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool0J@3oool010000?l0oooo0?ooo`3oool20000ob@0oooo
00<000000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`1V0?ooo`80003o:P3oool00`000000oooo0?oo
o`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo06@0oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0N
0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?oo
o`030000003oool0oooo06<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0V0?oo
o`030000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo02H0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3o
ool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0V0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`1P0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3o
ool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo05l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0V0?ooo`030000003oool0
oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0GP3oool01@000?l0oooo0?ooo`3oool0003o02T0oooo00<00000
0?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`1N0?ooo`<0003o:P3oool00`000000oooo0?ooo`070?oo
o`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`03
0000003oool0oooo05P0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`040?ooo`<0
0000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000
003oool0oooo05P0oooo00<0003o0?ooo`3oool0;P3oool010000000oooo0?ooo`3oool300000580
oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`1H0?ooo`030000o`3oool0oooo02d0oooo1000001E0?ooo`030000003oool0oooo01L0oooo
000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?oo
o`0Z0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W
0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0V
0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?oo
o`030000003oool0000006P0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0280oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3o
ool09@3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0J0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo0580oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0G0?ooo`<000003P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1A0?ooo`030000o`3o
ool0oooo01X0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo04X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0F0?ooo`<00000503o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1:0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0503oool3000001P0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0140oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0B@3oool0
1@000?l0oooo0?ooo`3oool0003o0100oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`19
0?ooo`<0003o3@3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo04T0oooo00<0003o0?oo
o`3oool02@3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3o
ool01P3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
:03oool2000007H0oooo00<000000?ooo`3oool0@03oool30000o`D0oooo00<0003o0?ooo`3oool0
0P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0n0?ooo`050000o`3o
ool0oooo0?ooo`000?l01@3oool010000?l0000000000000000^0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo03P0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`04
0000o`3oool0oooo0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0h0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o000000000000=03oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000
oooo0?ooo`1i0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`000?l00P3oool300000003
0000o`3oool0oooo03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03P0oooo0P000?l200000080oooo
00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool200000080003o103o
ool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<000000`3oool0
1@000?l0oooo0?ooo`3oool0003o03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`000007
0?ooo`040000o`3oool0003o0000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`000006
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?oo
o`<00000203oool30000o`@0oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool08@3oool3000000X0oooo00D0003o0?ooo`3oool0oooo0000o`0m0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000
oooo0?ooo`0L0?ooo`@00000303oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03`0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000@0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000001<0oooo00<0
003o0?ooo`3oool00`3oool20000oc`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000F
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0303oool3000001T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`080?ooo`<00000703oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000P0?ooo`050000
o`3oool0oooo0?ooo`000?l0?P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000T0?ooo`<0003o
?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08`0oooo0P00001Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0I03oool30000
0080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0?P3oool4000000H0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0d0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08@3oool01@000?l0oooo0?oo
o`3oool0003o03@0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`040000o`3o
ool0003o0000oc40oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3o
ool0oooo02h0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0
oooo02T0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0M0?ooo`<0003o;@3oool30000
01h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo01`0oooo00D0003o0?ooo`3oool0oooo0000o`0Y0?oo
o`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool06`3oool01@000?l0oooo0?ooo`3oool0003o
02L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0
oooo0P00002?0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0R0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool06P3oool01@000?l0oooo
0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool06`3oool4000002h0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo01/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0G0?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo01@0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool04@3oool3000003X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
01/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0>0?ooo`<00000?P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0
oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0203oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01d0oooo0P00
0?l20?ooo`80003o203oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01l0oooo0P000?l7
0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?oo
o`<00000SP3oool00`000000oooo0?ooo`0F0?ooo`80003o3@3oool300000580oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool05`3oool40000o`H0oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0G0?ooo`040000
o`3oool0oooo0?ooo`80003o00@0oooo0000000000000000F`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01P0oooo00<0003o0?ooo`3oool00`00001N0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01@0oooo00@0003o0?ooo`3oool0oooo0`00001R0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01@0oooo00H0003o00000000
000000000?ooo`000?mT0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool40000
00030000o`3oool0003o0080003oI@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0>0?ooo`<00000103oool010000?l0oooo0?ooo`3oool20000ofD0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0;0?ooo`<000001`3oool00`000?l0oooo0?ooo`1X0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`080?ooo`<000002`3oool00`000?l0oooo0?ooo`1X0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`040?ooo`@000003P3oool00`000?l0oooo0?ooo`1Y0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
10000000oooo0?ooo`3oool3000000`0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`1Y0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A
0?ooo`@00000403oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo06X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000A0?oo
o`80003o00<0oooo0000o`3oool0L03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo00h0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1_0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo
00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo06l0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`250?ooo`<000002@3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00<0oooo0P00
0?ma0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0740oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0LP3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`03
0000003oool0oooo00l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1c0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
N03oool4000001@0oooo00<000000?ooo`3oool0403oool01@000?l0oooo0?ooo`3oool0003o07H0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`0@0?ooo`@0003oN03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00
000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?oo
o`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`1l0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool02P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo07h0oooo00<000000?ooo`3oool0>03o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool0
0`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0O`3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05h0oooo0`00000a0?ooo`030000003oool0oooo00`0oooo10000?n20?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0
oooo00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`230?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo
00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`230?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo00H0oooo1@000?n;
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0CP3oool400000440oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo08P0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`050?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0R03oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0
103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo08P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3o
ool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0R@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo0480oooo0`00001>0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`2:0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo08/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000
oooo0?ooo`040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0R`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo
0`00001H0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`2=0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`07
0?ooo`050000o`3oool0oooo0?ooo`000?l0TP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0
oooo00P0oooo00@0003o0?ooo`3oool0003oT`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo00T0oooo0P000?nD0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`2C0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M
0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?oo
o`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`03
0000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000
O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo
0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0
oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo
0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?oo
o`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool20000
08@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00
001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`80
0000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?oo
o`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`80
0000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003o
ool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool0
1@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0012
0?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3o
ool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo
0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3o
ool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0
oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3o
ool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool20000
00l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0
oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040
oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?oo
o`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F
0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0
oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000
003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`80
0000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3o
ool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool20000
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0
oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo
00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?oo
o`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D0
00008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool20000
03L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0
oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo
00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@0
00000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo
001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00
000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?oo
o`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?oo
o`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3o
ool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000
JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3o
ool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool5
00000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4
000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00
000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I
0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?oo
o`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000
VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000
WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3o
ool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool0
06D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0
oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo
0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@0
00000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo
1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`04
0?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?oo
o`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@0
0000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo
00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo
002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo
1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.58661 .43629 m
.5752 .42219 L
s
.57592 .44147 m
.57534 .44689 L
s
.57475 .43798 m
.57592 .44147 L
s
.57534 .44689 m
.57394 .45132 L
s
.57394 .45132 m
.57171 .45476 L
s
.57072 .41461 m
.57108 .4171 L
s
.57108 .4171 m
.56978 .41755 L
s
.57171 .45476 m
.56959 .45424 L
s
.56943 .41506 m
.57072 .41461 L
s
.56978 .41755 m
.56943 .41506 L
s
.57016 .43441 m
.56897 .43091 L
s
.57004 .43837 m
.57016 .43441 L
s
.56851 .44678 m
.57004 .43837 L
s
.56959 .45424 m
.5684 .45075 L
s
.56897 .43091 m
.56814 .42989 L
s
.56814 .42989 m
.56601 .42933 L
s
.5684 .45075 m
.56851 .44678 L
s
.56747 .46813 m
.56736 .47211 L
s
.56675 .46316 m
.56747 .46813 L
s
.56736 .47211 m
.56594 .47659 L
s
.56601 .42933 m
.56375 .43276 L
s
.56691 .50246 m
.5656 .50299 L
s
.56655 .49998 m
.56691 .50246 L
s
.56525 .50051 m
.56655 .49998 L
s
.56594 .47659 m
.56415 .47859 L
s
.5656 .50299 m
.56525 .50051 L
s
.56375 .43276 m
.56233 .4372 L
s
.56415 .47859 m
.56153 .4796 L
s
.56174 .44268 m
.56293 .44619 L
s
.56233 .4372 m
.56174 .44268 L
s
.56153 .4796 m
.55853 .47812 L
s
.55744 .4561 m
.56007 .45513 L
s
.56023 .49461 m
.54839 .48069 L
s
.55853 .47812 m
.55685 .47613 L
s
.55563 .45809 m
.55744 .4561 L
s
.55685 .47613 m
.5548 .47162 L
s
.55419 .46259 m
.55563 .45809 L
s
.55702 .53026 m
.5391 .50967 L
s
.5548 .47162 m
.55407 .4666 L
s
.55407 .4666 m
.55419 .46259 L
s
.55507 .50724 m
.55301 .50277 L
s
.55495 .51126 m
.55507 .50724 L
s
.55351 .51582 m
.55495 .51126 L
s
.55169 .51789 m
.55351 .51582 L
s
.55301 .50277 m
.54449 .49285 L
s
.54768 .51954 m
.55169 .51789 L
s
.54489 .53936 m
.54415 .53433 L
s
.54477 .54341 m
.54489 .53936 L
s
.5433 .54804 m
.54477 .54341 L
s
.54415 .53433 m
.54206 .52986 L
s
.54146 .55017 m
.5433 .54804 L
s
.54206 .52986 m
.54034 .5279 L
s
.53875 .55133 m
.54146 .55017 L
s
.54134 .55424 m
.52303 .53371 L
s
.54034 .5279 m
.53725 .52649 L
s
.53725 .52649 m
.53453 .52762 L
s
.53789 .56512 m
.52568 .55154 L
s
.53604 .56727 m
.53592 .57136 L
s
.53529 .56222 m
.53604 .56727 L
s
.53592 .57136 m
.53443 .57605 L
s
.53453 .52762 m
.53267 .52973 L
s
.53443 .57605 m
.53257 .57822 L
s
.53267 .52973 m
.53117 .53438 L
s
.53105 .53847 m
.5318 .54354 L
s
.53257 .57822 m
.52982 .57945 L
s
.53117 .53438 m
.53105 .53847 L
s
.52982 .57945 m
.52669 .57814 L
s
.52795 .5965 m
.52945 .59176 L
s
.52555 .55565 m
.52831 .55446 L
s
.52607 .59871 m
.52795 .5965 L
s
.52669 .57814 m
.52493 .57621 L
s
.52367 .55781 m
.52555 .55565 L
s
.5233 .59998 m
.52607 .59871 L
s
.52621 .62438 m
.52608 .6285 L
s
.52545 .61931 m
.52621 .62438 L
s
.52493 .57621 m
.52279 .57174 L
s
.52608 .6285 m
.52407 .63489 L
s
.52544 .60442 m
.51301 .59103 L
s
.52419 .61584 m
.52545 .61931 L
s
.52215 .56252 m
.52367 .55781 L
s
.52279 .57174 m
.52203 .56665 L
s
.52014 .59871 m
.5233 .59998 L
s
.52407 .63489 m
.52218 .63716 L
s
.52203 .56665 m
.52215 .56252 L
s
.52218 .63716 m
.51939 .6385 L
s
.51939 .6385 m
.51711 .63824 L
s
.51455 .61626 m
.5171 .60827 L
s
.51442 .60541 m
.5171 .60827 L
s
.51711 .63824 m
.51392 .63704 L
s
.51212 .6051 m
.51442 .60541 L
s
.51392 .63704 m
.50943 .63234 L
s
.5093 .60639 m
.51212 .6051 L
s
.51174 .64766 m
.49699 .64102 L
s
.50737 .60864 m
.5093 .60639 L
s
.50943 .63234 m
.50724 .6279 L
s
.50531 .61508 m
.50737 .60864 L
s
.50724 .6279 m
.50595 .62439 L
s
.50763 .66064 m
.49699 .64102 L
s
.50763 .66064 m
.4928 .6541 L
s
.50595 .62439 m
.50518 .61926 L
s
.50518 .61926 m
.50531 .61508 L
s
.5035 .6737 m
.4928 .6541 L
s
.49986 .68518 m
.48699 .67222 L
s
.4979 .68756 m
.49777 .69177 L
s
.49712 .68242 m
.4979 .68756 L
s
.49777 .69177 m
.4962 .69673 L
s
.4962 .69673 m
.49424 .69912 L
s
.49424 .69912 m
.49134 .70061 L
s
.49134 .70061 m
.48804 .69953 L
s
.48936 .71832 m
.49095 .71332 L
s
.48685 .67646 m
.48976 .67502 L
s
.48738 .72076 m
.48936 .71832 L
s
.48804 .69953 m
.48619 .69769 L
s
.48486 .67885 m
.48685 .67646 L
s
.48446 .7223 m
.48738 .72076 L
s
.48619 .69769 m
.48393 .69326 L
s
.48671 .72669 m
.47361 .71395 L
s
.48327 .68383 m
.48486 .67885 L
s
.48644 .75054 m
.48565 .74539 L
s
.48578 .75649 m
.48644 .75054 L
s
.48565 .74539 m
.48432 .74192 L
s
.48205 .76834 m
.48578 .75649 L
s
.48393 .69326 m
.48313 .68808 L
s
.48112 .72126 m
.48446 .7223 L
s
.48313 .68808 m
.48327 .68383 L
s
.48432 .74192 m
.48205 .73755 L
s
.48205 .73755 m
.47737 .73304 L
s
.48205 .76834 m
.46218 .74962 L
s
.47737 .73304 m
.47401 .73202 L
s
.47401 .73202 m
.47158 .7319 L
s
.47158 .7319 m
.46859 .73347 L
s
.46859 .73347 m
.46601 .73767 L
s
.46601 .73767 m
.46218 .74962 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0780oooo0P000?l^0?ooo`030000003oool0oooo0580oooo0P00
000M0?ooo`00;P3oool2000004P0oooo00<000000?ooo`3oool0L@3oool20000obh0oooo00<00000
0?ooo`3oool0C`3oool3000000030?ooo`000000oooo01`0oooo000_0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0X03oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo0740
oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`000000
oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0740oooo
00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo06`0oooo0P00
0?l30?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool0@`3oool3000000h0oooo00<0
00000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1Z
0?ooo`030000o`3oool0003o00@0oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`10
0?ooo`<000004@3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo06T0oooo00<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`0W0?oo
o`030000003oool0oooo03d0oooo0`00000D0?ooo`030000003oool0oooo01X0oooo000^0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0J03oool01@000?l0oooo0000o`3oool0003o
00@0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`00
0000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo06H0
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l]0?ooo`030000003oool0oooo03H0oooo0`00000K
0?ooo`030000003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`1U0?oo
o`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`0c
0?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo06D0oooo00D0003o0?ooo`000?l0oooo0000o`0]0?ooo`030000003oool0
oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool0IP3oool00`000?l0oooo0000o`0]0?ooo`030000003oool0oooo
02d0oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool0I@3oool00`000?l0oooo0000o`0]0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0I03oool20000obh0oooo00<000000?ooo`3oool09`3oool3000002/0oooo
00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`1O0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo02@0oooo0`00
000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0G@3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0G03oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0F`3oool01@000?l0oooo0?ooo`3oool0003o0340oooo00<000000?ooo`3oool06P3oool30000
03L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`1I0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;`3oool00`000000
oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo
00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02l0oooo
00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00
001O0?ooo`030000003oool0oooo05P0oooo00D0003o0?ooo`3oool0oooo0000o`0a0?ooo`030000
003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0E`3oool01@000?l0oooo0?ooo`3oool0003o0340oooo
00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`1G0?ooo`040000o`3oool0oooo0000oc40oooo
00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo0080oooo0P00
0?lb0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0e
0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo06<0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`0d0?oo
o`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1T0?ooo`030000003oool0oooo0540oooo00<0003o0?ooo`3oool0=03oool40000
05D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1A0?ooo`030000o`3oool0oooo0340oooo0`00001H0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo02d0oooo0`0000020?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?oo
o`1<0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:@3oool3000000D0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<00000
0?ooo`3oool0C03oool00`000?l0oooo0?ooo`0[0?ooo`<00000203oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0C03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0240oooo0`00000;0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo01h0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo04`0oooo00<0003o0?ooo`3oool07`3oool300000140oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo01`0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`03
0000003oool0oooo04D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0I0?ooo`<0
0000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`150?ooo`04
0000o`3oool0oooo0000oaT0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0A@3oool00`000?l0oooo0000o`0F0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
A03oool20000oa<0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`140?ooo`030000o`3o
ool0oooo00h0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool02P3oool3000002P0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0?03oool00`00
0?l0oooo0000o`050?ooo`030000o`3oool0oooo00H0oooo0`00000[0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0>P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?oo
o`3oool00P3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0=P3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo00@0oooo0`00000a0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`00
0?l0103oool010000?l0oooo0?ooo`3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0f0?ooo`80003o103oool010000?l0000000000000000g0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`0f0?ooo`030000o`3oool0oooo0080000000<0003o0?ooo`3oool0>03oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool0=@3oool00`000?l00000000000020?ooo`030000o`3oool0oooo03P0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo0340oooo0`0000001@3oool0003o0?ooo`3oool0003o03/0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo02d0oooo0`0000050?ooo`030000o`3oool0003o03/0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo02T0oooo0`0000040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000001`3oool20000o`@0oooo00<0003o0?oo
o`3oool0>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000T0oooo00@0003o0?ooo`3o
ool0003o?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`03
0000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000`0oooo00@0003o0?ooo`3o
ool0003o@03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000100oooo00D0003o0?ooo`3o
ool0oooo0000o`0o0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000004`3oool010000?l0
oooo0?ooo`3oool20000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000F0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
303oool3000001T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0l0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`080?ooo`<00000703oool01@000?l0oooo0?ooo`3oool0003o03l0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00@0oooo0`00000P0?ooo`040000o`3oool0oooo0000ocl0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo00<000008`3oool30000od00oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000J@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`00
0000oooo0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo06@0oooo0`0000020?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`1P0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo03@0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<@3oool3000000h0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0280oooo0P000?l00`3oool0003o0000o`0`0?ooo`<000004P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool08`3oool20000obl0oooo0`00000F0?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo02T0oooo1000000J0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0O0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`0U0?ooo`<000007P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool07P3oool01@000?l0oooo0?ooo`3oool0003o02L0oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool08P3oool3
000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool20000
08l0oooo00<000000?ooo`3oool07@3oool01@000?l0oooo0?ooo`3oool0003o0280oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0M0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`000?l0oooo0?ooo`0I0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01D0oooo0`00000c0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool3000003H0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0?0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00`0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0O
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0203oool400000480oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0200oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?oo
o`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Q0?ooo`D0003o
0P3oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool3000008h0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`070?ooo`<00000DP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool0
0`000000oooo0?ooo`0K0?ooo`<0003o0`3oool4000005H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01`0oooo00<0003o0?ooo`0000000P00001K0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool06`3oool300000080oooo0P000?mJ0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01P0oooo0`0000020?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool300000080oooo00@0003o0?ooo`3oool0
003oH03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo100000060?ooo`80003o
00<0oooo0000o`3oool0G`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo
000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0>0?ooo`<000002P3oool010000?l0oooo0000o`000?mQ0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool02`3oool3000000h0oooo00@0003o0?ooo`3oool0003oH03oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0203oool300000140oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0103oool4000001D0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?oo
o`3oool0oooo0`00000I0?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000F0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`800000T03oool3000001T0oooo0P000?m[0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo
00<000000?ooo`3oool05`3oool00`000?l0oooo0000o`1[0?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<0
00000?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0003o06/0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0J@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo0880oooo0`00000<0?ooo`030000003oool0oooo01H0oooo00<0003o0?ooo`3oool00P3oool2
0000of/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0JP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo01L0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1[0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo
00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06`0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1f0?ooo`<00000603oool00`000000oooo0?ooo`0H0?ooo`050000o`3oool0oooo0?ooo`000?l0
K`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo01T0oooo0`000?ma0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3
000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0
oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo07@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`0D
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0MP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo01D0oooo00D0003o0?ooo`3oool0oooo0000o`1h0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool05P3oool010000?l0oooo0?ooo`000?mi0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool30000
03P0oooo00<000000?ooo`3oool05`3oool20000og/0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000
oooo0?ooo`0H0?ooo`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool04`3oool20000oh40oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;
0?ooo`<00000A@3oool00`000000oooo0?ooo`0B0?ooo`040000o`3oool0oooo0000oh40oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`000018
0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool00P3oool20000oh00oooo00<00000
0?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?oo
o`<00000B`3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0O`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`200?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0
403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0800oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3o
ool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0P03o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03T0oooo0`00001H0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`210?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0403oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0880oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000
oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0P`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo
1000001Q0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`240?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool04`3oool20000o`<0oooo00<0
003o0?ooo`3oool0Q03oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo01H0oooo00<0003o
0?ooo`000?l0R03oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo01L0oooo0P000?n90?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<0
0000K@3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo08P0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000
L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo
100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
0P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`80
0000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003o
ool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool5
00000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo
0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000
P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0
oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
04`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo
00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00
001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?oo
o`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3o
ool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo
001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo
001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo0000
00030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0
oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo
001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?oo
o`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00
K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2
000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool00000
03`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000
oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e
0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?oo
o`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00
J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`03
0000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D0
0000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000
E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03o
ool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool01000
0000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`00
0000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0
oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00
000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<00000
0?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000
R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3o
ool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0
oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo
00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<0
00000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<00000
0?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`03
0000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3o
ool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`80
00002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool00000
0000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo
002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3o
ool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool20000
00@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?oo
o`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?oo
o`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.55317 .44165 m
.5416 .42771 L
s
.54519 .44636 m
.54556 .45159 L
s
.54368 .44296 m
.54519 .44636 L
s
.54556 .45159 m
.5451 .45584 L
s
.5451 .45584 m
.5438 .45911 L
s
.53674 .42026 m
.53742 .42267 L
s
.53742 .42267 m
.53643 .42307 L
s
.53575 .42065 m
.53674 .42026 L
s
.53643 .42307 m
.53575 .42065 L
s
.5438 .45911 m
.54197 .45855 L
s
.53935 .43938 m
.53783 .43596 L
s
.53988 .44321 m
.53935 .43938 L
s
.53993 .4513 m
.53988 .44321 L
s
.53783 .43596 m
.53699 .43495 L
s
.53699 .43495 m
.53515 .43436 L
s
.54197 .45855 m
.54045 .45514 L
s
.54045 .45514 m
.53993 .4513 L
s
.53515 .43436 m
.53383 .4376 L
s
.54239 .47196 m
.54292 .47582 L
s
.54103 .46712 m
.54239 .47196 L
s
.54292 .47582 m
.54245 .48013 L
s
.53383 .4376 m
.53335 .44187 L
s
.54245 .48013 m
.54129 .48203 L
s
.53335 .44187 m
.53371 .44715 L
s
.53371 .44715 m
.53524 .45058 L
s
.54729 .50529 m
.5463 .50577 L
s
.54661 .50287 m
.54729 .50529 L
s
.54561 .50335 m
.54661 .50287 L
s
.54129 .48203 m
.53929 .48294 L
s
.5463 .50577 m
.54561 .50335 L
s
.53225 .46004 m
.53428 .45916 L
s
.53929 .48294 m
.53659 .48143 L
s
.53108 .46191 m
.53225 .46004 L
s
.54056 .49749 m
.52862 .48367 L
s
.53659 .48143 m
.53489 .47945 L
s
.53059 .46624 m
.53108 .46191 L
s
.53489 .47945 m
.5325 .47502 L
s
.53112 .47013 m
.53059 .46624 L
s
.5325 .47502 m
.53112 .47013 L
s
.54348 .53212 m
.52546 .51163 L
s
.53827 .50965 m
.53588 .50525 L
s
.5388 .51356 m
.53827 .50965 L
s
.53832 .51797 m
.5388 .51356 L
s
.53588 .50525 m
.52729 .49538 L
s
.53715 .51994 m
.53832 .51797 L
s
.53409 .52145 m
.53715 .51994 L
s
.53487 .54072 m
.53348 .53579 L
s
.53541 .54467 m
.53487 .54072 L
s
.53348 .53579 m
.53105 .53138 L
s
.53492 .54916 m
.53541 .54467 L
s
.53105 .53138 m
.52932 .52943 L
s
.53373 .5512 m
.53492 .54916 L
s
.52932 .52943 m
.52655 .52798 L
s
.53167 .55227 m
.53373 .5512 L
s
.53426 .55517 m
.5159 .53469 L
s
.52655 .52798 m
.52447 .52901 L
s
.53311 .56573 m
.52087 .55218 L
s
.52447 .52901 m
.52326 .53103 L
s
.53191 .5678 m
.53245 .5718 L
s
.5305 .56285 m
.53191 .5678 L
s
.53245 .5718 m
.53195 .57636 L
s
.52326 .53103 m
.52275 .53554 L
s
.53195 .57636 m
.53075 .57845 L
s
.52275 .53554 m
.52329 .53953 L
s
.52329 .53953 m
.5247 .5445 L
s
.53075 .57845 m
.52866 .57959 L
s
.52141 .55619 m
.52351 .5551 L
s
.52866 .57959 m
.52586 .57824 L
s
.52978 .59628 m
.53028 .59166 L
s
.52018 .55827 m
.52141 .55619 L
s
.52586 .57824 m
.5241 .57632 L
s
.52856 .59841 m
.52978 .59628 L
s
.51966 .56285 m
.52018 .55827 L
s
.5241 .57632 m
.52162 .57189 L
s
.52646 .5996 m
.52856 .59841 L
s
.52894 .604 m
.51652 .5906 L
s
.5202 .56688 m
.51966 .56285 L
s
.52162 .57189 m
.5202 .56688 L
s
.53269 .62363 m
.53324 .62769 L
s
.53127 .61864 m
.53269 .62363 L
s
.52968 .6152 m
.53127 .61864 L
s
.53324 .62769 m
.53257 .63393 L
s
.52364 .59828 m
.52646 .5996 L
s
.53257 .63393 m
.53135 .63613 L
s
.53135 .63613 m
.52925 .6374 L
s
.52174 .61542 m
.52261 .60761 L
s
.51994 .60475 m
.52261 .60761 L
s
.52925 .6374 m
.52731 .6371 L
s
.52731 .6371 m
.52447 .63586 L
s
.51798 .60439 m
.51994 .60475 L
s
.51583 .6056 m
.51798 .60439 L
s
.52447 .63586 m
.52 .63115 L
s
.51458 .60778 m
.51583 .6056 L
s
.52432 .64629 m
.511 .63946 L
s
.52 .63115 m
.51748 .62673 L
s
.51387 .61407 m
.51458 .60778 L
s
.51748 .62673 m
.51586 .62325 L
s
.51441 .61818 m
.51387 .61407 L
s
.51586 .62325 m
.51441 .61818 L
s
.52293 .65902 m
.511 .63946 L
s
.52293 .65902 m
.50954 .6523 L
s
.52153 .67184 m
.50954 .6523 L
s
.5203 .68314 m
.50753 .6701 L
s
.51904 .68546 m
.51959 .68963 L
s
.51758 .68036 m
.51904 .68546 L
s
.51959 .68963 m
.51906 .69451 L
s
.51906 .69451 m
.5178 .69685 L
s
.5178 .69685 m
.51561 .69828 L
s
.50808 .67429 m
.51029 .67291 L
s
.51561 .69828 m
.51269 .69715 L
s
.51674 .71582 m
.51728 .71088 L
s
.50679 .67661 m
.50808 .67429 L
s
.51269 .69715 m
.51085 .6953 L
s
.51546 .71821 m
.51674 .71582 L
s
.50624 .68152 m
.50679 .67661 L
s
.51085 .6953 m
.50827 .69087 L
s
.51326 .71969 m
.51546 .71821 L
s
.51583 .72408 m
.50288 .71123 L
s
.50679 .68573 m
.50624 .68152 L
s
.50827 .69087 m
.50679 .68573 L
s
.51031 .7186 m
.51326 .71969 L
s
.51936 .7478 m
.51788 .74267 L
s
.51974 .75371 m
.51936 .7478 L
s
.51788 .74267 m
.51623 .73919 L
s
.51848 .76547 m
.51974 .75371 L
s
.51623 .73919 m
.51364 .73481 L
s
.51364 .73481 m
.50902 .73026 L
s
.51848 .76547 m
.49889 .74653 L
s
.50902 .73026 m
.50604 .72919 L
s
.50604 .72919 m
.50399 .72903 L
s
.50399 .72903 m
.50174 .73055 L
s
.50174 .73055 m
.50023 .73469 L
s
.50023 .73469 m
.49889 .74653 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
06@0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo06<0
oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`000000
oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0AP3oool3000000/0oooo00<000000?ooo`3oool06P3oool002h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo03L0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo03H0oooo00<00000
0?ooo`3oool0@03oool300000140oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`1N0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0e0?oo
o`030000003oool0oooo03d0oooo0`00000D0?ooo`030000003oool0oooo01X0oooo000^0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0G@3oool20000o`<0oooo00<0003o0?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`000000oooo0?ooo`0J0?ooo`00
;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`1K0?ooo`050000o`3o
ool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo
0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0FP3oool01@000?l0oooo0000o`3oool0003o03P0oooo00<000000?ooo`3oool0
<03oool300000240oooo00<000000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0D`3o
ool00`000000oooo0?ooo`1I0?ooo`050000o`3oool0003o0?ooo`000?l0>03oool00`000000oooo
0?ooo`0]0?ooo`<000009@3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo05P0oooo00D0003o0?ooo`000?l0oooo0000o`0h0?ooo`030000
003oool0oooo02X0oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0000o`0h0?ooo`030000003o
ool0oooo02L0oooo0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0000o`0h0?ooo`030000003oool0
oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`020000ocP0oooo00<000000?oo
o`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3o
ool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0
6P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3o
ool00`000000oooo0?ooo`1A0?ooo`050000o`3oool0oooo0?ooo`000?l0>P3oool00`000000oooo
0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<0
00000?ooo`3oool0D03oool01@000?l0oooo0?ooo`3oool0003o03X0oooo00<000000?ooo`3oool0
503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003o
ool0oooo04l0oooo00D0003o0?ooo`3oool0oooo0000o`0j0?ooo`030000003oool0oooo0140oooo
0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0CP3oool01@000?l0oooo0?ooo`3oool0003o03X0oooo00<000000?ooo`3oool0
3P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1=0?ooo`050000o`3oool0oooo0?ooo`000?l0>P3oool00`000000oooo
0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1Q0?ooo`030000003oool0oooo04d0oooo00@0003o0?ooo`3oool0003o>P3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00`000?lj0?ooo`030000003o
ool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`0l0?ooo`040000003oool0
oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0?03oool4000005D0oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`190?oo
o`030000o`3oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0e0?ooo`<0
00000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000
003oool0000006P0oooo00<000000?ooo`3oool0A03oool01@000?l0oooo0?ooo`3oool0003o03@0
oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
0P00001Y0?ooo`030000003oool0oooo04D0oooo00D0003o0?ooo`3oool0oooo0000o`0`0?ooo`<0
0000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0^0?ooo`<00000
2`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo04D0oooo00@0003o0?ooo`3oool0oooo
0P000?lW0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`150?ooo`050000o`3oool0oooo0?ooo`000?l0903oool300000140oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0R0?ooo`<0
0000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0o0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool07`3oool3000001P0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06l0oooo00<000000?ooo`3oool0?`3oool01@000?l0oooo0?ooo`3oool0003o
01h0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240
oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0?`3oool010000?l0
oooo0?ooo`000?lK0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?`3oool20000oaP0
oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo01@0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo0100oooo0`00
000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f
0?ooo`030000003oool0oooo03P0oooo0P000?l40?ooo`030000o`3oool0oooo00`0oooo0`00000[
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0=`3oool010000?l0oooo0000o`000?l3
0?ooo`030000o`3oool0oooo00P0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo03<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?oo
o`030000003oool0oooo03<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`050?oo
o`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@0
0000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03<0oooo0P000?l30?ooo`03
0000o`3oool0oooo0080oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0c0?ooo`060000
o`3oool0oooo0?ooo`000?l0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0b0?ooo`80
003o00@0oooo000000000000003o?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool01@000000
003o0000003oool0003o03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000020?ooo`03
0000o`3oool0003o03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000020?ooo`040000
o`3oool0oooo0?ooo`80003o?P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000001P3oool01@000?l0oooo
0?ooo`3oool0003o03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`0000080?ooo`030000
o`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000;0?ooo`040000o`3o
ool0oooo0000od40oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000?0?ooo`050000o`3o
ool0oooo0?ooo`000?l0@03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool300000180oooo00@0
003o0?ooo`3oool0oooo0P000?lo0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000005@3o
ool01@000?l0oooo0?ooo`3oool0003o0400oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00
000H0?ooo`050000o`3oool0oooo0?ooo`000?l0@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203o
ool3000001/0oooo00D0003o0?ooo`3oool0oooo0000o`100?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<000007`3oool010000?l0oooo0?ooo`000?m00?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`03000002<0oooo0`000?m00?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool0I`3oool20000
05/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`1T0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`0l0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo03<0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S
0?ooo`040000o`3oool0oooo0000oc<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T
0?ooo`030000o`3oool0003o0300oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?oo
o`030000o`3oool0oooo02`0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`03
0000o`3oool0oooo02L0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q0?ooo`<0003o
:@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0003o
9@3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo
0000o`0R0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo
000S0?ooo`800000S`3oool00`000000oooo0?ooo`0P0?ooo`040000o`3oool0oooo0000ob00oooo
0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0P0?ooo`040000o`3oool0oooo0000o`80oooo
00<0003o0?ooo`3oool05`3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0C0?ooo`<00000<`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0100oooo0`00000f
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool03@3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`090?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
903oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo100000120?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0T0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool3000004L0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02D0oooo00@0003o0?ooo`3oool0003o0P3oool3000004X0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02H0oooo0P000?l3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0803oool2
0000o`<0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool0
0240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0N0?ooo`<0000000<0003o0?ooo`3oool00P000?mF0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool06`3oool3000000@0oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<000001@3oool010000?l0oooo
0?ooo`000?mI0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo
0`0000080?ooo`<0003o00<0oooo0000o`3oool0F03oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0140oooo1000000<0?ooo`040000o`3oool0003o0000oeX0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool300000100oooo00D0003o0?ooo`3oool0oooo
0000o`1J0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`00
00050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000001@0oooo00<0
003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000001L0oooo00<0003o
0?ooo`3oool0G03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000001/0oooo00<0003o0?oo
o`3oool0G03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000K0?ooo`050000o`3oool0oooo
0?ooo`000?l0G`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?oo
o`800000T@3oool4000001l0oooo00D0003o0?ooo`3oool0oooo0000o`1O0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<000008@3oool00`00
0?l0oooo0000o`1R0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool07`3oool010000?l0
oooo0?ooo`000?mR0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool07`3oool01@000?l0
oooo0?ooo`3oool0003o0680oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0O0?ooo`04
0000o`3oool0oooo0?ooo`80003oHP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo01l0
oooo00D0003o0?ooo`3oool0oooo0000o`1T0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<00000
4@3oool00`000000oooo0?ooo`0P0?ooo`050000o`3oool0oooo0?ooo`000?l0I@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo
1000000D0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0003oIP3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo
0`00000H0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`000?l0I`3oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00
000K0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0I`3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@0
0000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3o
ool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo0640oooo0`00000^0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000
o`1]0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0000o`1^
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`1^0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`1^0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo01l0oooo0`000?md0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool07P3oool0
10000?l0oooo0?ooo`000?md0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool07@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0780oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo
01d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0
oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo07<0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0L`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo01d0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1d0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo07<0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?oo
o`<00000F03oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0M03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1e0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0
803oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo07H0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3o
ool00`000000oooo0?ooo`0Q0?ooo`050000o`3oool0oooo0?ooo`000?l0N@3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00
001U0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`000?l0NP3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W
0?ooo`030000003oool0oooo02@0oooo0P000?mk0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool30000
07X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?oo
o`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H
0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?oo
o`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`80
0000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03o
ool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3o
ool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2
000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?oo
o`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0
_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3o
ool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo
0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`00
0000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo
0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000
J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2
000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2
000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo
0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo
0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?oo
o`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`01
0?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000
D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?oo
o`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo
0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?oo
o`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@0
00004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D00000
5P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3o
ool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`00
0000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0
oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V
0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?oo
o`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@0
0000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`80
0000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00
J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3o
ool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0
Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3o
ool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool0
08@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool0
08D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0
oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@00000
0?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O
0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0
DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3o
ool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool0
09D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0
oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo
0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo
0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00
000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000
002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>
0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?oo
o`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?oo
o`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`03
0000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<0
00004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<00000
00<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3o
ool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool0
0:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000
oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?oo
o`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000
g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.51954 .45327 m
.50779 .4395 L
s
.51424 .45705 m
.51555 .46192 L
s
.5124 .45378 m
.51424 .45705 L
s
.51555 .46192 m
.51602 .46583 L
s
.50255 .43225 m
.50355 .43454 L
s
.50355 .43454 m
.50285 .43483 L
s
.50185 .43254 m
.50255 .43225 L
s
.51602 .46583 m
.51565 .46876 L
s
.50285 .43483 m
.50185 .43254 L
s
.50832 .45014 m
.50646 .44687 L
s
.50947 .45373 m
.50832 .45014 L
s
.5111 .46124 m
.50947 .45373 L
s
.51565 .46876 m
.51411 .46811 L
s
.50646 .44687 m
.50561 .44587 L
s
.50561 .44587 m
.50406 .44518 L
s
.51411 .46811 m
.51226 .46484 L
s
.51226 .46484 m
.5111 .46124 L
s
.50406 .44518 m
.50366 .44809 L
s
.50366 .44809 m
.50411 .45201 L
s
.51707 .48059 m
.51824 .4842 L
s
.51505 .47599 m
.51707 .48059 L
s
.51824 .4842 m
.51871 .48817 L
s
.50411 .45201 m
.50543 .45693 L
s
.50543 .45693 m
.50729 .46022 L
s
.51871 .48817 m
.51818 .48985 L
s
.52744 .51192 m
.52675 .51229 L
s
.52643 .50962 m
.52744 .51192 L
s
.52574 .50999 m
.52643 .50962 L
s
.51818 .48985 m
.51679 .49056 L
s
.52675 .51229 m
.52574 .50999 L
s
.50681 .46878 m
.50822 .46811 L
s
.51679 .49056 m
.51439 .48895 L
s
.50626 .47043 m
.50681 .46878 L
s
.51439 .48895 m
.51267 .48699 L
s
.52064 .50418 m
.50859 .49046 L
s
.50672 .47441 m
.50626 .47043 L
s
.51267 .48699 m
.50993 .4827 L
s
.50789 .47806 m
.50672 .47441 L
s
.50993 .4827 m
.50789 .47806 L
s
.52124 .51533 m
.5185 .51106 L
s
.52242 .51901 m
.52124 .51533 L
s
.52291 .52308 m
.52242 .51901 L
s
.52973 .53664 m
.51159 .51626 L
s
.5185 .51106 m
.50985 .50126 L
s
.52238 .52484 m
.52291 .52308 L
s
.52028 .52603 m
.52238 .52484 L
s
.52469 .54406 m
.52262 .53936 L
s
.52588 .54779 m
.52469 .54406 L
s
.52262 .53936 m
.51986 .53507 L
s
.52638 .55195 m
.52588 .54779 L
s
.51986 .53507 m
.51812 .53313 L
s
.52585 .55377 m
.52638 .55195 L
s
.51812 .53313 m
.51566 .53158 L
s
.52445 .55463 m
.52585 .55377 L
s
.52705 .55751 m
.50863 .53709 L
s
.51566 .53158 m
.51424 .5324 L
s
.51424 .5324 m
.51368 .5342 L
s
.52823 .56731 m
.51596 .55378 L
s
.51368 .5342 m
.51417 .53837 L
s
.5277 .56916 m
.52891 .57294 L
s
.52562 .56443 m
.5277 .56916 L
s
.52891 .57294 m
.52942 .57718 L
s
.51417 .53837 m
.51537 .54213 L
s
.51537 .54213 m
.51746 .54688 L
s
.52942 .57718 m
.52889 .57905 L
s
.52889 .57905 m
.52748 .57997 L
s
.51718 .55757 m
.51861 .5567 L
s
.52748 .57997 m
.52501 .57852 L
s
.51662 .55943 m
.51718 .55757 L
s
.53165 .59568 m
.53113 .59139 L
s
.52501 .57852 m
.52325 .57659 L
s
.51712 .56368 m
.51662 .55943 L
s
.53111 .5976 m
.53165 .59568 L
s
.52325 .57659 m
.52044 .57227 L
s
.51833 .56749 m
.51712 .56368 L
s
.5297 .59857 m
.53111 .5976 L
s
.52044 .57227 m
.51833 .56749 L
s
.53251 .60287 m
.52012 .58945 L
s
.53935 .62156 m
.54057 .6254 L
s
.53724 .61677 m
.53935 .62156 L
s
.52722 .59715 m
.5297 .59857 L
s
.53531 .61343 m
.53724 .61677 L
s
.54057 .6254 m
.54129 .63123 L
s
.54129 .63123 m
.54077 .63322 L
s
.54077 .63322 m
.53937 .63427 L
s
.52912 .6131 m
.52825 .60583 L
s
.52559 .60296 m
.52825 .60583 L
s
.53937 .63427 m
.53778 .63386 L
s
.52398 .60249 m
.52559 .60296 L
s
.53778 .63386 m
.5353 .6325 L
s
.52253 .60348 m
.52398 .60249 L
s
.5353 .6325 m
.53086 .62777 L
s
.52198 .60544 m
.52253 .60348 L
s
.52266 .6113 m
.52198 .60544 L
s
.53725 .64231 m
.52542 .63499 L
s
.53086 .62777 m
.528 .62344 L
s
.528 .62344 m
.52604 .62006 L
s
.5239 .6152 m
.52266 .6113 L
s
.52604 .62006 m
.5239 .6152 L
s
.53869 .65421 m
.52542 .63499 L
s
.53869 .65421 m
.52682 .64698 L
s
.54013 .6662 m
.52682 .64698 L
s
.5414 .67679 m
.52876 .66363 L
s
.54087 .67889 m
.54213 .68287 L
s
.53871 .67399 m
.54087 .67889 L
s
.54213 .68287 m
.54268 .68744 L
s
.54268 .68744 m
.54215 .68958 L
s
.54215 .68958 m
.54072 .69078 L
s
.53002 .66763 m
.53148 .66647 L
s
.54072 .69078 m
.53819 .68953 L
s
.52947 .66974 m
.53002 .66763 L
s
.54509 .70745 m
.54453 .70281 L
s
.53819 .68953 m
.53637 .68766 L
s
.53 .67433 m
.52947 .66974 L
s
.54456 .70963 m
.54509 .70745 L
s
.53637 .68766 m
.53346 .68331 L
s
.53127 .67835 m
.53 .67433 L
s
.54312 .71089 m
.54456 .70963 L
s
.53346 .68331 m
.53127 .67835 L
s
.54603 .71522 m
.53325 .70222 L
s
.54058 .70967 m
.54312 .71089 L
s
.55353 .73793 m
.55134 .73296 L
s
.55501 .74357 m
.55353 .73793 L
s
.55134 .73296 m
.54934 .72957 L
s
.54934 .72957 m
.54643 .72525 L
s
.55637 .75465 m
.55501 .74357 L
s
.54643 .72525 m
.54188 .72064 L
s
.55637 .75465 m
.53712 .73544 L
s
.54188 .72064 m
.53932 .71943 L
s
.53932 .71943 m
.53766 .71915 L
s
.53766 .71915 m
.53619 .72045 L
s
.53619 .72045 m
.53582 .72428 L
s
.53582 .72428 m
.53712 .73544 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`1C0?ooo`030000o`3oool0oooo04H0oooo00<00000
0?ooo`3oool0@03oool300000140oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`1B0?ooo`80003oA`3oool00`000000oooo0?ooo`0m0?oo
o`<00000503oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool0>@3oool4000001L0oooo00<000000?ooo`3o
ool06P3oool002h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`1B0?ooo`030000
o`3oool0oooo04@0oooo00<000000?ooo`3oool0=P3oool3000001/0oooo00<000000?ooo`3oool0
6P3oool002d0oooo0P00001B0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`0c0?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo04l0oooo00@0003o0?ooo`3oool0003oA03o
ool00`000000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo04h0oooo0P000?l20?ooo`030000o`3oool0
oooo0440oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool0
02d0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1=0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo02X0oooo0`00000X0?ooo`030000003oool0oooo
01T0oooo000]0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0C03oool010000?l0
oooo0000o`000?l20?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool09`3oool30000
02/0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`1;0?ooo`040000o`3oool0003o0000od@0oooo00<000000?ooo`3oool0903oool30000
02h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`1:0?ooo`050000o`3oool0003o0?ooo`000?l0@`3oool00`000000oooo0?ooo`0Q0?oo
o`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`03
0000003oool0oooo04X0oooo0P000?l00`3oool0003o0?ooo`120?ooo`030000003oool0oooo01h0
oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo
00<000000?ooo`3oool0B`3oool20000od@0oooo00<000000?ooo`3oool06P3oool3000003L0oooo
00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?oo
o`1:0?ooo`80003oA03oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?oo
o`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0A`3oool010000?l0oooo0?ooo`00
0?m40?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`800000G`3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo04D0oooo00<00000
0?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`150?ooo`030000o`3oool0oooo04D0oooo00<000000?oo
o`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`140?ooo`040000o`3oool0oooo0000od@0oooo00<000000?oo
o`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3o
ool0H@3oool00`000000oooo0?ooo`130?ooo`050000o`3oool0oooo0?ooo`000?l0@`3oool00`00
0000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo04<0oooo00@0003o0?ooo`3oool0003o@`3oool00`00
0000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo0480oooo00@0003o0?ooo`3oool0003o@`3oool01000
0000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`120?ooo`<0003o@`3oool4000005D0oooo00<000000?oo
o`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`100?ooo`04
0000o`3oool0oooo0000od40oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0n0?ooo`<0
00000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000
003oool0000006P0oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0j0?ooo`<00000
1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3o
ool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo03L0oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0m0?ooo`040000o`3oool0oooo0000ocD0oooo0`00000;0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0?@3oool010000?l0oooo0?ooo`000?la0?ooo`<000003P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0l0?ooo`030000o`3o
ool0oooo02l0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo03`0oooo00D0003o0?ooo`3oool0oooo0000o`0Y0?ooo`<00000503oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo0080003o
9@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
?03oool00`000?l0oooo0?ooo`0S0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo03P0oooo00@0003o0?ooo`3oool0003o8P3oool3000001h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo03P0oooo00@0003o0?ooo`3oool0003o7@3oool400000240oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo03P0oooo00<0003o0?ooo`000?l06P3oool3000002D0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0
oooo03P0oooo0P000?lG0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo
01<0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0=03oool010000?l0
oooo0?ooo`000?lA0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`0b0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0;0?ooo`<00000<@3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0`0?ooo`80003o0P3oool010000?l0oooo
0?ooo`000?l90?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0300oooo
0P000?l20?ooo`030000o`3oool0oooo00H0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`0_0?ooo`80003o0P3oool00`000?l0oooo0?ooo`030?ooo`<00000>P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool0;`3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`<00000?@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<0
00000?ooo`3oool0;`3oool01@000?l0oooo000000000?l000000400oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02d0oooo0P0000000`000?l0oooo0000o`110?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y
0?ooo`<000000P3oool00`000?l0oooo0000o`110?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000030?oo
o`030000o`3oool0oooo0080003o@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000L0
oooo00@0003o0?ooo`3oool0003o@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000T0
oooo00<0003o0?ooo`000?l0A03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000000h0oooo
00<0003o0?ooo`000?l0@`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool300000140oooo00@0
003o0?ooo`3oool0003o@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001@0oooo00D0
003o0?ooo`3oool0oooo0000o`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000005`3o
ool01@000?l0oooo0?ooo`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00
000K0?ooo`040000o`3oool0oooo0000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00
000O0?ooo`030000o`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008`3oool2
0000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo06@0oooo
0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo03X0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0T0?ooo`040000o`3oool0oooo0000ocD0oooo0`00
000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0003o0380oooo0`00000>
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`<0003o;`3oool300000180oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02H0oooo00<0003o0?ooo`3oool0:`3oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02@0oooo0P000?l00`3oool0003o0?ooo`0W0?ooo`@000006P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?lV0?ooo`<000007P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?lS0?ooo`<000008P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0903oool00`000?l0oooo0000o`0P0?ooo`<000009P3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0T
0?ooo`050000o`3oool0003o0?ooo`000?l06`3oool3000002X0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0D0?ooo`@00000;P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o01<0oooo0`00000c
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool03@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00D0003o0?ooo`3o
ool0oooo0000o`0<0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool010000?l0
oooo0?ooo`000?l90?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool01@000?l0
oooo0?ooo`3oool0003o00@0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`05
0000o`3oool0oooo0000o`3oool00`0000170?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`05
0000o`3oool0oooo0?ooo`000?l00`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0W0?ooo`04
0000o`0000000000000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000080003oD03oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo
0?ooo`0Q0?ooo`@000000`3oool00`000?l0oooo0000o`1@0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0N0?ooo`<000001@3oool010000?l0oooo0?ooo`000?mB0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool06`3oool3000000T0oooo0P000?l00`3oool0003o0?ooo`1@0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000<0?ooo`040000o`3o
ool0003o0000oe80oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3o
ool300000100oooo00@0003o0?ooo`3oool0003oDP3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0140oooo1000000C0?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool03P3oool3000001P0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000L0?ooo`030000o`3oool0oooo
05<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000L0?ooo`040000o`3oool0oooo0000
oeH0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000O0?ooo`80003o0P3oool00`000?l0
oooo0?ooo`1D0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000002<0oooo00<0003o0?ooo`00
0?l0F@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000
T@3oool4000002H0oooo00<0003o0?ooo`3oool00P000?mH0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000:@3oool01@000?l0oooo0?oo
o`3oool0003o05P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0X0?ooo`050000o`3o
ool0oooo0?ooo`000?l0F03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo02P0oooo00D0
003o0?ooo`3oool0oooo0000o`1I0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0:@3o
ool010000?l0oooo0?ooo`000?mJ0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0:@3o
ool010000?l0oooo0?ooo`000?mK0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0:P3o
ool30000oe`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo05/0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1`0?ooo`<000007P3oool00`000000oooo0?ooo`0Z0?ooo`050000o`3oool0oooo0?ooo`000?l0
G`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3o
ool300000240oooo00<000000?ooo`3oool0:`3oool010000?l0oooo0?ooo`000?mO0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3o
ool4000002@0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0000o`1P0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3
000002P0oooo00<000000?ooo`3oool0;03oool30000of40oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`00
0000oooo0?ooo`0]0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`0^0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo
0?ooo`0[0?ooo`80003oI@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo02/0oooo00<0
003o0?ooo`000?l0I@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo02/0oooo00@0003o
0?ooo`3oool0003oI@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M
0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo02/0oooo00D0003o
0?ooo`3oool0oooo0000o`1U0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`00
0000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0
oooo0`0000150?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`1T0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo
0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo02d0oooo00D0
003o0?ooo`3oool0oooo0000o`1W0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0;P3o
ool01@000?l0oooo0?ooo`3oool0003o06L0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?oo
o`0^0?ooo`050000o`3oool0oooo0?ooo`000?l0J03oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003o
ool0oooo02l0oooo00@0003o0?ooo`3oool0003oJ03oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003o
ool0oooo0300oooo00<0003o0?ooo`000?l0J@3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0
oooo0340oooo0P000?mZ0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0<P3oool00`00
0?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo
0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?oo
o`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000
M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0
oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo
0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?oo
o`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`000000
0P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?oo
o`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`00
8`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003o
ool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D
0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`03
0000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00
<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo
0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo
0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000
K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0
HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0
oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000
oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo
00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?oo
o`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?oo
o`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?oo
o`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000
003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo
00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool0
0`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000
oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P000014
0?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?oo
o`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3o
ool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool0
0740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<0
00000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<00000
0?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?oo
o`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3o
ool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?oo
o`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?oo
o`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`03
0000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3o
ool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3o
ool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5
000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo
0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo
002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo
002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`03
0000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000
003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3o
ool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4
000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0
oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0
oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo
0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00
000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<00000
0?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W
0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?oo
o`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3o
ool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?oo
o`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3o
ool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool0
0:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?oo
o`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<0
0000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?oo
o`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`80
0000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48699 .4706 m
.47504 .45703 L
s
.48424 .47301 m
.48646 .47739 L
s
.48208 .46994 m
.48424 .47301 L
s
.48646 .47739 m
.48783 .4808 L
s
.46941 .45003 m
.47072 .45213 L
s
.47072 .45213 m
.47031 .45227 L
s
.46899 .45016 m
.46941 .45003 L
s
.47031 .45227 m
.46899 .45016 L
s
.48783 .4808 m
.48834 .48326 L
s
.47822 .4662 m
.47605 .46311 L
s
.47999 .46945 m
.47822 .4662 L
s
.48313 .47611 m
.47999 .46945 L
s
.47605 .46311 m
.47518 .46213 L
s
.48834 .48326 m
.48708 .48246 L
s
.47518 .46213 m
.4739 .4613 L
s
.48708 .48246 m
.4849 .47937 L
s
.4849 .47937 m
.48313 .47611 L
s
.4739 .4613 m
.47438 .46373 L
s
.47438 .46373 m
.47574 .46715 L
s
.49248 .49359 m
.49427 .49687 L
s
.48984 .48935 m
.49248 .49359 L
s
.49427 .49687 m
.49566 .50035 L
s
.47574 .46715 m
.47798 .47156 L
s
.47798 .47156 m
.48017 .47466 L
s
.49566 .50035 m
.49573 .5017 L
s
.49573 .5017 m
.49493 .5021 L
s
.50814 .52204 m
.50776 .52225 L
s
.50681 .51991 m
.50814 .52204 L
s
.50643 .52012 m
.50681 .51991 L
s
.48209 .48191 m
.48291 .48156 L
s
.50776 .52225 m
.50643 .52012 L
s
.49493 .5021 m
.4928 .50035 L
s
.48214 .48324 m
.48209 .48191 L
s
.4928 .50035 m
.49107 .49841 L
s
.48352 .48672 m
.48214 .48324 L
s
.50127 .51436 m
.4891 .50075 L
s
.49107 .49841 m
.48799 .49431 L
s
.48532 .49003 m
.48352 .48672 L
s
.48799 .49431 m
.48532 .49003 L
s
.50466 .52402 m
.50159 .51994 L
s
.50648 .52736 m
.50466 .52402 L
s
.50791 .53093 m
.50648 .52736 L
s
.51635 .54362 m
.49808 .52335 L
s
.50159 .51994 m
.49286 .51021 L
s
.508 .53236 m
.50791 .53093 L
s
.50683 .53306 m
.508 .53236 L
s
.51475 .54922 m
.51204 .54487 L
s
.5166 .55261 m
.51475 .54922 L
s
.51204 .54487 m
.50894 .54077 L
s
.51806 .55627 m
.5166 .55261 L
s
.50894 .54077 m
.50719 .53883 L
s
.51817 .55775 m
.51806 .55627 L
s
.50719 .53883 m
.50504 .53713 L
s
.5174 .55828 m
.51817 .55775 L
s
.52002 .56116 m
.50153 .5408 L
s
.50504 .53713 m
.50425 .53762 L
s
.50425 .53762 m
.50434 .53908 L
s
.52347 .56977 m
.51117 .55627 L
s
.50434 .53908 m
.50579 .54274 L
s
.52359 .57129 m
.52545 .57472 L
s
.52085 .5669 m
.52359 .57129 L
s
.50579 .54274 m
.50765 .54616 L
s
.52545 .57472 m
.52695 .57845 L
s
.50765 .54616 m
.51039 .55056 L
s
.52695 .57845 m
.52707 .57999 L
s
.52707 .57999 m
.52632 .58057 L
s
.51304 .55972 m
.51382 .55918 L
s
.52632 .58057 m
.52418 .57894 L
s
.51314 .56123 m
.51304 .55972 L
s
.53347 .59475 m
.53196 .59096 L
s
.52418 .57894 m
.52242 .57702 L
s
.51463 .56497 m
.51314 .56123 L
s
.53361 .59632 m
.53347 .59475 L
s
.52242 .57702 m
.51927 .57287 L
s
.51651 .56843 m
.51463 .56497 L
s
.51927 .57287 m
.51651 .56843 L
s
.53287 .59695 m
.53361 .59632 L
s
.53601 .60108 m
.52364 .58764 L
s
.53073 .59534 m
.53287 .59695 L
s
.54586 .61824 m
.54776 .62175 L
s
.54309 .61379 m
.54586 .61824 L
s
.54082 .61062 m
.54309 .61379 L
s
.54776 .62175 m
.54983 .62689 L
s
.54983 .62689 m
.55 .62853 L
s
.55 .62853 m
.54929 .62924 L
s
.53635 .60941 m
.53379 .60299 L
s
.53113 .60012 m
.53379 .60299 L
s
.54929 .62924 m
.54805 .62864 L
s
.52987 .59947 m
.53113 .60012 L
s
.54805 .62864 m
.54593 .6271 L
s
.52911 .60011 m
.52987 .59947 L
s
.54593 .6271 m
.54151 .62235 L
s
.52924 .60172 m
.52911 .60011 L
s
.53129 .60689 m
.52924 .60172 L
s
.54995 .63587 m
.5396 .62778 L
s
.54151 .62235 m
.53833 .61818 L
s
.53833 .61818 m
.53603 .61496 L
s
.53321 .61044 m
.53129 .60689 L
s
.53603 .61496 m
.53321 .61044 L
s
.55416 .64639 m
.5396 .62778 L
s
.55416 .64639 m
.5438 .63837 L
s
.55841 .657 m
.5438 .63837 L
s
.56216 .66636 m
.54966 .65309 L
s
.56235 .66811 m
.56432 .67175 L
s
.5595 .66354 m
.56235 .66811 L
s
.56432 .67175 m
.56594 .6758 L
s
.56594 .6758 m
.56614 .67757 L
s
.56614 .67757 m
.56545 .67841 L
s
.55163 .65674 m
.55235 .65595 L
s
.56545 .67841 m
.56331 .67695 L
s
.5518 .65849 m
.55163 .65674 L
s
.57305 .69353 m
.5714 .68942 L
s
.56331 .67695 m
.56152 .67506 L
s
.55342 .66255 m
.5518 .65849 L
s
.57326 .69535 m
.57305 .69353 L
s
.56152 .67506 m
.55829 .67085 L
s
.5554 .66622 m
.55342 .66255 L
s
.55829 .67085 m
.5554 .66622 L
s
.57258 .69624 m
.57326 .69535 L
s
.57581 .70042 m
.56323 .68725 L
s
.57044 .6948 m
.57258 .69624 L
s
.58727 .72129 m
.58437 .71664 L
s
.58984 .72641 m
.58727 .72129 L
s
.58437 .71664 m
.58204 .71339 L
s
.58204 .71339 m
.5788 .70921 L
s
.59381 .73627 m
.58984 .72641 L
s
.5788 .70921 m
.57433 .70453 L
s
.57433 .70453 m
.57218 .70311 L
s
.59381 .73627 m
.57495 .71672 L
s
.57218 .70311 m
.57094 .70262 L
s
.57094 .70262 m
.57024 .70354 L
s
.57024 .70354 m
.57101 .70681 L
s
.57101 .70681 m
.57495 .71672 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo0580
oooo00<000000?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo0580oooo
00<000000?ooo`3oool09`3oool3000002/0oooo00<000000?ooo`3oool06@3oool002d0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo02@0oooo0`00
000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0?P3oool20000oe40oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0m0?ooo`03
0000o`3oool0003o0540oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0l0?ooo`<0003o
D@3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0>`3oool010000?l0oooo0000o`000?m@0?ooo`030000
003oool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3o
ool00`000000oooo0?ooo`0k0?ooo`@0003oC`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3o
ool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo03/0oooo0P000?m@0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0>`3oool20000
odl0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0k0?ooo`80003oCP3oool00`000000
oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo03T0oooo0`000?m>0?ooo`030000003oool0oooo00@0oooo
0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0>03oool00`000?l0oooo0?ooo`1>0?ooo`040000003oool0oooo0?ooo`<00000
DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo03L0oooo00<0003o0?ooo`3oool0CP3oool4000005D0oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0
003o04/0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0=`3oool20000odP0oooo0`0000020?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000
oooo0?ooo`0f0?ooo`030000o`3oool0003o04@0oooo0`0000050?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo03L0oooo
0P000?m10?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0=@3oool010000?l0oooo0000
o`000?lm0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03D0oooo00<0
003o0?ooo`3oool0>P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0f0?ooo`<000004@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0K@3oool00`000000oooo0?ooo`0d0?ooo`80003o=03oool3000001@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0=03oool20000oc00oooo0`00
000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo03<0oooo00<0
003o0?ooo`000?l0;03oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0c
0?ooo`030000o`3oool0oooo02P0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0c0?oo
o`030000o`3oool0003o02<0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0a0?ooo`80
003o00<0oooo0000o`3oool07`3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo0340oooo
0P000?lN0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
000X0?ooo`800000MP3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0003o01X0oooo0`00
000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<03oool20000oaL0oooo0`00000^
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?oo
o`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0300oooo00<0003o0?oo
o`3oool04P3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3o
ool0;P3oool00`000?l0oooo0000o`0@0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo02d0oooo0`000?l=0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0:`3o
ool20000o`030?ooo`000?l0003o00T0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0[
0?ooo`030000o`3oool0oooo0080003o1@3oool3000003d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
02/0oooo00<0003o0?ooo`000?l00`3oool300000400oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02/0
oooo00<0003o0?ooo`000?l00P0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`800000
0P000?m50?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00
00210?ooo`030000003oool0oooo02D0oooo0`0000030?ooo`030000o`3oool0oooo04<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0240oooo0`0000040?ooo`040000o`3oool0oooo0000od@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo01`0oooo100000080?ooo`040000o`3oool0oooo0000od@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01P0oooo0`00000<0?ooo`80003oAP3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?oo
o`3oool0503oool300000100oooo0P000?m50?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<0
00004`3oool00`000?l0oooo0000o`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<00000
5P3oool010000?l0oooo0?ooo`000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000
6P3oool010000?l0oooo0?ooo`000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000
7P3oool30000od80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool20000od80oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`8000009P3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0903oool00`000?l0oooo0?ooo`0m0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0000o`0h0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3o
ool20000ocD0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`80003o<@3oool3
000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0;03oool30000
0180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo0P000?l00`3oool0003o0?ooo`0Y0?ooo`<0
00005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0000o`0W0?ooo`@00000
6P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09`3oool20000ob@0oooo0`00000N0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0003o0200oooo0`00000R0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0X0?ooo`040000o`3oool0oooo0000oa/0oooo0`00000V0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo
02T0oooo00<0003o0?ooo`000?l0603oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02T0
oooo00<0003o0?ooo`000?l0503oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo
00<0003o0?ooo`000?l0403oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo00<0
003o0?ooo`000?l0303oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo00<0003o
0?ooo`000?l02@3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo00D0003o0?oo
o`000?l0oooo0000o`050?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;03oool01@00
0?l0oooo0000o`000?l0oooo00@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;@3oool01000
0?l000000000000000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000000P000?m80?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000000P3oool20000odX0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0
9@3oool3000000H0oooo0P000?m:0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo100000090?ooo`<0003oBP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool07P3oool3000000h0oooo00<0003o0?ooo`000?l0BP3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000B0?ooo`030000o`3oool0oooo
04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool30000
01H0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0E0?ooo`<000005`3oool00`000?l0oooo0000o`1<0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool04@3oool4000001/0oooo00<0003o0?ooo`000?l0C03oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000007`3oool20000odh0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<000008P3oool20000odh0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00P0oooo0`00000U0?ooo`040000o`3oool0003o0000odd0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo1000000Y0?ooo`040000o`3oool0003o0000odd0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`040000003oool0oooo0?ooo`<00000;P3oool00`000?l0oooo0000o`1>0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000<@3oool00`00
0?l0oooo0000o`1?0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo0P00002@0?ooo`<00000=@3oool00`000?l0oooo0000o`1>0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo
00<000000?ooo`3oool0=03oool20000odl0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?oo
o`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`03
0000003oool0oooo03D0oooo00<0003o0?ooo`000?l0D@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000
003oool0oooo03L0oooo0P000?mA0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0>03o
ool20000oe40oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`0h0?ooo`80003oDP3oool0
0`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo
07<0oooo0`00000K0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`3oool0D03oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700
oooo0`00000N0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0D`3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo
00<000000?ooo`3oool0>03oool20000oe@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?oo
o`0h0?ooo`030000o`3oool0003o05@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0h
0?ooo`040000o`3oool0oooo0000oe@0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`0i
0?ooo`040000o`3oool0oooo0000oe@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`0i
0?ooo`050000o`3oool0oooo0?ooo`000?l0E03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0
oooo03X0oooo00@0003o0?ooo`3oool0003oE03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo03/0oooo00@0003o0?ooo`3oool0003oE03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0
oooo03`0oooo00<0003o0?ooo`000?l0E@3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo
03`0oooo00@0003o0?ooo`3oool0003oE@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo
03d0oooo00<0003o0?ooo`000?l0EP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo03h0
oooo0P000?mF0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0?`3oool20000oeH0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`00
00180?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0E@3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;
0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3
000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo
09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W
0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<00000
0?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003o
ool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3
000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo
0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`08
0?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?oo
o`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<00000
0?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?oo
o`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000
S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
1P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?oo
o`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P000004
0?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3o
ool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000
O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
1@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`00
0000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00
oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?oo
o`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0
oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`00
0000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3o
ool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`00
0000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3o
ool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0
oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000
oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo
00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo
0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`80
0000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0
oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo
0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo
00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0
oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<00000
0?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?oo
o`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D0
00005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@00000
6`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool0
0`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool20000
03`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?oo
o`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q
0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?oo
o`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?oo
o`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3o
ool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?oo
o`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?oo
o`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3o
ool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3o
ool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3o
ool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool0
08H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@0
00000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00
000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3o
ool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0
CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3o
ool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool0
09H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000
oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000
oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo
0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo
1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00
000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R
0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d
0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?oo
o`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?oo
o`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0
000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0
oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool0
5P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3o
ool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@00
0000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`000006
0?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`80
0000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.45669 .49294 m
.44453 .47956 L
s
.4563 .49361 m
.45936 .49735 L
s
.45383 .49077 m
.4563 .49361 L
s
.45936 .49735 m
.46156 .50014 L
s
.43854 .47285 m
.44014 .47473 L
s
.44014 .47473 m
.43998 .47468 L
s
.43838 .4728 m
.43854 .47285 L
s
.43998 .47468 m
.43838 .4728 L
s
.46156 .50014 m
.4629 .50199 L
s
.45018 .48689 m
.4477 .48404 L
s
.45252 .48971 m
.45018 .48689 L
s
.45706 .49532 m
.45252 .48971 L
s
.4477 .48404 m
.44682 .48307 L
s
.4629 .50199 m
.4619 .50101 L
s
.44682 .48307 m
.44579 .48206 L
s
.4619 .50101 m
.45941 .49815 L
s
.45941 .49815 m
.45706 .49532 L
s
.44579 .48206 m
.4471 .48387 L
s
.4471 .48387 m
.44929 .48666 L
s
.46957 .51045 m
.47193 .51329 L
s
.46634 .50664 m
.46957 .51045 L
s
.47193 .51329 m
.47417 .51614 L
s
.44929 .48666 m
.45238 .49043 L
s
.45238 .49043 m
.45488 .4933 L
s
.47417 .51614 m
.4748 .51708 L
s
.4748 .51708 m
.47456 .51707 L
s
.49016 .53522 m
.49005 .53523 L
s
.48854 .53331 m
.49016 .53522 L
s
.48843 .53332 m
.48854 .53331 L
s
.45904 .49889 m
.45932 .49894 L
s
.49005 .53523 m
.48843 .53332 L
s
.47456 .51707 m
.47268 .51514 L
s
.45965 .49981 m
.45904 .49889 L
s
.47268 .51514 m
.47093 .51322 L
s
.46189 .50265 m
.45965 .49981 L
s
.48322 .52761 m
.47092 .51412 L
s
.47093 .51322 m
.46754 .50937 L
s
.46427 .50552 m
.46189 .50265 L
s
.46754 .50937 m
.46427 .50552 L
s
.48921 .53535 m
.48582 .53151 L
s
.49161 .53825 m
.48921 .53535 L
s
.49392 .54118 m
.49161 .53825 L
s
.50387 .55274 m
.48547 .5326 L
s
.48582 .53151 m
.47701 .52185 L
s
.49459 .54218 m
.49392 .54118 L
s
.49429 .54225 m
.49459 .54218 L
s
.50549 .556 m
.50217 .5521 L
s
.50793 .55895 m
.50549 .556 L
s
.50217 .5521 m
.49876 .54822 L
s
.51029 .56194 m
.50793 .55895 L
s
.49876 .54822 m
.497 .5463 L
s
.511 .56299 m
.51029 .56194 L
s
.497 .5463 m
.49513 .54439 L
s
.51083 .56308 m
.511 .56299 L
s
.51346 .56595 m
.49489 .54566 L
s
.49513 .54439 m
.49493 .54445 L
s
.49493 .54445 m
.49561 .54547 L
s
.51902 .57302 m
.50669 .55954 L
s
.49561 .54547 m
.49797 .54847 L
s
.51975 .57409 m
.52223 .57708 L
s
.5164 .57015 m
.51975 .57409 L
s
.49797 .54847 m
.50043 .55144 L
s
.52223 .57708 m
.52464 .58013 L
s
.50043 .55144 m
.50379 .55538 L
s
.52464 .58013 m
.52537 .58122 L
s
.52537 .58122 m
.52524 .58136 L
s
.50918 .56254 m
.50935 .56245 L
s
.52524 .58136 m
.52341 .57951 L
s
.50989 .5636 m
.50918 .56254 L
s
.53518 .5935 m
.53273 .5904 L
s
.52341 .57951 m
.52165 .57758 L
s
.5123 .56666 m
.50989 .5636 L
s
.53594 .59462 m
.53518 .5935 L
s
.52165 .57758 m
.51819 .57366 L
s
.5148 .56968 m
.5123 .56666 L
s
.51819 .57366 m
.5148 .56968 L
s
.53583 .59479 m
.53594 .59462 L
s
.53928 .5987 m
.52693 .58524 L
s
.53401 .59296 m
.53583 .59479 L
s
.55194 .61383 m
.55447 .61688 L
s
.54854 .60983 m
.55194 .61383 L
s
.54597 .60688 m
.54854 .60983 L
s
.55447 .61688 m
.55781 .62111 L
s
.55781 .62111 m
.55862 .62229 L
s
.55862 .62229 m
.55855 .62252 L
s
.54311 .6045 m
.53896 .59924 L
s
.53631 .59635 m
.53896 .59924 L
s
.55855 .62252 m
.55765 .62169 L
s
.53537 .59547 m
.53631 .59635 L
s
.55765 .62169 m
.55587 .6199 L
s
.53525 .59564 m
.53537 .59547 L
s
.55587 .6199 m
.55147 .61512 L
s
.53602 .59679 m
.53525 .59564 L
s
.53936 .60102 m
.53602 .59679 L
s
.56181 .62728 m
.55286 .61816 L
s
.55147 .61512 m
.54798 .61117 L
s
.54798 .61117 m
.54537 .60818 L
s
.54192 .60411 m
.53936 .60102 L
s
.54537 .60818 m
.54192 .60411 L
s
.56863 .63592 m
.55286 .61816 L
s
.56863 .63592 m
.5597 .62685 L
s
.5755 .64465 m
.5597 .62685 L
s
.58158 .65235 m
.56922 .63894 L
s
.58244 .65361 m
.58507 .65677 L
s
.57895 .64949 m
.58244 .65361 L
s
.58507 .65677 m
.5877 .66011 L
s
.5877 .66011 m
.58858 .66139 L
s
.58858 .66139 m
.58859 .66173 L
s
.57185 .64212 m
.57188 .64183 L
s
.58859 .66173 m
.58683 .65998 L
s
.57271 .64337 m
.57185 .64212 L
s
.5992 .6747 m
.59653 .67131 L
s
.58683 .65998 m
.58507 .65807 L
s
.57534 .64671 m
.57271 .64337 L
s
.60012 .67602 m
.5992 .6747 L
s
.58507 .65807 m
.58153 .65407 L
s
.57799 .64991 m
.57534 .64671 L
s
.58153 .65407 m
.57799 .64991 L
s
.60015 .67639 m
.60012 .67602 L
s
.60368 .68038 m
.59132 .667 L
s
.59841 .67467 m
.60015 .67639 L
s
.61884 .69863 m
.61529 .69445 L
s
.62244 .70303 m
.61884 .69863 L
s
.61529 .69445 m
.61264 .69141 L
s
.61264 .69141 m
.60911 .68743 L
s
.62886 .71116 m
.62244 .70303 L
s
.60911 .68743 m
.60472 .68268 L
s
.60472 .68268 m
.60297 .68096 L
s
.62886 .71116 m
.61041 .69124 L
s
.60297 .68096 m
.60211 .6802 L
s
.60211 .6802 m
.60215 .68058 L
s
.60215 .68058 m
.60399 .68309 L
s
.60399 .68309 m
.61041 .69124 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0;03oool00`000?l0oooo
0?ooo`1L0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0:`3oool20000oed0oooo00<0
00000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0[0?ooo`80003oG03oool010000000oooo0?ooo`3o
ool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0Z0?ooo`80003oG03oool4000005D0oooo00<000000?ooo`3oool05`3oool0
02/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Z0?ooo`80003oF@3oool30000
05P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`0Z0?ooo`80003oE@3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo02X0oooo
00<0003o0?ooo`3oool0D03oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?oo
o`1<0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0:P3oool20000odX0oooo0`00000;
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`150?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0Z0?oo
o`80003o@P3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0:P3oool20000och0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0>@3oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0:@3oool20000ocL0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0:@3oool20000oc<0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo02d0oooo1000000Q0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo02T0oooo0`00000U0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool0
0`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo02D0oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
02T0oooo00<0003o0?ooo`3oool08@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo01d0oooo0`00000^0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo02P0oooo0`000?lJ0?ooo`<00000<@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0X0?ooo`80003o5`3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0180oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00h0oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0W0?ooo`80003o303oool3000003d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo02H0oooo0`000?l80?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09P3o
ool30000o`@0oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0V0?ooo`<0003o0`000016
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?oo
o`030000003oool0oooo02D0oooo00<000000000o`000?l0B@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool08@3oool300000080oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0
703oool4000000H0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000000/0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
000000l0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool30000
0180oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001H0
oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001X0oooo
0P000?m40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007@3oool00`000?l0oooo0000
o`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000240oooo0P000?m30?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool20000
02H0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo03l0
oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0k0?ooo`<000000P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool09`3oool20000ocL0oooo100000060?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0X
0?ooo`030000o`3oool0oooo0380oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?oo
o`80003o<03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo0P000?l/0?ooo`<0
00004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0W0?ooo`<00000
5P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:P3oool20000ob@0oooo1000000J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0[0?ooo`80003o803oool3000001h0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02`0oooo00<0003o0?ooo`3oool06`3oool300000280oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02d0
oooo00<0003o0?ooo`3oool05`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0;P3oool20000oa@0oooo
0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0_0?ooo`80003o3`3oool4000002h0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo0300oooo0P000?l<0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0<@3oool20000o`P0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`03
0000o`3oool0oooo00<0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0c0?ooo`030000
o`3oool0000000800000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02h0oooo0`0000030?ooo`80003o@P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:`3oool3000000L0oooo0P000?m10?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<0
00002`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000?0?ooo`030000
o`3oool0oooo0400oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3o
ool200000900oooo00<000000?ooo`3oool08@3oool400000180oooo0P000?m20?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0N0?ooo`<000005`3oool20000od80oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0K0?ooo`<000006`3oool20000od40oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool3000001l0oooo0P000?m10?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000S0?ooo`030000o`3oool0oooo0400
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@000009P3oool20000od80oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002/0oooo0P00
0?m20?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`000005
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000002l0oooo00<0003o
0?ooo`3oool0@03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00@0oooo1000000f0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000
003oool0oooo0?ooo`<00000>`3oool20000od80oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000o0?ooo`030000o`3oool0oooo0440oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00130?ooo`80003o@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo0480oooo00<0003o
0?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo0480oooo0P000?m20?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
PP3oool3000000`0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`110?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3o
ool3000000l0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`110?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool40000
01@0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0BP3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<0
00000?ooo`3oool0BP3oool20000od80oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo04/0oooo0P000?m1
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`100?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0C@3oool00`000?l0oooo0?ooo`100?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo
0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?oo
o`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool30000
05D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?oo
o`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3o
ool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool30000
07@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?oo
o`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool00000
00800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000
UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203o
ool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool0
02<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000
oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00
503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool0
0`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool0
0340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?oo
o`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?oo
o`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool20000
06`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo
0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?oo
o`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000
003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03o
ool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@00
0000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?oo
o`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<00000
0?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000
A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003o
ool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0
oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo
001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`03
0000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000
003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003o
ool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0
oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03o
ool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3o
ool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool0
0`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0
oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0
oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo
1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo0028
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?oo
o`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?oo
o`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?oo
o`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool0
0`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`00
0000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0
oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I
0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?oo
o`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`80
0000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000
003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
9`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3o
ool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0
oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3o
ool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140
oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo
002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003o
ool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool3
00000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3o
ool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2
000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42973 .51944 m
.41735 .50626 L
s
.43144 .51806 m
.43526 .52105 L
s
.42869 .51548 m
.43144 .51806 L
s
.43526 .52105 m
.4382 .52311 L
s
.41102 .49987 m
.41289 .5015 L
s
.41289 .5015 m
.41296 .50122 L
s
.4111 .49959 m
.41102 .49987 L
s
.41296 .50122 m
.4111 .49959 L
s
.4382 .52311 m
.44028 .52424 L
s
.42522 .51142 m
.42246 .50884 L
s
.42807 .51374 m
.42522 .51142 L
s
.43387 .51812 m
.42807 .51374 L
s
.42246 .50884 m
.42157 .50788 L
s
.44028 .52424 m
.43949 .52304 L
s
.42157 .50788 m
.42075 .50665 L
s
.43949 .52304 m
.43673 .52045 L
s
.43673 .52045 m
.43387 .51812 L
s
.42075 .50665 m
.4228 .50775 L
s
.4228 .50775 m
.42575 .5098 L
s
.4492 .53048 m
.45208 .53282 L
s
.44544 .52719 m
.4492 .53048 L
s
.45208 .53282 m
.45508 .53492 L
s
.42575 .5098 m
.4296 .51282 L
s
.4296 .51282 m
.43238 .51543 L
s
.45508 .53492 m
.45621 .53538 L
s
.45621 .53538 m
.45645 .53489 L
s
.4742 .55093 m
.47434 .55071 L
s
.47231 .54928 m
.4742 .55093 L
s
.47245 .54905 m
.47231 .54928 L
s
.43854 .51905 m
.43833 .51958 L
s
.47434 .55071 m
.47245 .54905 L
s
.45645 .53489 m
.4548 .53274 L
s
.43964 .51948 m
.43854 .51905 L
s
.4548 .53274 m
.45302 .53083 L
s
.44264 .52158 m
.43964 .51948 L
s
.46718 .54339 m
.45476 .53002 L
s
.45302 .53083 m
.44934 .52726 L
s
.44554 .52394 m
.44264 .52158 L
s
.44934 .52726 m
.44554 .52394 L
s
.47549 .54886 m
.47181 .54529 L
s
.47842 .55125 m
.47549 .54886 L
s
.48151 .55341 m
.47842 .55125 L
s
.4928 .56365 m
.47427 .54363 L
s
.47181 .54529 m
.46292 .53572 L
s
.48269 .5539 m
.48151 .55341 L
s
.48315 .55322 m
.48269 .5539 L
s
.49727 .5641 m
.49341 .56073 L
s
.50025 .56652 m
.49727 .5641 L
s
.49341 .56073 m
.48972 .55713 L
s
.50341 .56873 m
.50025 .56652 L
s
.48972 .55713 m
.48795 .55521 L
s
.50464 .56926 m
.50341 .56873 L
s
.48795 .55521 m
.48633 .55306 L
s
.505 .56883 m
.50464 .56926 L
s
.50764 .57169 m
.489 .55146 L
s
.48633 .55306 m
.48665 .5526 L
s
.48665 .5526 m
.48786 .5531 L
s
.51509 .5769 m
.50272 .56346 L
s
.48786 .5531 m
.49103 .5553 L
s
.51635 .57744 m
.51937 .5799 L
s
.51245 .57404 m
.51635 .57744 L
s
.49103 .5553 m
.49403 .55775 L
s
.51937 .5799 m
.52259 .58215 L
s
.49403 .55775 m
.49793 .56115 L
s
.52259 .58215 m
.52387 .5827 L
s
.52387 .5827 m
.52428 .5823 L
s
.50575 .56592 m
.50539 .56636 L
s
.52428 .5823 m
.52272 .58018 L
s
.50701 .56645 m
.50575 .56592 L
s
.53669 .59201 m
.53342 .58972 L
s
.52272 .58018 m
.52096 .57826 L
s
.51024 .5687 m
.50701 .56645 L
s
.538 .59259 m
.53669 .59201 L
s
.52096 .57826 m
.51722 .57461 L
s
.51329 .57117 m
.51024 .5687 L
s
.51722 .57461 m
.51329 .57117 L
s
.53845 .59221 m
.538 .59259 L
s
.54217 .59585 m
.52985 .58236 L
s
.53691 .5901 m
.53845 .59221 L
s
.55732 .60851 m
.5604 .61102 L
s
.55337 .60506 m
.55732 .60851 L
s
.55052 .60238 m
.55337 .60506 L
s
.5604 .61102 m
.56486 .61414 L
s
.56486 .61414 m
.56623 .61476 L
s
.56623 .61476 m
.56674 .61443 L
s
.54908 .5986 m
.54353 .59472 L
s
.54089 .59183 m
.54353 .59472 L
s
.56674 .61443 m
.56613 .61331 L
s
.54024 .59067 m
.54089 .59183 L
s
.56613 .61331 m
.56465 .61122 L
s
.54069 .59028 m
.54024 .59067 L
s
.56465 .61122 m
.56028 .60642 L
s
.54203 .59086 m
.54069 .59028 L
s
.5465 .59397 m
.54203 .59086 L
s
.57229 .61692 m
.56458 .60658 L
s
.56028 .60642 m
.55652 .60274 L
s
.55652 .60274 m
.55364 .60001 L
s
.54962 .59651 m
.5465 .59397 L
s
.55364 .60001 m
.54962 .59651 L
s
.5814 .62329 m
.56458 .60658 L
s
.5814 .62329 m
.57375 .61297 L
s
.59059 .62972 m
.57375 .61297 L
s
.59871 .6354 m
.5865 .62185 L
s
.60017 .63607 m
.60337 .63866 L
s
.59611 .63251 m
.60017 .63607 L
s
.60337 .63866 m
.60688 .64112 L
s
.60688 .64112 m
.60837 .6418 L
s
.60837 .6418 m
.609 .64153 L
s
.58971 .62446 m
.58913 .62477 L
s
.609 .64153 m
.60758 .63945 L
s
.59117 .62511 m
.58971 .62446 L
s
.62226 .65187 m
.61869 .64938 L
s
.60758 .63945 m
.60584 .63752 L
s
.59469 .62757 m
.59117 .62511 L
s
.62378 .65258 m
.62226 .65187 L
s
.60584 .63752 m
.60204 .63378 L
s
.59793 .63018 m
.59469 .62757 L
s
.60204 .63378 m
.59793 .63018 L
s
.62445 .65233 m
.62378 .65258 L
s
.62823 .65605 m
.61609 .64248 L
s
.62305 .65027 m
.62445 .65233 L
s
.64663 .67109 m
.6425 .66748 L
s
.65112 .6746 m
.64663 .67109 L
s
.6425 .66748 m
.63958 .66471 L
s
.63958 .66471 m
.6358 .66098 L
s
.65968 .68059 m
.65112 .6746 L
s
.6358 .66098 m
.63149 .65616 L
s
.63149 .65616 m
.6301 .65409 L
s
.65968 .68059 m
.64164 .66029 L
s
.6301 .65409 m
.62958 .65299 L
s
.62958 .65299 m
.63027 .65273 L
s
.63027 .65273 m
.63305 .65431 L
s
.63305 .65431 m
.64164 .66029 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo05h0oooo0`00
00080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0H0?ooo`80003oG03oool3000000/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`1b0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0003o05<0oooo0`00000A0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01P0oooo10000?m>0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0H0?oo
o`80003o00<0oooo0000o`3oool0B@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0603oool40000odH0oooo0`00000K0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0603oool010000?l0oooo0000o`000?m20?ooo`<000007P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0603oool00`000?l0oooo0000o`020000oc`0oooo1000000Q0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`0J0?ooo`@0003o=`3oool3000002D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003o
ool0oooo01X0oooo00<0003o0?ooo`000?l0=03oool3000002P0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool06`3oool2
0000oc00oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
00@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool06`3oool30000
ob/0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0
oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01/0
oooo0`000?lW0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0K0?ooo`@0003o8P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0M0?ooo`80003o7P3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01d0oooo0`000?lI
0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?oo
o`030000003oool0oooo07`0oooo00<000000?ooo`3oool07@3oool010000?l0oooo0000o`000?lD
0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07d0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0000o`0@0?oo
o`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool07@3oool20000o`030?ooo`000?l0oooo00/0
oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0M0?ooo`H0003o1P3oool3000004H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<0
00000?ooo`3oool07`3oool40000o`80oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0P
0?ooo`040000o`000000003o000004`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo10000004
0000od`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000050?ooo`@0003oB`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0503oool3000000X0oooo10000?m90?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0@0?ooo`<000003P3oool40000odP0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00
000C0?ooo`<0003oA`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001P0oooo0`000?m5
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000703oool20000odD0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00<00000803oool30000od<0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009@3oool00`000?l0oooo
0000o`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00
002=0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0?@3oool2000005/0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0X
0?ooo`030000o`3oool0oooo03T0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0X0?oo
o`@0003o=03oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo10000?l`0?ooo`<0
00002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool30000ob`0oooo0`00000>0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0]0?ooo`80003o:03oool300000180oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02l0oooo00<0003o0?ooo`3oool08P3oool3000001H0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02h0oooo00<0003o0?ooo`000?l07`3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02l0
oooo00<0003o0?ooo`000?l00P000?lI0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
<03oool30000o`030?ooo`000?l0oooo01@0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0b0?ooo`@0003o4@3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0<`3oool50000o``0oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0f0?ooo`<0003o1`3oool4000002h0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo03T0oooo0P000?l30?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>P3oool010000?l0000000000000000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0h0?ooo`<00000
0P000?l00`3oool0003o0?ooo`0e0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<000001@3o
ool010000?l0oooo0000o`000?le0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@000002@3o
ool20000o`030?ooo`000?l0oooo03@0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00000?
0?ooo`030000o`3oool0003o03D0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00000C0?oo
o`<0003o=03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000001P0oooo0P000?ld0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000
003oool0oooo02D0oooo0`00000L0?ooo`80003o=03oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@000008`3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3o
ool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000:03oool0
0`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool30000
02/0oooo0P000?la0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00000_0?ooo`80003o<@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0E0?ooo`<00000<`3oool010000?l0oooo0000o`000?l_0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool04@3oool4000003L0oooo0P000?l00`3oool0003o0000o`0^0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000m0?ooo`040000
o`3oool0oooo0000obh0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
@@3oool010000?l0oooo0?ooo`000?l]0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
A@3oool010000?l0oooo0?ooo`000?l]0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000
B@3oool010000?l0oooo0?ooo`000?l]0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000004h0
oooo0`000?l^0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo
0P00002A0?ooo`@00000D`3oool20000obh0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool200000900oooo0`00001G0?ooo`80003o;@3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo05H0oooo0P000?l]0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?oo
o`3oool0F03oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00
000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?oo
o`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo
00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00
001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.4071 .54915 m
.39452 .53615 L
s
.41058 .54544 m
.41505 .54761 L
s
.40759 .54316 m
.41058 .54544 L
s
.41505 .54761 m
.41863 .54886 L
s
.38789 .53011 m
.38998 .53146 L
s
.38998 .53146 m
.39025 .53092 L
s
.38815 .52958 m
.38789 .53011 L
s
.41863 .54886 m
.42132 .54917 L
s
.39025 .53092 m
.38815 .52958 L
s
.40427 .5389 m
.40127 .53661 L
s
.40755 .54066 m
.40427 .5389 L
s
.41443 .54366 m
.40755 .54066 L
s
.40127 .53661 m
.40036 .53566 L
s
.42132 .54917 m
.42073 .54772 L
s
.40036 .53566 m
.39973 .53419 L
s
.42073 .54772 m
.41773 .54543 L
s
.41773 .54543 m
.41443 .54366 L
s
.39973 .53419 m
.4024 .53448 L
s
.4024 .53448 m
.40599 .53571 L
s
.43216 .55294 m
.43548 .55472 L
s
.42795 .55023 m
.43216 .55294 L
s
.43548 .55472 m
.43912 .55598 L
s
.40599 .53571 m
.41049 .53789 L
s
.41049 .53789 m
.41351 .5402 L
s
.43912 .55598 m
.44066 .55589 L
s
.44066 .55589 m
.44132 .55486 L
s
.46089 .56857 m
.46124 .56807 L
s
.45878 .56721 m
.46089 .56857 L
s
.45913 .5667 m
.45878 .56721 L
s
.42136 .54163 m
.42075 .54269 L
s
.46124 .56807 m
.45913 .5667 L
s
.44132 .55486 m
.43985 .55246 L
s
.42288 .54152 m
.42136 .54163 L
s
.43985 .55246 m
.43806 .55057 L
s
.45381 .56109 m
.44125 .54784 L
s
.42653 .54278 m
.42288 .54152 L
s
.43806 .55057 m
.43413 .54731 L
s
.42988 .54457 m
.42653 .54278 L
s
.43413 .54731 m
.42988 .54457 L
s
.46405 .56402 m
.46014 .56075 L
s
.46743 .56582 m
.46405 .56402 L
s
.47117 .56713 m
.46743 .56582 L
s
.4836 .57588 m
.46494 .55598 L
s
.46014 .56075 m
.45117 .55125 L
s
.47278 .56705 m
.47117 .56713 L
s
.47388 .56552 m
.47278 .56705 L
s
.49044 .57319 m
.48613 .57041 L
s
.49387 .57502 m
.49044 .57319 L
s
.48613 .57041 m
.4822 .56712 L
s
.49769 .57635 m
.49387 .57502 L
s
.4822 .56712 m
.48042 .56521 L
s
.49937 .57629 m
.49769 .57635 L
s
.48042 .56521 m
.47901 .56278 L
s
.50017 .57528 m
.49937 .57629 L
s
.50281 .57813 m
.4841 .55796 L
s
.47901 .56278 m
.47977 .56174 L
s
.47977 .56174 m
.48142 .56165 L
s
.51182 .58126 m
.49943 .56785 L
s
.48142 .56165 m
.48526 .56297 L
s
.51353 .58121 m
.517 .58306 L
s
.50918 .5784 m
.51353 .58121 L
s
.517 .58306 m
.5209 .58442 L
s
.48526 .56297 m
.48871 .56482 L
s
.48871 .56482 m
.49307 .56763 L
s
.5209 .58442 m
.52263 .58437 L
s
.52263 .58437 m
.52349 .58337 L
s
.50291 .5697 m
.5021 .57074 L
s
.52349 .58337 m
.52216 .58094 L
s
.50462 .56963 m
.50291 .5697 L
s
.53794 .59034 m
.53398 .58897 L
s
.52216 .58094 m
.52039 .57902 L
s
.50853 .57098 m
.50462 .56963 L
s
.53971 .5903 m
.53794 .59034 L
s
.52039 .57902 m
.51643 .57568 L
s
.51203 .57284 m
.50853 .57098 L
s
.51643 .57568 m
.51203 .57284 L
s
.54061 .5893 m
.53971 .5903 L
s
.54455 .59264 m
.53226 .57914 L
s
.53931 .58688 m
.54061 .5893 L
s
.56175 .60254 m
.56529 .60443 L
s
.55734 .59971 m
.56175 .60254 L
s
.55428 .59733 m
.55734 .59971 L
s
.56529 .60443 m
.57066 .60631 L
s
.57066 .60631 m
.57249 .6063 L
s
.57249 .6063 m
.57348 .60533 L
s
.55401 .59197 m
.54731 .58965 L
s
.54467 .58675 m
.54731 .58965 L
s
.57348 .60533 m
.57311 .60389 L
s
.54425 .58527 m
.54467 .58675 L
s
.57311 .60389 m
.57187 .60148 L
s
.54518 .58425 m
.54425 .58527 L
s
.57187 .60148 m
.56753 .59665 L
s
.54698 .5842 m
.54518 .58425 L
s
.55238 .58606 m
.54698 .5842 L
s
.5809 .60528 m
.57422 .59357 L
s
.56753 .59665 m
.56355 .59327 L
s
.56355 .59327 m
.56044 .59085 L
s
.55597 .58797 m
.55238 .58606 L
s
.56044 .59085 m
.55597 .58797 L
s
.59188 .60909 m
.57422 .59357 L
s
.59188 .60909 m
.58528 .59737 L
s
.60295 .61294 m
.58528 .59737 L
s
.61272 .61634 m
.60066 .60266 L
s
.61467 .61635 m
.61834 .61829 L
s
.61015 .61343 m
.61467 .61635 L
s
.61834 .61829 m
.62257 .61976 L
s
.62257 .61976 m
.62454 .61977 L
s
.62454 .61977 m
.62567 .61881 L
s
.60434 .60462 m
.60326 .60561 L
s
.62567 .61881 m
.62453 .61637 L
s
.60629 .6046 m
.60434 .60462 L
s
.64105 .62619 m
.63676 .6247 L
s
.62453 .61637 m
.62281 .61441 L
s
.61054 .60606 m
.60629 .6046 L
s
.64307 .62621 m
.64105 .62619 L
s
.62281 .61441 m
.61881 .61097 L
s
.61424 .60802 m
.61054 .60606 L
s
.61881 .61097 m
.61424 .60802 L
s
.64425 .62526 m
.64307 .62621 L
s
.64824 .62869 m
.6363 .61492 L
s
.64315 .62282 m
.64425 .62526 L
s
.6692 .64008 m
.66462 .63712 L
s
.67441 .64257 m
.6692 .64008 L
s
.66462 .63712 m
.66149 .63466 L
s
.66149 .63466 m
.65751 .63123 L
s
.68467 .64616 m
.67441 .64257 L
s
.65751 .63123 m
.65328 .62633 L
s
.68467 .64616 m
.66703 .62549 L
s
.65328 .62633 m
.65219 .62387 L
s
.65219 .62387 m
.65194 .6224 L
s
.65194 .6224 m
.65316 .62142 L
s
.65316 .62142 m
.6567 .62194 L
s
.6567 .62194 m
.66703 .62549 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0103oool20000od<0
oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo
00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo00P0oooo
0P000?lk0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`050?ooo`050000o`3oool0003o0?ooo`000?l0=`3oool3000003@0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`050?ooo`030000o`3oool0003o00<0003o<P3oool3000003L0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo00D0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`80003o
:P3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`000?l00P00
0?l40?ooo`80003o9@3oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo00D0oooo00<0003o
0?ooo`000?l010000?l30?ooo`80003o00<0oooo0000o`3oool07@3oool300000400oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0P000?l00`3oool0003o0?ooo`02
0?ooo`030000o`3oool0003o01X0oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0<0?oo
o`80003o0P3oool01@000?l0oooo0000o`3oool0003o01@0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
00d0oooo0`000?l20?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool02P3oool30000
04T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`000?l00`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00<00000C03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0
4P3oool00`000?l0oooo0000o`030?ooo`040000o`3oool0oooo0?ooo`80000000<0003o0000003o
ool0C`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0503oool20000o`80oooo00<0003o000000000?l0
10000?m@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0B0?ooo`050000o`3oool000000000o`000000
0P000?l0103oool0003o0?ooo`3oool20000odl0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo
00<000000000o`000?l00P3oool30000o`80oooo00<0003o0?ooo`3oool00P000?l00`3oool0003o
0?ooo`1;0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<00000203oool010000?l0oooo0?oo
o`000?l20?ooo`030000o`3oool0oooo00<0003oB@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203o
ool3000000`0oooo00<0003o0?ooo`3oool00P000?l01P3oool0003o0?ooo`3oool0003o0?ooo`80
003oA`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool300000100oooo00@0003o0?ooo`3oool0
oooo0`000?l20?ooo`040000o`3oool0oooo0000odH0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
00006P3oool010000?l0oooo0?ooo`000?l20?ooo`80003o0`3oool00`000?l0oooo0?ooo`0n0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0S03oool200000240oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0
oooo00<000000?ooo`3oool08@3oool40000o`@0oooo00<0003o0?ooo`3oool00P000?li0?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02X0oooo00@0003o0?ooo`000?l0oooo0`000?lc0?ooo`<000000P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0:03oool40000o`030?ooo`000?l0oooo0080oooo0P000?l]0?ooo`@00000
1P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0;03oool010000?l0oooo0000o`000?l30?ooo`050000
o`3oool0oooo0?ooo`000?l09@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo
00@0003o0?ooo`3oool0oooo0P000?lQ0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
<03oool01@000?l0oooo0?ooo`3oool0003o00<0oooo0P000?l00`3oool0003o0?ooo`0J0?ooo`<0
00004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0<@3oool010000?l0oooo0?ooo`3oool20000o`03
0?ooo`000?l0oooo00<0003o5`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`020?ooo`80003o0`3oool00`000?l0oooo
0?ooo`0<0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool50000o`030?ooo`00
0?l0oooo0080oooo0`000?l20?ooo`@0003o1`3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo03h0oooo00<0003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l30?ooo`<000008P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0@@3oool00`000?l0oooo0000o`030?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`120?ooo`030000o`3oool00000008000000P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0200oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo100000000`3oool0
003o0000o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0803oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0?P3oool3000000L0oooo10000?l50?ooo`030000o`3oool0oooo0200oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03/0oooo0`00000C0?ooo`80003o0P3oool40000oa/0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03P0oooo0`00000D0?ooo`040000o`3oool0oooo0000o`80oooo00@0
003o0?ooo`3oool0oooo0`000?lI0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000603o
ool40000o`80oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0G0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0a0?ooo`@000007`3oool00`000?l0oooo0000o`050?ooo`030000o`3oool0
oooo01P0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00000V0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000002X0
oooo0P000?l40?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo
0`00000_0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05`3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?oo
o`0U0?ooo`<00000<`3oool01@000?l0oooo0?ooo`3oool0003o01X0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool4000003L0oooo0`000?l00`3oool0003o0?ooo`0I0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<00000?P3oool30000oaX0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.38969 .58099 m
.3769 .56817 L
s
.39455 .57477 m
.39953 .57606 L
s
.39137 .57281 m
.39455 .57477 L
s
.39953 .57606 m
.4036 .57642 L
s
.37002 .5625 m
.37229 .56354 L
s
.37229 .56354 m
.37271 .56273 L
s
.37043 .56168 m
.37002 .5625 L
s
.4036 .57642 m
.40679 .57587 L
s
.37271 .56273 m
.37043 .56168 L
s
.38814 .56831 m
.38495 .56633 L
s
.39178 .56947 m
.38814 .56831 L
s
.40679 .57587 m
.40634 .57414 L
s
.3995 .571 m
.39178 .56947 L
s
.38495 .56633 m
.38402 .5654 L
s
.38402 .5654 m
.38354 .56366 L
s
.40634 .57414 m
.40315 .57217 L
s
.40315 .57217 m
.3995 .571 L
s
.38354 .56366 m
.38669 .56308 L
s
.41913 .57697 m
.42279 .57814 L
s
.41456 .57487 m
.41913 .57697 L
s
.38669 .56308 m
.39079 .56343 L
s
.42279 .57814 m
.42694 .57851 L
s
.39079 .56343 m
.39581 .56471 L
s
.42694 .57851 m
.4288 .57783 L
s
.39581 .56471 m
.39902 .5667 L
s
.45078 .58743 m
.45129 .58664 L
s
.44849 .58638 m
.45078 .58743 L
s
.449 .58558 m
.44849 .58638 L
s
.4288 .57783 m
.42977 .57622 L
s
.45129 .58664 m
.449 .58558 L
s
.40819 .56578 m
.40727 .56742 L
s
.42977 .57622 m
.42844 .57354 L
s
.41004 .56508 m
.40819 .56578 L
s
.44363 .58001 m
.43095 .56687 L
s
.42844 .57354 m
.42663 .57167 L
s
.4142 .56543 m
.41004 .56508 L
s
.42663 .57167 m
.4225 .56873 L
s
.41789 .56661 m
.4142 .56543 L
s
.4225 .56873 m
.41789 .56661 L
s
.45537 .58021 m
.45127 .57727 L
s
.45909 .5814 m
.45537 .58021 L
s
.47665 .58896 m
.45786 .56917 L
s
.46334 .58178 m
.45909 .5814 L
s
.45127 .57727 m
.44222 .56783 L
s
.46528 .5811 m
.46334 .58178 L
s
.46687 .57865 m
.46528 .5811 L
s
.48529 .58289 m
.48064 .58074 L
s
.48906 .58409 m
.48529 .58289 L
s
.48064 .58074 m
.47652 .57777 L
s
.49339 .58448 m
.48906 .58409 L
s
.47652 .57777 m
.47473 .57588 L
s
.4954 .58379 m
.49339 .58448 L
s
.47473 .57588 m
.47348 .57315 L
s
.49653 .58215 m
.4954 .58379 L
s
.49918 .585 m
.48041 .56489 L
s
.47348 .57315 m
.47457 .57149 L
s
.47457 .57149 m
.47656 .57078 L
s
.50937 .58591 m
.49695 .57252 L
s
.47656 .57078 m
.4809 .57115 L
s
.51142 .58522 m
.51523 .58644 L
s
.50673 .58306 m
.51142 .58522 L
s
.51523 .58644 m
.51963 .58683 L
s
.4809 .57115 m
.48471 .57236 L
s
.48471 .57236 m
.48941 .57453 L
s
.51963 .58683 m
.5217 .58614 L
s
.5217 .58614 m
.52289 .5845 L
s
.50078 .57374 m
.49963 .57541 L
s
.52289 .5845 m
.52173 .58175 L
s
.53887 .58856 m
.53441 .58816 L
s
.50283 .57303 m
.50078 .57374 L
s
.52173 .58175 m
.51997 .57983 L
s
.54098 .58787 m
.53887 .58856 L
s
.50725 .57341 m
.50283 .57303 L
s
.51997 .57983 m
.51583 .57681 L
s
.54222 .58621 m
.54098 .58787 L
s
.51109 .57463 m
.50725 .57341 L
s
.51583 .57681 m
.51109 .57463 L
s
.54633 .58923 m
.53405 .5757 L
s
.56503 .59619 m
.5689 .59742 L
s
.56029 .594 m
.56503 .59619 L
s
.55706 .59195 m
.56029 .594 L
s
.54109 .58346 m
.54222 .58621 L
s
.5689 .59742 m
.57495 .59797 L
s
.57495 .59797 m
.57712 .59729 L
s
.57712 .59729 m
.57845 .59565 L
s
.55767 .58492 m
.55011 .58425 L
s
.54749 .58134 m
.55011 .58425 L
s
.57845 .59565 m
.57826 .59386 L
s
.54724 .57953 m
.54749 .58134 L
s
.57826 .59386 m
.5772 .59111 L
s
.54851 .57784 m
.54724 .57953 L
s
.5772 .59111 m
.57289 .58625 L
s
.55067 .57713 m
.54851 .57784 L
s
.58725 .5929 m
.58133 .57975 L
s
.55675 .57765 m
.55067 .57713 L
s
.57289 .58625 m
.56875 .5832 L
s
.56875 .5832 m
.56548 .58111 L
s
.56068 .57889 m
.55675 .57765 L
s
.56548 .58111 m
.56068 .57889 L
s
.59959 .594 m
.58133 .57975 L
s
.59959 .594 m
.59377 .58082 L
s
.61202 .59512 m
.59377 .58082 L
s
.62297 .5961 m
.61103 .5823 L
s
.62527 .5954 m
.62927 .59667 L
s
.62043 .59316 m
.62527 .5954 L
s
.62927 .59667 m
.63401 .59709 L
s
.63401 .59709 m
.63633 .59639 L
s
.63633 .59639 m
.63782 .59471 L
s
.61505 .58356 m
.61361 .58528 L
s
.63782 .59471 m
.63688 .59189 L
s
.6547 .59895 m
.6499 .59852 L
s
.61736 .58284 m
.61505 .58356 L
s
.63688 .59189 m
.63519 .5899 L
s
.65707 .59825 m
.6547 .59895 L
s
.62212 .58325 m
.61736 .58284 L
s
.63519 .5899 m
.63104 .58679 L
s
.65862 .59656 m
.65707 .59825 L
s
.62615 .58452 m
.62212 .58325 L
s
.63104 .58679 m
.62615 .58452 L
s
.66273 .59967 m
.65098 .58572 L
s
.65772 .59372 m
.65862 .59656 L
s
.68548 .6072 m
.68059 .60493 L
s
.69118 .60863 m
.68548 .6072 L
s
.68059 .60493 m
.67732 .60281 L
s
.67732 .60281 m
.67321 .59969 L
s
.70263 .60968 m
.69118 .60863 L
s
.67321 .59969 m
.66905 .59472 L
s
.70263 .60968 m
.68532 .58866 L
s
.66905 .59472 m
.66817 .59186 L
s
.66817 .59186 m
.66813 .59 L
s
.66813 .59 m
.66971 .58826 L
s
.66971 .58826 m
.67379 .58768 L
s
.67379 .58768 m
.68532 .58866 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1i0?ooo`80003o0`3oool40000o`80oooo00<0
00000?ooo`3oool0603oool3000005@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`1n0?ooo`040000o`3oool0oooo0?ooo`<0003o00<0
00000?ooo`000?l010000?l@0?ooo`<000000`3oool00`000?l0oooo0?ooo`1A0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0N`3oool0
10000?l0oooo0?ooo`3oool40000o`<0oooo00<000000000o`3oool00`3oool01@000?l0oooo0?oo
o`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3oool00`000000003o000000070?ooo`030000
o`3oool0oooo0500oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo00@0oooo0`000?l00`3oool000000?oo
o`040?ooo`80003o0P3oool01@000?l0oooo0?ooo`3oool0003o00<000000P3oool00`000?l0oooo
0?ooo`020?ooo`<0003o00<0oooo0000o`3oool0D03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo07d0oooo00@0003o0?ooo`3oool0oooo
0P000?l30?ooo`040000o`3oool000000000o`D0oooo00@0003o0?ooo`3oool0003o0`0000000`00
0?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0000o`<0oooo0`000?l20?ooo`030000o`3oool0
003o00<0003oB03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo07l0oooo00<0003o0?ooo`3oool00P3oool50000o`040?ooo`000000003o
0000o`<0oooo00D0003o00000000000000000000o`030?ooo`030000o`3oool0oooo00<0oooo00@0
003o0?ooo`3oool0003o1@3oool010000?l0oooo0?ooo`000?l40?ooo`80003o1P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0oooo00P0oooo
00<000000?ooo`000?l00`000?l40?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool01@000?l0
oooo0?ooo`3oool0003o00D0oooo00@0003o0?ooo`3oool0003o1@3oool20000o`D0oooo00H0003o
0?ooo`3oool0oooo0000o`3oool40000o`L0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo0840oooo00<0
003o0?ooo`3oool0203oool2000000d0oooo0`000?l00`3oool0003o0?ooo`020?ooo`<0003o0`3o
ool010000?l0oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0
003o1@3oool20000o`D0oooo0P000?l20?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`00
0?l0803oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000
S@3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool50000o`80oooo0`000?l30?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
10000?l30?ooo`030000o`3oool0oooo00<0oooo0P000?l0103oool0003o0000o`000?l50?ooo`03
0000o`3oool0003o0080003o703oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`080?ooo`80003o203oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0003o0080003o103oool00`000?l0oooo0?ooo`020000o`T0oooo
00<0003o0?ooo`3oool00P3oool01`000?l0oooo0000o`3oool0003o0?ooo`000?l01@3oool01000
0?l0oooo0?ooo`3oool20000o`L0oooo00<0003o0?ooo`3oool0103oool30000o`H0oooo0`000002
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo01<0oooo0P000?l20?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l2
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool20000o`H0oooo00<0003o
0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20000o`@000001P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l00P3o
ool20000o`80oooo0P000?l30?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o
ool01@000?l0oooo0?ooo`3oool0003o0080oooo0`0000000`3oool0003o0?ooo`070?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0b0?ooo`<0003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo
00@0003o0?ooo`3oool0oooo0`0000050?ooo`030000o`3oool0oooo00H0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03D0oooo10000?lB0?ooo`@0003o103oool40000o`<0000000<0oooo0000o`3oool0
1P3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<0000000<0
oooo0000o`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo0500oooo100000090?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0C@3oool3000000h0oooo0P000?l60?oo
o`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000C0?ooo`P0
003o1`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0A03o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000000^0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02h0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<0
0000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0
B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3o
ool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool2
00000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0
oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000680
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<0
0000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003o
ool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo
000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<00000
2@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo
0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`03
0000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000
:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo
0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000
B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo
0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003o
ool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2
000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo
0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<00000
0?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
2`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool40000
0900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3o
ool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00
002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool0
0`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool0
0280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo
0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0
Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
1P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`00
0000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300
oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000
oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo
0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?oo
o`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo
0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000
oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo
0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00
001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo
0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00
001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`80
00002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00
?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003o
ool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool0
05T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo
0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580
oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`80
0000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00
H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P000002
0?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@0
00001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3o
ool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo
00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<0
00000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b
0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?oo
o`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@0
0000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3o
ool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2
000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool01000
0000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool5
00000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0
oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool0
06T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo
0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?oo
o`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000
000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<00000
0?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`03
0000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0
G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3o
ool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4
000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980
oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo
0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<00000
0?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?oo
o`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3o
ool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0
;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0
000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool4
00000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool0
0`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80
000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo
0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<0
00000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool3
00000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37822 .61381 m
.36525 .60114 L
s
.38401 .60496 m
.38935 .60532 L
s
.38069 .60332 m
.38401 .60496 L
s
.38935 .60532 m
.39378 .60477 L
s
.39378 .60477 m
.39729 .60331 L
s
.35816 .59584 m
.36056 .59657 L
s
.36056 .59657 m
.36109 .59547 L
s
.35868 .59474 m
.35816 .59584 L
s
.39729 .60331 m
.39693 .6013 L
s
.36109 .59547 m
.35868 .59474 L
s
.37752 .59857 m
.37419 .59692 L
s
.3814 .59911 m
.37752 .59857 L
s
.38972 .5991 m
.3814 .59911 L
s
.37419 .59692 m
.37325 .596 L
s
.39693 .6013 m
.39361 .59965 L
s
.37325 .596 m
.37286 .59397 L
s
.39361 .59965 m
.38972 .5991 L
s
.37286 .59397 m
.37635 .59248 L
s
.41066 .60165 m
.41456 .6022 L
s
.40585 .60019 m
.41066 .60165 L
s
.41456 .6022 m
.41904 .60165 L
s
.37635 .59248 m
.3808 .59192 L
s
.41904 .60165 m
.42113 .60036 L
s
.4443 .60678 m
.44491 .60568 L
s
.44189 .60605 m
.4443 .60678 L
s
.4425 .60494 m
.44189 .60605 L
s
.38618 .59227 m
.38953 .59394 L
s
.3808 .59192 m
.38618 .59227 L
s
.44491 .60568 m
.4425 .60494 L
s
.42113 .60036 m
.4223 .59814 L
s
.4223 .59814 m
.42106 .59517 L
s
.39961 .59056 m
.39847 .5928 L
s
.43708 .59941 m
.4243 .58636 L
s
.40167 .58925 m
.39961 .59056 L
s
.42106 .59517 m
.41923 .59331 L
s
.41923 .59331 m
.41497 .59071 L
s
.40618 .58868 m
.40167 .58925 L
s
.41497 .59071 m
.41011 .58923 L
s
.41011 .58923 m
.40618 .58868 L
s
.47225 .60234 m
.45335 .58266 L
s
.44982 .59679 m
.44559 .59419 L
s
.45377 .59735 m
.44982 .59679 L
s
.45835 .59678 m
.45377 .59735 L
s
.44559 .59419 m
.43648 .58481 L
s
.46051 .59547 m
.45835 .59678 L
s
.4624 .59209 m
.46051 .59547 L
s
.48205 .5928 m
.47717 .5913 L
s
.48604 .59335 m
.48205 .5928 L
s
.49069 .59278 m
.48604 .59335 L
s
.47717 .5913 m
.47293 .58866 L
s
.49291 .59145 m
.49069 .59278 L
s
.47293 .58866 m
.47113 .58677 L
s
.47113 .58677 m
.46998 .58373 L
s
.49425 .58917 m
.49291 .59145 L
s
.49691 .59201 m
.47808 .57195 L
s
.46998 .58373 m
.47127 .58144 L
s
.50785 .59065 m
.4954 .57729 L
s
.47127 .58144 m
.47348 .58009 L
s
.5101 .58932 m
.51413 .58988 L
s
.5052 .58781 m
.5101 .58932 L
s
.51413 .58988 m
.51885 .58929 L
s
.47348 .58009 m
.47815 .57949 L
s
.51885 .58929 m
.52112 .58795 L
s
.48218 .58005 m
.4871 .58156 L
s
.47815 .57949 m
.48218 .58005 L
s
.52112 .58795 m
.52253 .58565 L
s
.52253 .58565 m
.52147 .58258 L
s
.49944 .57785 m
.49808 .58017 L
s
.53944 .58674 m
.53467 .58733 L
s
.54175 .58539 m
.53944 .58674 L
s
.5017 .57648 m
.49944 .57785 L
s
.52147 .58258 m
.5197 .58066 L
s
.5197 .58066 m
.51546 .57797 L
s
.54321 .58307 m
.54175 .58539 L
s
.50645 .57588 m
.5017 .57648 L
s
.54742 .58575 m
.53516 .57221 L
s
.56702 .58973 m
.57109 .59029 L
s
.56209 .58821 m
.56702 .58973 L
s
.57109 .59029 m
.57754 .58951 L
s
.55876 .58649 m
.56209 .58821 L
s
.51546 .57797 m
.51051 .57644 L
s
.51051 .57644 m
.50645 .57588 L
s
.54219 .57998 m
.54321 .58307 L
s
.57754 .58951 m
.57992 .58815 L
s
.57992 .58815 m
.58145 .58583 L
s
.58145 .58583 m
.58136 .5837 L
s
.55989 .57776 m
.55182 .57877 L
s
.54921 .57586 m
.55182 .57877 L
s
.58136 .5837 m
.58042 .58059 L
s
.54907 .5737 m
.54921 .57586 L
s
.58042 .58059 m
.57612 .57572 L
s
.55055 .57134 m
.54907 .5737 L
s
.59106 .58035 m
.58561 .56577 L
s
.55291 .56995 m
.55055 .57134 L
s
.57612 .57572 m
.5719 .57299 L
s
.55941 .56912 m
.55291 .56995 L
s
.5719 .57299 m
.56854 .57124 L
s
.56854 .57124 m
.56354 .56969 L
s
.56354 .56969 m
.55941 .56912 L
s
.60418 .57873 m
.58561 .56577 L
s
.60418 .57873 m
.59884 .56409 L
s
.61738 .57709 m
.59884 .56409 L
s
.62901 .57565 m
.61717 .56175 L
s
.63151 .57425 m
.63568 .57483 L
s
.62649 .57269 m
.63151 .57425 L
s
.63568 .57483 m
.6407 .5742 L
s
.6407 .5742 m
.64322 .5728 L
s
.64322 .5728 m
.64492 .5704 L
s
.64492 .5704 m
.6441 .56719 L
s
.62138 .56232 m
.61973 .56475 L
s
.6626 .57149 m
.65753 .57212 L
s
.66517 .57008 m
.6626 .57149 L
s
.62388 .56089 m
.62138 .56232 L
s
.6441 .56719 m
.64242 .5652 L
s
.64242 .5652 m
.63821 .5624 L
s
.66691 .56765 m
.66517 .57008 L
s
.62893 .56025 m
.62388 .56089 L
s
.67109 .57044 m
.65948 .55635 L
s
.63821 .5624 m
.63315 .56082 L
s
.63315 .56082 m
.62893 .56025 L
s
.69475 .57412 m
.68971 .57255 L
s
.7007 .57449 m
.69475 .57412 L
s
.66614 .56443 m
.66691 .56765 L
s
.68971 .57255 m
.68637 .57076 L
s
.71275 .57302 m
.7007 .57449 L
s
.68637 .57076 m
.68221 .56796 L
s
.68221 .56796 m
.6781 .56293 L
s
.71275 .57302 m
.69571 .55172 L
s
.6781 .56293 m
.67735 .55968 L
s
.67735 .55968 m
.67742 .55743 L
s
.67742 .55743 m
.67921 .55495 L
s
.67921 .55495 m
.68356 .55327 L
s
.68356 .55327 m
.69571 .55172 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00000o0?ooo`D0003o0P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`00
0000oooo0?ooo`0U0?ooo`<00000@03oool20000o`D0oooo00<0003o0?ooo`000000FP3oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000l0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
00000?ooo`1I0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000380oooo10000?l:0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01`3oool00`000?l000000?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000002`0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0000o`040?ooo`80003o2@3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0000003oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000Z
0?ooo`030000o`3oool0oooo0080oooo0`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0100oooo0`00000S0?ooo`030000o`3oool0oooo00L0oooo0`000?l30?oo
o`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000000003o0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000000P0oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`<0
003o00<0oooo0000o`000?l00P000?l60?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3o
ool0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo10000?l00`3o
ool0003o0?ooo`030?ooo`80003o1P3oool00`000000oooo0000o`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000000`0
oooo00<0003o0?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo0P000?l3
0?ooo`P0003o403oool60000o`04000000000?l0003o0000oeL0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000403oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00<0003o2P3oool01@000?l0oooo0?ooo`3o
ool0003o00P0oooo0P000?l30?ooo`040000o`3oool0oooo0?ooo`<0003o103oool01@000?l0oooo
0?ooo`3oool0003o01`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000003`3oool60000o`@0oooo
00<0003o0?ooo`3oool00P3oool20000o`P0oooo0P000?l30?ooo`@0003o1@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool08`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00
000;0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0oooo00/0oooo00D0
003o0?ooo`3oool0oooo0000o`0Z0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo0P000?l=0?ooo`030000o`3o
ool0oooo02X0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`000?l01@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00<0oooo0P000?l30?ooo`<0003o0P3oool010000?l0oooo0?ooo`3oool20000o`H0oooo0P00
0?lY0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08D0oooo1`000?l010000000oooo0?ooo`000?l40?ooo`030000o`3o
ool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo0080oooo
1@000?l@0?ooo`H0003o9`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1l0?ooo`D0003o0`3oool00`000?l0oooo0?oo
o`050?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo2@000?m20?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo07H0oooo0P000?l40?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`000000003o0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool20000od/0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0M`3oool0
0`000?l0oooo0?ooo`020?ooo`<0003o3P3oool00`000000003o0?ooo`030?ooo`030000o`3oool0
oooo0080oooo1@000?l20?ooo`030000o`3oool0oooo04D0oooo0`00000B0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0N@3oool00`00
0?l0oooo0?ooo`030?ooo`L0003o0P3oool30000o`80oooo0P000?l50?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0@@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`80003o00<000000?ooo`3o
ool04@3oool00`000?l0oooo0?ooo`0l0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo07/0oooo00<0003o0?ooo`3oool0
0P3oool50000o`P0oooo00<000000?ooo`3oool01P3oool20000odD0oooo0`00000N0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0O03o
ool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo04X0oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0OP3oool0
0`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo04L0oooo0`00000V0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P0000200?ooo`030000o`3oool0oooo
00`0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400
oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3
000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool30000
08h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?oo
o`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<0
0000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4
000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool30000
02/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?oo
o`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3o
ool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool30000
04/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?oo
o`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0
oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00
002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00
001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0
oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo
0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0013
0?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00
B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;
0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003o
ool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo
0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?oo
o`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003o
ool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0
f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`00
0000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0
oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo
1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000
000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?oo
o`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`80
0000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0
oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo
0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0
oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0
oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0
oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo
0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M
0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q
0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?oo
o`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3
000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo
0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A
0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?oo
o`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000
003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303o
ool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03o
ool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2
000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo
0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool50000
0;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0
oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0
oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo
0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:
0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo0000
00H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo
0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37327 .64637 m
.36013 .63384 L
s
.37951 .63485 m
.38503 .63429 L
s
.37611 .63354 m
.37951 .63485 L
s
.38503 .63429 m
.38962 .63282 L
s
.38962 .63282 m
.3933 .63045 L
s
.3933 .63045 m
.39298 .62814 L
s
.35292 .6289 m
.35539 .62931 L
s
.35539 .62931 m
.35597 .62792 L
s
.35349 .6275 m
.35292 .6289 L
s
.37294 .62852 m
.36952 .6272 L
s
.37695 .62844 m
.37294 .62852 L
s
.38557 .62689 m
.37695 .62844 L
s
.39298 .62814 m
.38958 .62682 L
s
.35597 .62792 m
.35349 .6275 L
s
.36952 .6272 m
.36858 .62629 L
s
.38958 .62682 m
.38557 .62689 L
s
.36858 .62629 m
.36822 .62397 L
s
.40717 .62602 m
.41119 .62594 L
s
.40223 .62518 m
.40717 .62602 L
s
.41119 .62594 m
.41583 .62446 L
s
.44176 .62583 m
.44241 .62442 L
s
.4393 .62541 m
.44176 .62583 L
s
.43995 .62401 m
.4393 .62541 L
s
.41583 .62446 m
.41801 .62256 L
s
.44241 .62442 m
.43995 .62401 L
s
.36822 .62397 m
.37189 .62157 L
s
.41801 .62256 m
.41928 .61974 L
s
.37189 .62157 m
.37651 .62008 L
s
.38208 .61951 m
.3855 .62084 L
s
.37651 .62008 m
.38208 .61951 L
s
.41928 .61974 m
.41807 .61648 L
s
.43449 .61851 m
.42162 .60554 L
s
.39601 .61502 m
.39478 .61786 L
s
.41807 .61648 m
.41622 .61463 L
s
.4706 .61548 m
.45161 .59587 L
s
.39818 .61309 m
.39601 .61502 L
s
.41622 .61463 m
.41188 .61236 L
s
.44767 .61309 m
.44337 .61082 L
s
.45172 .61302 m
.44767 .61309 L
s
.40285 .61159 m
.39818 .61309 L
s
.45644 .61151 m
.45172 .61302 L
s
.41188 .61236 m
.4069 .61151 L
s
.4069 .61151 m
.40285 .61159 L
s
.45868 .60958 m
.45644 .61151 L
s
.44337 .61082 m
.4342 .60148 L
s
.46071 .60527 m
.45868 .60958 L
s
.48085 .6025 m
.47588 .60164 L
s
.48493 .60242 m
.48085 .6025 L
s
.48971 .6009 m
.48493 .60242 L
s
.47588 .60164 m
.47159 .59933 L
s
.49201 .59894 m
.48971 .6009 L
s
.47159 .59933 m
.46978 .59745 L
s
.49343 .59603 m
.49201 .59894 L
s
.4961 .59886 m
.47722 .57885 L
s
.46978 .59745 m
.46866 .5941 L
s
.50731 .59528 m
.49484 .58194 L
s
.46866 .5941 m
.47004 .59118 L
s
.50964 .59331 m
.51374 .59323 L
s
.50466 .59244 m
.50964 .59331 L
s
.51374 .59323 m
.51858 .59169 L
s
.51858 .59169 m
.52093 .58971 L
s
.47004 .59118 m
.47233 .58919 L
s
.52093 .58971 m
.5224 .58677 L
s
.47233 .58919 m
.47714 .58764 L
s
.48125 .58756 m
.48626 .58844 L
s
.47714 .58764 m
.48125 .58756 L
s
.5224 .58677 m
.52138 .58338 L
s
.53963 .58498 m
.53475 .58653 L
s
.54201 .58298 m
.53963 .58498 L
s
.49897 .58186 m
.49753 .58482 L
s
.56764 .58346 m
.57176 .58338 L
s
.56265 .58258 m
.56764 .58346 L
s
.57176 .58338 m
.57832 .5813 L
s
.52138 .58338 m
.51961 .58146 L
s
.54353 .58002 m
.54201 .58298 L
s
.5593 .58118 m
.56265 .58258 L
s
.54777 .58238 m
.53553 .56883 L
s
.50131 .57985 m
.49897 .58186 L
s
.51961 .58146 m
.51533 .57909 L
s
.57832 .5813 m
.58076 .57929 L
s
.54255 .5766 m
.54353 .58002 L
s
.50617 .57829 m
.50131 .57985 L
s
.58076 .57929 m
.58235 .57632 L
s
.51533 .57909 m
.51031 .57821 L
s
.51031 .57821 m
.50617 .57829 L
s
.58235 .57632 m
.5823 .57385 L
s
.5823 .57385 m
.58139 .57041 L
s
.56059 .57082 m
.55237 .57345 L
s
.54976 .57053 m
.55237 .57345 L
s
.54966 .56805 m
.54976 .57053 L
s
.58139 .57041 m
.5771 .56552 L
s
.59217 .56821 m
.58687 .55227 L
s
.5512 .56503 m
.54966 .56805 L
s
.5771 .56552 m
.57287 .56311 L
s
.55363 .56299 m
.5512 .56503 L
s
.60548 .56397 m
.58687 .55227 L
s
.60548 .56397 m
.60029 .54795 L
s
.57287 .56311 m
.56948 .56168 L
s
.56025 .56086 m
.55363 .56299 L
s
.56948 .56168 m
.56443 .56078 L
s
.56443 .56078 m
.56025 .56086 L
s
.61885 .55971 m
.60029 .54795 L
s
.6306 .55596 m
.61885 .54197 L
s
.63314 .55389 m
.63734 .55381 L
s
.6281 .55298 m
.63314 .55389 L
s
.63734 .55381 m
.64241 .55219 L
s
.64241 .55219 m
.64497 .55012 L
s
.64497 .55012 m
.6467 .54703 L
s
.6467 .54703 m
.64592 .54348 L
s
.66448 .54515 m
.65937 .54678 L
s
.66707 .54306 m
.66448 .54515 L
s
.62308 .54188 m
.62138 .54499 L
s
.64592 .54348 m
.64425 .54146 L
s
.66886 .53995 m
.66707 .54306 L
s
.69671 .54247 m
.69167 .54155 L
s
.70266 .54184 m
.69671 .54247 L
s
.67301 .54243 m
.66152 .52822 L
s
.62563 .53978 m
.62308 .54188 L
s
.71473 .53801 m
.70266 .54184 L
s
.69167 .54155 m
.68834 .54008 L
s
.64425 .54146 m
.64005 .53898 L
s
.68834 .54008 m
.6842 .53759 L
s
.66811 .53637 m
.66886 .53995 L
s
.63073 .53814 m
.62563 .53978 L
s
.64005 .53898 m
.63497 .53806 L
s
.63497 .53806 m
.63073 .53814 L
s
.71473 .53801 m
.6979 .51649 L
s
.6842 .53759 m
.68014 .53251 L
s
.68014 .53251 m
.67942 .5289 L
s
.67942 .5289 m
.67951 .52629 L
s
.67951 .52629 m
.68133 .52312 L
s
.68133 .52312 m
.68572 .52042 L
s
.68572 .52042 m
.6979 .51649 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000K0?ooo`80
003o00<0oooo0000003oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000K0?ooo`<0003o0P3oool00`000?l00000
0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<0
00000?ooo`3oool0E@3oool3000001d0oooo0P000?l50?ooo`030000o`000000oooo05L0oooo00<0
00000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`1A
0?ooo`<000007`3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo04d0oooo0`00000L0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000000003o0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo04T0oooo0`00000P0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`000000oooo0000o`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000
003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<00000
903oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`000?l0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000002L0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`050?ooo`040000003oool0oooo0000oeH0oooo00<000000?ooo`3oool0
5@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3o
ool3000001X0oooo1`000?l90?ooo`80003o103oool00`000?l0oooo0?ooo`040?ooo`030000003o
ool0oooo0080003oE@3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo03T0oooo0`00000K0?ooo`80003o1`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0003o00@0oooo1P000?l00`000000003o0000o`1G0?ooo`030000003oool0
oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool30000
01l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80003o303oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0<@3oool3000001X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P000?l>0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<000007@3oool30000o`H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0C0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<000006`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0003o00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0D0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`000021
0?ooo`030000003oool0oooo02D0oooo0`00000N0?ooo`<0003o0`3oool010000?l0oooo0?ooo`00
0?l60?ooo`@0003o5`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool300000280oooo00H0003o
0?ooo`000?l0003o0?ooo`000?l30?ooo`80003o7`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703o
ool4000001T0oooo0`000?l90?ooo`040000o`3oool0oooo0?ooo`<0003o103oool00`000?l0oooo
0?ooo`0M0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000006`3oool20000o`<0oooo0`00
0?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0503oool3000001d0oooo00<0003o0?ooo`3oool01P3oool20000o`D0oooo00<0003o
0?ooo`3oool09`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001/0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool09`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001l0oooo00D0003o0?ooo`3o
ool0oooo0000o`020?ooo`80003o1`3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`080?ooo`<000008`3oool010000?l0oooo0?ooo`3oool20000o`T0oooo00<0003o0?oo
o`3oool0:`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000002H0oooo00<0003o0?ooo`3o
ool0303oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000140oooo
00<0003o0?ooo`3oool01P3oool60000o`X0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0S03oool2000001D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000
o`060?ooo`80003o1`3oool00`000?l0oooo0000o`030?ooo`<0003o103oool20000obh0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool05@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool0103oool20000o`P0oooo10000?l_0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01<0oooo0P000?l00`3o
ool0003o0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0P000?lj
0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool04@3oool20000o`80oooo0`000?l40?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>P3oool4000000H0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0100oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`H0
003o>P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
>@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o03`0oooo0`00000B0?ooo`030000003o
ool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool2
0000o`@0oooo00<0003o0?ooo`3oool0>P3oool3000001H0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`040?ooo`@0003o>@3oool40000
01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`03000000000?l0oooo00@0oooo00<0003o0?ooo`3oool01@3oool20000ocl0
oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0000o`050?ooo`030000o`3oool0oooo00@0oooo
0P000?ll0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08P0oooo10000?l20?ooo`040000003oool0oooo0000o`D0oooo
00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?lh0?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000QP3oool30000o`@0oooo
0P000?l01@000000oooo0?ooo`3oool0003o00D0oooo10000?l40?ooo`030000o`3oool0oooo0380
oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0Q@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0]0?ooo`@00000;P3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo07h0oooo0`00
0?l40?ooo`030000o`3oool0oooo00D0oooo00<000000000o`3oool0103oool00`000?l0oooo0?oo
o`0g0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo07`0oooo0P000?l30?ooo`80003o2P3oool00`000000003o0?ooo`0k
0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo07/0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00H0oooo0P000?l`0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07L0oooo0P000?l30?ooo`80
003o00<0oooo0000o`000?l01@000?l40?ooo`@0003o00<000000?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0[0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo07H0oooo0P000?l60?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07l0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo02h0oooo0`00
00170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0N@3oool00`000?l0oooo0?ooo`040?ooo`@0003o2P3oool00`000000oooo0?ooo`0[
0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo07X0oooo00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0X0?oo
o`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<0
0000N`3oool20000oa40oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool2000007l0oooo00<0003o0?ooo`3oool0
3P3oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo07l0oooo00<0003o0?ooo`3oool03@3o
ool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool0
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0
oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`00
00020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03o
ool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00
000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37521 .67736 m
.36195 .66494 L
s
.38136 .66324 m
.38687 .66178 L
s
.37795 .66224 m
.38136 .66324 L
s
.38687 .66178 m
.39146 .65943 L
s
.39146 .65943 m
.39511 .65617 L
s
.39511 .65617 m
.39476 .65358 L
s
.44333 .6438 m
.44396 .6421 L
s
.44088 .64368 m
.44333 .6438 L
s
.44151 .64198 m
.44088 .64368 L
s
.44396 .6421 m
.44151 .64198 L
s
.39476 .65358 m
.39135 .65256 L
s
.4129 .6484 m
.41752 .64603 L
s
.4089 .64907 m
.4129 .6484 L
s
.40397 .64884 m
.4089 .64907 L
s
.37874 .65629 m
.37474 .65696 L
s
.38735 .65324 m
.37874 .65629 L
s
.37474 .65696 m
.3713 .65595 L
s
.41752 .64603 m
.41967 .64353 L
s
.39135 .65256 m
.38735 .65324 L
s
.35468 .66035 m
.35716 .66046 L
s
.35716 .66046 m
.35773 .65877 L
s
.35524 .65866 m
.35468 .66035 L
s
.3713 .65595 m
.37035 .65505 L
s
.41967 .64353 m
.4209 .64013 L
s
.35773 .65877 m
.35524 .65866 L
s
.37035 .65505 m
.36997 .65244 L
s
.47181 .62781 m
.45274 .60827 L
s
.43602 .63651 m
.42307 .6236 L
s
.4209 .64013 m
.41966 .63659 L
s
.36997 .65244 m
.37362 .64916 L
s
.38379 .6453 m
.38723 .64633 L
s
.37362 .64916 m
.37823 .64678 L
s
.41966 .63659 m
.4178 .63475 L
s
.37823 .64678 m
.38379 .6453 L
s
.45306 .62775 m
.44905 .62842 L
s
.45772 .62535 m
.45306 .62775 L
s
.44905 .62842 m
.44475 .62645 L
s
.39767 .63814 m
.39647 .64156 L
s
.45993 .62283 m
.45772 .62535 L
s
.4178 .63475 m
.41346 .63279 L
s
.46188 .61763 m
.45993 .62283 L
s
.44475 .62645 m
.43554 .61716 L
s
.39981 .63562 m
.39767 .63814 L
s
.41346 .63279 m
.40849 .63255 L
s
.40445 .63322 m
.39981 .63562 L
s
.40849 .63255 m
.40445 .63322 L
s
.48581 .61091 m
.48178 .61158 L
s
.49051 .60849 m
.48581 .61091 L
s
.48178 .61158 m
.47685 .61132 L
s
.49275 .60594 m
.49051 .60849 L
s
.47685 .61132 m
.47258 .60932 L
s
.49679 .60526 m
.47787 .58529 L
s
.49411 .60244 m
.49275 .60594 L
s
.47258 .60932 m
.47077 .60744 L
s
.5078 .5996 m
.49531 .58627 L
s
.47077 .60744 m
.46961 .6038 L
s
.5141 .59636 m
.51884 .59392 L
s
.51006 .59703 m
.5141 .59636 L
s
.50514 .59676 m
.51006 .59703 L
s
.51884 .59392 m
.52112 .59135 L
s
.52112 .59135 m
.52252 .58781 L
s
.46961 .6038 m
.47094 .60028 L
s
.5709 .57698 m
.57728 .57371 L
s
.56686 .57765 m
.5709 .57698 L
s
.53942 .58334 m
.53466 .58579 L
s
.56196 .57737 m
.56686 .57765 L
s
.52252 .58781 m
.52147 .58412 L
s
.54173 .58074 m
.53942 .58334 L
s
.57728 .57371 m
.57962 .57111 L
s
.47094 .60028 m
.47318 .59771 L
s
.55865 .57626 m
.56196 .57737 L
s
.48197 .59458 m
.48694 .59486 L
s
.54317 .57718 m
.54173 .58074 L
s
.54737 .57925 m
.53514 .56569 L
s
.57962 .57111 m
.58112 .56753 L
s
.47318 .59771 m
.47791 .59526 L
s
.47791 .59526 m
.48197 .59458 L
s
.52147 .58412 m
.5197 .5822 L
s
.49938 .58559 m
.498 .58915 L
s
.54215 .57346 m
.54317 .57718 L
s
.58112 .56753 m
.58103 .56476 L
s
.5197 .5822 m
.51545 .58014 L
s
.50165 .58299 m
.49938 .58559 L
s
.58103 .56476 m
.58008 .56102 L
s
.51545 .58014 m
.51049 .57985 L
s
.50642 .58053 m
.50165 .58299 L
s
.51049 .57985 m
.50642 .58053 L
s
.55975 .5644 m
.55174 .56852 L
s
.54913 .5656 m
.55174 .56852 L
s
.58008 .56102 m
.57581 .55612 L
s
.59057 .55703 m
.58511 .53986 L
s
.54899 .56282 m
.54913 .5656 L
s
.60347 .5504 m
.58511 .53986 L
s
.60347 .5504 m
.59811 .53314 L
s
.57581 .55612 m
.57162 .554 L
s
.55045 .55921 m
.54899 .56282 L
s
.6164 .54375 m
.59811 .53314 L
s
.57162 .554 m
.56829 .55286 L
s
.5528 .55656 m
.55045 .55921 L
s
.56829 .55286 m
.56333 .55255 L
s
.62776 .53791 m
.61606 .52387 L
s
.55924 .55323 m
.5528 .55656 L
s
.56333 .55255 m
.55924 .55323 L
s
.63426 .53457 m
.63914 .53206 L
s
.63018 .53525 m
.63426 .53457 L
s
.62527 .53492 m
.63018 .53525 L
s
.63914 .53206 m
.64158 .52938 L
s
.64158 .52938 m
.6432 .52569 L
s
.66038 .52114 m
.65547 .52366 L
s
.69146 .51372 m
.68658 .51338 L
s
.69719 .5122 m
.69146 .51372 L
s
.70872 .50628 m
.69719 .5122 L
s
.6432 .52569 m
.64236 .52182 L
s
.66284 .51844 m
.66038 .52114 L
s
.68658 .51338 m
.68333 .51219 L
s
.6645 .51472 m
.66284 .51844 L
s
.66858 .51692 m
.65715 .50263 L
s
.70872 .50628 m
.69201 .48461 L
s
.68333 .51219 m
.67928 .50999 L
s
.64236 .52182 m
.64071 .5198 L
s
.62017 .52319 m
.61858 .5269 L
s
.6637 .51083 m
.6645 .51472 L
s
.64071 .5198 m
.63658 .5176 L
s
.67928 .50999 m
.67524 .50488 L
s
.6226 .52048 m
.62017 .52319 L
s
.63658 .5176 m
.63164 .51726 L
s
.62752 .51794 m
.6226 .52048 L
s
.63164 .51726 m
.62752 .51794 L
s
.67524 .50488 m
.67447 .50095 L
s
.67447 .50095 m
.6745 .49803 L
s
.6745 .49803 m
.67619 .49425 L
s
.67619 .49425 m
.68036 .49064 L
s
.68036 .49064 m
.69201 .48461 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08H0oooo00@0003o0?ooo`3oool000000`3oool300000580oooo00<0
00000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`23
0?ooo`80003o00<0oooo0000o`3oool01000001E0?ooo`030000003oool0oooo01L0oooo000[0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0P03oool20000o`<0oooo00<0003o0000
00000000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo07d0oooo0P000?l20?ooo`<0000000<0oooo0000o`000000F03oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo07/0oooo
00<0003o0?ooo`0000000P0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo07X0oooo00<000000000o`000000203o
ool00`000000003o0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0MP3oool3000000030?ooo`000?l0oooo00P0oooo00<00000
0000o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`1b0?ooo`03000000000?l0000000D0oooo00<0003o0?oo
o`3oool01P3oool00`000000oooo0000o`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00@000000?oo
o`3oool0003oEP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0JP3oool3000000H0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`03000000000?l0003o05L0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo06H0oooo0`0000090?ooo`030000o`3oool0oooo00@0oooo0P000?l4
0?ooo`80003o00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0HP3oool3
000000d0oooo00<0003o0?ooo`3oool01@3oool40000o`80oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`1N0?ooo`<000000P3oool40000o`T0oooo00<0003o0?ooo`000?l0303oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0F@3oool4000000<0oooo0P000?l40?ooo`80003o1P3oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1E0?ooo`<000001@3oool20000o`L0oooo
00<0003o0?ooo`3oool00P3oool20000oa00oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00
00090?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=
0?ooo`<00000303oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`190?ooo`<00000403oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0A@3oool3000000X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030000oaL0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo
0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000000d0oooo
0`000?l70?ooo`<0003o6P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0oooo0`00
000;0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`000?l0003o1P3oool00`000?l0oooo
0?ooo`0I0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000003P3oool30000o`<0oooo00@0
003o0?ooo`3oool0oooo0P000?lP0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<000004P3o
ool01P000?l0oooo0000o`000?l0oooo0000o`D0oooo00<0003o0?ooo`3oool07@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool0<@3oool3000001D0oooo00@0003o0?ooo`3oool0oooo0`000?lT0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`0]0?ooo`<00000603oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0280oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00000@0?ooo`D0003o1P3o
ool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000B0?ooo`030000o`3oool0
oooo00<0oooo0`000?l40?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000D0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0W0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000005P3oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo
0`00000J0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0503oool3000001L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020000o`L0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3
000001/0oooo00<0003o0?ooo`3oool00`3oool20000o`T0oooo00<0003o0?ooo`3oool0:`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0303oool3000001l0oooo00<0003o0?ooo`3oool0303oool00`00
0?l0oooo0?ooo`0/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000008`3oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo
0`00000V0?ooo`80003o103oool20000o`<0oooo0P000?l`0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`03000001d0oooo0`000?l90?ooo`030000o`3oool0003o00D0oooo0`000?lb0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2
000001l0oooo00@0003o0?ooo`3oool0oooo0P000?l70?ooo`030000o`3oool0oooo03X0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`<0003o1@3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo03X0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`030?oo
o`80003o203oool010000?l0oooo0?ooo`3oool20000ocX0oooo0`0000020?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0j0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool05P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=`3oool3000000X0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01<0oooo10000?l50?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0=@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0140oooo0P00
0?l40?ooo`030000o`3oool0oooo00<0oooo1@000?le0?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0<`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0100oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0d0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0403oool00`000?l0oooo0?ooo`060?ooo`80003o<P3oool3000001h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo00X0oooo00<0003o0?ooo`3oool00`3oool20000o`H0oooo00<0003o0?ooo`3oool0
;`3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0103o
ool60000obl0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0=@3oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0`0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0003o02h0oooo0`00000c0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0003o:P3oool3000003H0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`040000003oool0oooo0000o`H0oooo00<0003o0?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0003o02H0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool01@000000oooo0?ooo`3oool0003o
00H0oooo1@000?l50?ooo`030000o`3oool0oooo0200oooo0`00000n0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`020?ooo`030000o`3oool0oooo02`0oooo100000120?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0RP3oool40000o`030000
003oool0oooo00<0oooo00<0003o0?ooo`3oool0:03oool3000004L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`280?ooo`80003o103o
ool20000o`D0oooo00<0003o0?ooo`3oool0903oool3000004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`270?ooo`030000o`3oool0
oooo00@0oooo00<000000000o`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool3000008L0oooo00<0003o0?ooo`3oool0103oool00`00
0000oooo0000o`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0100oooo000Q0?ooo`800000T03oool00`000000003o0?ooo`060?ooo`80003o6@3oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`210?ooo`@0003o2P3oool00`000000003o0?ooo`0N0?ooo`<00000F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`1o0?ooo`80003o2@3oool60000oad0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`1n0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?oo
o`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0OP3oool00`000?l0oooo0?ooo`02
0?ooo`<0003o00<0oooo0000o`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`1n0?ooo`D0003o103oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo
0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`1h0?ooo`80003o303oool00`000?l0
oooo0?ooo`060?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0880oooo
1@000?l90?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0O03oool00`000?l0oooo0?oo
o`0A0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0O@3oool00`000?l0oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0OP3oool00`000?l0oooo0?ooo`0?0?oo
o`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0
oooo00h0oooo000P0?ooo`800000P03oool00`000?l0oooo0?ooo`0>0?ooo`@00000P`3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000PP3oool00`000?l0
oooo0?ooo`0;0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo0880oooo00<0003o0?ooo`3oool01`3oool300000080oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`25
0?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<00000
4@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo
000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V
0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000
<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo
100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?oo
o`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P000019
0?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?oo
o`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000
D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo
1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?oo
o`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?oo
o`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000
L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo
100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
0P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`80
0000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003o
ool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool5
00000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo
0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000
P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0
oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
04`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo
00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00
001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?oo
o`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3o
ool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo
001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo
001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo0000
00030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0
oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo
001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?oo
o`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00
K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2
000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool00000
03`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000
oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e
0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?oo
o`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00
J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`03
0000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D0
0000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000
E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03o
ool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool01000
0000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`00
0000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0
oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00
000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<00000
0?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000
R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3o
ool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0
oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo
00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<0
00000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<00000
0?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`03
0000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3o
ool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`80
00002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool00000
0000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo
002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3o
ool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool20000
00@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?oo
o`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?oo
o`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.3842 .70548 m
.37085 .69314 L
s
.44902 .6599 m
.44956 .65793 L
s
.44665 .66005 m
.44902 .6599 L
s
.44719 .65809 m
.44665 .66005 L
s
.44956 .65793 m
.44719 .65809 L
s
.39499 .68663 m
.39936 .68345 L
s
.38968 .68892 m
.39499 .68663 L
s
.39936 .68345 m
.40279 .67938 L
s
.38633 .6882 m
.38968 .68892 L
s
.47586 .6388 m
.45675 .6193 L
s
.40279 .67938 m
.40236 .67652 L
s
.41977 .66859 m
.42415 .66541 L
s
.41591 .66982 m
.41977 .66859 L
s
.42415 .66541 m
.42614 .66237 L
s
.41112 .67014 m
.41591 .66982 L
s
.40236 .67652 m
.39901 .67579 L
s
.42614 .66237 m
.4272 .65843 L
s
.44169 .65263 m
.4287 .63976 L
s
.39901 .67579 m
.39515 .67702 L
s
.39515 .67702 m
.3869 .68144 L
s
.4578 .6409 m
.45395 .64212 L
s
.4622 .6377 m
.4578 .6409 L
s
.4272 .65843 m
.42588 .65463 L
s
.3869 .68144 m
.38302 .68267 L
s
.46423 .63464 m
.4622 .6377 L
s
.45395 .64212 m
.44974 .64043 L
s
.38302 .68267 m
.37965 .68195 L
s
.46591 .62865 m
.46423 .63464 L
s
.37965 .68195 m
.37869 .68105 L
s
.42588 .65463 m
.42401 .6528 L
s
.48865 .61844 m
.48481 .61965 L
s
.49307 .61523 m
.48865 .61844 L
s
.3636 .68885 m
.36603 .68868 L
s
.36603 .68868 m
.36653 .68672 L
s
.44974 .64043 m
.4405 .63116 L
s
.37869 .68105 m
.37823 .67818 L
s
.49512 .61214 m
.49307 .61523 L
s
.48481 .61965 m
.48006 .61993 L
s
.56855 .57138 m
.57447 .56707 L
s
.56473 .57257 m
.56855 .57138 L
s
.3641 .68689 m
.3636 .68885 L
s
.49896 .61094 m
.48002 .59098 L
s
.36653 .68672 m
.3641 .68689 L
s
.57447 .56707 m
.57658 .56395 L
s
.56006 .5728 m
.56473 .57257 L
s
.49628 .60811 m
.49512 .61214 L
s
.42401 .6528 m
.41973 .65112 L
s
.39142 .66856 m
.39479 .66931 L
s
.50928 .60342 m
.49678 .5901 L
s
.48006 .61993 m
.47587 .61819 L
s
.37823 .67818 m
.38166 .67407 L
s
.57658 .56395 m
.57785 .55986 L
s
.51518 .59912 m
.51961 .5959 L
s
.51135 .60033 m
.51518 .59912 L
s
.40462 .65893 m
.40358 .66289 L
s
.55687 .57195 m
.56006 .5728 L
s
.51961 .5959 m
.52169 .59279 L
s
.50662 .60058 m
.51135 .60033 L
s
.38606 .67087 m
.39142 .66856 L
s
.38166 .67407 m
.38606 .67087 L
s
.52169 .59279 m
.52289 .58873 L
s
.41973 .65112 m
.41491 .65143 L
s
.53884 .5819 m
.5344 .58513 L
s
.57785 .55986 m
.57764 .55683 L
s
.47587 .61819 m
.47406 .61632 L
s
.54093 .57878 m
.53884 .5819 L
s
.40662 .65587 m
.40462 .65893 L
s
.54625 .5765 m
.53402 .56293 L
s
.41491 .65143 m
.41103 .65265 L
s
.54216 .5747 m
.54093 .57878 L
s
.41103 .65265 m
.40662 .65587 L
s
.52289 .58873 m
.52173 .58478 L
s
.57764 .55683 m
.57658 .55282 L
s
.47406 .61632 m
.47281 .61242 L
s
.54103 .57071 m
.54216 .5747 L
s
.52173 .58478 m
.51996 .58286 L
s
.58636 .5473 m
.58043 .52908 L
s
.57658 .55282 m
.57231 .54792 L
s
.47281 .61242 m
.47395 .60837 L
s
.59828 .53862 m
.58043 .52908 L
s
.59828 .53862 m
.59245 .52031 L
s
.51996 .58286 m
.51582 .58106 L
s
.48432 .6008 m
.4891 .60054 L
s
.47395 .60837 m
.476 .60526 L
s
.61022 .52992 m
.59245 .52031 L
s
.68476 .48684 m
.67947 .4891 L
s
.69527 .4792 m
.68476 .48684 L
s
.5574 .55879 m
.54996 .56421 L
s
.54735 .56129 m
.54996 .56421 L
s
.50065 .58889 m
.49948 .59297 L
s
.67947 .4891 m
.67488 .48925 L
s
.48045 .60201 m
.48432 .6008 L
s
.62068 .52231 m
.60901 .50823 L
s
.476 .60526 m
.48045 .60201 L
s
.69527 .4792 m
.6786 .45747 L
s
.62667 .51795 m
.63116 .51468 L
s
.62285 .51913 m
.62667 .51795 L
s
.51582 .58106 m
.51106 .5813 L
s
.63116 .51468 m
.63333 .51149 L
s
.67488 .48925 m
.67178 .48831 L
s
.6182 .51931 m
.62285 .51913 L
s
.57231 .54792 m
.56825 .54606 L
s
.50273 .58576 m
.50065 .58889 L
s
.5471 .55825 m
.54735 .56129 L
s
.63333 .51149 m
.63469 .5073 L
s
.65065 .50049 m
.64614 .50377 L
s
.51106 .5813 m
.50719 .58251 L
s
.50719 .58251 m
.50273 .58576 L
s
.65284 .49729 m
.65065 .50049 L
s
.67178 .48831 m
.66787 .48634 L
s
.65815 .49502 m
.64676 .48069 L
s
.54834 .55411 m
.5471 .55825 L
s
.56825 .54606 m
.56503 .54517 L
s
.65422 .49307 m
.65284 .49729 L
s
.63469 .5073 m
.63372 .50317 L
s
.66787 .48634 m
.66385 .48122 L
s
.56503 .54517 m
.56031 .54538 L
s
.55046 .55094 m
.54834 .55411 L
s
.65329 .48891 m
.65422 .49307 L
s
.56031 .54538 m
.55645 .54658 L
s
.63372 .50317 m
.63208 .50114 L
s
.55645 .54658 m
.55046 .55094 L
s
.63208 .50114 m
.62809 .49919 L
s
.66385 .48122 m
.66293 .47703 L
s
.61286 .50705 m
.61153 .51127 L
s
.62809 .49919 m
.62341 .49935 L
s
.61504 .50383 m
.61286 .50705 L
s
.66293 .47703 m
.66283 .47386 L
s
.62341 .49935 m
.61956 .50053 L
s
.61956 .50053 m
.61504 .50383 L
s
.66283 .47386 m
.66423 .46958 L
s
.66423 .46958 m
.66797 .46522 L
s
.66797 .46522 m
.6786 .45747 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2;0?ooo`030000o`3oool0oooo00@0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`290?ooo`030000o`3oool0003o00D0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`260?ooo`80003o0P3oool00`000?l0oooo0?ooo`040?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0Q03oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo0880oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`200?ooo`030000o`3oool0
oooo00L0oooo00D0003o0?ooo`3oool0oooo0000000C0?ooo`<00000@@3oool00`000000oooo0?oo
o`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo07l0oooo00<0003o
0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool000000100oooo0`0000140?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0OP3oool0
0`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo000000`0oooo100000170?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0M`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`0000002@3oool3
000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`1g0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool01000
0?l0oooo0?ooo`0000060?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo07H0oooo00<0003o0?ooo`3oool00`3oool20000
o`H0oooo0P000?l30?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G
0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo07H0oooo0P000?l50?oo
o`030000o`3oool0oooo00<0003o1@3oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1f0?ooo`030000o`3oool0oooo00@0
oooo0P000?l60?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3oool02@3oool300000080oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000
001X0?ooo`030000003oool0oooo07<0oooo00<0003o0?ooo`000?l01`3oool3000000D0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<00000
0?ooo`3oool0J03oool30000o`P0oooo00<0003o0?ooo`3oool0103oool3000000P0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?oo
o`030000003oool0oooo06H0oooo00@0003o0?ooo`3oool0oooo0P000?l60?ooo`040000o`3oool0
oooo0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q
0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo06<0oooo0P000?l5
0?ooo`030000o`3oool0oooo0080oooo0P000?l0103oool0000000000000000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0640oooo00<0003o0?ooo`3oool01P3o
ool010000?l0oooo0?ooo`3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool0G`3oool20000o`L0oooo00<0003o0?ooo`0000000P00000D0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool0
103oool00`000000003o0000000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo05l0oooo00<0003o0?ooo`3oool00`0000000`000?l0oooo0?ooo`0H0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0GP3oool00`000?l00000000000020?ooo`030000o`3o
ool0oooo01T0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05D0oooo00@0003o0?ooo`3oool0oooo1000
00000`3oool0003o0000o`020000oa`0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05@0oooo0`000?l0
0`000000oooo0?ooo`040?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo
0540oooo0`0000000`000?l0oooo0000o`0U0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo04d0oooo00<0003o00000000
00000`3oool00`000?l0oooo0?ooo`020000ob<0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`190?ooo`<000000`000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
803oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003o
ool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<00000103o
ool01P000?l0oooo0000o`000?l0oooo0000obL0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0@@3oool3000000L0oooo00@0003o0?ooo`3oool0oooo0`000?lV0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000000/0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000003P3o
ool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000203oool3
0000o`L0oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool30000
00T0oooo0P000?l30?ooo`80003o1@3oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0]0?ooo`<000002`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00000=0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000003`3oool00`000?l0oooo0?oo
o`080?ooo`030000o`3oool0oooo02`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000B
0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0/0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`0L0?ooo`@000005@3oool010000?l0oooo0?ooo`000?l70?ooo`030000o`3o
ool0oooo02d0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool0
0`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000D0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`000?l0203oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`0D0?ooo`<00000603oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001`0
oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0<0?ooo`<00000803oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?ooo`80
003o<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000002<0oooo0P000?l50?ooo`<0003o
<`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0103oool3000002H0oooo00<0003o0?ooo`000?l0>P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool00`00000Y0?ooo`030000o`3oool0oooo03X0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`8000007`3oool60000o`H0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0M0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20000ocd0oooo0P00001K0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
703oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03h0oooo0`0000020?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`3oool0>@3o
ool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03L0oooo0`00000:0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0d0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<P3oool300000180
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01D0oooo0`000?l60?ooo`@0003o<P3oool3000001H0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01@0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030000
o`3oool0oooo02h0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0B0?ooo`80003o1@3o
ool00`000?l0oooo0?ooo`0a0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool04P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02d0oooo0`00000R0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l0:`3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02P0
oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0903oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00`0oooo00<0
003o0?ooo`3oool0103oool70000ob@0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0=
0?ooo`030000o`3oool0oooo02/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0>0?oo
o`030000o`3oool0oooo02L0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0?0?ooo`03
0000o`3oool0oooo02<0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo01h0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`000?l0703oool3000004L0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo00L0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`000?lH0?ooo`<00000BP3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0203oool20000o`@0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0B0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00@0003o0?ooo`3oool0003o5`3oool300000580oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`80003o503oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00@0
oooo00<0003o0?ooo`3oool05`3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`050?ooo`030000o`3oool0oooo01<0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`2?0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0?0?ooo`<00000HP3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0S@3oool20000o`030000003oool0003o0080003o1@3oool00`000?l0oooo0?oo
o`0;0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2;0?ooo`80003o0P3oool01@000000oooo0?ooo`3o
ool0003o00L0oooo00<0003o0?ooo`3oool01@3oool4000006X0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo08/0oooo00D0003o0?ooo`3oool0oooo000000030?ooo`030000o`3oool0oooo00@0oooo0P00
0?l40?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H
0?ooo`<000001@3oool00`000000oooo0?ooo`2;0?ooo`030000o`3oool0oooo0080oooo00D00000
0?ooo`3oool0oooo0000o`090?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0003o1`3o
ool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`270?ooo`030000o`3oool0oooo00H0oooo00<000000000o`000?l0103oool4
000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`250?ooo`80003o00<0oooo0000o`3oool0103oool30000o`<0oooo0`00001o0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P0000250?ooo`03
0000o`3oool0oooo00T0oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo0P0000250?ooo`030000o`3oool0oooo00@0oooo0P000?l20?ooo`<00000
QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08<0oooo00<0003o0?ooo`3oool00P3oool30000o`040?ooo`000000000000000080oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08<0oooo00<0003o0?ooo`3oool00P000?l4000000D0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08@0oooo00@0003o00000000000000000`3oool00`000?l0oooo0?oo
o`030?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1n0?ooo`040000o`3oool0oooo0?ooo`<00000103o
ool20000o`H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07d0oooo0P000?l3000000@0oooo0`000?l8
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0N03oool4000000@0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
MP3oool3000000T0oooo00<0003o0?ooo`3oool0303oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3o
ool3000000d0oooo0P000?l<0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000004P3oool0
0`000?l0oooo0?ooo`090?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000F0?ooo`030000o`3oool0oooo
00P0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo
0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<0
00000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?oo
o`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3o
ool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000
oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo
0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<0
00000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?oo
o`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0
;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3o
ool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo
0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00
001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?oo
o`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?oo
o`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0
:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3o
ool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00
002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo
0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?oo
o`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@
0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`03
0000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`00
4`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0
]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo
000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`800000
00<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00
000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<00000
0?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?oo
o`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`03
0000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00
<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0
oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003o
ool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0
oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?oo
o`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?oo
o`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000
J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0
oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000
H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool20000
05h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000
oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0
oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo
00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?oo
o`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?oo
o`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool00000
00<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo0000
00<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000
oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool30000
0080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo
00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?oo
o`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B
0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?oo
o`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00
KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003o
ool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool0
0`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo
1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00
000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n
0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a
0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?oo
o`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;
0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?oo
o`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D0
0000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03o
ool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3o
ool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2
000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo
0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo
00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?oo
o`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@0
0000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2
000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool00000
0180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140
oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo
0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0
oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo
00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00
000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V
0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<00000
0?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B
0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3o
ool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool40000
0<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@0
0000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3o
ool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0
oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000
003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?oo
o`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.67525 .4578 m
.66617 .46676 L
s
.67525 .4578 m
.65855 .43609 L
s
.66617 .46676 m
.66149 .46958 L
s
.66149 .46958 m
.6573 .47012 L
s
.6573 .47012 m
.6544 .46936 L
s
.57003 .56167 m
.57178 .55814 L
s
.56482 .56681 m
.57003 .56167 L
s
.56136 .56843 m
.56482 .56681 L
s
.57178 .55814 m
.5727 .55362 L
s
.55704 .56908 m
.56136 .56843 L
s
.6544 .46936 m
.6507 .46759 L
s
.5727 .55362 m
.5723 .55039 L
s
.55402 .56844 m
.55704 .56908 L
s
.45867 .6734 m
.45907 .67121 L
s
.45645 .67379 m
.45867 .6734 L
s
.48261 .64797 m
.46349 .62847 L
s
.64238 .47761 m
.63098 .46329 L
s
.63587 .48404 m
.63196 .4879 L
s
.63766 .48045 m
.63587 .48404 L
s
.45907 .67121 m
.45684 .67159 L
s
.45684 .67159 m
.45645 .67379 L
s
.6507 .46759 m
.64667 .46247 L
s
.5723 .55039 m
.57106 .54618 L
s
.61892 .50077 m
.6207 .49719 L
s
.615 .50463 m
.61892 .50077 L
s
.61157 .5062 m
.615 .50463 L
s
.63865 .47585 m
.63766 .48045 L
s
.60978 .50978 m
.59811 .4957 L
s
.60065 .51879 m
.58363 .50998 L
s
.6207 .49719 m
.62167 .4926 L
s
.5902 .5291 m
.57309 .52038 L
s
.5902 .5291 m
.58363 .50998 L
s
.6073 .50678 m
.61157 .5062 L
s
.57975 .53941 m
.57309 .52038 L
s
.4001 .72942 m
.38671 .71711 L
s
.63752 .4715 m
.63865 .47585 L
s
.62167 .4926 m
.62051 .48828 L
s
.57106 .54618 m
.56679 .54127 L
s
.54445 .57426 m
.53222 .56069 L
s
.5379 .58072 m
.53397 .58459 L
s
.53965 .57717 m
.5379 .58072 L
s
.52088 .59752 m
.52262 .59398 L
s
.51695 .6014 m
.52088 .59752 L
s
.51344 .60304 m
.51695 .6014 L
s
.54053 .57266 m
.53965 .57717 L
s
.5117 .60657 m
.4992 .59325 L
s
.50253 .61563 m
.48359 .59567 L
s
.64667 .46247 m
.64555 .45809 L
s
.52262 .59398 m
.52348 .58949 L
s
.49728 .6208 m
.49335 .62469 L
s
.49901 .61728 m
.49728 .6208 L
s
.49335 .62469 m
.48982 .62634 L
s
.50904 .60373 m
.51344 .60304 L
s
.49985 .6128 m
.49901 .61728 L
s
.62051 .48828 m
.61886 .48625 L
s
.46972 .648 m
.46578 .65189 L
s
.47144 .64448 m
.46972 .648 L
s
.53923 .56847 m
.54053 .57266 L
s
.46578 .65189 m
.46224 .65356 L
s
.48982 .62634 m
.4854 .62707 L
s
.45133 .66615 m
.43832 .6533 L
s
.52348 .58949 m
.52215 .58532 L
s
.47265 .63781 m
.47144 .64448 L
s
.46224 .65356 m
.45817 .6521 L
s
.43556 .68172 m
.43726 .67822 L
s
.43161 .68561 m
.43556 .68172 L
s
.42804 .68731 m
.43161 .68561 L
s
.64555 .45809 m
.64524 .45474 L
s
.61886 .48625 m
.61507 .48449 L
s
.56679 .54127 m
.56291 .53962 L
s
.41319 .70379 m
.41619 .699 L
s
.40924 .70769 m
.41319 .70379 L
s
.43726 .67822 m
.43803 .67381 L
s
.4854 .62707 m
.48137 .62556 L
s
.40434 .7107 m
.40924 .70769 L
s
.55367 .55422 m
.54711 .5607 L
s
.42353 .68811 m
.42804 .68731 L
s
.5445 .55777 m
.54711 .5607 L
s
.41619 .699 m
.41562 .69592 L
s
.40111 .71023 m
.40434 .7107 L
s
.64524 .45474 m
.64624 .45008 L
s
.52215 .58532 m
.52038 .5834 L
s
.43803 .67381 m
.43655 .66978 L
s
.45817 .6521 m
.44892 .64284 L
s
.61507 .48449 m
.61078 .48505 L
s
.41562 .69592 m
.41241 .69542 L
s
.56291 .53962 m
.55987 .53894 L
s
.48137 .62556 m
.47955 .62368 L
s
.60158 .49412 m
.60063 .49874 L
s
.64624 .45008 m
.64936 .44515 L
s
.52038 .5834 m
.51641 .58181 L
s
.54408 .55452 m
.5445 .55777 L
s
.64936 .44515 m
.65855 .43609 L
s
.61078 .48505 m
.60732 .48662 L
s
.41241 .69542 m
.40882 .69713 L
s
.55987 .53894 m
.55551 .53956 L
s
.43655 .66978 m
.43468 .66795 L
s
.47955 .62368 m
.47814 .61956 L
s
.60337 .49051 m
.60158 .49412 L
s
.54497 .54996 m
.54408 .55452 L
s
.60732 .48662 m
.60337 .49051 L
s
.40882 .69713 m
.40126 .70276 L
s
.51641 .58181 m
.51199 .58249 L
s
.43468 .66795 m
.43054 .66651 L
s
.55551 .53956 m
.55201 .54117 L
s
.50275 .5916 m
.5019 .59612 L
s
.40126 .70276 m
.39766 .70447 L
s
.54673 .54637 m
.54497 .54996 L
s
.48821 .60594 m
.49266 .60523 L
s
.47814 .61956 m
.47896 .61506 L
s
.55201 .54117 m
.54673 .54637 L
s
.39766 .70447 m
.39441 .70399 L
s
.51199 .58249 m
.50845 .58413 L
s
.50449 .58804 m
.50275 .5916 L
s
.48466 .60759 m
.48821 .60594 L
s
.50845 .58413 m
.50449 .58804 L
s
.43054 .66651 m
.42601 .66729 L
s
.47896 .61506 m
.48069 .61151 L
s
.39441 .70399 m
.39345 .7031 L
s
.41673 .67644 m
.41598 .68088 L
s
.48069 .61151 m
.48466 .60759 L
s
.4048 .68821 m
.40803 .68872 L
s
.39345 .7031 m
.39285 .69999 L
s
.42601 .66729 m
.42241 .66899 L
s
.41844 .67291 m
.41673 .67644 L
s
.37958 .71309 m
.38188 .71267 L
s
.38188 .71267 m
.38223 .71047 L
s
.39986 .69124 m
.4048 .68821 L
s
.42241 .66899 m
.41844 .67291 L
s
.39285 .69999 m
.39587 .69516 L
s
.38223 .71047 m
.37993 .71089 L
s
.37993 .71089 m
.37958 .71309 L
s
.39587 .69516 m
.39986 .69124 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo08/0oooo00<0003o0?ooo`3o
ool0303oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool00`000000oooo0?ooo`0J0?ooo`00
;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo08T0oooo00<0003o0?ooo`000?l0
3@3oool00`000000oooo0?ooo`0f0?ooo`<000006`3oool00`000000oooo0?ooo`0J0?ooo`00;@3o
ool200000580oooo00<000000?ooo`3oool0Q`3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo
00<000000?ooo`3oool0<`3oool3000001h0oooo00<000000?ooo`3oool06P3oool002d0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`250?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool02@3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo0?oo
o`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo08<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02d0oooo0`00000U
0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0PP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00P0oooo00<000000?oo
o`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`210?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00
;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0800oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000
003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0O`3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool08@3o
ool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F@3oool0
0`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01P3oool0
0`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`00
0000oooo0?ooo`1J0?ooo`030000003oool0oooo07L0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`80003o2P3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`00
0000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo07L0
oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00<0003o0?ooo`3oool02P3oool00`000000
oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo
00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`040?ooo`@0003o3@3oool00`000000oooo
0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<0
00000?ooo`3oool0MP3oool20000oaH0oooo00<000000?ooo`3oool04@3oool300000440oooo00<0
00000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1f
0?ooo`030000o`3oool0oooo01@0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<00000
0?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1e0?oo
o`80003o5@3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?oo
o`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3o
ool0503oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0780oooo00<0003o0?ooo`3oool0
5@3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06P0oooo10000?l50?ooo`030000o`3o
ool0oooo01D0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo
000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0I@3oool20000o`<0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0F0?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06<0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0I0?ooo`<00000F03oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0640oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0E0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3o
ool0G`3oool20000o`H0oooo00<0003o0?ooo`3oool04`3oool3000000D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0
H03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo0`0000080?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool03@3o
ool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1O0?ooo`040000o`3oool0
oooo0?ooo`80003o3@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<0
00000?ooo`3oool0G`3oool30000o``0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`1]0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`080?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?oo
o`1E0?ooo`<0003o3P3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0E@3oool00`000?l0oooo0000o`0:0?ooo`<000006`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo05@0oooo00<0003o0?ooo`3oool00P000?l50?ooo`<000007P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo
0740oooo00<000000?ooo`3oool0CP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0000000000000P00000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1=0?ooo`<0
003o0P3oool00`000?l0oooo0?ooo`03000002D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo04d0oooo
00L0003o0?ooo`000?l0003o000000000?l0000002P0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C03oool010000?l0
00000000000000020000obT0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`190?ooo`80
000000<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`150?ooo`<000000P3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0440oooo0`0000060?ooo`030000o`3oool0oooo02/0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<0000010000?l50?ooo`030000o`3oool0
oooo02/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo0`0000020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000000@0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0_0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0a0?ooo`<000001P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02h0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1n0?ooo`030000003oool0oooo02d0oooo0`0000080?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000000/0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000>0?oo
o`040000o`3oool0oooo0000o`H0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool08@3oool300000140oooo00<0003o0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0^0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000003`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
603oool3000001@0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0`0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`0D0?ooo`<00000603oool00`000?l0oooo0?ooo`070?ooo`80003o<`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000001`0oooo00<0003o0?ooo`3oool00P3oool4
0000ocD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000O0?ooo`80003o?03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0203oool300000280oooo00<0003o0?ooo`000?l0>`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0103oool3000002D0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<0
00000?ooo`3oool00`00000W0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008@3oool2
0000o`L0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0N0?ooo`80003o0P3oool30000
o`<0oooo00<0003o0?ooo`3oool0?03oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0?@3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01`0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0i0?ooo`@000001P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool06`3oool20000o`L0oooo00<0003o0?ooo`3oool0=P3oool3000000X0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo03<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0a0?oo
o`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`040?ooo`05
0000o`3oool0oooo0?ooo`000?l0<@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01P0
oooo00<0003o0?ooo`3oool0103oool30000obh0oooo1000000J0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0G0?ooo`<0003o1P3oool00`000?l0oooo0?ooo`0Z0?ooo`<000007P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool05P3oool010000?l0oooo0?ooo`000?l`0?ooo`<000008P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0503oool20000o`@0oooo00<0003o0?ooo`3oool0:P3oool3000002H0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<00000
0?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02H0oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo0P000?lS0?oo
o`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo0200oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0D0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool07@3oool3000003H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo01D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool03`3oool00`000?l0oooo0?ooo`040?ooo`@0003o6`3oool3
000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool07P3oool40000
0480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool06P3oool3000004L0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool05P3oool3000004X0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo0180oooo00<0003o0?ooo`3oool04`3oool3000004h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<00000
0?ooo`3oool04P3oool20000oa40oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo00T0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0000o`0<0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l0203oool30000
05/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0;0?ooo`80003o103oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0`00001N0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00d0oooo00@0003o0?ooo`3oool0003o1`3oool30000
0680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000?l0
oooo0?ooo`060?ooo`80003o1@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`060?ooo`030000o`3oool0oooo00P0oooo1000001Z0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo00<00000LP3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?oo
o`<0003o100000020?ooo`030000o`3oool0oooo07D0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0003o0000
o`<0000000<0oooo0000o`3oool01P3oool00`000?l0oooo0?ooo`1c0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000103oool00`000?l0
oooo0?ooo`040?ooo`80003oMP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`800000T03oool3000000L0oooo00<0003o0?ooo`3oool0O03oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`00
00020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0O@3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo10000005
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0O`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0P@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`04
0000003oool0oooo0?ooo`<0003oQ03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000;0?ooo`80003o0P3oool010000000
oooo0?ooo`000?n80?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0O03oool3000000`0oooo0P000?l30?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1h0?ooo`@000003@3oool20000o`D0oooo00<0003o0?ooo`3oool0R`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000@0?ooo`030000o`3oool0oooo00<0oooo0P000?l00`000000003o0?ooo`2<0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3
000001<0oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`03000000000?l0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`
0?ooo`<000005`3oool00`000?l0oooo0000o`040?ooo`030000o`3oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000J0?oo
o`80003o1@3oool00`000?l0oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool400000280oooo0P000?l00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo
00<000000?ooo`3oool0IP3oool3000001/0oooo0P000?l60?ooo`<0003o0P3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0I03oool3000001h0oooo0P000?l;0?ooo`030000003oool0oooo0940oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q
0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3000002L0oooo00<0003o0?oo
o`3oool01`3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000002/0oooo00<0003o0?ooo`3o
ool01P3oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0E`3oool300000300oooo0P000?l60?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3o
ool00`000000oooo0?ooo`1D0?ooo`<00000=@3oool00`000?l0oooo0?ooo`030?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000>@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0
oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00
001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3o
ool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0
oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`03
0000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603o
ool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<00000
0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P000004
0?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`80
0000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0
^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo
0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P00
00040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?oo
o`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<0
0000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool200000003
0?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?oo
o`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
04P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00
B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
04l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`00
0000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000
oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?oo
o`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?oo
o`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000
oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo
0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<0
00000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`38
0?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?oo
o`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@0
00006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03o
ool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2
000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo
0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?oo
o`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M
0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?
0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;
0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<00000
0?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?oo
o`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000
G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000
H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3o
ool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo
00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo
0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?oo
o`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3o
ool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000
T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3o
ool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`00
0000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0
oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo
00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300
oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo
0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?oo
o`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00
002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;
0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S
0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?oo
o`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000
bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`00
00060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O
0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?oo
o`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.64976 .44282 m
.64244 .45265 L
s
.64976 .44282 m
.63297 .4212 L
s
.64244 .45265 m
.63851 .45585 L
s
.63851 .45585 m
.63481 .45664 L
s
.63481 .45664 m
.63215 .45602 L
s
.63215 .45602 m
.62868 .45439 L
s
.62868 .45439 m
.62463 .44929 L
s
.6221 .4653 m
.61065 .45102 L
s
.61682 .47238 m
.61365 .47663 L
s
.61812 .46854 m
.61682 .47238 L
s
.61861 .46368 m
.61812 .46854 L
s
.61722 .45921 m
.61861 .46368 L
s
.62463 .44929 m
.62325 .44479 L
s
.60305 .49084 m
.60435 .48699 L
s
.59987 .49511 m
.60305 .49084 L
s
.60435 .48699 m
.60483 .48214 L
s
.59691 .49696 m
.59987 .49511 L
s
.59561 .50081 m
.58391 .48676 L
s
.60483 .48214 m
.60341 .47769 L
s
.59312 .49782 m
.59691 .49696 L
s
.62325 .44479 m
.62268 .44132 L
s
.58816 .5108 m
.57208 .50257 L
s
.56417 .55773 m
.56546 .5539 L
s
.55989 .56348 m
.56417 .55773 L
s
.62554 .43112 m
.63297 .4212 L
s
.62268 .44132 m
.62317 .43641 L
s
.56546 .5539 m
.5659 .54909 L
s
.60341 .47769 m
.60176 .47567 L
s
.55689 .56539 m
.55989 .56348 L
s
.62317 .43641 m
.62554 .43112 L
s
.57963 .52224 m
.56345 .5141 L
s
.57963 .52224 m
.57208 .50257 L
s
.5659 .54909 m
.56527 .54571 L
s
.55303 .56635 m
.55689 .56539 L
s
.60176 .47567 m
.5982 .47406 L
s
.56527 .54571 m
.56379 .54135 L
s
.57107 .53371 m
.56345 .5141 L
s
.55024 .56587 m
.55303 .56635 L
s
.5982 .47406 m
.59439 .47488 L
s
.56379 .54135 m
.55952 .53645 L
s
.59439 .47488 m
.59142 .47673 L
s
.58689 .48491 m
.58643 .48979 L
s
.59142 .47673 m
.5882 .48103 L
s
.5882 .48103 m
.58689 .48491 L
s
.54205 .57261 m
.52982 .55904 L
s
.55952 .53645 m
.55587 .53494 L
s
.53665 .57985 m
.53341 .5842 L
s
.53794 .57599 m
.53665 .57985 L
s
.53836 .57117 m
.53794 .57599 L
s
.54873 .55089 m
.54333 .55813 L
s
.53683 .56682 m
.53836 .57117 L
s
.55587 .53494 m
.55306 .53442 L
s
.54072 .5552 m
.54333 .55813 L
s
.52257 .59872 m
.52386 .59486 L
s
.51932 .60308 m
.52257 .59872 L
s
.52386 .59486 m
.52427 .59004 L
s
.51626 .60505 m
.51932 .60308 L
s
.55306 .53442 m
.54917 .53534 L
s
.49181 .65486 m
.47271 .63536 L
s
.51497 .60891 m
.50247 .59559 L
s
.52427 .59004 m
.52272 .58572 L
s
.51231 .60607 m
.51626 .60505 L
s
.54006 .5518 m
.54072 .5552 L
s
.50735 .61912 m
.48842 .59916 L
s
.54917 .53534 m
.54613 .53725 L
s
.54049 .54694 m
.54006 .5518 L
s
.50299 .62497 m
.49972 .62935 L
s
.50428 .6211 m
.50299 .62497 L
s
.52272 .58572 m
.52095 .5838 L
s
.50467 .6163 m
.50428 .6211 L
s
.49972 .62935 m
.49663 .63135 L
s
.54613 .53725 m
.54179 .54305 L
s
.47195 .68366 m
.47213 .68129 L
s
.46994 .68423 m
.47195 .68366 L
s
.54179 .54305 m
.54049 .54694 L
s
.47213 .68129 m
.47012 .68185 L
s
.52095 .5838 m
.5172 .58237 L
s
.47012 .68185 m
.46994 .68423 L
s
.49663 .63135 m
.49265 .63241 L
s
.49265 .63241 m
.48884 .63107 L
s
.5172 .58237 m
.51323 .58336 L
s
.48001 .65577 m
.47672 .66018 L
s
.4813 .6519 m
.48001 .65577 L
s
.48187 .64471 m
.4813 .6519 L
s
.47672 .66018 m
.47361 .66221 L
s
.47361 .66221 m
.46976 .66092 L
s
.51323 .58336 m
.51015 .58533 L
s
.48884 .63107 m
.48702 .6292 L
s
.50557 .59361 m
.50517 .59846 L
s
.46462 .67641 m
.45162 .66354 L
s
.51015 .58533 m
.50686 .58972 L
s
.50686 .58972 m
.50557 .59361 L
s
.49349 .60976 m
.49749 .60873 L
s
.48702 .6292 m
.4854 .6249 L
s
.46976 .66092 m
.46052 .65166 L
s
.45137 .69417 m
.45265 .6903 L
s
.44805 .69862 m
.45137 .69417 L
s
.49038 .61175 m
.49349 .60976 L
s
.45265 .6903 m
.453 .68552 L
s
.4854 .6249 m
.48578 .62007 L
s
.4449 .70069 m
.44805 .69862 L
s
.42246 .74797 m
.40909 .73566 L
s
.48707 .61617 m
.49038 .61175 L
s
.453 .68552 m
.45132 .6813 L
s
.48578 .62007 m
.48707 .61617 L
s
.4408 .70186 m
.4449 .70069 L
s
.43251 .71944 m
.43491 .71407 L
s
.42918 .72391 m
.43251 .71944 L
s
.43491 .71407 m
.43413 .71079 L
s
.45132 .6813 m
.44945 .67947 L
s
.42489 .7275 m
.42918 .72391 L
s
.43413 .71079 m
.43113 .71049 L
s
.44945 .67947 m
.44553 .67821 L
s
.42187 .72722 m
.42489 .7275 L
s
.43113 .71049 m
.42795 .71258 L
s
.44553 .67821 m
.44142 .67936 L
s
.42795 .71258 m
.42141 .71916 L
s
.42141 .71916 m
.41822 .72127 L
s
.44142 .67936 m
.43824 .68143 L
s
.4336 .68981 m
.43326 .69462 L
s
.41822 .72127 m
.41518 .72098 L
s
.43824 .68143 m
.43489 .68591 L
s
.43489 .68591 m
.4336 .68981 L
s
.42352 .70328 m
.42655 .70359 L
s
.41518 .72098 m
.41422 .72008 L
s
.4192 .70687 m
.42352 .70328 L
s
.41422 .72008 m
.41342 .71678 L
s
.41583 .71137 m
.4192 .70687 L
s
.41342 .71678 m
.41583 .71137 L
s
.40216 .73183 m
.40426 .73122 L
s
.40426 .73122 m
.40442 .72882 L
s
.40442 .72882 m
.40232 .72943 L
s
.40232 .72943 m
.40216 .73183 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
08P0oooo00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`1<0?ooo`<00000103oool00`00
0000oooo0?ooo`0K0?ooo`00;`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo08H0
oooo00<0003o0?ooo`000?l05P3oool00`000000oooo0?ooo`190?ooo`<000001`3oool00`000000
oooo0?ooo`0K0?ooo`00;P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo08@0oooo
00@0003o0?ooo`3oool0003o5P3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000
oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo08<0oooo
00D0003o0?ooo`3oool0oooo0000o`0E0?ooo`030000003oool0oooo04<0oooo0`00000>0?ooo`03
0000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
P@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0
@03oool300000140oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`1o0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04@3o
ool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?ooo`00;P3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo03T0oooo1000000G0?ooo`030000003oool0
oooo01X0oooo000^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0O@3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool0=P3oool30000
01/0oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000003oool0oooo07`0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo03<0
oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0N`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo
00<000000?ooo`3oool0<03oool300000240oooo00<000000?ooo`3oool06P3oool002d0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool04@3oool00`000000oooo0?ooo`0]0?ooo`<000009@3oool00`000000oooo0?oo
o`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo07D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0140oooo00<00000
0?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`1e0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool0
0`000?l0oooo0?ooo`0B0?ooo`030000003oool0oooo02L0oooo0`00000[0?ooo`030000003oool0
oooo01T0oooo000]0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0M03oool00`00
0?l0oooo0?ooo`020?ooo`D0003o5@3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`00
0000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo07@0
oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000
oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo07<0oooo
0P000?lL0?ooo`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo
000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0L`3oool00`000?l0oooo0?oo
o`0K0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/
0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0L@3oool00`000?l0oooo0000o`0L
0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?oo
o`800000G@3oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo01`0oooo00<000000?oo
o`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`03
0000003oool0oooo06l0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`0A0?ooo`<0
0000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo06H0oooo0`000?l40?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0
3P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1S0?ooo`80003o0`3oool01@000?l0oooo0?ooo`3oool0003o01l0oooo
00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo0600oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo00@0oooo0`00001>
0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0G`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0240oooo00@000000?oo
o`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06@0oooo00<000000?ooo`3oool0G@3oool20000o`D0oooo00<0003o0?ooo`3oool08@3oool40000
05D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`1M0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool07`3oool3000005P0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo
0?ooo`1M0?ooo`050000o`3oool0oooo0?ooo`000?l07`3oool300000080oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000
003oool0oooo05`0oooo00<0003o0?ooo`000?l00P000?lL0?ooo`<000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?oo
o`1M0?ooo`030000o`3oool0oooo01X0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1M
0?ooo`030000o`3oool0oooo01H0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0D`3oool00`000?l0oooo0?ooo`0L0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`1B0?ooo`<0003o6@3oool300000140oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0DP3oool010000?l0oooo0000o`000?lD
0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1A
0?ooo`040000o`3oool0oooo0?ooo`80003o3`3oool3000001P0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00h0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0B`3oool3
0000o`80oooo00<0003o0?ooo`3oool02`3oool3000001h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
04/0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l80?ooo`@000008@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<00000
0?ooo`3oool0BP3oool010000?l0oooo0?ooo`3oool20000o`D0oooo0`00000U0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool0
0`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo00@0oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04T0oooo00@0003o0?ooo`3oool0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?oo
o`3oool0B@3oool00`000?l000000000000^0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo0440oooo00@0003o0?ooo`3oool0oooo0`0000000`000?l0oooo0?ooo`0^0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03h0oooo0P000?l0103oool0
003o0000o`000?ld0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?03oool010000?l0
00000000000000020?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0
oooo0P0000000`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000
003oool0oooo03D0oooo0`0000000`3oool0003o0?ooo`060?ooo`030000o`3oool0oooo0340oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo0340oooo0`0000030?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3000000H0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?oo
o`<000002@3oool010000?l0oooo0?ooo`000?l60?ooo`030000o`3oool0oooo0300oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?oo
o`3oool09@3oool3000000`0oooo00<0003o0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0`0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000403oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000>0?ooo`030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000001<0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`0c0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0D0?ooo`<000005`3oool20000o`@0oooo10000?lf0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`0@0?ooo`<000006`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0<0?ooo`<000007`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`080?ooo`<000008@3oool00`000?l0oooo0000o`0l0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000903oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03
000002L0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000S0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0O0?ooo`<0003o00<0oooo0000o`3o
ool00`3oool00`000?l0oooo0?ooo`0l0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0m0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03T0oooo100000060?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=P3oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0oooo0P000?l60?ooo`030000o`3oool0oooo
03<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0<03oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01L0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02h0oooo
0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00@0oooo00D0
003o0?ooo`3oool0oooo0000o`0/0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06@3o
ool00`000?l0oooo0?ooo`040?ooo`<0003o:P3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo01X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0V0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0603oool20000o`030?ooo`000?l0oooo02X0oooo0`00000V0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`03
0000003oool0oooo01L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0U0?ooo`<0
0000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0200oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0G0?ooo`030000o`3o
ool0oooo00@0oooo0P000?lN0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01X0oooo0`00000f0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0603oool30000
03X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0F0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool05`3oool20000o`<0oooo
00<0003o0?ooo`3oool04P3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01T0oooo0`00
0?lB0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`0F
0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`0B0?oo
o`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<0
0000SP3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo00h0oooo0`00001B0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000
003oool0oooo01D0oooo00<0003o0?ooo`3oool02@3oool4000005H0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01H0oooo00<0003o0?ooo`3oool01@3oool3000005/0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0E0?ooo`030000o`3oool0003o00<0oooo0`00001N0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?
0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`030?ooo`<0000000<0oooo0000o`3oool0H`3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00l0oooo00<0003o0?ooo`0000000`0000000`000?l0
oooo0?ooo`1W0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo
0`0000030?ooo`030000o`3oool0oooo06T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0;0?ooo`<000000`3oool30000of`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000000`3oool00`000?l0oooo0?ooo`1d0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0T03oool010000000oooo0?ooo`3oool3000000P0oooo0P000?me0?ooo`030000003oool0oooo
04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@000003@3oool00`000?l0
oooo0?ooo`1c0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<000004@3oool00`000?l0oooo0?ooo`1b0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<0
00000?ooo`3oool01P3oool30000og`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`05
0?ooo`040000o`3oool0oooo0?ooo`80003o1P3oool20000og<0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool0
0`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool2
0000og@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo00@0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1k0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo
00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo07/0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1h0?ooo`@00000503oool00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0O@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo00X0oooo00<0003o
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo00T0oooo0P000?n20?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0L03oool3000001h0oooo00D000000?ooo`3oool0oooo0000o`050?ooo`80003oQ@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240
oooo00H000000?ooo`3oool0003o0?ooo`000?n;0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?oo
o`000?l0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`03
0000003oool0oooo06H0oooo0`00000X0?ooo`03000000000?l0oooo00@0oooo0P000?n:0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000?l0oooo08X0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0
R`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05h0oooo0`00000a0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0
R`3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05X0oooo1000000d0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`2=0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3
000003P0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`2>0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool30000
03/0oooo00<000000?ooo`3oool00`000?nB0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003X0oooo0P000?l20?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000?@3oool20000o`80oooo00<000000?ooo`3oool0
UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04/0oooo0`0000130?ooo`030000o`3oool0000009T0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000170?ooo`030000o`000000
oooo09T0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`150?ooo`<00000B`3oool00`000?l0oooo0?ooo`2I0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0
oooo00<000000000o`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0003o09/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0l0?ooo`<00000E@3oool010000000oooo0?ooo`000?nJ0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<0
00000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?oo
o`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3o
ool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool30000
06d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I
0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?oo
o`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3o
ool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo
00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000
oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2
000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003o
ool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00
00250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3o
ool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool0
02d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo
0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d
0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k
0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`03
0000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00
@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<00000
0?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`800000
00<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000
003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`00
0000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0
d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3o
ool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2
000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000
oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo
0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000
003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0
oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R
0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`80
0000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3o
ool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3o
ool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool20000
04<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?oo
o`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f
0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?oo
o`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00
M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3o
ool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0
000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool20000
03@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo0000
00h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0
oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool40000
04L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0
oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<0
00000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<0
00000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<00000
0?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?oo
o`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@0
0000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0
I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3o
ool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool0
08l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900
oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo
0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<0
00000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?oo
o`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?oo
o`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@0
0000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000
Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03o
ool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool0
0`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`00
0000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0
oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo
01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<0
00000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=
0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool0
0:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool40000
0=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.62008 .43465 m
.61474 .44489 L
s
.62008 .43465 m
.60312 .41318 L
s
.61474 .44489 m
.61164 .44828 L
s
.61164 .44828 m
.6085 .44921 L
s
.6085 .44921 m
.60611 .44867 L
s
.60611 .44867 m
.6029 .44711 L
s
.6029 .44711 m
.59882 .44204 L
s
.59831 .45847 m
.58678 .44427 L
s
.59444 .46588 m
.59211 .47033 L
s
.59517 .46191 m
.59444 .46588 L
s
.59508 .45693 m
.59517 .46191 L
s
.59882 .44204 m
.59714 .43751 L
s
.59339 .45241 m
.59508 .45693 L
s
.59769 .42351 m
.60312 .41318 L
s
.59714 .43751 m
.59627 .43398 L
s
.59627 .43398 m
.59618 .42897 L
s
.59618 .42897 m
.59769 .42351 L
s
.58432 .48523 m
.58505 .48125 L
s
.58198 .48972 m
.58432 .48523 L
s
.58505 .48125 m
.58496 .47626 L
s
.58496 .47626 m
.58325 .47176 L
s
.57958 .49172 m
.58198 .48972 L
s
.57885 .49571 m
.56708 .48171 L
s
.57634 .49273 m
.57958 .49172 L
s
.58325 .47176 m
.58158 .46975 L
s
.58158 .46975 m
.57829 .46822 L
s
.57335 .50622 m
.55834 .49834 L
s
.57829 .46822 m
.57504 .46919 L
s
.56705 .51828 m
.55195 .5105 L
s
.56705 .51828 m
.55834 .49834 L
s
.55715 .55541 m
.55789 .5514 L
s
.55398 .56151 m
.55715 .55541 L
s
.55789 .5514 m
.55777 .54643 L
s
.57504 .46919 m
.57262 .47118 L
s
.55777 .54643 m
.55686 .54297 L
s
.56072 .53039 m
.55195 .5105 L
s
.55153 .5636 m
.55398 .56151 L
s
.57262 .47118 m
.57025 .47569 L
s
.56951 .47971 m
.56962 .48473 L
s
.55686 .54297 m
.5551 .53853 L
s
.57025 .47569 m
.56951 .47971 L
s
.54822 .56473 m
.55153 .5636 L
s
.5551 .53853 m
.55082 .53364 L
s
.5457 .56434 m
.54822 .56473 L
s
.55082 .53364 m
.54744 .53222 L
s
.54744 .53222 m
.54491 .53178 L
s
.53916 .57163 m
.52693 .55807 L
s
.54281 .54893 m
.53878 .55661 L
s
.53514 .57933 m
.53272 .58396 L
s
.53588 .57529 m
.53514 .57933 L
s
.53575 .57028 m
.53588 .57529 L
s
.54491 .53178 m
.54156 .53287 L
s
.53617 .55369 m
.53878 .55661 L
s
.53394 .56584 m
.53575 .57028 L
s
.54156 .53287 m
.53908 .53496 L
s
.53524 .5502 m
.53617 .55369 L
s
.53908 .53496 m
.53585 .5411 L
s
.53511 .54516 m
.53524 .5502 L
s
.52463 .59944 m
.52537 .59539 L
s
.52219 .60411 m
.52463 .59944 L
s
.52537 .59539 m
.52523 .59038 L
s
.53585 .5411 m
.53511 .54516 L
s
.52523 .59038 m
.5234 .58596 L
s
.51968 .60627 m
.52219 .60411 L
s
.51894 .61033 m
.50645 .597 L
s
.51628 .60749 m
.51968 .60627 L
s
.5234 .58596 m
.52164 .58404 L
s
.52164 .58404 m
.51816 .5827 L
s
.51322 .62126 m
.49432 .60127 L
s
.50995 .62752 m
.50749 .63223 L
s
.5107 .62345 m
.50995 .62752 L
s
.51055 .61843 m
.5107 .62345 L
s
.50309 .65916 m
.48404 .63962 L
s
.51816 .5827 m
.51475 .58389 L
s
.50749 .63223 m
.50496 .63443 L
s
.50496 .63443 m
.50151 .63571 L
s
.51475 .58389 m
.51221 .58605 L
s
.51221 .58605 m
.50975 .59074 L
s
.509 .59483 m
.50915 .59987 L
s
.50151 .63571 m
.49798 .63447 L
s
.50975 .59074 m
.509 .59483 L
s
.48832 .69015 m
.48824 .68765 L
s
.48659 .69084 m
.48832 .69015 L
s
.48824 .68765 m
.48651 .68834 L
s
.49992 .61209 m
.50338 .61085 L
s
.48651 .68834 m
.48659 .69084 L
s
.49266 .66061 m
.49017 .66537 L
s
.49341 .65652 m
.49266 .66061 L
s
.49317 .64898 m
.49341 .65652 L
s
.49798 .63447 m
.49617 .63259 L
s
.49017 .66537 m
.4876 .66762 L
s
.49617 .63259 m
.49428 .62818 L
s
.49736 .61429 m
.49992 .61209 L
s
.4876 .66762 m
.48403 .66645 L
s
.49487 .61902 m
.49736 .61429 L
s
.49428 .62818 m
.49412 .62313 L
s
.49412 .62313 m
.49487 .61902 L
s
.48102 .68287 m
.46807 .66998 L
s
.48403 .66645 m
.47481 .65716 L
s
.47098 .70209 m
.47173 .69797 L
s
.46846 .70691 m
.47098 .70209 L
s
.47173 .69797 m
.47156 .69294 L
s
.47156 .69294 m
.46962 .6886 L
s
.46584 .70923 m
.46846 .70691 L
s
.46229 .71065 m
.46584 .70923 L
s
.46962 .6886 m
.46776 .68676 L
s
.46776 .68676 m
.46411 .68562 L
s
.45824 .72376 m
.45721 .72035 L
s
.45664 .72952 m
.45824 .72376 L
s
.45051 .76008 m
.43721 .74772 L
s
.4541 .73438 m
.45664 .72952 L
s
.45721 .72035 m
.45449 .72017 L
s
.45061 .73837 m
.4541 .73438 L
s
.46411 .68562 m
.46054 .687 L
s
.45449 .72017 m
.45184 .72251 L
s
.44786 .73822 m
.45061 .73837 L
s
.46054 .687 m
.45791 .68931 L
s
.45184 .72251 m
.44663 .72975 L
s
.45791 .68931 m
.45535 .69416 L
s
.4546 .69832 m
.45478 .70338 L
s
.45535 .69416 m
.4546 .69832 L
s
.44663 .72975 m
.44397 .73211 L
s
.44691 .71293 m
.44967 .71312 L
s
.44397 .73211 m
.44121 .73195 L
s
.44339 .71691 m
.44691 .71293 L
s
.44121 .73195 m
.44025 .73105 L
s
.44082 .7218 m
.44339 .71691 L
s
.44025 .73105 m
.4392 .72761 L
s
.4392 .72761 m
.44082 .7218 L
s
.43058 .74401 m
.4324 .74326 L
s
.4324 .74326 m
.4323 .74072 L
s
.4323 .74072 m
.43047 .74147 L
s
.43047 .74147 m
.43058 .74401 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`200?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0L0?ooo`00;`3oool2000004H0oooo00<000000?ooo`3oool0OP3oool00`000?l0oooo0000
o`0Q0?ooo`030000003oool0oooo0580oooo0P00000M0?ooo`00;P3oool2000004P0oooo00<00000
0?ooo`3oool0O@3oool00`000?l0oooo0000o`0Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
07/0oooo00D0003o0?ooo`3oool0oooo0000o`0P0?ooo`030000003oool0oooo04`0oooo0`000004
0?ooo`030000003oool0oooo01/0oooo000_0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0NP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01d0oooo00<000000?oo
o`3oool0B@3oool3000000L0oooo00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1h0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0703oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo0?ooo`0J0?ooo`00
;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo07L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo04<0oooo0`00000>0?ooo`030000
003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0MP3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0@03o
ool300000140oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`1e0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool06P3oool0
0`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0K0?ooo`030000003oool0oooo03T0oooo1000000G0?ooo`030000003oool0oooo
01X0oooo000^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0M03oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0=P3oool3000001/0
oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000003oool0oooo07<0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo03<0oooo
0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool0KP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0703oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool00`000000oooo0?oo
o`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo06h0oooo00<0003o
0?ooo`3oool00P3oool20000o`030?ooo`000?l0oooo01h0oooo00<000000?ooo`3oool0;@3oool3
000002D0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`1^0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool07P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo06d0oooo00<0003o0?ooo`3oool0903oool00`000000
oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo06d0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo
0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo06`0oooo0P000?lT0?ooo`030000003oool0oooo0240oooo0`00
000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo01h0oooo0`00000d
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?oo
o`3oool0JP3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo01X0oooo0`00000g0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3o
ool0J@3oool00`000?l0oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`03
0000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1P0?ooo`@0003o
0`3oool00`000?l0oooo0?ooo`0U0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`1N0?ooo`050000o`3o
ool0oooo0?ooo`000?l0:`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo
0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05d0oooo00D0
003o0?ooo`3oool0oooo0000o`0[0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000
003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0F`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02P0oooo00<000000?ooo`3oool02P3o
ool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool0
0`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:03oool0
0`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo05P0oooo0P000?l50?ooo`030000o`3oool0oooo
02P0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0:03oool010000000oooo0?ooo`3oool300000580oooo00<000000?oo
o`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1H0?ooo`05
0000o`3oool0oooo0?ooo`000?l0:`3oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1H0?ooo`040000o`3oool0003o0000
obT0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`0V0?ooo`<000000P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo
00<000000?ooo`3oool0F03oool00`000?l0oooo0?ooo`0R0?ooo`<000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?oo
o`1@0?ooo`030000o`3oool0oooo02L0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1?
0?ooo`<0003o903oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1?0?oo
o`040000o`3oool0003o0000oal0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[
0?ooo`030000003oool0oooo04h0oooo00@0003o0?ooo`3oool0oooo0P000?lJ0?ooo`<000004@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1:0?ooo`050000o`3o
ool0oooo0?ooo`000?l06`3oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0B@3oool30000o`030?ooo`000?l0oooo01L0oooo0`00000H0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`000?l0
0P000?lD0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04P0oooo00D0
003o0?ooo`3oool0oooo0000o`0A0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0A`3o
ool00`000?l0oooo0?ooo`0?0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0A`3oool0
0`000?l0oooo0?ooo`0;0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0AP3oool00`00
0?l0oooo0?ooo`080?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`160?ooo`030000o`3oool0oooo00@0
oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo
0?ooo`030?ooo`040000o`3oool0oooo0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0m0?ooo`040000o`3oool0003o0000o`@0oooo0`00000a0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`000000
8@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03/0oooo00<0003o0?ooo`3oool0
0P3oool010000?l0000000000000000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
>@3oool010000?l0oooo0?ooo`3oool3000000030000o`3oool0oooo03@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo03P0oooo00@0003o00000000000000000`3oool00`000?l0oooo0?ooo`0d0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0
O03oool00`000000oooo0?ooo`0e0?ooo`03000000000?l0000000L0oooo00<0003o0?ooo`3oool0
<`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`3oool0<@3oool3000000030?ooo`000?l0oooo00L0oooo00<0
003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3000000@0oooo00@0003o
0?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y
0?ooo`<000001`3oool010000?l0oooo0?ooo`000?l50?ooo`030000o`3oool0oooo03<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<00000
0?ooo`3oool09@3oool3000000/0oooo0P000?l60?ooo`030000o`3oool0oooo03<0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0240oooo0`00000:0?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@0
00003P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo01P0oooo0`00000C0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
=P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0503oool3000001L0oooo00@0003o0?ooo`3oool0oooo
0`000?li0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000006P3oool20000och0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000N0?ooo`80003o?@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool300000240oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool3000002@0oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000V0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0000o`04
0?ooo`030000o`3oool0oooo03`0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0803oool01@000?l0oooo0?ooo`3oool0
003o03l0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0>03oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01l0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0e0?ooo`<000002P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0380oooo
0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0N0?ooo`80003o103oool00`000?l0oooo0?oo
o`0`0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;@3oool3000001H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0
003o02/0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`3oool0003o:@3oool3000001h0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
01`0oooo00<0003o0?ooo`3oool00P3oool20000obL0oooo0`00000R0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0K0?ooo`<0003o103oool00`000?l0oooo0?ooo`0R0?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo
0?ooo`0J0?ooo`040000o`3oool0oooo0000obH0oooo0`00000Z0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0I0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool07`3oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0K0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`03
0?ooo`80003o6@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01X0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0E0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool06P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0180oooo0`00000n0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
3`3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01/0oooo00D0003o0?ooo`3oool0oooo
0000o`0>0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0703oool30000o``0oooo0`00
001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo00`0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo01L0oooo00<0003o0?ooo`3o
ool01`3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`00
8@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool0
0`3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0I0?ooo`80003o0`00
001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00
001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`000002
0?ooo`80003oHP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo100000050?oo
o`030000o`3oool0003o0680oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000000<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?mR0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000000H0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
2P3oool01@000?l0oooo0?ooo`3oool0003o06L0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo
1000000>0?ooo`<0003oJ@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000<0?ooo`030000
o`3oool0oooo0700oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool200000940oooo1000000@0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000D0?ooo`030000o`3oool0
oooo06l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
06l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000
oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo06l0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo
0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo06l0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`220?ooo`<00000303oool00`000000oooo0?ooo`0>0?ooo`<0003oM`3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?
0?ooo`030000003oool0oooo00d0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`80003oL03o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07`0oooo0`00000A0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`030?ooo`80003oL03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
00d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1e0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo07H0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0N03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo00`0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1i0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo07T0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`0B0?oo
o`030000o`3oool0oooo07X0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?oo
o`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`0?0?ooo`<0
003oOP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo00T0oooo0`000?n50?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3o
ool3000002h0oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`270?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0203oool00`000?l0oooo0?ooo`270?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`80003oQ@3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0
oooo0`00000h0?ooo`030000003oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`020?oo
o`030000o`3oool0oooo08<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?oo
o`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`070?ooo`04
0000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo00L0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`260?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
CP3oool400000440oooo00<000000?ooo`3oool01`3oool20000o`<0oooo00<0003o0?ooo`3oool0
Q`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3oool0R03o
ool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3
000004P0oooo00<000000?ooo`3oool02P3oool20000oh`0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`00
0000oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0R`3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480
oooo0`00001>0?ooo`030000003oool0oooo00<0oooo0P000?nE0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`2E0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<0
00000?ooo`3oool01P3oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<00000
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo02l0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?oo
o`3oool0203oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3o
ool02@3oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`2B0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`2A0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0
oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00
002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00
001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0
oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo
0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0013
0?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00
B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;
0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003o
ool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo
0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?oo
o`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003o
ool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0
f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`00
0000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0
oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo
1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000
000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?oo
o`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`80
0000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0
oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo
0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0
oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0
oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0
oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo
0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M
0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q
0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?oo
o`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3
000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo
0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A
0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?oo
o`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000
003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303o
ool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03o
ool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2
000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo
0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool50000
0;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0
oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0
oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo
0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:
0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo0000
00H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo
0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.58753 .43338 m
.58431 .4436 L
s
.58753 .43338 m
.57037 .41212 L
s
.58431 .4436 m
.58211 .447 L
s
.58211 .447 m
.57955 .44795 L
s
.57955 .44795 m
.57745 .44742 L
s
.57745 .44742 m
.57452 .44589 L
s
.57452 .44589 m
.5704 .44086 L
s
.57207 .45724 m
.56042 .44315 L
s
.56707 .42241 m
.57037 .41212 L
s
.5704 .44086 m
.56839 .43635 L
s
.56983 .46069 m
.56971 .46466 L
s
.56911 .45572 m
.56983 .46069 L
s
.56971 .46466 m
.5683 .46913 L
s
.5671 .45123 m
.56911 .45572 L
s
.56839 .43635 m
.5672 .43285 L
s
.56648 .42786 m
.56707 .42241 L
s
.5672 .43285 m
.56648 .42786 L
s
.56368 .48009 m
.56296 .4751 L
s
.56356 .48408 m
.56368 .48009 L
s
.56214 .48858 m
.56356 .48408 L
s
.56296 .4751 m
.56092 .47062 L
s
.56034 .49061 m
.56214 .48858 L
s
.56092 .47062 m
.55925 .46862 L
s
.55771 .49164 m
.56034 .49061 L
s
.56023 .49461 m
.54839 .48069 L
s
.55925 .46862 m
.55624 .46711 L
s
.55624 .46711 m
.55359 .46811 L
s
.55688 .50519 m
.54302 .49742 L
s
.55359 .46811 m
.55178 .47011 L
s
.55302 .51735 m
.5391 .50967 L
s
.55302 .51735 m
.54302 .49742 L
s
.55178 .47011 m
.55033 .47464 L
s
.55021 .47867 m
.55094 .48369 L
s
.55033 .47464 m
.55021 .47867 L
s
.54915 .52957 m
.5391 .50967 L
s
.54941 .55075 m
.54868 .54574 L
s
.54929 .55479 m
.54941 .55075 L
s
.54735 .56097 m
.54929 .55479 L
s
.54868 .54574 m
.54746 .54227 L
s
.54746 .54227 m
.54538 .53782 L
s
.54552 .56311 m
.54735 .56097 L
s
.54538 .53782 m
.54108 .53294 L
s
.54282 .56429 m
.54552 .56311 L
s
.54061 .56393 m
.54282 .56429 L
s
.54108 .53294 m
.538 .53155 L
s
.538 .53155 m
.53577 .53113 L
s
.53577 .53113 m
.53304 .53226 L
s
.53615 .54842 m
.53367 .5562 L
s
.53592 .57136 m
.52367 .55781 L
s
.53106 .55329 m
.53367 .5562 L
s
.53304 .53226 m
.53117 .53438 L
s
.53356 .57509 m
.53344 .57918 L
s
.53281 .57004 m
.53356 .57509 L
s
.53344 .57918 m
.53195 .58389 L
s
.53069 .56558 m
.53281 .57004 L
s
.53117 .53438 m
.52918 .54061 L
s
.52981 .54978 m
.53106 .55329 L
s
.52906 .5447 m
.52981 .54978 L
s
.52918 .54061 m
.52906 .5447 L
s
.52707 .59555 m
.52632 .59048 L
s
.52695 .59966 m
.52707 .59555 L
s
.52544 .60442 m
.52695 .59966 L
s
.52632 .59048 m
.52418 .58603 L
s
.52356 .60664 m
.52544 .60442 L
s
.52418 .58603 m
.52241 .58411 L
s
.52078 .60793 m
.52356 .60664 L
s
.52343 .61077 m
.51097 .59742 L
s
.52241 .58411 m
.51925 .5828 L
s
.51925 .5828 m
.51646 .58404 L
s
.5199 .62193 m
.50103 .60191 L
s
.51799 .62419 m
.51787 .62834 L
s
.51723 .6191 m
.51799 .62419 L
s
.51787 .62834 m
.51634 .63315 L
s
.51646 .58404 m
.51455 .58626 L
s
.51634 .63315 m
.51443 .63543 L
s
.51455 .58626 m
.51301 .59103 L
s
.51597 .66063 m
.49699 .64102 L
s
.51289 .59519 m
.51366 .6003 L
s
.51443 .63543 m
.51161 .63678 L
s
.51301 .59103 m
.51289 .59519 L
s
.51161 .63678 m
.5084 .63558 L
s
.50724 .61281 m
.51007 .61151 L
s
.5084 .63558 m
.5066 .63369 L
s
.50531 .61508 m
.50724 .61281 L
s
.50725 .65809 m
.50712 .66227 L
s
.50608 .65042 m
.50725 .65809 L
s
.5066 .63369 m
.5044 .62924 L
s
.50712 .66227 m
.50557 .66716 L
s
.50712 .69249 m
.50673 .68994 L
s
.5057 .69322 m
.50712 .69249 L
s
.50375 .61992 m
.50531 .61508 L
s
.50673 .68994 m
.50531 .69067 L
s
.50557 .66716 m
.50363 .6695 L
s
.5044 .62924 m
.50363 .6241 L
s
.50531 .69067 m
.5057 .69322 L
s
.50363 .6241 m
.50375 .61992 L
s
.50363 .6695 m
.50038 .66836 L
s
.50038 .66836 m
.49122 .65903 L
s
.49986 .68518 m
.48699 .67222 L
s
.49371 .70078 m
.49292 .69564 L
s
.49358 .70501 m
.49371 .70078 L
s
.492 .70999 m
.49358 .70501 L
s
.49292 .69564 m
.49069 .69122 L
s
.49002 .71241 m
.492 .70999 L
s
.49069 .69122 m
.48884 .68938 L
s
.48711 .71393 m
.49002 .71241 L
s
.48884 .68938 m
.48553 .68827 L
s
.48553 .68827 m
.4826 .68975 L
s
.48525 .72746 m
.48392 .72398 L
s
.48459 .7334 m
.48525 .72746 L
s
.48299 .73845 m
.48459 .7334 L
s
.48392 .72398 m
.48152 .72384 L
s
.4826 .68975 m
.4806 .69216 L
s
.48045 .74261 m
.48299 .73845 L
s
.48311 .76495 m
.46994 .7525 L
s
.48152 .72384 m
.47952 .7263 L
s
.4806 .69216 m
.47899 .69717 L
s
.47886 .70144 m
.47966 .70663 L
s
.47804 .74251 m
.48045 .74261 L
s
.47899 .69717 m
.47886 .70144 L
s
.47952 .7263 m
.47589 .73383 L
s
.47401 .71656 m
.47644 .7167 L
s
.47589 .73383 m
.47387 .73631 L
s
.47145 .7207 m
.47401 .71656 L
s
.47387 .73631 m
.47144 .73619 L
s
.46982 .72578 m
.47145 .7207 L
s
.47144 .73619 m
.47049 .73529 L
s
.47049 .73529 m
.46914 .73178 L
s
.46914 .73178 m
.46982 .72578 L
s
.46368 .74881 m
.46519 .748 L
s
.46519 .748 m
.46478 .74539 L
s
.46478 .74539 m
.46327 .7462 L
s
.46327 .7462 m
.46368 .74881 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`1d0?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0L0?ooo`00;`3oool2000004H0oooo00<000000?ooo`3oool0LP3oool00`000?l0oooo0000
o`0]0?ooo`030000003oool0oooo0580oooo0P00000M0?ooo`00;P3oool2000004P0oooo00<00000
0?ooo`3oool0L@3oool00`000?l0oooo0000o`0]0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
06l0oooo00D0003o0?ooo`3oool0oooo0000o`0/0?ooo`030000003oool0oooo04`0oooo0`000004
0?ooo`030000003oool0oooo01/0oooo000_0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02T0oooo00<000000?oo
o`3oool0B@3oool3000000L0oooo00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0:03oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo0?ooo`0J0?ooo`00
;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo04<0oooo0`00000>0?ooo`030000
003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0@03o
ool300000140oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool0
0`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0V0?ooo`030000003oool0oooo03T0oooo1000000G0?ooo`030000003oool0oooo
01X0oooo000^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0JP3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0=P3oool3000001/0
oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000003oool0oooo06D0oooo
00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3o
ool0<`3oool3000001h0oooo00<000000?ooo`3oool06P3oool002d0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`1U0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0
oooo0?ooo`0W0?ooo`030000003oool0oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0
oooo000]0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo
0?ooo`020?ooo`<0003o:P3oool00`000000oooo0?ooo`0]0?ooo`<000009@3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo06@0oooo00<0
003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000oooo0?oo
o`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo06<0oooo0P000?l_
0?ooo`030000003oool0oooo02L0oooo0`00000[0?ooo`030000003oool0oooo01T0oooo000]0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool0H`3oool00`000?l0oooo0?ooo`0]0?oo
o`030000003oool0oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0HP3oool20000obh0oooo00<000000?ooo`3o
ool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F@3oool00`000000oooo0?ooo`1Q0?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0
7P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3o
ool00`000000oooo0?ooo`1P0?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool06P3o
ool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool0
0`000000oooo0?ooo`1J0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool20000
05d0oooo00<000000?ooo`3oool0F03oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo
02h0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0
oooo0P00001O0?ooo`030000003oool0oooo05H0oooo00D0003o0?ooo`3oool0oooo0000o`0c0?oo
o`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0300oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1D0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`@00000
A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003o
ool0oooo0580oooo0P000?l40?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool01`3o
ool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool0
0`000000oooo0?ooo`1B0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<03oool0
0`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0580oooo00D0003o0?ooo`3oool0oooo0000o`0b
0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0540oooo00@0003o0?ooo`3oool0003o<`3o
ool4000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`1A0?ooo`<0003o<@3oool3000005P0oooo00<000000?ooo`3oool05`3oool0
02X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo
02d0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0
oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo02T0
oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
0P00001Y0?ooo`030000003oool0oooo04X0oooo0P000?l^0?ooo`<00000203oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool0BP3oool40000obP0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0B@3oool010000?l0oooo0?ooo`3oool20000ob<0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool08P3o
ool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0A@3o
ool010000?l0oooo0?ooo`000?lQ0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`140?ooo`<0003o00<0oooo0000o`3oool0703oool3000001P0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0A03oool010000?l0oooo
0000o`000?lJ0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04<0oooo
00D0003o0?ooo`3oool0oooo0000o`0F0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
@`3oool00`000?l0oooo0?ooo`0C0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0@P3o
ool00`000?l0oooo0?ooo`0@0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0@P3oool0
0`000?l0oooo0?ooo`0<0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`110?ooo`030000o`3oool0oooo
00T0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?03oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo0`00000^0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo03T0oooo0P000?l00`3oool0003o0000o`070?ooo`<00000
<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003o
ool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0h0?ooo`050000o`3o
ool0oooo0?ooo`000?l0103oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0f0?ooo`030000o`3oool0oooo00<0oooo00@0003o0000000000000000=`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0=@3oool010000?l0oooo0?ooo`3oool3000000030000o`3oool0oooo03L0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo03@0oooo00@0003o00000000000000000`3oool00`000?l0oooo
0?ooo`0g0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`80000000<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<000000P3oool0
10000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo02T0oooo0`0000060?ooo`030000o`3oool0003o00@0oooo00<0003o0?ooo`3oool0=P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`00
0000oooo0?ooo`0U0?ooo`<000002@3oool20000o`D0oooo00<0003o0?ooo`3oool0=P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool08@3oool3000000T0oooo00D0003o0?ooo`3oool0oooo0000o`040?oo
o`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000=0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0
603oool300000180oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o03/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo01@0oooo0`00000F0?ooo`050000o`3oool0oooo0?ooo`000?l0?03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0
oooo00<000000?ooo`3oool0403oool3000001T0oooo0P000?lo0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0<0?ooo`<000007@3oool20000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00
000P0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000S
0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000009P3oool00`00
0?l0oooo0?ooo`0m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0S03oool2000002<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo
0P00002=0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0
oooo0?ooo`0m0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0003o?`3oool300000080
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0h0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo03D0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0P
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<P3oool3000000h0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01l0oooo0P000?l40?ooo`030000o`3oool0oooo02l0oooo0`00000B0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0;03oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0
0P3oool01@000?l0oooo0?ooo`3oool0003o02X0oooo1000000J0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0M0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`000?l0003o9`3oool3000001h0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0T0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0200oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo01d0oooo0P000?l0
0`3oool0003o0?ooo`0R0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07@3oool01@00
0?l0oooo0?ooo`3oool0003o01h0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0N0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0603oool3000003<0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo01h0oooo00<0003o0?ooo`3oool00P3oool20000oaH0oooo0`00000f0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
4P3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0?0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07P3oool0
1@000?l0oooo0?ooo`3oool0003o00h0oooo100000120?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0O
0?ooo`040000o`3oool0oooo0000o`/0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0O
0?ooo`040000o`3oool0oooo0000o`P0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0P
0?ooo`80003o1P3oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`070?oo
o`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000T03oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0080oooo1000001F0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0M0?ooo`040000o`0000000000000005/0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0K0?ooo`<0000000<0003o0?ooo`3oool0F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000103oool00`000?l0oooo
0?ooo`1K0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00
00070?ooo`80003oG@3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000:
0?ooo`030000o`3oool0003o05d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?
0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool03P3oool3000000P0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?mM
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000000`0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<0
0000403oool010000?l0oooo0?ooo`000?mR0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@0
0000503oool00`000?l0oooo0000o`1S0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000001T0
oooo0P000?mT0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo
0P00002A0?ooo`@000005P3oool00`000?l0oooo0?ooo`1Z0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<000006P3oool00`000?l0oooo0?oo
o`1Y0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`1Y
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0R03oool4000000D0oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`1Y0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`1Y0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
PP3oool3000000`0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`1Y0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3o
ool3000000l0oooo00<000000?ooo`3oool05P3oool30000o`H0oooo00<0003o0?ooo`3oool0I`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07`0oooo0`00000A0?ooo`030000003oool0oooo01H0oooo00D0003o0?ooo`3oool0oooo0000
o`040?ooo`80003oJ@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo01D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06T0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?oo
o`<00000603oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0KP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`1_0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0
5@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003o
ool0oooo01D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1`0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4
000002@0oooo00<000000?ooo`3oool05P3oool01@000?l0oooo0?ooo`3oool0003o07@0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V
0?ooo`<00000:03oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo07<0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?oo
o`<00000:`3oool00`000000oooo0?ooo`0H0?ooo`<0003oMP3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`03
0000003oool0oooo01@0oooo0P000?ml0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
4`3oool00`000?l0oooo0?ooo`1l0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool04`3o
ool00`000?l0oooo0?ooo`1m0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool04P3oool0
10000?l0oooo0?ooo`3oool20000og`0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`0B
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`1l0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<0
00000?ooo`3oool04P3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo07/0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`0B0?ooo`040000o`3oool0oooo0000o`80oooo
00<0003o0?ooo`3oool0N`3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo0180oooo00<0
003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`0C
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`1n0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?oo
o`3oool05`3oool00`000?l0oooo0?ooo`1o0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3o
ool05@3oool20000oh<0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo08P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo08P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool30000
05/0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`280?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0
oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`280?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo
00<000000?ooo`3oool0503oool20000ohT0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?oo
o`0F0?ooo`030000o`3oool0oooo08H0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`0H
0?ooo`030000o`3oool0oooo08H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<0
0000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool0
0`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0
oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`000027
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?oo
o`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<00000
0?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;
0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003o
ool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool0
0`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool0
03/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo
00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000
J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`00
0000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P00
00000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`00
0000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@0
00000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?oo
o`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo10000003
0?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?oo
o`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000
003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003o
ool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<0
00000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P000000
0`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
0680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo
0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W
0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo10000009
0?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`80
0000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0
oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo
0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0
oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo
001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e
0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?oo
o`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`80
0000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00
J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@0
0000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000
503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool0
0`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool0
0`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740
oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k
0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?oo
o`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00
T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003o
ool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool0
0`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440
oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0
oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo
1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00
002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`
0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`03
0000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00
I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3o
ool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo
00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?oo
o`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@0
0000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.55347 .43885 m
.55242 .44865 L
s
.55347 .43885 m
.53606 .41785 L
s
.55242 .44865 m
.55114 .45188 L
s
.55114 .45188 m
.54919 .45273 L
s
.54919 .45273 m
.54738 .45216 L
s
.54738 .45216 m
.54473 .4506 L
s
.54473 .4506 m
.54056 .44562 L
s
.53495 .42769 m
.53606 .41785 L
s
.54448 .46153 m
.5327 .44757 L
s
.54056 .44562 m
.5382 .44121 L
s
.5382 .44121 m
.53668 .43778 L
s
.53531 .43294 m
.53495 .42769 L
s
.54318 .46481 m
.5437 .46866 L
s
.54181 .45998 m
.54318 .46481 L
s
.53945 .45557 m
.54181 .45998 L
s
.5437 .46866 m
.54323 .47295 L
s
.53668 .43778 m
.53531 .43294 L
s
.54113 .48347 m
.53976 .47861 L
s
.54166 .48734 m
.54113 .48347 L
s
.53976 .47861 m
.53739 .4742 L
s
.54119 .49168 m
.54166 .48734 L
s
.53739 .4742 m
.53569 .47222 L
s
.54003 .4936 m
.54119 .49168 L
s
.53569 .47222 m
.53298 .47068 L
s
.53801 .49455 m
.54003 .4936 L
s
.54056 .49749 m
.52862 .48367 L
s
.53298 .47068 m
.53095 .47158 L
s
.53944 .5077 m
.52679 .4998 L
s
.53095 .47158 m
.52977 .47348 L
s
.52977 .47348 m
.52928 .47784 L
s
.52928 .47784 m
.52981 .48174 L
s
.52981 .48174 m
.53119 .48665 L
s
.53816 .51944 m
.52546 .51163 L
s
.53816 .51944 m
.52679 .4998 L
s
.53687 .53127 m
.52546 .51163 L
s
.54039 .55195 m
.539 .54704 L
s
.54093 .55589 m
.54039 .55195 L
s
.539 .54704 m
.53745 .54362 L
s
.54029 .56189 m
.54093 .55589 L
s
.53745 .54362 m
.53504 .53922 L
s
.53911 .56394 m
.54029 .56189 L
s
.53504 .53922 m
.53072 .53437 L
s
.53706 .56504 m
.53911 .56394 L
s
.53072 .53437 m
.52796 .53293 L
s
.53517 .56463 m
.53706 .56504 L
s
.52796 .53293 m
.52605 .53247 L
s
.52605 .53247 m
.52397 .53351 L
s
.52906 .54937 m
.52822 .55692 L
s
.52397 .53351 m
.52275 .53554 L
s
.53245 .5718 m
.52018 .55827 L
s
.5256 .55401 m
.52822 .55692 L
s
.52275 .53554 m
.52207 .54157 L
s
.53108 .5754 m
.53162 .57941 L
s
.52967 .57044 m
.53108 .5754 L
s
.52721 .56603 m
.52967 .57044 L
s
.53162 .57941 m
.53112 .58399 L
s
.52402 .55055 m
.5256 .55401 L
s
.52207 .54157 m
.5226 .54557 L
s
.5226 .54557 m
.52402 .55055 L
s
.5289 .59532 m
.52748 .59034 L
s
.52944 .59936 m
.5289 .59532 L
s
.52748 .59034 m
.52501 .58592 L
s
.52894 .604 m
.52944 .59936 L
s
.52501 .58592 m
.52324 .584 L
s
.52772 .60615 m
.52894 .604 L
s
.52324 .584 m
.52042 .58265 L
s
.52561 .60735 m
.52772 .60615 L
s
.52826 .6102 m
.51582 .59683 L
s
.52042 .58265 m
.51829 .58381 L
s
.52707 .6211 m
.50826 .60104 L
s
.51829 .58381 m
.51705 .58594 L
s
.52584 .62329 m
.52639 .62737 L
s
.52441 .61827 m
.52584 .62329 L
s
.52639 .62737 m
.52587 .63208 L
s
.51705 .58594 m
.51652 .5906 L
s
.52587 .63208 m
.52464 .63429 L
s
.51652 .5906 m
.51707 .59467 L
s
.51707 .59467 m
.5185 .59971 L
s
.52464 .63429 m
.52251 .63556 L
s
.52987 .65916 m
.511 .63946 L
s
.51512 .61188 m
.51727 .61065 L
s
.52251 .63556 m
.51965 .63431 L
s
.51387 .61407 m
.51512 .61188 L
s
.51965 .63431 m
.51785 .63242 L
s
.51333 .6188 m
.51387 .61407 L
s
.51785 .63242 m
.51533 .62799 L
s
.52221 .65649 m
.52276 .66062 L
s
.52004 .6489 m
.52221 .65649 L
s
.52276 .66062 m
.52223 .66542 L
s
.51388 .62292 m
.51333 .6188 L
s
.51533 .62799 m
.51388 .62292 L
s
.52223 .66542 m
.52098 .6677 L
s
.5275 .6905 m
.52678 .68797 L
s
.52643 .6912 m
.5275 .6905 L
s
.52678 .68797 m
.52571 .68867 L
s
.52571 .68867 m
.52643 .6912 L
s
.52098 .6677 m
.5181 .66651 L
s
.5181 .66651 m
.509 .65713 L
s
.5203 .68314 m
.50753 .6701 L
s
.51762 .69849 m
.51615 .69338 L
s
.51817 .70268 m
.51762 .69849 L
s
.51615 .69338 m
.51359 .68897 L
s
.51763 .70759 m
.51817 .70268 L
s
.51359 .68897 m
.51176 .68711 L
s
.51636 .70996 m
.51763 .70759 L
s
.51176 .68711 m
.50882 .68596 L
s
.51417 .71143 m
.51636 .70996 L
s
.50882 .68596 m
.50661 .68737 L
s
.50661 .68737 m
.50531 .68972 L
s
.51474 .72483 m
.51308 .72135 L
s
.51511 .73072 m
.51474 .72483 L
s
.51308 .72135 m
.51105 .72118 L
s
.51457 .73572 m
.51511 .73072 L
s
.50531 .68972 m
.50475 .69466 L
s
.5131 .73982 m
.51457 .73572 L
s
.51105 .72118 m
.50976 .72359 L
s
.50475 .69466 m
.50531 .69889 L
s
.50531 .69889 m
.50679 .70405 L
s
.51884 .7621 m
.50585 .74951 L
s
.50976 .72359 m
.5079 .73102 L
s
.51106 .73968 m
.5131 .73982 L
s
.50362 .71382 m
.50567 .714 L
s
.5079 .73102 m
.5066 .73345 L
s
.50212 .7179 m
.50362 .71382 L
s
.5066 .73345 m
.50454 .7333 L
s
.50156 .72292 m
.50212 .7179 L
s
.50454 .7333 m
.50361 .73239 L
s
.50193 .72887 m
.50156 .72292 L
s
.50361 .73239 m
.50193 .72887 L
s
.50002 .74575 m
.50115 .74497 L
s
.50115 .74497 m
.5004 .74236 L
s
.5004 .74236 m
.49927 .74314 L
s
.49927 .74314 m
.50002 .74575 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`1U0?ooo`030000o`3oool0oooo03T0oooo00<00000
0?ooo`3oool0C`3oool3000000030?ooo`000000oooo01`0oooo000_0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0I03oool20000ocX0oooo00<000000?ooo`3oool0C03oool30000
00@0oooo00<000000?ooo`3oool06`3oool002l0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`1R0?ooo`030000o`3oool0003o03X0oooo00<000000?ooo`3oool0B@3oool3000000L0
oooo00<000000?ooo`3oool06`3oool002h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`1Q0?ooo`040000o`3oool0oooo0000ocT0oooo00<000000?ooo`3oool0AP3oool3000000/0
oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`1P0?ooo`050000o`3oool0oooo0?ooo`000?l0>03oool00`000000oooo0?ooo`130?ooo`<0
00003P3oool00`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo05l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0e0?ooo`030000
003oool0oooo0400oooo0`00000A0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0GP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo03D0oooo00<000000?ooo`3oool0?@3oool3000001@0oooo00<000000?ooo`3oool06P3o
ool002h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1N0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`0i0?ooo`@000005`3oool0
0`000000oooo0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
05d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo
03H0oooo0`00000K0?ooo`030000003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000
oooo0?ooo`1M0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool00`000000
oooo0?ooo`0c0?ooo`<000007P3oool00`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo05`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0c0?ooo`030000003oool0oooo0300oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo
000]0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0F03oool01@000?l0oooo0?oo
o`3oool0003o00<0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0]0?ooo`<00000
9@3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo05P0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o03H0oooo00<000000?ooo`3o
ool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`1H0?ooo`040000o`3oool0oooo0?ooo`80003o=P3oool00`000000
oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo
0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo05L0oooo0P000?li0?ooo`030000003oool0oooo0240oooo0`00
000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0E`3oool20000ocP0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<00000
0?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1F0?oo
o`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1E0?ooo`03
0000o`3oool0oooo03P0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3o
ool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo05D0oooo00<0003o0?ooo`3oool0
=`3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool2000005l0oooo00<000000?ooo`3oool0C`3oool30000o`030?ooo`000?l0oooo03T0oooo00<0
00000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`1=0?ooo`040000o`3oool0oooo0000oc`0oooo00<0
00000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`1<0?ooo`040000o`3oool0oooo0000oc`0oooo00<0
00000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0H@3oool00`000000oooo0?ooo`1;0?ooo`050000o`3oool0oooo0?ooo`000?l0>`3o
ool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool0
0`000000oooo0?ooo`1R0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0B@3oool20000
o`<0oooo00<0003o0?ooo`3oool0>03oool010000000oooo0?ooo`3oool300000580oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`190?oo
o`050000o`3oool0oooo0?ooo`000?l0>P3oool4000005D0oooo00<000000?ooo`3oool05`3oool0
02/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`190?ooo`040000o`3oool0oooo
0000ocP0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0B@3oool20000ocH0oooo0`0000020?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000
oooo0?ooo`180?ooo`030000o`3oool0oooo0380oooo0`0000050?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo04@0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0^0?ooo`<00000203oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<0
00000?ooo`3oool0A03oool20000oc00oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool0@`3oool010000?l0oooo0000o`000?l[0?ooo`<000003P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`130?ooo`040000o`3oool0oooo0000obL0oooo
0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@0
00000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0480oooo
00<0003o0?ooo`3oool09@3oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo
00<000000?ooo`3oool0?`3oool010000?l0oooo0?ooo`000?lS0?ooo`<00000603oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0
oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0o0?ooo`80003o00<0oooo0000o`3o
ool07P3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
8@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0n0?ooo`040000
o`3oool0003o0000oa`0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0n0?ooo`040000
o`3oool0oooo0000oaL0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0m0?ooo`030000
o`3oool0oooo01D0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0m0?ooo`030000o`3o
ool0oooo0140oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo0P00001f0?ooo`030000003oool0oooo03`0oooo00<0003o0?ooo`3oool03P3oool3
000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool40000
0200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo
00X0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0
oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo03H0
oooo10000?l;0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0e0?ooo`040000o`3oool0oooo0000o`P0oooo0`00000d0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0=03oool01@000?l0oooo0?ooo`3oool0003o00@0oooo0`00000g0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0c0?ooo`060000o`3oool0oooo0?ooo`000?l0oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo0080000000<0003o0?ooo`3o
ool0>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool00`000?l00000000000030?ooo`030000
o`3oool0oooo03X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000000`000?l0oooo0000
o`030?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`000003
0?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?oo
o`<000001`3oool20000o`@0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool08@3oool3000000P0oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0i0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000303oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo03/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000A0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503o
ool3000001@0oooo00<0003o0?ooo`3oool00P000?ln0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<000005`3oool20000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000K0?oo
o`80003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001h0oooo00<0003o0?ooo`3o
ool0?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool300000280oooo00<0003o0?ooo`3oool0
?P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000U0?ooo`030000o`3oool0oooo03h0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`800000903oool01@000?l0oooo0?ooo`3oool0003o0400oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08P3oool0
0`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03d0oooo0P00001K0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08P3oool01000
0?l0oooo0?ooo`000?ln0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03L0oooo100000060?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=03oool3000000X0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0280oooo00D0003o0?ooo`3oool0oooo0000o`0c0?ooo`<0
00003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool08@3oool20000o`<0oooo00<0003o0?ooo`3oool0
;P3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01h0oooo00D0003o0?ooo`3oool0oooo
0000o`030?ooo`030000o`3oool0oooo02/0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0O0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0W0?ooo`@00000
6P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0803oool01`000?l0oooo0?ooo`3oool0003o0?ooo`00
0?l09P3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0240oooo00D0003o0?ooo`3oool0
oooo0000o`0T0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08@3oool20000o`<0oooo
00<0003o0?ooo`3oool07P3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0000
o`0Q0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0803oool010000?l0oooo0?ooo`00
0?lL0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08@3oool01@000?l0oooo0?ooo`3o
ool0003o01P0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q0?ooo`040000o`3oool0
oooo0?ooo`80003o503oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0240oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0?0?ooo`<00000>P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0`00000n0?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l02P3oool400000480oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o1`3oool3000004L0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02@0oooo0P000?l50?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool3000008h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`<00000
DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03o
ool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3
000000030?ooo`000?l0oooo05P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<000001@3oool20000oeL0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool3000000T0oooo00<0003o0?ooo`3oool0EP3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000003@3oool00`000?l0oooo0?ooo`1F0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000000/0oooo00<0003o0?ooo`3oool0
0P3oool20000oeP0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3o
ool300000100oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o05P0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0;0?ooo`<000004`3oool01@000?l0oooo0?ooo`3oool0003o05X0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000G0?ooo`040000o`3oool0oooo0000oe/0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000K0?ooo`80003oG@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@0
00000?ooo`3oool0oooo0`00000K0?ooo`030000o`3oool0oooo0640oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000O0?ooo`030000o`3o
ool0oooo0640oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool2
00000900oooo0`00000S0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?oo
o`0O0?ooo`<0003oIP3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo01h0oooo00@0003o
0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`1P0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool07`3oool010000?l0oooo0?ooo`000?l40?ooo`80003oH@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D
0?ooo`030000003oool0oooo01l0oooo00D0003o0?ooo`3oool0oooo0000o`1W0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3
000001P0oooo00<000000?ooo`3oool07`3oool01@000?l0oooo0?ooo`3oool0003o06P0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`<000006`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0IP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo01l0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`0P0?ooo`05
0000o`3oool0oooo0?ooo`000?l0J@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo02@0
oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0
oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo02<0oooo
00<0003o0?ooo`3oool0JP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo01l0oooo00<0
003o0?ooo`3oool0K`3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo01h0oooo00<0003o
0?ooo`3oool0L@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo01h0oooo00<0003o0?oo
o`3oool0L@3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3o
ool00P000?m`0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool07P3oool01P000?l0oooo
0?ooo`000?l0oooo0000og00oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?oo
o`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`0N0?ooo`06
0000o`3oool0oooo0000o`3oool0003oL@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo
01h0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`1`0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440
oooo00<000000?ooo`3oool07`3oool20000o`80oooo00<0003o0?ooo`3oool0L03oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo
0`0000150?ooo`030000003oool0oooo01l0oooo0P000?l20?ooo`030000o`3oool0oooo0740oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`00
00180?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0LP3oool00`000000oooo0?oo
o`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;
0?ooo`030000003oool0oooo0240oooo0P000?mf0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?oo
o`3oool07@3oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3o
ool07@3oool20000og`0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3o
ool3000005P0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`1j0?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3
000005/0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`1j0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool30000
05h0oooo00<000000?ooo`3oool08@3oool20000og/0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo07T0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo07P0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?oo
o`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000
M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0
oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo
0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?oo
o`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`000000
0P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?oo
o`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`00
8`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003o
ool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D
0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`03
0000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00
<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo
0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo
0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000
K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0
HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0
oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000
oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo
00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?oo
o`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?oo
o`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?oo
o`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000
003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo
00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool0
0`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000
oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P000014
0?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?oo
o`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3o
ool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool0
0740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<0
00000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<00000
0?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?oo
o`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3o
ool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?oo
o`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?oo
o`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`03
0000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3o
ool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3o
ool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5
000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo
0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo
002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo
002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`03
0000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000
003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3o
ool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4
000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0
oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0
oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo
0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00
000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<00000
0?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W
0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?oo
o`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3o
ool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?oo
o`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3o
ool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool0
0:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?oo
o`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<0
0000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?oo
o`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`80
0000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.51923 .4507 m
.52033 .4597 L
s
.51923 .4507 m
.50155 .42997 L
s
.52033 .4597 m
.51997 .4626 L
s
.51997 .4626 m
.51861 .46324 L
s
.51861 .46324 m
.51708 .46258 L
s
.51708 .46258 m
.51471 .46094 L
s
.51471 .46094 m
.51048 .45602 L
s
.5026 .439 m
.50155 .42997 L
s
.51048 .45602 m
.50777 .45175 L
s
.51665 .47105 m
.50472 .45724 L
s
.5039 .44388 m
.5026 .439 L
s
.50777 .45175 m
.50592 .44847 L
s
.50592 .44847 m
.5039 .44388 L
s
.51628 .47401 m
.51744 .47761 L
s
.51427 .46942 m
.51628 .47401 L
s
.51156 .46516 m
.51427 .46942 L
s
.51744 .47761 m
.51792 .48156 L
s
.51834 .49118 m
.51632 .48657 L
s
.51951 .49482 m
.51834 .49118 L
s
.51632 .48657 m
.5136 .4823 L
s
.51999 .49882 m
.51951 .49482 L
s
.5136 .4823 m
.51188 .48034 L
s
.51946 .50052 m
.51999 .49882 L
s
.51188 .48034 m
.50946 .47871 L
s
.51807 .50125 m
.51946 .50052 L
s
.52064 .50418 m
.50859 .49046 L
s
.50946 .47871 m
.50805 .4794 L
s
.50805 .4794 m
.5075 .48107 L
s
.52177 .5136 m
.51032 .50533 L
s
.5075 .48107 m
.50796 .48509 L
s
.50796 .48509 m
.50914 .48876 L
s
.50914 .48876 m
.51119 .49342 L
s
.52308 .52445 m
.51159 .51626 L
s
.52308 .52445 m
.51032 .50533 L
s
.52439 .53538 m
.51159 .51626 L
s
.53122 .55493 m
.52917 .55025 L
s
.53242 .55866 m
.53122 .55493 L
s
.52917 .55025 m
.52728 .54694 L
s
.5331 .56421 m
.53242 .55866 L
s
.52728 .54694 m
.52452 .54267 L
s
.52452 .54267 m
.52019 .53783 L
s
.53258 .56605 m
.5331 .56421 L
s
.53119 .56693 m
.53258 .56605 L
s
.52019 .53783 m
.51774 .5363 L
s
.52963 .56642 m
.53119 .56693 L
s
.51774 .5363 m
.51615 .53574 L
s
.51615 .53574 m
.51472 .53656 L
s
.52183 .55173 m
.52266 .55873 L
s
.51472 .53656 m
.51417 .53837 L
s
.52891 .57294 m
.51662 .55943 L
s
.52004 .55582 m
.52266 .55873 L
s
.51417 .53837 m
.51482 .54395 L
s
.52855 .57622 m
.52976 .58001 L
s
.52646 .57147 m
.52855 .57622 L
s
.51811 .55248 m
.52004 .55582 L
s
.52367 .56717 m
.52646 .57147 L
s
.51482 .54395 m
.51603 .54773 L
s
.52976 .58001 m
.53027 .58426 L
s
.51603 .54773 m
.51811 .55248 L
s
.53077 .59473 m
.52867 .58996 L
s
.53199 .59855 m
.53077 .59473 L
s
.52867 .58996 m
.52586 .58565 L
s
.53251 .60287 m
.53199 .59855 L
s
.52586 .58565 m
.5241 .58373 L
s
.53198 .6048 m
.53251 .60287 L
s
.5241 .58373 m
.52161 .58227 L
s
.53056 .60579 m
.53198 .6048 L
s
.5332 .60864 m
.52079 .59525 L
s
.52161 .58227 m
.52017 .58321 L
s
.52017 .58321 m
.51961 .58512 L
s
.53443 .6188 m
.51568 .59868 L
s
.51961 .58512 m
.52012 .58945 L
s
.53389 .62077 m
.53513 .62464 L
s
.53178 .61596 m
.53389 .62077 L
s
.53513 .62464 m
.53566 .62904 L
s
.52012 .58945 m
.52135 .59331 L
s
.52135 .59331 m
.52347 .59813 L
s
.53566 .62904 m
.53513 .63103 L
s
.53513 .63103 m
.5337 .63209 L
s
.54417 .65479 m
.52542 .63499 L
s
.52322 .60933 m
.52466 .60832 L
s
.5337 .63209 m
.53121 .63072 L
s
.52266 .6113 m
.52322 .60933 L
s
.53121 .63072 m
.52942 .62882 L
s
.52318 .61571 m
.52266 .6113 L
s
.52942 .62882 m
.52656 .62448 L
s
.52442 .61962 m
.52318 .61571 L
s
.52656 .62448 m
.52442 .61962 L
s
.53762 .65177 m
.53887 .6557 L
s
.5344 .64448 m
.53762 .65177 L
s
.53887 .6557 m
.53941 .66019 L
s
.53941 .66019 m
.53887 .66226 L
s
.54853 .6842 m
.54746 .68177 L
s
.54783 .68479 m
.54853 .6842 L
s
.54746 .68177 m
.54676 .68235 L
s
.53887 .66226 m
.53637 .66095 L
s
.54676 .68235 m
.54783 .68479 L
s
.53637 .66095 m
.52734 .6515 L
s
.5414 .67679 m
.52876 .66363 L
s
.54234 .69111 m
.54017 .68618 L
s
.54361 .69511 m
.54234 .69111 L
s
.54017 .68618 m
.53728 .68185 L
s
.54416 .69972 m
.54361 .69511 L
s
.53728 .68185 m
.53546 .67998 L
s
.54363 .70188 m
.54416 .69972 L
s
.53546 .67998 m
.53292 .6787 L
s
.54219 .70313 m
.54363 .70188 L
s
.53292 .6787 m
.53145 .67989 L
s
.53145 .67989 m
.5309 .68202 L
s
.54531 .71586 m
.54331 .71245 L
s
.54678 .72146 m
.54531 .71586 L
s
.5309 .68202 m
.53144 .68666 L
s
.54331 .71245 m
.54167 .71216 L
s
.54734 .72616 m
.54678 .72146 L
s
.53144 .68666 m
.53272 .6907 L
s
.53272 .6907 m
.53491 .69568 L
s
.54167 .71216 m
.54113 .71436 L
s
.547 .72996 m
.54734 .72616 L
s
.54113 .71436 m
.54115 .72129 L
s
.55598 .75148 m
.54321 .73871 L
s
.54537 .7297 m
.547 .72996 L
s
.53435 .70472 m
.53601 .70502 L
s
.53398 .70849 m
.53435 .70472 L
s
.54115 .72129 m
.54061 .72351 L
s
.54061 .72351 m
.53895 .72324 L
s
.53453 .71321 m
.53398 .70849 L
s
.53895 .72324 m
.53803 .72231 L
s
.536 .71887 m
.53453 .71321 L
s
.53803 .72231 m
.536 .71887 L
s
.53786 .73476 m
.5386 .73409 L
s
.5386 .73409 m
.53749 .73157 L
s
.53749 .73157 m
.53675 .73224 L
s
.53675 .73224 m
.53786 .73476 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo05@0oooo00<0
003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`130?ooo`<000003P3oool00`000000oooo0?oo
o`0J0?ooo`00;P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo05<0oooo0P000?m7
0?ooo`030000003oool0oooo0400oooo0`00000A0?ooo`030000003oool0oooo01X0oooo000^0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0DP3oool20000odL0oooo00<000000?oo
o`3oool0?@3oool3000001@0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3o
ool0CP3oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0003o04H0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`1@0?ooo`040000o`3oool0oooo0000odD0oooo00<000000?ooo`3o
ool0=P3oool3000001/0oooo00<000000?ooo`3oool06P3oool002d0oooo0P00001B0?ooo`030000
003oool0oooo04l0oooo00D0003o0?ooo`3oool0oooo0000o`140?ooo`030000003oool0oooo03<0
oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo0580oooo
00<000000?ooo`3oool0C`3oool010000?l0oooo0?ooo`000?m40?ooo`030000003oool0oooo0300
oooo0`00000Q0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool0C`3oool010000?l0oooo0?ooo`000?m30?ooo`030000003oool0oooo02d0
oooo0`00000U0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0CP3oool01@000?l0oooo0?ooo`3oool0003o0480oooo00<000000?ooo`3o
ool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`1=0?ooo`050000o`3oool0oooo0?ooo`000?l0@P3oool00`000000
oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo04d0oooo00@0003o0?ooo`3oool0003o@P3oool00`000000
oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo04X0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0
oooo0?ooo`0o0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0
oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool0BP3oool01P000?l0oooo
0?ooo`000?l0oooo0000od40oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1:0?ooo`03
0000o`3oool0oooo0080003o@P3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000
oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo04X0oooo
00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo
0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0BP3oool00`000?l0oooo0?oo
o`120?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`800000G`3oool00`000000oooo0?ooo`190?ooo`80003o@`3oool00`000000oooo0?ooo`0A
0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?oo
o`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo04P0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0:0?ooo`@0
0000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000
003oool0oooo04<0oooo0`000?l00`3oool0003o0?ooo`120?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0@P3oool01@000?l0oooo0000o`3oool0003o04<0oooo00<000000?ooo`3oool0
103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3o
ool00`000000oooo0?ooo`110?ooo`030000o`3oool0003o04D0oooo00@000000?ooo`3oool0oooo
0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0@@3oool00`000?l0oooo0000o`140?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0400oooo00@0003o
0?ooo`3oool0003o@@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`3oool0I`3oool00`000000oooo0?ooo`0o0?ooo`80003o00<0oooo0000o`3oool0?@3oool3
00000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`00
0000oooo0000001X0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`000?l0>P3oool30000
00D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0
oooo00<000000?ooo`3oool0@03oool00`000?l0oooo0000o`0g0?ooo`<00000203oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo
00<000000?ooo`3oool0@03oool20000oc@0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<0
00000?ooo`3oool0@03oool00`000?l0oooo0?ooo`0_0?ooo`<000003P3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`0k0?ooo`030000o`3oool0oooo0300oooo0`00
000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@00000
0?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo03/0oooo00<0
003o0?ooo`3oool0;03oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool0>P3oool30000obT0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?oo
o`1_0?ooo`030000003oool0oooo03X0oooo00<0003o0?ooo`000?l09@3oool3000001/0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0003o02<0oooo0`00000N
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0003o01h0oooo1000000Q0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0g0?ooo`<0003o6`3oool3000002D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000
003oool0oooo03L0oooo00<0003o0?ooo`000?l05`3oool3000002P0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0=P3o
ool00`000?l0oooo0?ooo`0D0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo03H0oooo00<0003o0?ooo`3oool0403oool3000002h0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0=0?ooo`<00000<@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0b0?ooo`80003o00<0oooo0000o`3o
ool02P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0a0?ooo`030000
o`3oool0003o00T0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0`0?ooo`040000o`3o
ool0oooo0000o`D0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0_0?ooo`040000o`3o
ool0oooo0000o`80oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0^0?ooo`060000o`3o
ool0oooo000000000?l00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool00`000?l00000
000000020?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00
00000`3oool0003o0000o`020?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3
000000D0oooo00D0003o0?ooo`3oool0oooo0000o`0o0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q
0?ooo`<000002@3oool010000?l0oooo0?ooo`000?lo0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L
0?ooo`@000002@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03h0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo01P0oooo0`00000>0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0?@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool300000180oooo00<0003o0?ooo`3o
ool00`000?lo0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000005P3oool010000?l0oooo
0?ooo`000?m00?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000006P3oool00`000?l0oooo
0?ooo`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000007@3oool20000od40oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo00@0oooo0`00000Q0?ooo`030000o`3oool0oooo03l0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo00<00000903oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000002@0
oooo00@0003o0?ooo`3oool0003o@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0S0?ooo`80003o0P3oool00`000?l0
oooo0?ooo`0m0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`000?l0?P3oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o>@3oool4000000H0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o=P3oool3000000X0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02<0oooo00D0003o0?ooo`3oool0oooo0000o`0b0?ooo`<00000
3P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool08@3oool010000?l0oooo0?ooo`000?l20?ooo`030000
o`3oool0oooo02d0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`060000o`3o
ool0oooo0000o`3oool0003o;03oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0oooo
00<0003o0?ooo`3oool00P000?lX0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903o
ool010000?l0oooo0?ooo`000?lU0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903o
ool01@000?l0oooo0?ooo`3oool0003o0240oooo0`00000R0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0T0?ooo`80003o8@3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0000o`0M
0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?ooo`000?lH
0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`020000
oa@0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`050000o`3oool0oooo0?oo
o`000?l04@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3o
ool0003o3P3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3o
ool0003o2`3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02L0oooo10000?l60?ooo`@0
0000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`020?ooo`<00000
A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`020?ooo`<00000BP3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool09`3oool010000?l0000000000000001>0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0
oooo02D0oooo0`0000000`000?l0oooo0?ooo`1?0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo100000040?oo
o`030000o`3oool0oooo04l0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?oo
o`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`0000080?ooo`80
003oD@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000<0?ooo`80003o
D03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000
2`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0D03oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000003`3oool010000?l0oooo0?ooo`000?l20?oo
o`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@0
00004`3oool010000?l0oooo0?ooo`000?mC0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00h0oooo0`00000H0?ooo`030000o`3oool0003o05@0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0;0?ooo`<00000703oool20000oe@0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00P0oooo0`00000L0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000000P0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo
0?ooo`<000009@3oool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000:@3oool00`000?l0oooo0?ooo`1G0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000;@3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0
:@3oool010000?l0oooo0?ooo`000?mH0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0
:03oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0EP3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo0880oooo0`00000<0?ooo`030000003oool0oooo02P0oooo00@0003o0?ooo`3oool0003o0P3o
ool00`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0:03oool0
10000?l0oooo0?ooo`000?mM0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0:P3oool0
10000?l0oooo0?ooo`000?mL0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0:P3oool0
1@000?l0oooo0?ooo`3oool0003o05`0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`0Z
0?ooo`050000o`3oool0oooo0?ooo`000?l0G@3oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0
oooo02h0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo
02d0oooo0P000?mO0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0
oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`0Z0?ooo`80003oHP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo
1000000T0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00
000X0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[
0?ooo`030000003oool0oooo02X0oooo00@0003o0?ooo`3oool0003oH`3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^
0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool00P000?mS0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool30000
0340oooo00<000000?ooo`3oool0:`3oool010000?l0oooo0000o`000?mS0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool0:`3oool01@000?l0oooo0000o`3oool0003o06<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?oo
o`<00000>03oool00`000000oooo0?ooo`0[0?ooo`80003o0P3oool00`000?l0oooo0?ooo`1R0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3o
ool0E03oool3000003/0oooo00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`1S0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
DP3oool3000003h0oooo00<000000?ooo`3oool0;P3oool20000ofH0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3o
ool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool0
0`000000oooo0?ooo`0[0?ooo`80003oJP3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0
oooo0`00001;0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0J@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo
0`00001>0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool0J@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000
001A0?ooo`030000003oool0oooo02l0oooo0P000?mZ0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<00000
0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?oo
o`3oool0<P3oool00`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo
0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?oo
o`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000
002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0
oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo
000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?oo
o`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`
0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?oo
o`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3o
ool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@00000
0?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`80
0000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`80
0000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003o
ool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2
000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool0
0`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
03d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B
0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool2
00000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool0
0600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?oo
o`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`800000
0P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4
000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0
oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?oo
o`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0
/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool4
00000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0
oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo
0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo
1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo
0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo
001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo0021
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?oo
o`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3o
ool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`00
00009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000
003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo
05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0
oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo
100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B
0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?oo
o`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000
003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003o
ool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0
oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo
1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo
00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?oo
o`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0
oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo
0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48609 .46836 m
.48925 .47622 L
s
.48609 .46836 m
.4681 .44792 L
s
.48925 .47622 m
.48976 .47864 L
s
.48976 .47864 m
.48897 .47898 L
s
.48897 .47898 m
.48772 .47818 L
s
.48772 .47818 m
.48561 .47642 L
s
.47123 .45579 m
.4681 .44792 L
s
.48561 .47642 m
.48131 .47156 L
s
.48131 .47156 m
.47827 .46749 L
s
.48966 .48537 m
.47756 .47172 L
s
.47345 .46017 m
.47123 .45579 L
s
.47827 .46749 m
.47608 .4644 L
s
.47608 .4644 m
.47345 .46017 L
s
.49018 .48784 m
.49196 .4911 L
s
.48754 .48361 m
.49018 .48784 L
s
.4845 .47954 m
.48754 .48361 L
s
.49196 .4911 m
.49334 .49456 L
s
.49619 .50287 m
.49354 .4986 L
s
.49799 .50616 m
.49619 .50287 L
s
.49354 .4986 m
.49048 .49453 L
s
.49939 .50967 m
.49799 .50616 L
s
.49048 .49453 m
.48875 .49259 L
s
.49947 .51104 m
.49939 .50967 L
s
.48875 .49259 m
.4866 .49082 L
s
.49868 .51146 m
.49947 .51104 L
s
.50127 .51436 m
.4891 .50075 L
s
.4866 .49082 m
.48579 .49119 L
s
.48579 .49119 m
.48584 .49255 L
s
.50458 .52261 m
.49428 .51378 L
s
.48584 .49255 m
.48723 .49606 L
s
.48723 .49606 m
.48904 .49938 L
s
.48904 .49938 m
.49173 .50369 L
s
.50839 .53213 m
.49808 .52335 L
s
.50839 .53213 m
.49428 .51378 L
s
.51223 .54172 m
.49808 .52335 L
s
.52228 .55957 m
.51958 .55523 L
s
.52412 .56295 m
.52228 .55957 L
s
.51958 .55523 m
.51736 .5521 L
s
.52609 .56784 m
.52412 .56295 L
s
.51736 .5521 m
.51427 .54801 L
s
.51427 .54801 m
.50991 .54319 L
s
.52621 .56934 m
.52609 .56784 L
s
.52546 .56989 m
.52621 .56934 L
s
.50991 .54319 m
.50777 .5415 L
s
.52422 .56922 m
.52546 .56989 L
s
.50777 .5415 m
.50649 .54078 L
s
.50649 .54078 m
.5057 .54127 L
s
.51478 .55539 m
.51724 .56154 L
s
.5057 .54127 m
.50579 .54274 L
s
.50579 .54274 m
.50774 .54764 L
s
.52545 .57472 m
.51314 .56123 L
s
.5146 .55865 m
.51724 .56154 L
s
.51235 .55548 m
.5146 .55865 L
s
.50774 .54764 m
.5096 .55107 L
s
.52607 .57749 m
.52794 .58094 L
s
.52333 .57309 m
.52607 .57749 L
s
.5202 .56897 m
.52333 .57309 L
s
.5096 .55107 m
.51235 .55548 L
s
.52794 .58094 m
.52945 .58469 L
s
.5326 .59379 m
.52983 .58936 L
s
.53449 .59727 m
.5326 .59379 L
s
.52983 .58936 m
.52669 .58522 L
s
.53601 .60108 m
.53449 .59727 L
s
.52669 .58522 m
.52493 .5833 L
s
.53615 .60267 m
.53601 .60108 L
s
.52493 .5833 m
.52278 .58167 L
s
.53541 .60331 m
.53615 .60267 L
s
.53805 .60617 m
.52567 .59274 L
s
.52278 .58167 m
.52201 .58226 L
s
.52201 .58226 m
.52212 .58383 L
s
.54164 .61513 m
.52296 .59494 L
s
.52212 .58383 m
.52364 .58764 L
s
.54179 .61675 m
.5437 .62028 L
s
.539 .61227 m
.54179 .61675 L
s
.52364 .58764 m
.52554 .59115 L
s
.5437 .62028 m
.54525 .62416 L
s
.52554 .59115 m
.52834 .59564 L
s
.54525 .62416 m
.54541 .6258 L
s
.54541 .6258 m
.54469 .6265 L
s
.53116 .60527 m
.53191 .60461 L
s
.5582 .64771 m
.5396 .62778 L
s
.54469 .6265 m
.54255 .62495 L
s
.53129 .60689 m
.53116 .60527 L
s
.54255 .62495 m
.54078 .62304 L
s
.53284 .61078 m
.53129 .60689 L
s
.54078 .62304 m
.53759 .61886 L
s
.53476 .61434 m
.53284 .61078 L
s
.53759 .61886 m
.53476 .61434 L
s
.55275 .64412 m
.55469 .64771 L
s
.54851 .63733 m
.55275 .64412 L
s
.55469 .64771 m
.55628 .65168 L
s
.55628 .65168 m
.55646 .65339 L
s
.56921 .67385 m
.5678 .67158 L
s
.56888 .67426 m
.56921 .67385 L
s
.5678 .67158 m
.56746 .67199 L
s
.55646 .65339 m
.55433 .65189 L
s
.56746 .67199 m
.56888 .67426 L
s
.55433 .65189 m
.54539 .64236 L
s
.56216 .66636 m
.54966 .65309 L
s
.56668 .67893 m
.56382 .67434 L
s
.56866 .68259 m
.56668 .67893 L
s
.56382 .67434 m
.5606 .67015 L
s
.5703 .68668 m
.56866 .68259 L
s
.5606 .67015 m
.55881 .66826 L
s
.57051 .68848 m
.5703 .68668 L
s
.55881 .66826 m
.55666 .66677 L
s
.56982 .68935 m
.57051 .68848 L
s
.55666 .66677 m
.55594 .66759 L
s
.55594 .66759 m
.55612 .66936 L
s
.55612 .66936 m
.55775 .67346 L
s
.57547 .70087 m
.57313 .69762 L
s
.57803 .70597 m
.57547 .70087 L
s
.57313 .69762 m
.57189 .69713 L
s
.5797 .71014 m
.57803 .70597 L
s
.55775 .67346 m
.55975 .67716 L
s
.55975 .67716 m
.56265 .68181 L
s
.57189 .69713 m
.5721 .69896 L
s
.58048 .7134 m
.5797 .71014 L
s
.5721 .69896 m
.57399 .70499 L
s
.57925 .71293 m
.58048 .7134 L
s
.56469 .68958 m
.56595 .69009 L
s
.59267 .73344 m
.58016 .72046 L
s
.56544 .6928 m
.56469 .68958 L
s
.57399 .70499 m
.5742 .70685 L
s
.5742 .70685 m
.57296 .70637 L
s
.56711 .69699 m
.56544 .6928 L
s
.57296 .70637 m
.57205 .70543 L
s
.56968 .70214 m
.56711 .69699 L
s
.57205 .70543 m
.56968 .70214 L
s
.57529 .71624 m
.57564 .71577 L
s
.57564 .71577 m
.57417 .71341 L
s
.57417 .71341 m
.57382 .71388 L
s
.57382 .71388 m
.57529 .71624 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0400oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0]0?ooo`<000009@3oool00`00
0000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0400
oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0Z0?ooo`<00000:03oool00`000000
oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo03l0oooo
0P000?mC0?ooo`030000003oool0oooo02L0oooo0`00000[0?ooo`030000003oool0oooo01T0oooo
000]0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0?`3oool20000oe80oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0n0?ooo`80003oDP3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo03d0oooo00<0003o0?ooo`000?l0D@3oool00`000000oooo0?ooo`0N0?oo
o`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo03d0oooo00<0003o0?ooo`000?l0D@3oool00`000000oooo0?ooo`0J0?ooo`<0
0000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo03d0oooo00<0003o0?ooo`000?l0D03oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0?03o
ool010000?l0oooo0?ooo`000?m?0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0k0?ooo`80003o00<0
oooo0000o`3oool0CP3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?oo
o`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo03/0oooo0P000?l0
0`3oool0003o0?ooo`1=0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0>`3oool30000
odh0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0j0?ooo`<0003oCP3oool00`000000
oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo03X0oooo0P000?m>0?ooo`030000003oool0oooo00@0oooo
0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<0
00000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`1<0?ooo`040000003oool0oooo0?ooo`<00000
DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003o
ool0oooo03X0oooo00<0003o0?ooo`3oool0B`3oool4000005D0oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0
003o04/0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0=P3oool30000odP0oooo0`0000020?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000
oooo0?ooo`0f0?ooo`<0003oA03oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo
0000o`110?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0000
o`0n0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q
0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03D0oooo00<0003o
0?ooo`000?l0>P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0=@3oool00`000?l0oooo0000o`0f0?ooo`<000004@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`0e0?ooo`80003o<`3oool3000001@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0?ooo`0^
0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0b
0?ooo`040000o`3oool0oooo0000ob`0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0<P3oool00`000?l0oooo0?ooo`0Y0?ooo`<000007P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool0<@3oool30000obD0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0a0?ooo`03
0000o`3oool0003o0240oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0a0?ooo`030000
o`3oool0oooo01d0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo0300oooo0P000?lK0?ooo`<00000:`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3oool05P3oool3
000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`00
0000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0<03oool00`00
0?l0oooo0?ooo`0B0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0`0?ooo`030000o`3oool0oooo00h0oooo0`00000d0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`0;0?ooo`<00000=`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0;03oool20000o`030?ooo`000?l0oooo00P0oooo0`00000j0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0[0?ooo`030000o`3oool0003o00L0oooo0`00000m0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`0[0?ooo`040000o`3oool0003o0000o`80oooo0`0000100?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0Z0?ooo`040000o`3oool0oooo0000o`800000@`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?oo
o`3oool0:@3oool01@000000003o0000003oool0003o04@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool30000
0080oooo0P000?l00`3oool0003o0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<0
00001P3oool00`000?l0oooo0000o`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000
203oool30000o`030?ooo`000?l0oooo0480oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
000=0?ooo`80003o00<0oooo0000o`3oool0@P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
00000140oooo00<0003o0?ooo`000?l0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool30000
01D0oooo0`000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<00000603oool30000od80
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000L0?ooo`80003o@P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0103oool300000200oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool00`00000S0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009@3oool00`00
0?l0oooo0000o`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo0P00002=0?ooo`030000003oool0oooo02@0oooo0`000?m00?ooo`800000F`3oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo
0P000?ln0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0000
o`0i0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool20000ocH0oooo0`00000:
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`040000o`3oool0003o0000oc80oooo0`00000>
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`040000o`3oool0003o0000obh0oooo0`00000B
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`80003o00<0oooo0000o`3oool0:@3oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo0`000?lV0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0000o`0S0?ooo`<000007P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool09`3oool20000ob40oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X
0?ooo`<0003o703oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0000o`0I0?oo
o`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0?ooo`000?lD0?oo
o`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool010000?l0oooo0?ooo`000?l@0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool30000o`d0oooo0`00000f0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0/0?ooo`80003o2P3oool3000003X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02/0oooo00<0003o0?ooo`000?l01`3oool3000003h0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02`0oooo00<0003o0?ooo`3oool00P3oool400000480oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02d0oooo00@0003o0000000000000000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
00030000o`3oool0oooo04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`0000030?ooo`03
0000o`3oool0oooo04P0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000L0oooo00<0003o0?ooo`3oool0
B03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03o
ool00`000000oooo0?ooo`0Q0?ooo`@00000203oool010000?l0oooo0?ooo`000?m:0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0N0?ooo`<000003@3oool010000?l0oooo0000o`000?m:0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool06`3oool300000140oooo10000?m90?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000F0?ooo`030000o`3o
ool0oooo04T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3
000001L0oooo00<0003o0?ooo`000?l0C03oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0140oooo1000000K0?ooo`030000o`3oool0oooo04`0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool03P3oool300000200oooo00<0003o0?ooo`3oool0C03oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000S0?ooo`030000o`3oool0oooo04`0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00P0oooo0`00000W0?ooo`030000o`3oool0oooo04`0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00@0oooo1000000Y0?ooo`<0003oCP3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?oo
o`3oool0oooo0`00000]0?ooo`030000o`3oool0003o04l0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000a0?ooo`80003o00<0oooo0000
o`000?l0C@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`80
0000T03oool3000003@0oooo00D0003o0?ooo`000?l0oooo0000o`1=0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080
oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0000o`1?0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo
00<000000?ooo`3oool0=03oool20000oe00oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?oo
o`0f0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0g
0?ooo`030000o`3oool0oooo04h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0d0?oo
o`@0003oD@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0
DP3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo03H0oooo00@0003o0?ooo`000?l0003o
DP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo03H0oooo00@0003o0?ooo`000?l0003o
D`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo03L0oooo0`000?mD0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`0h0?ooo`<0003oD`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
03T0oooo0P000?mD0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0>`3oool00`000?l0
oooo0?ooo`1B0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo
0000o`1E0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0>@3oool20000oeL0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0>`3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3o
ool0?03oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
?@3oool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0?P3o
ool00`000?l0oooo0?ooo`1E0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0?`3oool0
0`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0@03oool00`00
0?l0oooo0?ooo`1D0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.45524 .49111 m
.46031 .49754 L
s
.45524 .49111 m
.43693 .47096 L
s
.46031 .49754 m
.46164 .49936 L
s
.46164 .49936 m
.46137 .49931 L
s
.46137 .49931 m
.46037 .49833 L
s
.46037 .49833 m
.45849 .4964 L
s
.442 .47739 m
.43693 .47096 L
s
.45849 .4964 m
.45413 .4916 L
s
.45413 .4916 m
.45077 .48778 L
s
.46451 .50388 m
.45224 .4904 L
s
.44506 .48113 m
.442 .47739 L
s
.45077 .48778 m
.44828 .48492 L
s
.44828 .48492 m
.44506 .48113 L
s
.46586 .50574 m
.46821 .50857 L
s
.46263 .50194 m
.46586 .50574 L
s
.45927 .49813 m
.46263 .50194 L
s
.46821 .50857 m
.47044 .5114 L
s
.47555 .51803 m
.47231 .51421 L
s
.47793 .5209 m
.47555 .51803 L
s
.47231 .51421 m
.46893 .51038 L
s
.48019 .52377 m
.47793 .5209 L
s
.46893 .51038 m
.46718 .50846 L
s
.48083 .52473 m
.48019 .52377 L
s
.46718 .50846 m
.46529 .50651 L
s
.4806 .52473 m
.48083 .52473 L
s
.48322 .52761 m
.47092 .51412 L
s
.46529 .50651 m
.46502 .50647 L
s
.46502 .50647 m
.46564 .50741 L
s
.48855 .53437 m
.47931 .52477 L
s
.46564 .50741 m
.4679 .51028 L
s
.4679 .51028 m
.47029 .51317 L
s
.47029 .51317 m
.47357 .51703 L
s
.49469 .54216 m
.48547 .5326 L
s
.49469 .54216 m
.47931 .52477 L
s
.50089 .55002 m
.48547 .5326 L
s
.51394 .56566 m
.51063 .56176 L
s
.51638 .5686 m
.51394 .56566 L
s
.51063 .56176 m
.5081 .55886 L
s
.51955 .57261 m
.51638 .5686 L
s
.5081 .55886 m
.5047 .555 L
s
.5047 .555 m
.50032 .55021 L
s
.52027 .57367 m
.51955 .57261 L
s
.52012 .57379 m
.52027 .57367 L
s
.50032 .55021 m
.49846 .54831 L
s
.51917 .5729 m
.52012 .57379 L
s
.49846 .54831 m
.49748 .54738 L
s
.49748 .54738 m
.49728 .54744 L
s
.5082 .5602 m
.51217 .56524 L
s
.49728 .54744 m
.49797 .54847 L
s
.49797 .54847 m
.50113 .55248 L
s
.52223 .57708 m
.50989 .5636 L
s
.50952 .56235 m
.51217 .56524 L
s
.50696 .55941 m
.50952 .56235 L
s
.50113 .55248 m
.5036 .55546 L
s
.52376 .57918 m
.52625 .58218 L
s
.5204 .57523 m
.52376 .57918 L
s
.51696 .57133 m
.5204 .57523 L
s
.5036 .55546 m
.50696 .55941 L
s
.52625 .58218 m
.52867 .58525 L
s
.5343 .59255 m
.53092 .58857 L
s
.53682 .59558 m
.5343 .59255 L
s
.53092 .58857 m
.52747 .58466 L
s
.53928 .5987 m
.53682 .59558 L
s
.52747 .58466 m
.52571 .58273 L
s
.54005 .59983 m
.53928 .5987 L
s
.52571 .58273 m
.52387 .58087 L
s
.53994 .60001 m
.54005 .59983 L
s
.54257 .60288 m
.53022 .58942 L
s
.52387 .58087 m
.52373 .58101 L
s
.52373 .58101 m
.52447 .58212 L
s
.54837 .61024 m
.52977 .58998 L
s
.52447 .58212 m
.52693 .58524 L
s
.54916 .6114 m
.55171 .61447 L
s
.54574 .60737 m
.54916 .6114 L
s
.52693 .58524 m
.52946 .5883 L
s
.55171 .61447 m
.55422 .61765 L
s
.52946 .5883 m
.53289 .59232 L
s
.55422 .61765 m
.55503 .61883 L
s
.55503 .61883 m
.55496 .61906 L
s
.53858 .59987 m
.53869 .59969 L
s
.57131 .63822 m
.55286 .61816 L
s
.55496 .61906 m
.55316 .61726 L
s
.53936 .60102 m
.53858 .59987 L
s
.55316 .61726 m
.5514 .61534 L
s
.54187 .60421 m
.53936 .60102 L
s
.5514 .61534 m
.5479 .61138 L
s
.54444 .60731 m
.54187 .60421 L
s
.5479 .61138 m
.54444 .60731 L
s
.5669 .63389 m
.56948 .63701 L
s
.5617 .62778 m
.5669 .63389 L
s
.56948 .63701 m
.57206 .64027 L
s
.57206 .64027 m
.5729 .64151 L
s
.58855 .65991 m
.58681 .65786 L
s
.58855 .66007 m
.58855 .65991 L
s
.58681 .65786 m
.58681 .65802 L
s
.5729 .64151 m
.57113 .63974 L
s
.58681 .65802 m
.58855 .66007 L
s
.57113 .63974 m
.56228 .63013 L
s
.58158 .65235 m
.56922 .63894 L
s
.58946 .66251 m
.58595 .65837 L
s
.5921 .6657 m
.58946 .66251 L
s
.58595 .65837 m
.58243 .6544 L
s
.59476 .66906 m
.5921 .6657 L
s
.58243 .6544 m
.58066 .65248 L
s
.59566 .67037 m
.59476 .66906 L
s
.58066 .65248 m
.57889 .65072 L
s
.59568 .67072 m
.59566 .67037 L
s
.57889 .65072 m
.57887 .65103 L
s
.57887 .65103 m
.57975 .6523 L
s
.57975 .6523 m
.5824 .65568 L
s
.6037 .68057 m
.60105 .67753 L
s
.60728 .68494 m
.6037 .68057 L
s
.60105 .67753 m
.60019 .67676 L
s
.60999 .68837 m
.60728 .68494 L
s
.5824 .65568 m
.58507 .65889 L
s
.58507 .65889 m
.58862 .66308 L
s
.60019 .67676 m
.60111 .67809 L
s
.61183 .69088 m
.60999 .68837 L
s
.60111 .67809 m
.60474 .68287 L
s
.61098 .69013 m
.61183 .69088 L
s
.59311 .66911 m
.59399 .66989 L
s
.62702 .70883 m
.61477 .69561 L
s
.59492 .67157 m
.59311 .66911 L
s
.60474 .68287 m
.60567 .68422 L
s
.60567 .68422 m
.60481 .68346 L
s
.59763 .67501 m
.59492 .67157 L
s
.60481 .68346 m
.60393 .6825 L
s
.60124 .67943 m
.59763 .67501 L
s
.60393 .6825 m
.60124 .67943 L
s
.61038 .69103 m
.61035 .69083 L
s
.61035 .69083 m
.60854 .6887 L
s
.60854 .6887 m
.60857 .68891 L
s
.60857 .68891 m
.61038 .69103 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0/0?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0/0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0[0?ooo`80003oGP3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02/0oooo0P00
0?mM0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0:`3oool20000oe`0oooo00@00000
0?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool0:`3oool20000oe/0oooo1000001E0?ooo`030000003oool0
oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0:P3oool30000
oeP0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool0:P3oool20000oeD0oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`0Z0?ooo`80003oD@3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0:`3oool20000odd0oooo0`00
00080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo04P0oooo0`00000;
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`140?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0Z0?oo
o`80003o@P3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0:P3oool20000och0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0>@3oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0:@3oool20000ocL0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0:@3oool20000oc<0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`0Y0?ooo`80003o;P3oool400000240oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo02T0oooo0P000?lZ0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`0U0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo
0240oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0:@3oool00`000?l0
oooo0?ooo`0M0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0X0?ooo`80003o6`3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0F0?ooo`<00000=03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool04P3oool3000003L0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool03P3oool3000003X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo02P0oooo00<0003o0?ooo`3oool02P3oool3000003d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo02L0oooo0P000?l80?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool09`3o
ool20000o`@0oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
000000800000AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`80000000<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool08@3oool300000080oooo00<0003o0?ooo`3oool0A`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool4000000H0oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0603oool3000000/0oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0503oool3000000l0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000001<0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000001L0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
203oool3000001X0oooo0P000?m40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007P3o
ool20000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool00`000?l0oooo0?ooo`11
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0S03oool2000002D0oooo0P000?m20?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo02D0oooo0P000?m00?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02D0oooo0P000?lm0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3o
ool20000ocP0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0W0?ooo`80003o=03oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo0P000?l`0?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:@3oool20000ob`0oooo0`00000B0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0Y0?ooo`80003o:@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo0P00
0?lT0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0O
0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0K0?oo
o`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0;@3oool20000oaP0oooo0`00000V0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000
003oool0oooo02d0oooo00<0003o0?ooo`000?l0503oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02h0oooo0`000?l?0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<03oool2
0000o``0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo
00L0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00<0
oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0000000800000
?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02h0oooo0`0000030?ooo`80003o@P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
00L0oooo0P000?m10?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000002`3oool20000od40
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo
00<000000?ooo`3oool09@3oool3000000l0oooo0P000?m10?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000
000C0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000H
0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000703oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01P0oooo0`00000O0?ooo`80003o@@3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000008P3oool20000od80oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0A0?ooo`@000009P3oool00`000?l0oooo0000o`110?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000[0?ooo`80003o@P3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000_0?ooo`80003o@@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0203oool3000003@0oooo00<0003o0?ooo`3oool0?`3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0103oool4000003L0oooo00<0003o0?ooo`3oool0@03oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00000k0?ooo`80003o@P3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000003l0oooo00<0003o0?ooo`3oool0
@@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03o
ool3000004<0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0
oooo0440oooo0P000?m20?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0@P3oool20000
od80oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000
oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`130?ooo`80003o@P3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo
0`00000<0?ooo`030000003oool0oooo04@0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00
000?0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo04H0oooo0P000?m20?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0
@@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo04X0oooo0P000?m20?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`1=0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00
000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`00
7@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3o
ool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000
oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00
001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3o
ool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0
oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00
001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3o
ool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0
oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo
0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo
0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?oo
o`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo
100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0
oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo
000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?oo
o`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00
=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`03
0000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00
>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool0
0`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool0
0400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[
0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000
003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool20000
00030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000
003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool01000
0000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo
0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0
oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo
0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@00000
0?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?oo
o`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`00
0000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool200000003
0?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00
HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2
000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0
oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0
oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P00
00130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3o
ool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0
]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03o
ool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool0
07@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0
oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo
0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00
000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00
000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X
0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo1000
00170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<0
00000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D
0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`03
0000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`03
0000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000
003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3o
ool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4
000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo
06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0
oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo
002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@
0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?oo
o`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`03
0000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3o
ool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03o
ool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool4
00000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool50000
0:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00
oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo
00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<0
00000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U
0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?oo
o`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`03
0000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool0
3@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo
002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000
003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42779 .51808 m
.43458 .52284 L
s
.42779 .51808 m
.40916 .49824 L
s
.43458 .52284 m
.43663 .52395 L
s
.43663 .52395 m
.43682 .52345 L
s
.43682 .52345 m
.43604 .52225 L
s
.43604 .52225 m
.43437 .52011 L
s
.41595 .50298 m
.40916 .49824 L
s
.43437 .52011 m
.42994 .51538 L
s
.42994 .51538 m
.42629 .51184 L
s
.44215 .52587 m
.42969 .51255 L
s
.41978 .50597 m
.41595 .50298 L
s
.42629 .51184 m
.42352 .50925 L
s
.42352 .50925 m
.41978 .50597 L
s
.44423 .52701 m
.4471 .52934 L
s
.44048 .52373 m
.44423 .52701 L
s
.43683 .52019 m
.44048 .52373 L
s
.4471 .52934 m
.45009 .53143 L
s
.45721 .53608 m
.45344 .53278 L
s
.46011 .53844 m
.45721 .53608 L
s
.45344 .53278 m
.44977 .52923 L
s
.46313 .54055 m
.46011 .53844 L
s
.44977 .52923 m
.448 .52732 L
s
.46428 .54102 m
.46313 .54055 L
s
.448 .52732 m
.44633 .52516 L
s
.46454 .54054 m
.46428 .54102 L
s
.46718 .54339 m
.45476 .53002 L
s
.44633 .52516 m
.44655 .52464 L
s
.44655 .52464 m
.44767 .52508 L
s
.47432 .54838 m
.466 .53786 L
s
.44767 .52508 m
.4507 .5272 L
s
.4507 .5272 m
.45362 .52957 L
s
.45362 .52957 m
.45744 .53291 L
s
.48254 .55413 m
.47427 .54363 L
s
.48254 .55413 m
.466 .53786 L
s
.49083 .55993 m
.47427 .54363 L
s
.50655 .57294 m
.5027 .56958 L
s
.50953 .57536 m
.50655 .57294 L
s
.5027 .56958 m
.4999 .56695 L
s
.51375 .57833 m
.50953 .57536 L
s
.4999 .56695 m
.49622 .56337 L
s
.49622 .56337 m
.49181 .55859 L
s
.515 .57887 m
.51375 .57833 L
s
.51538 .57846 m
.515 .57887 L
s
.49181 .55859 m
.49021 .55645 L
s
.5147 .57731 m
.51538 .57846 L
s
.49021 .55645 m
.48948 .55526 L
s
.48948 .55526 m
.48981 .5548 L
s
.50236 .56596 m
.50768 .56967 L
s
.48981 .5548 m
.49103 .5553 L
s
.49103 .5553 m
.49526 .55826 L
s
.51937 .5799 m
.50701 .56645 L
s
.50502 .56679 m
.50768 .56967 L
s
.50218 .56412 m
.50502 .56679 L
s
.49526 .55826 m
.49828 .56071 L
s
.52172 .5812 m
.52475 .58366 L
s
.51781 .57778 m
.52172 .5812 L
s
.5141 .57416 m
.51781 .57778 L
s
.49828 .56071 m
.50218 .56412 L
s
.52475 .58366 m
.52799 .58593 L
s
.53582 .59106 m
.53188 .58762 L
s
.53888 .59354 m
.53582 .59106 L
s
.53188 .58762 m
.52816 .58398 L
s
.54217 .59585 m
.53888 .59354 L
s
.52816 .58398 m
.52639 .58205 L
s
.54349 .59643 m
.54217 .59585 L
s
.52639 .58205 m
.52483 .57992 L
s
.54395 .59606 m
.54349 .59643 L
s
.54657 .59893 m
.53426 .58544 L
s
.52483 .57992 m
.52525 .57951 L
s
.52525 .57951 m
.52655 .58007 L
s
.55433 .60435 m
.5358 .58403 L
s
.52655 .58007 m
.52985 .58236 L
s
.55568 .60495 m
.55879 .60747 L
s
.55171 .60148 m
.55568 .60495 L
s
.52985 .58236 m
.53294 .58487 L
s
.55879 .60747 m
.56215 .60982 L
s
.53294 .58487 m
.53691 .58835 L
s
.56215 .60982 m
.56352 .61044 L
s
.56352 .61044 m
.56403 .61009 L
s
.54515 .59338 m
.54468 .59377 L
s
.58289 .62678 m
.56458 .60658 L
s
.56403 .61009 m
.56254 .60799 L
s
.5465 .59397 m
.54515 .59338 L
s
.56254 .60799 m
.56078 .60606 L
s
.54986 .59632 m
.5465 .59397 L
s
.56078 .60606 m
.55702 .60237 L
s
.553 .59886 m
.54986 .59632 L
s
.55702 .60237 m
.553 .59886 L
s
.57939 .62153 m
.58254 .62409 L
s
.57336 .61626 m
.57939 .62153 L
s
.58254 .62409 m
.58599 .6265 L
s
.58599 .6265 m
.58742 .62715 L
s
.60559 .64304 m
.60357 .64127 L
s
.6059 .6429 m
.60559 .64304 L
s
.60357 .64127 m
.60388 .64113 L
s
.58742 .62715 m
.58596 .62507 L
s
.60388 .64113 m
.6059 .6429 L
s
.58596 .62507 m
.57721 .61538 L
s
.59871 .6354 m
.5865 .62185 L
s
.60955 .64263 m
.60546 .63906 L
s
.61277 .64524 m
.60955 .64263 L
s
.60546 .63906 m
.60169 .63534 L
s
.61632 .64772 m
.61277 .64524 L
s
.60169 .63534 m
.59994 .6334 L
s
.61783 .64842 m
.61632 .64772 L
s
.59994 .6334 m
.5985 .63131 L
s
.61848 .64815 m
.61783 .64842 L
s
.5985 .63131 m
.59911 .63101 L
s
.59911 .63101 m
.60059 .63168 L
s
.60059 .63168 m
.60415 .63416 L
s
.62857 .65593 m
.62565 .65316 L
s
.63304 .65942 m
.62857 .65593 L
s
.62565 .65316 m
.62512 .65207 L
s
.63666 .66195 m
.63304 .65942 L
s
.60415 .63416 m
.6074 .63679 L
s
.6074 .63679 m
.61153 .6404 L
s
.62512 .65207 m
.62666 .65278 L
s
.63943 .66353 m
.63666 .66195 L
s
.62666 .65278 m
.63183 .65603 L
s
.63892 .66245 m
.63943 .66353 L
s
.61817 .6443 m
.61871 .64541 L
s
.65723 .67887 m
.64525 .6654 L
s
.62091 .64584 m
.61817 .6443 L
s
.63183 .65603 m
.63339 .65676 L
s
.63339 .65676 m
.63288 .65566 L
s
.62454 .64837 m
.62091 .64584 L
s
.63288 .65566 m
.63201 .65469 L
s
.62905 .65188 m
.62454 .64837 L
s
.63201 .65469 m
.62905 .65188 L
s
.64128 .66041 m
.64092 .66053 L
s
.64092 .66053 m
.63882 .6587 L
s
.63882 .6587 m
.63918 .65858 L
s
.63918 .65858 m
.64128 .66041 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo05l0oooo0`00
00080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0H0?ooo`80003oG03oool3000000/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`0H0?ooo`80003oF03oool3000000h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0603oool20000oe@0oooo0`00000A0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01P0oooo0`000?m?0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0H0?oo
o`040000o`3oool0003o0000odX0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo01P0oooo00@0003o0?ooo`000?l0003oAP3oool3000001/0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`0H0?ooo`040000o`3oool0003o0000od80oooo0`00
000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<00000
0?ooo`3oool0L@3oool00`000000oooo0?ooo`0H0?ooo`@0003o?@3oool400000240oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo01T0oooo0`000?li0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3o
ool06P3oool40000oc<0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo01X0oooo00@0003o0?ooo`000?l0
003o;`3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0J0?ooo`@0003o
:`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3o
ool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0703o
ool20000obL0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo01`0oooo0P000?lS0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
01`0oooo0P000?l00`3oool0003o0?ooo`0L0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0703oool20000o`030?ooo`000?l0oooo01P0oooo0`00000j0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`0M0?ooo`@0003o503oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo01h0oooo0`00
0?l@0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool07P3oool30000o``0oooo0`000013
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`0O0?ooo`80003o203oool3000004H0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3o
ool07`3oool40000o`80oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0P0?ooo`@0003o
C03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0703oool400000080003o00<0oooo0000o`3oool0B`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08@0oooo00<000000?ooo`3oool0603oool3000000H0oooo00<0003o0?ooo`000?l0B`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0503oool3000000T0oooo00<0003o0?ooo`000?l00P000?m90?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000003@3oool01@000?l0oooo0000o`3oool0003o
04P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000A0?ooo`050000o`3oool0003o0?oo
o`000?l0A`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001D0oooo0P000?l20?ooo`03
0000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000J0?ooo`040000
o`3oool0003o0000odD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000007P3oool40000o`030?oo
o`000?l0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`800000903oool010000?l0oooo0000o`000?m10?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003o
ool0oooo02@0oooo1P000?lm0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0oooo1@000?li0?ooo`<000000P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0:03oool40000oc@0oooo100000060?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0Y0?ooo`@0003o<03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo
10000?l[0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;03oool40000obL0oooo0`00
000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0_0?ooo`80003o8`3oool3000001H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02l0oooo0`000?lN0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0<03oool010000?l0oooo0000o`000?lI0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0<@3oool010000?l0oooo0000o`000?lE0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0<P3oool20000o`030?ooo`000?l0oooo0100oooo0`00000V0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo03H0oooo
00<0003o0?ooo`3oool02`3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03H0oooo0`00
0?l70?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool30000o`<0oooo0`00000c
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0i0?ooo`80003o0`00000f0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0h0?ooo`<000000P000?l00`3oool0003o0?ooo`0e0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0e0?ooo`<000000`3oool30000o`030?ooo`000?l0oooo03D0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0340oooo1000000:0?ooo`030000o`3oool0003o03D0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02h0oooo0`00000?0?ooo`<0003o=@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
01<0oooo0`000?ld0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000603oool20000oc@0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo
00<000000?ooo`3oool09@3oool3000001/0oooo10000?lc0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000
000O0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<000009@3oool010000?l0oooo0?ooo`000?lb0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool06`3oool3000002T0oooo1@000?l`0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01P0oooo0`00000`0?ooo`80003o<03oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000<`3oool40000obl0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000=`3oool30000oc00oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000003`0oooo0P000?l00`3oool0003o
0000o`0^0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`00
00050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000440oooo0P00
0?l_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000A@3oool010000?l0oooo0?ooo`00
0?l]0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000C03oool00`000?l0oooo0?ooo`0[
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0T03oool010000000oooo0?ooo`3oool300000540oooo00<0003o0?ooo`3oool0:`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool40000
05@0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`800000T03oool3000005P0oooo00<0003o0?ooo`3oool0:`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo
0`0000020?ooo`030000003oool0oooo05L0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo1000
00050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?oo
o`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03o
ool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000
000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3o
ool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`00
0000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0
oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03o
ool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<00000
0?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3o
ool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`00
0000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<00000
0?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<0
0000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0
[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?oo
o`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?oo
o`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?oo
o`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
1P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool0
01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P000024
0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`06
0?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`03
0000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000
O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
1@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool20000
07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo
000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0
oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool20000
07<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo
0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D0
00000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3o
ool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo
0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`00
0000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?oo
o`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo
00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?oo
o`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?oo
o`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool0
0000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3o
ool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?oo
o`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000
oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool20000
04/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo
00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P000002
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?oo
o`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`03
0000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4
000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool50000
02<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g
0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?oo
o`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`03
0000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000
003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00
J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`00
0000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000
;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0
oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0
oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo
07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0
oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo
00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00
001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000
001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000
703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3o
ool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0
oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0
oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0
oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo
002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U
0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?oo
o`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?oo
o`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3o
ool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000
003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D0
0000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103o
ool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0
oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool40000
0<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`04
0000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00
[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D0
00000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.40475 .54832 m
.413 .55121 L
s
.40475 .54832 m
.3858 .52877 L
s
.413 .55121 m
.41566 .55152 L
s
.41566 .55152 m
.41625 .5505 L
s
.41625 .5505 m
.41565 .54906 L
s
.41565 .54906 m
.41415 .54668 L
s
.41415 .54668 m
.40965 .54201 L
s
.39407 .53161 m
.3858 .52877 L
s
.40965 .54201 m
.40575 .53878 L
s
.42342 .55052 m
.41079 .53736 L
s
.39854 .53378 m
.39407 .53161 L
s
.40575 .53878 m
.40274 .53649 L
s
.40274 .53649 m
.39854 .53378 L
s
.42613 .55084 m
.42943 .55261 L
s
.42193 .54814 m
.42613 .55084 L
s
.41803 .54491 m
.42193 .54814 L
s
.42943 .55261 m
.43306 .55387 L
s
.44188 .55632 m
.43766 .55359 L
s
.44522 .5581 m
.44188 .55632 L
s
.43766 .55359 m
.43375 .55035 L
s
.44889 .55938 m
.44522 .5581 L
s
.43375 .55035 m
.43195 .54846 L
s
.45046 .55929 m
.44889 .55938 L
s
.43195 .54846 m
.43046 .54604 L
s
.45113 .55827 m
.45046 .55929 L
s
.45381 .56109 m
.44125 .54784 L
s
.43046 .54604 m
.4311 .54499 L
s
.4311 .54499 m
.43264 .54488 L
s
.46246 .5641 m
.45491 .55253 L
s
.43264 .54488 m
.43632 .54614 L
s
.43632 .54614 m
.43969 .54794 L
s
.43969 .54794 m
.44396 .55069 L
s
.47242 .56756 m
.46494 .55598 L
s
.47242 .56756 m
.45491 .55253 L
s
.48247 .57105 m
.46494 .55598 L
s
.50042 .58112 m
.49612 .57835 L
s
.50384 .58296 m
.50042 .58112 L
s
.49612 .57835 m
.49309 .57602 L
s
.50895 .58474 m
.50384 .58296 L
s
.49309 .57602 m
.48917 .57275 L
s
.48917 .57275 m
.48474 .56799 L
s
.51064 .5847 m
.50895 .58474 L
s
.51146 .5837 m
.51064 .5847 L
s
.48474 .56799 m
.48334 .56557 L
s
.511 .58226 m
.51146 .5837 L
s
.48334 .56557 m
.48283 .5641 L
s
.48283 .5641 m
.48359 .56305 L
s
.49751 .57242 m
.50395 .57464 L
s
.48359 .56305 m
.48526 .56297 L
s
.517 .58306 m
.50462 .56963 L
s
.48526 .56297 m
.49039 .56474 L
s
.50129 .57177 m
.50395 .57464 L
s
.49822 .5694 m
.50129 .57177 L
s
.52002 .58346 m
.52351 .58532 L
s
.51566 .58065 m
.52002 .58346 L
s
.49039 .56474 m
.49386 .56659 L
s
.51172 .57733 m
.51566 .58065 L
s
.49386 .56659 m
.49822 .5694 L
s
.52351 .58532 m
.52742 .58668 L
s
.53706 .58938 m
.53268 .58655 L
s
.54058 .59126 m
.53706 .58938 L
s
.53268 .58655 m
.52872 .58322 L
s
.54455 .59264 m
.54058 .59126 L
s
.52872 .58322 m
.52696 .58129 L
s
.54634 .59261 m
.54455 .59264 L
s
.52696 .58129 m
.52563 .57885 L
s
.54726 .59161 m
.54634 .59261 L
s
.54987 .59449 m
.53759 .58097 L
s
.52563 .57885 m
.52651 .57783 L
s
.52651 .57783 m
.52827 .57777 L
s
.55924 .59774 m
.54078 .57735 L
s
.52827 .57777 m
.53226 .57914 L
s
.56106 .59772 m
.56462 .59962 L
s
.55663 .59486 m
.56106 .59772 L
s
.56462 .59962 m
.56867 .60102 L
s
.53226 .57914 m
.53581 .58103 L
s
.53581 .58103 m
.54024 .58389 L
s
.56867 .60102 m
.57051 .601 L
s
.57051 .601 m
.57149 .60002 L
s
.55056 .58611 m
.54963 .58712 L
s
.59239 .6139 m
.57422 .59357 L
s
.57149 .60002 m
.57025 .59759 L
s
.55238 .58606 m
.55056 .58611 L
s
.57025 .59759 m
.56851 .59565 L
s
.55645 .58746 m
.55238 .58606 L
s
.56851 .59565 m
.56452 .59226 L
s
.56005 .58937 m
.55645 .58746 L
s
.56452 .59226 m
.56005 .58937 L
s
.58964 .60765 m
.59326 .60957 L
s
.58293 .60332 m
.58964 .60765 L
s
.59326 .60957 m
.5974 .61101 L
s
.5974 .61101 m
.59932 .61101 L
s
.61953 .62406 m
.61728 .62261 L
s
.62008 .62358 m
.61953 .62406 L
s
.61728 .62261 m
.61783 .62213 L
s
.59932 .61101 m
.59813 .60858 L
s
.61783 .62213 m
.62008 .62358 L
s
.59813 .60858 m
.58946 .59881 L
s
.61272 .61634 m
.60066 .60266 L
s
.62596 .62027 m
.62142 .61734 L
s
.62965 .62222 m
.62596 .62027 L
s
.62142 .61734 m
.61744 .61392 L
s
.63391 .62371 m
.62965 .62222 L
s
.61744 .61392 m
.61572 .61196 L
s
.63591 .62373 m
.63391 .62371 L
s
.61572 .61196 m
.61455 .6095 L
s
.63707 .62277 m
.63591 .62373 L
s
.61455 .6095 m
.61566 .60851 L
s
.61566 .60851 m
.61764 .6085 L
s
.64883 .62821 m
.6457 .62576 L
s
.65401 .6307 m
.64883 .62821 L
s
.61764 .6085 m
.62192 .60998 L
s
.6457 .62576 m
.64544 .6243 L
s
.65836 .63221 m
.65401 .6307 L
s
.62192 .60998 m
.62565 .61195 L
s
.62565 .61195 m
.63024 .61491 L
s
.64544 .6243 m
.64748 .62432 L
s
.66188 .63275 m
.65836 .63221 L
s
.64748 .62432 m
.65389 .62584 L
s
.66165 .63129 m
.66188 .63275 L
s
.68173 .64513 m
.67001 .63142 L
s
.63861 .61641 m
.63887 .61789 L
s
.6421 .61691 m
.63861 .61641 L
s
.65389 .62584 m
.65596 .62587 L
s
.65596 .62587 m
.65572 .62439 L
s
.64646 .61842 m
.6421 .61691 L
s
.65572 .62439 m
.65487 .6234 L
s
.6517 .62092 m
.64646 .61842 L
s
.65487 .6234 m
.6517 .62092 L
s
.6664 .62598 m
.66577 .62646 L
s
.66577 .62646 m
.66345 .62496 L
s
.66345 .62496 m
.66407 .62447 L
s
.66407 .62447 m
.6664 .62598 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
00D0oooo0P000?m60?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00D0
oooo0`000?m10?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`050?ooo`030000o`3oool0003o03d0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo00D0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0oooo
0?ooo`0c0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo00@0oooo00D0
003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo02l0oooo0`00000g0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80003o00<0oooo0000o`3oool0
;03oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo
0000o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool08P3oool3000003d0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1m0?ooo`030000003oool0oooo00@0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`80
oooo00<0003o0?ooo`000?l00P000?lN0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
103oool20000o`80oooo00@0003o0?ooo`000?l0003o0P3oool20000o`80oooo00<0003o0?ooo`3o
ool0603oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo00D0oooo0`000?l20?ooo`<0003o
00<0oooo0000o`3oool00P3oool010000?l0oooo0?ooo`000?lC0?ooo`<00000AP3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo
0?ooo`0<0?ooo`030000o`3oool0003o00<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0
oooo0?ooo`0:0?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool03P3oool30000o`030?oo
o`000?l0oooo0080003o0P3oool00`000?l0oooo0?ooo`060?ooo`<00000C03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<0
00000?ooo`3oool0403oool30000o`030?ooo`000?l0003o00<0003o0`3oool400000500oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`000?l00`000?l010000000oooo0000o`00
0?mA0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`80000000L0003o0?ooo`3oool0003o0?oo
o`000?l0oooo00<0003oCP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000000<0oooo00H0
003o0?ooo`3oool0003o0?ooo`000?l30?ooo`80003oC03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
303oool3000000X0oooo0P000?l50?ooo`80003oBP3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203o
ool3000000l0oooo00<0003o0?ooo`3oool01@000?m90?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`04
0?ooo`<000004`3oool20000o`D0oooo0P000?l:0?ooo`030000o`3oool0oooo03X0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo00<00000603oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo0`000?l40?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000703oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`020000o`80oooo00<0003o
0?ooo`3oool0>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`800000S@3oool00`000000oooo0?ooo`0L0?ooo`D0003o00H0oooo0000o`000?l0003o0?ooo`00
0?l30?ooo`040000o`3oool0oooo0000ocT0oooo0P00001K0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool30000o`<0oooo00<0
003o0?ooo`3oool00`000?lc0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool2
0000o`80oooo00D0003o0?ooo`3oool0003o0?ooo`020000obd0oooo100000060?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0Z0?ooo`@0003o00<0oooo0000o`3oool00P3oool01@000?l0oooo0?ooo`3o
ool0003o02D0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0
003o00<0oooo0P000?l20?ooo`030000o`3oool0oooo01l0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0a0?ooo`80003o0`3oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0
oooo01L0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0c0?ooo`@0003o0`3oool01@00
0?l0oooo0?ooo`3oool0003o01D0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0j0?oo
o`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0<0?ooo`@000006P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool20000o`80oooo00@0003o0?ooo`3oool0003o2P3oool3
000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03`0oooo0`000?l01@3oool0003o0?ooo`3oool0
003o0080oooo0P000?l20?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0?@3oool01000
0?l0oooo0000o`000?l20?ooo`040000o`3oool0oooo0000o`<0000000<0003o0?ooo`3oool08`3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool0
0`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo00<0oooo0`00000010000?l0oooo0?ooo`3o
ool20000ob@0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo10000000103oool0003o0?ooo`3o
ool20000o`D0oooo0P000?lQ0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<000002P3oool0
0`000?l0oooo0?ooo`020?ooo`040000o`3oool0003o0000ob00oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo03/0oooo0`00000:0?ooo`040000o`3oool0oooo0?ooo`80003o00<0oooo0000o`3oool00`3o
ool20000oah0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000>0?ooo`030000o`3oool0
oooo0080oooo0P000?l30?ooo`80003o00@0oooo0000o`3oool0oooo0P000?lJ0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0e0?ooo`<00000703oool40000o`80oooo00<0003o0?ooo`3oool06@3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0<@3oool400000200oooo0P000?lP0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0^0?ooo`<000009P3oool30000o`80oooo00<0003o0?ooo`3oool06@3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0:`3oool3000002l0oooo00<0003o0?ooo`3oool0603oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:03oool3000003<0oooo00<0003o0?ooo`3oool0603oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U
0?ooo`<00000=P3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000j0?oo
o`030000o`3oool0oooo01T0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?oo
o`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000o0?ooo`03
0000o`3oool0oooo01T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000
GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003o
ool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000
HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo
0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@00000
0?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3o
ool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`00
00090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?oo
o`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`03
0000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3o
ool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo
00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00
000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3o
ool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0
oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440
oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`00
00180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3o
ool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0
oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<00000
0?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`03
0000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3o
ool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0
oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`00
0000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<00000
0?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@0
0000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo0007
0?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
00000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?oo
o`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?oo
o`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0
]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3o
ool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?oo
o`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<00000
0?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`03
0000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00
<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0
_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0
oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000
003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3o
ool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0
oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3o
ool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000
003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2
000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0
oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool2
00000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000
oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo
0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo
00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo
000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<00000
0?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?oo
o`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000
DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo
0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo
001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool20000
0080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo
100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=
0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3o
ool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool0
0`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo
0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0
oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo
1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g
0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?oo
o`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`04
0000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?oo
o`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?oo
o`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3o
ool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?oo
o`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00
P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3o
ool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0
oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0
000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`00
0000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo
00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?oo
o`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K
0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?oo
o`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00
TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3o
ool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`00
0000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000
oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo
0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?oo
o`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<00000
0?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?oo
o`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?oo
o`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?oo
o`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo
0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3o
ool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool0
0`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:
0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?oo
o`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.38701 .58074 m
.39641 .5816 L
s
.38701 .58074 m
.36774 .56145 L
s
.39641 .5816 m
.39955 .58106 L
s
.39955 .58106 m
.40044 .57948 L
s
.40044 .57948 m
.39999 .57777 L
s
.39999 .57777 m
.39862 .57514 L
s
.39862 .57514 m
.39405 .57052 L
s
.37719 .56226 m
.36774 .56145 L
s
.40906 .57691 m
.39626 .5639 L
s
.39405 .57052 m
.38994 .56762 L
s
.38218 .56354 m
.37719 .56226 L
s
.38994 .56762 m
.38674 .56564 L
s
.38674 .56564 m
.38218 .56354 L
s
.41226 .57636 m
.41591 .57753 L
s
.4077 .57426 m
.41226 .57636 L
s
.4036 .57136 m
.4077 .57426 L
s
.41591 .57753 m
.42004 .5779 L
s
.43019 .57796 m
.42561 .57585 L
s
.43387 .57914 m
.43019 .57796 L
s
.42561 .57585 m
.4215 .57293 L
s
.43804 .57951 m
.43387 .57914 L
s
.4215 .57293 m
.41968 .57106 L
s
.43993 .57883 m
.43804 .57951 L
s
.41968 .57106 m
.41833 .56837 L
s
.44093 .57721 m
.43993 .57883 L
s
.44363 .58001 m
.43095 .56687 L
s
.41833 .56837 m
.41928 .56673 L
s
.41928 .56673 m
.42116 .56603 L
s
.45345 .58089 m
.44647 .5682 L
s
.42116 .56603 m
.42535 .56639 L
s
.42535 .56639 m
.42906 .56757 L
s
.42906 .56757 m
.43368 .5697 L
s
.46475 .58191 m
.45786 .56917 L
s
.46475 .58191 m
.44647 .5682 L
s
.47614 .58293 m
.45786 .56917 L
s
.4958 .58986 m
.49116 .58772 L
s
.49956 .59106 m
.4958 .58986 L
s
.49116 .58772 m
.48795 .58571 L
s
.50534 .59159 m
.49956 .59106 L
s
.48795 .58571 m
.48386 .58276 L
s
.48386 .58276 m
.4794 .57803 L
s
.50737 .59092 m
.50534 .59159 L
s
.50852 .5893 m
.50737 .59092 L
s
.4794 .57803 m
.47816 .5753 L
s
.50822 .58754 m
.50852 .5893 L
s
.47816 .5753 m
.47781 .57352 L
s
.47781 .57352 m
.4789 .57186 L
s
.49387 .5793 m
.50115 .57994 L
s
.4789 .57186 m
.4809 .57115 L
s
.51523 .58644 m
.50283 .57303 L
s
.49848 .57707 m
.50115 .57994 L
s
.4809 .57115 m
.48672 .57165 L
s
.51875 .58588 m
.52258 .58709 L
s
.51405 .58371 m
.51875 .58588 L
s
.50994 .58072 m
.51405 .58371 L
s
.49524 .57503 m
.49848 .57707 L
s
.52258 .58709 m
.527 .58749 L
s
.48672 .57165 m
.49053 .57286 L
s
.49053 .57286 m
.49524 .57503 L
s
.53799 .5876 m
.53327 .58542 L
s
.54185 .58882 m
.53799 .5876 L
s
.53327 .58542 m
.52915 .58241 L
s
.54633 .58923 m
.54185 .58882 L
s
.52915 .58241 m
.52739 .58048 L
s
.54845 .58853 m
.54633 .58923 L
s
.52739 .58048 m
.52623 .57771 L
s
.54972 .58688 m
.54845 .58853 L
s
.55232 .58976 m
.54007 .57622 L
s
.52623 .57771 m
.52745 .57603 L
s
.52745 .57603 m
.52955 .57532 L
s
.56287 .59071 m
.54449 .57025 L
s
.52955 .57532 m
.53405 .5757 L
s
.56503 .59002 m
.56893 .59125 L
s
.56027 .58782 m
.56503 .59002 L
s
.56893 .59125 m
.57349 .59166 L
s
.53405 .5757 m
.53794 .57693 L
s
.53794 .57693 m
.54272 .57914 L
s
.57349 .59166 m
.57568 .59097 L
s
.57568 .59097 m
.57701 .5893 L
s
.59937 .60021 m
.58133 .57975 L
s
.55458 .57837 m
.5533 .58006 L
s
.57701 .5893 m
.57595 .58652 L
s
.55675 .57765 m
.55458 .57837 L
s
.57595 .58652 m
.57422 .58457 L
s
.56133 .57804 m
.55675 .57765 L
s
.57422 .58457 m
.57008 .58151 L
s
.56527 .57928 m
.56133 .57804 L
s
.57008 .58151 m
.56527 .57928 L
s
.59718 .59289 m
.60113 .59414 L
s
.58998 .58956 m
.59718 .59289 L
s
.60113 .59414 m
.60579 .59456 L
s
.60579 .59456 m
.60805 .59386 L
s
.62971 .60389 m
.6273 .60277 L
s
.63044 .60306 m
.62971 .60389 L
s
.6273 .60277 m
.62803 .60195 L
s
.60805 .59386 m
.60705 .59107 L
s
.62803 .60195 m
.63044 .60306 L
s
.60705 .59107 m
.59846 .58122 L
s
.62297 .5961 m
.61103 .5823 L
s
.63792 .59653 m
.63306 .59428 L
s
.64193 .5978 m
.63792 .59653 L
s
.63306 .59428 m
.62894 .59119 L
s
.64671 .59823 m
.64193 .5978 L
s
.62894 .59119 m
.62724 .58921 L
s
.64906 .59753 m
.64671 .59823 L
s
.62724 .58921 m
.62627 .58637 L
s
.65059 .59584 m
.64906 .59753 L
s
.62627 .58637 m
.62775 .58466 L
s
.62775 .58466 m
.63008 .58393 L
s
.66351 .59882 m
.66023 .5967 L
s
.66919 .60025 m
.66351 .59882 L
s
.66023 .5967 m
.66017 .59486 L
s
.63008 .58393 m
.63488 .58434 L
s
.67404 .60068 m
.66919 .60025 L
s
.63488 .58434 m
.63894 .58562 L
s
.66017 .59486 m
.66257 .59415 L
s
.67809 .60013 m
.67404 .60068 L
s
.63894 .58562 m
.64385 .58789 L
s
.66257 .59415 m
.66984 .59386 L
s
.69935 .60938 m
.68784 .59544 L
s
.67806 .59828 m
.67809 .60013 L
s
.65344 .58687 m
.65351 .58873 L
s
.66984 .59386 m
.67227 .59315 L
s
.65746 .58628 m
.65344 .58687 L
s
.67227 .59315 m
.67223 .59128 L
s
.66234 .5867 m
.65746 .58628 L
s
.67223 .59128 m
.67139 .59028 L
s
.66808 .58812 m
.66234 .5867 L
s
.67139 .59028 m
.66808 .58812 L
s
.6845 .58954 m
.68369 .5904 L
s
.68369 .5904 m
.6812 .58925 L
s
.6812 .58925 m
.68202 .58838 L
s
.68202 .58838 m
.6845 .58954 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo07P0oooo
0P000?l90?ooo`030000003oool0oooo01`0oooo1000001@0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0N@3oool50000o`D0oooo00<0
003o0000003oool06@3oool3000005@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`1j0?ooo`040000o`3oool0oooo0?ooo`80003o103o
ool00`000?l000000?ooo`040?ooo`<0003o3P3oool3000005L0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l000000?ooo`030?ooo`030000o`3oool0
oooo00<0003o103oool01`000?l0oooo0?ooo`3oool000000000o`000000FP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo07/0oooo00<0
003o0?ooo`3oool00`3oool20000o`80oooo00<0003o0?ooo`0000000`3oool00`000?l0oooo0?oo
o`020?ooo`80003o103oool20000o`040000003oool0003o0000o`D0oooo10000?lE0?ooo`030000
o`3oool0oooo03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`1l0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0oooo
0P000?l01@000000oooo0?ooo`3oool0003o00D0oooo00L0003o00000000000000000000o`3oool0
003o0080oooo0P000?l40?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`000?l0oooo0?oo
o`0>0?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`3oool0oooo10000?l20?ooo`80003o00D0oooo00000000000000000000o`030?ooo`070000
o`3oool0003o0?ooo`000?l0oooo0000o`030?ooo`030000o`3oool0oooo00<0oooo0`000?l00`3o
ool0003o0?ooo`070?ooo`D0003o0`3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0O`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<000000000o`3oool00P0000060000o`80
oooo00<0003o0?ooo`3oool00`000?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo0080
oooo10000?l00`3oool0003o0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`H0
003o1@3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0P03oool60000o`H0oooo0P00000;0?ooo`050000
o`3oool0oooo0?ooo`000?l00P3oool01@000?l0oooo0?ooo`3oool0003o00T0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0103oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0P0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo0P00002=0?ooo`030000003oool0oooo0180oooo00D0003o0?ooo`3oool0oooo0000o`09
0?ooo`80003o1@3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`80003o0`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool40000oaP0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool05`3oool20000o`D0oooo00<0003o0?ooo`3oool01@000?l3
0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`050000o`3o
ool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0000o`@0
oooo0`000?l30?ooo`H0003o2@3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01T0oooo
0P000?l30?ooo`030000o`3oool0oooo00T0oooo10000?l00`3oool0003o0?ooo`020?ooo`80003o
0`3oool00`000?l0oooo0?ooo`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`020?ooo`050000
o`3oool0oooo0?ooo`000?l02@3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?oo
o`000?l0100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0K0?ooo`<0003o5`3oool40000o`D0
oooo0`000?l20?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o403oool01000
0?l0000000000000000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo
00@0003o103oool00`000?l0oooo0?ooo`020000o`D0oooo00@0003o0?ooo`3oool0oooo0`000?l3
000000@0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?`3oool00`00
0?l0oooo0?ooo`0<0?ooo`H0003o0`3oool3000000@0oooo00D0003o0?ooo`3oool0oooo0000o`09
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`100?ooo`030000o`3oool0oooo0140oooo0`0000020?oo
o`H0003o103oool00`000?l0oooo0?ooo`070?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1;0?ooo`80
003o0`3oool400000100oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
C@3oool3000001D0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0BP3o
ool3000001T0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3
000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool20000
08l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400
oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3
000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool30000
08h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?oo
o`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<0
0000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4
000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool30000
02/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?oo
o`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3o
ool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool30000
04/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?oo
o`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0
oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00
002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00
001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0
oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo
0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0013
0?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00
B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;
0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003o
ool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo
0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?oo
o`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003o
ool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0
f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`00
0000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0
oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo
1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000
000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?oo
o`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`80
0000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0
oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo
0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0
oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0
oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0
oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo
0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M
0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q
0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?oo
o`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3
000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo
0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A
0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?oo
o`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000
003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303o
ool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03o
ool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2
000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo
0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool50000
0;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0
oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0
oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo
0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:
0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo0000
00H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo
0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37531 .61416 m
.38551 .61292 L
s
.37531 .61416 m
.35576 .59511 L
s
.38551 .61292 m
.38899 .61148 L
s
.38899 .61148 m
.39009 .60932 L
s
.39009 .60932 m
.38972 .60732 L
s
.38972 .60732 m
.38843 .60441 L
s
.38843 .60441 m
.38381 .59984 L
s
.36603 .5938 m
.35576 .59511 L
s
.39969 .60404 m
.38674 .59116 L
s
.38381 .59984 m
.37954 .59728 L
s
.40322 .60258 m
.40711 .60312 L
s
.39842 .60111 m
.40322 .60258 L
s
.37954 .59728 m
.3762 .59563 L
s
.40711 .60312 m
.41158 .60257 L
s
.39416 .59855 m
.39842 .60111 L
s
.37138 .59416 m
.36603 .5938 L
s
.3762 .59563 m
.37138 .59416 L
s
.42263 .60017 m
.4178 .5987 L
s
.42654 .60072 m
.42263 .60017 L
s
.43105 .60016 m
.42654 .60072 L
s
.4178 .5987 m
.41355 .59611 L
s
.43316 .59886 m
.43105 .60016 L
s
.41355 .59611 m
.41172 .59426 L
s
.41172 .59426 m
.41045 .59128 L
s
.43436 .59663 m
.43316 .59886 L
s
.43708 .59941 m
.4243 .58636 L
s
.41045 .59128 m
.41162 .58904 L
s
.44769 .5981 m
.44106 .58422 L
s
.41162 .58904 m
.41371 .58772 L
s
.41371 .58772 m
.41824 .58714 L
s
.45988 .59659 m
.45335 .58266 L
s
.45988 .59659 m
.44106 .58422 L
s
.42219 .58769 m
.42706 .58918 L
s
.41824 .58714 m
.42219 .58769 L
s
.47214 .59507 m
.45335 .58266 L
s
.4929 .59878 m
.48804 .59729 L
s
.49688 .59934 m
.4929 .59878 L
s
.50309 .59858 m
.49688 .59934 L
s
.48804 .59729 m
.48472 .59561 L
s
.48472 .59561 m
.4805 .59299 L
s
.50532 .59727 m
.50309 .59858 L
s
.4805 .59299 m
.47603 .58828 L
s
.50668 .59501 m
.50532 .59727 L
s
.50648 .59293 m
.50668 .59501 L
s
.47603 .58828 m
.47488 .58524 L
s
.47488 .58524 m
.47463 .58314 L
s
.47463 .58314 m
.47594 .58084 L
s
.49158 .58633 m
.4994 .58535 L
s
.51413 .58988 m
.5017 .57648 L
s
.47594 .58084 m
.47815 .57949 L
s
.49673 .58248 m
.4994 .58535 L
s
.51797 .58834 m
.522 .5889 L
s
.51305 .58683 m
.51797 .58834 L
s
.47815 .57949 m
.48441 .57869 L
s
.522 .5889 m
.52674 .58831 L
s
.50883 .58416 m
.51305 .58683 L
s
.49337 .58077 m
.49673 .58248 L
s
.48844 .57925 m
.49337 .58077 L
s
.48441 .57869 m
.48844 .57925 L
s
.53857 .58578 m
.53363 .58426 L
s
.54263 .58635 m
.53857 .58578 L
s
.54742 .58575 m
.54263 .58635 L
s
.53363 .58426 m
.52941 .58158 L
s
.54975 .5844 m
.54742 .58575 L
s
.52941 .58158 m
.52765 .57965 L
s
.52765 .57965 m
.5266 .57655 L
s
.55122 .58207 m
.54975 .5844 L
s
.55382 .58496 m
.5416 .57139 L
s
.5266 .57655 m
.52803 .57421 L
s
.56508 .58357 m
.54675 .56305 L
s
.52803 .57421 m
.53034 .57283 L
s
.56745 .5822 m
.57154 .58277 L
s
.56249 .58067 m
.56745 .5822 L
s
.57154 .58277 m
.57641 .58216 L
s
.53034 .57283 m
.53516 .57221 L
s
.57641 .58216 m
.5788 .58079 L
s
.53926 .57278 m
.54423 .57432 L
s
.53516 .57221 m
.53926 .57278 L
s
.60354 .58634 m
.58561 .56577 L
s
.5788 .58079 m
.58033 .57844 L
s
.58033 .57844 m
.57939 .57531 L
s
.55703 .57051 m
.55554 .57288 L
s
.55941 .56912 m
.55703 .57051 L
s
.57939 .57531 m
.57766 .57335 L
s
.57766 .57335 m
.57343 .57062 L
s
.5643 .56849 m
.55941 .56912 L
s
.60169 .57795 m
.60582 .57852 L
s
.5942 .57563 m
.60169 .57795 L
s
.60582 .57852 m
.61077 .57791 L
s
.57343 .57062 m
.56843 .56906 L
s
.56843 .56906 m
.5643 .56849 L
s
.63568 .5835 m
.63319 .58272 L
s
.63652 .58232 m
.63568 .5835 L
s
.61077 .57791 m
.61323 .57652 L
s
.63319 .58272 m
.63402 .58154 L
s
.63402 .58154 m
.63652 .58232 L
s
.61323 .57652 m
.61235 .57336 L
s
.61235 .57336 m
.60382 .56345 L
s
.62901 .57565 m
.61717 .56175 L
s
.6449 .57259 m
.63987 .57102 L
s
.6491 .57317 m
.6449 .57259 L
s
.65415 .57254 m
.6491 .57317 L
s
.63987 .57102 m
.63568 .56825 L
s
.6567 .57113 m
.65415 .57254 L
s
.63568 .56825 m
.634 .56626 L
s
.634 .56626 m
.63315 .56304 L
s
.65843 .56871 m
.6567 .57113 L
s
.63315 .56304 m
.63484 .56061 L
s
.67197 .56923 m
.66862 .56744 L
s
.6779 .5696 m
.67197 .56923 L
s
.63484 .56061 m
.63737 .55917 L
s
.68303 .56896 m
.6779 .5696 L
s
.66862 .56744 m
.66867 .56522 L
s
.63737 .55917 m
.64245 .55852 L
s
.68735 .56732 m
.68303 .56896 L
s
.66867 .56522 m
.67126 .56379 L
s
.7093 .57344 m
.69797 .55932 L
s
.64669 .5591 m
.65176 .56068 L
s
.64245 .55852 m
.64669 .5591 L
s
.68743 .5651 m
.68735 .56732 L
s
.67126 .56379 m
.679 .5617 L
s
.66203 .55714 m
.66198 .55939 L
s
.679 .5617 m
.68161 .56026 L
s
.66633 .55547 m
.66203 .55714 L
s
.68161 .56026 m
.68169 .55801 L
s
.67149 .55481 m
.66633 .55547 L
s
.68169 .55801 m
.68086 .55699 L
s
.68086 .55699 m
.67748 .55517 L
s
.67748 .55517 m
.67149 .55481 L
s
.6948 .55297 m
.69388 .55421 L
s
.69388 .55421 m
.69132 .55341 L
s
.69132 .55341 m
.69224 .55217 L
s
.69224 .55217 m
.6948 .55297 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000120?ooo`80003o0P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`00
0000oooo0?ooo`0U0?ooo`<00000>`3oool60000o`D0oooo00@0003o0?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000e0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`050?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000=P3oool20000o`03
0?ooo`000?l0003o0080003o0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00@0003o0?ooo`3oool00000F@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000I0?ooo`030000o`3oool0oooo0180
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00/0
oooo10000?l70?ooo`030000o`3oool0000005T0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000007@3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030000o`000000oooo05T0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000008@3oool00`000?l0oooo0000
o`040000o`H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool30000o`<0oooo
0P000?l50?ooo`030000o`000000oooo05T0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000007@3oool010000?l0oooo0?oo
o`000?l40?ooo`80003o103oool20000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`<0003o203oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001h0oooo0P00
0?l00`3oool0003o0000o`020000o`<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`H0003o4P3oool00`000000003o0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001L0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l01`3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo01X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000004@3oool50000o`D0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`L0003o8P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000;0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool30000o`<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo1`000?l60?oo
o`030000o`3oool0oooo00X0oooo0P000?lI0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool30000o`D0oooo00<0003o0?ooo`3oool01@3oool20000o`<0oooo00<0003o0?ooo`3o
ool01@3oool20000o`D0oooo0P000?l40?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0F0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2:0?ooo`D0003o1P3oool20000o`<0oooo00<0003o0?ooo`000?l0
103oool00`000?l0oooo0?ooo`030?ooo`80003o1P3oool00`000?l0oooo0?ooo`060?ooo`D0003o
503oool00`000?l0oooo0?ooo`0O0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08T0oooo00D0003o0?ooo`3oool00000
0?ooo`020000o`D0oooo00<0003o0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l40?ooo`03
0000o`3oool0oooo00/0oooo1@000?lj0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo0800oooo00<0003o0?ooo`3oool0
1P3oool010000?l0oooo0?ooo`0000030?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`00
0?l0oooo0000o`030?ooo`80003o0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
03`0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0M@3oool90000o`@0oooo00<0003o0?ooo`3oool01@3oool20000o`03
0?ooo`000000oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030000o`@0
oooo00@0003o0?ooo`3oool0oooo0P000?l70?ooo`030000o`3oool0oooo03T0oooo0`00000>0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0MP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P000?l70?ooo`80
003o103oool20000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`<0003o0P3oool20000
ocT0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`050?ooo`80003o103oool00`000?l0
oooo0?ooo`050?ooo`03000000000?l0003o00<0003o00<0oooo0000o`3oool0503oool20000ocP0
oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0N03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo
1@000?l20?ooo`030000003oool0oooo0500oooo1000000J0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0N@3oool20000o`L0oooo00<0
003o0?ooo`3oool0203oool00`000000oooo0?ooo`1=0?ooo`<000007P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo07/0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`030000003oool0oooo04X0oooo0`00000R
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0O@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00P0oooo00<000000?oo
o`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool2000007l0oooo1@000?l;0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3o
ool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000
003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
3`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
07l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`28
0?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The following shows the effect when the text is first rotated to lie along \
the y-axis.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Phi]frame[0, \[Pi]/2]\)[\[Phi]], {\[Phi], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59438 .68315 m
.61611 .67669 L
s
.62625 .67477 m
.62391 .67437 L
s
.62704 .67344 m
.62625 .67477 L
s
.62391 .67437 m
.6247 .67305 L
s
.6247 .67305 m
.62704 .67344 L
s
.59967 .67176 m
.59573 .66965 L
s
.60358 .67169 m
.59967 .67176 L
s
.59573 .66965 m
.59334 .66705 L
s
.61061 .66849 m
.61453 .66842 L
s
.60746 .66723 m
.61061 .66849 L
s
.61453 .66842 m
.61609 .66795 L
s
.61609 .66795 m
.61844 .66615 L
s
.60193 .66337 m
.60746 .66723 L
s
.59334 .66705 m
.59251 .66398 L
s
.61844 .66615 m
.61766 .66308 L
s
.59251 .66398 m
.59484 .66217 L
s
.59877 .6621 m
.60193 .66337 L
s
.61766 .66308 m
.61529 .66047 L
s
.59484 .66217 m
.59877 .6621 L
s
.61529 .66047 m
.61134 .65832 L
s
.61134 .65832 m
.6074 .65839 L
s
.59002 .65693 m
.58527 .65613 L
s
.58527 .65613 m
.58208 .65485 L
s
.58208 .65485 m
.57964 .65221 L
s
.60417 .65041 m
.60261 .65313 L
s
.57964 .65221 m
.57959 .64996 L
s
.60415 .64816 m
.60417 .65041 L
s
.57959 .64996 m
.58111 .64723 L
s
.60174 .6455 m
.60415 .64816 L
s
.58111 .64723 m
.58503 .6449 L
s
.55961 .64583 m
.55721 .64542 L
s
.56036 .64446 m
.55961 .64583 L
s
.59855 .6442 m
.60174 .6455 L
s
.55721 .64542 m
.55795 .64405 L
s
.58503 .6449 m
.5882 .64394 L
s
.55795 .64405 m
.56036 .64446 L
s
.59376 .64338 m
.59855 .6442 L
s
.5882 .64394 m
.59376 .64338 L
s
.56982 .64156 m
.59202 .63476 L
s
.56395 .63299 m
.56954 .63243 L
s
.56069 .63167 m
.56395 .63299 L
s
.56954 .63243 m
.58547 .62752 L
s
.55819 .62896 m
.56069 .63167 L
s
.5581 .62665 m
.55819 .62896 L
s
.54287 .62786 m
.57637 .61746 L
s
.56036 .62243 m
.5581 .62665 L
s
.55117 .61465 m
.55682 .61408 L
s
.54627 .61381 m
.55117 .61465 L
s
.55682 .61408 m
.56003 .61307 L
s
.54296 .61246 m
.54627 .61381 L
s
.56003 .61307 m
.564 .61064 L
s
.54039 .60967 m
.54296 .61246 L
s
.564 .61064 m
.56553 .60777 L
s
.54028 .60731 m
.54039 .60967 L
s
.56553 .60777 m
.56546 .6054 L
s
.54177 .60443 m
.54028 .60731 L
s
.53696 .60595 m
.57087 .59526 L
s
.56546 .6054 m
.56292 .6026 L
s
.56292 .6026 m
.5596 .60123 L
s
.5596 .60123 m
.55467 .60037 L
s
.5309 .59939 m
.55353 .59222 L
s
.53574 .59786 m
.53078 .59699 L
s
.53078 .59699 m
.52742 .59562 L
s
.52742 .59562 m
.5248 .59278 L
s
.55018 .59084 m
.54866 .59376 L
s
.5248 .59278 m
.52467 .59036 L
s
.55008 .58842 m
.55018 .59084 L
s
.52467 .59036 m
.52615 .58743 L
s
.54749 .58555 m
.55008 .58842 L
s
.52615 .58743 m
.53013 .58492 L
s
.54413 .58416 m
.54749 .58555 L
s
.53013 .58492 m
.53338 .58388 L
s
.53913 .58328 m
.54413 .58416 L
s
.53338 .58388 m
.53913 .58328 L
s
.51334 .58036 m
.516 .58324 L
s
.51319 .57791 m
.51334 .58036 L
s
.51466 .57492 m
.51319 .57791 L
s
.50889 .57553 m
.53174 .56815 L
s
.51866 .57238 m
.51466 .57492 L
s
.4961 .57084 m
.49103 .56994 L
s
.50025 .57075 m
.4961 .57084 L
s
.49103 .56994 m
.48759 .56852 L
s
.48759 .56852 m
.48395 .56461 L
s
.50881 .56162 m
.5133 .56652 L
s
.51821 .56493 m
.5133 .56652 L
s
.5206 .56289 m
.51821 .56493 L
s
.48395 .56461 m
.48375 .56211 L
s
.5221 .55985 m
.5206 .56289 L
s
.48375 .56211 m
.48518 .55907 L
s
.52195 .55734 m
.5221 .55985 L
s
.48518 .55907 m
.48753 .55701 L
s
.51836 .55337 m
.52195 .55734 L
s
.48753 .55701 m
.49153 .55441 L
s
.49153 .55441 m
.49975 .55171 L
s
.51491 .55192 m
.51836 .55337 L
s
.5098 .55101 m
.51491 .55192 L
s
.49975 .55171 m
.5056 .55109 L
s
.5056 .55109 m
.5098 .55101 L
s
.48438 .54897 m
.50383 .53732 L
s
.47697 .54094 m
.50383 .53732 L
s
.47697 .54094 m
.49646 .52917 L
s
.46949 .53283 m
.49646 .52917 L
s
.46288 .52567 m
.48621 .51785 L
s
.46786 .524 m
.46265 .52306 L
s
.46265 .52306 m
.45908 .52156 L
s
.45908 .52156 m
.45622 .51846 L
s
.48266 .51634 m
.4812 .51953 L
s
.45622 .51846 m
.45597 .51582 L
s
.48245 .5137 m
.48266 .51634 L
s
.45597 .51582 m
.4574 .51261 L
s
.47962 .51057 m
.48245 .5137 L
s
.4574 .51261 m
.46145 .50987 L
s
.47605 .50904 m
.47962 .51057 L
s
.46145 .50987 m
.4648 .50874 L
s
.47079 .50808 m
.47605 .50904 L
s
.4648 .50874 m
.47079 .50808 L
s
.4437 .50489 m
.44661 .50804 L
s
.44343 .50221 m
.4437 .50489 L
s
.44484 .49895 m
.44343 .50221 L
s
.43884 .49961 m
.46241 .49155 L
s
.44891 .49617 m
.44484 .49895 L
s
.42328 .49235 m
.42763 .49226 L
s
.41794 .49137 m
.42328 .49235 L
s
.42763 .49226 m
.43365 .4916 L
s
.43365 .4916 m
.44208 .4887 L
s
.41328 .48874 m
.41794 .49137 L
s
.40626 .48121 m
.41328 .48874 L
s
.44208 .4887 m
.44617 .48588 L
s
.44617 .48588 m
.44857 .48364 L
s
.44857 .48364 m
.45001 .48031 L
s
.40626 .48121 m
.44185 .46884 L
s
.45001 .48031 m
.44876 .47647 L
s
.44876 .47647 m
.44185 .46884 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0^0?ooo`80003oG`3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0:P3oool30000o`80oooo00<0003o0?ooo`3oool0G03oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo0P000?l50?ooo`030000o`3oool0oooo
05`0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0S0?ooo`<0003o203oool00`000?l0
oooo0?ooo`1K0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool07`3oool30000o``0oooo
00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01`0oooo0P00
0?l>0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<0
00000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0L
0?ooo`80003o303oool00`000?l0oooo0?ooo`1L0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo01d0oooo00<0003o0?ooo`3oool01`3oool20000oel0oooo1000001E0?ooo`030000003oool0
oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool07@3oool20000
o`@0oooo0`000?l70?ooo`80003oEP3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0N0?ooo`@0003o1`3oool30000oeD0
oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
00<000000?ooo`000000J03oool00`000000oooo0?ooo`0U0?ooo`<0003oE@3oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool08`3oool20000o`030?ooo`000?l0oooo0580oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo04l0oooo0`00000;0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`1<0?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
04T0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool00`3oool80000ocX0oooo0`00000D0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo02D0oooo0P000?l70?ooo`030000o`3oool0oooo
03D0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
02@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0a0?ooo`<000006`3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool01`3oool20000obl0
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00@0oooo
0`000?l]0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool08P3oool20000o`040?ooo`00
0?l0003o0000obd0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0R0?ooo`<0003o;03o
ool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2
000007H0oooo00<000000?ooo`3oool0;03oool30000oah0oooo0`00000[0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool09P3oool70000oa`0oooo0`00000^0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0280oooo0`000?l40?ooo`030000o`3oool0oooo01T0
oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo02L0oooo
00<0003o0?ooo`3oool00P3oool30000oa80oooo0`00000d0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0903oool90000oa00oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0R
0?ooo`<0003o103oool00`000?l0oooo0?ooo`0=0?ooo`<00000>P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?oo
o`3oool09P3oool20000o`d0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0S0?ooo`80
003o303oool300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0
2@3oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02D0oooo2@000?m40?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0
oooo0280oooo0P000?l0103oool000000000000000040?ooo`030000o`3oool0oooo0480oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0200oooo00@0003o0000000000000000203oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`80000000<0003o0000003oool02`3oool0
0`000?l0oooo0?ooo`110?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool0
02H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<0000000<0oooo0000
o`3oool0203oool01@000?l0oooo0?ooo`3oool0003o04@0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo
01@0oooo0`0000040?ooo`030000o`3oool0oooo00P0oooo0`000?m50?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0@0?ooo`<00000203oool20000o`h0oooo0P000?m00?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0<0?ooo`<000003@3oool40000o`P0oooo0P000?m20?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`080?ooo`<000006@3oool30000od@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000J
0?ooo`<0003oAP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000N0?ooo`030000o`3oool0oooo
04D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`8000008@3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0240oooo
00<0003o0?ooo`3oool00`3oool70000ocT0oooo0P00001K0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool20000o`H0oooo00<0
003o0?ooo`3oool0=03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02D0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0_0?ooo`@000001P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`050?ooo`<0003o;@3oool3000000X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02H0oooo00<0003o0?ooo`3oool00`3oool20000o`L0oooo0P000?lS0?ooo`<0
00003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool09`3oool50000o`H0oooo0`000?lR0?ooo`<00000
4P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09`3oool20000o`D0oooo1@000?lQ0?ooo`<000005P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0:`3oool30000o`D0oooo00<0003o0?ooo`3oool06P3oool4
000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo0`000?l80?ooo`030000o`3oool0oooo
01H0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool04`3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02X0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0A0?ooo`<000009P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?oo
o`0[0?ooo`P0003o4@3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03L0oooo0P000?l7
0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=@3oool30000o`H0oooo0`00000c0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0a0?ooo`@0003o1P3oool3000003H0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02h0oooo0`000?l00`3oool0003o0?ooo`040?ooo`<00000>P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0;03oool20000o`@0oooo00<0003o0?ooo`3oool00`0000030?ooo`80003o>@3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0<@3oool4000000<0oooo0`000?ll0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0^0?ooo`<000000P3oool50000od00oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00000?0?ooo`<0003o>03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000h0oooo
10000?ll0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00
002>0?ooo`030000003oool0oooo02D0oooo0`00000>0?ooo`<0003o@@3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q
0?ooo`@000003@3oool20000o`T0oooo1@000?li0?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?oo
o`<000004@3oool20000o`L0oooo0P000?l50?ooo`030000o`3oool0oooo03L0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000703oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo03H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00
5`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0603oool3000001l0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0g0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000S0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0140oooo1000000W0?ooo`<0003o@03oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0>0?ooo`<00000<`3oool40000ocP0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`0;0?ooo`<00000<P3oool20000o`H0oooo00<0003o0?ooo`3oool0=@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0203oool3000003@0oooo00@0003o0?ooo`3oool0003o1@3oool00`00
0?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000=`3oool010000?l0
oooo0?ooo`3oool60000ocT0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000?03oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200
oooo0P00002A0?ooo`@00000@03oool30000o`L0oooo0P000?lg0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000B@3oool20000o`80oooo
00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04D0oooo0P00
0?ln0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0@P3oool30000od40oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?oo
o`<000002@3oool00`000000oooo0?ooo`100?ooo`80003oA@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03o
ool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00
000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59486 .68663 m
.61602 .67611 L
s
.6259 .67244 m
.62361 .67234 L
s
.62665 .67083 m
.6259 .67244 L
s
.62361 .67234 m
.62435 .67072 L
s
.62435 .67072 m
.62665 .67083 L
s
.60367 .67227 m
.59984 .67293 L
s
.59984 .67293 m
.59594 .6711 L
s
.61431 .66697 m
.61584 .66621 L
s
.61048 .66762 m
.61431 .66697 L
s
.60738 .66665 m
.61048 .66762 L
s
.61584 .66621 m
.6181 .66382 L
s
.59594 .6711 m
.59354 .66851 L
s
.60189 .66308 m
.60738 .66665 L
s
.6181 .66382 m
.61727 .66045 L
s
.59354 .66851 m
.59267 .66515 L
s
.61727 .66045 m
.61491 .65784 L
s
.59877 .6621 m
.60189 .66308 L
s
.59267 .66515 m
.59492 .66276 L
s
.59492 .66276 m
.59877 .6621 L
s
.61491 .65784 m
.611 .65598 L
s
.611 .65598 m
.60715 .65664 L
s
.5901 .65752 m
.58543 .6573 L
s
.58543 .6573 m
.58228 .65631 L
s
.60384 .64806 m
.60236 .65137 L
s
.58228 .65631 m
.57984 .65367 L
s
.60377 .64552 m
.60384 .64806 L
s
.57984 .65367 m
.57975 .65114 L
s
.60137 .64286 m
.60377 .64552 L
s
.57975 .65114 m
.58119 .64782 L
s
.59821 .64185 m
.60137 .64286 L
s
.58119 .64782 m
.58499 .64461 L
s
.59351 .64162 m
.59821 .64185 L
s
.58499 .64461 m
.58807 .64306 L
s
.58807 .64306 m
.59351 .64162 L
s
.56006 .64935 m
.5577 .64924 L
s
.56077 .64769 m
.56006 .64935 L
s
.5577 .64924 m
.5584 .64758 L
s
.5584 .64758 m
.56077 .64769 L
s
.57001 .64303 m
.59165 .63211 L
s
.5641 .63417 m
.56958 .63272 L
s
.56088 .63315 m
.5641 .63417 L
s
.56958 .63272 m
.58511 .62487 L
s
.55838 .63043 m
.56088 .63315 L
s
.55825 .62783 m
.55838 .63043 L
s
.5604 .62272 m
.55825 .62783 L
s
.54331 .6314 m
.57601 .6148 L
s
.55124 .61524 m
.55678 .61378 L
s
.54642 .61499 m
.55124 .61524 L
s
.55678 .61378 m
.55991 .61219 L
s
.55991 .61219 m
.56377 .60886 L
s
.54314 .61394 m
.54642 .61499 L
s
.56377 .60886 m
.56522 .60541 L
s
.54058 .61116 m
.54314 .61394 L
s
.56522 .60541 m
.5651 .60274 L
s
.54043 .6085 m
.54058 .61116 L
s
.5651 .60274 m
.56257 .59993 L
s
.54185 .60502 m
.54043 .6085 L
s
.53714 .60743 m
.57023 .59051 L
s
.56257 .59993 m
.55929 .59886 L
s
.55929 .59886 m
.55444 .59859 L
s
.53108 .60088 m
.55318 .58955 L
s
.53581 .59845 m
.53092 .59818 L
s
.53092 .59818 m
.5276 .59711 L
s
.54988 .58846 m
.54844 .59198 L
s
.5276 .59711 m
.52498 .59427 L
s
.54974 .58574 m
.54988 .58846 L
s
.52498 .59427 m
.52481 .59155 L
s
.54715 .58287 m
.54974 .58574 L
s
.52481 .59155 m
.52622 .58802 L
s
.54383 .58177 m
.54715 .58287 L
s
.52622 .58802 m
.5301 .58462 L
s
.53891 .58149 m
.54383 .58177 L
s
.5301 .58462 m
.53327 .58298 L
s
.53327 .58298 m
.53891 .58149 L
s
.51351 .58185 m
.51617 .58473 L
s
.51332 .5791 m
.51351 .58185 L
s
.51473 .57552 m
.51332 .5791 L
s
.50906 .57702 m
.53141 .56546 L
s
.51862 .57208 m
.51473 .57552 L
s
.50048 .57285 m
.49639 .57353 L
s
.49639 .57353 m
.49139 .57324 L
s
.49139 .57324 m
.48797 .57212 L
s
.50878 .56132 m
.51327 .56622 L
s
.51807 .56373 m
.51327 .56622 L
s
.48797 .57212 m
.48432 .56821 L
s
.52039 .56109 m
.51807 .56373 L
s
.52181 .55745 m
.52039 .56109 L
s
.48432 .56821 m
.48409 .56541 L
s
.52163 .55464 m
.52181 .55745 L
s
.48409 .56541 m
.48546 .56177 L
s
.51805 .55067 m
.52163 .55464 L
s
.48546 .56177 m
.48776 .55911 L
s
.48776 .55911 m
.49166 .55561 L
s
.51463 .54952 m
.51805 .55067 L
s
.49166 .55561 m
.49971 .55141 L
s
.5096 .54921 m
.51463 .54952 L
s
.50546 .54989 m
.5096 .54921 L
s
.49971 .55141 m
.50546 .54989 L
s
.48454 .55048 m
.50353 .53461 L
s
.47712 .54245 m
.50353 .53461 L
s
.47712 .54245 m
.49616 .52646 L
s
.46964 .53434 m
.49616 .52646 L
s
.46303 .52719 m
.48592 .51513 L
s
.46792 .52461 m
.46276 .52427 L
s
.46276 .52427 m
.45923 .52307 L
s
.4824 .51392 m
.481 .51772 L
s
.45923 .52307 m
.45637 .51997 L
s
.48216 .51097 m
.4824 .51392 L
s
.45637 .51997 m
.45609 .51703 L
s
.47933 .50784 m
.48216 .51097 L
s
.45609 .51703 m
.45745 .51322 L
s
.4758 .50662 m
.47933 .50784 L
s
.45745 .51322 m
.46142 .50957 L
s
.4706 .50626 m
.4758 .50662 L
s
.46142 .50957 m
.46471 .50783 L
s
.46471 .50783 m
.4706 .50626 L
s
.44384 .50641 m
.44675 .50956 L
s
.44355 .50343 m
.44384 .50641 L
s
.4449 .49956 m
.44355 .50343 L
s
.43897 .50113 m
.46214 .48882 L
s
.44888 .49586 m
.4449 .49956 L
s
.42781 .4944 m
.43376 .49281 L
s
.42351 .49509 m
.42781 .4944 L
s
.43376 .49281 m
.44205 .4884 L
s
.41822 .49473 m
.42351 .49509 L
s
.41357 .4924 m
.41822 .49473 L
s
.44205 .4884 m
.44605 .48466 L
s
.44605 .48466 m
.4484 .48181 L
s
.40655 .48488 m
.41357 .4924 L
s
.4484 .48181 m
.44978 .47787 L
s
.44978 .47787 m
.4485 .47373 L
s
.40655 .48488 m
.4416 .46609 L
s
.4485 .47373 m
.4416 .46609 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0
5`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003o
ool0oooo02d0oooo0P000?l00`3oool0003o0?ooo`1M0?ooo`030000003oool0oooo01@0oooo0`00
000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0Z
0?ooo`80003o0`3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo0140oooo0`000011
0?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool09`3oool20000o`H0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?oo
o`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo02@0oooo0P000?l90?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3o
ool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0Q0?ooo`80003o2P3oool00`000?l0oooo0?ooo`1K0?ooo`030000
003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool07P3oool20000o``0oooo00<0003o0?ooo`3oool0F`3o
ool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool0
0`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01/0oooo0P000?l=0?ooo`030000o`3oool0
oooo05`0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0EP3oool4000005D0oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0K0?oo
o`030000o`3oool0oooo00L0oooo0P000?l50?ooo`80003oE`3oool3000005P0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0K0?ooo`03
0000o`3oool0oooo0080oooo10000?l60?ooo`030000o`3oool0oooo05@0oooo0`0000020?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000
J03oool00`000000oooo0?ooo`0K0?ooo`@0003o203oool20000oe@0oooo0`0000050?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003o
ool0oooo02D0oooo0P000?mC0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08`3oool2
0000oe40oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`1<0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00D0oooo1`000?lm0?ooo`<000004@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0h0?ooo`<00000503oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0U0?ooo`80003o203oool00`00
0?l0oooo0?ooo`0d0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00L0oooo0P000?lb0?ooo`<000006`3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool01P3oool20000oc00
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00@0oooo
0P000?l^0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool08P3oool010000?l0oooo0?oo
o`3oool20000obd0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0R0?ooo`<0003o2@3o
ool20000ob40oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo0P00001f0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool4
0000oal0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
00@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool09@3oool40000
o`80oooo00<0003o0?ooo`3oool06`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool08P3oool20000o`@0oooo0P000?l40?ooo`80003o5@3oool300000340
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo
0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool09P3oool010000?l0oooo
0?ooo`3oool40000oa<0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0
903oool50000o`80oooo00<0003o0?ooo`3oool03`3oool3000003L0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0280oooo0P000?l40?ooo`80003o3`3oool3000003X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0
oooo02H0oooo00<0003o0?ooo`3oool0303oool3000003d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
02@0oooo00<0003o0?ooo`3oool02P3oool300000400oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0280
oooo00<0003o0?ooo`3oool0103oool60000o`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo02D0oooo0`000?l01P3oool00000000000000000oooo0000od@0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3o
ool08P3oool20000o`040?ooo`0000000000000000D0oooo00<0003o0?ooo`3oool0@@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool0803oool010000?l000000000000000080?ooo`030000o`3oool0oooo
0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo0`0000000`000?l0oooo0?ooo`050?ooo`05
0000o`3oool0oooo0?ooo`000?l0A03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000080
oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`000?m50?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000
oooo0?ooo`0D0?ooo`<00000103oool00`000?l0oooo0?ooo`080?ooo`80003o1@3oool00`000?l0
oooo0?ooo`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000001`3oool00`000?l0oooo
0?ooo`0=0?ooo`80003o@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000000/0oooo0P00
0?l:0?ooo`<0003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool300000100oooo10000?l5
0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001X0oooo0`000?m60?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`03000001h0oooo00<0003o0?ooo`3oool0A@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo
0P00000Q0?ooo`030000o`3oool0oooo00L0oooo10000?lj0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0240oooo00<0
003o0?ooo`3oool00`3oool30000o`<0oooo00<0003o0?ooo`3oool0=`3oool2000005/0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0U
0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0c0?ooo`<000000P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3oool00`000?l0oooo0?ooo`0W0?oo
o`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`050?ooo`80
003o1@3oool20000obL0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000
o`3oool0oooo00<0oooo0P000?l50?ooo`80003o9P3oool3000000h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02H0oooo1@000?l50?ooo`80003o9@3oool300000180oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02L0oooo0P000?l50?ooo`80003o0P3oool20000ob00oooo0`00000F0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0/0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0I0?ooo`@000006P3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:P3oool20000o`P0oooo00<0003o0?ooo`3oool05P3oool3000001h0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02T0oooo0P000?l80?ooo`030000o`3oool0oooo01@0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool04P3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0:`3oool30000o`80oooo0P000?l6
0?ooo`030000o`3oool0oooo00T0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?oo
o`80003o1P3oool20000o`P0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0e0?ooo`80
003o1`3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo0P000?l60?ooo`<00000
=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0<@3oool20000o`D0oooo0`0000000`3oool0003o0?oo
o`0g0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0_0?ooo`80003o00@0oooo0000o`3oool0oooo0`00
00020?ooo`80003o>P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;@3oool20000o`80oooo10000003
0?ooo`80003o?@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo000000020000
0080oooo00<0003o0?ooo`3oool00P000?l60?ooo`80003o>03oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0:`3oool3000000H0oooo0P000?l60?ooo`80003o>P3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
:03oool3000000l0oooo0P000?lm0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000@0?ooo`80003o1@3o
ool30000ocP0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool2
00000900oooo00<000000?ooo`3oool08@3oool400000140oooo0P000?l50?ooo`80003o0`3oool0
0`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool0
0240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000006`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0K0?ooo`<00000503oool20000o`L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0f0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0
oooo0`00000O0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>03oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000008P3oool00`000?l0oooo
0?ooo`110?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P00
00070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000002H0oooo1000
0?l50?ooo`@0003o=`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>
0?ooo`<00000=`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool02`3oool300000380oooo0`000?l50?ooo`030000o`3oool0oooo03D0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00P0oooo0`00000d0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`00
0?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000=`3oool00`000?l0
oooo0?ooo`020?ooo`D0003o>@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0
oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000l0?ooo`03
0000o`3oool0oooo00P0oooo0P000?lf0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000@03oool30000o`H0oooo0P000?lh0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000BP3o
ool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0AP3oool2
0000ocd0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`140?ooo`80003o@03oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo0480oooo0P000?m30?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo
00<000000?ooo`3oool0@03oool20000odH0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3
000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo
0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool30000
04D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool30000
06D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool30000
08@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo000000020000
09@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo
0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?oo
o`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo
0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo
0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00
000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J
0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool01000
0000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0
oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo
00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?oo
o`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`33
0?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?oo
o`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00
L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3o
ool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000
oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo
0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?oo
o`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00
000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000
001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<00000
0?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@0
0000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@0
0000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000
I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0
oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<00000
0?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?oo
o`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D0
0000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000
UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool20000
00`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo
0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo
1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00
000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00
000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T
0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D0
0000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?oo
o`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00
003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P000004
0?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59613 .68974 m
.6158 .67559 L
s
.62502 .67038 m
.62284 .67053 L
s
.62566 .66851 m
.62502 .67038 L
s
.62284 .67053 m
.62347 .66866 L
s
.62347 .66866 m
.62566 .66851 L
s
.60388 .67279 m
.60027 .67396 L
s
.60027 .67396 m
.59647 .6724 L
s
.61377 .66567 m
.61518 .66466 L
s
.61015 .66685 m
.61377 .66567 L
s
.61518 .66466 m
.61722 .66176 L
s
.60716 .66613 m
.61015 .66685 L
s
.61722 .66176 m
.61628 .65813 L
s
.59647 .6724 m
.59408 .66981 L
s
.60178 .66282 m
.60716 .66613 L
s
.61628 .65813 m
.61392 .65551 L
s
.59408 .66981 m
.5931 .66619 L
s
.59877 .6621 m
.60178 .66282 L
s
.61392 .65551 m
.61013 .65391 L
s
.5931 .66619 m
.59513 .66327 L
s
.59513 .66327 m
.59877 .6621 L
s
.61013 .65391 m
.60649 .65509 L
s
.59032 .65804 m
.58585 .65834 L
s
.60296 .64599 m
.60171 .64982 L
s
.58585 .65834 m
.58281 .65761 L
s
.58281 .65761 m
.58037 .65497 L
s
.60279 .64319 m
.60296 .64599 L
s
.60038 .64053 m
.60279 .64319 L
s
.58037 .65497 m
.58017 .65218 L
s
.58017 .65218 m
.5814 .64834 L
s
.59734 .63978 m
.60038 .64053 L
s
.59286 .64007 m
.59734 .63978 L
s
.5814 .64834 m
.58488 .64435 L
s
.58775 .64228 m
.59286 .64007 L
s
.58488 .64435 m
.58775 .64228 L
s
.56132 .65248 m
.55906 .65263 L
s
.56193 .65056 m
.56132 .65248 L
s
.55906 .65263 m
.55966 .65071 L
s
.55966 .65071 m
.56193 .65056 L
s
.57054 .64433 m
.59067 .62978 L
s
.56968 .63298 m
.58413 .62253 L
s
.56452 .63521 m
.56968 .63298 L
s
.56141 .63445 m
.56452 .63521 L
s
.5589 .63173 m
.56141 .63445 L
s
.55867 .62887 m
.5589 .63173 L
s
.56051 .62298 m
.55867 .62887 L
s
.54456 .63454 m
.57503 .61246 L
s
.55667 .61352 m
.55959 .6114 L
s
.55145 .61577 m
.55667 .61352 L
s
.55959 .6114 m
.56312 .6073 L
s
.54684 .61604 m
.55145 .61577 L
s
.56312 .6073 m
.56436 .60332 L
s
.54367 .61525 m
.54684 .61604 L
s
.5411 .61247 m
.54367 .61525 L
s
.56436 .60332 m
.56414 .60039 L
s
.56414 .60039 m
.5616 .59758 L
s
.54085 .60954 m
.5411 .61247 L
s
.54206 .60555 m
.54085 .60954 L
s
.5616 .59758 m
.55843 .59677 L
s
.53766 .60874 m
.56849 .58634 L
s
.55843 .59677 m
.5538 .59702 L
s
.5316 .60219 m
.55222 .5872 L
s
.53602 .59898 m
.53134 .59923 L
s
.54903 .58637 m
.5478 .59041 L
s
.53134 .59923 m
.52812 .59842 L
s
.52812 .59842 m
.5255 .59558 L
s
.54878 .58339 m
.54903 .58637 L
s
.54619 .58052 m
.54878 .58339 L
s
.5255 .59558 m
.52522 .59261 L
s
.52522 .59261 m
.52643 .58855 L
s
.54298 .57968 m
.54619 .58052 L
s
.53827 .57992 m
.54298 .57968 L
s
.52643 .58855 m
.52999 .58436 L
s
.53296 .5822 m
.53827 .57992 L
s
.52999 .58436 m
.53296 .5822 L
s
.51403 .58316 m
.51669 .58605 L
s
.51374 .58015 m
.51403 .58316 L
s
.51494 .57605 m
.51374 .58015 L
s
.51852 .57181 m
.51494 .57605 L
s
.50957 .57834 m
.53046 .5631 L
s
.5012 .5747 m
.49731 .57591 L
s
.49731 .57591 m
.49251 .57614 L
s
.50867 .56105 m
.51316 .56596 L
s
.51765 .56268 m
.51316 .56596 L
s
.51976 .55951 m
.51765 .56268 L
s
.49251 .57614 m
.48919 .57529 L
s
.52097 .55535 m
.51976 .55951 L
s
.48919 .57529 m
.48554 .57138 L
s
.52068 .55228 m
.52097 .55535 L
s
.5171 .54831 m
.52068 .55228 L
s
.48554 .57138 m
.48521 .56832 L
s
.48521 .56832 m
.48638 .56415 L
s
.51379 .54742 m
.5171 .54831 L
s
.48638 .56415 m
.48847 .56096 L
s
.50897 .54763 m
.51379 .54742 L
s
.48847 .56096 m
.49207 .55667 L
s
.50505 .54884 m
.50897 .54763 L
s
.49207 .55667 m
.49961 .55115 L
s
.49961 .55115 m
.50505 .54884 L
s
.48505 .5518 m
.50258 .53224 L
s
.47763 .54377 m
.50258 .53224 L
s
.47763 .54377 m
.49522 .52409 L
s
.47015 .53567 m
.49522 .52409 L
s
.46354 .52851 m
.48499 .51275 L
s
.46813 .52514 m
.46317 .52533 L
s
.48158 .5118 m
.48039 .51613 L
s
.46317 .52533 m
.45973 .5244 L
s
.45973 .5244 m
.45687 .5213 L
s
.48123 .50859 m
.48158 .5118 L
s
.4784 .50546 m
.48123 .50859 L
s
.45687 .5213 m
.45649 .51809 L
s
.45649 .51809 m
.45766 .51375 L
s
.47497 .5045 m
.4784 .50546 L
s
.46999 .50467 m
.47497 .5045 L
s
.45766 .51375 m
.46132 .5093 L
s
.46441 .50703 m
.46999 .50467 L
s
.46132 .5093 m
.46441 .50703 L
s
.44434 .50774 m
.44725 .51088 L
s
.44395 .50449 m
.44434 .50774 L
s
.4451 .50009 m
.44395 .50449 L
s
.44878 .4956 m
.4451 .50009 L
s
.43947 .50246 m
.46122 .48643 L
s
.43416 .49388 m
.44195 .48813 L
s
.4285 .49626 m
.43416 .49388 L
s
.4244 .49749 m
.4285 .49626 L
s
.44195 .48813 m
.44565 .4836 L
s
.41929 .49766 m
.4244 .49749 L
s
.44565 .4836 m
.44779 .48022 L
s
.41474 .49561 m
.41929 .49766 L
s
.44779 .48022 m
.44896 .47575 L
s
.40771 .48809 m
.41474 .49561 L
s
.44896 .47575 m
.44759 .47134 L
s
.44759 .47134 m
.44068 .4637 L
s
.40771 .48809 m
.44068 .4637 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0300oooo00<0003o0?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02h0oooo00<0003o0?ooo`000?l0
G`3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0:`3oool20000o`<0oooo00<0003o0?ooo`3oool0G03o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo05/0oooo00<000000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool0
02`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02@0
oooo0P000?l80?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`0R0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`1L0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool07@3oool20000o`X0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`1F0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo01/0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo05L0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`070?ooo`80003o103oool20000
oeP0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool06P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0E@3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo01X0oooo
00<0003o0?ooo`3oool00`3oool20000o`D0oooo00<0003o0?ooo`3oool0D`3oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool06`3oool50000o`D0oooo0P000?mC0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool08`3oool00`000?l0oooo0000o`1@0?ooo`<000002`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool01`3oool30000od80oooo0`00000>0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02<0oooo00<0003o0?oo
o`3oool0103oool20000o`<0oooo00<0003o0?ooo`3oool0?03oool300000140oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>03oool3000001@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0
003o00L0oooo00<0003o0?ooo`000?l0=@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`060?ooo`80003o<`3oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
00D0oooo0P000?la0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo02d0oooo1000000Q0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:`3oool3000002D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000
001d0?ooo`030000003oool0oooo0240oooo1@000?l80?ooo`80003o8@3oool3000002P0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<00000
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`060?ooo`<0003o7`3oool3000002/0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`0W0?ooo`<0003o00<0oooo0000o`3oool0703oool30000
02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000
oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0903oool20000o`<0
oooo00@0003o0?ooo`3oool0oooo0P000?lF0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0Q0?ooo`80003o103oool00`000?l0oooo0?ooo`030000oa@0
oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool09@3oool01P000?l0oooo
0000o`000?l0oooo0000oa80oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0S0?ooo`<0
003o0P3oool00`000?l0oooo0?ooo`0>0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
8@3oool20000o`@0oooo00<0003o0?ooo`3oool02`3oool3000003d0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003o
ool0oooo02D0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo0`0000100?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool0
0`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00<0oooo0P000?l20?ooo`80003o00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?oo
o`80003o00@0oooo00000000000000000P3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02<0oooo0P000?l3000000D0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool08@3oool00`000?l00000000000080?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo01`0oooo0`0000000`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`00
0?l0A03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000080oooo00<0003o0?ooo`3oool0
1P3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo01@0oooo0`0000050?ooo`030000o`3oool0oooo00L0oooo0P000?l40?ooo`030000
o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`0000080?ooo`030000o`3o
ool0oooo00/0oooo0P000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000002`3oool0
0`000?l0oooo0?ooo`090?ooo`80003oA03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool30000
00h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003oA@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0
oooo00<000000?ooo`3oool0103oool300000180oooo1@000?l40?ooo`80003oAP3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool00`00000M0?ooo`80003o2@3oool20000oc`0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008@3o
ool00`000?l0oooo0?ooo`050?ooo`80003o0P3oool20000ocX0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08@3oool0
0`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo0?ooo`0f0?ooo`800000F`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0280oooo00@0003o0?ooo`3oool0003o203oool20000o`D0oooo00<0003o0?ooo`3oool0;03oool3
00000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01@3oool20000
o`@0oooo0P000?l[0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool00`000?l0
oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?ooo`0X0?ooo`<000002P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
0P000?lX0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`020000o`@0oooo10000?lT0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09`3oool3
0000o`<0oooo0P000?l40?ooo`030000o`3oool0oooo01h0oooo0`00000F0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0J0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool20000o`L0
oooo00<0003o0?ooo`3oool05`3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo
00<0003o0?ooo`000?l01`3oool00`000?l0oooo0?ooo`0D0?ooo`<000008P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0180oooo0`00
000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?
0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool00P3oool20000o`D0oooo00<0003o
0?ooo`3oool02P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02`0oooo10000?l50?oo
o`80003o2@3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03D0oooo00<0003o0?ooo`3o
ool01P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo0P000?l60?ooo`<00000
=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0<P3oool20000o`@0oooo0`0000000`000?l0oooo0?oo
o`0g0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`80003o0P3oool3000000030?ooo`000?l0
oooo03/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0300oooo00<0003o0000000000000P0000020?oo
o`80003o1@3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<0
000000<0oooo0000o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`80003o>P3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0:`3oool3000000D0oooo0`000?l50?ooo`030000o`3oool0oooo03X0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02P0oooo0`00000?0?ooo`030000o`3oool0oooo03`0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<00000
0?ooo`3oool09@3oool300000100oooo0P000?l50?ooo`@0003o=`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?oo
o`@000004P3oool00`000?l0oooo0?ooo`020?ooo`<0003o103oool00`000?l0oooo0?ooo`0e0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000006P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo03H0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000
7@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000001P0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01D0oooo0`00000J0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01`3o
ool20000ocP0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2
000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@000009P3oool0
0`000?l0oooo0?ooo`080?ooo`80003o=`3oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0>0?ooo`<00000:`3oool30000o`T0oooo00<0003o0?ooo`3oool0=@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000b0?ooo`<0003o1@3oool00`000?l0
oooo0?ooo`0e0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000=03oool01@000?l0oooo
0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
103oool4000003L0oooo00<0003o0?ooo`3oool00P3oool30000o`<0oooo0P000?lf0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03o
ool010000000oooo0?ooo`3oool3000003/0oooo00<0003o0?ooo`3oool0203oool20000ocL0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000
000o0?ooo`@0003o@03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`800000T03oool3000004X0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?oo
o`030000003oool0oooo04H0oooo0P000?lm0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3o
ool0A@3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0
@`3oool20000od80oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`110?ooo`80003oA@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07l0oooo0`00000?0?ooo`030000003oool0oooo0400oooo00<0003o0?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00
000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?oo
o`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3o
ool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00
000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`03
0000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00
703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3o
ool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00
001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3o
ool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00
001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203o
ool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00
603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003o
ool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool2
00000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0
oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0
oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103o
ool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool0
02h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo
0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0
oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?oo
o`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool0
00000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool00000
06/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo
0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000
oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo
0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?oo
o`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?oo
o`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3o
ool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0
oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool20000
05<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?oo
o`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3o
ool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`03
0000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo
0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?oo
o`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?oo
o`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003o
ool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool4
00000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool50000
01H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0
oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<0
00000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l
0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0
YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3o
ool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4
000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool2
00000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool0
06P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0
oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo
08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880
oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo
00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo
00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo0026
0?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000
003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<00000
7`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo
0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0
oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo
002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F
0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?oo
o`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`80
00004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@0
0000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`800000
3P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3o
ool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03o
ool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool0
0`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool3
00000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool30000
00030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?oo
o`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0
oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo
002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3o
ool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool20000
0=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.62366 .66868 m
.62164 .66904 L
s
.62412 .6666 m
.62366 .66868 L
s
.6221 .66696 m
.62412 .6666 L
s
.62164 .66904 m
.6221 .66696 L
s
.59815 .69232 m
.61546 .67517 L
s
.61416 .66338 m
.61585 .66005 L
s
.61291 .66461 m
.61416 .66338 L
s
.60964 .6662 m
.61291 .66461 L
s
.60422 .67322 m
.60094 .67482 L
s
.61585 .66005 m
.61474 .65621 L
s
.60682 .66571 m
.60964 .6662 L
s
.60094 .67482 m
.59732 .67347 L
s
.60161 .6626 m
.60682 .66571 L
s
.61474 .65621 m
.61238 .6536 L
s
.59732 .67347 m
.59492 .67088 L
s
.61238 .6536 m
.60876 .65221 L
s
.59492 .67088 m
.59377 .66705 L
s
.59877 .6621 m
.60161 .6626 L
s
.60876 .65221 m
.60547 .65381 L
s
.59547 .6637 m
.59877 .6621 L
s
.59377 .66705 m
.59547 .6637 L
s
.60159 .64429 m
.60069 .64854 L
s
.59066 .65846 m
.58653 .6592 L
s
.60125 .64127 m
.60159 .64429 L
s
.58653 .6592 m
.58366 .65869 L
s
.59884 .63861 m
.60125 .64127 L
s
.58366 .65869 m
.58122 .65605 L
s
.59597 .63807 m
.59884 .63861 L
s
.58122 .65605 m
.58085 .65304 L
s
.59184 .63878 m
.59597 .63807 L
s
.58085 .65304 m
.58174 .64877 L
s
.58724 .64164 m
.59184 .63878 L
s
.58174 .64877 m
.58471 .64414 L
s
.58471 .64414 m
.58724 .64164 L
s
.57139 .64541 m
.58913 .62785 L
s
.56334 .65508 m
.56124 .65544 L
s
.56378 .65293 m
.56334 .65508 L
s
.56168 .6533 m
.56378 .65293 L
s
.56124 .65544 m
.56168 .6533 L
s
.56985 .6332 m
.58259 .62061 L
s
.5652 .63607 m
.56985 .6332 L
s
.56226 .63553 m
.5652 .63607 L
s
.55975 .63281 m
.56226 .63553 L
s
.55935 .62973 m
.55975 .63281 L
s
.56068 .6232 m
.55935 .62973 L
s
.54657 .63714 m
.57349 .61053 L
s
.55908 .61076 m
.5621 .60602 L
s
.5565 .6133 m
.55908 .61076 L
s
.55179 .6162 m
.5565 .6133 L
s
.5621 .60602 m
.56299 .60161 L
s
.54751 .6169 m
.55179 .6162 L
s
.56299 .60161 m
.56259 .59847 L
s
.54451 .61632 m
.54751 .6169 L
s
.56259 .59847 m
.56006 .59566 L
s
.54195 .61354 m
.54451 .61632 L
s
.56006 .59566 m
.55706 .59506 L
s
.54152 .61041 m
.54195 .61354 L
s
.55706 .59506 m
.55277 .59573 L
s
.5424 .60598 m
.54152 .61041 L
s
.53851 .60982 m
.56573 .58294 L
s
.53245 .60327 m
.55068 .58527 L
s
.54766 .58465 m
.54677 .58913 L
s
.53636 .59941 m
.53201 .6001 L
s
.54724 .58146 m
.54766 .58465 L
s
.53201 .6001 m
.52897 .5995 L
s
.54465 .57859 m
.54724 .58146 L
s
.52897 .5995 m
.52634 .59666 L
s
.54161 .57797 m
.54465 .57859 L
s
.52634 .59666 m
.5259 .59347 L
s
.53725 .57863 m
.54161 .57797 L
s
.5259 .59347 m
.52677 .58898 L
s
.53245 .58155 m
.53725 .57863 L
s
.52677 .58898 m
.52982 .58414 L
s
.52982 .58414 m
.53245 .58155 L
s
.51487 .58425 m
.51754 .58713 L
s
.51441 .58102 m
.51487 .58425 L
s
.51527 .57648 m
.51441 .58102 L
s
.51835 .5716 m
.51527 .57648 L
s
.51042 .57942 m
.52892 .56117 L
s
.51697 .56182 m
.51299 .56575 L
s
.51873 .55823 m
.51697 .56182 L
s
.5085 .56084 m
.51299 .56575 L
s
.50238 .57621 m
.49882 .57786 L
s
.5196 .55364 m
.51873 .55823 L
s
.49882 .57786 m
.49435 .57853 L
s
.51914 .55035 m
.5196 .55364 L
s
.49435 .57853 m
.4912 .57789 L
s
.51556 .54638 m
.51914 .55035 L
s
.4912 .57789 m
.48755 .57398 L
s
.51242 .5457 m
.51556 .54638 L
s
.48755 .57398 m
.48705 .57071 L
s
.50795 .54634 m
.51242 .5457 L
s
.48705 .57071 m
.48789 .5661 L
s
.50436 .54798 m
.50795 .54634 L
s
.48789 .5661 m
.48965 .56248 L
s
.49944 .55093 m
.50436 .54798 L
s
.48965 .56248 m
.49275 .55753 L
s
.49275 .55753 m
.49944 .55093 L
s
.48589 .55288 m
.50104 .53031 L
s
.47847 .54485 m
.50104 .53031 L
s
.47847 .54485 m
.49368 .52216 L
s
.47099 .53675 m
.49368 .52216 L
s
.46438 .52959 m
.48345 .51082 L
s
.48021 .51009 m
.47936 .51484 L
s
.46847 .52557 m
.46384 .5262 L
s
.4797 .50666 m
.48021 .51009 L
s
.46384 .5262 m
.46057 .52548 L
s
.47687 .50353 m
.4797 .50666 L
s
.46057 .52548 m
.45771 .52238 L
s
.47361 .50279 m
.47687 .50353 L
s
.45771 .52238 m
.45717 .51896 L
s
.46897 .50339 m
.47361 .50279 L
s
.45717 .51896 m
.45799 .51418 L
s
.4639 .50639 m
.46897 .50339 L
s
.45799 .51418 m
.46115 .50909 L
s
.46115 .50909 m
.4639 .50639 L
s
.44518 .50882 m
.44809 .51197 L
s
.44462 .50535 m
.44518 .50882 L
s
.44544 .50052 m
.44462 .50535 L
s
.44861 .49538 m
.44544 .50052 L
s
.44031 .50355 m
.45968 .4845 L
s
.44178 .48791 m
.44497 .48274 L
s
.43483 .49474 m
.44178 .48791 L
s
.42967 .49778 m
.43483 .49474 L
s
.44497 .48274 m
.44678 .47893 L
s
.4259 .49945 m
.42967 .49778 L
s
.44678 .47893 m
.4476 .47404 L
s
.42112 .50005 m
.4259 .49945 L
s
.4476 .47404 m
.44606 .46941 L
s
.41673 .49822 m
.42112 .50005 L
s
.44606 .46941 m
.43915 .46177 L
s
.4097 .49069 m
.41673 .49822 L
s
.4097 .49069 m
.43915 .46177 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0<@3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0;`3oool00`000?l0oooo0000o`1O0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;@3oool010000?l0oooo0?ooo`000?mO0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`03
0000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0[0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`0D0?ooo`<00000
?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool04@3o
ool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0F`3oool0
0`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`1L0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool08`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool01`3oool3000004/0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo
0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1S0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo05L0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000
003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool07@3o
ool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F03o
ool4000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`1G0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05D0oooo0`0000020?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000
oooo0?ooo`0J0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`1C0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0K0?ooo`040000o`3oool0oooo0?ooo`<0
003o103oool00`000?l0oooo0?ooo`1A0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0
6`3oool30000o`H0oooo0P000?m@0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003o
ool0oooo0280oooo00<0003o0?ooo`000?l0203oool40000od40oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0103o
ool20000o`@0oooo00<0003o0?ooo`3oool0>`3oool300000140oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0>03oool3000001@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo
0P000?lf0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<P3oool3000001/0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool0<03oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0280oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0]0?ooo`@000008@3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool08`3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo0280oooo10000?l60?ooo`80
003o8`3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
:03oool2000007H0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`030?ooo`<0003o
8@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo0080oooo0P000?l20?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool05`3o
ool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool0
0`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool08`3oool2
0000o`<0oooo00@0003o0?ooo`3oool0oooo0P000?lG0?ooo`<00000<@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00`000?lE0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo
02@0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0oooo0?ooo`0@0?ooo`<00000=`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool08`3oool20000o`<0oooo00<0003o0?ooo`3oool03P3oool30000
03X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0<0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0903oool00`000?l0oooo
0?ooo`030?ooo`D0003o0P3oool300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02<0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03000000000?l0000004<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
000000030?ooo`000?l0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool300000840oooo00<000000?ooo`3oool0903oool010000?l00000000000000005
0?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo00<000000000
o`0000001`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@0
000000<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?oo
o`3oool0?`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000000<0oooo00<0003o0?ooo`3o
ool01@3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo0400oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo01@0oooo0`0000060?ooo`030000o`3oool0oooo00H0oooo0P000?l20?ooo`03
0000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`0000080?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303o
ool3000000/0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`130?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`080?ooo`<000003`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000B0?ooo`030000o`3oool0oooo
0080oooo00@0003o0?ooo`3oool0oooo0P000?m60?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`030000
01H0oooo10000?l30?ooo`030000o`3oool0003o00L0oooo10000?lk0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool200000280
oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00<0003o0?ooo`3oool0>03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo
00<0003o0?ooo`3oool0<03oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo0000o`L0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0^0?ooo`<000000P3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool09@3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?oo
o`0[0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:@3oool3000000X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`@0003o9`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00D0003o0?ooo`3o
ool0oooo0000o`050?ooo`050000o`3oool0oooo0?ooo`000?l08`3oool300000180oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02H0oooo10000?l40?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool07P3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo1000000J0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0[0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0H0?ooo`<00000
7P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo01H0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Z0?ooo`80003o1@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00d0oooo0`00000V0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo
02/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00/0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`@0003o1@3oool00`000?l0
oooo0?ooo`080?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo
0?ooo`060?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?oo
o`040?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0?ooo`02
0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`030000
0080003o103oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@0
00000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo02h0oooo0`0000020?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3o
ool0>@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000030?ooo`000?l0oooo00<0oooo
0P000?l50?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00
00030?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool30000ocL0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<00000
0?ooo`3oool09@3oool300000140oooo00@0003o0?ooo`3oool0oooo0P000?l30?ooo`030000o`3o
ool0oooo03D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool2
00000900oooo00<000000?ooo`3oool08@3oool4000001<0oooo00D0003o0?ooo`3oool0oooo0000
o`050?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?oo
o`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000F
0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool06`3oool3000001d0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01P0oooo0`00000O0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool0=@3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000006`3oool20000
o`D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0000o`0g0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool04@3oool4000001h0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`090?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool03P3oool3000002/0oooo0`000?l90?ooo`030000o`3oool0oooo03D0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000<`3oool20000o`@0oooo00<0
003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000003D0oooo00<0003o
0?ooo`3oool00P000?l00`3oool0003o0000o`0i0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`@00000=`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0P000?lf0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0T03oool010000000oooo0?ooo`3oool3000003`0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200
oooo0P00002A0?ooo`@00000@03oool00`000?l0oooo0000o`100?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000A03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?oo
o`160?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`15
0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`140?oo
o`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`130?ooo`03
0000o`3oool0oooo0480oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`120?ooo`030000
o`3oool0oooo04@0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`120?ooo`030000o`3o
ool0oooo04D0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool30000
01P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool30000
03P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?oo
o`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool30000
05P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?oo
o`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`800000
9@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool30000
07L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?oo
o`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03o
ool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D0
00000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000
003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool20000
00T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?oo
o`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?oo
o`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003o
ool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool0
10000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool20000
07@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00
001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0
oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0
oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0
oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0019
0?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680
oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?oo
o`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;
0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<00000
0?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?oo
o`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3o
ool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3o
ool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool0
0`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@
0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?oo
o`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo
001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo10000005
0?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?oo
o`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00
JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`00
0000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000
oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo
1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00
000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a
0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`03
0000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`800000
3@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000
@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0
U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3o
ool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool20000
02X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo0000
02H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0
oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo
0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<00000
0?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?oo
o`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@0
0000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000
Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool0
0`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool20000
01T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo
0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d
0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?oo
o`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`00
00002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`000000
8`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000
^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000
003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool20000
00D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000
oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D0
0000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<00000
0P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.62186 .66741 m
.62007 .66793 L
s
.62209 .66517 m
.62186 .66741 L
s
.6203 .66569 m
.62209 .66517 L
s
.62007 .66793 m
.6203 .66569 L
s
.60082 .69427 m
.61502 .67485 L
s
.61281 .66242 m
.61405 .65878 L
s
.61179 .66381 m
.61281 .66242 L
s
.60897 .66573 m
.61179 .66381 L
s
.61405 .65878 m
.61271 .65479 L
s
.60637 .66539 m
.60897 .66573 L
s
.60467 .67354 m
.60184 .67546 L
s
.61271 .65479 m
.61035 .65217 L
s
.60184 .67546 m
.59844 .67427 L
s
.60139 .66244 m
.60637 .66539 L
s
.61035 .65217 m
.60696 .65094 L
s
.59844 .67427 m
.59604 .67169 L
s
.59877 .6621 m
.60139 .66244 L
s
.60696 .65094 m
.60412 .65285 L
s
.59604 .67169 m
.59467 .66769 L
s
.59592 .66402 m
.59877 .6621 L
s
.59467 .66769 m
.59592 .66402 L
s
.59979 .64302 m
.59933 .64758 L
s
.59922 .63985 m
.59979 .64302 L
s
.5911 .65879 m
.58743 .65984 L
s
.59681 .63718 m
.59922 .63985 L
s
.58743 .65984 m
.58478 .65949 L
s
.59417 .6368 m
.59681 .63718 L
s
.58478 .65949 m
.58234 .65685 L
s
.59048 .63783 m
.59417 .6368 L
s
.58234 .65685 m
.58175 .65368 L
s
.58656 .64116 m
.59048 .63783 L
s
.58175 .65368 m
.58219 .64909 L
s
.58449 .64398 m
.58656 .64116 L
s
.58219 .64909 m
.58449 .64398 L
s
.57251 .64621 m
.5871 .62643 L
s
.56603 .65702 m
.56415 .65755 L
s
.56624 .65471 m
.56603 .65702 L
s
.56437 .65524 m
.56624 .65471 L
s
.56415 .65755 m
.56437 .65524 L
s
.57008 .63336 m
.58055 .61918 L
s
.5661 .63671 m
.57008 .63336 L
s
.56338 .63633 m
.5661 .63671 L
s
.56087 .63361 m
.56338 .63633 L
s
.56025 .63037 m
.56087 .63361 L
s
.54927 .63908 m
.57145 .60911 L
s
.5609 .62336 m
.56025 .63037 L
s
.5584 .61028 m
.56074 .60507 L
s
.55628 .61314 m
.5584 .61028 L
s
.56074 .60507 m
.56117 .60034 L
s
.55225 .61652 m
.55628 .61314 L
s
.56117 .60034 m
.56055 .59705 L
s
.54842 .61754 m
.55225 .61652 L
s
.56055 .59705 m
.55801 .59424 L
s
.54564 .61712 m
.54842 .61754 L
s
.55801 .59424 m
.55525 .59379 L
s
.54307 .61434 m
.54564 .61712 L
s
.53964 .61062 m
.56208 .58044 L
s
.55525 .59379 m
.55141 .59479 L
s
.54243 .61104 m
.54307 .61434 L
s
.54285 .6063 m
.54243 .61104 L
s
.53358 .60407 m
.54863 .58385 L
s
.54583 .58339 m
.54541 .58818 L
s
.54519 .58005 m
.54583 .58339 L
s
.53681 .59973 m
.53292 .60074 L
s
.5426 .57718 m
.54519 .58005 L
s
.53292 .60074 m
.5301 .6003 L
s
.53978 .57671 m
.5426 .57718 L
s
.5301 .6003 m
.52748 .59746 L
s
.53588 .57769 m
.53978 .57671 L
s
.52748 .59746 m
.52681 .59411 L
s
.53176 .58108 m
.53588 .57769 L
s
.52681 .59411 m
.52722 .5893 L
s
.5296 .58398 m
.53176 .58108 L
s
.52722 .5893 m
.5296 .58398 L
s
.51601 .58504 m
.51867 .58792 L
s
.51532 .58165 m
.51601 .58504 L
s
.51155 .58022 m
.52686 .55976 L
s
.51573 .5768 m
.51532 .58165 L
s
.51812 .57144 m
.51573 .5768 L
s
.51606 .56119 m
.51277 .56559 L
s
.51736 .55728 m
.51606 .56119 L
s
.51777 .55238 m
.51736 .55728 L
s
.50827 .56068 m
.51277 .56559 L
s
.51708 .54894 m
.51777 .55238 L
s
.50397 .57733 m
.50086 .5793 L
s
.5135 .54497 m
.51708 .54894 L
s
.50086 .5793 m
.49684 .58029 L
s
.49684 .58029 m
.49391 .57982 L
s
.51059 .54445 m
.5135 .54497 L
s
.49391 .57982 m
.49026 .57591 L
s
.50657 .5454 m
.51059 .54445 L
s
.50345 .54735 m
.50657 .5454 L
s
.49026 .57591 m
.48954 .57247 L
s
.49921 .55078 m
.50345 .54735 L
s
.48954 .57247 m
.48993 .56754 L
s
.49366 .55816 m
.49921 .55078 L
s
.48993 .56754 m
.49124 .56359 L
s
.49124 .56359 m
.49366 .55816 L
s
.48703 .55367 m
.49898 .5289 L
s
.47961 .54564 m
.49898 .5289 L
s
.47961 .54564 m
.49162 .52076 L
s
.47213 .53754 m
.49162 .52076 L
s
.46552 .53038 m
.48138 .50943 L
s
.47837 .50884 m
.47799 .51391 L
s
.47763 .50527 m
.47837 .50884 L
s
.46892 .52588 m
.46475 .52683 L
s
.4748 .50214 m
.47763 .50527 L
s
.46475 .52683 m
.46171 .52627 L
s
.47177 .50154 m
.4748 .50214 L
s
.46171 .52627 m
.45885 .52317 L
s
.46759 .50245 m
.47177 .50154 L
s
.45885 .52317 m
.45808 .51959 L
s
.46321 .50592 m
.46759 .50245 L
s
.45808 .51959 m
.45845 .51449 L
s
.46092 .50893 m
.46321 .50592 L
s
.45845 .51449 m
.46092 .50893 L
s
.44632 .50961 m
.44923 .51275 L
s
.44553 .50598 m
.44632 .50961 L
s
.44145 .50433 m
.45761 .48311 L
s
.44589 .50084 m
.44553 .50598 L
s
.44839 .49523 m
.44589 .50084 L
s
.44155 .48776 m
.44405 .48212 L
s
.43574 .49537 m
.44155 .48776 L
s
.44405 .48212 m
.4454 .478 L
s
.4454 .478 m
.44576 .4728 L
s
.43127 .49888 m
.43574 .49537 L
s
.44576 .4728 m
.44398 .46803 L
s
.42795 .50087 m
.43127 .49888 L
s
.42363 .50179 m
.42795 .50087 L
s
.44398 .46803 m
.43708 .46039 L
s
.41946 .50011 m
.42363 .50179 L
s
.41243 .49259 m
.41946 .50011 L
s
.41243 .49259 m
.43708 .46039 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0<03oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0;P3oool00`000?l0oooo0000o`1P0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;03oool010000?l0oooo0?ooo`000?mP0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`03
0000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0[0?ooo`050000
o`3oool0oooo0?ooo`000?l0G`3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool04@3oool300000440oooo
00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?oo
o`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1L
0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0640oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0R0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1H0?ooo`03
0000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F@3oool010000000oooo0?ooo`3oool300000580
oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo
0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`1L0?ooo`@0
0000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo01d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo05P0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003o
ool0oooo06L0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`060?ooo`050000o`3o
ool0oooo0?ooo`000?l0F03oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo01/0oooo00<0
003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3oool20000oeD0oooo0`0000050?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003o
ool0oooo01/0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3oool20000oe<0oooo
0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<0
00000?ooo`3oool0J@3oool00`000000oooo0?ooo`0K0?ooo`D0003o103oool20000o`L0oooo1000
0?m50?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q
0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0280oooo00<0003o
0?ooo`000?l01P3oool01@000?l0oooo0?ooo`3oool0003o0480oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03`0oooo0`00000A0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`80003o>P3oool3000001@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo
00<0003o0?ooo`3oool0=P3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`030?ooo`80003o=@3oool3000001/0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0<@3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02L0oooo1000000Q
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?oo
o`3oool0LP3oool00`000000oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool2
0000obH0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
02P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0003o
0000o`D0oooo0P000?lT0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0R0?ooo`80003o1@3oool00`00
0?l0oooo0000o`030?ooo`030000o`3oool0oooo01/0oooo0`00000[0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0003o00<0
oooo00<0003o0?ooo`3oool06@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool09@3oool010000?l0oooo0?ooo`000?l20?ooo`80003o603oool300000340
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo
0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool08`3oool01P000?l0oooo
0?ooo`3oool0003o0?ooo`80003o5P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0Q0?ooo`090000o`3oool0oooo0?ooo`000?l0oooo0000o`3oool0003o01<0oooo0`00
000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<00000
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0T0?ooo`80003o00<0oooo0000o`3oool0403oool3
000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0280oooo0P000?l20?ooo`030000o`3oool0oooo
00<0oooo0`000?l60?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool08@3oool010000?l0
oooo0?ooo`000?l50?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool300000400oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?oo
o`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`03000000000?l0000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`03000000030?ooo`000?l0oooo04<0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool0
803oool01@000?l0oooo0?ooo`3oool0003o00<00000103oool00`000?l0oooo0?ooo`120?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0000000L0oooo00<0003o0?ooo`3oool0
@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000030000o`3oool0oooo00<0oooo00@0
003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0H0?ooo`<00000103oool00`000?l0oooo0?ooo`040?ooo`80003o0`3oool00`000?l0oooo0?oo
o`110?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000001`3oool00`000?l0oooo0?ooo`05
0?ooo`050000o`3oool0oooo0?ooo`000?l0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3
000000X0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`120?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0<0?ooo`<00000303oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo
04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000?0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001<0oooo
00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo0P000?ll0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`03000001L0oooo00@0003o0?ooo`3oool0003o0`3oool20000o`L0
oooo00@0003o0?ooo`3oool0003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000K0?ooo`80003o1@3oool00`000?l0
oooo0?ooo`030?ooo`80003o0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03<0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo
00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
0P000?l30?ooo`030000o`3oool0oooo03<0oooo0P00001K0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08P3oool010000?l0oooo0?oo
o`000?l60?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<03oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?oo
o`3oool0003o02l0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0U0?ooo`030000o`3o
ool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0]0?ooo`<000002P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool09@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`@0003o
:03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3oool0003o
103oool01@000?l0oooo0?ooo`3oool0003o02@0oooo0`00000B0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0W0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01l0oooo
0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`000?l0
1@3oool00`000?l0oooo0?ooo`0K0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01P0oooo0`00000N0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0A0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:P3oool20000
o`D0oooo00D0003o0?ooo`3oool0oooo0000o`0A0?ooo`<000009P3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0[0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?oo
o`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0;03oool40000o`@0oooo00<0003o0?ooo`3o
ool02@3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0
0`3oool010000?l0oooo0?ooo`3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo00000002000003H0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo03<0oooo00<0003o0?ooo`3oool00P3oool3000003X0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0380oooo0P000?l01@3oool00000000000000000003o00@0oooo00<0003o0?ooo`3oool0=P3o
ool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0<@3oool400000080oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<000000P3oool01000
0?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo0`0000020?ooo`040000o`3oool0oooo0?ooo`80003o103oool00`000?l0oooo0?ooo`0k
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`000?lh0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo
02D0oooo0`00000A0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0f
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?oo
o`030000003oool0oooo0240oooo1000000C0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool0
0`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool0
0240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000005P3oool01@00
0?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01/0oooo0`00000M0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0>03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000803oool00`000?l0oooo0?ooo`060?ooo`80003o=`3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000703oool20000o`D0oooo00<0003o0?ooo`3o
ool01@3oool010000?l0oooo0?ooo`000?lg0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool04@3oool4000001l0oooo0P000?l50?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool0=P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000
:`3oool30000o`P0oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00/0oooo0`00000c0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0g0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`080?ooo`<00000=@3oool00`000?l0oooo0?ooo`040000o`80oooo0P000?lf
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000>03oool00`000?l0oooo0?ooo`060?oo
o`80003o=`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000l0?ooo`030000o`3oool0oooo
0400oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo1000000o0?ooo`040000o`3oool0oooo0000od00oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000130?ooo`80003o103oool00`000?l0
oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo
0?ooo`0l0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo0?oo
o`0m0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0o
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?oo
o`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`110?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0O`3oool3000000l0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`130?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O03oool300000140oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`130?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03o
ool4000001@0oooo00<000000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`150?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3
000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<0
00000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3
000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`000018
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3
000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z
0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`80
00009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3
000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;
0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000
T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?oo
o`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
0980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`00
8P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2
000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`24
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000
003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03o
ool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2
000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo
0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003o
ool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool20000
06T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool20000
0680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00
000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m
0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?oo
o`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3o
ool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00
001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P
0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080
oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo1000
00050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A
0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?oo
o`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool0
0`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80
oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo
1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000
000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?oo
o`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`80
00003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D0
0000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3o
ool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00
J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2
000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo
000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool00000
02H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000
oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<0
00000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O
0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?oo
o`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@0
0000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3o
ool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2
000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000
oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/
0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`00
00008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@0
0000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`03
0000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2
000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<0
00000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61971 .66662 m
.61819 .66724 L
s
.61968 .66428 m
.61971 .66662 L
s
.61816 .6649 m
.61968 .66428 L
s
.61819 .66724 m
.61816 .6649 L
s
.60403 .69549 m
.61448 .67465 L
s
.61119 .66183 m
.6119 .658 L
s
.61045 .66332 m
.61119 .66183 L
s
.6119 .658 m
.61029 .65391 L
s
.60816 .66543 m
.61045 .66332 L
s
.60583 .66519 m
.60816 .66543 L
s
.61029 .65391 m
.60793 .65129 L
s
.60521 .67374 m
.60291 .67586 L
s
.60112 .66234 m
.60583 .66519 L
s
.60291 .67586 m
.59978 .67478 L
s
.60793 .65129 m
.6048 .65016 L
s
.59978 .67478 m
.59739 .67219 L
s
.6048 .65016 m
.6025 .65226 L
s
.59877 .6621 m
.60112 .66234 L
s
.59739 .67219 m
.59575 .66809 L
s
.59646 .66422 m
.59877 .6621 L
s
.59575 .66809 m
.59646 .66422 L
s
.59763 .64224 m
.59771 .647 L
s
.59678 .63897 m
.59763 .64224 L
s
.59437 .63631 m
.59678 .63897 L
s
.59164 .65898 m
.58851 .66024 L
s
.592 .63603 m
.59437 .63631 L
s
.58851 .66024 m
.58613 .65999 L
s
.58886 .63725 m
.592 .63603 L
s
.58613 .65999 m
.58369 .65735 L
s
.58575 .64087 m
.58886 .63725 L
s
.58369 .65735 m
.58283 .65407 L
s
.58422 .64388 m
.58575 .64087 L
s
.58283 .65407 m
.58273 .64929 L
s
.58273 .64929 m
.58422 .64388 L
s
.57386 .6467 m
.58465 .62556 L
s
.57035 .63345 m
.5781 .61832 L
s
.56927 .65822 m
.56766 .65885 L
s
.56922 .65581 m
.56927 .65822 L
s
.56761 .65644 m
.56922 .65581 L
s
.56766 .65885 m
.56761 .65644 L
s
.56719 .63711 m
.57035 .63345 L
s
.56474 .63682 m
.56719 .63711 L
s
.56223 .63411 m
.56474 .63682 L
s
.55252 .64027 m
.569 .60825 L
s
.56134 .63076 m
.56223 .63411 L
s
.56117 .62345 m
.56134 .63076 L
s
.5591 .60449 m
.55899 .59958 L
s
.55758 .60999 m
.5591 .60449 L
s
.55601 .61305 m
.55758 .60999 L
s
.55899 .59958 m
.55809 .59619 L
s
.55279 .61671 m
.55601 .61305 L
s
.55809 .59619 m
.55555 .59338 L
s
.54951 .61793 m
.55279 .61671 L
s
.55555 .59338 m
.55306 .59304 L
s
.541 .61111 m
.55769 .57894 L
s
.54701 .61761 m
.54951 .61793 L
s
.55306 .59304 m
.54977 .59422 L
s
.54444 .61483 m
.54701 .61761 L
s
.54352 .61143 m
.54444 .61483 L
s
.5434 .60649 m
.54352 .61143 L
s
.53495 .60455 m
.54616 .58301 L
s
.54364 .58264 m
.54376 .58761 L
s
.54272 .5792 m
.54364 .58264 L
s
.54012 .57633 m
.54272 .5792 L
s
.53736 .59992 m
.53401 .60112 L
s
.53759 .57596 m
.54012 .57633 L
s
.53401 .60112 m
.53147 .60078 L
s
.53424 .57712 m
.53759 .57596 L
s
.53147 .60078 m
.52884 .59794 L
s
.53094 .58079 m
.53424 .57712 L
s
.52884 .59794 m
.5279 .59449 L
s
.52932 .58389 m
.53094 .58079 L
s
.5279 .59449 m
.52777 .58949 L
s
.52777 .58949 m
.52932 .58389 L
s
.51738 .58552 m
.52004 .5884 L
s
.51293 .58069 m
.52438 .55893 L
s
.51642 .58204 m
.51738 .58552 L
s
.51628 .57699 m
.51642 .58204 L
s
.51784 .57135 m
.51628 .57699 L
s
.51496 .56082 m
.51249 .56549 L
s
.51571 .55672 m
.51496 .56082 L
s
.51556 .55164 m
.51571 .55672 L
s
.5146 .54811 m
.51556 .55164 L
s
.508 .56059 m
.51249 .56549 L
s
.51101 .54414 m
.5146 .54811 L
s
.50589 .578 m
.50334 .58016 L
s
.50838 .54371 m
.51101 .54414 L
s
.50334 .58016 m
.49987 .58135 L
s
.50491 .54484 m
.50838 .54371 L
s
.49987 .58135 m
.49722 .58097 L
s
.50234 .54698 m
.50491 .54484 L
s
.49722 .58097 m
.49357 .57706 L
s
.49894 .55068 m
.50234 .54698 L
s
.49357 .57706 m
.49257 .57352 L
s
.49476 .55854 m
.49894 .55068 L
s
.49257 .57352 m
.49241 .5684 L
s
.49317 .56426 m
.49476 .55854 L
s
.49241 .5684 m
.49317 .56426 L
s
.48841 .55414 m
.49648 .52808 L
s
.481 .54611 m
.49648 .52808 L
s
.481 .54611 m
.48912 .51994 L
s
.47351 .538 m
.48912 .51994 L
s
.46691 .53085 m
.47888 .50862 L
s
.47614 .50813 m
.47632 .51337 L
s
.47512 .50446 m
.47614 .50813 L
s
.47229 .50133 m
.47512 .50446 L
s
.46948 .52607 m
.46587 .52719 L
s
.46954 .50083 m
.47229 .50133 L
s
.46587 .52719 m
.4631 .52673 L
s
.46591 .50192 m
.46954 .50083 L
s
.4631 .52673 m
.46024 .52363 L
s
.46237 .50565 m
.46591 .50192 L
s
.46024 .52363 m
.45919 .51996 L
s
.46064 .50884 m
.46237 .50565 L
s
.45919 .51996 m
.45901 .51468 L
s
.45901 .51468 m
.46064 .50884 L
s
.44772 .51006 m
.45062 .51321 L
s
.44285 .50479 m
.45509 .48232 L
s
.44665 .50635 m
.44772 .51006 L
s
.44645 .50102 m
.44665 .50635 L
s
.44811 .49514 m
.44645 .50102 L
s
.44293 .48177 m
.44371 .47748 L
s
.44127 .48767 m
.44293 .48177 L
s
.44371 .47748 m
.44352 .4721 L
s
.43686 .49573 m
.44127 .48767 L
s
.44352 .4721 m
.44145 .46724 L
s
.43322 .49951 m
.43686 .49573 L
s
.44145 .46724 m
.43455 .45961 L
s
.43046 .50169 m
.43322 .49951 L
s
.4267 .50279 m
.43046 .50169 L
s
.42282 .50121 m
.4267 .50279 L
s
.41579 .49368 m
.43455 .45961 L
s
.41579 .49368 m
.42282 .50121 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0oooo05l0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0003o0600oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0003o0640oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0[0?ooo`050000o`3oool0oooo0?ooo`000?l0H03oool00`000000
oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo
00<000000?ooo`3oool0:P3oool01@000?l0oooo0?ooo`3oool0003o0600oooo00<000000?ooo`3o
ool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1M0?ooo`030000
003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo05d0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603o
ool002/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool0
0`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
02@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo
00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0F03oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0240oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05T0oooo
00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F@3oool4000005D0oooo00<000000?ooo`3oool0
5`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3o
ool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`1J0?ooo`<00000F03oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01`0oooo00<0
003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o05P0oooo0`0000020?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03o
ool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo
0000o`1E0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo0080oooo0P00
0?l30?ooo`030000o`3oool0oooo0540oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0L
0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool01@3oool30000odH0oooo0`00
000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P000007
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0703oool20000o`D0oooo0P000?l6
0?ooo`050000o`3oool0oooo0?ooo`000?l0@P3oool3000000h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0?@3oool300000140oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo0P000?lk0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0
=`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03@0oooo0`00000K0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0380oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0X0?ooo`@000008@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo0P000?lW
0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?oo
o`030000003oool0000007@0oooo00<000000?ooo`3oool08P3oool010000?l0oooo0?ooo`000?l4
0?ooo`80003o9@3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool08P3oool20000o`@0oooo00<0003o0?oo
o`000?l00`3oool00`000?l0oooo0?ooo`0L0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`020?ooo`80
003o6`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
1@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0000o`020?ooo`80003o6@3oool300000340oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool08`3oool020000?l0oooo0?ooo`000?l0oooo0000o`3o
ool0003o5P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0Q0?ooo`09
0000o`3oool0oooo0?ooo`000?l0oooo0000o`3oool0003o01<0oooo0`00000g0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`0T0?ooo`80003o00<0oooo0000o`3oool0403oool3000003X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo0280oooo0P000?l20?ooo`030000o`3oool0oooo0080oooo0`000?l70?oo
o`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool08@3oool01@000?l0oooo0?ooo`3oool0003o
00<0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`<00000@03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool0903oool010000?l0oooo0?ooo`000?l50?ooo`030000o`000000000004<0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?oo
o`030000003oool0oooo0280oooo00@0003o0?ooo`3oool0003o0`3oool3000000030000o`3oool0
oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool30000
0840oooo00<000000?ooo`3oool08@3oool010000?l0oooo0?ooo`000?l3000000<0oooo00<0003o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool00`000000003o000000060?oo
o`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo100000000`3oool0
003o0?ooo`030?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0@@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0603oool3000000D0oooo00<0003o0?ooo`3oool00`3oool20000o`80
oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000P0oooo
00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`000?m40?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo
0?ooo`0@0?ooo`<000002P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo04<0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo00`0oooo0`00000=0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool300000140oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<00000503oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0`000?lm0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0R`3oool00`000000oooo0?ooo`03000001L0oooo00D0003o0?ooo`3oool0oooo0000o`020?oo
o`80003o1@3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0=03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo
08`0oooo0P00000K0?ooo`<0003o0`3oool20000o`D0oooo00<0003o0?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0003o03L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0
003o00D0oooo0P000?l20?ooo`030000o`3oool0oooo03@0oooo0P00001K0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08P3oool01@00
0?l0oooo0?ooo`3oool0003o00D0oooo00@0003o0?ooo`3oool0003o=03oool300000080oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o1@3oool010000?l0oooo0?oo
o`000?l`0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00<0003o;03oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`040000o`3oool0oooo0000obP0oooo
0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l0
0P3oool01@000?l0oooo0?ooo`3oool0003o02D0oooo0`00000B0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0W0?ooo`<0003o0`3oool01@000?l0oooo0?ooo`3oool0003o0280oooo0`00000F0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0Y0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3o
ool0703oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0
0P000?l40?ooo`030000o`3oool0oooo01T0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0[0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0D0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:`3oool20000o`@0oooo00@0003o0?ooo`3oool0003o
4P3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool2000008l0oooo00<000000?ooo`3oool0;03oool01@000?l0oooo0?ooo`3oool0003o00<0oooo
00<0003o0?ooo`3oool03@3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02d0oooo00<0
003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0:0?ooo`@00000;P3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo00000002000003H0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0
oooo00<0003o0?ooo`3oool00P3oool3000000030?ooo`000?l0oooo03L0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo0380oooo0P000?l01@3oool00000000000000000003o0080oooo00<0003o0?ooo`3o
ool0>03oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000080oooo00D0003o0?ooo`3oool0
oooo0000o`0k0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<0000000<0003o0?ooo`000?l0
0`3oool010000?l0oooo0?ooo`000?lm0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000
0`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool00P3oool20000
ocL0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`0000050?ooo`040000o`3oool0oooo0?oo
o`80003o0`3oool010000?l0oooo0?ooo`3oool20000o`030?ooo`000?l0oooo03L0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?oo
o`3oool09@3oool3000000P0oooo00<0003o0?ooo`3oool01P3oool010000?l0oooo0?ooo`000?l3
0?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@
0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000001<0oooo00D0003o0?oo
o`3oool0oooo0000o`040?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01h0oooo0`00000G0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0>03oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000M0?ooo`030000o`3oool0oooo
03h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool30000
0200oooo00<0003o0?ooo`3oool01@3oool30000ocL0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool05@3oool3000002<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`0f0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool400000240oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03L0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002D0oooo00<0
003o0?ooo`3oool00`3oool30000o`L0oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00/0oooo0`00000c0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0g
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000=@3oool00`000?l0oooo0?ooo`040000
o`030?ooo`000?l0003o03L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000h0?ooo`03
0000o`3oool0oooo00D0oooo0P000?lh0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000003`0
oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0
oooo000P0?ooo`800000T@3oool400000400oooo00@0003o0?ooo`3oool0003o?`3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000004@0oooo
0P000?l30?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?oo
o`160?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`16
0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`150?oo
o`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`150?ooo`03
0000o`3oool0oooo0400oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`140?ooo`030000
o`3oool0oooo0480oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`150?ooo`030000o`3o
ool0oooo0480oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`140?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo
04D0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4
000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo
09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000
oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;
0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3
000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo
09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/
0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?oo
o`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3
000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo
0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>
0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?oo
o`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000
S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`80
0000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`03
0000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00
203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3o
ool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo
08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`00
0000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?oo
o`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?oo
o`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000
003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3o
ool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h
0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo
0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?oo
o`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D00000
0?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003o
ool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2
000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000
oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0016
0?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`03
0000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00
A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000
DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool0
1@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G
0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo
04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<0
00000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`80
0000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000
003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool40000
01l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0
oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?oo
o`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`03
0000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000
003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003o
ool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03o
ool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000
;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3o
ool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo
07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo
07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0
oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo
00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo0029
0?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b
0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g
0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703o
ool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool0
0`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo
04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0
oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo
002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo
002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<
0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?oo
o`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`03
0000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool0
4@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003o
ool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000
_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo
0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0
oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000
003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3o
ool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D00000
0P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3o
ool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61731 .66635 m
.61609 .66701 L
s
.61697 .66398 m
.61731 .66635 L
s
.61575 .66463 m
.61697 .66398 L
s
.61609 .66701 m
.61575 .66463 L
s
.60764 .69593 m
.61388 .67458 L
s
.60949 .65773 m
.60758 .65361 L
s
.60939 .66163 m
.60949 .65773 L
s
.60894 .66315 m
.60939 .66163 L
s
.60726 .66533 m
.60894 .66315 L
s
.60758 .65361 m
.60521 .651 L
s
.60523 .66512 m
.60726 .66533 L
s
.60581 .67381 m
.60412 .676 L
s
.60521 .651 m
.60238 .6499 L
s
.60082 .66231 m
.60523 .66512 L
s
.60412 .676 m
.60129 .67495 L
s
.60238 .6499 m
.60069 .65207 L
s
.60129 .67495 m
.5989 .67236 L
s
.59877 .6621 m
.60082 .66231 L
s
.59706 .66429 m
.59877 .6621 L
s
.5989 .67236 m
.59696 .66823 L
s
.59696 .66823 m
.59706 .66429 L
s
.59521 .64199 m
.5959 .6468 L
s
.59406 .63869 m
.59521 .64199 L
s
.59164 .63603 m
.59406 .63869 L
s
.59225 .65905 m
.58972 .66037 L
s
.58957 .63578 m
.59164 .63603 L
s
.58704 .63706 m
.58957 .63578 L
s
.58972 .66037 m
.58764 .66015 L
s
.58764 .66015 m
.58521 .65751 L
s
.58484 .64077 m
.58704 .63706 L
s
.58391 .64385 m
.58484 .64077 L
s
.58521 .65751 m
.58404 .65421 L
s
.58334 .64935 m
.58391 .64385 L
s
.58404 .65421 m
.58334 .64935 L
s
.57539 .64687 m
.58191 .62529 L
s
.57066 .63349 m
.57536 .61805 L
s
.57293 .65862 m
.57163 .65929 L
s
.57257 .65618 m
.57293 .65862 L
s
.57127 .65685 m
.57257 .65618 L
s
.57163 .65929 m
.57127 .65685 L
s
.56841 .63723 m
.57066 .63349 L
s
.56627 .63698 m
.56841 .63723 L
s
.5562 .64066 m
.56624 .60799 L
s
.56376 .63426 m
.56627 .63698 L
s
.56256 .63089 m
.56376 .63426 L
s
.56148 .62349 m
.56256 .63089 L
s
.55726 .60432 m
.55653 .59936 L
s
.55666 .60991 m
.55726 .60432 L
s
.55653 .59936 m
.55532 .59594 L
s
.5557 .61302 m
.55666 .60991 L
s
.55532 .59594 m
.55278 .59313 L
s
.5534 .61677 m
.5557 .61302 L
s
.54254 .61126 m
.55277 .57852 L
s
.55074 .61805 m
.5534 .61677 L
s
.55278 .59313 m
.5506 .59281 L
s
.5506 .59281 m
.54792 .59405 L
s
.54854 .61776 m
.55074 .61805 L
s
.54598 .61498 m
.54854 .61776 L
s
.54475 .61155 m
.54598 .61498 L
s
.54401 .60655 m
.54475 .61155 L
s
.53649 .6047 m
.54338 .58276 L
s
.54117 .58242 m
.54191 .58744 L
s
.53994 .57896 m
.54117 .58242 L
s
.53734 .57609 m
.53994 .57896 L
s
.53797 .59998 m
.53525 .60124 L
s
.53511 .57574 m
.53734 .57609 L
s
.53238 .57696 m
.53511 .57574 L
s
.53525 .60124 m
.53301 .60092 L
s
.53301 .60092 m
.53039 .59808 L
s
.53001 .58071 m
.53238 .57696 L
s
.52901 .58386 m
.53001 .58071 L
s
.53039 .59808 m
.52914 .5946 L
s
.52839 .58954 m
.52901 .58386 L
s
.52914 .5946 m
.52839 .58954 L
s
.51448 .58083 m
.52158 .5587 L
s
.51893 .58566 m
.52159 .58854 L
s
.51766 .58215 m
.51893 .58566 L
s
.51753 .57132 m
.5169 .57704 L
s
.5169 .57704 m
.51766 .58215 L
s
.51384 .55657 m
.51371 .56072 L
s
.51307 .55145 m
.51384 .55657 L
s
.51371 .56072 m
.51218 .56547 L
s
.51179 .54789 m
.51307 .55145 L
s
.5082 .54393 m
.51179 .54789 L
s
.50769 .56056 m
.51218 .56547 L
s
.50588 .54352 m
.5082 .54393 L
s
.50807 .57819 m
.50614 .58041 L
s
.50304 .5447 m
.50588 .54352 L
s
.50614 .58041 m
.5033 .58165 L
s
.50109 .54688 m
.50304 .5447 L
s
.5033 .58165 m
.50096 .5813 L
s
.49862 .55066 m
.50109 .54688 L
s
.50096 .5813 m
.49732 .57739 L
s
.49601 .55864 m
.49862 .55066 L
s
.49732 .57739 m
.49601 .57382 L
s
.49536 .56444 m
.49601 .55864 L
s
.49601 .57382 m
.49523 .56863 L
s
.49523 .56863 m
.49536 .56444 L
s
.48998 .55427 m
.49366 .52788 L
s
.48257 .54623 m
.49366 .52788 L
s
.48257 .54623 m
.48629 .51975 L
s
.47509 .53812 m
.48629 .51975 L
s
.46848 .53096 m
.47604 .50843 L
s
.47362 .50796 m
.47443 .51324 L
s
.47228 .50428 m
.47362 .50796 L
s
.46944 .50115 m
.47228 .50428 L
s
.47011 .52611 m
.46713 .52729 L
s
.46701 .50067 m
.46944 .50115 L
s
.46402 .5018 m
.46701 .50067 L
s
.46713 .52729 m
.46468 .52684 L
s
.46468 .52684 m
.46182 .52374 L
s
.46142 .50559 m
.46402 .5018 L
s
.46033 .50882 m
.46142 .50559 L
s
.46182 .52374 m
.46046 .52004 L
s
.45964 .51472 m
.46033 .50882 L
s
.46046 .52004 m
.45964 .51472 L
s
.44444 .50489 m
.45223 .48216 L
s
.4493 .51017 m
.45221 .51332 L
s
.44792 .50643 m
.4493 .51017 L
s
.44779 .49512 m
.44709 .50106 L
s
.44709 .50106 m
.44792 .50643 L
s
.4418 .47737 m
.44097 .47197 L
s
.44166 .4817 m
.4418 .47737 L
s
.44095 .48765 m
.44166 .4817 L
s
.44097 .47197 m
.43858 .46709 L
s
.43814 .49581 m
.44095 .48765 L
s
.43858 .46709 m
.43167 .45947 L
s
.43546 .49965 m
.43814 .49581 L
s
.43333 .50187 m
.43546 .49965 L
s
.43021 .50302 m
.43333 .50187 L
s
.41963 .49391 m
.43167 .45947 L
s
.42665 .50145 m
.43021 .50302 L
s
.41963 .49391 m
.42665 .50145 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0oooo0600oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0^0?ooo`80003oH@3oool00`000000oooo0?ooo`0N0?oo
o`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo02`0oooo00<0003o0?ooo`000?l0HP3oool00`000000oooo0?ooo`0J0?ooo`<0
0000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo02/0oooo00@0003o0?ooo`3oool0003oH@3oool00`000000oooo0?ooo`0G0?ooo`<0
0000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0
:@3oool01@000?l0oooo0?ooo`3oool0003o0640oooo00<000000?ooo`3oool0503oool3000003h0
oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo0140oooo
0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool09`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05h0oooo00<0
00000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0H03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0G@3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H
0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02@0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo00L0oooo0`00001;0?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0000oe`0oooo00<000000?oo
o`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3o
ool0oooo0000o`1L0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G
0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0200oooo00<0003o0?oo
o`3oool0103oool010000?l0oooo0?ooo`000?mM0?ooo`@00000E@3oool00`000000oooo0?ooo`0G
0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01h0oooo00<0003o0?oo
o`3oool01@3oool010000?l0oooo0?ooo`000?mK0?ooo`<00000F03oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01d0oooo00<0003o0?oo
o`3oool0103oool01@000?l0oooo0?ooo`3oool0003o05P0oooo0`0000020?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`00
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`1E
0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?oo
o`800000J@3oool00`000000oooo0?ooo`0N0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool2
0000oe80oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
02X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0003o
00@0oooo0P000?l50?ooo`<0003oA`3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo00<0oooo0P000?l40?ooo`050000o`3oool0oooo0?oo
o`000?l0@`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0903oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0@03oool3
00000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool08`3oool0
1@000?l0oooo0?ooo`3oool0003o00@0oooo0P000?ll0?ooo`<00000503oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l0
1@3oool00`000?l0oooo0?ooo`0g0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
K`3oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3o
ool0=@3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
8@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<P3oool3000001h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo02@0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo02T0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0S0?ooo`050000o`3oool0oooo0?ooo`000?l0
0`3oool20000obP0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0R0?ooo`040000o`3o
ool0oooo0000o`@0oooo0P000?lU0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0R0?ooo`<0003o0`3o
ool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo01d0oooo0`00000[0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool08`3oool020000?l0oooo0?ooo`3oool0003o0?ooo`000?l0
oooo0P000?lL0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0U0?ooo`030000o`3oool0003o0080oooo0P000?lI0?ooo`<00000<@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0T0?ooo`070000o`3oool0003o0?ooo`000?l0
oooo0000o`0F0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo0280oooo
00P0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000oa<0oooo0`00000g0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`0T0?ooo`80003o00<0oooo0000o`3oool0403oool3000003X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo02<0oooo0P000?l00`3oool0003o0?ooo`020?ooo`<0003o203oool3000003d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0280oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0
oooo0?ooo`020000o`<0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0T0?ooo`040000
o`3oool0oooo0000o`@0oooo00@0003o0000000000000000@`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3o
ool08`3oool010000?l0oooo0?ooo`000?l20?ooo`80000000<0003o0?ooo`3oool0A03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0003o00<000000P3oool00`000?l0oooo0?ooo`140?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`0Q0?ooo`80000000<0003o0?ooo`3oool00`3oool010000?l0oooo
0?ooo`000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000000P3oool01`000?l0oooo
0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0H0?ooo`<000001P3oool00`000?l0oooo0?ooo`020?ooo`80003o0P3oool00`000?l0
oooo0?ooo`120?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000002@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0003o04D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00
000<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0303oool3000000l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`13
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000004P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000E0?ooo`03
0000o`3oool0oooo00@0oooo0P000?l40?ooo`<0003o?P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000I0?ooo`040000o`3oool0oooo0000o`80oooo0P000?l30?ooo`050000o`3oool0oooo0?oo
o`000?l0103oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001d0oooo0`000?l20?ooo`80
003o0`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0>03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000
oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool010000?l0oooo0?ooo`000?lh
0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0280oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`040000o`3oool0
oooo0000ocD0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?ooo`040000o`3oool0
oooo0000o`<0oooo00D0003o0?ooo`3oool0oooo0000o`0a0?ooo`@000001P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo0`000?l]0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo
00@0003o0?ooo`3oool0003o:@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo
00@0003o0?ooo`3oool0003o0P3oool010000?l0oooo0?ooo`000?lV0?ooo`<000004P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:03oool20000o`80oooo00D0003o0?ooo`3oool0oooo0000o`0S0?oo
o`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool010000?l0oooo0?ooo`000?l40?oo
o`030000o`3oool0oooo01`0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`04
0000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool06@3oool3000001h0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02/0oooo0P000?l30?ooo`050000o`3oool0oooo0?ooo`000?l05@3oool30000
0280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0P000?l30?ooo`050000o`3oool0oooo0?oo
o`000?l04P3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool2000008l0oooo00<000000?ooo`3oool0;03oool01@000?l0oooo0?ooo`3oool0003o
0080oooo00<0003o0?ooo`3oool03P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02d0
oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0:0?ooo`@00000;P3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0;`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`00
0?l01@3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`03000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo00<0
003o0?ooo`3oool00P3oool3000000030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03<0oooo00<0003o0?ooo`0000000P0000030?ooo`030000o`3oool0oooo03P0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0340oooo100000020?ooo`040000o`3oool0oooo0000oc`0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02h0oooo0`000000103oool0003o0?ooo`000?l20?ooo`040000o`3oool0
oooo0000ocd0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000040?ooo`050000o`3oool0
003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03L0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02P0oooo0`0000060?ooo`040000o`3oool0oooo0?ooo`80003o0P3o
ool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0>@3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000
2@3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3o
ool0>03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000
T03oool00`000000oooo0?ooo`0Q0?ooo`@000004`3oool01@000?l0oooo0?ooo`3oool0003o00<0
oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0
oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000001L0oooo
00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool06`3oool3000001d0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0f0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo
0`00000P0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l0>03oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000903oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A
0?ooo`@000008P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool0=`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?oo
o`<000009P3oool20000o`@0oooo0`000?l50?ooo`030000o`3oool0oooo03P0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000<`3oool20000o`80oooo00<0003o0?ooo`3o
ool0>03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000003H0oooo00@0003o0?ooo`000?l0
003o0P3oool20000ocP0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000h0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo
0`00000l0?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0>0?ooo`00803oool200000940oooo100000100?ooo`040000o`3oool0oooo0000ocl0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00140?ooo`80003o0`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<00000
0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0
A@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0A@3o
ool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`110?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0A@3oool00`00
0?l0oooo0?ooo`130?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0A@3oool00`000?l0
oooo0?ooo`140?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00
000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?oo
o`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo
00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00
001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61476 .66661 m
.61385 .66723 L
s
.6141 .66428 m
.61476 .66661 L
s
.6132 .6649 m
.6141 .66428 L
s
.61385 .66723 m
.6132 .6649 L
s
.6115 .69556 m
.61324 .67464 L
s
.60693 .658 m
.60469 .65392 L
s
.60746 .66183 m
.60693 .658 L
s
.60734 .66332 m
.60746 .66183 L
s
.6063 .66543 m
.60734 .66332 L
s
.60469 .65392 m
.60232 .65131 L
s
.60459 .66519 m
.6063 .66543 L
s
.60232 .65131 m
.59981 .65017 L
s
.60049 .66234 m
.60459 .66519 L
s
.60645 .67374 m
.60541 .67587 L
s
.59981 .65017 m
.59876 .65227 L
s
.60541 .67587 m
.6029 .67479 L
s
.59877 .6621 m
.60049 .66234 L
s
.6029 .67479 m
.60051 .6722 L
s
.59771 .66422 m
.59877 .6621 L
s
.60051 .6722 m
.59825 .66809 L
s
.59263 .64226 m
.59396 .64701 L
s
.59825 .66809 m
.59771 .66422 L
s
.59116 .63901 m
.59263 .64226 L
s
.58874 .63635 m
.59116 .63901 L
s
.58699 .63606 m
.58874 .63635 L
s
.5929 .65898 m
.59101 .66024 L
s
.58509 .63727 m
.58699 .63606 L
s
.59101 .66024 m
.58926 .65999 L
s
.58387 .64088 m
.58509 .63727 L
s
.58926 .65999 m
.58683 .65735 L
s
.58359 .64388 m
.58387 .64088 L
s
.58683 .65735 m
.58534 .65407 L
s
.58399 .64928 m
.58359 .64388 L
s
.57702 .64669 m
.579 .62562 L
s
.58534 .65407 m
.58399 .64928 L
s
.57098 .63345 m
.57243 .61839 L
s
.57684 .65822 m
.57587 .65885 L
s
.57616 .6558 m
.57684 .65822 L
s
.57519 .65643 m
.57616 .6558 L
s
.56971 .63709 m
.57098 .63345 L
s
.57587 .65885 m
.57519 .65643 L
s
.56015 .64022 m
.5633 .60834 L
s
.5679 .6368 m
.56971 .63709 L
s
.5654 .63408 m
.5679 .6368 L
s
.56387 .63074 m
.5654 .63408 L
s
.56181 .62345 m
.56387 .63074 L
s
.55529 .60455 m
.55391 .59967 L
s
.55568 .61002 m
.55529 .60455 L
s
.55391 .59967 m
.55237 .5963 L
s
.55537 .61306 m
.55568 .61002 L
s
.55237 .5963 m
.54983 .59349 L
s
.55406 .6167 m
.55537 .61306 L
s
.54419 .61106 m
.54752 .57918 L
s
.54983 .59349 m
.54797 .59313 L
s
.55205 .6179 m
.55406 .6167 L
s
.54797 .59313 m
.54595 .59429 L
s
.55019 .61757 m
.55205 .6179 L
s
.54763 .61479 m
.55019 .61757 L
s
.54607 .6114 m
.54763 .61479 L
s
.53815 .6045 m
.54042 .58313 L
s
.54467 .60647 m
.54607 .6114 L
s
.53853 .58275 m
.53993 .58769 L
s
.53697 .57933 m
.53853 .58275 L
s
.53437 .57647 m
.53697 .57933 L
s
.53247 .57608 m
.53437 .57647 L
s
.53864 .5999 m
.53657 .60108 L
s
.53039 .57721 m
.53247 .57608 L
s
.53657 .60108 m
.53467 .60072 L
s
.52902 .58084 m
.53039 .57721 L
s
.53467 .60072 m
.53205 .59788 L
s
.52868 .5839 m
.52902 .58084 L
s
.53205 .59788 m
.53047 .59444 L
s
.52905 .58946 m
.52868 .5839 L
s
.53047 .59444 m
.52905 .58946 L
s
.51615 .58062 m
.51859 .5591 L
s
.5206 .58545 m
.52326 .58834 L
s
.519 .58198 m
.5206 .58545 L
s
.5172 .57136 m
.51757 .57696 L
s
.51757 .57696 m
.519 .58198 L
s
.51184 .55684 m
.51238 .56089 L
s
.5104 .5518 m
.51184 .55684 L
s
.50879 .5483 m
.5104 .5518 L
s
.51238 .56089 m
.51184 .56551 L
s
.50519 .54434 m
.50879 .5483 L
s
.50735 .5606 m
.51184 .56551 L
s
.50321 .54389 m
.50519 .54434 L
s
.50103 .54497 m
.50321 .54389 L
s
.51042 .57789 m
.50916 .58002 L
s
.50916 .58002 m
.50699 .58119 L
s
.49975 .54706 m
.50103 .54497 L
s
.49829 .5507 m
.49975 .54706 L
s
.50699 .58119 m
.50499 .58079 L
s
.49736 .55846 m
.49829 .5507 L
s
.50499 .58079 m
.50135 .57687 L
s
.49166 .55404 m
.49064 .52831 L
s
.48426 .546 m
.49064 .52831 L
s
.49771 .56413 m
.49736 .55846 L
s
.50135 .57687 m
.49971 .57334 L
s
.49826 .56824 m
.49771 .56413 L
s
.49971 .57334 m
.49826 .56824 L
s
.48426 .546 m
.48326 .52018 L
s
.47678 .53789 m
.48326 .52018 L
s
.47018 .53072 m
.47299 .50888 L
s
.47091 .50836 m
.47239 .51353 L
s
.46923 .50473 m
.47091 .50836 L
s
.46639 .50161 m
.46923 .50473 L
s
.46429 .50107 m
.46639 .50161 L
s
.47079 .52602 m
.46849 .52709 L
s
.46198 .5021 m
.46429 .50107 L
s
.46849 .52709 m
.46639 .5266 L
s
.4604 .50574 m
.46198 .5021 L
s
.46639 .5266 m
.46353 .5235 L
s
.45999 .50887 m
.4604 .50574 L
s
.46353 .5235 m
.46182 .51985 L
s
.46032 .51462 m
.45999 .50887 L
s
.46182 .51985 m
.46032 .51462 L
s
.44615 .50464 m
.44916 .48263 L
s
.45101 .50992 m
.45392 .51307 L
s
.44929 .50623 m
.45101 .50992 L
s
.44745 .49517 m
.44777 .50096 L
s
.44777 .50096 m
.44929 .50623 L
s
.43975 .47769 m
.43823 .4724 L
s
.44029 .48191 m
.43975 .47769 L
s
.43823 .4724 m
.4355 .46758 L
s
.44061 .4877 m
.44029 .48191 L
s
.43951 .4956 m
.44061 .4877 L
s
.4355 .46758 m
.42858 .45996 L
s
.43786 .49929 m
.43951 .4956 L
s
.43643 .50141 m
.43786 .49929 L
s
.42378 .49328 m
.42858 .45996 L
s
.434 .50245 m
.43643 .50141 L
s
.43079 .50083 m
.434 .50245 L
s
.42378 .49328 m
.43079 .50083 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0;@3oool00`000?l0oooo0?ooo`1Q0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0;03oool20000of<0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0[0?ooo`030000
o`3oool0003o0680oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo02T0oooo00@0003o0?ooo`3oool0003o
HP3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool2000005l0oooo00<000000?ooo`3oool0:03oool01@000?l0oooo0?ooo`3oool0003o0640oooo
00<000000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0W0?ooo`050000o`3oool0oooo0?ooo`000?l0
H@3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool01`3oool3
000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003oG@3oool0
0`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1S0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00`3oool01000
0?l0oooo0?ooo`000?mM0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0240oooo00<0003o
0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?mM0?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0200oooo00<0003o
0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?mK0?ooo`<00000F03oool00`000000oooo0?oo
o`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01l0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0000o`1I0?ooo`<000000P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0003o0000oeD0oooo0`000005
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?oo
o`030000003oool0oooo01l0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003oDP3oool3
000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`00
0000oooo0?ooo`1Y0?ooo`030000003oool0oooo01l0oooo10000?l20?ooo`80003o103oool30000
odP0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240
oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0903oool20000o`@0
oooo00@0003o0?ooo`3oool0003oA03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
06/0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo
0000od40oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo02@0oooo00@0003o0?ooo`3oool0003o0`3oool20000ocd0oooo0`00000D0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`000?l00`3o
ool20000ocX0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo02D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0e0?ooo`<000006`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0b0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0903oool01000
0?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo02X0oooo1000000Q0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0003o00@0oooo00<0003o0?ooo`3oool09`3oool30000
02D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000
oooo0000001d0?ooo`030000003oool0oooo02@0oooo0P000?l30?ooo`80003o9P3oool3000002P0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo
00<000000?ooo`3oool0903oool010000?l0oooo0?ooo`3oool20000o`80oooo00<0003o0?ooo`3o
ool07P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0S0?ooo`040000
o`3oool0oooo0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0K0?ooo`<00000;P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0V0?ooo`80003o00<0oooo0000o`000?l0
6P3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0903o
ool010000?l0oooo0000o`3oool20000oaL0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool08`3oool01P000?l0oooo0000o`000?l0oooo0000oa@0oooo0`00000g0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0
NP3oool00`000000oooo0?ooo`0T0?ooo`80003o00<0oooo0000o`3oool0403oool3000003X0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o0`3oool20000o`T0oooo
0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo0000o`80oooo
00@0003o0?ooo`3oool0003o1@3oool300000400oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02@0oooo
00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo00000002000004<0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo02<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000000003o000000160?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`000?l00`0000000`3oool0003o0?ooo`160?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`0Q0?ooo`80000000<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000000P3oool02@000?l0oooo0?ooo`3o
ool0003o0?ooo`000?l0oooo0000o`150?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000
1P3oool00`000?l0oooo0?ooo`020?ooo`80003o00<0oooo0000o`3oool0A03oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0503oool3000000T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000
o`150?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000003@3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000@0?oo
o`030000o`3oool0oooo00<0oooo0P000?m50?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<0
00004`3oool00`000?l0oooo0?ooo`030?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0
103oool3000001L0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo0P000?lo0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`03000001X0oooo00D0003o0?ooo`3oool0003o0?ooo`020000o`<0oooo
00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001h0oooo
0P000?l20?ooo`80003o0`3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3o
ool0>03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000
S@3oool00`000000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`<0oooo00@0003o0?ooo`3o
ool0003o>@3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000o`<0oooo00@0003o0?oo
o`3oool0003o=P3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo00<0003o0?oo
o`000?l00`3oool010000?l0oooo0?ooo`000?lb0?ooo`@000001P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo0P000?l^0?ooo`<000002P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool09`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo00<0
003o0?ooo`3oool0:03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00H0003o
0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo02D0oooo0`00000B0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0X0?ooo`<0003o00D0oooo0000o`3oool0oooo0000o`0T0?ooo`<00000
5P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0000o`020?ooo`030000o`3o
ool0oooo01h0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0
003o00<0oooo00<0003o0?ooo`3oool06P3oool3000001h0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02`0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo01@0oooo0`00000R
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool0
0`000?l0oooo0?ooo`0A0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0]0?ooo`040000o`3oool0oooo
0000o`80oooo00<0003o0?ooo`3oool03P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02h0oooo0P000?l30?ooo`030000o`3oool0oooo00X0oooo1000000^0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0`0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`040?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool010000?l0oooo0?ooo`000?l30?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool01@000?l0oooo0?ooo`3oool0003o
00<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0000000200000080
oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000080oooo
00@0003o0?ooo`3oool0003o?03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool300000080oooo
0P000?l20?ooo`040000o`3oool0oooo0000ocd0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo
0`0000050?ooo`040000o`3oool0003o0000o`80oooo00D0003o0?ooo`3oool0oooo0000o`0j0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000203oool010000?l0oooo0?ooo`000?l20?oo
o`060000o`3oool0oooo0000o`3oool0003o>P3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000002`3oool0
0`000?l0oooo0?ooo`030?ooo`060000o`3oool0oooo0000o`3oool0003o>`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?oo
o`0Q0?ooo`@00000503oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo03T0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01h0oooo0`00000H0?ooo`030000o`3oool0003o00<0oooo00<0003o
0?ooo`3oool0>P3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000N0?oo
o`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool300000240oooo00<0003o0?ooo`3oool00P3oool20000ocX0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000002@0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
4@3oool4000002<0oooo0P000?l30?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
>@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000:03o
ool00`000?l0oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`0i0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool3000003<0oooo0P000?l00`3oool0003o0?ooo`0j
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000=P3oool010000?l0oooo0000o`000?l2
0?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000i0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3o
ool0oooo0`00000m0?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000110?ooo`030000o`3oool0003o03l0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo
0`0000150?ooo`80003o0P3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<0
00000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<00000
0?ooo`3oool0A`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0A`3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3o
ool0AP3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0
AP3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0A`3o
ool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0A`3oool0
0`000?l0oooo0?ooo`110?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`120?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61216 .66739 m
.61158 .66791 L
s
.61118 .66515 m
.61216 .66739 L
s
.6106 .66567 m
.61118 .66515 L
s
.61158 .66791 m
.6106 .66567 L
s
.61543 .69441 m
.61259 .67484 L
s
.60433 .65878 m
.60176 .6548 L
s
.60551 .66242 m
.60433 .65878 L
s
.60571 .6638 m
.60551 .66242 L
s
.60532 .66572 m
.60571 .6638 L
s
.60176 .6548 m
.59939 .65219 L
s
.60394 .66538 m
.60532 .66572 L
s
.59939 .65219 m
.5972 .65096 L
s
.60017 .66244 m
.60394 .66538 L
s
.6071 .67355 m
.60671 .67548 L
s
.5972 .65096 m
.5968 .65287 L
s
.60671 .67548 m
.60454 .6743 L
s
.59877 .6621 m
.60017 .66244 L
s
.60454 .6743 m
.60215 .67171 L
s
.59837 .66403 m
.59877 .6621 L
s
.60215 .67171 m
.59956 .6677 L
s
.59001 .64306 m
.592 .64761 L
s
.5882 .63991 m
.59001 .64306 L
s
.59956 .6677 m
.59837 .66403 L
s
.58579 .63725 m
.5882 .63991 L
s
.58436 .63687 m
.58579 .63725 L
s
.59355 .65878 m
.59233 .65984 L
s
.58312 .63788 m
.58436 .63687 L
s
.59233 .65984 m
.59091 .65949 L
s
.58288 .64118 m
.58312 .63788 L
s
.59091 .65949 m
.58848 .65685 L
s
.58326 .64398 m
.58288 .64118 L
s
.57867 .64619 m
.57603 .62653 L
s
.58465 .64908 m
.58326 .64398 L
s
.58848 .65685 m
.58666 .65367 L
s
.58666 .65367 m
.58465 .64908 L
s
.57131 .63335 m
.56945 .61931 L
s
.57105 .63668 m
.57131 .63335 L
s
.58084 .65701 m
.5802 .65754 L
s
.57982 .65469 m
.58084 .65701 L
s
.57919 .65522 m
.57982 .65469 L
s
.56417 .63899 m
.56031 .60927 L
s
.5802 .65754 m
.57919 .65522 L
s
.56957 .63629 m
.57105 .63668 L
s
.56707 .63357 m
.56957 .63629 L
s
.56521 .63033 m
.56707 .63357 L
s
.56214 .62334 m
.56521 .63033 L
s
.55329 .60518 m
.55124 .60051 L
s
.55468 .61034 m
.55329 .60518 L
s
.55124 .60051 m
.54937 .59725 L
s
.54937 .59725 m
.54682 .59445 L
s
.55504 .61316 m
.55468 .61034 L
s
.54588 .61053 m
.54218 .58088 L
s
.55473 .61649 m
.55504 .61316 L
s
.54682 .59445 m
.54529 .59398 L
s
.5534 .61748 m
.55473 .61649 L
s
.54529 .59398 m
.54393 .59493 L
s
.55187 .61705 m
.5534 .61748 L
s
.54931 .61426 m
.55187 .61705 L
s
.53984 .60397 m
.5374 .5841 L
s
.54742 .61097 m
.54931 .61426 L
s
.54535 .60626 m
.54742 .61097 L
s
.53584 .58361 m
.53792 .58833 L
s
.53394 .5803 m
.53584 .58361 L
s
.53134 .57744 m
.53394 .5803 L
s
.52977 .57695 m
.53134 .57744 L
s
.53931 .59968 m
.53793 .60065 L
s
.52837 .57786 m
.52977 .57695 L
s
.53793 .60065 m
.53636 .60019 L
s
.528 .58116 m
.52837 .57786 L
s
.53636 .60019 m
.53375 .59734 L
s
.52834 .58401 m
.528 .58116 L
s
.52973 .58925 m
.52834 .58401 L
s
.53375 .59734 m
.53183 .59401 L
s
.53183 .59401 m
.52973 .58925 L
s
.51786 .58007 m
.51554 .56009 L
s
.5223 .58491 m
.52496 .58779 L
s
.51686 .57147 m
.51825 .57674 L
s
.52036 .58154 m
.5223 .58491 L
s
.51825 .57674 m
.52036 .58154 L
s
.50979 .55751 m
.51101 .56134 L
s
.50768 .5527 m
.50979 .55751 L
s
.50572 .5493 m
.50768 .5527 L
s
.51101 .56134 m
.5115 .56562 L
s
.50212 .54535 m
.50572 .5493 L
s
.50701 .56072 m
.5115 .56562 L
s
.50047 .54479 m
.50212 .54535 L
s
.49897 .54565 m
.50047 .54479 L
s
.51282 .57712 m
.51225 .57903 L
s
.49838 .54751 m
.49897 .54565 L
s
.51225 .57903 m
.51077 .57997 L
s
.49794 .55082 m
.49838 .54751 L
s
.51077 .57997 m
.50913 .57946 L
s
.49874 .55801 m
.49794 .55082 L
s
.50913 .57946 m
.50549 .57554 L
s
.49339 .55348 m
.48754 .52934 L
s
.48599 .54543 m
.48754 .52934 L
s
.50013 .56334 m
.49874 .55801 L
s
.50549 .57554 m
.50351 .57211 L
s
.50136 .56723 m
.50013 .56334 L
s
.50351 .57211 m
.50136 .56723 L
s
.48599 .54543 m
.48015 .52122 L
s
.47852 .53731 m
.48015 .52122 L
s
.47193 .53014 m
.46988 .50993 L
s
.46814 .5093 m
.47031 .51424 L
s
.46611 .50579 m
.46814 .5093 L
s
.46327 .50267 m
.46611 .50579 L
s
.46151 .50202 m
.46327 .50267 L
s
.47148 .52578 m
.46988 .52663 L
s
.45989 .50281 m
.46151 .50202 L
s
.46988 .52663 m
.46813 .52602 L
s
.45936 .50609 m
.45989 .50281 L
s
.46813 .52602 m
.46527 .52291 L
s
.45964 .50899 m
.45936 .50609 L
s
.46102 .51438 m
.45964 .50899 L
s
.46527 .52291 m
.46322 .51938 L
s
.46322 .51938 m
.46102 .51438 L
s
.44791 .50404 m
.44601 .48372 L
s
.45277 .50932 m
.45568 .51247 L
s
.44709 .49529 m
.44848 .50072 L
s
.45069 .50575 m
.45277 .50932 L
s
.44848 .50072 m
.45069 .50575 L
s
.43764 .47842 m
.43541 .47337 L
s
.43888 .48239 m
.43764 .47842 L
s
.43541 .47337 m
.43233 .46869 L
s
.44026 .48782 m
.43888 .48239 L
s
.43233 .46869 m
.4254 .46108 L
s
.44092 .49512 m
.44026 .48782 L
s
.44034 .49845 m
.44092 .49512 L
s
.42806 .49181 m
.4254 .46108 L
s
.43962 .50032 m
.44034 .49845 L
s
.43791 .50112 m
.43962 .50032 L
s
.43506 .49937 m
.43791 .50112 L
s
.42806 .49181 m
.43506 .49937 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0:`3oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0:P3oool20000ofD0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0Y0?ooo`030000
o`3oool0003o06@0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo02P0oooo00@0003o0?ooo`3oool0003o
H`3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool2000005l0oooo00<000000?ooo`3oool09`3oool010000?l0oooo0?ooo`000?mS0?ooo`030000
003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool09P3oool01@000?l0oooo0?ooo`3oool0003o0680oooo
00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0H03oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l0
H@3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo00D0003o0?ooo`3oool0oooo
0000o`1Q0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0903oool01@000?l0oooo0?oo
o`3oool0003o0080oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`040?ooo`<00000
CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo02<0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo05`0oooo
00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000
003oool0oooo06@0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0003o05h0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0003o05`0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06L0oooo00<000000?ooo`3oool08@3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0
F@3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3o
ool00`000000oooo0000001X0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0003o
0P3oool00`000?l0oooo0?ooo`1C0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3o
ool0003o0080oooo00<0003o0?ooo`3oool0D03oool3000000P0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0
oooo0280oooo0P000?l20?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0B03oool3
000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool20000
00L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0U0?ooo`070000o`3oool0oooo
0?ooo`000?l0oooo0000o`160?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`0U0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0
@03oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0000o`020?ooo`80003o?P3oool3000001@0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo06h0oooo00<000000?ooo`3oool09@3oool20000o`80oooo0P000?lk0?ooo`<00000
603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0V0?ooo`040000
o`3oool0oooo0000ocP0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
9@3oool010000?l0oooo0?ooo`000?le0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
9@3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo02/0oooo1000000Q0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3o
ool00`000000oooo0?ooo`0T0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool0
:03oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03o
ool00`000000oooo0000001d0?ooo`030000003oool0oooo02@0oooo0`000?l20?ooo`030000o`3o
ool0oooo02D0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo0P00001f0?ooo`030000003oool0oooo02D0oooo00D0003o0?ooo`000?l0oooo0000
o`0S0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0004
0?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02@0oooo00L0003o
0?ooo`000?l0oooo0000o`3oool0003o01h0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo02D0oooo00D0003o0?ooo`000?l0oooo0000o`0K0?ooo`<00000
<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003o
ool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0T0?ooo`050000o`3o
ool0003o0?ooo`000?l0603oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0U0?ooo`80003o00<0oooo0000o`3oool04`3oool3000003L0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo02D0oooo00<0003o0?ooo`000?l04@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
02@0oooo00<0003o0?ooo`000?l00P3oool20000o`X0oooo0`00000m0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oool0003o0080oooo0P000?l70?ooo`<00000@03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool09@3oool01@000?l0oooo0000o`3oool0003o00<0oooo0`0000130?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0003o0080oooo00<0003o000000000000
AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3o
ool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0003o0080000000<0003o0?ooo`3oool0AP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool08@3oool3000000050000o`3oool0oooo0?ooo`000?l0A`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08<0oooo00<000000?ooo`3oool0703oool4000000<0oooo00<0003o0?ooo`3oool00P000?l0
0`3oool0003o0?ooo`150?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool0
02H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000001`3oool01`00
0?l0oooo0?ooo`3oool0003o0?ooo`000?l0AP3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
000000X0oooo00<0003o0?ooo`3oool00P3oool20000odH0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0100oooo0`00000>0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0A03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0303oool300000180oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000005@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00
000H0?ooo`060000o`3oool0oooo0000o`3oool0003o0`3oool20000od00oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo00<00000703oool30000o`030?ooo`000?l0oooo0080oooo0P000?m00?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03o
ool2000002@0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?ooo`030000o`3oool0oooo03X0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo
00<000000?ooo`3oool0903oool00`000?l0oooo0000o`020?ooo`030000o`3oool0003o03/0oooo
0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool09@3oool20000o`80oooo00<0003o0?ooo`000?l0>03oool300000080oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo02H0oooo00H0003o0?ooo`3oool0003o0?ooo`000?ld0?ooo`@00000
1P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool09P3oool01P000?l0oooo0?ooo`000?l0oooo0000oc40
oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00@0003o
;03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00L0003o0?ooo`000?l0oooo
0000o`3oool0003o02P0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`80003o
00@0oooo0000o`3oool0003o9@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo
00D0003o0?ooo`000?l0oooo0000o`0Q0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
;03oool010000?l0oooo0?ooo`000?lM0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
;03oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo01D0oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0/0?ooo`80003o0P3oool00`000?l0oooo0000o`0D0?ooo`<00000
9P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3o
ool00`000000oooo0?ooo`0^0?ooo`050000o`3oool0003o0?ooo`000?l04@3oool3000002X0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02l0oooo0P000?l00`3oool0003o0?ooo`0<0?ooo`@00000;P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0<`3oool010000?l0oooo0?ooo`000?l70?ooo`<00000<`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0<`3oool010000?l0oooo0?ooo`000?l40?ooo`<00000=P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0<`3oool20000o`030?ooo`000?l0oooo00<00000>P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0=03oool01P000?l00000000000000000oooo0000oc`0oooo00<0
00000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo0340oooo100000001@000?l0oooo0000o`3oool0003o03d0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02h0oooo0`0000030?ooo`80003o00@0oooo0000o`3oool0003o?P3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000H0oooo00H0003o0?ooo`000?l0003o0?oo
o`000?ln0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000002@3oool010000?l0oooo0?oo
o`000?l20?ooo`<0003o?03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo
000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000004P3oool20000o`030?ooo`00
0?l0oooo03/0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool2
00000900oooo00<000000?ooo`3oool08@3oool4000001D0oooo0P000?l20?ooo`030000o`3oool0
oooo03X0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000I0?ooo`80003o0P3oool00`00
0?l0oooo0?ooo`0k0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0
oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000001h0
oooo00@0003o0?ooo`3oool0003o?03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0H0?ooo`<000008@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
03T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool300000280
oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`0k0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool04@3oool4000002D0oooo00@0003o0?ooo`3oool0003o103oool00`00
0?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0
oooo0`00000]0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool02`3oool3000003<0oooo0P000?l00`3oool0003o0?ooo`0j0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`080?ooo`<00000=P3oool01P000?l0oooo0000o`000?l0oooo0000ocX0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000i0?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000m0?ooo`030000
o`3oool0oooo03l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool200000940oooo100000110?ooo`030000o`3oool0003o03l0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000150?ooo`80003o00<0oooo
0000o`3oool0?03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04H0oooo00<0003o0?oo
o`3oool0?03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3o
ool0?@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0
?P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07l0oooo0`00000?0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07`0oooo0`00000A0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0
oooo1000000D0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0@03oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo
0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`03
0000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000
:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3o
ool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo
0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?oo
o`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`03
0000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000
B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo
0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003o
ool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2
000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo
0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?oo
o`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<00000
0?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
2`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003o
ool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool40000
0900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3o
ool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003o
ool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3o
ool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00
002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303o
ool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool0
0`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool0
0280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo
0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0
Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
1P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003o
ool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`00
0000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300
oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000
oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo
0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo
0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?oo
o`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo
0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000
oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo
0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00
001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?oo
o`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo
0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00
001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?oo
o`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`80
00002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?oo
o`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`03
0000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00
?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003o
ool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool0
05T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo
0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580
oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`80
0000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00
H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P000002
0?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@0
00001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3o
ool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo
00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<0
00000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b
0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?oo
o`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@0
0000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3o
ool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2
000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool01000
0000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool5
00000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0
oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo
00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool0
06T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo
0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?oo
o`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000
000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<00000
0?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`03
0000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0
G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3o
ool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4
000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980
oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo
0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<00000
0?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?oo
o`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3o
ool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0
;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003o
ool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0
000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool4
00000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool0
0`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80
000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo
0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<0
00000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3o
ool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool3
00000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60964 .66864 m
.60938 .66901 L
s
.60835 .66656 m
.60964 .66864 L
s
.60808 .66693 m
.60835 .66656 L
s
.60938 .66901 m
.60808 .66693 L
s
.61925 .69252 m
.61196 .67515 L
s
.60179 .66005 m
.59891 .65623 L
s
.60361 .66337 m
.60179 .66005 L
s
.60412 .6646 m
.60361 .66337 L
s
.60437 .66619 m
.60412 .6646 L
s
.59891 .65623 m
.59653 .65363 L
s
.6033 .6657 m
.60437 .66619 L
s
.59653 .65363 m
.59466 .65224 L
s
.59985 .6626 m
.6033 .6657 L
s
.60774 .67323 m
.60799 .67485 L
s
.59466 .65224 m
.59489 .65382 L
s
.60799 .67485 m
.60613 .6735 L
s
.59877 .6621 m
.59985 .6626 L
s
.60613 .6735 m
.60375 .67091 L
s
.599 .66371 m
.59877 .6621 L
s
.58745 .64435 m
.59008 .64857 L
s
.58533 .64136 m
.58745 .64435 L
s
.60375 .67091 m
.60084 .66706 L
s
.58291 .6387 m
.58533 .64136 L
s
.60084 .66706 m
.599 .66371 L
s
.5818 .63816 m
.58291 .6387 L
s
.58119 .63885 m
.5818 .63816 L
s
.5942 .65846 m
.59362 .6592 L
s
.58191 .64166 m
.58119 .63885 L
s
.59362 .6592 m
.59252 .65868 L
s
.59252 .65868 m
.59009 .65604 L
s
.58294 .64414 m
.58191 .64166 L
s
.58029 .64537 m
.57314 .628 L
s
.58529 .64876 m
.58294 .64414 L
s
.59009 .65604 m
.58795 .65302 L
s
.58795 .65302 m
.58529 .64876 L
s
.57164 .63318 m
.56655 .62078 L
s
.57235 .63602 m
.57164 .63318 L
s
.56811 .637 m
.5574 .61076 L
s
.58474 .65505 m
.58443 .65542 L
s
.58339 .6529 m
.58474 .65505 L
s
.58309 .65326 m
.58339 .6529 L
s
.58443 .65542 m
.58309 .65326 L
s
.5712 .63547 m
.57235 .63602 L
s
.5687 .63274 m
.5712 .63547 L
s
.56651 .62967 m
.5687 .63274 L
s
.56247 .62318 m
.56651 .62967 L
s
.55133 .60618 m
.54863 .60185 L
s
.5537 .61083 m
.55133 .60618 L
s
.54863 .60185 m
.54643 .59875 L
s
.54643 .59875 m
.54388 .59595 L
s
.54753 .60969 m
.53697 .58357 L
s
.55471 .61333 m
.5537 .61083 L
s
.55539 .61615 m
.55471 .61333 L
s
.54388 .59595 m
.54267 .59532 L
s
.54267 .59532 m
.54197 .59593 L
s
.55471 .61681 m
.55539 .61615 L
s
.55352 .61621 m
.55471 .61681 L
s
.55095 .61342 m
.55352 .61621 L
s
.54149 .60312 m
.53444 .58562 L
s
.54873 .6103 m
.55095 .61342 L
s
.53321 .58496 m
.53594 .58934 L
s
.53098 .58183 m
.53321 .58496 L
s
.546 .60592 m
.54873 .6103 L
s
.52838 .57897 m
.53098 .58183 L
s
.52713 .57831 m
.52838 .57897 L
s
.52638 .57888 m
.52713 .57831 L
s
.53997 .59935 m
.53925 .59997 L
s
.52701 .58167 m
.52638 .57888 L
s
.53925 .59997 m
.53802 .59934 L
s
.53802 .59934 m
.53541 .59649 L
s
.52801 .58418 m
.52701 .58167 L
s
.53039 .5889 m
.52801 .58418 L
s
.53541 .59649 m
.53315 .59333 L
s
.53315 .59333 m
.53039 .5889 L
s
.51953 .57921 m
.51255 .56164 L
s
.52397 .58405 m
.52663 .58694 L
s
.51653 .57165 m
.51892 .57639 L
s
.5217 .58085 m
.52397 .58405 L
s
.51892 .57639 m
.5217 .58085 L
s
.50779 .55855 m
.50968 .56203 L
s
.50501 .55408 m
.50779 .55855 L
s
.50272 .55087 m
.50501 .55408 L
s
.50968 .56203 m
.51117 .5658 L
s
.49911 .54692 m
.50272 .55087 L
s
.50667 .56089 m
.51117 .5658 L
s
.49779 .54618 m
.49911 .54692 L
s
.49696 .5467 m
.49779 .54618 L
s
.51517 .5759 m
.51528 .57747 L
s
.49704 .54821 m
.49696 .5467 L
s
.51528 .57747 m
.51448 .57806 L
s
.49761 .55099 m
.49704 .54821 L
s
.51448 .57806 m
.51318 .57737 L
s
.50009 .55731 m
.49761 .55099 L
s
.49509 .55259 m
.48451 .53093 L
s
.48769 .54454 m
.48451 .53093 L
s
.51318 .57737 m
.50955 .57344 L
s
.5025 .56211 m
.50009 .55731 L
s
.50955 .57344 m
.50723 .57018 L
s
.50441 .56565 m
.5025 .56211 L
s
.50723 .57018 m
.50441 .56565 L
s
.48769 .54454 m
.47711 .52282 L
s
.48023 .53641 m
.47711 .52282 L
s
.47364 .52924 m
.46682 .51155 L
s
.46542 .51073 m
.46827 .51531 L
s
.46304 .50741 m
.46542 .51073 L
s
.4602 .50429 m
.46304 .50741 L
s
.45878 .50347 m
.4602 .50429 L
s
.45783 .5039 m
.45878 .50347 L
s
.47217 .52542 m
.47126 .5259 L
s
.45833 .50664 m
.45783 .5039 L
s
.47126 .5259 m
.46985 .52511 L
s
.46985 .52511 m
.46699 .522 L
s
.45929 .50917 m
.45833 .50664 L
s
.46171 .51402 m
.45929 .50917 L
s
.46699 .522 m
.4646 .51865 L
s
.4646 .51865 m
.46171 .51402 L
s
.44965 .50312 m
.44292 .48537 L
s
.4545 .5084 m
.4574 .51156 L
s
.44675 .49547 m
.44917 .50035 L
s
.45208 .50502 m
.4545 .5084 L
s
.44917 .50035 m
.45208 .50502 L
s
.43556 .47953 m
.43265 .47486 L
s
.4375 .48313 m
.43556 .47953 L
s
.43265 .47486 m
.42922 .47036 L
s
.43991 .48801 m
.4375 .48313 L
s
.42922 .47036 m
.42228 .46276 L
s
.44231 .49438 m
.43991 .48801 L
s
.44278 .49715 m
.44231 .49438 L
s
.43228 .48956 m
.42228 .46276 L
s
.44276 .49865 m
.44278 .49715 L
s
.44176 .49907 m
.44276 .49865 L
s
.43927 .49713 m
.44176 .49907 L
s
.43228 .48956 m
.43927 .49713 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3o
ool0I@3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02P0oooo0`000?mU0?ooo`030000
003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`800000G@3o
ool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0003o06@0oooo00<000000?ooo`3oool0503o
ool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0
oooo02L0oooo00<0003o0?ooo`000?l0I03oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`000?l0H`3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02H0
oooo00<0003o0?ooo`000?l0H`3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo
00@0003o0?ooo`3oool0003oHP3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02D0oooo
00@0003o0?ooo`3oool0003oH@3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02@0oooo
00H0003o0?ooo`3oool0003o0?ooo`000?mO0?ooo`040000003oool0oooo0?ooo`<00000DP3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo
02@0oooo00<0003o0?ooo`3oool00P000?mO0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?oo
o`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02<0oooo00H0003o0?ooo`3o
ool0003o0?ooo`000?mL0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`00
0000oooo0?ooo`1W0?ooo`030000003oool0oooo02<0oooo0P000?l00`3oool0003o0000o`1I0?oo
o`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0000006P0oooo00<000000?ooo`3oool0903oool40000oeD0oooo0`0000050?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000
003oool0oooo02D0oooo0`000?mB0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool09P3o
ool20000odh0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool09P3oool0
10000?l0oooo0?ooo`000?m80?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3o
ool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00<0003o@`3oool300000140oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool09@3oool01@000?l0oooo0000
o`3oool0003o0400oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo02D0oooo0P000?l00`3oool0003o0000o`0l0?ooo`<00000603oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0003o03T0oooo
0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P00
00060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool09@3oool010000?l0oooo0?oo
o`000?le0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0000
o`0a0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y
0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool09@3oool20000o`80oooo00<0003o
0?ooo`3oool0:@3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F
0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo02D0oooo0P000?l00`3o
ool0003o0?ooo`0W0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0U0?ooo`040000o`3oool0003o0000
ob@0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool09`3oool00`000?l0
oooo0000o`0O0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0V0?ooo`<0003o703oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool09@3oool40000oaP0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool09P3oool20000oaD0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0U0?oo
o`80003o4P3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02D0oooo0P000?l>0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool09@3oool010000?l0oooo0000o`000?l80?ooo`<0
0000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07h0oooo00<000000?ooo`3oool09@3oool30000o`D0oooo0`0000130?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3o
ool00`000000oooo0?ooo`0T0?ooo`80003o00<0oooo0000o`3oool00`0000160?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0
oooo02@0oooo00@0003o000000000000003oB@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3
000000040000o`3oool0oooo0000odP0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo10000003
0?ooo`040000o`3oool0oooo0000odT0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`000008
0?ooo`030000o`3oool0003o0080003oA`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool30000
00`0oooo00@0003o0?ooo`000?l0003oA`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool30000
00l0oooo00D0003o0?ooo`3oool0oooo0000o`160?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?oo
o`<000004`3oool010000?l0oooo0?ooo`000?m60?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?oo
o`<000005`3oool010000?l0oooo0000o`000?m50?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<000006`3oool30000odD0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000007`3oool30000o`03
0?ooo`000?l0003o0440oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`800000903oool01@000?l0oooo0000o`3oool0003o0400
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo
00<000000?ooo`3oool0903oool010000?l0oooo0000o`3oool20000ocd0oooo0P00001K0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
9@3oool20000o`030?ooo`000?l0003o03X0oooo0`0000020?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0W0?ooo`@0003o=@3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02P0oooo0`000?lb
0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool20000o`030?ooo`000?l0003o
02d0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`<0003o00<0oooo0000o`3o
ool0:03oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo0P000?l00`3oool0003o
0000o`0V0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool30000ob80oooo1000
000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0/0?ooo`<0003o7P3oool3000001h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02`0oooo0`000?lK0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0;@3oool01@000?l0oooo0000o`3oool0003o01D0oooo0`00000V0?ooo`030000003oool0oooo
0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo02h0
oooo00@0003o0?ooo`000?l0003o4P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02l0
oooo0P000?l00`3oool0003o0?ooo`0<0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
<`3oool00`000?l0oooo0?ooo`080?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03o
ool20000o`D0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`80003o0P3oool3
000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03@0oooo00D0003o00000000000000000000o`0m
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@000000P000?l00`3oool0003o0?ooo`0m0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000103oool30000o`030?ooo`000?l0oooo03d0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000080?ooo`80003o00<0oooo0000o`3oool0
?@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000/0oooo00H0003o0?ooo`3oool0003o
0?ooo`000?lm0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo
0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000A0?ooo`040000o`3oool0003o0000ocd0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo
00<000000?ooo`3oool08@3oool4000001D0oooo0P000?l00`3oool0003o0?ooo`0l0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0N0?ooo`<000006@3oool20000o`030?ooo`000?l0oooo03d0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<000007P3oool00`000?l0oooo0000o`0m
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000Q
0?ooo`050000o`3oool0oooo0?ooo`000?l0?03oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0E0?ooo`<000008`3oool30000o`80oooo00<0003o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000W0?ooo`030000o`3oool0003o
0080oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0>0?ooo`<00000;P3oool010000?l0oooo0?ooo`000?lm0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool02`3oool3000003<0oooo0P000?lm0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`080?ooo`<00000=P3oool00`000?l0oooo0000o`0m0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`040?ooo`@00000>P3oool20000o`030?ooo`000?l0oooo03/0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0
oooo0?ooo`<00000?`3oool00`000?l0oooo0000o`0m0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000@`3oool20000och0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000170?oo
o`80003o?@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3o
ool0?03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0
?03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool0?@3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo0880oooo0`00000<0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07l0oooo0`00000?0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0
oooo0`00000A0?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0?@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo
1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000
903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo
1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<00000
0?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo
0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?oo
o`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003o
ool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo
0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<00000
0?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?oo
o`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
3P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003o
ool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool30000
08d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2
000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool0
00P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0
oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<0
00000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3o
ool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0
oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j
0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00
>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?oo
o`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c
0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04
0?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000
003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000
oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo
0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`38
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool00000
0?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool0
0000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool0
04@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo0000
0580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo
00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0
e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?oo
o`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`03
0000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2
000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`00
0000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000
000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S
0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3o
ool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool0
0`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`00
0000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000
oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool00000
02d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0
oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?oo
o`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?oo
o`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e
0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?oo
o`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00
R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000
LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000
M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0
oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo
00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?oo
o`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`15
0?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?oo
o`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?oo
o`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00
S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3o
ool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool0
0`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0
oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo
0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000
oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool50000
0;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo
00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?oo
o`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?
0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool01000
0000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0
oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool50000
0080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0
oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.6073 .67033 m
.60733 .67049 L
s
.60571 .66846 m
.6073 .67033 L
s
.60574 .66862 m
.60571 .66846 L
s
.60733 .67049 m
.60574 .66862 L
s
.6228 .68997 m
.61137 .67557 L
s
.59944 .66175 m
.59626 .65814 L
s
.60185 .66464 m
.59944 .66175 L
s
.60265 .66566 m
.60185 .66464 L
s
.60348 .66683 m
.60265 .66566 L
s
.59626 .65814 m
.59388 .65554 L
s
.60271 .66613 m
.60348 .66683 L
s
.59388 .65554 m
.5923 .65394 L
s
.59955 .66282 m
.60271 .66613 L
s
.60833 .67281 m
.60917 .674 L
s
.5923 .65394 m
.59311 .6551 L
s
.60917 .674 m
.60762 .67244 L
s
.59877 .6621 m
.59955 .66282 L
s
.60762 .67244 m
.60523 .66984 L
s
.5996 .66328 m
.59877 .6621 L
s
.58508 .64606 m
.5883 .64985 L
s
.58266 .64329 m
.58508 .64606 L
s
.60523 .66984 m
.60203 .66621 L
s
.58023 .64064 m
.58266 .64329 L
s
.60203 .66621 m
.5996 .66328 L
s
.57942 .63988 m
.58023 .64064 L
s
.5794 .64014 m
.57942 .63988 L
s
.59479 .65803 m
.59481 .65833 L
s
.58102 .64231 m
.5794 .64014 L
s
.59481 .65833 m
.59402 .6576 L
s
.59402 .6576 m
.59159 .65496 L
s
.58264 .64436 m
.58102 .64231 L
s
.5818 .64428 m
.57045 .62995 L
s
.58589 .64833 m
.58264 .64436 L
s
.59159 .65496 m
.58915 .65216 L
s
.58915 .65216 m
.58589 .64833 L
s
.57194 .63296 m
.56385 .62274 L
s
.57356 .63515 m
.57194 .63296 L
s
.57178 .63435 m
.55468 .61273 L
s
.58837 .65243 m
.58837 .65257 L
s
.58672 .65049 m
.58837 .65243 L
s
.58672 .65064 m
.58672 .65049 L
s
.58837 .65257 m
.58672 .65064 L
s
.57271 .63437 m
.57356 .63515 L
s
.57021 .63164 m
.57271 .63437 L
s
.56773 .62879 m
.57021 .63164 L
s
.56277 .62296 m
.56773 .62879 L
s
.54951 .6075 m
.5462 .60361 L
s
.55278 .6115 m
.54951 .6075 L
s
.5462 .60361 m
.5437 .60074 L
s
.5437 .60074 m
.54114 .59794 L
s
.54906 .60858 m
.53211 .5871 L
s
.55441 .61355 m
.55278 .6115 L
s
.556 .61571 m
.55441 .61355 L
s
.54114 .59794 m
.54024 .59709 L
s
.54024 .59709 m
.54013 .59727 L
s
.55593 .61592 m
.556 .61571 L
s
.55505 .6151 m
.55593 .61592 L
s
.55249 .61231 m
.55505 .6151 L
s
.54303 .602 m
.53169 .58762 L
s
.54996 .60941 m
.55249 .61231 L
s
.53076 .58675 m
.5341 .59068 L
s
.52822 .58384 m
.53076 .58675 L
s
.54662 .60548 m
.54996 .60941 L
s
.52561 .58099 m
.52822 .58384 L
s
.52467 .5801 m
.52561 .58099 L
s
.52453 .58023 m
.52467 .5801 L
s
.54059 .5989 m
.54049 .59907 L
s
.52608 .58235 m
.52453 .58023 L
s
.54049 .59907 m
.53957 .59822 L
s
.53957 .59822 m
.53695 .59537 L
s
.5277 .58441 m
.52608 .58235 L
s
.53101 .58845 m
.5277 .58441 L
s
.53695 .59537 m
.53439 .59243 L
s
.53439 .59243 m
.53101 .58845 L
s
.52109 .57807 m
.50976 .56368 L
s
.52553 .58291 m
.52818 .5858 L
s
.51622 .57187 m
.51954 .57594 L
s
.52295 .57994 m
.52553 .58291 L
s
.51954 .57594 m
.52295 .57994 L
s
.50592 .55991 m
.50843 .56294 L
s
.50252 .55591 m
.50592 .55991 L
s
.49991 .55292 m
.50252 .55591 L
s
.50843 .56294 m
.51086 .56602 L
s
.4963 .54898 m
.49991 .55292 L
s
.50636 .56112 m
.51086 .56602 L
s
.49529 .54802 m
.4963 .54898 L
s
.49508 .54808 m
.49529 .54802 L
s
.51737 .5743 m
.51811 .5754 L
s
.49578 .54913 m
.49508 .54808 L
s
.51811 .5754 m
.51795 .57552 L
s
.49729 .55122 m
.49578 .54913 L
s
.51795 .57552 m
.51697 .5746 L
s
.50135 .55639 m
.49729 .55122 L
s
.49667 .55143 m
.48168 .53301 L
s
.48929 .54337 m
.48168 .53301 L
s
.51697 .5746 m
.51335 .57066 L
s
.50471 .5605 m
.50135 .55639 L
s
.51335 .57066 m
.51072 .56764 L
s
.50726 .56357 m
.50471 .5605 L
s
.51072 .56764 m
.50726 .56357 L
s
.48929 .54337 m
.47426 .52491 L
s
.48183 .53524 m
.47426 .52491 L
s
.47524 .52806 m
.46395 .51365 L
s
.46286 .51261 m
.46636 .51672 L
s
.46017 .50952 m
.46286 .51261 L
s
.45732 .50641 m
.46017 .50952 L
s
.45622 .50535 m
.45732 .50641 L
s
.45591 .50531 m
.45622 .50535 L
s
.47281 .52495 m
.47254 .52496 L
s
.45736 .50735 m
.45591 .50531 L
s
.47254 .52496 m
.47146 .52393 L
s
.47146 .52393 m
.46861 .52082 L
s
.45897 .50941 m
.45736 .50735 L
s
.46235 .51355 m
.45897 .50941 L
s
.46861 .52082 m
.46589 .5177 L
s
.46589 .5177 m
.46235 .51355 L
s
.45127 .50192 m
.44001 .48751 L
s
.45613 .50721 m
.45902 .51037 L
s
.44642 .49571 m
.44982 .49987 L
s
.45338 .50406 m
.45613 .50721 L
s
.44982 .49987 m
.45338 .50406 L
s
.43361 .48097 m
.43005 .47678 L
s
.4362 .48409 m
.43361 .48097 L
s
.43005 .47678 m
.42629 .47252 L
s
.43959 .48825 m
.4362 .48409 L
s
.42629 .47252 m
.41934 .46493 L
s
.44362 .49342 m
.43959 .48825 L
s
.44507 .49546 m
.44362 .49342 L
s
.43625 .48662 m
.41934 .46493 L
s
.44571 .49647 m
.44507 .49546 L
s
.44537 .49641 m
.44571 .49647 L
s
.44322 .49422 m
.44537 .49641 L
s
.43625 .48662 m
.44322 .49422 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3o
ool0IP3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0
I@3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`1T0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0W0?ooo`80003oI@3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
02L0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02L0
oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02L0oooo
0P000?mR0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool09P3oool20000of80oooo00<0
00000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo0600oooo00@00000
0?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool09P3oool20000of00oooo1000001E0?ooo`030000003oool0
oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool09P3oool20000
oed0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0
oooo00<000000?ooo`3oool09P3oool20000oeT0oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`0V0?ooo`030000o`3oool0oooo05@0oooo0`0000050?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02L0oooo00<0
003o0?ooo`3oool0D03oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02L0oooo00<0003o
0?ooo`3oool0C03oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0W0?oo
o`030000o`3oool0oooo04P0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0A03oool300000140oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`100?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0V0?oo
o`80003o?P3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool09P3oool20000ocX0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool09P3oool20000ocH0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo02l0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0V0?ooo`80003o;@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo02H0oooo0P000?lY0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0V0?ooo`80003o9@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0V0?ooo`030000o`3oool0oooo0200oooo0`00000^0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0703oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?oo
o`0H0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0004
0?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02D0oooo0P000?lF
0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool09@3oool20000oa80oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00d0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0U0?ooo`<0003o2@3oool300000400oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02D0oooo0P000?l60?ooo`<00000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool09@3oool2
0000o`80oooo0`0000160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0P000?l00`000000oooo0?ooo`170?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<0000000<0oooo0000o`000?l0B@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool4000000D0oooo0P000?m90?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0H0?ooo`<000002P3oool20000odP0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000=
0?ooo`<0003oA`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool300000140oooo0P000?m70?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000005@3oool20000odH0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo00P0oooo0`00000I0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103o
ool3000001d0oooo0P000?m40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000240oooo0`000?m2
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0S03oool2000002H0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0U0?ooo`80
003o@03oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0V0?ooo`80003o?03oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02L0oooo0P000?lg0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool2
0000oc<0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`80003o;`3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo0P000?l[0?ooo`<000004P3oool00`000000
oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0:P3oool30000obL0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0[0?ooo`<0003o8P3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo00<0003o
0?ooo`3oool07@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02h0oooo00<0003o0?oo
o`3oool06@3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3o
ool05@3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool2000008l0oooo00<000000?ooo`3oool0;`3oool20000oa<0oooo0`00000Z0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0`0?ooo`80003o3P3oool4000002h0oooo00<000000?ooo`3oool0D03o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0380oooo00<0003o0?ooo`3oool02@3oool3000003<0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03<0oooo0P000?l60?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool20000o`80
oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0<@3oool4000000<0003o?`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3
000000D0oooo0`000?lo0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000002@3oool30000
och0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00000>0?ooo`030000o`3oool0oooo03d0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo
00<000000?ooo`3oool09@3oool300000180oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?oo
o`0Q0?ooo`@000005P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<000006P3oool20000ocl0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<000007P3oool20000och0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool300000280oooo0P000?ln0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01D0oooo0`00000V0?ooo`80003o?P3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0140oooo1000000Z0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002l0oooo00<0003o0?ooo`3oool0?@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000c0?ooo`030000o`3oool0
oooo03`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000f0?ooo`<0003o?@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0103oool4000003X0oooo0`000?lm0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo
0?ooo`3oool3000003l0oooo0P000?ln0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000@`3oool20000och0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000180?ooo`030000o`3o
ool0oooo03/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0
oooo03/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo
03/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000
oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo03`0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`190?ooo`030000o`3oool0oooo03`0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`1:0?ooo`030000o`3oool0oooo03`0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l
0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60524 .67237 m
.60552 .67227 L
s
.6034 .67075 m
.60524 .67237 L
s
.60368 .67066 m
.6034 .67075 L
s
.60552 .67227 m
.60368 .67066 L
s
.62592 .68687 m
.61085 .67609 L
s
.59737 .66379 m
.59393 .66045 L
s
.60029 .66618 m
.59737 .66379 L
s
.60136 .66694 m
.60029 .66618 L
s
.6027 .6676 m
.60136 .66694 L
s
.59393 .66045 m
.59155 .65785 L
s
.60219 .66664 m
.6027 .6676 L
s
.59155 .65785 m
.59022 .656 L
s
.59929 .66307 m
.60219 .66664 L
s
.60885 .67229 m
.61021 .67297 L
s
.59022 .656 m
.59155 .65665 L
s
.61021 .67297 m
.60892 .67115 L
s
.59877 .6621 m
.59929 .66307 L
s
.60892 .67115 m
.60654 .66855 L
s
.60012 .66276 m
.59877 .6621 L
s
.58299 .64813 m
.58674 .65141 L
s
.58031 .64561 m
.58299 .64813 L
s
.60654 .66855 m
.60307 .66517 L
s
.57788 .64297 m
.58031 .64561 L
s
.60307 .66517 m
.60012 .66276 L
s
.57732 .64196 m
.57788 .64297 L
s
.57783 .6417 m
.57732 .64196 L
s
.59532 .65751 m
.59586 .65729 L
s
.58023 .64309 m
.57783 .6417 L
s
.59586 .65729 m
.59533 .6563 L
s
.59533 .6563 m
.59291 .65365 L
s
.58238 .64462 m
.58023 .64309 L
s
.58313 .64297 m
.56807 .63229 L
s
.58642 .6478 m
.58238 .64462 L
s
.59291 .65365 m
.59021 .65111 L
s
.59021 .65111 m
.58642 .6478 L
s
.57221 .6327 m
.56146 .6251 L
s
.57462 .63409 m
.57221 .6327 L
s
.57501 .63115 m
.55228 .6151 L
s
.59156 .64926 m
.59184 .64914 L
s
.58965 .64759 m
.59156 .64926 L
s
.58993 .64747 m
.58965 .64759 L
s
.59184 .64914 m
.58993 .64747 L
s
.57405 .63305 m
.57462 .63409 L
s
.57155 .63032 m
.57405 .63305 L
s
.5688 .62773 m
.57155 .63032 L
s
.56304 .62269 m
.5688 .62773 L
s
.5479 .60909 m
.54405 .60573 L
s
.55198 .61229 m
.5479 .60909 L
s
.54405 .60573 m
.54128 .60312 L
s
.54128 .60312 m
.53872 .60033 L
s
.55042 .60723 m
.52781 .59135 L
s
.55414 .61381 m
.55198 .61229 L
s
.55654 .61518 m
.55414 .61381 L
s
.53872 .60033 m
.53808 .59922 L
s
.53808 .59922 m
.53851 .59887 L
s
.55701 .61485 m
.55654 .61518 L
s
.5564 .61376 m
.55701 .61485 L
s
.55385 .61097 m
.5564 .61376 L
s
.5444 .60065 m
.52925 .59003 L
s
.55105 .60834 m
.55385 .61097 L
s
.52859 .58889 m
.53248 .59229 L
s
.52578 .58625 m
.52859 .58889 L
s
.54716 .60494 m
.55105 .60834 L
s
.52316 .5834 m
.52578 .58625 L
s
.52249 .58225 m
.52316 .5834 L
s
.52289 .58185 m
.52249 .58225 L
s
.54113 .59836 m
.54158 .598 L
s
.52526 .58316 m
.52289 .58185 L
s
.54158 .598 m
.54093 .59687 L
s
.54093 .59687 m
.53832 .59401 L
s
.52743 .58468 m
.52526 .58316 L
s
.53156 .58791 m
.52743 .58468 L
s
.53832 .59401 m
.53549 .59135 L
s
.53549 .59135 m
.53156 .58791 L
s
.52248 .5767 m
.50729 .56612 L
s
.52691 .58155 m
.52956 .58444 L
s
.51594 .57214 m
.52009 .57539 L
s
.52405 .57885 m
.52691 .58155 L
s
.52009 .57539 m
.52405 .57885 L
s
.50426 .56155 m
.50732 .56403 L
s
.5003 .55809 m
.50426 .56155 L
s
.49742 .55538 m
.5003 .55809 L
s
.50732 .56403 m
.51058 .5663 L
s
.4938 .55144 m
.49742 .55538 L
s
.50608 .56139 m
.51058 .5663 L
s
.49307 .55021 m
.4938 .55144 L
s
.49341 .54972 m
.49307 .55021 L
s
.51932 .57238 m
.52062 .57292 L
s
.49466 .55023 m
.49341 .54972 L
s
.52062 .57292 m
.52102 .57249 L
s
.49701 .5515 m
.49466 .55023 L
s
.52102 .57249 m
.52033 .57129 L
s
.50247 .55528 m
.49701 .5515 L
s
.49808 .55004 m
.47916 .53549 L
s
.4907 .54198 m
.47916 .53549 L
s
.52033 .57129 m
.51672 .56734 L
s
.50668 .55856 m
.50247 .55528 L
s
.51672 .56734 m
.51381 .56459 L
s
.50979 .56108 m
.50668 .55856 L
s
.51381 .56459 m
.50979 .56108 L
s
.4907 .54198 m
.47173 .52741 L
s
.48325 .53384 m
.47173 .52741 L
s
.47667 .52665 m
.4614 .51616 L
s
.46059 .51485 m
.46465 .5184 L
s
.45761 .51204 m
.46059 .51485 L
s
.45476 .50893 m
.45761 .51204 L
s
.45394 .5076 m
.45476 .50893 L
s
.45419 .507 m
.45394 .5076 L
s
.47338 .52439 m
.47368 .52384 L
s
.4565 .50819 m
.45419 .507 L
s
.47368 .52384 m
.47289 .52252 L
s
.47289 .52252 m
.47004 .51941 L
s
.45869 .50969 m
.4565 .50819 L
s
.46293 .51298 m
.45869 .50969 L
s
.47004 .51941 m
.46703 .51657 L
s
.46703 .51657 m
.46293 .51298 L
s
.45272 .50049 m
.43742 .49006 L
s
.45757 .50579 m
.46047 .50895 L
s
.44614 .496 m
.4504 .4993 L
s
.45454 .50292 m
.45757 .50579 L
s
.4504 .4993 m
.45454 .50292 L
s
.43187 .48268 m
.42773 .47906 L
s
.43503 .48523 m
.43187 .48268 L
s
.42773 .47906 m
.42368 .47509 L
s
.4393 .48853 m
.43503 .48523 L
s
.42368 .47509 m
.41671 .46751 L
s
.44479 .49227 m
.4393 .48853 L
s
.44712 .49345 m
.44479 .49227 L
s
.4398 .48314 m
.41671 .46751 L
s
.44835 .49388 m
.44712 .49345 L
s
.4486 .49324 m
.44835 .49388 L
s
.44675 .49075 m
.4486 .49324 L
s
.4398 .48314 m
.44675 .49075 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo06L0oooo00<000000?ooo`3oool0
5`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003o
ool0oooo02H0oooo0P000?mW0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0V0?ooo`80003oIP3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02H0oooo0`000?mT0?ooo`030000003oool0oooo
00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool09@3oool010000?l0oooo0?ooo`000?mS0?ooo`030000003oool0oooo
00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`020000of40oooo00<000000?ooo`3o
ool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0
HP3oool00`000000oooo0?ooo`0U0?ooo`80003o0P3oool00`000?l0oooo0?ooo`1N0?ooo`030000
003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?mO0?ooo`040000
003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo
0?ooo`1T0?ooo`030000003oool0oooo02H0oooo0`000?mO0?ooo`@00000E@3oool00`000000oooo
0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02D0oooo00@0
003o0?ooo`000?l0003oG03oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`0U0?ooo`@0003oF03oool300000080oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X
0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0E03oool3000000D0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?oo
o`3oool09`3oool20000oe40oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0W0?ooo`80
003oC@3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
8@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0oooo04P0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000
003oool0oooo02H0oooo0P000?m60?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
K@3oool00`000000oooo0?ooo`0U0?ooo`@0003o@@3oool3000001@0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000
003oool0oooo06h0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0000o`0n0?ooo`<00000
603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0U0?ooo`<0003o
>P3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3o
ool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0U0?ooo`<0003o=P3o
ool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02D0oooo0`000?la0?ooo`@000008@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool09P3oool20000obd0oooo0`00000U0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000
oooo0?ooo`0V0?ooo`<0003o:03oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`0U0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02D0oooo0P00
0?lR0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0005
0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0V
0?ooo`80003o7@3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool09@3oool20000oaX0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool09@3oool30000oaD0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0V0?ooo`80003o
4@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0303o
ool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02H0oooo0P000?l90?ooo`<00000@03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo
07h0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0000o`050?ooo`<00000@`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0903oool20000o`<0oooo0`0000160?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02@0oooo
0`000?l00`000000oooo0?ooo`170?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<0000000@0
003o0?ooo`000?l0003oB03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000@0oooo00@0
003o0?ooo`000?l0003oB03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000000T0oooo0`00
0?m80?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000003@3oool30000odL0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0100oooo0`00000A0?ooo`@0003oA@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000001H0oooo00<0003o0?ooo`000?l0A03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
203oool3000001X0oooo0P000?m40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007P3o
ool20000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool00`000?l0oooo0?ooo`11
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0S03oool2000002D0oooo0P000?m20?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo02@0oooo0`000?m00?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02D0oooo00<0003o0?ooo`000?l0?03oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02H0oooo00<0003o0?ooo`000?l0=`3oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02H0oooo10000?lc0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09`3oool01000
0?l0oooo0000o`000?l_0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool40000
ob/0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0003o02L0
oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0280oooo
1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0/0?ooo`80003o7`3oool3000001h0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02d0oooo0P000?lK0?ooo`<000008P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0;P3oool20000oaL0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo0300oooo0P000?lB0?ooo`<0
0000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;`3oool20000o`l0oooo1000000^0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0a0?ooo`80003o2`3oool3000003<0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo03<0oooo0P000?l60?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool30000
o`80oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0d0?ooo`040000o`00000000000000
03h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000040000och0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo02h0oooo0`0000050?ooo`<0003o?`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3o
ool3000000T0oooo0P000?lo0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000003@3oool2
0000ocl0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool30000
08h0oooo00<000000?ooo`3oool09@3oool300000140oooo0P000?lo0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240
oooo1000000D0?ooo`<0003o?`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0
oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000001T0oooo
0P000?m00?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P00
00070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000001d0oooo1@00
0?ll0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00
000Q0?ooo`<0003o?P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E
0?ooo`<000009`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool04@3oool4000002T0oooo00<0003o0?ooo`000?l0?P3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000;P3oool00`000?l0oooo0?ooo`0n0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000380oooo0`000?lm0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`080?ooo`<00000=P3oool00`000?l0oooo0000o`0m0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`040?ooo`@00000>P3oool30000ocd0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo
0?ooo`<00000?`3oool00`000?l0oooo0000o`0m0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000@`3oool20000och0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000180?ooo`03
0000o`3oool0oooo03/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`170?ooo`030000
o`3oool0oooo03/0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`180?ooo`80003o?03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08D0oooo0`0000090?ooo`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool0>P3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo04/0oooo00<0003o0?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0
oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo
0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=
0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003o
ool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3o
ool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`00
0000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640
oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h
0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;
0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?oo
o`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000
003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool0
0`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480
oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo
0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?oo
o`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H
0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000
003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3
000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo
0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0
oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g
0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`09
0?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3o
ool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3o
ool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003o
ool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3
000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo
0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000
oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo
00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool50000
0080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo
0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`00
0000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?oo
o`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`00
0000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000
oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P000009
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool0
0`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool0
00d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo
0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo
0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@0
00000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000
003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?oo
o`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d
0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`04
0?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3o
ool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000
L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?oo
o`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?oo
o`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?oo
o`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000
003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3o
ool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?oo
o`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?oo
o`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0
c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3o
ool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003o
ool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4
000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo
00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo
00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<0
00000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03o
ool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2
000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?oo
o`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00
I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3o
ool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4
000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0
oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo
0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<00000
0?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?oo
o`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@0
0000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000
;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3o
ool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`00
0000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0
oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo
0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480
oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0
oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo
0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z
0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V
0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?oo
o`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3o
ool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003o
ool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5
000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool40000
0800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0
oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<0
00000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I
0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3o
ool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3o
ool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0
>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03o
ool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool4
00000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool00000
00/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0
oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0
oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000
oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0
oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P000005
0?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?oo
o`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool50000
0=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080
oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60356 .67467 m
.60404 .67429 L
s
.6015 .67335 m
.60356 .67467 L
s
.60199 .67297 m
.6015 .67335 L
s
.60404 .67429 m
.60199 .67297 L
s
.62848 .68337 m
.61043 .67666 L
s
.59567 .66611 m
.59202 .66305 L
s
.59902 .66791 m
.59567 .66611 L
s
.6003 .66839 m
.59902 .66791 L
s
.60207 .66847 m
.6003 .66839 L
s
.59202 .66305 m
.58963 .66046 L
s
.60176 .66722 m
.60207 .66847 L
s
.58963 .66046 m
.58851 .65833 L
s
.59908 .66337 m
.60176 .66722 L
s
.60928 .67171 m
.61107 .6718 L
s
.58851 .65833 m
.59027 .6584 L
s
.61107 .6718 m
.60999 .66969 L
s
.59877 .6621 m
.59908 .66337 L
s
.60999 .66969 m
.60761 .66708 L
s
.60055 .66218 m
.59877 .6621 L
s
.58127 .65047 m
.58545 .65316 L
s
.57837 .64824 m
.58127 .65047 L
s
.60761 .66708 m
.60393 .664 L
s
.57594 .6456 m
.57837 .64824 L
s
.60393 .664 m
.60055 .66218 L
s
.57559 .6443 m
.57594 .6456 L
s
.57653 .64346 m
.57559 .6443 L
s
.59575 .65693 m
.59673 .65612 L
s
.57958 .64398 m
.57653 .64346 L
s
.59673 .65612 m
.59641 .65483 L
s
.59641 .65483 m
.59399 .65218 L
s
.58216 .64491 m
.57958 .64398 L
s
.58422 .64149 m
.56612 .63494 L
s
.58686 .64721 m
.58216 .64491 L
s
.59399 .65218 m
.59107 .64993 L
s
.59107 .64993 m
.58686 .64721 L
s
.57243 .6324 m
.5595 .62775 L
s
.5755 .6329 m
.57243 .6324 L
s
.59419 .64569 m
.59468 .64527 L
s
.59206 .64432 m
.59419 .64569 L
s
.59255 .6439 m
.59206 .64432 L
s
.57767 .62754 m
.5503 .61777 L
s
.59468 .64527 m
.59255 .6439 L
s
.57515 .63156 m
.5755 .6329 L
s
.57266 .62883 m
.57515 .63156 L
s
.56968 .62654 m
.57266 .62883 L
s
.56326 .6224 m
.56968 .62654 L
s
.54657 .61088 m
.54228 .60812 L
s
.55131 .61319 m
.54657 .61088 L
s
.54228 .60812 m
.53928 .60581 L
s
.53928 .60581 m
.53672 .60302 L
s
.55154 .60572 m
.52425 .59612 L
s
.55391 .61411 m
.55131 .61319 L
s
.55698 .61458 m
.55391 .61411 L
s
.53672 .60302 m
.5363 .60162 L
s
.5363 .60162 m
.53717 .60067 L
s
.5579 .61365 m
.55698 .61458 L
s
.55752 .61226 m
.5579 .61365 L
s
.55496 .60946 m
.55752 .61226 L
s
.54552 .59914 m
.52723 .59273 L
s
.55194 .60713 m
.55496 .60946 L
s
.5268 .5913 m
.53113 .5941 L
s
.52376 .58896 m
.5268 .5913 L
s
.54761 .60434 m
.55194 .60713 L
s
.52114 .58611 m
.52376 .58896 L
s
.52069 .58467 m
.52114 .58611 L
s
.52154 .58366 m
.52069 .58467 L
s
.54158 .59776 m
.54248 .59678 L
s
.52458 .58407 m
.52154 .58366 L
s
.54248 .59678 m
.54206 .59535 L
s
.54206 .59535 m
.53946 .59249 L
s
.5272 .58498 m
.52458 .58407 L
s
.53202 .5873 m
.5272 .58498 L
s
.53946 .59249 m
.5364 .59013 L
s
.5364 .59013 m
.53202 .5873 L
s
.52363 .57517 m
.50524 .56885 L
s
.52806 .58002 m
.5307 .58291 L
s
.51571 .57245 m
.52055 .57478 L
s
.52497 .57763 m
.52806 .58002 L
s
.52055 .57478 m
.52497 .57763 L
s
.50288 .56338 m
.50641 .56526 L
s
.49847 .56053 m
.50288 .56338 L
s
.49535 .55813 m
.49847 .56053 L
s
.50641 .56526 m
.51035 .5666 L
s
.49173 .55419 m
.49535 .55813 L
s
.50585 .5617 m
.51035 .5666 L
s
.49122 .55266 m
.49173 .55419 L
s
.49202 .55157 m
.49122 .55266 L
s
.52093 .57022 m
.52269 .57015 L
s
.49374 .55147 m
.49202 .55157 L
s
.52269 .57015 m
.52357 .56909 L
s
.49678 .55181 m
.49374 .55147 L
s
.52357 .56909 m
.52311 .56758 L
s
.5034 .55404 m
.49678 .55181 L
s
.52311 .56758 m
.51951 .56362 L
s
.49925 .54849 m
.47706 .53827 L
s
.49188 .54042 m
.47706 .53827 L
s
.5083 .55639 m
.5034 .55404 L
s
.51951 .56362 m
.51636 .56118 L
s
.51188 .55829 m
.5083 .55639 L
s
.51636 .56118 m
.51188 .55829 L
s
.49188 .54042 m
.46962 .53019 L
s
.48443 .53228 m
.46962 .53019 L
s
.47786 .52508 m
.45928 .51897 L
s
.4587 .51734 m
.46323 .52027 L
s
.45548 .51485 m
.4587 .51734 L
s
.45262 .51174 m
.45548 .51485 L
s
.45203 .5101 m
.45262 .51174 L
s
.45276 .50888 m
.45203 .5101 L
s
.47385 .52376 m
.47464 .52258 L
s
.45579 .50914 m
.45276 .50888 L
s
.47464 .52258 m
.47408 .52095 L
s
.47408 .52095 m
.47123 .51783 L
s
.45845 .51 m
.45579 .50914 L
s
.46341 .51235 m
.45845 .51 L
s
.47123 .51783 m
.46799 .51531 L
s
.46799 .51531 m
.46341 .51235 L
s
.45393 .4989 m
.43526 .49289 L
s
.45878 .5042 m
.46167 .50736 L
s
.44589 .49631 m
.45088 .49867 L
s
.4555 .50165 m
.45878 .5042 L
s
.45088 .49867 m
.4555 .50165 L
s
.43042 .48458 m
.42579 .48159 L
s
.43406 .4865 m
.43042 .48458 L
s
.42579 .48159 m
.42149 .47795 L
s
.43905 .48885 m
.43406 .4865 L
s
.42149 .47795 m
.41452 .47038 L
s
.44576 .49099 m
.43905 .48885 L
s
.44882 .49121 m
.44576 .49099 L
s
.44276 .47927 m
.41452 .47038 L
s
.45054 .491 m
.44882 .49121 L
s
.45129 .4897 m
.45054 .491 L
s
.44969 .48689 m
.45129 .4897 L
s
.44276 .47927 m
.44969 .48689 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0T0?ooo`80003oJ@3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0903oool40000ofH0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080003oI03oool00`000000oooo0?ooo`0>0?oo
o`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo02@0oooo00@0003o0?ooo`3oool0oooo0`000?mQ0?ooo`030000003oool0oooo
00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`030?ooo`80003oG`3oool00`000000
oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`1L0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo05/0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000
003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0903o
ool40000o`<0oooo00<0003o0?ooo`3oool0FP3oool4000005D0oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0W0?ooo`@0003oFP3oool3
000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`00
0000oooo0?ooo`0S0?ooo`80003oG03oool300000080oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo02@0
oooo10000?mE0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0W0?ooo`<0003oD03oool3000000P0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo02P0oooo0P000?m<0?ooo`<000002`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool0AP3oool3000000h0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`12
0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0T
0?ooo`@0003o@P3oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F
0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<00000
0?ooo`3oool0903oool00`000?l0oooo0?ooo`020000ocd0oooo0`00000H0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02@0oooo00D0003o0?ooo`3oool0oooo0000
o`0i0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q
0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02@0oooo00@0003o
0?ooo`3oool0oooo0P000?ld0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool08`3oool3
0000o`<0oooo00<0003o0?ooo`3oool0;@3oool400000240oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo
02@0oooo1@000?l/0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool09`3oool20000obP0
oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo
0P00001f0?ooo`030000003oool0oooo04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool08`3oool30000ob<0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo02<0oooo1@000?lM0?ooo`<00000<@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`0T0?ooo`80003o6`3oool3000003@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`0S0?ooo`@0003o5P3oool3000003L0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo02<0oooo1@000?lA0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0903o
ool20000o`l0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0U0?ooo`80003o2P3oool3
00000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo02H0oooo0P000?l50?ooo`<00000@`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool08`3oool40000o`80oooo0`0000160?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo0280oooo
00@0003o0?ooo`3oool000000P000?m90?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`030000
00000?l0003o00<0oooo0`000?m60?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000000`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0
oooo01P0oooo0`0000080?ooo`80003o103oool20000od@0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo
01@0oooo0`00000<0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`0@0?ooo`<000003`3oool20000o`D0oooo00<0003o0?ooo`3oool0@@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0303oool3000001@0oooo0P000?l20?ooo`80003o@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0203oool3000001T0oooo0`000?m40?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`04
0?ooo`<000007P3oool20000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008`3oool20000
od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`800000:03oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo02<0oooo
0`000?m10?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P000?ll0?ooo`<000000P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0903oool010000?l0oooo0?ooo`3oool20000ocH0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0U0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0`
0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool50000o`80oooo00<0003o0?oo
o`3oool0;03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo1P000?l[0?ooo`<0
00004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool40000obL0oooo0`00000F0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool0003o0080003o8P3oool4000001X0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02X0oooo00@0003o0?ooo`3oool0oooo0P000?lM0?ooo`<000007P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0:`3oool010000?l0oooo0?ooo`3oool20000oaT0oooo0`00
000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0C
0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?oo
o`800000S`3oool00`000000oooo0?ooo`0^0?ooo`@0003o4P3oool3000002X0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0_0?ooo`80003o
3@3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo10000?l60?ooo`<00000=P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0=03oool40000o`<00000>P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0<`3oool00`000?l0oooo0000000200000080003o?03oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0<@3oool4000000030000o`3oool0003o03l0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo
0`0000050?ooo`<0003o?`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000L0oooo0P00
0?m10?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000303oool40000och0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?oo
o`3oool09@3oool3000001<0oooo0P000?lm0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000D0?ooo`80
003o103oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000
603oool00`000?l0oooo0000o`020000o`030?ooo`000?l0003o03/0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0K0?ooo`<00000703oool010000?l0oooo0?ooo`000?ln0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000P0?ooo`030000
o`3oool0oooo0080003o?@3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo
000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0E0?ooo`<00000903oool01@000?l0oooo0?ooo`3oool0003o03d0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0A0?ooo`@00000:`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000/0?ooo`80003o@@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000a0?ooo`040000o`3oool0003o
0000ocd0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000d0?ooo`050000o`3oool0003o
0?ooo`000?l0?@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000003P0oooo0`000?l00`3o
ool0003o0?ooo`0l0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool300000440oooo00<0003o0?oo
o`3oool0>`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`80
0000T@3oool400000440oooo00<0003o0?ooo`3oool00P000?lm0?ooo`030000003oool0oooo0480
oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000A@3oool010000?l0oooo
0?ooo`000?lm0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0A`3oool20000oc`0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`280?ooo`@000001@3oool00`000000oooo0?ooo`190?ooo`80003o>`3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`000009
0?ooo`030000003oool0oooo04/0oooo0P000?lj0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<00000
4@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo
000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V
0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000
<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`00
0000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo
100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?oo
o`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P000019
0?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?oo
o`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000
D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`00
0000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo
1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?oo
o`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?oo
o`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000
L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`00
0000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo
100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?oo
o`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
0P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`80
0000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003o
ool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool5
00000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo
0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000
P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
1@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003o
ool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0
oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3o
ool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103o
ool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000
003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3o
ool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool0
04`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo
00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo
00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?oo
o`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00
001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?oo
o`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3o
ool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo
001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo
001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo0000
00030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`00
0000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0
oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo
001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?oo
o`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00
K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3o
ool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2
000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool00000
03`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000
oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e
0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?oo
o`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00
J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`03
0000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D0
0000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000
E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03o
ool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool01000
0000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`00
0000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0
oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00
000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<00000
0?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000
R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3o
ool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0
oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180
oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo
00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<0
00000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00
000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<00000
0?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?oo
o`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`03
0000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3o
ool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`80
00002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool00000
0000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo
002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3o
ool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool20000
00@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?oo
o`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?oo
o`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60231 .67714 m
.60296 .67646 L
s
.6001 .67613 m
.60231 .67714 L
s
.60074 .67544 m
.6001 .67613 L
s
.60296 .67646 m
.60074 .67544 L
s
.63034 .67962 m
.61012 .67728 L
s
.59442 .66859 m
.59061 .66585 L
s
.59808 .66978 m
.59442 .66859 L
s
.59951 .66994 m
.59808 .66978 L
s
.6016 .66941 m
.59951 .66994 L
s
.59061 .66585 m
.58821 .66326 L
s
.60145 .66784 m
.6016 .66941 L
s
.58821 .66326 m
.58725 .66082 L
s
.59892 .66368 m
.60145 .66784 L
s
.60959 .67109 m
.61169 .67055 L
s
.58725 .66082 m
.58932 .66027 L
s
.61169 .67055 m
.61077 .66812 L
s
.59877 .6621 m
.59892 .66368 L
s
.61077 .66812 m
.6084 .66552 L
s
.60087 .66155 m
.59877 .6621 L
s
.6084 .66552 m
.60456 .66274 L
s
.58 .65297 m
.58449 .65503 L
s
.57694 .65105 m
.58 .65297 L
s
.60456 .66274 m
.60087 .66155 L
s
.5745 .64841 m
.57694 .65105 L
s
.57431 .6468 m
.5745 .64841 L
s
.59606 .6563 m
.59736 .65486 L
s
.57557 .64534 m
.57431 .6468 L
s
.59736 .65486 m
.59721 .65325 L
s
.5791 .64492 m
.57557 .64534 L
s
.59721 .65325 m
.59479 .6506 L
s
.582 .64523 m
.5791 .64492 L
s
.58718 .64658 m
.582 .64523 L
s
.59479 .6506 m
.59171 .64867 L
s
.58503 .6399 m
.56467 .63777 L
s
.59171 .64867 m
.58718 .64658 L
s
.57259 .63209 m
.55804 .63059 L
s
.57615 .63163 m
.57259 .63209 L
s
.59612 .64188 m
.59678 .64113 L
s
.59384 .64082 m
.59612 .64188 L
s
.59449 .64008 m
.59384 .64082 L
s
.59678 .64113 m
.59449 .64008 L
s
.57964 .62369 m
.54883 .62062 L
s
.57596 .62997 m
.57615 .63163 L
s
.57347 .62724 m
.57596 .62997 L
s
.57034 .62526 m
.57347 .62724 L
s
.56342 .62208 m
.57034 .62526 L
s
.54558 .6128 m
.54096 .61067 L
s
.55082 .61415 m
.54558 .6128 L
s
.54096 .61067 m
.53779 .60868 L
s
.53779 .60868 m
.53522 .60589 L
s
.55375 .61443 m
.55082 .61415 L
s
.55238 .60411 m
.52159 .60121 L
s
.55731 .61394 m
.55375 .61443 L
s
.53522 .60589 m
.53497 .60417 L
s
.55856 .61237 m
.55731 .61394 L
s
.53497 .60417 m
.53617 .60259 L
s
.55834 .61065 m
.55856 .61237 L
s
.55579 .60786 m
.55834 .61065 L
s
.54636 .59752 m
.52573 .59561 L
s
.55261 .60585 m
.55579 .60786 L
s
.54794 .6037 m
.55261 .60585 L
s
.52545 .59387 m
.53013 .59602 L
s
.52224 .59184 m
.52545 .59387 L
s
.51962 .58901 m
.52224 .59184 L
s
.51934 .58724 m
.51962 .58901 L
s
.54192 .59711 m
.54315 .59549 L
s
.52052 .5856 m
.51934 .58724 L
s
.54315 .59549 m
.5429 .59373 L
s
.52407 .58504 m
.52052 .5856 L
s
.5429 .59373 m
.5403 .59088 L
s
.52703 .5853 m
.52407 .58504 L
s
.53235 .58666 m
.52703 .5853 L
s
.5403 .59088 m
.53707 .58883 L
s
.53707 .58883 m
.53235 .58666 L
s
.52448 .57354 m
.5037 .57177 L
s
.52891 .57839 m
.53155 .58129 L
s
.51554 .57278 m
.52089 .57413 L
s
.52565 .57632 m
.52891 .57839 L
s
.52089 .57413 m
.52565 .57632 L
s
.50185 .56533 m
.50572 .56656 L
s
.49709 .56313 m
.50185 .56533 L
s
.4938 .56105 m
.49709 .56313 L
s
.50572 .56656 m
.51018 .56693 L
s
.49017 .55712 m
.4938 .56105 L
s
.50568 .56203 m
.51018 .56693 L
s
.48983 .55527 m
.49017 .55712 L
s
.49098 .55353 m
.48983 .55527 L
s
.52213 .56793 m
.52424 .5672 L
s
.49304 .55277 m
.49098 .55353 L
s
.52424 .5672 m
.52547 .56548 L
s
.49661 .55214 m
.49304 .55277 L
s
.52547 .56548 m
.52519 .56363 L
s
.5041 .55273 m
.49661 .55214 L
s
.52519 .56363 m
.52159 .55966 L
s
.50013 .54684 m
.47548 .54122 L
s
.49276 .53877 m
.47548 .54122 L
s
.50952 .55408 m
.5041 .55273 L
s
.52159 .55966 m
.51828 .55755 L
s
.51345 .55532 m
.50952 .55408 L
s
.51828 .55755 m
.51345 .55532 L
s
.49276 .53877 m
.46803 .53315 L
s
.48532 .53061 m
.46803 .53315 L
s
.47876 .52342 m
.45767 .52194 L
s
.45727 .51999 m
.46216 .52226 L
s
.45387 .51783 m
.45727 .51999 L
s
.451 .51473 m
.45387 .51783 L
s
.45059 .51276 m
.451 .51473 L
s
.47421 .5231 m
.47535 .52124 L
s
.45168 .51088 m
.45059 .51276 L
s
.47535 .52124 m
.47498 .51928 L
s
.45524 .51014 m
.45168 .51088 L
s
.47498 .51928 m
.47213 .51616 L
s
.45827 .51034 m
.45524 .51014 L
s
.46377 .51168 m
.45827 .51034 L
s
.47213 .51616 m
.46871 .51397 L
s
.46871 .51397 m
.46377 .51168 L
s
.45485 .49721 m
.43361 .4959 L
s
.45969 .50252 m
.46258 .50569 L
s
.44571 .49665 m
.45125 .49799 L
s
.45623 .50031 m
.45969 .50252 L
s
.45125 .49799 m
.45623 .50031 L
s
.42931 .4866 m
.42431 .48428 L
s
.43333 .48785 m
.42931 .4866 L
s
.42431 .48428 m
.41982 .48097 L
s
.43887 .48919 m
.43333 .48785 L
s
.4465 .48964 m
.43887 .48919 L
s
.41982 .48097 m
.41284 .47341 L
s
.45011 .48884 m
.4465 .48964 L
s
.445 .47517 m
.41284 .47341 L
s
.4522 .48795 m
.45011 .48884 L
s
.45332 .48597 m
.4522 .48795 L
s
.45192 .48281 m
.45332 .48597 L
s
.445 .47517 m
.45192 .48281 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool08P3oool=0000
oeh0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00T0
oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0280oooo
00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo05X0oooo00<0
00000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<00000
0?ooo`3oool0H`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0F@3oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0R0?ooo`<0003o1P3oool0
0`000?l0oooo0?ooo`1J0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo02@0oooo1P000?mK0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0840
oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
00<000000?ooo`000000J03oool00`000000oooo0?ooo`0R0?ooo`D0003oEP3oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool09P3oool40000oe00oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0X
0?ooo`<0003oB`3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo04H0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo02T0oooo00<0003o0?ooo`3oool0@P3oool300000140oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool09P3oool20000od80oooo0`00000D0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02<0oooo0P000?l20?oo
o`80003o?@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`80003o>03oool3000001/0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0<P3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0]0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool08@3o
ool90000ob/0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`1A0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`1=0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02H0
oooo10000?lO0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0Q0?ooo`@0003o803oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool08`3oool50000oaT0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool09P3oool40000oa<0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0Q0?oo
o`@0003o503oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02<0oooo10000?l>0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool09P3oool30000o`P0oooo0`0000100?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0]0?ooo`<00000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0903oool5
0000o`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`<00000P@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<000000`000?m60?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`000000000000H0oooo0P000?m40?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0L0?ooo`@0000000<0oooo0000o`3oool0203oool00`000?l0oooo
0?ooo`120?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000001P3oool010000?l0oooo0?oo
o`000?l60?ooo`80003o@P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000X0oooo1000
0?l60?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000@
0?ooo`80003o103oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?oo
o`<000004P3oool40000odL0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000I0?ooo`@0
003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001l0oooo0P000?m20?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3o
ool00`000000oooo0?ooo`03000002@0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000X
0?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08`3oool30000od40oooo0P00001K0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`020000oc`0oooo0`0000020?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0S0?ooo`030000o`3oool0oooo0080oooo0`000?le0?ooo`@000001P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0903oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0300oooo0`00
000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`@0003o0P3oool00`000?l0oooo0?ooo`0/
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool50000obT0oooo0`00000B0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0S0?ooo`H0003o:`3oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02P0oooo20000?lP0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`030?ooo`80003o7@3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:P3oool20000o`D0oooo00<0003o0?ooo`3oool04`3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool0;03oool60000oa80oooo0`00000Z0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02l0oooo1`000?l50?ooo`<00000=P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0=@3oool30000o`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool300000003
0000o`3oool0oooo03/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000040?ooo`030000
o`3oool0oooo03/0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000040?ooo`D0003o?P3o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02P0oooo0`0000090?ooo`@0003o@@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000403oool50000o`80
oooo0P000?li0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo
0P00002@0?ooo`030000003oool0oooo0240oooo1000000K0?ooo`030000o`3oool0oooo03P0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01h0oooo0`00000G0?ooo`H0003o?P3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01/0oooo0`00000J0?ooo`030000o`3oool0oooo00<0oooo0P000?ll
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000N
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000008P3oool30000o`@0oooo00<0003o0?oo
o`3oool0>P3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000[0?ooo`03
0000o`3oool0oooo03`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00
603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
3P3oool3000002d0oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00/0oooo0`00000_0?ooo`040000o`3oool0oooo0?ooo`<0003o?03oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0203oool3000003<0oooo00@0003o0?ooo`3oool0003o0P3oool20000oc/0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00@0oooo1000000g0?ooo`80003o00<0oooo0000o`3oool00P3o
ool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3o
ool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000003d0oooo0P00
0?l20?ooo`80003o?03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P
0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool200000900oooo0`0000140?ooo`80003o@03oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`03
0000003oool0oooo0480oooo00<0003o0?ooo`3oool010000?ll0?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo
00<000000?ooo`3oool0B@3oool50000ocP0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool30000
01h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo
1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo
0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003o
ool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool0
0`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0
oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool30000
03h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?oo
o`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?oo
o`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003o
ool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0
oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool30000
05h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<0
00000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<00000
0?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?oo
o`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
7@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003o
ool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool30000
07d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<0
00000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?oo
o`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3o
ool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P000009
0?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?oo
o`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo10000004
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3o
ool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P00
00240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?oo
o`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool0
0000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2
000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0
oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003o
ool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2
000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000
oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo
00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`03
0000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00
@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0
oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?oo
o`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0
oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo
0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0
oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00
000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G
0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`01
0?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3o
ool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0
eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo
0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`00
0000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2
000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0
oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P00
00020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y
0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?oo
o`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3o
ool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5
000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00
000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d
0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?oo
o`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`04
0000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?oo
o`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`80
0000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003o
ool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003o
ool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0
oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool40000
06X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0
oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo
1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo
1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`80
0000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`000000
6@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003o
ool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool40000
09X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool50000
09h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0
oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo
001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W
0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<00000
0?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?oo
o`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`04
0000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?oo
o`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0
103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003o
ool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool4
00000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?oo
o`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?oo
o`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?oo
o`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60157 .67967 m
.6023 .67867 L
s
.59926 .67897 m
.60157 .67967 L
s
.59999 .67797 m
.59926 .67897 L
s
.6023 .67867 m
.59999 .67797 L
s
.63145 .67579 m
.60993 .67792 L
s
.59367 .67113 m
.58975 .66871 L
s
.59752 .67168 m
.59367 .67113 L
s
.59904 .67153 m
.59752 .67168 L
s
.60131 .67036 m
.59904 .67153 L
s
.58975 .66871 m
.58736 .66612 L
s
.60126 .66848 m
.60131 .67036 L
s
.58736 .66612 m
.58648 .66337 L
s
.60978 .67045 m
.61207 .66928 L
s
.59883 .664 m
.60126 .66848 L
s
.61207 .66928 m
.61124 .66652 L
s
.58648 .66337 m
.58875 .66218 L
s
.59877 .6621 m
.59883 .664 L
s
.61124 .66652 m
.60887 .66392 L
s
.60106 .66091 m
.59877 .6621 L
s
.60887 .66392 m
.60494 .66146 L
s
.60494 .66146 m
.60106 .66091 L
s
.57923 .65552 m
.58392 .65695 L
s
.57607 .65393 m
.57923 .65552 L
s
.57363 .6513 m
.57607 .65393 L
s
.57354 .64937 m
.57363 .6513 L
s
.59625 .65566 m
.59775 .65357 L
s
.57499 .64727 m
.57354 .64937 L
s
.59775 .65357 m
.59769 .65165 L
s
.5788 .64588 m
.57499 .64727 L
s
.59769 .65165 m
.59527 .64899 L
s
.5819 .64555 m
.5788 .64588 L
s
.59527 .64899 m
.5921 .64738 L
s
.58737 .64594 m
.5819 .64555 L
s
.5921 .64738 m
.58737 .64594 L
s
.58551 .63828 m
.56378 .64066 L
s
.57269 .63176 m
.55715 .63349 L
s
.59728 .63799 m
.59804 .63691 L
s
.5949 .63726 m
.59728 .63799 L
s
.59565 .63618 m
.5949 .63726 L
s
.57655 .63033 m
.57269 .63176 L
s
.59804 .63691 m
.59565 .63618 L
s
.57646 .62834 m
.57655 .63033 L
s
.58083 .61978 m
.54792 .62353 L
s
.57397 .62561 m
.57646 .62834 L
s
.57073 .62396 m
.57397 .62561 L
s
.56352 .62175 m
.57073 .62396 L
s
.54497 .61475 m
.54015 .61327 L
s
.55051 .61512 m
.54497 .61475 L
s
.54015 .61327 m
.53687 .6116 L
s
.55365 .61476 m
.55051 .61512 L
s
.53687 .6116 m
.5343 .60882 L
s
.55751 .61329 m
.55365 .61476 L
s
.55289 .60247 m
.51993 .60641 L
s
.5343 .60882 m
.53415 .60678 L
s
.55897 .61106 m
.55751 .61329 L
s
.53415 .60678 m
.53556 .60454 L
s
.55885 .60902 m
.55897 .61106 L
s
.5563 .60622 m
.55885 .60902 L
s
.55302 .60454 m
.5563 .60622 L
s
.54688 .59588 m
.52479 .59856 L
s
.54815 .60304 m
.55302 .60454 L
s
.52462 .59648 m
.5295 .59798 L
s
.52131 .59479 m
.52462 .59648 L
s
.51868 .59195 m
.52131 .59479 L
s
.5185 .58986 m
.51868 .59195 L
s
.54212 .59645 m
.54356 .59418 L
s
.51989 .58757 m
.5185 .58986 L
s
.54356 .59418 m
.54342 .59208 L
s
.52376 .58603 m
.51989 .58757 L
s
.54342 .59208 m
.54082 .58923 L
s
.52693 .58563 m
.52376 .58603 L
s
.54082 .58923 m
.53749 .58751 L
s
.53256 .586 m
.52693 .58563 L
s
.53749 .58751 m
.53256 .586 L
s
.52501 .57188 m
.50273 .57473 L
s
.52944 .57673 m
.53208 .57963 L
s
.52607 .575 m
.52944 .57673 L
s
.51543 .57311 m
.5211 .57347 L
s
.5211 .57347 m
.52607 .575 L
s
.50121 .56732 m
.50529 .56788 L
s
.49622 .56578 m
.50121 .56732 L
s
.50529 .56788 m
.51007 .56726 L
s
.49282 .56403 m
.49622 .56578 L
s
.48919 .56011 m
.49282 .56403 L
s
.50557 .56236 m
.51007 .56726 L
s
.48896 .55792 m
.48919 .56011 L
s
.52288 .5656 m
.5252 .5642 L
s
.49032 .55552 m
.48896 .55792 L
s
.5252 .5642 m
.52664 .56181 L
s
.4926 .55411 m
.49032 .55552 L
s
.52664 .56181 m
.52647 .55962 L
s
.4965 .55247 m
.4926 .55411 L
s
.52647 .55962 m
.52288 .55565 L
s
.50454 .55139 m
.4965 .55247 L
s
.52288 .55565 m
.51946 .55387 L
s
.51028 .55174 m
.50454 .55139 L
s
.50067 .54517 m
.47448 .54422 L
s
.49331 .53709 m
.47448 .54422 L
s
.51946 .55387 m
.51442 .55231 L
s
.51442 .55231 m
.51028 .55174 L
s
.49331 .53709 m
.46702 .53616 L
s
.48588 .52893 m
.46702 .53616 L
s
.47932 .52173 m
.45665 .52496 L
s
.45636 .52268 m
.46148 .52427 L
s
.45284 .52085 m
.45636 .52268 L
s
.44997 .51776 m
.45284 .52085 L
s
.44967 .51545 m
.44997 .51776 L
s
.47444 .52242 m
.4758 .51989 L
s
.45099 .5129 m
.44967 .51545 L
s
.4758 .51989 m
.47554 .51759 L
s
.4549 .51115 m
.45099 .5129 L
s
.47554 .51759 m
.4727 .51447 L
s
.45815 .51067 m
.4549 .51115 L
s
.4727 .51447 m
.46917 .51262 L
s
.464 .51101 m
.45815 .51067 L
s
.46917 .51262 m
.464 .51101 L
s
.45543 .49551 m
.43256 .49895 L
s
.46027 .50082 m
.46315 .50399 L
s
.45669 .49894 m
.46027 .50082 L
s
.44559 .49699 m
.45148 .49731 L
s
.45148 .49731 m
.45669 .49894 L
s
.4286 .48864 m
.42336 .487 L
s
.43286 .48921 m
.4286 .48864 L
s
.43875 .48953 m
.43286 .48921 L
s
.42336 .487 m
.41875 .48403 L
s
.44696 .48828 m
.43875 .48953 L
s
.41875 .48403 m
.41175 .47648 L
s
.45093 .48645 m
.44696 .48828 L
s
.45326 .48487 m
.45093 .48645 L
s
.44642 .47104 m
.41175 .47648 L
s
.45461 .4822 m
.45326 .48487 L
s
.45333 .47868 m
.45461 .4822 L
s
.44642 .47104 m
.45333 .47868 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0/0?ooo`@0003oGP3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
02D0oooo1P000?l40?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0P0?ooo`@0003o2`3oool00`000?l0oooo0?ooo`1J0?ooo`030000003oool0oooo00X0
oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo05T0oooo
00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3oool0F@3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0200oooo00<0003o
0?ooo`3oool02@3oool20000oe/0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0803oool4
0000o`D0oooo0P000?mM0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo02<0oooo1@000?mM0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0840
oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
00<000000?ooo`000000J03oool00`000000oooo0?ooo`0V0?ooo`D0003oDP3oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool08@3oool50000o`030?ooo`000?l0003o0080003oC`3oool3000000P0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0B@3oool3000000/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`0Z0?ooo`80003oAP3oool3000000h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0KP3oool300000140oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06d0oooo00<000000?ooo`3oool0JP3oool3000001@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool08`3oool80000oc/0oooo0`00000H0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0280oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0e0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`03
0000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0a0?ooo`<0
00007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo02d0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3o
ool0oooo0080oooo1@000?lZ0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0803oool5
0000ob`0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo0P00001f0?ooo`030000003oool0oooo02T0oooo0P000?lR0?ooo`<00000:`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo02H0oooo0P000?lQ0?ooo`<00000;P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0S0?ooo`80003o803oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0803oool;0000oaH0oooo0`00
000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool09P3oool20000oaD0oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0S0?ooo`80003o503oool3000003X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo0200oooo2`000?l:0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
<@3oool300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000130?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`0U0?ooo`P0003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0R0?ooo`80003o00@0oooo0000
000000000000103oool30000od80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0200oooo00@0003o0000
0000000000002@3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?oo
o`<0000000<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000
oooo0?ooo`0H0?ooo`<00000103oool20000o`<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`100?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000002@3oool01@000?l0oooo
0?ooo`3oool0003o00D0oooo0P000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000
3@3oool50000odP0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000F0?ooo`D0003o@P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0203oool3000001@0oooo20000?m40?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`040?ooo`<000007`3oool30000od40oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
00009@3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool0I`3o
ool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0S0?ooo`L0003o>P3oool300000080oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0280oooo00<0003o0?ooo`3oool01@3oool20000oc@0oooo100000060?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0;P3oool3000000X0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0103oool40000ob`0oooo
0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`H0003o00<0oooo0000o`3oool0:P3o
ool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05@0oooo0`00000F0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0Z0?ooo`H0003o803oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0
oooo1`000?l40?ooo`<0003o703oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000
oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0F0?ooo`<000008P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01<0oooo0`00
000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?
0?ooo`030000003oool0oooo02X0oooo0`000?l20?ooo`<0003o4P3oool3000002X0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02d0oooo0P000?lA0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>03oool30000o`<0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`H0003o
0`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02h0oooo10000?l40?ooo`80003o0`00
000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<0000000<0oooo0000o`3oool0>`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0<@3oool4000000@0oooo00<0003o0?ooo`3oool0>`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0;P3oool3000000030?ooo`000?l0003o00D0003o?`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0:`3oool300000180oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:03oool3000000h0oooo10000?l30?ooo`80003o=`3oool00`000000oooo0?oo
o`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U
0?ooo`<00000303oool50000od40oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@
0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01h0oooo0`00000I0?ooo`@0003o?P3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo01/0oooo0`00000J0?ooo`80003o103oool30000oc/0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000001d0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01D0oooo0`00000Q0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>P3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000U0?ooo`<0003o0`3oool0
0`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool0
01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0
oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000002l0
oooo00@0003o0?ooo`3oool0oooo0`000?ll0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<0
0000<P3oool01@000?l0oooo0?ooo`3oool0003o0080oooo0P000?lk0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`040?ooo`@00000=@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`000?l0>`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000j0?ooo`80003o0P3oool00`00
0?l0oooo0?ooo`020000oc`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo1000000o0?ooo`80003o@P3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000004`0oooo10000?lf0?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03o
ool300000080oooo00<000000?ooo`3oool0@@3oool20000o`80oooo1@000?lk0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4
000000D0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool30000
00T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?oo
o`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool30000
02P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?oo
o`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool30000
04P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?oo
o`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo
0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?oo
o`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000
002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0
oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo
000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?oo
o`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`
0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?oo
o`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3o
ool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@00000
0?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`80
0000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`80
0000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003o
ool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2
000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool0
0`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
03d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B
0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool2
00000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool0
0600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?oo
o`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`800000
0P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4
000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0
oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?oo
o`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0
/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool4
00000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0
oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo
0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo
1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo
0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo
001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo0021
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?oo
o`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3o
ool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`00
00009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000
003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo
05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0
oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo
100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B
0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?oo
o`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000
003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003o
ool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0
oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo
1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo
00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?oo
o`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0
oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo
0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60135 .68216 m
.60212 .68085 L
s
.59902 .68177 m
.60135 .68216 L
s
.59978 .68046 m
.59902 .68177 L
s
.60212 .68085 m
.59978 .68046 L
s
.63174 .67205 m
.60988 .67854 L
s
.59345 .67362 m
.5895 .67151 L
s
.59735 .67355 m
.59345 .67362 L
s
.59891 .67309 m
.59735 .67355 L
s
.60123 .6713 m
.59891 .67309 L
s
.5895 .67151 m
.5871 .66893 L
s
.60121 .66911 m
.60123 .6713 L
s
.60983 .66982 m
.61217 .66803 L
s
.5988 .66431 m
.60121 .66911 L
s
.5871 .66893 m
.58626 .66586 L
s
.61217 .66803 m
.61137 .66496 L
s
.58626 .66586 m
.58858 .66406 L
s
.61137 .66496 m
.609 .66235 L
s
.59877 .6621 m
.5988 .66431 L
s
.609 .66235 m
.60505 .66021 L
s
.60111 .66028 m
.59877 .6621 L
s
.60505 .66021 m
.60111 .66028 L
s
.579 .65803 m
.58375 .65883 L
s
.57581 .65675 m
.579 .65803 L
s
.57336 .65412 m
.57581 .65675 L
s
.59631 .65503 m
.59786 .65232 L
s
.5733 .65188 m
.57336 .65412 L
s
.59786 .65232 m
.59783 .65007 L
s
.57481 .64915 m
.5733 .65188 L
s
.59783 .65007 m
.59541 .64742 L
s
.57872 .64683 m
.57481 .64915 L
s
.59541 .64742 m
.59221 .64612 L
s
.58187 .64587 m
.57872 .64683 L
s
.59221 .64612 m
.58743 .64531 L
s
.58743 .64531 m
.58187 .64587 L
s
.58566 .63671 m
.56351 .64349 L
s
.57272 .63145 m
.55686 .63633 L
s
.59762 .63419 m
.5984 .6328 L
s
.59521 .63378 m
.59762 .63419 L
s
.59599 .63239 m
.59521 .63378 L
s
.5984 .6328 m
.59599 .63239 L
s
.57667 .62907 m
.57272 .63145 L
s
.57661 .62676 m
.57667 .62907 L
s
.57412 .62403 m
.57661 .62676 L
s
.58119 .61596 m
.54763 .62638 L
s
.57086 .62269 m
.57412 .62403 L
s
.56355 .62143 m
.57086 .62269 L
s
.54477 .61665 m
.53988 .61581 L
s
.55042 .61608 m
.54477 .61665 L
s
.55362 .61508 m
.55042 .61608 L
s
.53988 .61581 m
.53657 .61446 L
s
.55758 .61265 m
.55362 .61508 L
s
.53657 .61446 m
.53399 .61168 L
s
.5591 .60979 m
.55758 .61265 L
s
.53399 .61168 m
.53387 .60933 L
s
.55305 .60088 m
.51937 .61149 L
s
.55901 .60743 m
.5591 .60979 L
s
.53387 .60933 m
.53535 .60645 L
s
.55646 .60463 m
.55901 .60743 L
s
.55315 .60326 m
.55646 .60463 L
s
.54821 .6024 m
.55315 .60326 L
s
.54704 .59428 m
.52448 .60143 L
s
.52434 .59904 m
.5293 .5999 L
s
.52099 .59766 m
.52434 .59904 L
s
.51836 .59483 m
.52099 .59766 L
s
.54219 .59581 m
.5437 .5929 L
s
.51821 .59242 m
.51836 .59483 L
s
.5437 .5929 m
.54359 .59048 L
s
.51968 .58949 m
.51821 .59242 L
s
.54359 .59048 m
.54099 .58762 L
s
.52365 .58699 m
.51968 .58949 L
s
.54099 .58762 m
.53762 .58623 L
s
.52689 .58595 m
.52365 .58699 L
s
.53762 .58623 m
.53263 .58535 L
s
.53263 .58535 m
.52689 .58595 L
s
.52961 .57513 m
.53225 .57803 L
s
.52519 .57027 m
.50239 .57762 L
s
.52621 .57371 m
.52961 .57513 L
s
.52118 .57282 m
.52621 .57371 L
s
.5154 .57343 m
.52118 .57282 L
s
.50098 .56925 m
.50514 .56917 L
s
.49591 .56836 m
.50098 .56925 L
s
.50514 .56917 m
.51003 .56758 L
s
.49247 .56693 m
.49591 .56836 L
s
.50553 .56268 m
.51003 .56758 L
s
.48883 .56301 m
.49247 .56693 L
s
.52313 .56334 m
.52553 .56129 L
s
.48864 .56051 m
.48883 .56301 L
s
.52553 .56129 m
.52704 .55825 L
s
.49008 .55746 m
.48864 .56051 L
s
.52704 .55825 m
.5269 .55573 L
s
.49245 .5554 m
.49008 .55746 L
s
.5269 .55573 m
.52332 .55176 L
s
.49646 .55279 m
.49245 .5554 L
s
.50469 .55009 m
.49646 .55279 L
s
.52332 .55176 m
.51987 .5503 L
s
.51987 .5503 m
.51476 .54939 L
s
.51055 .54947 m
.50469 .55009 L
s
.51476 .54939 m
.51055 .54947 L
s
.50087 .54354 m
.47411 .54714 L
s
.49351 .53546 m
.47411 .54714 L
s
.49351 .53546 m
.46664 .53909 L
s
.48608 .5273 m
.46664 .53909 L
s
.47953 .52009 m
.45626 .5279 L
s
.45601 .52529 m
.46122 .52623 L
s
.45245 .52379 m
.45601 .52529 L
s
.44958 .5207 m
.45245 .52379 L
s
.47452 .52177 m
.47597 .51858 L
s
.44932 .51807 m
.44958 .5207 L
s
.47597 .51858 m
.47575 .51595 L
s
.45072 .51487 m
.44932 .51807 L
s
.47575 .51595 m
.47291 .51283 L
s
.45477 .51213 m
.45072 .51487 L
s
.47291 .51283 m
.46934 .51131 L
s
.45811 .511 m
.45477 .51213 L
s
.46934 .51131 m
.46408 .51035 L
s
.46408 .51035 m
.45811 .511 L
s
.46049 .49917 m
.46337 .50234 L
s
.45565 .49386 m
.43214 .5019 L
s
.45687 .49763 m
.46049 .49917 L
s
.45157 .49665 m
.45687 .49763 L
s
.44555 .49732 m
.45157 .49665 L
s
.42832 .49062 m
.42298 .48964 L
s
.43267 .49053 m
.42832 .49062 L
s
.4387 .48986 m
.43267 .49053 L
s
.44715 .48696 m
.4387 .48986 L
s
.42298 .48964 m
.41831 .487 L
s
.41831 .487 m
.41131 .47946 L
s
.45125 .48413 m
.44715 .48696 L
s
.45366 .48189 m
.45125 .48413 L
s
.45511 .47855 m
.45366 .48189 L
s
.44697 .46705 m
.41131 .47946 L
s
.45387 .47471 m
.45511 .47855 L
s
.44697 .46705 m
.45387 .47471 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0a0?ooo`80003oG@3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0;@3o
ool30000o`80oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0:P3oool2
0000o`D0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
02H0oooo0`000?l80?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0R0?ooo`<0003o2`3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo00X0
oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool07`3oool20000o`l0oooo00<0003o0?ooo`3oool0F03oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?oo
o`1I0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0:
0?ooo`030000o`3oool0oooo05X0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`070?ooo`80003oG@3oool4000005D0oooo00<000000?ooo`3oool05`3oool0
02/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0O0?ooo`T0003oG@3oool30000
05P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`0Z0?ooo`80003oE@3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo02H0oooo
0`000?mD0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0S0?ooo`D0003o00<0oooo0000o`000?l00P00
0?m=0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0803oool20000o`X0oooo00<0003o
0?ooo`3oool0A`3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0Y0?oo
o`030000o`3oool0oooo03h0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo02@0oooo10000?l0103oool0003o0000o`000?lj0?ooo`<00000603oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0=@3oool3000001/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0<@3oool30000
01h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool01`3oool30000obd0
oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0O0?ooo`80003o1@3oool30000ob`0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`0P0?ooo`D0003o;03oool3000002P0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<00000
0?ooo`3oool07`3oool20000o`T0oooo00<0003o0?ooo`3oool0803oool3000002/0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`0W0?ooo`80003o803oool3000002h0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0903oool20000oal0oooo0`00000a0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`000000
8@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0240oooo0P000?l30?ooo`D0003o
5P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0O0?ooo`H0003o0P3o
ool20000oa@0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0T0?ooo`80003o4`3oool3
000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0240oooo0P000?l30?ooo`D0003o2P3oool30000
03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1m0?ooo`030000003oool0oooo01l0oooo1P000?l<0?ooo`<00000@03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo
00<000000?ooo`3oool0:03oool80000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02D0oooo0P00
0?l20?ooo`<000000`3oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo0280oooo0P000?l0
103oool000000000000000070?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0240oooo00<0003o0000000000002P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0L0?ooo`<0000000<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`100?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000000`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
503oool3000000H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`170?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0@0?ooo`<000002P3oool80000odP0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo00`0oooo0`00000I0?ooo`80003o@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool30000
01T0oooo1@000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000006@3oool30000o`D0
oooo00<0003o0?ooo`3oool0?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000J0?ooo`80003o
2@3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool09`3oool0
0`000?l0oooo0?ooo`0m0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo0`000?l00`3oool0003o0000o`020000
ocP0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool0<@3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0280oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^0?ooo`<000002P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool08P3oool00`000?l0oooo0?ooo`060?ooo`<0003o;03oool3000000h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02<0oooo00@0003o0?ooo`3oool0oooo10000?l/0?ooo`<000004P3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0903oool30000o`L0oooo0P000?lT0?ooo`<000005P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0:`3oool50000ob00oooo1000000J0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0X0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`0J0?ooo`<000007P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09@3oool40000o`P0oooo00<0003o0?ooo`3oool05P3oool300000280oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02<0oooo0P000?l30?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool04`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`03
0?ooo`<0003o4P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02X0oooo1@000?l:0?oo
o`80003o1@3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03L0oooo0`000?l40?ooo`<0
0000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool50000o`<0oooo0`00000f0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0`0?ooo`<0003o1@3oool3000003X0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02h0oooo0P000?l50?ooo`<0000000<0oooo0000o`3oool0>`3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0<@3oool4000000@0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0;P3oool3000000@0oooo10000?l70?ooo`80003o=P3oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
:`3oool3000000@0oooo0`000?l<0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02P0oooo0`00000@0?ooo`80003o?03oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000003`3oool4
0000ocl0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool20000
0900oooo00<000000?ooo`3oool08@3oool4000000l0oooo0`000?m40?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0N0?ooo`<000006@3oool60000oc`0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0K0?ooo`<000006P3oool20000o`H0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<000007@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool05@3oool300000200oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0k0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P000007
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000002@0oooo00<0003o
0?ooo`3oool0@`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?oo
o`<00000:@3oool30000o`D0oooo0`000?lk0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool02`3oool3000003<0oooo00D0003o0?ooo`3oool0oooo0000o`0j0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`080?ooo`<00000<@3oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0h0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000=03oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@0
00000?ooo`3oool0oooo0`00000i0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0
003o?@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000
T@3oool4000003d0oooo10000?l:0?ooo`80003o=P3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000004X0oooo10000?lh0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool3
00000080oooo00<000000?ooo`3oool0A@3oool30000ocd0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`00
0000oooo0?ooo`110?ooo`80003o@`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo0480
oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<0
0000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60168 .68448 m
.6024 .68288 L
s
.59938 .68438 m
.60168 .68448 L
s
.6001 .68278 m
.59938 .68438 L
s
.6024 .68288 m
.6001 .68278 L
s
.63121 .66856 m
.60996 .67912 L
s
.5976 .6753 m
.59377 .67595 L
s
.59911 .67454 m
.5976 .6753 L
s
.59377 .67595 m
.58986 .67414 L
s
.60136 .67217 m
.59911 .67454 L
s
.60129 .66969 m
.60136 .67217 L
s
.60975 .66924 m
.612 .66686 L
s
.58986 .67414 m
.58746 .67155 L
s
.59884 .6646 m
.60129 .66969 L
s
.612 .66686 m
.61116 .6635 L
s
.58746 .67155 m
.58658 .6682 L
s
.61116 .6635 m
.60879 .66089 L
s
.58658 .6682 m
.58882 .66581 L
s
.59877 .6621 m
.59884 .6646 L
s
.60879 .66089 m
.60488 .65904 L
s
.60103 .6597 m
.59877 .6621 L
s
.60488 .65904 m
.60103 .6597 L
s
.57931 .66037 m
.58399 .66058 L
s
.57616 .65939 m
.57931 .66037 L
s
.59623 .65445 m
.59769 .65115 L
s
.57371 .65675 m
.57616 .65939 L
s
.59769 .65115 m
.59762 .64861 L
s
.57361 .65422 m
.57371 .65675 L
s
.59762 .64861 m
.5952 .64595 L
s
.57504 .65091 m
.57361 .65422 L
s
.5952 .64595 m
.59205 .64495 L
s
.57883 .64771 m
.57504 .65091 L
s
.59205 .64495 m
.58735 .64472 L
s
.58191 .64616 m
.57883 .64771 L
s
.58735 .64472 m
.58191 .64616 L
s
.58546 .63524 m
.56385 .64614 L
s
.59712 .63067 m
.59786 .62898 L
s
.59475 .63055 m
.59712 .63067 L
s
.59549 .62886 m
.59475 .63055 L
s
.59786 .62898 m
.59549 .62886 L
s
.57268 .63115 m
.5572 .63898 L
s
.57651 .62789 m
.57268 .63115 L
s
.57641 .62529 m
.57651 .62789 L
s
.57392 .62255 m
.57641 .62529 L
s
.5707 .62151 m
.57392 .62255 L
s
.5807 .61241 m
.54796 .62904 L
s
.56352 .62114 m
.5707 .62151 L
s
.54499 .61843 m
.54017 .61817 L
s
.55053 .61696 m
.54499 .61843 L
s
.55365 .61537 m
.55053 .61696 L
s
.5575 .61206 m
.55365 .61537 L
s
.54017 .61817 m
.53689 .61713 L
s
.55894 .60861 m
.5575 .61206 L
s
.53689 .61713 m
.53432 .61435 L
s
.55882 .60594 m
.55894 .60861 L
s
.53432 .61435 m
.53416 .6117 L
s
.55286 .59939 m
.51991 .61624 L
s
.55627 .60314 m
.55882 .60594 L
s
.53416 .6117 m
.53557 .60823 L
s
.55299 .60207 m
.55627 .60314 L
s
.54814 .60181 m
.55299 .60207 L
s
.54686 .59279 m
.52479 .6041 L
s
.52462 .60142 m
.52951 .60168 L
s
.5213 .60034 m
.52462 .60142 L
s
.54212 .59522 m
.54355 .59171 L
s
.51867 .59751 m
.5213 .60034 L
s
.54355 .59171 m
.5434 .58899 L
s
.51849 .5948 m
.51867 .59751 L
s
.5434 .58899 m
.5408 .58614 L
s
.51989 .59128 m
.51849 .5948 L
s
.5408 .58614 m
.53748 .58504 L
s
.52376 .58788 m
.51989 .59128 L
s
.53748 .58504 m
.53256 .58476 L
s
.52693 .58625 m
.52376 .58788 L
s
.53256 .58476 m
.52693 .58625 L
s
.52943 .57363 m
.53207 .57653 L
s
.52607 .57252 m
.52943 .57363 L
s
.52501 .56877 m
.50269 .58031 L
s
.52111 .57222 m
.52607 .57252 L
s
.51543 .57373 m
.52111 .57222 L
s
.50527 .57037 m
.51007 .56788 L
s
.50118 .57105 m
.50527 .57037 L
s
.49617 .57075 m
.50118 .57105 L
s
.50557 .56298 m
.51007 .56788 L
s
.49276 .56963 m
.49617 .57075 L
s
.48912 .56571 m
.49276 .56963 L
s
.52288 .56124 m
.52521 .55859 L
s
.52521 .55859 m
.52664 .55495 L
s
.4889 .56291 m
.48912 .56571 L
s
.52664 .55495 m
.52647 .55213 L
s
.49028 .55927 m
.4889 .56291 L
s
.52647 .55213 m
.52289 .54815 L
s
.49258 .5566 m
.49028 .55927 L
s
.49649 .55309 m
.49258 .5566 L
s
.52289 .54815 m
.51948 .547 L
s
.50455 .54889 m
.49649 .55309 L
s
.51948 .547 m
.51444 .54668 L
s
.51444 .54668 m
.51031 .54737 L
s
.51031 .54737 m
.50455 .54889 L
s
.5007 .54204 m
.47438 .54985 L
s
.49335 .53395 m
.47438 .54985 L
s
.49335 .53395 m
.46691 .5418 L
s
.48592 .52579 m
.46691 .5418 L
s
.47937 .51858 m
.45652 .53062 L
s
.45624 .52771 m
.4614 .52804 L
s
.4527 .52651 m
.45624 .52771 L
s
.47446 .52117 m
.47585 .51737 L
s
.44983 .52342 m
.4527 .52651 L
s
.47585 .51737 m
.4756 .51444 L
s
.44954 .52049 m
.44983 .52342 L
s
.4756 .51444 m
.47276 .51131 L
s
.4509 .51669 m
.44954 .52049 L
s
.47276 .51131 m
.46922 .51009 L
s
.45485 .51304 m
.4509 .51669 L
s
.46922 .51009 m
.46402 .50974 L
s
.45814 .51131 m
.45485 .51304 L
s
.46402 .50974 m
.45814 .51131 L
s
.46034 .49765 m
.46322 .50083 L
s
.45675 .49641 m
.46034 .49765 L
s
.45551 .49234 m
.43238 .50464 L
s
.45151 .49605 m
.45675 .49641 L
s
.44558 .49762 m
.45151 .49605 L
s
.43278 .49175 m
.42848 .49245 L
s
.43873 .49016 m
.43278 .49175 L
s
.44703 .48574 m
.43873 .49016 L
s
.42848 .49245 m
.42318 .49208 L
s
.42318 .49208 m
.41854 .48975 L
s
.45104 .482 m
.44703 .48574 L
s
.4534 .47915 m
.45104 .482 L
s
.41854 .48975 m
.41154 .4822 L
s
.45478 .4752 m
.4534 .47915 L
s
.45352 .47105 m
.45478 .4752 L
s
.44663 .46339 m
.41154 .4822 L
s
.44663 .46339 m
.45352 .47105 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0380oooo00<0003o0?ooo`3o
ool0G03oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02l0oooo0P000?l00`3oool0003o
0?ooo`1L0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo
000/0?ooo`800000G@3oool00`000000oooo0?ooo`0/0?ooo`80003o103oool00`000?l0oooo0?oo
o`1J0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`800000G`3oool00`000000oooo0?ooo`0Y0?ooo`80003o1`3oool00`000?l0oooo0?ooo`1I
0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool09P3oool20000o`T0oooo00<0003o0?oo
o`3oool0F@3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?oo
o`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02<0oooo0P000?l;0?ooo`03
0000o`3oool0oooo05T0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0P0?ooo`80003o
3@3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool07P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0103o
ool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0F`3oool0
10000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00L0oooo0P000?mN
0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00P3oool40000oeh0oooo0`00001H0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool07P3oool40000o`P0oooo0P000?mE0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0
9`3oool40000oe80oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02D0oooo0`000?l30?ooo`030000o`3o
ool0oooo04`0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0R0?ooo`80003o1`3oool2
0000odT0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07`3oool20000
oe40oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
06h0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo
02T0oooo0`000?ln0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`0T0?ooo`@0003o0`3oool00`000?l0oooo0?ooo`0h0?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0=03oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`000?l0<@3oool3000001h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool01`3oool20000obh0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00@0oooo0P00
0?l]0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X
0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool07`3oool010000?l0oooo0?ooo`3o
ool20000o`H0oooo00<0003o0?ooo`3oool08`3oool3000002P0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool07`3oool3
0000o`L0oooo00<0003o0?ooo`3oool08@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07`3oool30000
02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000
oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0903oool20000o`@0
oooo0P000?lI0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo
0?ooo`0R0?ooo`040000o`3oool0oooo0?ooo`@0003o5`3oool3000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0P0?ooo`D0003o0P3oool00`000?l0oooo0?ooo`0C0?ooo`<00000
=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool07P3oool20000o`@0oooo0P000?l40?ooo`80003o3@3o
ool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool0
0`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0280oooo00@0003o0?ooo`3oool0oooo0`00
0?l<0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0803oool50000o`L0oooo1@000?l3
00000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo01h0oooo0P000?l80?ooo`<0003o0P3oool30000
00030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02D0oooo0P000?l20?ooo`<0
0000103oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`000000
0P0000070?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo00<0
00000000o`0000002P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L
0?ooo`@0000000<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`00
0000oooo0?ooo`0H0?ooo`<000000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
04P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`0000060?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000000X0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0400oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo00`0oooo0`00000>0?ooo`H0003o103oool20000od<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo00P0oooo0`00000I0?ooo`H0003o@@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0103oool3000001X0oooo0P000?l60?ooo`030000o`3oool0oooo03h0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00<000006`3oool20000odT0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007@3oool00`000?l0oooo
0?ooo`190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00
002=0?ooo`030000003oool0oooo02L0oooo0`000?lm0?ooo`800000F`3oool00`000000oooo0?oo
o`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo0`000?l3
0?ooo`80003o>03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0b0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`060?ooo`80003o;`3oool3000000X0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`3oool01P3oool20000obd0oooo0`00000>0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00@0oooo0P000?l/0?ooo`<000004P3o
ool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool08`3oool60000o`H0oooo00<0003o0?ooo`3oool08P3oool3
000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo0P000?l60?ooo`@0003o7`3oool40000
01X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo0P000?l40?ooo`030000o`3oool0oooo01T0
oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`80003o1P3oool00`000?l0oooo
0?ooo`0F0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool09`3oool20000o`P0oooo00<0
003o0?ooo`3oool04`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool09@3oool20000o`030?ooo`000?l0
oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`080?ooo`<00000:P3oool0
0`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool08`3oool20000o`@0oooo00<0003o0?ooo`3oool00P3oool20000
o`L0oooo0P000?l70?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool40000o`L0
oooo0P000?l60?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool50000o`80oooo
0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`80003o103oool3000003X0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo0300oooo0P000?l30?ooo`<0000000<0oooo0000o`3oool0>`3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0;P3oool20000o`030?ooo`0000000000008000000P3oool20000
o`L0oooo0P000?le0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000103oool20000od40
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000050?ooo`80003o1`3oool00`000?l0oooo
0?ooo`0i0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000001`3oool00`000?l0oooo0?oo
o`050?ooo`80003o?@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R
0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000403oool20000od00oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?oo
o`3oool08@3oool400000140oooo0P000?m30?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<0
00004`3oool20000o`D0oooo1P000?lk0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
6`3oool3000001`0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0h0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000M0?ooo`80003o
1`3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01D0oooo0`00000P0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>`3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000S0?ooo`030000o`3oool0
oooo04@0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool30000
02P0oooo10000?l50?ooo`80003o?03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0
oooo0`00000c0?ooo`030000o`3oool0oooo0080003o>P3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
203oool300000380oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo03P0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000e0?ooo`050000o`3oool0oooo0?ooo`00
0?l0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000
003oool0oooo0?ooo`<00000>@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000
o`D0oooo0P000?lf0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200
oooo0P00002A0?ooo`@00000?03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0
oooo0P000?li0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000@03oool40000o`D0oooo0P000?lk0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<0
00000?ooo`3oool0A@3oool20000och0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0@@3oool30000od<0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<0
0000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0
R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0
oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00
001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?oo
o`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<0
0000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0
oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`000015
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;
0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<0
0000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0
oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U
0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0
oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo
0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`000024
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000
003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000
103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2
000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo
0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`80
0000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003o
ool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3
000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P000000
0`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3o
ool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo
00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
04/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0013
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<00000
0?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<00000
4@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3o
ool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0
oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@00000
0?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`00
0000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000
oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?oo
o`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`03
0000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0
b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3o
ool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4
000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700
oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo
0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?oo
o`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3o
ool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0
W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool00000
3`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000
B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000
003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003o
ool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool40000
05d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool40000
0640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0
oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P000003
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?oo
o`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?oo
o`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003o
ool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0
oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool50000
0940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0
oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<0
00000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<
0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`
0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?oo
o`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3o
ool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D0
0000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`800000
2`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool00000
8`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03o
ool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool50000
0<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool0
00001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000
g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103o
ool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60254 .68655 m
.60315 .68469 L
s
.60034 .68671 m
.60254 .68655 L
s
.60096 .68485 m
.60034 .68671 L
s
.60315 .68469 m
.60096 .68485 L
s
.62988 .66547 m
.61018 .67964 L
s
.59824 .67685 m
.59462 .67803 L
s
.59965 .67584 m
.59824 .67685 L
s
.60168 .67295 m
.59965 .67584 L
s
.59462 .67803 m
.59082 .67647 L
s
.60953 .66873 m
.61157 .66583 L
s
.60151 .67021 m
.60168 .67295 L
s
.61157 .66583 m
.61062 .66221 L
s
.59082 .67647 m
.58842 .67389 L
s
.59895 .66486 m
.60151 .67021 L
s
.61062 .66221 m
.60825 .6596 L
s
.58842 .67389 m
.58743 .67027 L
s
.60825 .6596 m
.60445 .65801 L
s
.59877 .6621 m
.59895 .66486 L
s
.58743 .67027 m
.58946 .66736 L
s
.60081 .65918 m
.59877 .6621 L
s
.60445 .65801 m
.60081 .65918 L
s
.58016 .66245 m
.58462 .66214 L
s
.59601 .65393 m
.59726 .65011 L
s
.57711 .66172 m
.58016 .66245 L
s
.57466 .65909 m
.57711 .66172 L
s
.59726 .65011 m
.59708 .64732 L
s
.59708 .64732 m
.59466 .64466 L
s
.57446 .6563 m
.57466 .65909 L
s
.57568 .65247 m
.57446 .6563 L
s
.59466 .64466 m
.59162 .64391 L
s
.59162 .64391 m
.58713 .6442 L
s
.57915 .64849 m
.57568 .65247 L
s
.58713 .6442 m
.58202 .64642 L
s
.58202 .64642 m
.57915 .64849 L
s
.58492 .63394 m
.5648 .64848 L
s
.59581 .62756 m
.59644 .62561 L
s
.59355 .62769 m
.59581 .62756 L
s
.59418 .62575 m
.59355 .62769 L
s
.59644 .62561 m
.59418 .62575 L
s
.57257 .63089 m
.55815 .64133 L
s
.57608 .62685 m
.57257 .63089 L
s
.57587 .62398 m
.57608 .62685 L
s
.57338 .62125 m
.57587 .62398 L
s
.57027 .62047 m
.57338 .62125 L
s
.56341 .62088 m
.57027 .62047 L
s
.5794 .60929 m
.5489 .63139 L
s
.55085 .61775 m
.54562 .62 L
s
.55376 .61563 m
.55085 .61775 L
s
.55729 .61154 m
.55376 .61563 L
s
.54562 .62 m
.541 .62027 L
s
.55852 .60756 m
.55729 .61154 L
s
.541 .62027 m
.53783 .61948 L
s
.53783 .61948 m
.53525 .61671 L
s
.55828 .60464 m
.55852 .60756 L
s
.55574 .60184 m
.55828 .60464 L
s
.53525 .61671 m
.53499 .6138 L
s
.53499 .6138 m
.5362 .60981 L
s
.55257 .60103 m
.55574 .60184 L
s
.55233 .59809 m
.52156 .62044 L
s
.54792 .60129 m
.55257 .60103 L
s
.54632 .59148 m
.52572 .60646 L
s
.52545 .60352 m
.53013 .60326 L
s
.54191 .5947 m
.54313 .59066 L
s
.52223 .60271 m
.52545 .60352 L
s
.5196 .59987 m
.52223 .60271 L
s
.54313 .59066 m
.54287 .58769 L
s
.54287 .58769 m
.54027 .58483 L
s
.51931 .59691 m
.5196 .59987 L
s
.52051 .59286 m
.51931 .59691 L
s
.54027 .58483 m
.53705 .58399 L
s
.53705 .58399 m
.53235 .58423 L
s
.52407 .58867 m
.52051 .59286 L
s
.53235 .58423 m
.52703 .58651 L
s
.52703 .58651 m
.52407 .58867 L
s
.5289 .57232 m
.53154 .57522 L
s
.52565 .57147 m
.5289 .57232 L
s
.5209 .5717 m
.52565 .57147 L
s
.52449 .56746 m
.50362 .58269 L
s
.51553 .57399 m
.5209 .5717 L
s
.50568 .57142 m
.51017 .56815 L
s
.50179 .57263 m
.50568 .57142 L
s
.50567 .56325 m
.51017 .56815 L
s
.49699 .57287 m
.50179 .57263 L
s
.52215 .5594 m
.52425 .55623 L
s
.49368 .57201 m
.49699 .57287 L
s
.52425 .55623 m
.52547 .55206 L
s
.49004 .56809 m
.49368 .57201 L
s
.52547 .55206 m
.52519 .54898 L
s
.52519 .54898 m
.52161 .545 L
s
.48971 .56502 m
.49004 .56809 L
s
.49089 .56085 m
.48971 .56502 L
s
.52161 .545 m
.51831 .54411 L
s
.49299 .55766 m
.49089 .56085 L
s
.51831 .54411 m
.51349 .54432 L
s
.49659 .55336 m
.49299 .55766 L
s
.51349 .54432 m
.50957 .54553 L
s
.50414 .54784 m
.49659 .55336 L
s
.50957 .54553 m
.50414 .54784 L
s
.50018 .54072 m
.47529 .55223 L
s
.49283 .53263 m
.47529 .55223 L
s
.49283 .53263 m
.46782 .54419 L
s
.4854 .52447 m
.46782 .54419 L
s
.47885 .51726 m
.45742 .53301 L
s
.45704 .52983 m
.46201 .52964 L
s
.47425 .52064 m
.47544 .51632 L
s
.4536 .5289 m
.45704 .52983 L
s
.45073 .52581 m
.4536 .5289 L
s
.47544 .51632 m
.47508 .51311 L
s
.47508 .51311 m
.47224 .50999 L
s
.45034 .52262 m
.45073 .52581 L
s
.4515 .51828 m
.45034 .52262 L
s
.47224 .50999 m
.46881 .50904 L
s
.46881 .50904 m
.46382 .50921 L
s
.45516 .51384 m
.4515 .51828 L
s
.46382 .50921 m
.45824 .51157 L
s
.45824 .51157 m
.45516 .51384 L
s
.45983 .49633 m
.46271 .4995 L
s
.45635 .49535 m
.45983 .49633 L
s
.45131 .49552 m
.45635 .49535 L
s
.455 .49102 m
.43327 .50704 L
s
.44568 .49789 m
.45131 .49552 L
s
.43883 .49043 m
.43317 .49281 L
s
.44663 .48468 m
.43883 .49043 L
s
.43317 .49281 m
.42907 .49404 L
s
.45033 .48015 m
.44663 .48468 L
s
.42907 .49404 m
.42397 .49421 L
s
.45248 .47676 m
.45033 .48015 L
s
.42397 .49421 m
.41942 .49215 L
s
.45366 .47228 m
.45248 .47676 L
s
.41942 .49215 m
.41241 .48461 L
s
.45229 .46787 m
.45366 .47228 L
s
.4454 .4602 m
.45229 .46787 L
s
.4454 .4602 m
.41241 .48461 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0<`3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0<@3oool00`000?l0oooo0000o`1M0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;P3oool20000o`80oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0;03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool0503o
ool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0
oooo02X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0
oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool09`3oool20000o`P0oooo00<0003o0?ooo`3oool0F@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`1I0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool08`3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool01`3oool3000004/0oooo
00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0P0?ooo`80003o2P3oool00`000?l0oooo0?ooo`1K0?ooo`030000003oool0oooo00@0oooo0`00
001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool07P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo05`0oooo00@00000
0?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`060?ooo`80003oG`3oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`1F0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo01d0oooo1`000?l50?ooo`80003oEP3oool300000080
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0000001X0?ooo`030000003oool0oooo02L0oooo1@000?mA0?ooo`<000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?oo
o`0U0?ooo`<0003o103oool00`000?l0oooo0?ooo`1;0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool08`3oool00`000?l0oooo0?ooo`1@0?ooo`<000002`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo0?ooo`1Z0?oo
o`030000003oool0oooo0200oooo0P000?m@0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo04d0oooo0`00000A0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02T0oooo10000?lm0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0V0?oo
o`80003o103oool00`000?l0oooo0?ooo`0g0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0=03oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0Q0?ooo`80
003o1`3oool20000oc80oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0P0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;@3oool400000240oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo01l0oooo00<0003o0?ooo`3oool0103oool20000obd0oooo0`00000U0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool0
0`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`0S0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0N0?ooo`050000o`3oool0oooo
0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0Q0?ooo`<00000:`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo01h0oooo0`000?l60?ooo`030000o`3oool0oooo01l0oooo0`00000^0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`00
0000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`80003o6@3oool300000340oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool08`3oool010000?l0oooo0?ooo`3oool30000oaL0
oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo
0000o`020000o`030?ooo`000?l0oooo01@0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`0O0?ooo`<0003o0`3oool010000?l0oooo0?ooo`3oool20000o`h0oooo0`00000j0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03o
ool00`000000oooo0?ooo`0M0?ooo`80003o103oool00`000?l0oooo0?ooo`020000o`H0oooo1000
0?l30?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool08@3oool010000?l0oooo0000o`00
0?l50?ooo`<0003o103oool00`000?l00000000000100?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0O
0?ooo`<0003o1@3oool20000o`@0oooo0`0000000`3oool0003o0?ooo`100?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`00
0000oooo0?ooo`0M0?ooo`80003o1P3oool010000?l0oooo0?ooo`3oool3000000@0oooo00<0003o
0?ooo`3oool0?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`<00000P@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool00000008000001P3oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`03000000000?l0000000T0
oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4000000030000
o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000000<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`180?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool0
0`000000oooo0?ooo`0D0?ooo`<000001P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo04L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000:0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0<0?ooo`<000003P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo10000?m20?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`080?ooo`<000004P3oool30000o`@0oooo0P000?l30?ooo`03
0000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000K0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00
000L0?ooo`80003oB03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08`0oooo0P00000N0?ooo`030000o`3oool0oooo04P0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?oo
o`3oool09`3oool40000oc`0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool20000o`@0oooo00<0003o0?ooo`3o
ool0=P3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0b0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o02l0oooo0`00000:0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00D0oooo0P000?l]0?ooo`<000003P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool09@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo0`000?lT0?ooo`<000005P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0903oool40000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`0O0?ooo`@0
00006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`020?ooo`80003o
1@3oool00`000?l0oooo0?ooo`0I0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03P3o
ool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02L0oooo0`000?l70?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0303oool3000002H0oooo00<000000?ooo`3oool0DP3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0000o`070?ooo`030000o`3oool0oooo00<0oooo0P000?l<0?ooo`<00000:P3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0903oool20000o`80oooo00<0003o0?ooo`3oool00`3oool20000o`D0
oooo00<0003o0?ooo`3oool0203oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02@0oooo
00<0003o0?ooo`3oool00`3oool50000o`H0oooo00<0003o0?ooo`3oool01P3oool3000003<0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03@0oooo1@000?l20?ooo`<00000=P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`020?ooo`<00000103oool20000oc@0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0340oooo0P000?l20?ooo`<0000000<0oooo0000o`3oool0103oool20000
ocD0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0300oooo00<0003o0000000000000P0000020?ooo`80
003o?P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000D0oooo00<0003o0?ooo`3oool0
?`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000H0oooo0P000?l60?ooo`030000o`3o
ool0oooo03T0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`0000080?ooo`030000o`3oool0
oooo00@0oooo0P000?lm0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000:0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@000004P3oool20000o`@0
oooo0P000?ll0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000503oool20000o`@0oooo
0P000?l20?ooo`80003o>`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo
000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00
000F0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0h0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00
000N0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000803oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?oo
o`@000008`3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00h0oooo0`00000W0?ooo`030000o`3oool0oooo00L0oooo10000?lj0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000002/0oooo10000?l40?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203o
ool3000003H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo0340oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000f0?ooo`040000o`3oool0
oooo0000o`<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0c0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
10000000oooo0?ooo`3oool3000003T0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?oo
o`000?l40?ooo`80003o=`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo
000P0?ooo`800000T@3oool4000003`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool200000900oooo0`0000100?ooo`040000o`3oool0oooo0000o`H0oooo00<0
003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo03l0oooo0`000?l4
0?ooo`80003o?@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo04D0oooo00<0003o0?oo
o`3oool0?P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3o
ool0@@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo0480oooo0P000?m40?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3o
ool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3o
ool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0
oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3o
ool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0
oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<0
0000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3o
ool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?oo
o`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<0
0000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D00000
0P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`00
3@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool01000
0000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`
0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo
000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo
00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?oo
o`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?oo
o`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@0
00000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool0
3`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool0
10000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`00
0000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?oo
o`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80
000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T
0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?oo
o`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@0
00002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3o
ool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000
oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo
0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000
000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/
0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?oo
o`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000
003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3o
ool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3o
ool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03o
ool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2
000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0
oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0
oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo
00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?oo
o`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]
0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D0
0000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000
P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03o
ool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`00
0000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0
oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?oo
o`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?oo
o`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h
0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?oo
o`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@0
0000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3o
ool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3o
ool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003o
ool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0
oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo
0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000
d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3o
ool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.62782 .66292 m
.61052 .68007 L
s
.60389 .68827 m
.60433 .68619 L
s
.60186 .68864 m
.60389 .68827 L
s
.60433 .68619 m
.60231 .68657 L
s
.60231 .68657 m
.60186 .68864 L
s
.60919 .6683 m
.61089 .66497 L
s
.60049 .67691 m
.59925 .67814 L
s
.60219 .67359 m
.60049 .67691 L
s
.59925 .67814 m
.59597 .67974 L
s
.61089 .66497 m
.60976 .66114 L
s
.60185 .67063 m
.60219 .67359 L
s
.59597 .67974 m
.59234 .6784 L
s
.59912 .66507 m
.60185 .67063 L
s
.60976 .66114 m
.60739 .65853 L
s
.59234 .6784 m
.58994 .67582 L
s
.60739 .65853 m
.60377 .65715 L
s
.58994 .67582 m
.58878 .67199 L
s
.59877 .6621 m
.59912 .66507 L
s
.60377 .65715 m
.60047 .65875 L
s
.60047 .65875 m
.59877 .6621 L
s
.58878 .67199 m
.59047 .66865 L
s
.59567 .6535 m
.59658 .64926 L
s
.58151 .66417 m
.58564 .66343 L
s
.59658 .64926 m
.59622 .64625 L
s
.57863 .66366 m
.58151 .66417 L
s
.59622 .64625 m
.59381 .64359 L
s
.57618 .66103 m
.57863 .66366 L
s
.59381 .64359 m
.59093 .64306 L
s
.57581 .65803 m
.57618 .66103 L
s
.59093 .64306 m
.58679 .64378 L
s
.57669 .65376 m
.57581 .65803 L
s
.58679 .64378 m
.58219 .64663 L
s
.57966 .64913 m
.57669 .65376 L
s
.58219 .64663 m
.57966 .64913 L
s
.59374 .625 m
.5942 .62284 L
s
.59167 .62535 m
.59374 .625 L
s
.5942 .62284 m
.59212 .62319 L
s
.59212 .62319 m
.59167 .62535 L
s
.58406 .63287 m
.56631 .65042 L
s
.5724 .63068 m
.55966 .64327 L
s
.5754 .62599 m
.5724 .63068 L
s
.57502 .62291 m
.5754 .62599 L
s
.57253 .62018 m
.57502 .62291 L
s
.56959 .61961 m
.57253 .62018 L
s
.56324 .62066 m
.56959 .61961 L
s
.57733 .60674 m
.55042 .63333 L
s
.55393 .61585 m
.55135 .61839 L
s
.55695 .61111 m
.55393 .61585 L
s
.55135 .61839 m
.54664 .62129 L
s
.55783 .6067 m
.55695 .61111 L
s
.54664 .62129 m
.54235 .622 L
s
.55743 .60357 m
.55783 .6067 L
s
.54235 .622 m
.53935 .62143 L
s
.55488 .60077 m
.55743 .60357 L
s
.53935 .62143 m
.53677 .61866 L
s
.55189 .60017 m
.55488 .60077 L
s
.53677 .61866 m
.53634 .61552 L
s
.54758 .60086 m
.55189 .60017 L
s
.53634 .61552 m
.53721 .6111 L
s
.55147 .59702 m
.52423 .62392 L
s
.54547 .59041 m
.52724 .60841 L
s
.54157 .59427 m
.54244 .5898 L
s
.5268 .60525 m
.53115 .60455 L
s
.54244 .5898 m
.54202 .58661 L
s
.52374 .60465 m
.5268 .60525 L
s
.54202 .58661 m
.53942 .58375 L
s
.52111 .60182 m
.52374 .60465 L
s
.53942 .58375 m
.53637 .58313 L
s
.52066 .59864 m
.52111 .60182 L
s
.53637 .58313 m
.53201 .5838 L
s
.52152 .59415 m
.52066 .59864 L
s
.53201 .5838 m
.5272 .58673 L
s
.52458 .58932 m
.52152 .59415 L
s
.5272 .58673 m
.52458 .58932 L
s
.52805 .57125 m
.53069 .57415 L
s
.52497 .57061 m
.52805 .57125 L
s
.52056 .57127 m
.52497 .57061 L
s
.5157 .57421 m
.52056 .57127 L
s
.52363 .56639 m
.50513 .58464 L
s
.52095 .5579 m
.52271 .5543 L
s
.50584 .56346 m
.51034 .56836 L
s
.50636 .57229 m
.51034 .56836 L
s
.5028 .57393 m
.50636 .57229 L
s
.52271 .5543 m
.52359 .54971 L
s
.49834 .5746 m
.5028 .57393 L
s
.52359 .54971 m
.52313 .54642 L
s
.49519 .57396 m
.49834 .5746 L
s
.52313 .54642 m
.51956 .54244 L
s
.49155 .57004 m
.49519 .57396 L
s
.51956 .54244 m
.51643 .54176 L
s
.49106 .56676 m
.49155 .57004 L
s
.51643 .54176 m
.51195 .54239 L
s
.4919 .56215 m
.49106 .56676 L
s
.51195 .54239 m
.50838 .54402 L
s
.49366 .55852 m
.4919 .56215 L
s
.50838 .54402 m
.50346 .54698 L
s
.49676 .55357 m
.49366 .55852 L
s
.50346 .54698 m
.49676 .55357 L
s
.49933 .53964 m
.4768 .55418 L
s
.49198 .53156 m
.4768 .55418 L
s
.49198 .53156 m
.46932 .54614 L
s
.48455 .52339 m
.46932 .54614 L
s
.478 .51618 m
.45892 .53496 L
s
.47392 .52021 m
.47476 .51546 L
s
.45838 .53157 m
.46301 .53093 L
s
.47476 .51546 m
.47423 .51204 L
s
.45511 .53086 m
.45838 .53157 L
s
.47423 .51204 m
.4714 .50892 L
s
.45223 .52777 m
.45511 .53086 L
s
.4714 .50892 m
.46813 .50818 L
s
.45168 .52435 m
.45223 .52777 L
s
.46813 .50818 m
.46348 .50878 L
s
.4525 .51958 m
.45168 .52435 L
s
.46348 .50878 m
.45841 .51179 L
s
.45566 .51449 m
.4525 .51958 L
s
.45841 .51179 m
.45566 .51449 L
s
.45898 .49525 m
.46186 .49843 L
s
.45567 .49449 m
.45898 .49525 L
s
.45097 .49509 m
.45567 .49449 L
s
.44585 .4981 m
.45097 .49509 L
s
.45415 .48994 m
.43477 .50899 L
s
.44595 .48382 m
.439 .49065 L
s
.44914 .47864 m
.44595 .48382 L
s
.439 .49065 m
.43384 .49368 L
s
.45095 .47483 m
.44914 .47864 L
s
.43384 .49368 m
.43007 .49534 L
s
.45178 .46993 m
.45095 .47483 L
s
.43007 .49534 m
.4253 .49594 L
s
.45024 .4653 m
.45178 .46993 L
s
.4253 .49594 m
.42092 .4941 L
s
.44336 .45764 m
.45024 .4653 L
s
.42092 .4941 m
.41391 .48656 L
s
.44336 .45764 m
.41391 .48656 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0oooo05`0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0003o05d0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0_0?ooo`050000o`3oool0oooo0?ooo`000?l0G@3oool00`00
0000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`1J0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0
oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo05X0oooo00<000000?ooo`3oool04@3oool300000440oooo00<0
00000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`0>
0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1K0?oo
o`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo05/0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`040?ooo`<00000
CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo01l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`1L0?ooo`040000003o
ool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`1M0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo01d0oooo0P000?l70?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0E`3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo0080oooo0P000?l40?oo
o`030000o`3oool0003o05D0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`0N0?ooo`@0
003o1@3oool30000o`030?ooo`000?l0oooo0500oooo0`0000050?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02H0oooo
0P000?l40?ooo`030000o`3oool0oooo04/0oooo0`0000080?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?oo
o`0T0?ooo`030000o`3oool0oooo04l0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<00000
0?ooo`3oool08P3oool00`000?l0oooo0?ooo`1=0?ooo`<000003P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo04/0oooo0`00000A
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo01h0oooo00<0003o
0?ooo`3oool0203oool40000ocd0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo02H0oooo0P000?l40?ooo`030000o`3oool0oooo03L0oooo0`00000H
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0d0?ooo`<000006`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo0280oooo00<0003o0?ooo`3oool01@3oool20000oc80oooo0`00000N0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3o
ool0L@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0;@3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02H0oooo0`00000U0?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03o
ool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0T0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0Q0?ooo`<00000:`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`00
0000oooo0?ooo`1f0?ooo`030000003oool0oooo01d0oooo1@000?l50?ooo`050000o`3oool0oooo
0?ooo`000?l07@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l06`3oool3
00000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`00
0000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0003o0080003o603oool3000003@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0N@3oool00`000000oooo0?ooo`0R0?ooo`050000o`3oool0003o0?ooo`000?l0103oool00`00
0?l0oooo0?ooo`0?0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0803oool00`000?l0
oooo0000o`020?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool40000o`H0oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0O0?ooo`80003o0P3oool00`000?l0oooo0?ooo`020000o`@0
oooo0P000?l30?ooo`040000o`3oool0oooo0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool07@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3o
ool0103oool00`000?l00000000000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0P0?ooo`030000
o`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool3000000030000o`3oool0oooo0400oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo01l0oooo0P000?l50?ooo`030000o`3oool0oooo00<000000`3o
ool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002H0oooo0`0000210?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool0103oool0
10000?l000000000000000060?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0240oooo00<000000000o`000000203oool00`000?l0oooo0?ooo`110?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`00
0000oooo0?ooo`0L0?ooo`@0000000<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0603oool3000000@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`180?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0D0?ooo`<000001`3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403o
ool3000000X0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o04@0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`270?ooo`030000003oool0oooo00`0oooo0`00000=0?ooo`030000o`3oool0oooo00<0oooo00@0
003o0?ooo`3oool0oooo1@000?m10?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000004@3o
ool60000o`80oooo0P000?l40?ooo`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo00@0oooo0`00000K0?ooo`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
00<000007@3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001l0oooo00<0003o0?ooo`3o
ool0A`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000
S@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00L0oooo10000?ll0?ooo`800000
F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02D0oooo0P000?l40?ooo`030000o`3oool0oooo03H0oooo0`0000020?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo00@0oooo0P000?lc0?ooo`@000001P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
02l0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00@0
oooo0P000?l^0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool09@3oool300000180oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`020?ooo`@0003o8`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02<0oooo00D0003o
0?ooo`3oool0oooo0000o`050?ooo`050000o`3oool0oooo0?ooo`000?l07P3oool4000001X0oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02@0oooo10000?l40?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0B0?ooo`<000007P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool09@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0@0?ooo`<000008P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:@3oool20000o`H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?oo
o`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`80
0000S`3oool00`000000oooo0?ooo`0X0?ooo`80003o1P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00`0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0W0?ooo`030000
o`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`@00000
;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09`3oool010000?l0oooo0?ooo`000?l40?ooo`030000
o`3oool0oooo0080oooo00@0003o0?ooo`000?l0003o1P3oool3000003<0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02H0oooo00<0003o0?ooo`3oool00P3oool40000o`@0oooo0`000?l20?ooo`030000
o`3oool0oooo00<0000000<0oooo0000o`3oool0<`3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo0`0000040?ooo`030000o`3o
ool0oooo03<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo00@0003o0?ooo`3oool0oooo0`00
00000`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0`0?ooo`030000o`000000
0000008000000P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?oo
o`<000001@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03T0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02/0oooo0`0000070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0>P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000X0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0
403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000<0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@000003P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0`000?lk0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0N0?ooo`<000005P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o
0?ooo`3oool0>@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000H0?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000J0?ooo`050000o`3oool0
oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01D0oooo0`00000Q0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0>`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000T0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000:03oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0003o03/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
:`3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0
oooo0?ooo`0a0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000;`3oool30000o`@0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03<0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00@0oooo1000000f0?ooo`040000o`3oool0oooo0000o`<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?oo
o`3oool3000003T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo03L0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool200000940oooo1000000l0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3o
ool001l0oooo0P00002@0?ooo`<00000@03oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0
003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo03l0oooo00@0003o
0?ooo`000?l0003o103oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<00000
0?ooo`3oool0@03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03d0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?oo
o`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3o
ool0@P3oool20000od@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`120?ooo`80003o
A@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0
oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00
001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?oo
o`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<0
0000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0
oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`000015
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;
0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<0
0000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0
VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0
oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo
0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U
0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0
X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`00
0000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0
oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo
0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`000024
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000
003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D
0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`07
0?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`03
0000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000
103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2
000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?oo
o`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo
0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?oo
o`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`80
0000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3o
ool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003o
ool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3
000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P000000
0`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo
00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3o
ool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool0
0`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool0
04<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo
00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo
00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool0
04/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo
00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo
001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0013
0?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<00000
0?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3o
ool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<00000
4@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000
003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3o
ool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0
oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@00000
0?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H
0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`00
0000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000
oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?oo
o`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`03
0000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0
b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3o
ool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4
000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700
oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo
0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?oo
o`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?oo
o`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3o
ool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0
W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool00000
3`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003o
ool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000
B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000
003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003o
ool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool40000
05d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool40000
0640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0
oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P000003
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?oo
o`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?oo
o`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003o
ool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0
oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool50000
0940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0
oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<0
00000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<
0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`
0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?oo
o`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3o
ool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D0
0000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`800000
2`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool00000
8`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03o
ool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0
oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool50000
0<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo
00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool0
00001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000
g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103o
ool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.62512 .66102 m
.61097 .68039 L
s
.60567 .68956 m
.6059 .68732 L
s
.60387 .6901 m
.60567 .68956 L
s
.6059 .68732 m
.60409 .68786 L
s
.60409 .68786 m
.60387 .6901 L
s
.60874 .66798 m
.60999 .66434 L
s
.60999 .66434 m
.60864 .66035 L
s
.60161 .67771 m
.60059 .67911 L
s
.60286 .67407 m
.60161 .67771 L
s
.60059 .67911 m
.59776 .68104 L
s
.60229 .67096 m
.60286 .67407 L
s
.60864 .66035 m
.60627 .65774 L
s
.59776 .68104 m
.59435 .67986 L
s
.59934 .66523 m
.60229 .67096 L
s
.60627 .65774 m
.60287 .65652 L
s
.59435 .67986 m
.59195 .67728 L
s
.59877 .6621 m
.59934 .66523 L
s
.60287 .65652 m
.60002 .65843 L
s
.59195 .67728 m
.59056 .67329 L
s
.60002 .65843 m
.59877 .6621 L
s
.59056 .67329 m
.59182 .66962 L
s
.59522 .65318 m
.59567 .64862 L
s
.59567 .64862 m
.5951 .64545 L
s
.5833 .66546 m
.58698 .6644 L
s
.5951 .64545 m
.59268 .64279 L
s
.58064 .66512 m
.5833 .66546 L
s
.59268 .64279 m
.59003 .64242 L
s
.5782 .66248 m
.58064 .66512 L
s
.59003 .64242 m
.58634 .64346 L
s
.5776 .65932 m
.5782 .66248 L
s
.58634 .64346 m
.58241 .64679 L
s
.57804 .65473 m
.5776 .65932 L
s
.58241 .64679 m
.58034 .64961 L
s
.58034 .64961 m
.57804 .65473 L
s
.59103 .62311 m
.59125 .62079 L
s
.58917 .62361 m
.59103 .62311 L
s
.59125 .62079 m
.5894 .6213 L
s
.5894 .6213 m
.58917 .62361 L
s
.58293 .63207 m
.56833 .65188 L
s
.57218 .63052 m
.56168 .64472 L
s
.57449 .62536 m
.57218 .63052 L
s
.57388 .62212 m
.57449 .62536 L
s
.5714 .61939 m
.57388 .62212 L
s
.56868 .61898 m
.5714 .61939 L
s
.56301 .6205 m
.56868 .61898 L
s
.57461 .60485 m
.55244 .63478 L
s
.55416 .61601 m
.55203 .61887 L
s
.55649 .61079 m
.55416 .61601 L
s
.55693 .60607 m
.55649 .61079 L
s
.55203 .61887 m
.54799 .62225 L
s
.5563 .60278 m
.55693 .60607 L
s
.54799 .62225 m
.54415 .62328 L
s
.55375 .59997 m
.5563 .60278 L
s
.54415 .62328 m
.54137 .62288 L
s
.55098 .59954 m
.55375 .59997 L
s
.54137 .62288 m
.5388 .6201 L
s
.54713 .60054 m
.55098 .59954 L
s
.5388 .6201 m
.53814 .61681 L
s
.55034 .59622 m
.52783 .62651 L
s
.53814 .61681 m
.53856 .61206 L
s
.54433 .58962 m
.52927 .60986 L
s
.54111 .59395 m
.54153 .58917 L
s
.54153 .58917 m
.54088 .58582 L
s
.5286 .60653 m
.5325 .60551 L
s
.54088 .58582 m
.53828 .58296 L
s
.52578 .6061 m
.5286 .60653 L
s
.53828 .58296 m
.53546 .5825 L
s
.52314 .60327 m
.52578 .6061 L
s
.53546 .5825 m
.53155 .58349 L
s
.52247 .59992 m
.52314 .60327 L
s
.53155 .58349 m
.52743 .58689 L
s
.52288 .59511 m
.52247 .59992 L
s
.52743 .58689 m
.52526 .5898 L
s
.52526 .5898 m
.52288 .59511 L
s
.52691 .57046 m
.52955 .57336 L
s
.52406 .56998 m
.52691 .57046 L
s
.5201 .57095 m
.52406 .56998 L
s
.51593 .57436 m
.5201 .57095 L
s
.52249 .5656 m
.50716 .58608 L
s
.51935 .5568 m
.52065 .55289 L
s
.52065 .55289 m
.52107 .54799 L
s
.52107 .54799 m
.52038 .54454 L
s
.50607 .56362 m
.51057 .56852 L
s
.50727 .57292 m
.51057 .56852 L
s
.50417 .57488 m
.50727 .57292 L
s
.52038 .54454 m
.5168 .54057 L
s
.50015 .57588 m
.50417 .57488 L
s
.49723 .57539 m
.50015 .57588 L
s
.5168 .54057 m
.51391 .54004 L
s
.49359 .57148 m
.49723 .57539 L
s
.51391 .54004 m
.50989 .54098 L
s
.50989 .54098 m
.50678 .54293 L
s
.49287 .56803 m
.49359 .57148 L
s
.50678 .54293 m
.50254 .54635 L
s
.49326 .5631 m
.49287 .56803 L
s
.50254 .54635 m
.49699 .55373 L
s
.49457 .55916 m
.49326 .5631 L
s
.49699 .55373 m
.49457 .55916 L
s
.49818 .53886 m
.47885 .55562 L
s
.49083 .53077 m
.47885 .55562 L
s
.49083 .53077 m
.47137 .54757 L
s
.48341 .52261 m
.47137 .54757 L
s
.47686 .5154 m
.46097 .53639 L
s
.47346 .51989 m
.47384 .51483 L
s
.47384 .51483 m
.47309 .51126 L
s
.4602 .53283 m
.46438 .53188 L
s
.47309 .51126 m
.47025 .50814 L
s
.45715 .53228 m
.4602 .53283 L
s
.47025 .50814 m
.46721 .50755 L
s
.45428 .52919 m
.45715 .53228 L
s
.46721 .50755 m
.46302 .50847 L
s
.4535 .52562 m
.45428 .52919 L
s
.46302 .50847 m
.45864 .51194 L
s
.45387 .52053 m
.4535 .52562 L
s
.45864 .51194 m
.45635 .51496 L
s
.45635 .51496 m
.45387 .52053 L
s
.45783 .49448 m
.46071 .49765 L
s
.45475 .49387 m
.45783 .49448 L
s
.45051 .49477 m
.45475 .49387 L
s
.44608 .49826 m
.45051 .49477 L
s
.453 .48917 m
.43682 .51041 L
s
.44503 .4832 m
.43923 .4908 L
s
.44753 .47756 m
.44503 .4832 L
s
.44888 .47345 m
.44753 .47756 L
s
.44924 .46824 m
.44888 .47345 L
s
.43923 .4908 m
.43476 .4943 L
s
.44747 .46346 m
.44924 .46824 L
s
.43476 .4943 m
.43144 .49628 L
s
.43144 .49628 m
.42713 .4972 L
s
.44059 .45581 m
.44747 .46346 L
s
.42713 .4972 m
.42298 .49552 L
s
.42298 .49552 m
.41596 .48797 L
s
.44059 .45581 m
.41596 .48797 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo03<0oooo00<0
003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0340oooo00<0003o
0?ooo`000?l0GP3oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I
0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02l0oooo00D0003o0?oo
o`3oool0oooo0000o`1M0?ooo`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0
oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0;P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool06P3oool30000
03L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`0/0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0F`3oool00`000000
oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo
00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05/0oooo
00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00
001O0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`1K0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<00000
0?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0U0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`0:0?oo
o`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`03
0000003oool0oooo02<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1L0?ooo`03
0000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo05`0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0P0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool0G@3oool010000000oooo0?ooo`3oool300000580oooo
00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0N0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0G@3oool4000005D0oooo00<0
00000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0N
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1G
0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo10000?mD0?oo
o`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0000006P0oooo00<000000?ooo`3oool07P3oool010000?l0oooo0?ooo`000?l50?oo
o`80003o0P3oool00`000?l0oooo0?ooo`1?0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0O0?ooo`80
003o1@3oool20000o`@0oooo00<0003o0?ooo`3oool0B`3oool3000000P0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo02D0oooo00<0003o0?ooo`3oool0CP3oool3000000/0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo04`0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`100?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3o
ool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00H0oooo0P000?l00`3oool0003o0?oo
o`0m0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?oo
o`0V0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0>03oool3000001P0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`00
00050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?oo
o`040?ooo`80003o=@3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0R
0?ooo`030000o`3oool0oooo00@0oooo0P000?lc0?ooo`<000007P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool08@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02h0oooo1000000Q0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3o
ool0oooo0000o`0Y0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool07`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0903oool3000002P0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo
00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool08P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`0M0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool01@000?l0oooo0?ooo`3oool0003o01d0
oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo
00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo01d0oooo
10000?l40?ooo`050000o`3oool0oooo0?ooo`000?l06`3oool300000340oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000
003oool0oooo07P0oooo00<000000?ooo`3oool07P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080003o603oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0R0?ooo`030000o`3oool0003o0080003o103oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00X0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0Q0?ooo`80003o0P3oool0
1@000?l0oooo0?ooo`3oool0003o00@0oooo00@0003o0?ooo`000?l0003o1`3oool3000003X0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo01l0oooo0P000?l20?ooo`030000o`3oool0oooo0080003o103o
ool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`<00000?@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<0
00000?ooo`3oool07P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0103oool20000o`D0
oooo00@0003o0000000000000000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0803oool00`000?l0
oooo0000o`040?ooo`030000o`3oool0oooo00<0oooo0P0000000`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0O0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0300000080oooo
00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0M0?ooo`030000o`3oool0oooo00@0oooo00@0
003o00000000000000001@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`0Q0?ooo`03000000000?l0000000P0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0703oool4000000030?ooo`000?l0oooo04d0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
01P0oooo0`0000050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0503oool3000000P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo
0`00000;0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`140?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`0<0?ooo`<000003P3oool00`000?l0oooo0?ooo`020?ooo`040000
o`3oool0oooo0?ooo`@0003o@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool300000140oooo
00@0003o0?ooo`3oool0oooo0P000?l20?ooo`80003o0`3oool00`000?l0oooo0?ooo`0o0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`040?ooo`<000005@3oool30000o`@0oooo00<0003o0?ooo`3oool0
A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000N0?ooo`030000o`3oool0oooo04D0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`800000803oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?oo
o`3oool07`3oool00`000?l0oooo0?ooo`050?ooo`80003o00<0oooo0000o`3oool0>`3oool20000
05/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0f0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`030?ooo`80003o<`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0_0?ooo`<000002P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0903oool00`000?l0oooo0?ooo`030?ooo`80003o0P3oool00`000?l0oooo0?ooo`0Y
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`030?oo
o`040000o`3oool0oooo0000obT0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?oo
o`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`000?lT0?ooo`<000005P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0903oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00D0003o
0?ooo`3oool0oooo0000o`0O0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool3
0000o`<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01<0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`050000o`3oool0oooo
0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo0`00000R
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00h0oooo0`00000V0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo
02T0oooo0P000?l50?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool30000
02X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02T0oooo0P000?l50?ooo`050000o`3oool0oooo0?oo
o`000?l02`3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`00
0?l0103oool01P000?l0oooo0?ooo`3oool0003o0?ooo`80003o1P3oool3000003<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02P0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`@0oooo0P00
0?l20?ooo`030000o`3oool0oooo00<0000000<0003o0?ooo`3oool0<`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool3000000<0oooo00<0003o0?ooo`3oool0=03oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00<00000?P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0<@3oool400000080oooo00<0003o0?ooo`3oool0?@3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0;P3oool3000000030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000000P3o
ool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0?@3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:03oool3000000X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0l0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>
0?ooo`030000003oool0oooo02D0oooo0`00000<0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0?P3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?oo
o`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@000003`3oool01@000?l0oooo0?ooo`3oool0
003o00@0oooo0`000?lk0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool0
0240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000004P3oool01@00
0?l0oooo0?ooo`3oool0003o00<0oooo0P000?l30?ooo`030000o`3oool0oooo03T0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<000006@3oool010000?l0oooo0?ooo`000?l5
0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0603oool3000001/0oooo00@0003o0?ooo`3oool0003o1P3oool00`000?l0oooo0?oo
o`0j0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000Q
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo0140oooo1000000T0?ooo`030000o`3oool0oooo00L0oooo0P000?lj0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000X0?ooo`03
0000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0003o>P3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00000[0?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3o
ool0oooo0000o`050?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0
oooo0`00000_0?ooo`@0003o0`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?oo
o`3oool0=03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000003T0oooo00D0003o0?ooo`3o
ool0oooo0000o`040?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?oo
o`<00000>`3oool010000?l0oooo0?ooo`000?l60?ooo`030000o`3oool0oooo03L0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000m0?oo
o`050000o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000@03oool00`00
0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l0?03oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?oo
o`030000003oool0oooo03l0oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0k
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0@03oool20000o`@0oooo00<0003o0?oo
o`3oool0?@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000
303oool00`000000oooo0?ooo`140?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3o
ool00`000000oooo0?ooo`130?ooo`80003oA03oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3o
ool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0
oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3o
ool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0
oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<0
0000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3o
ool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?oo
o`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<0
0000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D00000
0P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`00
3@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool01000
0000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`
0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo
000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo
00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?oo
o`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?oo
o`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@0
00000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool0
3`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool0
10000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`00
0000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?oo
o`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80
000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T
0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?oo
o`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@0
00002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3o
ool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000
oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo
0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000
000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/
0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?oo
o`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000
003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3o
ool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3o
ool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03o
ool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2
000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0
oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0
oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo
00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?oo
o`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]
0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D0
0000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000
P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03o
ool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`00
0000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0
oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?oo
o`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?oo
o`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h
0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?oo
o`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@0
0000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3o
ool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3o
ool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003o
ool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0
oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo
0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000
d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3o
ool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.6219 .65985 m
.6115 .68059 L
s
.60781 .69037 m
.60777 .68803 L
s
.60628 .69101 m
.60781 .69037 L
s
.60777 .68803 m
.60624 .68867 L
s
.60624 .68867 m
.60628 .69101 L
s
.6082 .66778 m
.60891 .66394 L
s
.60891 .66394 m
.60729 .65986 L
s
.60729 .65986 m
.60492 .65725 L
s
.60295 .67822 m
.6022 .67971 L
s
.60366 .67437 m
.60295 .67822 L
s
.60283 .67115 m
.60366 .67437 L
s
.6022 .67971 m
.59991 .68184 L
s
.59961 .66533 m
.60283 .67115 L
s
.59991 .68184 m
.59676 .68076 L
s
.60492 .65725 m
.60179 .65612 L
s
.59676 .68076 m
.59436 .67818 L
s
.60179 .65612 m
.59948 .65824 L
s
.59877 .6621 m
.59961 .66533 L
s
.59948 .65824 m
.59877 .6621 L
s
.59436 .67818 m
.59272 .67409 L
s
.59272 .67409 m
.59343 .67022 L
s
.59468 .65298 m
.59459 .64823 L
s
.59459 .64823 m
.59375 .64496 L
s
.59375 .64496 m
.59133 .64231 L
s
.58546 .66626 m
.5886 .66499 L
s
.59133 .64231 m
.58895 .64203 L
s
.58307 .66602 m
.58546 .66626 L
s
.58895 .64203 m
.5858 .64326 L
s
.58062 .66339 m
.58307 .66602 L
s
.5858 .64326 m
.58268 .64689 L
s
.57976 .66011 m
.58062 .66339 L
s
.58268 .64689 m
.58115 .64991 L
s
.58777 .62196 m
.58772 .61955 L
s
.58619 .62256 m
.58777 .62196 L
s
.57966 .65533 m
.57976 .66011 L
s
.58772 .61955 m
.58614 .62015 L
s
.58115 .64991 m
.57966 .65533 L
s
.58614 .62015 m
.58619 .62256 L
s
.58158 .63159 m
.57077 .65277 L
s
.5734 .62497 m
.5719 .63042 L
s
.57253 .62164 m
.5734 .62497 L
s
.5719 .63042 m
.56412 .64562 L
s
.57004 .6189 m
.57253 .62164 L
s
.56759 .61859 m
.57004 .6189 L
s
.57133 .60371 m
.55489 .63567 L
s
.56274 .62041 m
.56759 .61859 L
s
.55595 .6106 m
.55443 .6161 L
s
.55583 .60569 m
.55595 .6106 L
s
.55443 .6161 m
.55285 .61916 L
s
.55493 .6023 m
.55583 .60569 L
s
.55285 .61916 m
.54963 .62284 L
s
.55238 .5995 m
.55493 .6023 L
s
.54963 .62284 m
.54633 .62407 L
s
.54988 .59916 m
.55238 .5995 L
s
.54633 .62407 m
.54383 .62376 L
s
.54658 .60035 m
.54988 .59916 L
s
.54383 .62376 m
.54125 .62099 L
s
.54897 .59575 m
.53219 .62809 L
s
.54125 .62099 m
.54033 .61759 L
s
.54033 .61759 m
.5402 .61265 L
s
.54296 .58915 m
.53173 .61073 L
s
.54056 .59376 m
.54044 .58879 L
s
.54044 .58879 m
.53951 .58535 L
s
.53951 .58535 m
.53691 .58249 L
s
.53079 .60731 m
.53414 .60609 L
s
.53691 .58249 m
.53437 .58212 L
s
.52824 .60697 m
.53079 .60731 L
s
.53437 .58212 m
.53101 .5833 L
s
.52561 .60414 m
.52824 .60697 L
s
.53101 .5833 m
.5277 .58698 L
s
.52466 .60069 m
.52561 .60414 L
s
.5277 .58698 m
.52608 .59008 L
s
.52452 .59569 m
.52466 .60069 L
s
.52608 .59008 m
.52452 .59569 L
s
.52554 .56999 m
.52818 .57289 L
s
.52296 .5696 m
.52554 .56999 L
s
.51955 .57076 m
.52296 .5696 L
s
.52112 .56513 m
.50964 .58694 L
s
.51621 .57446 m
.51955 .57076 L
s
.51742 .55615 m
.51817 .55206 L
s
.51817 .55206 m
.51803 .54698 L
s
.51803 .54698 m
.51706 .54345 L
s
.51706 .54345 m
.51348 .53947 L
s
.50634 .56371 m
.51084 .56862 L
s
.50837 .5733 m
.51084 .56862 L
s
.50582 .57546 m
.50837 .5733 L
s
.51348 .53947 m
.51086 .53903 L
s
.50235 .57664 m
.50582 .57546 L
s
.51086 .53903 m
.5074 .54016 L
s
.49971 .57626 m
.50235 .57664 L
s
.5074 .54016 m
.50484 .54228 L
s
.49607 .57233 m
.49971 .57626 L
s
.50484 .54228 m
.50144 .54598 L
s
.49508 .56879 m
.49607 .57233 L
s
.50144 .54598 m
.49727 .55382 L
s
.49492 .56367 m
.49508 .56879 L
s
.49727 .55382 m
.49568 .55953 L
s
.49568 .55953 m
.49492 .56367 L
s
.4968 .5384 m
.48133 .55647 L
s
.48944 .53032 m
.48133 .55647 L
s
.48944 .53032 m
.47386 .54842 L
s
.48202 .52216 m
.47386 .54842 L
s
.47546 .51495 m
.46347 .53723 L
s
.4729 .51971 m
.47273 .51447 L
s
.47273 .51447 m
.47169 .51081 L
s
.47169 .51081 m
.46885 .50769 L
s
.46243 .53358 m
.46605 .53244 L
s
.46885 .50769 m
.4661 .50719 L
s
.45966 .53312 m
.46243 .53358 L
s
.4661 .50719 m
.46246 .50829 L
s
.45678 .53003 m
.45966 .53312 L
s
.46246 .50829 m
.45891 .51203 L
s
.45573 .52636 m
.45678 .53003 L
s
.45891 .51203 m
.45718 .51523 L
s
.45554 .52108 m
.45573 .52636 L
s
.45718 .51523 m
.45554 .52108 L
s
.45643 .49403 m
.45932 .4972 L
s
.45363 .49351 m
.45643 .49403 L
s
.44995 .49459 m
.45363 .49351 L
s
.4516 .48872 m
.43933 .51124 L
s
.44635 .49835 m
.44995 .49459 L
s
.44557 .47695 m
.44391 .48284 L
s
.44635 .47266 m
.44557 .47695 L
s
.44615 .46729 m
.44635 .47266 L
s
.44391 .48284 m
.43951 .49089 L
s
.4441 .46242 m
.44615 .46729 L
s
.43951 .49089 m
.43588 .49466 L
s
.43721 .45478 m
.4441 .46242 L
s
.43588 .49466 m
.43312 .49683 L
s
.43312 .49683 m
.42937 .49793 L
s
.42937 .49793 m
.42549 .49633 L
s
.43721 .45478 m
.41848 .48879 L
s
.42549 .49633 m
.41848 .48879 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0380oooo00<0
003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0300oooo00<0003o
0?ooo`000?l0G`3oool00`000000oooo0?ooo`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I
0?ooo`00;03oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo02l0oooo00<0003o0?oo
o`000?l0G`3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo02d0oooo00D0003o0?ooo`3o
ool0oooo0000o`1O0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo
01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0;03oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool05`3oool3000003/0
oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo02X0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo01@0oooo
0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?oo
o`0X0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?oo
o`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1L
0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0T0?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`070?ooo`<0
0000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1M0?ooo`030000
003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo05d0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo
000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?oo
o`050?ooo`050000o`3oool0oooo0?ooo`000?l0G03oool4000005D0oooo00<000000?ooo`3oool0
5`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`1J0?ooo`<00000F03oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01h0oooo00<0
003o0?ooo`3oool00`3oool01P000?l0oooo0?ooo`3oool0003o0?ooo`80003oE@3oool300000080
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0000001X0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00P000?l40?ooo`80003o
00<0oooo0000o`3oool0D@3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool07`3oool20000o`D0oooo0P00
0?l30?ooo`030000o`3oool0oooo04`0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo04h0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool08`3oool00`000?l0oooo0?ooo`1<0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00H0oooo0P000?m10?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0P0?oo
o`030000o`3oool0oooo00D0oooo0P000?l00`3oool0003o0?ooo`0m0?ooo`<00000503oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0h0?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
00<0oooo0P000?lf0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0b0?ooo`<000007P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02h0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0W0?ooo`<000009@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<00000
0?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0903oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool07`3oool01@000?l0oooo0?ooo`3oool0
003o00@0oooo00<0003o0?ooo`3oool08P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0N0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool010000?l0oooo0?ooo`00
0?lN0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0005
0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0N
0?ooo`@0003o103oool010000?l0oooo0000o`000?lK0?ooo`<00000<@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<00000
0?ooo`3oool0N03oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`3oool0003o6@3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0S
0?ooo`040000o`3oool0003o0000o`<0oooo00<0003o0?ooo`3oool00P3oool20000o``0oooo0`00
000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<00000
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0R0?ooo`80003o00D0oooo0000o`3oool0oooo0000
o`030?ooo`80003o0P3oool00`000?l0oooo0?ooo`060?ooo`<00000>P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<00000
0?ooo`3oool08@3oool00`000?l0oooo0000o`020?ooo`050000o`3oool0oooo0?ooo`000?l01@3o
ool00`000?l0oooo0?ooo`020?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool07`3oool2
0000o`040?ooo`000?l0oooo0000o`@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000
000200000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1n0?ooo`030000003oool0oooo01h0oooo00H0003o0?ooo`3oool0003o0?oo
o`000?l30?ooo`030000o`3oool0oooo00<0oooo00<000000000o`000000@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0803oool20000o`@0oooo00<0003o0?ooo`3oool00`0000000`3oool0003o0?oo
o`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`000021
0?ooo`030000003oool0oooo01h0oooo0P000?l40?ooo`040000o`0000000000000000@0oooo00<0
003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool07@3oool010000?l0oooo0?ooo`3o
ool2000000030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0703oool400000080oooo00<0003o0?ooo`3oool0B`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?oo
o`3oool0603oool3000000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`170?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000203oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000000/0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?m50?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
Q`3oool00`000000oooo0?ooo`0<0?ooo`<000003P3oool00`000?l0oooo0?ooo`020?ooo`040000
o`3oool0oooo0?ooo`@0003o@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool300000180oooo
00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`0o0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`040?ooo`<000005P3oool30000o`<0oooo00<0003o0?ooo`3oool0
A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000N0?ooo`030000o`3oool0oooo04D0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`8000008@3oool00`000?l0oooo0?ooo`050?ooo`80003o?P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0O0?oo
o`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0003o?03oool2000005/0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0O0?oo
o`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`0i0?ooo`<000000P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`020?ooo`80003o=03oool40000
00H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`0`0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool00`000?l0oooo
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0:`3oool3000000h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo02@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o02T0
oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080oooo
00@0003o0?ooo`3oool0oooo0`000?lT0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
9@3oool010000?l0oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`00
0?l0oooo0?ooo`0G0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09P3oool00`000?l0
oooo0000o`030?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`0E0?oo
o`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool09`3oool01@000?l0oooo0?ooo`3oool0003o
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0B0?ooo`<000008P3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool09`3oool010000?l0oooo0?ooo`000?l50?ooo`050000o`3oool0oooo
0?ooo`000?l04P3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`030?oo
o`050000o`3oool0oooo0?ooo`000?l03`3oool3000002X0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02T0oooo0P000?l50?ooo`040000o`3oool0oooo0000o``0oooo1000000^0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0Z0?ooo`80003o103oool010000?l0oooo0?ooo`3oool30000o`D0oooo0P000?l3
000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02T0oooo00@0003o0?ooo`3oool0003o0P3oool0
1@000?l0oooo0?ooo`3oool0003o00<0oooo00@0003o0?ooo`3oool0oooo0`00000f0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0Y0?ooo`040000o`3oool0oooo0?ooo`80003o103oool00`000?l0oooo
0?ooo`020?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool4
00000080oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool30000
00030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0j0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000000`3oool00`000?l0oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`000?l0?@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000X0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo
0`00000=0?ooo`050000o`3oool0oooo0?ooo`000?l0@03oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000
3`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0003o?03oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool07P3oool3000001<0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`050000
o`3oool0oooo0?ooo`000?l0?03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0
oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo
0`00000J0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0>@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000703oool01@000?l0
oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000007`3oool010000?l0oooo0?ooo`000?l50?oo
o`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@0
00009@3oool00`000?l0oooo0?ooo`050?ooo`80003o>`3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0>0?ooo`<00000:@3oool00`000?l0oooo0?ooo`040?ooo`040000
o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00/0oooo0`00000/0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0
003o103oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
;`3oool010000?l0oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000<`3oool20000o`D0
oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000
oooo0?ooo`3oool3000003/0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0
oooo03P0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool20000
0940oooo1000000n0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0j
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?oo
o`<00000@@3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool0>P3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08`0oooo0`0000020?ooo`030000003oool0oooo0400oooo00@0003o0?ooo`3oool0003o0P3oool0
0`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0@03oool30000
o`<0oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0A03oool20000od<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`15
0?ooo`80003o@`3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<0
0000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61829 .65946 m
.6121 .68066 L
s
.61022 .69066 m
.60988 .68828 L
s
.60899 .69134 m
.61022 .69066 L
s
.60988 .68828 m
.60864 .68896 L
s
.60864 .68896 m
.60899 .69134 L
s
.60771 .66381 m
.60579 .65969 L
s
.6076 .66771 m
.60771 .66381 L
s
.60579 .65969 m
.60341 .65708 L
s
.60457 .67447 m
.60446 .67839 L
s
.60343 .67122 m
.60457 .67447 L
s
.60446 .67839 m
.60401 .67992 L
s
.60401 .67992 m
.60232 .68213 L
s
.60341 .65708 m
.60058 .65599 L
s
.59991 .66537 m
.60343 .67122 L
s
.60232 .68213 m
.59948 .68108 L
s
.60058 .65599 m
.59888 .65817 L
s
.59877 .6621 m
.59991 .66537 L
s
.59948 .68108 m
.59708 .6785 L
s
.59888 .65817 m
.59877 .6621 L
s
.59708 .6785 m
.59514 .67437 L
s
.59514 .67437 m
.59525 .67043 L
s
.59408 .65292 m
.59338 .6481 L
s
.59338 .6481 m
.59223 .6448 L
s
.59223 .6448 m
.58981 .64215 L
s
.58788 .66653 m
.59042 .6652 L
s
.58981 .64215 m
.58773 .6419 L
s
.58773 .6419 m
.58519 .6432 L
s
.5858 .66633 m
.58788 .66653 L
s
.58336 .66369 m
.5858 .66633 L
s
.58519 .6432 m
.58299 .64692 L
s
.58412 .62159 m
.58377 .61916 L
s
.58284 .62222 m
.58412 .62159 L
s
.58377 .61916 m
.58249 .61979 L
s
.58249 .61979 m
.58284 .62222 L
s
.58299 .64692 m
.58206 .65001 L
s
.58219 .66038 m
.58336 .66369 L
s
.58206 .65001 m
.58148 .65553 L
s
.58148 .65553 m
.58219 .66038 L
s
.58006 .63143 m
.57351 .65307 L
s
.57218 .62485 m
.5716 .63039 L
s
.571 .62149 m
.57218 .62485 L
s
.5716 .63039 m
.56687 .64591 L
s
.56851 .61875 m
.571 .62149 L
s
.56637 .61847 m
.56851 .61875 L
s
.56766 .60336 m
.55765 .63596 L
s
.56244 .62038 m
.56637 .61847 L
s
.55533 .61054 m
.55474 .61613 L
s
.55461 .60557 m
.55533 .61054 L
s
.55339 .60215 m
.55461 .60557 L
s
.55474 .61613 m
.55377 .61926 L
s
.55084 .59935 m
.55339 .60215 L
s
.55377 .61926 m
.55147 .62302 L
s
.55147 .62302 m
.54879 .62432 L
s
.54865 .59904 m
.55084 .59935 L
s
.54597 .60029 m
.54865 .59904 L
s
.54879 .62432 m
.5466 .62404 L
s
.54743 .59561 m
.53712 .6286 L
s
.5466 .62404 m
.54402 .62126 L
s
.54402 .62126 m
.54279 .61783 L
s
.54279 .61783 m
.54205 .61283 L
s
.54142 .58901 m
.53451 .611 L
s
.53995 .5937 m
.5392 .58868 L
s
.5392 .58868 m
.53797 .58521 L
s
.53797 .58521 m
.53536 .58235 L
s
.53326 .60754 m
.536 .60627 L
s
.53536 .58235 m
.53313 .58201 L
s
.53313 .58201 m
.53039 .58324 L
s
.53102 .60724 m
.53326 .60754 L
s
.52839 .60441 m
.53102 .60724 L
s
.53039 .58324 m
.52801 .58701 L
s
.52801 .58701 m
.52701 .59017 L
s
.52714 .60093 m
.52839 .60441 L
s
.52398 .56986 m
.52663 .57276 L
s
.52701 .59017 m
.52638 .59586 L
s
.52638 .59586 m
.52714 .60093 L
s
.52171 .5695 m
.52398 .56986 L
s
.51893 .57071 m
.52171 .5695 L
s
.51956 .565 m
.51244 .5872 L
s
.51652 .57449 m
.51893 .57071 L
s
.51537 .55184 m
.5146 .54672 L
s
.51524 .55598 m
.51537 .55184 L
s
.5146 .54672 m
.51332 .54316 L
s
.51332 .54316 m
.50974 .53919 L
s
.50666 .56374 m
.51115 .56864 L
s
.50962 .57341 m
.51115 .56864 L
s
.50974 .53919 m
.50743 .53878 L
s
.50769 .57562 m
.50962 .57341 L
s
.50743 .53878 m
.50459 .53995 L
s
.50485 .57686 m
.50769 .57562 L
s
.50459 .53995 m
.50265 .54212 L
s
.50252 .5765 m
.50485 .57686 L
s
.50265 .54212 m
.50019 .54588 L
s
.49888 .57258 m
.50252 .5765 L
s
.50019 .54588 m
.49758 .55385 L
s
.49758 .569 m
.49888 .57258 L
s
.49758 .55385 m
.49693 .55964 L
s
.4968 .56383 m
.49758 .569 L
s
.49693 .55964 m
.4968 .56383 L
s
.49523 .53828 m
.48416 .55669 L
s
.48787 .5302 m
.48416 .55669 L
s
.48787 .5302 m
.47669 .54864 L
s
.48045 .52205 m
.47669 .54864 L
s
.47389 .51484 m
.46631 .53744 L
s
.47227 .51967 m
.47146 .51438 L
s
.47146 .51438 m
.47012 .5107 L
s
.47012 .5107 m
.46727 .50758 L
s
.46495 .53377 m
.46794 .53258 L
s
.46727 .50758 m
.46483 .50711 L
s
.46483 .50711 m
.46183 .50825 L
s
.4625 .53333 m
.46495 .53377 L
s
.45963 .53024 m
.4625 .53333 L
s
.46183 .50825 m
.45923 .51206 L
s
.45923 .51206 m
.45813 .5153 L
s
.45826 .52654 m
.45963 .53024 L
s
.45485 .49393 m
.45773 .4971 L
s
.45813 .5153 m
.45744 .52121 L
s
.45744 .52121 m
.45826 .52654 L
s
.45236 .49343 m
.45485 .49393 L
s
.44932 .49456 m
.45236 .49343 L
s
.45001 .48863 m
.44219 .51143 L
s
.44667 .49837 m
.44932 .49456 L
s
.44349 .4725 m
.44334 .47682 L
s
.44265 .4671 m
.44349 .4725 L
s
.44334 .47682 m
.44264 .48277 L
s
.44027 .46223 m
.44265 .4671 L
s
.44264 .48277 m
.43983 .49091 L
s
.43338 .45459 m
.44027 .46223 L
s
.43983 .49091 m
.43715 .49474 L
s
.43715 .49474 m
.43503 .49695 L
s
.43503 .49695 m
.43192 .49809 L
s
.43338 .45459 m
.42136 .48896 L
s
.43192 .49809 m
.42837 .49651 L
s
.42837 .49651 m
.42136 .48896 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0300oooo00<0
003o0?ooo`3oool0H03oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02l0oooo0`000?mP
0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0;@3oool01@000?l0oooo0?ooo`3oool0
003o05l0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool0
02`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0/0?ooo`050000o`3oool0oooo
0?ooo`000?l0H03oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I
0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo02/0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo01L0oooo0`00000k0?oo
o`030000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0Y0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`0D0?ooo`<0
0000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0
:03oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0
4@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0G@3o
ool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`1M0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0903oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool01`3oool30000
04/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000
oooo0?ooo`0S0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0G@3oool00`000000
oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1S0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`1M0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00
:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0
103oool01@000?l0oooo0?ooo`3oool0003o05`0oooo1000001E0?ooo`030000003oool0oooo01L0
oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0803oool00`000?l0oooo
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0FP3oool3000005P0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0P0?ooo`050000
o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0000o`1F0?ooo`<000000P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo
00<000000?ooo`3oool0803oool010000?l0oooo0000o`000?l30?ooo`80003o00<0oooo0000o`00
0?l0D@3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool2000006T0oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`80003o
DP3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0CP3o
ool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0
oooo04/0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo02<0oooo00<0003o0?ooo`3oool0103oool20000od80oooo0`00000A0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0000o`0o0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`0P0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000
o`0k0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P
0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo0080oooo0P000?lf0?ooo`<000006`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00`3oool20000oc<0oooo0`00000N
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?oo
o`3oool0L@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0;P3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3o
ool00`3oool010000?l0oooo0?ooo`000?lZ0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3o
ool08@3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000obL0oooo0`00000X0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`03
0000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
0280oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool07`3oool01@000?l0
oooo0?ooo`3oool0003o00<0oooo00@0003o0?ooo`3oool0003o7P3oool3000002h0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool07`3oool40000o`<0oooo00@0003o0?oo
o`000?l0003o6`3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0803oool01@000?l0oooo0?ooo`3oool0003o0080oooo0P000?lH0?ooo`<00000=03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo01l0oooo00H0003o0?ooo`3oool0oooo0000o`3o
ool20000o`<0oooo00<0003o0?ooo`3oool00`000?l=0?ooo`<00000=`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool08P3oool010000?l0oooo0000o`000?l20?ooo`040000o`3oool0oooo0000o`80oooo
00<0003o0?ooo`3oool0203oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo0240oooo0P00
0?l01`3oool0003o0?ooo`3oool0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`040?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0803oool20000o`040?ooo`000?l0oooo0000o`80
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0300000400oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo01l0oooo00<0003o0?ooo`3oool00P000?l30?ooo`030000o`3oool0oooo00<0oooo
00<0003o000000000000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0803oool20000o`<0oooo00@0
003o0?ooo`3oool0oooo0`0000000`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo01l0oooo0P00
0?l30?ooo`040000o`0000000000000000<0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool07P3oool00`000?l0oooo0?ooo`02000000030000o`3oool0oooo04X0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`23
0?ooo`030000003oool0oooo01`0oooo100000020?ooo`030000o`3oool0oooo04/0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo01P0oooo0`0000060?ooo`050000o`3oool0oooo0?ooo`000?l0B@3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08D0oooo00<000000?ooo`3oool0503oool3000000T0oooo00D0003o0?ooo`3oool0oooo0000o`04
0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000<0?oo
o`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`140?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0<0?ooo`<000003`3oool00`000?l0oooo0?ooo`020?ooo`060000o`3oool0oooo
0000o`3oool0003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001<0oooo00H0003o
0?ooo`3oool0oooo0000o`3oool20000o`80oooo00<0003o0?ooo`3oool0@03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0103oool3000001L0oooo0`000?l20?ooo`030000o`3oool0oooo04@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo00<000007`3oool00`000?l0oooo0?ooo`140?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool20000
0280oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0200
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000o`0m0?ooo`800000F`3oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0200oooo
00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?lj0?ooo`<000000P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`020?ooo`80003o=03oool4000000H0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00P3oool20000oc40oooo0`00
000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0080oooo00@0003o
0?ooo`3oool0003o;03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00<0003o
0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?lY0?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo0`000?lU0?ooo`<000005P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo00@0
003o0?ooo`3oool0003o1@3oool00`000?l0oooo0?ooo`0H0?ooo`@000006P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?l20?ooo`050000o`3oool0oooo0?ooo`00
0?l0103oool00`000?l0oooo0?ooo`0E0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
9`3oool20000o`80oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o01D0
oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`040000o`3oool0oooo0000o`@0
oooo00D0003o0?ooo`3oool0oooo0000o`0B0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0[0?ooo`03
0000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0?0?ooo`<00000:P3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000
o``0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`80003o0`3oool010000?l0
oooo0?ooo`3oool30000o`@0oooo0P000?l0103oool0000000000000000c0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0[0?ooo`030000o`3oool0003o0080oooo00D0003o0?ooo`3oool0oooo0000o`02
0?ooo`040000o`3oool0oooo0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool0
0`000?l0oooo0?ooo`020000o`<0oooo00D0003o0?ooo`3oool0oooo0000o`03000003X0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo00000002
000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0103oool40000
0080oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool300000003
0?ooo`000?l0oooo00<0oooo00@0003o0?ooo`3oool0003o?@3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0:`3oool3000000@0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo
03/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00000;0?ooo`040000o`3oool0oooo0000
ocl0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0
oooo00<000000?ooo`3oool09@3oool3000000h0oooo00@0003o0?ooo`3oool0003o@03oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000
oooo0?ooo`0Q0?ooo`@00000403oool01@000?l0oooo0?ooo`3oool0003o0080oooo0`000?ll0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000503oool01`000?l0oooo0?ooo`3oool0003o
0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool06`3oool3000001X0oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0j
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000M
0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000803oool010000?l0oooo0?ooo`00
0?l30?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A
0?ooo`@000009P3oool00`000?l0oooo0?ooo`040?ooo`80003o>`3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000:P3oool00`000?l0oooo0?ooo`030?oo
o`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00/0oooo0`00000]0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?oo
o`3oool0003o0`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?oo
o`<00000<03oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0003o0080oooo00<0003o
0?ooo`3oool0=`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000003@0oooo0P000?l40?oo
o`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0>03oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3o
ool0oooo0`00000l0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0>@3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool40000
03l0oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000@P3oool01000
0?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`00
0000oooo0?ooo`110?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0?03oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0
oooo100000050?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`000?l00P3oool00`000?l0
oooo0?ooo`0m0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0@P3oool00`000?l0oooo
0?ooo`120?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?
0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?oo
o`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3o
ool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool30000
06h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo
00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00
000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03o
ool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0
oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00
001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3o
ool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0
oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`03
0000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603o
ool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<00000
0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P000004
0?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`80
0000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0
^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo
0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P00
00040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?oo
o`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<0
0000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool200000003
0?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?oo
o`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
04P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00
B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
04l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`00
0000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000
oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?oo
o`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?oo
o`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000
oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo
0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<0
00000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`38
0?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?oo
o`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@0
00006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03o
ool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2
000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo
0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?oo
o`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M
0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?
0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;
0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<00000
0?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?oo
o`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000
G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000
H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3o
ool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo
00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo
0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?oo
o`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3o
ool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000
T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3o
ool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`00
0000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0
oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo
00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300
oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo
0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?oo
o`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00
002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;
0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S
0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?oo
o`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000
bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`00
00060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O
0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?oo
o`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61447 .65985 m
.61274 .6806 L
s
.61278 .69041 m
.61212 .68806 L
s
.61187 .69106 m
.61278 .69041 L
s
.61212 .68806 m
.61121 .68871 L
s
.60642 .66394 m
.60418 .65985 L
s
.60696 .66778 m
.60642 .66394 L
s
.61121 .68871 m
.61187 .69106 L
s
.60418 .65985 m
.60181 .65725 L
s
.60181 .65725 m
.59929 .65613 L
s
.60553 .67438 m
.60607 .67823 L
s
.60408 .67116 m
.60553 .67438 L
s
.60607 .67823 m
.60594 .67973 L
s
.60023 .66533 m
.60408 .67116 L
s
.60594 .67973 m
.60489 .68187 L
s
.59929 .65613 m
.59823 .65824 L
s
.60489 .68187 m
.60238 .6808 L
s
.59877 .6621 m
.60023 .66533 L
s
.59823 .65824 m
.59877 .6621 L
s
.60238 .6808 m
.59999 .67821 L
s
.59999 .67821 m
.59772 .67411 L
s
.59343 .65299 m
.59209 .64824 L
s
.59772 .67411 m
.59718 .67023 L
s
.59209 .64824 m
.59062 .64498 L
s
.59062 .64498 m
.5882 .64232 L
s
.5882 .64232 m
.58644 .64204 L
s
.59047 .66627 m
.59236 .665 L
s
.58644 .64204 m
.58454 .64327 L
s
.58872 .66603 m
.59047 .66627 L
s
.58024 .62204 m
.57956 .61964 L
s
.57928 .62263 m
.58024 .62204 L
s
.57956 .61964 m
.5786 .62023 L
s
.58454 .64327 m
.58331 .64689 L
s
.5786 .62023 m
.57928 .62263 L
s
.58628 .66339 m
.58872 .66603 L
s
.58331 .64689 m
.58303 .6499 L
s
.58479 .66011 m
.58628 .66339 L
s
.58303 .6499 m
.58343 .65532 L
s
.57843 .63161 m
.57644 .65276 L
s
.58343 .65532 m
.58479 .66011 L
s
.57088 .62499 m
.57127 .63043 L
s
.56937 .62167 m
.57088 .62499 L
s
.56688 .61894 m
.56937 .62167 L
s
.57127 .63043 m
.56981 .64559 L
s
.56375 .60383 m
.5606 .63563 L
s
.56506 .61862 m
.56688 .61894 L
s
.56211 .62041 m
.56506 .61862 L
s
.55468 .61061 m
.55506 .6161 L
s
.55329 .60572 m
.55468 .61061 L
s
.55175 .60235 m
.55329 .60572 L
s
.55506 .6161 m
.55475 .61914 L
s
.5492 .59955 m
.55175 .60235 L
s
.55475 .61914 m
.55344 .6228 L
s
.54734 .5992 m
.5492 .59955 L
s
.55344 .6228 m
.55143 .62402 L
s
.54531 .60037 m
.54734 .5992 L
s
.54579 .59581 m
.54242 .628 L
s
.55143 .62402 m
.54956 .6237 L
s
.54956 .6237 m
.54699 .62092 L
s
.54699 .62092 m
.54543 .61753 L
s
.53977 .58921 m
.53749 .61065 L
s
.54543 .61753 m
.54403 .6126 L
s
.53929 .59378 m
.53788 .58884 L
s
.53788 .58884 m
.53632 .58542 L
s
.53632 .58542 m
.53371 .58256 L
s
.53371 .58256 m
.5318 .58218 L
s
.53592 .60723 m
.53798 .60604 L
s
.5318 .58218 m
.52972 .58333 L
s
.53401 .60689 m
.53592 .60723 L
s
.52972 .58333 m
.52834 .58697 L
s
.53138 .60405 m
.53401 .60689 L
s
.52834 .58697 m
.528 .59004 L
s
.52232 .57007 m
.52497 .57297 L
s
.5298 .60061 m
.53138 .60405 L
s
.528 .59004 m
.52838 .59562 L
s
.52838 .59562 m
.5298 .60061 L
s
.52038 .56967 m
.52232 .57007 L
s
.51826 .5708 m
.52038 .56967 L
s
.5179 .56522 m
.51545 .58682 L
s
.51685 .57444 m
.51826 .5708 L
s
.51237 .55224 m
.51094 .54721 L
s
.51291 .55629 m
.51237 .55224 L
s
.51094 .54721 m
.50933 .54371 L
s
.50933 .54371 m
.50574 .53974 L
s
.50574 .53974 m
.50375 .53928 L
s
.50699 .5637 m
.51149 .5686 L
s
.51095 .57324 m
.51149 .5686 L
s
.50375 .53928 m
.50158 .54036 L
s
.5097 .57536 m
.51095 .57324 L
s
.50753 .57652 m
.5097 .57536 L
s
.50158 .54036 m
.50031 .54244 L
s
.50031 .54244 m
.49884 .54607 L
s
.50554 .57611 m
.50753 .57652 L
s
.49884 .54607 m
.49792 .5538 L
s
.50191 .57219 m
.50554 .57611 L
s
.49792 .5538 m
.49827 .55946 L
s
.50027 .56866 m
.50191 .57219 L
s
.49827 .55946 m
.49881 .56356 L
s
.49355 .53851 m
.4872 .55629 L
s
.49881 .56356 m
.50027 .56866 L
s
.48619 .53044 m
.4872 .55629 L
s
.48619 .53044 m
.47974 .54823 L
s
.47876 .52229 m
.47974 .54823 L
s
.47219 .51509 m
.46937 .53702 L
s
.47159 .51976 m
.47011 .51458 L
s
.47011 .51458 m
.46842 .51095 L
s
.46842 .51095 m
.46558 .50783 L
s
.46558 .50783 m
.46347 .50731 L
s
.46768 .53338 m
.46998 .53229 L
s
.46347 .50731 m
.46115 .50835 L
s
.46557 .5329 m
.46768 .53338 L
s
.46115 .50835 m
.45957 .51201 L
s
.4627 .5298 m
.46557 .5329 L
s
.45957 .51201 m
.45915 .51515 L
s
.45314 .49419 m
.45603 .49736 L
s
.46099 .52615 m
.4627 .5298 L
s
.45915 .51515 m
.45949 .52092 L
s
.45949 .52092 m
.46099 .52615 L
s
.451 .49364 m
.45314 .49419 L
s
.44863 .49466 m
.451 .49364 L
s
.44831 .48889 m
.44528 .51098 L
s
.44701 .49832 m
.44863 .49466 L
s
.44041 .47299 m
.44095 .4772 L
s
.43889 .4677 m
.44041 .47299 L
s
.43616 .46289 m
.43889 .4677 L
s
.44095 .4772 m
.44127 .48298 L
s
.44127 .48298 m
.44017 .49086 L
s
.42926 .45526 m
.43616 .46289 L
s
.44017 .49086 m
.43853 .49453 L
s
.43853 .49453 m
.4371 .49664 L
s
.42926 .45526 m
.42447 .48848 L
s
.4371 .49664 m
.43467 .49767 L
s
.43467 .49767 m
.43147 .49604 L
s
.43147 .49604 m
.42447 .48848 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02l0oooo00<0
003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02h0oooo0P000?mR
0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0;@3oool20000of80oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0[0?ooo`040000o`3oool0oooo0000of80oooo00<000000?oo
o`3oool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0F`3oool00`000000oooo0?ooo`0Z0?ooo`050000o`3oool0oooo0?ooo`000?l0H@3oool00`00
0000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0
oooo00<000000?ooo`3oool0:@3oool01@000?l0oooo0?ooo`3oool0003o0640oooo00<000000?oo
o`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`03
0000003oool0oooo02P0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1N0?ooo`03
0000003oool0oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo05h0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0V0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo02@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0
oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo
0680oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
05h0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0GP3oool010000000oooo0?ooo`3oool300000580oooo00<000000?oo
o`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0003oG@3oool4000005D0oooo00<000000?oo
o`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003oF`3oool3000005P0oooo00<000000?oo
o`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0Q0?ooo`04
0000o`3oool0oooo0000o`<0oooo0`000?mF0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3o
ool08@3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0003o05<0oooo0`0000050?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?m?0?ooo`<0
0000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000
003oool0oooo06T0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1>0?ooo`<00000
2`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0B`3o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0440oooo0`00000A0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0000o`0o0?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3o
ool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo
0000o`0k0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo
0?ooo`0U0?ooo`040000o`3oool0oooo0?ooo`80003o=`3oool3000001/0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`0T0?ooo`040000o`3oool0oooo0?ooo`80003o=03oool3000001h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0^0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0003o02/0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0R
0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3oool09P3oool3000002P0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<00000
0?ooo`3oool08@3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0oooo02<0oooo0`00
000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0803oool010000?l0oooo0?ooo`00
0?l20?ooo`040000o`3oool0oooo0000oal0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0200oooo0`000?l20?ooo`040000o`3oool0oooo0000oa`0oooo
0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0240oooo00D0
003o0?ooo`3oool0003o0?ooo`020000oaT0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<0
00000?ooo`3oool0903oool30000o`80oooo00D0003o0?ooo`3oool0oooo0000o`0?0?ooo`<00000
=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool08`3oool30000o`80oooo00H0003o0?ooo`000?l0003o
0?ooo`000?l;0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool08P3oool30000o`050?oo
o`000?l0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`050?ooo`<00000?@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo
00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020000o`80oooo00D0003o0?ooo`3oool0
oooo0000o`040?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo
0?ooo`020000o`80oooo00H0003o0?ooo`3oool0oooo0000o`3oool3000004<0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`03
0000003oool0oooo0280oooo0P000?l20?ooo`030000o`3oool0oooo0080000000<0003o0?ooo`3o
ool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000
P@3oool00`000000oooo0?ooo`0Q0?ooo`050000o`3oool0oooo0?ooo`000?l00P0000020?ooo`03
0000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0200oooo00D0003o000000000000
00000000o`040?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
100000030?ooo`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
00070?ooo`040000o`3oool0oooo0000odT0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00
000:0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`130?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0@0?ooo`<000003@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0003o04D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000A0?ooo`040000o`3oool0
oooo0000o`80oooo0`000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000503oool0
10000?l0oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0000od80oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00@0oooo0`00000H0?ooo`<0003o00<0oooo0000o`3oool0A@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool00`00000O0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008P3oool00`00
0?l0oooo0?ooo`030?ooo`80003o?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080
oooo00@0003o0?ooo`3oool0003o?@3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080
oooo00@0003o0?ooo`3oool0003o>P3oool300000080oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0
oooo00<0003o0?ooo`3oool00P000?le0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
9P3oool00`000?l0oooo0?ooo`020000oc80oooo0`00000:0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0V0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0]0?ooo`<000003P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0:P3oool30000
0180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3oool0003o0P3oool30000
obD0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0003o0080
oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`0J0?ooo`@000006P3oool00`00
0000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:03oool20000o`80oooo00@0003o0?ooo`3oool0003o0`3oool00`00
0?l0oooo0?ooo`0G0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool010000?l0
oooo0?ooo`000?l20?ooo`050000o`3oool0oooo0?ooo`000?l05P3oool300000280oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02T0oooo00<0003o0?ooo`000?l0103oool010000?l0oooo0?ooo`000?lC
0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?oo
o`800000S`3oool00`000000oooo0?ooo`0[0?ooo`80003o0`3oool010000?l0oooo0?ooo`000?l@
0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool20000o`<0oooo00@0003o0?oo
o`3oool0003o303oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo0P000?l30?oo
o`030000o`3oool0003o0080003o103oool010000?l0oooo0?ooo`3oool3000003<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02`0oooo00D0003o0?ooo`000?l0oooo0000o`020?ooo`040000o`3oool0
oooo0000o`<0oooo00@0003o0000000000000000=P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;03o
ool010000?l0oooo0?ooo`000?l30?ooo`050000o`3oool0oooo0?ooo`000?l00`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000000
0P00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@000000P3oool00`000?l0oooo0?oo
o`0m0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<000000P3oool01@000?l0oooo0?ooo`3o
ool0003o0080oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3
000000D0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo03/0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02P0oooo0`00000;0?ooo`050000o`3oool0oooo0?ooo`000?l0?P3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool0
0`000000oooo0?ooo`0U0?ooo`<000003P3oool01@000?l0oooo0?ooo`3oool0003o03l0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<00000
0?ooo`3oool08@3oool400000140oooo00@0003o0?ooo`3oool0003o0P3oool20000ocd0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01h0oooo0`00000E0?ooo`060000o`3oool0oooo0000o`3oool0003o
0P3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3o
ool3000001/0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000N0?ooo`030000o`3o
ool0003o00<0oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0E0?ooo`<000008@3oool00`000?l0oooo0000o`030?ooo`030000o`3oool0
oooo03`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool20000
00L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@000009P3oool00`00
0?l0oooo0?ooo`030?ooo`80003o?03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0>0?ooo`<00000:`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00<0
oooo00<0003o0?ooo`3oool0=P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo
0`00000^0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo
0?ooo`0f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000<@3oool010000?l0oooo0?oo
o`000?l20?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0103oool4000003D0oooo0P000?l30?ooo`030000o`3oool0003o0080oooo00<0
003o0?ooo`3oool0>03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P
0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000m0?ooo`030000o`3o
ool0003o0080oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`800000T@3oool400000400oooo00<0003o0?ooo`000?l00P3oool0
0`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo0P00002@0?ooo`<00000@`3oool01P000?l0oooo0?ooo`000?l0oooo0000ocd0oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<
0?ooo`<000000P3oool00`000000oooo0?ooo`120?ooo`050000o`3oool0003o0?ooo`000?l0?P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08P0oooo100000050?ooo`030000003oool0oooo04<0oooo0P000?l00`3oool0003o0?ooo`0n
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`160?ooo`030000
o`3oool0oooo0400oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`170?ooo`030000o`3o
ool0oooo0400oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool30000
01P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool30000
03P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?oo
o`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool30000
05P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?oo
o`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`800000
9@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool30000
07L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?oo
o`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03o
ool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D0
00000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000
003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool20000
00T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?oo
o`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?oo
o`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003o
ool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool0
10000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool20000
07@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00
001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0
oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0
oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0
oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0019
0?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680
oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?oo
o`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;
0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<00000
0?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?oo
o`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3o
ool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3o
ool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool0
0`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@
0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?oo
o`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo
001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo10000005
0?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?oo
o`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00
JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`00
0000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000
oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo
1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00
000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a
0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`03
0000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`800000
3@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000
@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0
U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3o
ool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool20000
02X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo0000
02H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0
oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo
0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<00000
0?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?oo
o`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@0
0000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000
Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool0
0`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool20000
01T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo
0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d
0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?oo
o`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`00
00002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`000000
8`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000
^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000
003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool20000
00D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000
oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D0
0000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<00000
0P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61058 .66102 m
.61339 .6804 L
s
.60512 .66433 m
.60255 .66035 L
s
.60631 .66797 m
.60512 .66433 L
s
.6154 .68964 m
.61441 .68739 L
s
.61481 .69019 m
.6154 .68964 L
s
.61441 .68739 m
.61383 .68794 L
s
.60255 .66035 m
.60017 .65774 L
s
.61383 .68794 m
.61481 .69019 L
s
.60017 .65774 m
.59798 .65652 L
s
.60651 .67409 m
.60771 .67775 L
s
.60473 .67096 m
.60651 .67409 L
s
.60771 .67775 m
.60791 .67915 L
s
.60056 .66524 m
.60473 .67096 L
s
.60791 .67915 m
.60752 .6811 L
s
.59798 .65652 m
.59758 .65844 L
s
.60752 .6811 m
.60534 .67992 L
s
.59877 .6621 m
.60056 .66524 L
s
.59758 .65844 m
.59877 .6621 L
s
.60534 .67992 m
.60295 .67733 L
s
.60295 .67733 m
.60035 .67332 L
s
.59277 .65319 m
.59078 .64863 L
s
.59078 .64863 m
.58897 .64548 L
s
.60035 .67332 m
.59915 .66964 L
s
.58897 .64548 m
.58655 .64282 L
s
.58655 .64282 m
.58512 .64245 L
s
.59311 .66547 m
.59434 .66441 L
s
.58512 .64245 m
.58388 .64347 L
s
.57628 .62326 m
.57528 .62097 L
s
.57565 .62375 m
.57628 .62326 L
s
.57528 .62097 m
.57465 .62146 L
s
.59169 .66513 m
.59311 .66547 L
s
.58388 .64347 m
.58364 .64679 L
s
.57465 .62146 m
.57565 .62375 L
s
.58926 .66249 m
.59169 .66513 L
s
.58364 .64679 m
.58403 .6496 L
s
.57678 .63212 m
.57944 .65185 L
s
.58403 .6496 m
.58542 .65472 L
s
.58744 .65932 m
.58926 .66249 L
s
.58542 .65472 m
.58744 .65932 L
s
.56955 .62541 m
.57094 .63053 L
s
.56771 .62219 m
.56955 .62541 L
s
.56522 .61946 m
.56771 .62219 L
s
.57094 .63053 m
.57282 .64468 L
s
.55977 .60508 m
.56362 .6347 L
s
.56373 .61904 m
.56522 .61946 L
s
.56177 .62052 m
.56373 .61904 L
s
.55401 .61082 m
.5554 .61599 L
s
.55196 .60615 m
.55401 .61082 L
s
.55008 .60288 m
.55196 .60615 L
s
.54753 .60008 m
.55008 .60288 L
s
.5554 .61599 m
.55576 .61883 L
s
.55576 .61883 m
.55546 .62217 L
s
.546 .59962 m
.54753 .60008 L
s
.55546 .62217 m
.55412 .62318 L
s
.54464 .60058 m
.546 .59962 L
s
.54411 .59634 m
.54785 .62632 L
s
.55412 .62318 m
.55259 .62276 L
s
.55259 .62276 m
.55003 .61998 L
s
.53809 .58975 m
.54054 .60969 L
s
.55003 .61998 m
.54813 .61669 L
s
.54813 .61669 m
.54606 .61196 L
s
.53861 .594 m
.53653 .58927 L
s
.53653 .58927 m
.53463 .58596 L
s
.53463 .58596 m
.53202 .5831 L
s
.53202 .5831 m
.53045 .58261 L
s
.53863 .60638 m
.54001 .6054 L
s
.53045 .58261 m
.52905 .58354 L
s
.53706 .60592 m
.53863 .60638 L
s
.52905 .58354 m
.52868 .58686 L
s
.53444 .60308 m
.53706 .60592 L
s
.52063 .57062 m
.52327 .57352 L
s
.52868 .58686 m
.52902 .58972 L
s
.52902 .58972 m
.53042 .59497 L
s
.53252 .59975 m
.53444 .60308 L
s
.51902 .57011 m
.52063 .57062 L
s
.53042 .59497 m
.53252 .59975 L
s
.51758 .57102 m
.51902 .57011 L
s
.5162 .56577 m
.51853 .58584 L
s
.51719 .57433 m
.51758 .57102 L
s
.50931 .55324 m
.50719 .54844 L
s
.51052 .55706 m
.50931 .55324 L
s
.50719 .54844 m
.50524 .54505 L
s
.50524 .54505 m
.50164 .54109 L
s
.50164 .54109 m
.5 .54052 L
s
.50733 .56358 m
.51183 .56849 L
s
.51232 .5728 m
.51183 .56849 L
s
.5 .54052 m
.4985 .54137 L
s
.51175 .5747 m
.51232 .5728 L
s
.4985 .54137 m
.49791 .54323 L
s
.51028 .57563 m
.51175 .5747 L
s
.49791 .54323 m
.49747 .54652 L
s
.50864 .57512 m
.51028 .57563 L
s
.49747 .54652 m
.49826 .55369 L
s
.50501 .57118 m
.50864 .57512 L
s
.49826 .55369 m
.49965 .55901 L
s
.49183 .53908 m
.49032 .55527 L
s
.50303 .56776 m
.50501 .57118 L
s
.49965 .55901 m
.50088 .56289 L
s
.50088 .56289 m
.50303 .56776 L
s
.48446 .53101 m
.49032 .55527 L
s
.48446 .53101 m
.48287 .54719 L
s
.47703 .52287 m
.48287 .54719 L
s
.47046 .51567 m
.47252 .53597 L
s
.4709 .52 m
.46872 .51505 L
s
.46872 .51505 m
.46668 .51154 L
s
.46668 .51154 m
.46384 .50842 L
s
.46384 .50842 m
.46208 .50778 L
s
.47047 .53245 m
.47207 .53159 L
s
.46208 .50778 m
.46045 .50858 L
s
.46872 .53185 m
.47047 .53245 L
s
.46045 .50858 m
.45992 .51189 L
s
.46585 .52875 m
.46872 .53185 L
s
.45139 .49479 m
.45428 .49795 L
s
.45992 .51189 m
.46021 .51479 L
s
.46021 .51479 m
.46159 .52021 L
s
.4638 .52521 m
.46585 .52875 L
s
.4496 .49412 m
.45139 .49479 L
s
.46159 .52021 m
.4638 .52521 L
s
.44793 .4949 m
.4496 .49412 L
s
.44655 .48949 m
.44846 .5099 L
s
.44737 .4982 m
.44793 .4949 L
s
.43724 .47408 m
.43849 .47805 L
s
.43502 .46904 m
.43724 .47408 L
s
.43195 .46436 m
.43502 .46904 L
s
.43849 .47805 m
.43986 .48347 L
s
.42503 .45674 m
.43195 .46436 L
s
.43986 .48347 m
.44052 .49074 L
s
.44052 .49074 m
.43994 .49405 L
s
.42503 .45674 m
.42768 .48737 L
s
.43994 .49405 m
.43922 .49591 L
s
.43922 .49591 m
.43751 .4967 L
s
.43751 .4967 m
.43467 .49495 L
s
.43467 .49495 m
.42768 .48737 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02d0oooo00<0
003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?oo
o`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo02`0oooo0P000?mT
0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0000o`1S0?oo
o`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0:P3oool010000?l0oooo0?ooo`000?mS0?oo
o`030000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05/0oooo00<000000?ooo`3oool0:@3oool010000?l0oooo0?ooo`000?mS0?oo
o`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`80
0000G@3oool00`000000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`000?l0HP3oool00`00
0000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0
oooo00<000000?ooo`3oool09`3oool01@000?l0oooo0?ooo`3oool0003o0680oooo00<000000?oo
o`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`0W0?ooo`050000o`3oool0oooo0?ooo`000?l0H@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo02H0oooo00D0003o0?ooo`3oool0oooo0000o`1Q0?oo
o`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool09@3oool01@000?l0oooo0?ooo`3oool0003o
0640oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0GP3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1N0?ooo`040000003oool0oooo0?ooo`<0
0000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1N0?ooo`@00000
E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0280oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o05`0oooo0`00001H0?ooo`03
0000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
8P3oool01@000?l0oooo0?ooo`000?l0oooo0080003oF03oool300000080oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000
003oool0oooo0280oooo0`000?l0103oool0003o0000o`000?mD0?ooo`<000001@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo
0?ooo`0V0?ooo`80003o00<0oooo0000o`3oool0C`3oool3000000P0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo02H0oooo00<0003o0?ooo`3oool0C@3oool3000000/0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool0
0`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo04X0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`120?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0080oooo0P000?m00?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0
oooo0000oc`0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo02D0oooo00D0003o0?ooo`3oool0oooo0000o`0h0?ooo`<000006`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo02@0oooo00D0003o0?ooo`3oool0oooo0000o`0e0?ooo`<00000
7P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool0903oool010000?l0oooo0?ooo`000?la0?ooo`@00000
8@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?l20?ooo`030000
o`3oool0oooo02T0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0S0?ooo`030000o`3o
ool0003o0080oooo00<0003o0?ooo`3oool09P3oool3000002P0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool08`3oool0
1@000?l0oooo0000o`3oool0003o02D0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool08`3oool20000o`80oooo0P000?lP0?ooo`<00000;P3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`0R0?ooo`80003o0P3oool20000oad0oooo0`00000a0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3o
ool00`000?lI0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo02@0oooo
0`000?l00`3oool0003o0?ooo`0C0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0903o
ool20000o`040?ooo`000?l0oooo0?ooo`80003o3@3oool3000003X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo02<0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0oooo0000o`090?ooo`<00000
?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003o
ool0oooo07d0oooo00<000000?ooo`3oool08P3oool01P000?l0oooo0000o`000?l0oooo0000o`80
oooo00<0003o0?ooo`3oool0103oool300000400oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02<0oooo
0P000?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo00<00000@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool08`3oool010000?l0oooo0?ooo`000?l20?ooo`03000000000?l0000004H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<0
00000?ooo`3oool08P3oool010000?l0oooo0?ooo`000?l2000000030?ooo`000?l0oooo04H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0240oooo0`0000001@000?l0oooo0?ooo`3oool0003o04L0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?oo
o`230?ooo`030000003oool0oooo01`0oooo100000030?ooo`030000o`3oool0oooo04X0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01P0oooo0`0000080?ooo`030000o`3oool0003o04T0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo01@0oooo0`00000;0?ooo`060000o`3oool0oooo0000o`3oool0003oAP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000000h0oooo00@0003o0?ooo`3oool0oooo0P00
0?m60?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000004P3oool00`000?l0oooo0?ooo`04
0000od@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000F0?ooo`030000o`3oool0003o
0080003o00<0oooo0000o`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001X0
oooo00<0003o0?ooo`000?l0AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000P0?ooo`030000
o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`8000008`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2
000008d0oooo00<000000?ooo`3oool08P3oool010000?l0oooo0?ooo`3oool20000ocl0oooo0P00
001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool08P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0>`3oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool00P000?le0?ooo`@000001P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`020000oc80oooo0`00000:
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`040000o`3oool0oooo0000obl0oooo0`00000>
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`060000o`3oool0oooo0000o`3oool0003o:P3o
ool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00D0003o0?ooo`3oool0003o0?oo
o`020000obH0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`070000o`3oool0
003o0?ooo`000?l0oooo0000o`0Q0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3o
ool20000o`050?ooo`000?l0oooo0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0H0?ooo`<00000
7P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0000o`020?ooo`040000o`3o
ool0oooo0000oaL0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`040000o`3o
ool0oooo0000o`80oooo00<0003o0?ooo`3oool04P3oool3000002H0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0;03o
ool20000o`050?ooo`000?l0oooo0?ooo`000?l04@3oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02d0oooo00H0003o0?ooo`3oool0003o0?ooo`000?l=0?ooo`@00000;P3oool00`000000
oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0;P3oool20000o`030?ooo`000?l0oooo00<0003o203oool3000003<0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02h0oooo00D0003o0?ooo`000?l0003o0?ooo`020000o`040?oo
o`000?l0oooo0000o`80oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`030000
o`3oool0003o00<0oooo00@0003o0?ooo`000?l0oooo0`00000j0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0^0?ooo`030000o`3oool0oooo00<0oooo00@0003o0000000000000000?P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0<@3oool400000080oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0;P3oool3000000<0oooo00H0003o0?ooo`3oool0003o0?ooo`000?ln0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0[0?ooo`<000001P3oool01P000?l0oooo0?ooo`000?l0oooo0000
och0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00000<0?ooo`030000o`3oool0003o03l0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo
00<000000?ooo`3oool09@3oool3000000l0oooo00<0003o0?ooo`000?l0@03oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?oo
o`0Q0?ooo`@000004P3oool01@000?l0oooo0?ooo`000?l0oooo0080003o?@3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool07P3oool3000001H0oooo00P0003o0?ooo`3oool0003o0?ooo`000?l0oooo0000
ocd0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000703oool01@000?l0
oooo0000o`3oool0003o03d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool3000001l0oooo00D0003o0?ooo`000?l0oooo0000o`0n0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000T0?ooo`040000o`3oool0oooo
0000och0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool20000
00L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@000009`3oool00`00
0?l0oooo0?ooo`020?ooo`80003o?03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0>0?ooo`<00000;03oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l0?03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000`0?ooo`060000o`3oool0oooo
0000o`3oool0003o0P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`08
0?ooo`<00000=03oool20000o`060?ooo`000?l0oooo0000o`3oool0003o>P3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0103oool4000003X0oooo00D0003o0?ooo`000?l0oooo0000o`0k0?ooo`030000
003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03o
ool010000000oooo0?ooo`3oool3000003d0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo
0?ooo`0j0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00
002A0?ooo`@00000@@3oool20000o`<0oooo00<0003o0?ooo`3oool0>P3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000004@0oooo00<0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?oo
o`3oool0@`3oool30000o`030?ooo`000?l0oooo03`0oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000
oooo0?ooo`140?ooo`040000o`3oool0oooo0000och0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000
oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo
0?ooo`0n0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?oo
o`0o0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`0o
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?oo
o`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03o
ool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo
06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00
000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`03
0000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`00
7@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000
003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3o
ool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000
oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00
001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`03
0000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3o
ool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0
oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo
00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00
001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`03
0000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3o
ool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0
oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo
00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<00000
0?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo
0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000
003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo
0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?oo
o`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000
oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo
100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0
oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo
000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?oo
o`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`03
0000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00
=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`03
0000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00
>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool0
0`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool0
0400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[
0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000
003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0
oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool20000
00030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000
003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3o
ool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool01000
0000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo
0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0
oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo
0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@00000
0?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?oo
o`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`00
0000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool200000003
0?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00
HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2
000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0
oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0
oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P00
00130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3o
ool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0
]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03o
ool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool0
07@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0
oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo
0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00
000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00
000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X
0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo1000
00170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<0
00000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D
0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`03
0000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`03
0000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000
003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3o
ool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4
000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo
06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0
oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo
002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@
0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?oo
o`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`03
0000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3o
ool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03o
ool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool4
00000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool50000
0:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00
oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo
00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<0
00000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U
0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?oo
o`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000
003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`03
0000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool0
3@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo
002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000
003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60681 .6629 m
.61403 .68009 L
s
.60385 .66496 m
.60096 .66114 L
s
.60567 .66829 m
.60385 .66496 L
s
.61794 .68838 m
.61663 .68629 L
s
.61768 .68877 m
.61794 .68838 L
s
.61663 .68629 m
.61637 .68668 L
s
.60096 .66114 m
.59858 .65854 L
s
.61637 .68668 m
.61768 .68877 L
s
.59858 .65854 m
.59671 .65716 L
s
.60747 .67361 m
.6093 .67695 L
s
.60537 .67065 m
.60747 .67361 L
s
.6093 .67695 m
.60982 .6782 L
s
.60088 .66508 m
.60537 .67065 L
s
.60982 .6782 m
.61007 .67982 L
s
.59671 .65716 m
.59694 .65876 L
s
.61007 .67982 m
.60822 .67849 L
s
.59877 .6621 m
.60088 .66508 L
s
.59694 .65876 m
.59877 .6621 L
s
.60822 .67849 m
.60583 .67589 L
s
.59213 .65351 m
.5895 .64928 L
s
.5895 .64928 m
.58737 .64628 L
s
.60583 .67589 m
.60292 .67204 L
s
.58737 .64628 m
.58495 .64363 L
s
.60292 .67204 m
.60108 .66868 L
s
.58495 .64363 m
.58384 .64309 L
s
.58384 .64309 m
.58324 .64379 L
s
.59569 .66419 m
.59626 .66344 L
s
.57244 .62521 m
.57111 .62308 L
s
.57212 .62554 m
.57244 .62521 L
s
.57111 .62308 m
.5708 .62341 L
s
.5708 .62341 m
.57212 .62554 L
s
.58324 .64379 m
.58397 .64663 L
s
.59459 .66368 m
.59569 .66419 L
s
.59216 .66104 m
.59459 .66368 L
s
.58397 .64663 m
.58499 .64912 L
s
.57517 .63294 m
.58236 .65038 L
s
.58499 .64912 m
.58736 .65375 L
s
.59002 .65802 m
.59216 .66104 L
s
.58736 .65375 m
.59002 .65802 L
s
.56826 .62606 m
.57062 .63069 L
s
.56609 .62301 m
.56826 .62606 L
s
.5636 .62028 m
.56609 .62301 L
s
.57062 .63069 m
.57575 .6432 L
s
.55589 .60706 m
.56656 .63321 L
s
.56244 .6197 m
.5636 .62028 L
s
.56145 .62068 m
.56244 .6197 L
s
.55336 .61116 m
.55573 .61583 L
s
.55065 .60681 m
.55336 .61116 L
s
.54845 .60371 m
.55065 .60681 L
s
.54589 .60092 m
.54845 .60371 L
s
.55573 .61583 m
.55674 .61833 L
s
.55674 .61833 m
.55743 .62117 L
s
.54469 .60029 m
.54589 .60092 L
s
.54398 .60092 m
.54469 .60029 L
s
.55743 .62117 m
.55675 .62184 L
s
.54247 .59718 m
.55315 .62362 L
s
.55675 .62184 m
.55556 .62125 L
s
.55556 .62125 m
.553 .61847 L
s
.53645 .59059 m
.54352 .60817 L
s
.553 .61847 m
.55077 .61534 L
s
.53795 .59433 m
.53522 .58995 L
s
.53522 .58995 m
.53298 .5868 L
s
.55077 .61534 m
.54804 .61095 L
s
.53298 .5868 m
.53037 .58395 L
s
.53037 .58395 m
.52913 .58329 L
s
.52913 .58329 m
.52838 .58388 L
s
.54128 .60502 m
.542 .60438 L
s
.52838 .58388 m
.52901 .58669 L
s
.54005 .60439 m
.54128 .60502 L
s
.51897 .57148 m
.52162 .57437 L
s
.53743 .60155 m
.54005 .60439 L
s
.52901 .58669 m
.53002 .58921 L
s
.53002 .58921 m
.53241 .59395 L
s
.5177 .57079 m
.51897 .57148 L
s
.53518 .59838 m
.53743 .60155 L
s
.53241 .59395 m
.53518 .59838 L
s
.51692 .57136 m
.5177 .57079 L
s
.51454 .56663 m
.52154 .58428 L
s
.51753 .57416 m
.51692 .57136 L
s
.50631 .5548 m
.50353 .55035 L
s
.50819 .55828 m
.50631 .5548 L
s
.50353 .55035 m
.50124 .54713 L
s
.50124 .54713 m
.49764 .54318 L
s
.49764 .54318 m
.49632 .54244 L
s
.49632 .54244 m
.49549 .54295 L
s
.50767 .56341 m
.51217 .56831 L
s
.51366 .5721 m
.51217 .56831 L
s
.51377 .57366 m
.51366 .5721 L
s
.49549 .54295 m
.49556 .54445 L
s
.51297 .57424 m
.51377 .57366 L
s
.49556 .54445 m
.49613 .54722 L
s
.51167 .57355 m
.51297 .57424 L
s
.49613 .54722 m
.4986 .55352 L
s
.50805 .56961 m
.51167 .57355 L
s
.4986 .55352 m
.501 .55831 L
s
.49015 .53996 m
.49338 .55367 L
s
.50573 .56636 m
.50805 .56961 L
s
.501 .55831 m
.50291 .56184 L
s
.50291 .56184 m
.50573 .56636 L
s
.48277 .5319 m
.49338 .55367 L
s
.48277 .5319 m
.48595 .54559 L
s
.47533 .52376 m
.48595 .54559 L
s
.46876 .51657 m
.47561 .53435 L
s
.47022 .52036 m
.46735 .51577 L
s
.46735 .51577 m
.46498 .51244 L
s
.46498 .51244 m
.46213 .50933 L
s
.46213 .50933 m
.46071 .5085 L
s
.46071 .5085 m
.45977 .50895 L
s
.47322 .53101 m
.47413 .53051 L
s
.45977 .50895 m
.46027 .51171 L
s
.47181 .53022 m
.47322 .53101 L
s
.44967 .4957 m
.45256 .49887 L
s
.46895 .52712 m
.47181 .53022 L
s
.46027 .51171 m
.46124 .51425 L
s
.46124 .51425 m
.46366 .51912 L
s
.44822 .49485 m
.44967 .4957 L
s
.46655 .52376 m
.46895 .52712 L
s
.46366 .51912 m
.46655 .52376 L
s
.44724 .49527 m
.44822 .49485 L
s
.44483 .49041 m
.45159 .50824 L
s
.44771 .49801 m
.44724 .49527 L
s
.43414 .47575 m
.43607 .47934 L
s
.43123 .47108 m
.43414 .47575 L
s
.4278 .46659 m
.43123 .47108 L
s
.43607 .47934 m
.43848 .4842 L
s
.42087 .45898 m
.4278 .46659 L
s
.43848 .4842 m
.44087 .49055 L
s
.44087 .49055 m
.44133 .49331 L
s
.42087 .45898 m
.43084 .48569 L
s
.44133 .49331 m
.44131 .4948 L
s
.44131 .4948 m
.4403 .49521 L
s
.4403 .49521 m
.43782 .49327 L
s
.43782 .49327 m
.43084 .48569 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo06@0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0Z0?ooo`80003oI@3oool00`000000oooo0?ooo`0N0?oo
o`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo02X0oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`0J0?ooo`<0
0000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000
003oool0oooo02T0oooo0P000?mU0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3o
ool0003o06@0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo02L0oooo00@0003o0?ooo`3oool0003oH`3o
ool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`000?l0H`3oool0
0`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3oool0003oHP3oool0
0`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo00@0003o0?ooo`3oool0003oHP3oool0
0`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1R0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`000?l0HP3oool00`00
0000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1S0?ooo`030000003oool0oooo02@0oooo00@0003o0?ooo`3oool0003oH@3oool01000
0000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?oo
o`3oool0I03oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0003o0640oooo1000001E0?oo
o`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool0903oool01@000?l0oooo0000o`3oool0003o05`0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0903oool20000o`03
0?ooo`000?l0oooo05P0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`0T0?ooo`030000
o`3oool0oooo0080003oE03oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo0000
o`1@0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`1=
0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?oo
o`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo02D0oooo00<0003o0?oo
o`3oool0BP3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool09@3oool00`000?l0oooo0?ooo`160?ooo`<000004@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K@3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080003o@@3oool30000
01@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0000o`0m0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`00
0000oooo0?ooo`0V0?ooo`030000o`3oool0003o03T0oooo0`00000K0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700
oooo00<000000?ooo`3oool09@3oool010000?l0oooo0000o`000?le0?ooo`<000007P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0000o`0a0?ooo`@000008@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool09@3oool010000?l0oooo0000o`000?l/0?ooo`<000009@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo
00<000000?ooo`3oool0903oool010000?l0oooo0000o`000?lY0?ooo`<00000:03oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo
0?ooo`0T0?ooo`80003o00<0oooo0000o`3oool0903oool3000002/0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`0T0?ooo`<0003o00<0oooo0000o`3oool07`3oool3000002h0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P
0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0903oool010000?l0oooo0000o`00
0?lM0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0004
0?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0U
0?ooo`<0003o6@3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0U0?oo
o`80003o00<0oooo0000o`3oool04`3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo02@0
oooo10000?l00`3oool0003o0?ooo`0>0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
903oool30000o`030?ooo`000?l0oooo00/0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?oo
o`0S0?ooo`040000o`3oool0003o0?ooo`<0003o1`3oool300000400oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02@0oooo0`000?l20?ooo`040000o`3oool0oooo0?ooo`<00000@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<0
00000?ooo`3oool0903oool01@000?l0oooo0000o`3oool0003o00<00000AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?oo
o`0S0?ooo`030000o`3oool0003o0080000000<0003o0?ooo`3oool0AP3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool08@3oool3000000040?ooo`000?l0oooo0000odP0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo01`0oooo100000040?ooo`030000o`3oool0oooo04T0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
01P0oooo0`0000080?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0
oooo0`00000<0?ooo`050000o`3oool0003o0?ooo`000?l0AP3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0403oool3000000l0oooo00<0003o0?ooo`3oool00P000?m60?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo
0?ooo`0<0?ooo`<000004`3oool01@000?l0oooo0000o`3oool0003o04D0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo00P0oooo0`00000G0?ooo`80003o00<0oooo0000o`000?l0A03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0103oool3000001d0oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool00`00000P0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000903oool00`00
0?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo0P00002=0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P000?lo0?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02H0oooo00<0003o0?ooo`000?l0>`3oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02H0oooo00@0003o0?ooo`000?l0003o=P3oool4000000H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02H0oooo00@0003o0?ooo`000?l0003o<`3oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02L0oooo00@0003o0?ooo`000?l0003o;`3oool3000000h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02P0oooo00@0003o0?ooo`000?l0003o:`3oool300000180oooo00<000000?ooo`3oool0
E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02T0oooo00@0003o0?ooo`000?l0003o9`3oool3000001H0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02T0oooo00<0003o0?ooo`000?l00P000?lR0?ooo`@000006P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0:P3oool30000o`030?ooo`000?l0oooo01d0oooo0`00000N0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0/0?ooo`<0003o00<0oooo0000o`3oool0603oool300000280oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02d0oooo00@0003o0?ooo`000?l0003o5P3oool3000002H0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3o
ool0;@3oool01@000?l0oooo0000o`3oool0003o0180oooo0`00000Z0?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0^0?ooo`040000o`3oool0003o0000o`h0oooo1000000^0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0_0?ooo`<0003o00<0oooo0000o`000?l02@3oool3000003<0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo0300oooo10000?l0103oool0003o0?ooo`000?l30?ooo`<00000=P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0<03oool010000?l0oooo0?ooo`3oool20000o`030?ooo`000?l000000080
0000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0=03oool010000?l0000000000000000n0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0a0?ooo`@0000000<0003o0?ooo`000?l0?`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0;P3oool3000000@0oooo00@0003o0?ooo`000?l0003o?`3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:`3oool3000000X0oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0:03oool3000000d0oooo0P000?lo0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000A0?oo
o`030000o`3oool0oooo03h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?oo
o`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000001@0oooo10000?ln0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<000006@3oool010000?l0oooo0000o`000?ln0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000001d0oooo0P000?l00`3oool0003o
0?ooo`0l0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo
0`00000P0?ooo`80003o00<0oooo0000o`3oool0?@3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0E0?ooo`<000009@3oool00`000?l0oooo0000o`0n0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool04@3oool4000002P0oooo00@0003o0?ooo`3oool0003o?P3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000;@3oool0
10000?l0oooo0000o`000?ln0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3
00000340oooo00H0003o0?ooo`000?l0003o0?ooo`000?lk0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`080?ooo`<00000=@3oool00`000?l0oooo0000o`020000oc`0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000000k0?ooo`<0003o?03oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000n
0?ooo`040000o`3oool0003o0000ocd0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0>0?ooo`00803oool200000940oooo100000120?ooo`80003o00<0oooo0000o`3oool0?03oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool30000
04H0oooo00<0003o0?ooo`000?l0?@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04D0
oooo00<0003o0?ooo`000?l0?@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo04D0oooo
00<0003o0?ooo`000?l0?P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`22
0?ooo`<00000303oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo03d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?oo
o`<000003`3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo03h0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<0
00004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0
oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<0
0000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0
oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P00
00190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<00000
0?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@0
0000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0
oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z
0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`09
0?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@0
0000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140
oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00
002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?oo
o`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000
003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3o
ool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0
oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`80
0000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0
L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`03
0000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00
@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0
a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3o
ool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3o
ool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0
oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo
0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo0014
0?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`03
0000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00
F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0
oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0
oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo
000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080
oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<
0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?oo
o`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00
K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3o
ool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0
000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`00
0000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000
000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i
0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?oo
o`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?oo
o`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`04
0000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?oo
o`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@0
0000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000
F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool0
10000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool0
0`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool20000
02H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?oo
o`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<0
00000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D0
0000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000
S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool20000
01H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180
oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo
00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo
001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<0
00000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A
0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?oo
o`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?oo
o`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?oo
o`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool0
00000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80
oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000
aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2
000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo
0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H
0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.6033 .66543 m
.61462 .67966 L
s
.60267 .66581 m
.59949 .6622 L
s
.60508 .66871 m
.60267 .66581 L
s
.6203 .68668 m
.6187 .6848 L
s
.62034 .68686 m
.6203 .68668 L
s
.6187 .6848 m
.61874 .68498 L
s
.59949 .6622 m
.59711 .6596 L
s
.61874 .68498 m
.62034 .68686 L
s
.59711 .6596 m
.59553 .65801 L
s
.60836 .67297 m
.61078 .67589 L
s
.60596 .67022 m
.60836 .67297 L
s
.61078 .67589 m
.6116 .67692 L
s
.60118 .66486 m
.60596 .67022 L
s
.6116 .67692 m
.61244 .67812 L
s
.59553 .65801 m
.59635 .65918 L
s
.61244 .67812 m
.61089 .67656 L
s
.59877 .6621 m
.60118 .66486 L
s
.59635 .65918 m
.59877 .6621 L
s
.61089 .67656 m
.60851 .67397 L
s
.59154 .65393 m
.58831 .65014 L
s
.58831 .65014 m
.58589 .64735 L
s
.60851 .67397 m
.6053 .67033 L
s
.58589 .64735 m
.58346 .6447 L
s
.6053 .67033 m
.60286 .66739 L
s
.58346 .6447 m
.58265 .64395 L
s
.58265 .64395 m
.58264 .64422 L
s
.59808 .66246 m
.59806 .66215 L
s
.56886 .6278 m
.56723 .62589 L
s
.56884 .62792 m
.56886 .6278 L
s
.56723 .62589 m
.56721 .62601 L
s
.56721 .62601 m
.56884 .62792 L
s
.58264 .64422 m
.58426 .64641 L
s
.59729 .66174 m
.59808 .66246 L
s
.59487 .65909 m
.59729 .66174 L
s
.58426 .64641 m
.58589 .64847 L
s
.57367 .63402 m
.58508 .64842 L
s
.58589 .64847 m
.58916 .65245 L
s
.59242 .65629 m
.59487 .65909 L
s
.58916 .65245 m
.59242 .65629 L
s
.56705 .62693 m
.57032 .63091 L
s
.56459 .6241 m
.56705 .62693 L
s
.56209 .62137 m
.56459 .6241 L
s
.57032 .63091 m
.57848 .64122 L
s
.55227 .60968 m
.56931 .63123 L
s
.56123 .62057 m
.56209 .62137 L
s
.56115 .6209 m
.56123 .62057 L
s
.55275 .6116 m
.55603 .6156 L
s
.54943 .6077 m
.55275 .6116 L
s
.54692 .60482 m
.54943 .6077 L
s
.54436 .60203 m
.54692 .60482 L
s
.55603 .6156 m
.55766 .61767 L
s
.55766 .61767 m
.55926 .61984 L
s
.54346 .60118 m
.54436 .60203 L
s
.54337 .60136 m
.54346 .60118 L
s
.55926 .61984 m
.5592 .62006 L
s
.54094 .59829 m
.55811 .62003 L
s
.5592 .62006 m
.55832 .61925 L
s
.55832 .61925 m
.55576 .61646 L
s
.53491 .59171 m
.54631 .60615 L
s
.55576 .61646 m
.55323 .61355 L
s
.53734 .59478 m
.53399 .59084 L
s
.53399 .59084 m
.53144 .58792 L
s
.55323 .61355 m
.54988 .60961 L
s
.53144 .58792 m
.52883 .58507 L
s
.52883 .58507 m
.5279 .58419 L
s
.5279 .58419 m
.52777 .58433 L
s
.54376 .60322 m
.54385 .60303 L
s
.52777 .58433 m
.52932 .58647 L
s
.54284 .60237 m
.54376 .60322 L
s
.51742 .57261 m
.52007 .5755 L
s
.54023 .59952 m
.54284 .60237 L
s
.52932 .58647 m
.53095 .58853 L
s
.53095 .58853 m
.53428 .59259 L
s
.51645 .5717 m
.51742 .57261 L
s
.53766 .59658 m
.54023 .59952 L
s
.53428 .59259 m
.53766 .59658 L
s
.51629 .57181 m
.51645 .5717 L
s
.51298 .56777 m
.52437 .58222 L
s
.51784 .57393 m
.51629 .57181 L
s
.50351 .55685 m
.50011 .55285 L
s
.50601 .55987 m
.50351 .55685 L
s
.50011 .55285 m
.49751 .54987 L
s
.49751 .54987 m
.4939 .54592 L
s
.4939 .54592 m
.49288 .54496 L
s
.49288 .54496 m
.49267 .54501 L
s
.50798 .56318 m
.51248 .56809 L
s
.51492 .57119 m
.51248 .56809 L
s
.51565 .57228 m
.51492 .57119 L
s
.49267 .54501 m
.49336 .54606 L
s
.51549 .5724 m
.51565 .57228 L
s
.49336 .54606 m
.49487 .54814 L
s
.51451 .57147 m
.51549 .5724 L
s
.49487 .54814 m
.49891 .55329 L
s
.51089 .56753 m
.51451 .57147 L
s
.49891 .55329 m
.50226 .55738 L
s
.48857 .54112 m
.49625 .55157 L
s
.50826 .56451 m
.51089 .56753 L
s
.50226 .55738 m
.5048 .56045 L
s
.5048 .56045 m
.50826 .56451 L
s
.48119 .53306 m
.49625 .55157 L
s
.48119 .53306 m
.48883 .54348 L
s
.47374 .52493 m
.48883 .54348 L
s
.46716 .51775 m
.47851 .53222 L
s
.46958 .52083 m
.46607 .51671 L
s
.46607 .51671 m
.46338 .51361 L
s
.46338 .51361 m
.46053 .5105 L
s
.46053 .5105 m
.45942 .50945 L
s
.45942 .50945 m
.45912 .50942 L
s
.4758 .52912 m
.47606 .5291 L
s
.45912 .50942 m
.46059 .51147 L
s
.47472 .52809 m
.4758 .52912 L
s
.44806 .49689 m
.45095 .50005 L
s
.47186 .52498 m
.47472 .52809 L
s
.46059 .51147 m
.46221 .51354 L
s
.46221 .51354 m
.4656 .51769 L
s
.44693 .49581 m
.44806 .49689 L
s
.46914 .52186 m
.47186 .52498 L
s
.4656 .51769 m
.46914 .52186 L
s
.44659 .49574 m
.44693 .49581 L
s
.44321 .4916 m
.45453 .50608 L
s
.44804 .49778 m
.44659 .49574 L
s
.43122 .47791 m
.43379 .48102 L
s
.42766 .47372 m
.43122 .47791 L
s
.42391 .46947 m
.42766 .47372 L
s
.43379 .48102 m
.43718 .48516 L
s
.41696 .46188 m
.42391 .46947 L
s
.43718 .48516 m
.4412 .49031 L
s
.4412 .49031 m
.44264 .49234 L
s
.41696 .46188 m
.43381 .48349 L
s
.44264 .49234 m
.44328 .49335 L
s
.44328 .49335 m
.44293 .49328 L
s
.44293 .49328 m
.44078 .49108 L
s
.44078 .49108 m
.43381 .48349 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0:03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
:03oool00`000?l0oooo0?ooo`1U0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo06@0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0I03oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo02L0oooo0P000?mS0?ooo`030000003oool0oooo00X0
oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool09`3oool20000of80oooo00<000000?ooo`3oool01`3oool3000004/0oooo
00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0103oool3000004h0oooo00<0
00000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0W
0?ooo`030000o`3oool0oooo05l0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`1O0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo02H0oooo0P000?mM0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02H0
oooo0P000?mI0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool09P3oool20000oeD0oooo
0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00
001Y0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0D03oool3000000P0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0C03oool3000000/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?oo
o`3oool0JP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo04T0oooo0`00000>0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo02H0oooo00<0003o0?oo
o`3oool0A@3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool09`3oool20000od40oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0?03oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool09P3oool20000ocX0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool09P3oool20000ocH0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`0V0?ooo`80003o<@3oool400000240oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003o
ool0oooo02H0oooo00<0003o0?ooo`3oool0;03oool3000002D0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0
oooo02H0oooo00<0003o0?ooo`3oool0:03oool3000002P0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool09P3oool00`00
0?l0oooo0?ooo`0T0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02D0
oooo0P000?lR0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`0U0?ooo`80003o7P3oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<0
00000?ooo`3oool09@3oool20000oaX0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<00000
0?ooo`3oool09@3oool20000oaH0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0U0?oo
o`80003o4P3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02D0oooo0`000?l=0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool09@3oool20000o`X0oooo0`0000100?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0U0?ooo`80003o1P3oool3000004<0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo02D0oooo0P000?l20?ooo`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`80003o00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000030?ooo`000?l0003o04T0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo01`0oooo100000050?ooo`80003oB@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0603oool3000000T0oooo0P000?m90?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D
0?ooo`<000003@3oool20000odP0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000A0?oo
o`80003oA`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001D0oooo0P000?m60?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<000006@3oool20000odD0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo00@0oooo0`00000M0?ooo`80003oA03oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000Q
0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009@3oool00`000?l0oooo0?ooo`110?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`03
0000003oool0oooo02H0oooo00<0003o0?ooo`3oool0?P3oool2000005/0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`80003o
?03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02L0oooo0P000?lg0?ooo`@000001P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0b0?ooo`<000002P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0:03oool20000oc00oooo0`00000>0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0Y0?ooo`<0003o:`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo
0`000?lW0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool20000ob<0oooo1000
000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0]0?ooo`030000o`3oool0oooo01d0oooo0`00000N
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`80003o6P3oool300000280oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02h0oooo0`000?lF0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0_0?ooo`80003o
4`3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0300oooo0P000?l>0?ooo`@00000;P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0<P3oool20000o`X0oooo0`00000c0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0c0?ooo`030000o`3oool0oooo00D0oooo0`00000f0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0d0?ooo`040000o`3oool0oooo0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000030000ocl0oooo
00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02h0oooo0`0000050?ooo`030000o`3oool0003o03l0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02/0oooo0`00000:0?ooo`030000o`3oool0oooo03d0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02P0oooo0`00000>0?ooo`030000o`3oool0oooo03d0oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3o
ool09@3oool300000180oooo00<0003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000
5@3oool20000ocl0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000J0?ooo`80003o?`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000N0?ooo`030000o`3oool0
oooo03d0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool01000
0000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3
00000280oooo0P000?ln0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool0
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01D0oooo0`00000V0?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@00000:P3oool00`000?l0oooo0?ooo`0m0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000_0?ooo`80003o?P3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00/0oooo0`00000c0?ooo`030000o`3oool0oooo03`0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00P0oooo0`00000g0?ooo`80003o?@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool4000003/0oooo0P000?lm0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
0400oooo00<0003o0?ooo`3oool0?03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00h0oooo000P0?ooo`800000T@3oool4000004@0oooo00<0003o0?ooo`3oool0?03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000004P0oooo
00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04H0oooo00<0
003o0?ooo`3oool0?03oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo04L0oooo00<0003o
0?ooo`3oool0?03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<0
0000303oool00`000000oooo0?ooo`190?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.60022 .66848 m
.61513 .67915 L
s
.60164 .66684 m
.59819 .66349 L
s
.60456 .66923 m
.60164 .66684 L
s
.62238 .68463 m
.62052 .683 L
s
.62268 .68455 m
.62238 .68463 L
s
.62052 .683 m
.62081 .68292 L
s
.59819 .66349 m
.59581 .66089 L
s
.62081 .68292 m
.62268 .68455 L
s
.59581 .66089 m
.59448 .65904 L
s
.60914 .6722 m
.61208 .6746 L
s
.60648 .6697 m
.60914 .6722 L
s
.61208 .6746 m
.61316 .67537 L
s
.60144 .66461 m
.60648 .6697 L
s
.61316 .67537 m
.61453 .67605 L
s
.59448 .65904 m
.59583 .6597 L
s
.61453 .67605 m
.61324 .67423 L
s
.59877 .6621 m
.60144 .66461 L
s
.59583 .6597 m
.59877 .6621 L
s
.61324 .67423 m
.61087 .67163 L
s
.59102 .65445 m
.58726 .65117 L
s
.58726 .65117 m
.58458 .64865 L
s
.61087 .67163 m
.6074 .66825 L
s
.58458 .64865 m
.58215 .646 L
s
.6074 .66825 m
.60444 .66584 L
s
.58215 .646 m
.5816 .64499 L
s
.5816 .64499 m
.58211 .64475 L
s
.60019 .66037 m
.59963 .66059 L
s
.5657 .63092 m
.56381 .62927 L
s
.56594 .63078 m
.5657 .63092 L
s
.56381 .62927 m
.56405 .62913 L
s
.56405 .62913 m
.56594 .63078 L
s
.58211 .64475 m
.58453 .64615 L
s
.59967 .65938 m
.60019 .66037 L
s
.59725 .65673 m
.59967 .65938 L
s
.58453 .64615 m
.58669 .64768 L
s
.57235 .63533 m
.58747 .64605 L
s
.58669 .64768 m
.59075 .65088 L
s
.59454 .65419 m
.59725 .65673 L
s
.59075 .65088 m
.59454 .65419 L
s
.56599 .62798 m
.57005 .63117 L
s
.56326 .62541 m
.56599 .62798 L
s
.56076 .62269 m
.56326 .62541 L
s
.57005 .63117 m
.58089 .63884 L
s
.54908 .61284 m
.57173 .62883 L
s
.56016 .62163 m
.56076 .62269 L
s
.56088 .62117 m
.56016 .62163 L
s
.55221 .61213 m
.5563 .61534 L
s
.54835 .60876 m
.55221 .61213 L
s
.54558 .60615 m
.54835 .60876 L
s
.54302 .60336 m
.54558 .60615 L
s
.5563 .61534 m
.55847 .61687 L
s
.55847 .61687 m
.56088 .61824 L
s
.54238 .60225 m
.54302 .60336 L
s
.54283 .6019 m
.54238 .60225 L
s
.56088 .61824 m
.56137 .61792 L
s
.53959 .59962 m
.56248 .6157 L
s
.56137 .61792 m
.56076 .61683 L
s
.56076 .61683 m
.55821 .61404 L
s
.53355 .59305 m
.54877 .60372 L
s
.55821 .61404 m
.55541 .61141 L
s
.53679 .59532 m
.5329 .59191 L
s
.5329 .59191 m
.53008 .58926 L
s
.55541 .61141 m
.55151 .608 L
s
.53008 .58926 m
.52747 .58642 L
s
.52747 .58642 m
.5268 .58527 L
s
.5268 .58527 m
.52722 .58487 L
s
.54595 .60106 m
.54549 .60142 L
s
.52722 .58487 m
.5296 .58619 L
s
.54531 .59993 m
.54595 .60106 L
s
.51604 .57396 m
.5187 .57685 L
s
.5427 .59708 m
.54531 .59993 L
s
.5296 .58619 m
.53177 .58772 L
s
.53177 .58772 m
.53592 .59096 L
s
.51535 .57279 m
.51604 .57396 L
s
.53986 .5944 m
.5427 .59708 L
s
.53592 .59096 m
.53986 .5944 L
s
.51574 .57236 m
.51535 .57279 L
s
.5116 .56912 m
.52687 .57976 L
s
.51811 .57366 m
.51574 .57236 L
s
.50102 .5593 m
.49707 .55584 L
s
.50408 .56178 m
.50102 .5593 L
s
.49707 .55584 m
.49419 .55313 L
s
.49419 .55313 m
.49057 .54919 L
s
.49057 .54919 m
.48983 .54796 L
s
.48983 .54796 m
.49017 .54748 L
s
.50826 .56291 m
.51276 .56781 L
s
.51603 .57009 m
.51276 .56781 L
s
.51732 .57063 m
.51603 .57009 L
s
.49017 .54748 m
.49141 .54798 L
s
.51772 .5702 m
.51732 .57063 L
s
.49141 .54798 m
.49375 .54924 L
s
.51702 .56899 m
.51772 .5702 L
s
.49375 .54924 m
.49919 .55301 L
s
.51341 .56505 m
.51702 .56899 L
s
.49919 .55301 m
.50338 .55628 L
s
.48717 .5425 m
.4988 .54906 L
s
.5105 .5623 m
.51341 .56505 L
s
.50338 .55628 m
.50649 .55879 L
s
.50649 .55879 m
.5105 .5623 L
s
.47978 .53445 m
.4988 .54906 L
s
.47978 .53445 m
.49139 .54096 L
s
.47232 .52632 m
.49139 .54096 L
s
.46574 .51914 m
.48108 .52968 L
s
.46901 .52139 m
.46494 .51783 L
s
.46494 .51783 m
.46195 .51502 L
s
.46195 .51502 m
.4591 .51191 L
s
.4591 .51191 m
.45828 .51057 L
s
.45828 .51057 m
.45855 .50998 L
s
.47809 .52686 m
.47777 .52741 L
s
.45855 .50998 m
.46087 .51119 L
s
.4773 .52555 m
.47809 .52686 L
s
.44662 .49831 m
.44952 .50146 L
s
.47445 .52243 m
.4773 .52555 L
s
.46087 .51119 m
.46307 .51269 L
s
.46307 .51269 m
.46733 .51599 L
s
.44577 .49694 m
.44662 .49831 L
s
.47144 .51959 m
.47445 .52243 L
s
.46733 .51599 m
.47144 .51959 L
s
.44601 .49631 m
.44577 .49694 L
s
.44177 .49302 m
.45714 .5035 L
s
.44833 .49749 m
.44601 .49631 L
s
.42861 .48046 m
.43177 .48301 L
s
.42447 .47685 m
.42861 .48046 L
s
.42043 .47288 m
.42447 .47685 L
s
.43177 .48301 m
.43602 .4863 L
s
.41346 .46531 m
.42043 .47288 L
s
.43602 .4863 m
.44149 .49003 L
s
.44149 .49003 m
.4438 .4912 L
s
.41346 .46531 m
.43646 .48088 L
s
.4438 .4912 m
.44503 .49162 L
s
.44503 .49162 m
.44527 .49098 L
s
.44527 .49098 m
.44342 .48849 L
s
.44342 .48849 m
.43646 .48088 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0
5`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003o
ool0oooo02D0oooo0P000?mX0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0V0?ooo`80003oIP3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02D0oooo00@0003o0?ooo`000?l0003oI03oool0
0`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1P0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00P000?mR0?oo
o`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool09@3oool20000o`80oooo00<0003o0?ooo`3o
ool0G`3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02H0oooo00@0003o0?ooo`3oool0
003oH03oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`000?l0
H03oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo
00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0003o05l0oooo
1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool09P3oool30000oe`0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`1H
0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?oo
o`030000003oool0000006P0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`1D0?oo
o`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`80
0000J@3oool00`000000oooo0?ooo`0V0?ooo`<0003oD@3oool3000000P0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo02H0oooo00<0003o0?ooo`000?l0C@3oool3000000/0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo04L0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06h0oooo0`00000A0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0@03o
ool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool09P3o
ool30000ocd0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003o
ool0oooo02H0oooo0P000?lj0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0
oooo02H0oooo0P000?lf0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool09P3oool30000
oc00oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0003o02`0
oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo
00<000000?ooo`000000M03oool00`000000oooo0?ooo`0V0?ooo`<0003o:03oool3000002P0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<0
00000?ooo`3oool09P3oool20000obD0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool09P3oool20000ob40oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo02H0oooo0P000?lM0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0V0?ooo`80003o6@3oool3000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0V0?ooo`80003o5@3oool3000003L0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo02H0oooo0P000?lA0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool09P3oool2
0000o`d0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0U0?ooo`<0003o2@3oool30000
0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo02@0oooo0P000?l00`3oool0003o0?ooo`040?ooo`<0
0000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0903oool30000o`80oooo0`0000160?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo02@0oooo00@0003o000000000?l00000B@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3o
ool3000000040000o`3oool0003o0000odP0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000
00040?ooo`030000o`3oool0003o04T0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`000009
0?ooo`<0003oB03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000h0oooo0P000?m70?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000004P3oool30000odD0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00`0oooo0`00000F0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203o
ool3000001T0oooo0`000?m40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007@3oool0
0`000?l0oooo0000o`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000002<0oooo00<0003o0?oo
o`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo08`0oooo0P00001Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0
?`3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0V0?ooo`80003o?03oool300000080oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02L0oooo0`000?lf0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool20000
oc<0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`80003o;`3oool3000000h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02X0oooo0P000?l[0?ooo`<000004P3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0:P3oool00`000?l0oooo0000o`0W0?ooo`<000005P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0:`3oool30000ob80oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0/0?oo
o`80003o7`3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo0`000?lJ0?ooo`<0
00008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool30000oaH0oooo0`00000V0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003o
ool0oooo02h0oooo0P000?l00`3oool0003o0000o`0A0?ooo`<00000:P3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0;`3oool50000o``0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0a0?oo
o`<0003o2P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3o
ool01@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03@0oooo00@0003o0?ooo`3oool0
oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0<@3oool4000000030000o`3oool0003o03l0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02h0oooo0`0000050?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo0`0000090?ooo`80003o?`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000d0
oooo0`000?ln0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo
0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000B0?ooo`030000o`3oool0oooo03d0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<0
00000?ooo`3oool08@3oool4000001H0oooo0P000?ln0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<000006P3oool30000och0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<000007P3oool20000och0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool300000280oooo0P000?ln0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01D0oooo0`00000V0?ooo`<0003o?@3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0140oooo1000000/0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002l0oooo0`000?lm0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000380oooo0P000?ln0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`080?ooo`<00000=P3oool30000ocd0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0
oooo1000000j0?ooo`<0003o?@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0
oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000o0?ooo`<0
003o?@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000
T@3oool4000004<0oooo0`000?lm0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo0P00002@0?ooo`<00000B03oool20000oc`0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`170?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0B@3oool20000oc`0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?oo
o`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool40000
02@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?oo
o`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000
003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?oo
o`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3o
ool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000
oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<0
00000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?oo
o`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00
002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo
0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`06
0?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`03
0000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l
0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000
NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
03P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3o
ool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000
L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@00
0000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<00000
0?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?oo
o`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0
b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000
003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0
c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo
00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo
00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00
001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?oo
o`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo
0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003o
ool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000
B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool0
0`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo
0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<0
00000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@0
00007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D00000
8`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0
oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo
00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<0
00000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@00000
0?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000
000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]
0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3o
ool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3o
ool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0
M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3o
ool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool0
08T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool50000
0780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool40000
07L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L
0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?oo
o`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3o
ool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3o
ool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3o
ool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool0
08`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0
oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo
00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?oo
o`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@00000
0?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00
002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?oo
o`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3o
ool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000
c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@0
00000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]
0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@00
00020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y
0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59769 .67193 m
.61556 .67857 L
s
.60078 .668 m
.59713 .66494 L
s
.60414 .66981 m
.60078 .668 L
s
.62407 .6823 m
.622 .68097 L
s
.62459 .68193 m
.62407 .6823 L
s
.622 .68097 m
.62251 .68059 L
s
.59713 .66494 m
.59474 .66234 L
s
.62251 .68059 m
.62459 .68193 L
s
.59474 .66234 m
.59363 .66021 L
s
.60978 .67132 m
.61315 .67314 L
s
.60691 .66912 m
.60978 .67132 L
s
.61315 .67314 m
.61444 .67362 L
s
.60165 .66431 m
.60691 .66912 L
s
.61444 .67362 m
.61624 .67371 L
s
.59363 .66021 m
.5954 .66028 L
s
.61624 .67371 m
.61517 .6716 L
s
.59877 .6621 m
.60165 .66431 L
s
.5954 .66028 m
.59877 .6621 L
s
.61517 .6716 m
.6128 .66899 L
s
.59059 .65504 m
.5864 .65234 L
s
.5864 .65234 m
.5835 .65011 L
s
.6128 .66899 m
.60912 .6659 L
s
.5835 .65011 m
.58107 .64747 L
s
.60912 .6659 m
.60573 .66408 L
s
.58107 .64747 m
.58073 .64617 L
s
.58073 .64617 m
.58168 .64533 L
s
.60192 .65802 m
.60093 .65882 L
s
.5631 .63444 m
.56099 .63309 L
s
.56355 .63401 m
.5631 .63444 L
s
.56099 .63309 m
.56145 .63265 L
s
.56145 .63265 m
.56355 .63401 L
s
.58168 .64533 m
.58475 .64585 L
s
.60162 .65673 m
.60192 .65802 L
s
.5992 .65408 m
.60162 .65673 L
s
.58475 .64585 m
.58734 .6468 L
s
.57126 .6368 m
.58944 .64337 L
s
.58734 .6468 m
.59205 .6491 L
s
.59628 .65183 m
.5992 .65408 L
s
.59205 .6491 m
.59628 .65183 L
s
.56512 .62917 m
.56983 .63147 L
s
.56216 .62689 m
.56512 .62917 L
s
.55966 .62417 m
.56216 .62689 L
s
.56983 .63147 m
.58287 .63616 L
s
.54644 .61639 m
.57373 .62613 L
s
.55928 .62281 m
.55966 .62417 L
s
.56066 .62147 m
.55928 .62281 L
s
.55177 .61273 m
.55652 .61504 L
s
.54747 .60996 m
.55177 .61273 L
s
.54446 .60764 m
.54747 .60996 L
s
.5419 .60485 m
.54446 .60764 L
s
.55652 .61504 m
.55913 .61597 L
s
.55913 .61597 m
.56222 .61644 L
s
.54149 .60345 m
.5419 .60485 L
s
.54238 .6025 m
.54149 .60345 L
s
.56222 .61644 m
.56315 .61551 L
s
.53847 .60112 m
.56608 .61084 L
s
.56315 .61551 m
.56278 .61412 L
s
.56278 .61412 m
.56023 .61132 L
s
.53243 .59455 m
.5508 .60098 L
s
.56023 .61132 m
.5572 .60899 L
s
.53635 .59592 m
.532 .59312 L
s
.532 .59312 m
.52896 .59077 L
s
.5572 .60899 m
.55286 .60619 L
s
.52896 .59077 m
.52634 .58793 L
s
.52634 .58793 m
.5259 .58648 L
s
.5259 .58648 m
.52677 .58548 L
s
.54775 .59863 m
.54684 .5996 L
s
.52677 .58548 m
.52982 .58589 L
s
.54734 .59719 m
.54775 .59863 L
s
.54474 .59434 m
.54734 .59719 L
s
.51491 .57548 m
.51756 .57837 L
s
.52982 .58589 m
.53246 .5868 L
s
.53246 .5868 m
.53729 .58913 L
s
.54168 .59197 m
.54474 .59434 L
s
.51444 .574 m
.51491 .57548 L
s
.53729 .58913 m
.54168 .59197 L
s
.51529 .57297 m
.51444 .574 L
s
.51046 .57065 m
.52893 .57699 L
s
.51834 .57335 m
.51529 .57297 L
s
.49896 .56204 m
.49455 .5592 L
s
.50247 .56391 m
.49896 .56204 L
s
.49455 .5592 m
.49144 .55679 L
s
.49144 .55679 m
.48781 .55286 L
s
.48781 .55286 m
.4873 .55133 L
s
.4873 .55133 m
.48809 .55024 L
s
.50849 .5626 m
.51299 .56751 L
s
.51695 .56886 m
.51299 .56751 L
s
.51871 .56879 m
.51695 .56886 L
s
.48809 .55024 m
.4898 .55013 L
s
.51957 .56773 m
.51871 .56879 L
s
.4898 .55013 m
.49282 .55047 L
s
.51911 .56621 m
.51957 .56773 L
s
.49282 .55047 m
.49943 .5527 L
s
.5155 .56226 m
.51911 .56621 L
s
.49943 .5527 m
.50431 .55504 L
s
.48601 .54404 m
.50091 .54625 L
s
.51236 .55982 m
.5155 .56226 L
s
.50431 .55504 m
.50788 .55693 L
s
.50788 .55693 m
.51236 .55982 L
s
.47861 .536 m
.50091 .54625 L
s
.47861 .536 m
.49351 .53814 L
s
.47115 .52787 m
.49351 .53814 L
s
.46456 .5207 m
.48322 .52685 L
s
.46853 .52201 m
.46399 .51908 L
s
.46399 .51908 m
.46077 .51658 L
s
.46077 .51658 m
.45791 .51347 L
s
.45791 .51347 m
.45733 .51183 L
s
.45733 .51183 m
.45807 .51061 L
s
.47999 .52434 m
.4792 .52552 L
s
.45807 .51061 m
.46111 .51087 L
s
.47945 .52271 m
.47999 .52434 L
s
.4766 .51959 m
.47945 .52271 L
s
.44542 .49988 m
.44832 .50304 L
s
.46111 .51087 m
.46379 .51174 L
s
.46379 .51174 m
.46876 .5141 L
s
.47336 .51706 m
.4766 .51959 L
s
.44481 .4982 m
.44542 .49988 L
s
.46876 .5141 m
.47336 .51706 L
s
.44553 .49694 m
.44481 .4982 L
s
.44056 .4946 m
.45932 .50063 L
s
.44857 .49717 m
.44553 .49694 L
s
.42643 .48331 m
.43007 .48523 L
s
.42181 .48033 m
.42643 .48331 L
s
.41751 .47669 m
.42181 .48033 L
s
.43007 .48523 m
.43505 .48757 L
s
.41054 .46912 m
.41751 .47669 L
s
.43505 .48757 m
.44173 .48971 L
s
.44173 .48971 m
.44478 .48992 L
s
.41054 .46912 m
.43868 .47798 L
s
.44478 .48992 m
.44649 .48971 L
s
.44649 .48971 m
.44722 .48841 L
s
.44722 .48841 m
.44562 .4856 L
s
.44562 .4856 m
.43868 .47798 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0S0?ooo`80003oJP3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool08`3oool40000ofL0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00@0003oH`3oool00`000000oooo0?ooo`0>0?oo
o`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo02<0oooo00<0003o0?ooo`3oool00`3oool20000of40oooo00<000000?ooo`3o
ool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0
H@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
GP3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo02<0oooo0P000?l50?ooo`030000o`3o
ool0oooo05d0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0603o
ool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool0G03oool010000000oooo0?ooo`3oool300000580oooo00<0
00000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0T
0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`1K0?ooo`@00000E@3oool00`000000oooo0?ooo`0G
0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo02H0oooo0`000?mL0?oo
o`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`0T0?ooo`@0003o
E@3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3o
ool2000006T0oooo00<000000?ooo`3oool09P3oool40000oe00oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0U0?ooo`040000o`3oool0oooo0?ooo`80003oB`3oool3000000/0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<00000
0?ooo`3oool0JP3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo04X0oooo0`00000>
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo06h0oooo0`00000A
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06X0oooo0`00000D
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02D0oooo10000?lm
0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo0080003o>03oool3000001/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`00
0000oooo0?ooo`0U0?ooo`050000o`3oool0oooo0?ooo`000?l0=03oool3000001h0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo02D0oooo0P000?l20?ooo`80003o;P3oool400000240oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo02D0oooo0`000?l20?ooo`030000o`3oool0oooo02P0oooo0`00000U0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000
M03oool00`000000oooo0?ooo`0W0?ooo`<0003o9`3oool3000002P0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool09@3o
ool00`000?l0oooo0?ooo`020000ob<0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool09@3oool20000ob80oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo02H0oooo0P000?lM0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3o
ool0N03oool00`000000oooo0?ooo`0T0?ooo`D0003o603oool3000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
N@3oool00`000000oooo0?ooo`0U0?ooo`D0003o4`3oool3000003L0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo02H0oooo0P000?lA0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0903oool5
0000o``0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0V0?ooo`@0003o1`3oool30000
0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1n0?ooo`030000003oool0oooo02<0oooo0`000?l70?ooo`<00000@`3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo
00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`020000o`80oooo0`0000160?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo0240oooo00D0003o0?ooo`3oool0oooo000000020000odT0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003o
ool0oooo0240oooo00<0003o0000000000000`3oool00`000?l0oooo0?ooo`160?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`0L0?ooo`@0000000<0oooo0000o`3oool0103oool20000odL0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?oo
o`030000003oool0oooo01P0oooo0`0000060?ooo`<0003o00D0oooo0000o`3oool0oooo0000o`16
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000003P3oool010000?l0oooo0?ooo`000?m5
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000004P3oool40000od@0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00`0oooo0`00000D0?ooo`80003oA`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
203oool3000001T0oooo10000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000703o
ool010000?l0oooo0?ooo`3oool20000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<00000803o
ool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`0o0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo02D0oooo0`000?ll0?ooo`<000000P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool09P3oool010000?l0oooo0000o`000?lf0?ooo`@000001P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool09`3oool00`000?l0oooo0?ooo`020000oc40oooo0`00000:0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0W0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0[0?ooo`<000003P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0:@3oool50000obT0oooo0`00000B0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0Z0?ooo`80003o00<0oooo0000o`000?l09@3oool3000001H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02/0oooo0`000?lR0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
:`3oool00`000?l0oooo0?ooo`030000oa`0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0/0?ooo`040000o`3oool0oooo0?ooo`<0003o5`3oool300000280oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02d0oooo00<0003o0?ooo`3oool00P3oool30000oa80oooo0`00000V0?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0
oooo02h0oooo0`000?l20?ooo`030000o`3oool0oooo00h0oooo0`00000Z0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0]0?ooo`80003o0P3oool30000o``0oooo1000000^0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0`0?ooo`80003o303oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo
0`000?l60?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<`3oool01@000?l0oooo0000
o`000?l0oooo00<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<`3oool00`000?l0oooo0000
0002000000030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo10000000
0`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<000000P3oool00`00
0?l0oooo0?ooo`030000ocl0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000060?ooo`03
0000o`3oool0oooo0080oooo0`000?ll0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000
303oool20000od00oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool3000008h0oooo00<000000?ooo`3oool09@3oool300000140oooo10000?lm0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0
oooo0240oooo1000000H0?ooo`80003o?03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
01T0oooo10000?ln0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0
oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000001d0
oooo00<0003o0?ooo`3oool00P000?ll0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01P0oooo0`00000P0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0j0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000V0?ooo`040000
o`3oool0oooo0000oc`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000
;@3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
3`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo00h0oooo0`00000^0?ooo`80003o00<0oooo0000o`3oool0?03oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00/0oooo0`00000b0?ooo`80003o?P3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000003H0oooo0P000?l00`3oool0003o0000o`0k0?ooo`030000003oool0oooo
04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`040?ooo`@00000>P3oool20000o`030?ooo`000?l0oooo03/0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000
003oool0oooo0?ooo`<00000?`3oool40000oc`0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000100?ooo`80003o0`3oool30000oc/0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00150?ooo`<0003o?P3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04H0oooo0P000?lm
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0BP3oool20000ocX0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<0
00002@3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0oooo03T0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000
303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo
0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^
0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`03
0000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000
:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`00
0000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo
0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?oo
o`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?oo
o`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000
B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000
oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo
0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?oo
o`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?oo
o`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
9`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000
oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo
0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?oo
o`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?oo
o`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003o
ool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?oo
o`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?oo
o`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000
003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103o
ool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool20000
08`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0
oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3o
ool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000
103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0
oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool30000
07`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo
0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<0
00000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`30
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3o
ool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo
0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0
000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`00
0000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0
oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<0
00000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo0018
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`00
0000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0
oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?
0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?oo
o`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?oo
o`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0
d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003o
ool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2
000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo
0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?oo
o`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?oo
o`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000
oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo
0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I
0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000
003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03o
ool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5
000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool40000
01/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo
00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00
000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3o
ool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0
X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3o
ool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3o
ool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0
oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3o
ool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003o
ool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0
oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0
oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640
oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo
00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`04
0000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<0
00007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0
oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo
04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940
oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo
002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<00000
0?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?oo
o`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`04
0000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?oo
o`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`80
00003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool0
8P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000
]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3o
ool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3o
ool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3
000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J
0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo
01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0
oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool00000
1P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool2
00000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59583 .67563 m
.61587 .67795 L
s
.60016 .66924 m
.59634 .66649 L
s
.60382 .67043 m
.60016 .66924 L
s
.62532 .67981 m
.62309 .67879 L
s
.62599 .67912 m
.62532 .67981 L
s
.62309 .67879 m
.62376 .6781 L
s
.62376 .6781 m
.62599 .67912 L
s
.59634 .66649 m
.59395 .6639 L
s
.59395 .6639 m
.593 .66146 L
s
.61025 .67039 m
.61393 .67158 L
s
.60722 .6685 m
.61025 .67039 L
s
.61393 .67158 m
.61538 .67174 L
s
.60181 .664 m
.60722 .6685 L
s
.61538 .67174 m
.61749 .67121 L
s
.593 .66146 m
.59508 .66091 L
s
.61749 .67121 m
.61658 .66878 L
s
.59877 .6621 m
.60181 .664 L
s
.59508 .66091 m
.59877 .6621 L
s
.61658 .66878 m
.61421 .66617 L
s
.61421 .66617 m
.61038 .66339 L
s
.59027 .65566 m
.58577 .65359 L
s
.58577 .65359 m
.5827 .65168 L
s
.61038 .66339 m
.60667 .66219 L
s
.5827 .65168 m
.58027 .64904 L
s
.58027 .64904 m
.58009 .64742 L
s
.60319 .65549 m
.60188 .65694 L
s
.58009 .64742 m
.58136 .64596 L
s
.56116 .63821 m
.5589 .63717 L
s
.56178 .63747 m
.56116 .63821 L
s
.5589 .63717 m
.55951 .63642 L
s
.60305 .65389 m
.60319 .65549 L
s
.58136 .64596 m
.58491 .64554 L
s
.55951 .63642 m
.56178 .63747 L
s
.60064 .65123 m
.60305 .65389 L
s
.58491 .64554 m
.58782 .64585 L
s
.58782 .64585 m
.59301 .64721 L
s
.59756 .6493 m
.60064 .65123 L
s
.57046 .63838 m
.59089 .64052 L
s
.59301 .64721 m
.59756 .6493 L
s
.56447 .63044 m
.56967 .63179 L
s
.56135 .62848 m
.56447 .63044 L
s
.55884 .62576 m
.56135 .62848 L
s
.56967 .63179 m
.58433 .63329 L
s
.54447 .62019 m
.5752 .62325 L
s
.55863 .62408 m
.55884 .62576 L
s
.56049 .62178 m
.55863 .62408 L
s
.55143 .61337 m
.55669 .61472 L
s
.54681 .61123 m
.55143 .61337 L
s
.54364 .60924 m
.54681 .61123 L
s
.54107 .60645 m
.54364 .60924 L
s
.55669 .61472 m
.55963 .61501 L
s
.55963 .61501 m
.56321 .61451 L
s
.54082 .60473 m
.54107 .60645 L
s
.56321 .61451 m
.56448 .61294 L
s
.54205 .60314 m
.54082 .60473 L
s
.53764 .60272 m
.56875 .60566 L
s
.56448 .61294 m
.56427 .61122 L
s
.56427 .61122 m
.56172 .60842 L
s
.53159 .59616 m
.55231 .59807 L
s
.56172 .60842 m
.55853 .60641 L
s
.55853 .60641 m
.55386 .60425 L
s
.53601 .59656 m
.53133 .59441 L
s
.53133 .59441 m
.52812 .59238 L
s
.52812 .59238 m
.5255 .58954 L
s
.5255 .58954 m
.52523 .58777 L
s
.5491 .59604 m
.54785 .59766 L
s
.52523 .58777 m
.52643 .58613 L
s
.54886 .59427 m
.5491 .59604 L
s
.52643 .58613 m
.52999 .58557 L
s
.54626 .59141 m
.54886 .59427 L
s
.51405 .5771 m
.51671 .57999 L
s
.52999 .58557 m
.53296 .58583 L
s
.53296 .58583 m
.5383 .58719 L
s
.54303 .58937 m
.54626 .59141 L
s
.5383 .58719 m
.54303 .58937 L
s
.51376 .5753 m
.51405 .5771 L
s
.51494 .57362 m
.51376 .5753 L
s
.50961 .57227 m
.53047 .57405 L
s
.51851 .57303 m
.51494 .57362 L
s
.49741 .56496 m
.49265 .56277 L
s
.50127 .56619 m
.49741 .56496 L
s
.49265 .56277 m
.48937 .56069 L
s
.48937 .56069 m
.48573 .55676 L
s
.48573 .55676 m
.48539 .55491 L
s
.50866 .56227 m
.51316 .56718 L
s
.51764 .56755 m
.51316 .56718 L
s
.48539 .55491 m
.48652 .55317 L
s
.51974 .56682 m
.51764 .56755 L
s
.48652 .55317 m
.48858 .55242 L
s
.52095 .5651 m
.51974 .56682 L
s
.48858 .55242 m
.49213 .55178 L
s
.52066 .56326 m
.52095 .5651 L
s
.49213 .55178 m
.4996 .55237 L
s
.51706 .5593 m
.52066 .56326 L
s
.4996 .55237 m
.50501 .55372 L
s
.51375 .55719 m
.51706 .5593 L
s
.48513 .54568 m
.5025 .54327 L
s
.50501 .55372 m
.50893 .55496 L
s
.50893 .55496 m
.51375 .55719 L
s
.47773 .53764 m
.5025 .54327 L
s
.47773 .53764 m
.49511 .53515 L
s
.47026 .52953 m
.49511 .53515 L
s
.46366 .52236 m
.48483 .52384 L
s
.46817 .52268 m
.46327 .52041 L
s
.46327 .52041 m
.45987 .51824 L
s
.45987 .51824 m
.45701 .51513 L
s
.45701 .51513 m
.45661 .51316 L
s
.48143 .52167 m
.48027 .52352 L
s
.45661 .51316 m
.45771 .51128 L
s
.48107 .5197 m
.48143 .52167 L
s
.45771 .51128 m
.46129 .51054 L
s
.47823 .51657 m
.48107 .5197 L
s
.44451 .50155 m
.44741 .50471 L
s
.46129 .51054 m
.46433 .51074 L
s
.46433 .51074 m
.46985 .51209 L
s
.4748 .51438 m
.47823 .51657 L
s
.46985 .51209 m
.4748 .51438 L
s
.44408 .49954 m
.44451 .50155 L
s
.44517 .49762 m
.44408 .49954 L
s
.43965 .49627 m
.46097 .49759 L
s
.44875 .49684 m
.44517 .49762 L
s
.42477 .48633 m
.42878 .48758 L
s
.41978 .48402 m
.42477 .48633 L
s
.41529 .48071 m
.41978 .48402 L
s
.42878 .48758 m
.43431 .48892 L
s
.43431 .48892 m
.44191 .48937 L
s
.4083 .47316 m
.41529 .48071 L
s
.44191 .48937 m
.44552 .48857 L
s
.4083 .47316 m
.44036 .47492 L
s
.44552 .48857 m
.4476 .48768 L
s
.4476 .48768 m
.4487 .4857 L
s
.4487 .4857 m
.44729 .48254 L
s
.44729 .48254 m
.44036 .47492 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0803oool=0000
of00oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0P0?ooo`80003o2P3oool00`000?l0
oooo0?ooo`1M0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool08@3oool00`000?l0oooo
0?ooo`080?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool01`3oool3000004/0oooo
00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`0P0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo0200oooo0`000?l80?ooo`030000o`3oool0oooo05/0oooo00@00000
0?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0
oooo06@0oooo00<000000?ooo`3oool08P3oool50000o`80oooo0P000?mM0?ooo`@00000E@3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
02H0oooo0P000?mM0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`0T0?ooo`@0003oE@3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool09@3oool20000o`030?ooo`00
0?l0003o00<0003oC@3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo02D0oooo00<0003o
0?ooo`3oool0CP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0U0?oo
o`030000o`3oool0oooo04X0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?oo
o`030000003oool0oooo06h0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0?`3oool3000001@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06h0oooo00<000000?ooo`3oool09@3oool20000o`040?ooo`000?l0003o
0000oc/0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo02@0oooo00<0003o0?ooo`3oool00`3oool20000ocH0oooo0`00000K0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0300oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0T0?ooo`80003o1@3oool00`000?l0
oooo0?ooo`0[0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0903oool90000obP0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`1A0?ooo`<00000:03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=
0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?oo
o`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo02<0oooo0`000?lS0?oo
o`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0U0?ooo`@0
003o703oool300000340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
:03oool30000oaH0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool08`3o
ool40000oaH0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0U0?ooo`@0003o403oool3
000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo02P0oooo0`000?l:0?ooo`<00000?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool08`3oool40000o`X0oooo0`0000100?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<00000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool08@3oool60000o`80oooo0`00
00160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`000021
0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool00P3oool00`000000003o0000o`02
0000odL0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`210?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`0000000P0000050?oo
o`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo0`0000000`000?l0
oooo0?ooo`070?ooo`80003oA@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000000@0oooo
0P000?l50?ooo`050000o`3oool0oooo0?ooo`000?l0A03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
503oool3000000T0oooo0`000?l20?ooo`050000o`3oool0oooo0?ooo`000?l0A03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0403oool300000180oooo0`000?m50?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?oo
o`0<0?ooo`<00000G@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001L0oooo2@000?m0
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000006`3oool20000odH0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00<00000803oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<0
00000?ooo`3oool09P3oool00`000?l0oooo0?ooo`0n0?ooo`800000F`3oool00`000000oooo0?oo
o`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02D0oooo00<0003o
0?ooo`000?l00`000?li0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0380oooo100000060?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`0V0?ooo`030000o`3oool0oooo00<0oooo0P000?l_0?ooo`<000002P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09`3oool40000o`<0oooo00<0003o0?ooo`3oool0:@3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02P0oooo0P000?l00`3oool0003o0000o`030000obL0oooo0`00
000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0:@3oool70000ob00oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`04
0000o`3oool0oooo0?ooo`L0003o5`3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0E0?ooo`<000008P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0;@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo
0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00
002?0?ooo`030000003oool0oooo02h0oooo1P000?l@0?ooo`<00000:P3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo0`000?l>0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0<03oool60000o`D0oooo0`00000f0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0b0?ooo`040000o`3oool0oooo0?ooo`80003o0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0c0?ooo`030000o`3oool0000000800000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`000004
0?ooo`P0003o>`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000D0oooo00<0003o0?oo
o`3oool0@P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000L0oooo0P000?l30?ooo`@0
003o?P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000
SP3oool00`000000oooo0?ooo`0U0?ooo`<000004`3oool40000oc/0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000J0?ooo`D0003o?03oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000L0?ooo`030000o`3oool0oooo
00<0oooo0P000?lj0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00000P0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000903oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0A0?ooo`@00000:03oool20000o`<0oooo0P000?lk0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool02`3oool300000340oooo0`000?l20?ooo`030000o`3oool0oooo03T0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00P0oooo0`00000d0?ooo`040000o`3oool0oooo0000o`80oooo00<0003o
0?ooo`3oool0>@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000003P0oooo00<0003o0?oo
o`3oool00P000?l00`3oool0003o0000o`0j0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
03d0oooo0`000?l01@3oool0003o0?ooo`3oool0003o03X0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000150?ooo`80003o?03oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool300000480
oooo10000?m00?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0A03oool50000o`030?oo
o`000?l0003o03T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`1;0?ooo`030000o`3o
ool0oooo03P0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool30000
02/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?oo
o`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3o
ool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool30000
04/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?oo
o`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0
oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00
002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00
001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0
oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo
0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0013
0?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00
B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;
0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003o
ool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo
0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?oo
o`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003o
ool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0
f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`00
0000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0
oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo
1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000
000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?oo
o`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`80
0000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0
oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo
0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0
oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0
oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0
oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo
0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M
0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q
0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?oo
o`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3
000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo
0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A
0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?oo
o`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000
003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303o
ool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03o
ool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2
000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo
0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool50000
0;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0
oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0
oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo
0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:
0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo0000
00H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo
0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.5947 .67942 m
.61606 .67731 L
s
.62605 .67726 m
.62374 .67655 L
s
.62682 .67625 m
.62605 .67726 L
s
.62374 .67655 m
.6245 .67555 L
s
.59978 .67052 m
.59587 .66809 L
s
.60364 .67107 m
.59978 .67052 L
s
.6245 .67555 m
.62682 .67625 L
s
.59587 .66809 m
.59348 .66549 L
s
.61053 .66943 m
.6144 .66998 L
s
.60741 .66786 m
.61053 .66943 L
s
.59348 .66549 m
.59262 .66273 L
s
.6144 .66998 m
.61594 .66983 L
s
.61594 .66983 m
.61824 .66865 L
s
.6019 .66368 m
.60741 .66786 L
s
.61824 .66865 m
.61743 .66589 L
s
.59262 .66273 m
.59489 .66155 L
s
.59877 .6621 m
.6019 .66368 L
s
.59489 .66155 m
.59877 .6621 L
s
.61743 .66589 m
.61506 .66328 L
s
.61506 .66328 m
.61113 .66083 L
s
.61113 .66083 m
.60724 .66027 L
s
.59008 .65631 m
.58538 .65488 L
s
.58538 .65488 m
.58222 .65328 L
s
.58222 .65328 m
.57979 .65064 L
s
.57979 .65064 m
.5797 .64871 L
s
.60396 .65292 m
.60245 .65501 L
s
.5797 .64871 m
.58117 .64661 L
s
.60391 .65099 m
.60396 .65292 L
s
.55998 .64206 m
.55762 .64134 L
s
.5607 .641 m
.55998 .64206 L
s
.58117 .64661 m
.585 .64522 L
s
.55762 .64134 m
.55833 .64028 L
s
.6015 .64833 m
.60391 .65099 L
s
.55833 .64028 m
.5607 .641 L
s
.585 .64522 m
.58811 .64488 L
s
.59832 .64672 m
.6015 .64833 L
s
.58811 .64488 m
.59359 .64527 L
s
.59359 .64527 m
.59832 .64672 L
s
.56997 .63999 m
.59177 .6376 L
s
.56407 .63173 m
.56957 .63211 L
s
.56085 .63009 m
.56407 .63173 L
s
.56957 .63211 m
.58521 .63037 L
s
.55834 .62737 m
.56085 .63009 L
s
.55823 .62538 m
.55834 .62737 L
s
.54327 .62407 m
.57609 .62032 L
s
.56039 .62211 m
.55823 .62538 L
s
.55123 .61402 m
.55679 .61439 L
s
.5464 .61253 m
.55123 .61402 L
s
.54313 .61087 m
.5464 .61253 L
s
.55679 .61439 m
.55993 .61403 L
s
.54056 .60808 m
.54313 .61087 L
s
.55993 .61403 m
.56381 .61255 L
s
.54042 .60604 m
.54056 .60808 L
s
.56381 .61255 m
.56528 .61032 L
s
.54184 .60379 m
.54042 .60604 L
s
.53713 .60436 m
.57037 .60039 L
s
.56528 .61032 m
.56517 .60828 L
s
.56517 .60828 m
.56263 .60547 L
s
.56263 .60547 m
.55935 .60379 L
s
.53108 .59779 m
.55323 .59511 L
s
.55935 .60379 m
.55447 .60229 L
s
.5358 .59722 m
.53092 .59572 L
s
.53092 .59572 m
.5276 .59402 L
s
.5276 .59402 m
.52498 .59118 L
s
.52498 .59118 m
.52481 .58908 L
s
.54992 .5934 m
.54846 .59569 L
s
.52481 .58908 m
.52622 .58678 L
s
.54978 .59131 m
.54992 .5934 L
s
.52622 .58678 m
.5301 .58524 L
s
.54719 .58844 m
.54978 .59131 L
s
.5301 .58524 m
.53328 .58484 L
s
.54386 .58673 m
.54719 .58844 L
s
.51352 .57875 m
.51618 .58163 L
s
.53328 .58484 m
.53893 .58521 L
s
.53893 .58521 m
.54386 .58673 L
s
.51333 .57662 m
.51352 .57875 L
s
.51473 .57428 m
.51333 .57662 L
s
.50907 .57392 m
.53142 .57106 L
s
.51862 .5727 m
.51473 .57428 L
s
.49644 .56794 m
.49146 .5664 L
s
.50052 .5685 m
.49644 .56794 L
s
.49146 .5664 m
.48806 .56466 L
s
.48806 .56466 m
.48442 .56074 L
s
.48442 .56074 m
.48418 .55856 L
s
.50877 .56194 m
.51326 .56685 L
s
.51807 .56622 m
.51326 .56685 L
s
.52038 .56483 m
.51807 .56622 L
s
.48418 .55856 m
.48554 .55616 L
s
.52181 .56244 m
.52038 .56483 L
s
.48554 .55616 m
.48781 .55475 L
s
.52163 .56025 m
.52181 .56244 L
s
.48781 .55475 m
.49169 .55311 L
s
.51803 .55629 m
.52163 .56025 L
s
.49169 .55311 m
.49971 .55204 L
s
.51461 .55452 m
.51803 .55629 L
s
.49971 .55204 m
.50545 .55239 L
s
.50958 .55295 m
.51461 .55452 L
s
.50545 .55239 m
.50958 .55295 L
s
.48458 .54735 m
.50348 .54025 L
s
.47717 .53931 m
.50348 .54025 L
s
.47717 .53931 m
.49611 .53211 L
s
.4697 .5312 m
.49611 .53211 L
s
.4631 .52404 m
.48585 .5208 L
s
.46795 .52335 m
.46282 .52175 L
s
.46282 .52175 m
.4593 .51992 L
s
.4593 .51992 m
.45644 .51682 L
s
.45644 .51682 m
.45615 .51451 L
s
.48233 .51896 m
.48095 .5215 L
s
.45615 .51451 m
.45748 .51196 L
s
.48208 .51665 m
.48233 .51896 L
s
.45748 .51196 m
.46141 .5102 L
s
.47925 .51352 m
.48208 .51665 L
s
.46141 .5102 m
.46467 .50972 L
s
.47571 .51167 m
.47925 .51352 L
s
.44393 .50325 m
.44683 .5064 L
s
.46467 .50972 m
.47053 .51005 L
s
.47053 .51005 m
.47571 .51167 L
s
.44362 .5009 m
.44393 .50325 L
s
.44493 .49829 m
.44362 .5009 L
s
.43906 .49797 m
.46202 .49452 L
s
.44887 .4965 m
.44493 .49829 L
s
.42371 .48939 m
.42795 .48996 L
s
.41847 .48775 m
.42371 .48939 L
s
.42795 .48996 m
.43384 .49028 L
s
.41386 .48479 m
.41847 .48775 L
s
.43384 .49028 m
.44203 .48903 L
s
.40685 .47725 m
.41386 .48479 L
s
.44203 .48903 m
.44599 .4872 L
s
.44599 .4872 m
.4483 .48562 L
s
.40685 .47725 m
.44143 .47182 L
s
.4483 .48562 m
.44965 .48296 L
s
.44965 .48296 m
.44835 .47945 L
s
.44835 .47945 m
.44143 .47182 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`0[0?ooo`<0003oH03oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
02@0oooo1P000?l30?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0O0?ooo`@0003o2P3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo00X0
oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo05/0oooo
00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00`0oooo00<0
003o0?ooo`3oool0FP3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01h0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1K0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo01h0oooo0P000?l70?ooo`<0003oGP3oool4000005D0oooo00<000000?ooo`3oool05`3oool0
02/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0O0?ooo`L0003oG`3oool30000
05P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`210?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool09`3oool00`000?l0oooo
0000o`030000oe00oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02@0oooo1@000?mA0?ooo`<00000203o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`1?0?ooo`<000002`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0C03oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`180?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0X0?ooo`@0003o?P3oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
06h0oooo00<000000?ooo`3oool09@3oool20000o`@0oooo0P000?li0?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo
00D0oooo0P000?ld0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0^0?ooo`<000007P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo
00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`060?ooo`80003o:`3oool400000240oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?oo
o`1b0?ooo`030000003oool0oooo02<0oooo0`000?l00`3oool0003o0000o`020000obX0oooo0`00
000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<00000
0?ooo`000000M03oool00`000000oooo0?ooo`0S0?ooo`<0003o:`3oool3000002P0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?oo
o`3oool0C@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0S0?ooo`D0
003o8@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
1@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
9`3oool60000oaP0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003o
ool0oooo02H0oooo10000?lG0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0
oooo02<0oooo1@000?lE0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool09`3oool60000
o``0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0V0?ooo`@0003o2`3oool3000003d0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo02<0oooo0P000?l<0?ooo`<00000@03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<0
00000?ooo`3oool0;@3oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02<0oooo20000?l0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo0`0000210?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0oooo0`000002
0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool07P3oool20000o`040?ooo`0000000000
000000L0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool01000
0000003o00000000000;0?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo
01P0oooo0`0000020?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`14
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000001P3oool20000o`L0oooo10000?m40?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000002`3oool30000od`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00`0oooo0`00000I0?ooo`@0003o@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203o
ool3000001L0oooo1@000?m40?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000006`3oool0
0`000?l0oooo0?ooo`150?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000001h0oooo00<0003o0?oo
o`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo08`0oooo0P00000R0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool0
9`3oool40000oc`0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool09@3oool20000o`@0oooo0P000?lg0?ooo`<000000P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0300oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0;03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0
oooo0P000?l40?ooo`@0003o:P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo
1@000?l[0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<03oool70000oad0oooo0`00
000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`T0003o7P3oool4000001X0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool01@3oool20000oaT0oooo0`00000N0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool04`3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0@0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0/0?ooo`P0003o403o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000000^0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0f0?ooo`@0003o103oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0300
oooo1P000?l50?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;03oool40000o`80oooo
00<0003o0?ooo`3oool00`3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0380oooo00<0
003o0?ooo`3oool00`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@000001@3oool3
0000ocX0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000030?ooo`H0003o?P3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo
0`00000@0?ooo`D0003o>@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo
000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000002P3oool20000o`80oooo1@00
0?lo0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@
0?ooo`030000003oool0oooo0240oooo1000000>0?ooo`030000o`3oool0oooo04D0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01h0oooo0`00000J0?ooo`L0003o>P3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01/0oooo0`00000L0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0=`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<0
00007`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03L0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000002<0oooo0P000?l60?ooo`030000
o`3oool0oooo03P0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000:03o
ool20000od00oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3
000003<0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00/0oooo0`00000a0?ooo`<0003o0`3oool30000ocP0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0
oooo0`00000d0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0=P3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0103oool4000003P0oooo00<0003o0?ooo`3oool00P000?l30?ooo`03
0000o`3oool0oooo03L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000?@3oool30000o`03
0?ooo`000?l0003o0080003o>P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0
oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool200000900oooo0`00001<0?ooo`<0003o=`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo04D0oooo10000?l20?ooo`030000o`3oool0oooo03L0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?oo
o`@000001@3oool00`000000oooo0?ooo`100?ooo`D0003o@@3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3o
ool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3o
ool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0
oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3o
ool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0
oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<0
0000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3o
ool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?oo
o`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<0
0000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D00000
0P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`00
3@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool01000
0000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`
0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo
000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo
00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?oo
o`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?oo
o`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@0
00000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool0
3`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool0
10000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`00
0000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?oo
o`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80
000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T
0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?oo
o`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@0
00002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3o
ool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000
oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo
0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000
000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/
0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?oo
o`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000
003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3o
ool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3o
ool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03o
ool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2
000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0
oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0
oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo
00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?oo
o`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]
0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D0
0000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000
P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03o
ool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`00
0000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0
oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?oo
o`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?oo
o`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h
0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?oo
o`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@0
0000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3o
ool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3o
ool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003o
ool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0
oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo
0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000
d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3o
ool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The following swings the normal vector of the text plane around toward the \
west.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Phi]frame[\(-\[Pi]\)/3, \[Pi]/2]\)[\[Phi]], {\[Phi], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71673 .59907 m
.71918 .58396 L
s
.63627 .59886 m
.63457 .59776 L
s
.63822 .59782 m
.63627 .59886 L
s
.63651 .59672 m
.63822 .59782 L
s
.63457 .59776 m
.63651 .59672 L
s
.60166 .59724 m
.60376 .57441 L
s
.48633 .5954 m
.479 .59528 L
s
.49002 .59438 m
.48633 .5954 L
s
.479 .59528 m
.47535 .59415 L
s
.49375 .59229 m
.49002 .59438 L
s
.47535 .59415 m
.47171 .59193 L
s
.34318 .59312 m
.34863 .59213 L
s
.33032 .59291 m
.34318 .59312 L
s
.33032 .59291 m
.32866 .56996 L
s
.49564 .59016 m
.49375 .59229 L
s
.34863 .59213 m
.35218 .59003 L
s
.47171 .59193 m
.4699 .58974 L
s
.69595 .5912 m
.69045 .59111 L
s
.70162 .5902 m
.69595 .5912 L
s
.69045 .59111 m
.6851 .58994 L
s
.66477 .5907 m
.65927 .59061 L
s
.66859 .58967 m
.66477 .5907 L
s
.65927 .59061 m
.65573 .58947 L
s
.63725 .59026 m
.63897 .57498 L
s
.70379 .58807 m
.70162 .5902 L
s
.35218 .59003 m
.3539 .58789 L
s
.6851 .58994 m
.68357 .58774 L
s
.61705 .58993 m
.62083 .58891 L
s
.61154 .58984 m
.61705 .58993 L
s
.60797 .5887 m
.61154 .58984 L
s
.4699 .58974 m
.4681 .58646 L
s
.67255 .58757 m
.66859 .58967 L
s
.65573 .58947 m
.65233 .58724 L
s
.57847 .58931 m
.58223 .58829 L
s
.57296 .58923 m
.57847 .58931 L
s
.56936 .58808 m
.57296 .58923 L
s
.5656 .58911 m
.56721 .56605 L
s
.62083 .58891 m
.62301 .58568 L
s
.55273 .5889 m
.55368 .5736 L
s
.54538 .58879 m
.53986 .5887 L
s
.54912 .58776 m
.54538 .58879 L
s
.60275 .58536 m
.60797 .5887 L
s
.53986 .5887 m
.53624 .58755 L
s
.51595 .58831 m
.52147 .5884 L
s
.51231 .58717 m
.51595 .58831 L
s
.58223 .58829 m
.58609 .58618 L
s
.50675 .58817 m
.50727 .57285 L
s
.56583 .58585 m
.56936 .58808 L
s
.3539 .58789 m
.35556 .58466 L
s
.55294 .58565 m
.54912 .58776 L
s
.68357 .58774 m
.68572 .5856 L
s
.53624 .58755 m
.53267 .58532 L
s
.45703 .58737 m
.44966 .57192 L
s
.65233 .58724 m
.65088 .58395 L
s
.5087 .58494 m
.51231 .58717 L
s
.44229 .58713 m
.44966 .57192 L
s
.44229 .58713 m
.43479 .57168 L
s
.42755 .5869 m
.43479 .57168 L
s
.41465 .58669 m
.41432 .57135 L
s
.40727 .58657 m
.40174 .58648 L
s
.41093 .58555 m
.40727 .58657 L
s
.40174 .58648 m
.39802 .58534 L
s
.4681 .58646 m
.46816 .58101 L
s
.37776 .5861 m
.3833 .58619 L
s
.58609 .58618 m
.5882 .58294 L
s
.37402 .58495 m
.37776 .5861 L
s
.36854 .58595 m
.36779 .57059 L
s
.62301 .58568 m
.62415 .57474 L
s
.68572 .5856 m
.68956 .58457 L
s
.41458 .58343 m
.41093 .58555 L
s
.39802 .58534 m
.39425 .5831 L
s
.53267 .58532 m
.53098 .58202 L
s
.37023 .58272 m
.37402 .58495 L
s
.50697 .58164 m
.5087 .58494 L
s
.35556 .58466 m
.35525 .5792 L
s
.68956 .58457 m
.69893 .58363 L
s
.65088 .58395 m
.65114 .58177 L
s
.69893 .58363 m
.70277 .5826 L
s
.39425 .5831 m
.39229 .57979 L
s
.5882 .58294 m
.58838 .58076 L
s
.36822 .5794 m
.37023 .58272 L
s
.70277 .5826 m
.70495 .58044 L
s
.53098 .58202 m
.53109 .57983 L
s
.65114 .58177 m
.65339 .57851 L
s
.48664 .58131 m
.49588 .58146 L
s
.49597 .57817 m
.49588 .58146 L
s
.46816 .58101 m
.47005 .57775 L
s
.58838 .58076 m
.5868 .57744 L
s
.70495 .58044 m
.70512 .57935 L
s
.53109 .57983 m
.5331 .57657 L
s
.39229 .57979 m
.39222 .5776 L
s
.70512 .57935 m
.70361 .57712 L
s
.35525 .5792 m
.3532 .57587 L
s
.68696 .57685 m
.6848 .57902 L
s
.67031 .57659 m
.67372 .57884 L
s
.65339 .57851 m
.65736 .57638 L
s
.72209 .57742 m
.72007 .57849 L
s
.72007 .57849 m
.7184 .57736 L
s
.49418 .57594 m
.49597 .57817 L
s
.47005 .57775 m
.47193 .57559 L
s
.39222 .5776 m
.39396 .57433 L
s
.5868 .57744 m
.58328 .57518 L
s
.72042 .57629 m
.72209 .57742 L
s
.7184 .57736 m
.72042 .57629 L
s
.70361 .57712 m
.69822 .57593 L
s
.5703 .57497 m
.56644 .57711 L
s
.54991 .57464 m
.55348 .5769 L
s
.69267 .57584 m
.68696 .57685 L
s
.66676 .57543 m
.67031 .57659 L
s
.5331 .57657 m
.53692 .57443 L
s
.65736 .57638 m
.6612 .57534 L
s
.49053 .57368 m
.49418 .57594 L
s
.69822 .57593 m
.69267 .57584 L
s
.3532 .57587 m
.35122 .57364 L
s
.47193 .57559 m
.47567 .57344 L
s
.6612 .57534 m
.66676 .57543 L
s
.58328 .57518 m
.57966 .57402 L
s
.57409 .57393 m
.5703 .57497 L
s
.41063 .57239 m
.41439 .57466 L
s
.54626 .57348 m
.54991 .57464 L
s
.53692 .57443 m
.54069 .57339 L
s
.39396 .57433 m
.39761 .57218 L
s
.57966 .57402 m
.57409 .57393 L
s
.48684 .57252 m
.49053 .57368 L
s
.35122 .57364 m
.34736 .57137 L
s
.54069 .57339 m
.54626 .57348 L
s
.47567 .57344 m
.4794 .5724 L
s
.4794 .5724 m
.48684 .57252 L
s
.40688 .57123 m
.41063 .57239 L
s
.39761 .57218 m
.4013 .57113 L
s
.34736 .57137 m
.34171 .57017 L
s
.4013 .57113 m
.40688 .57123 L
s
.34171 .57017 m
.32866 .56996 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000008`3oool00`000?l0oooo0?ooo`0a
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000009P3oool00`000?l0oooo0?ooo`0a0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0J@3oool80000o`L0oooo00<0003o0?ooo`3oool0203oool50000o`030?ooo`000?l0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool00`000000003o0000000Y0?ooo`030000o`3oool0oooo0340
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo
0?ooo`1Y0?ooo`030000o`3oool0oooo00D0oooo0P000?l50?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool00`3oool20000o`H0oooo0P000?l0103oool000000000000000020000o`P0
oooo1`000?l50?ooo`030000o`3oool0oooo00P0oooo1`000?l40?ooo`030000o`3oool0oooo00<0
003o203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01/0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l000000000o`030?ooo`030000
o`3oool0003o00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`<0003o
0`3oool30000o`D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo1P000?l50?ooo`L0003o00<000000?ooo`3oool00P3oool20000oe@0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`040000o`000000oooo0?ooo`80000000@0003o0?ooo`3oool0003o0P3oool010000?l0
oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`08
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3o
ool0003o00L0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`020?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0
000000000080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool00`000?l000000?ooo`1I0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`800000K03oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`000?l01`3oool20000o`@0oooo0P000?l01@3oool00000
0?ooo`3oool0003o00@0oooo0P000?l40?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool20000
o`L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`H0003o0P0000040?oo
o`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool010000?l50?ooo`@0003o00@0oooo0000o`3oool000000P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0
003o00L0oooo0P000?l40?ooo`80003o103oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0000o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool3000000030000o`3o
ool0000000<0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05P3oool0
0`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool3
0000o`H0oooo10000?l00`3oool0003o0?ooo`030?ooo`030000o`3oool0003o00@0003o1P3oool0
0`000?l0oooo0?ooo`050000o`H0oooo00<0003o0?ooo`3oool00`3oool70000o`@0oooo10000002
0?ooo`80003o0P3oool010000000oooo0?ooo`000?mF0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo06/0oooo20000?lI0?ooo`030000003oool0oooo0140oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo01T0oooo0`000000
0`3oool0003o0000o`030000o`@0oooo00<000000?ooo`000?l0E`3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0180oooo1`000?lX0?oo
o`030000o`3oool0oooo01H0oooo0`00000>0?ooo`03000000000?l0oooo05H0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`110?ooo`03
0000o`3oool0oooo00X0oooo0P000?l70?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
E03oool3000001D0oooo00<0003o0000003oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0500oooo1000000J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`1=0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0BP3oool30000
0280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo04L0oooo0`00000V0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo
0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
04X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool30000
07H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo
0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00
803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<0
0000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71701 .6025 m
.71914 .58338 L
s
.63645 .60257 m
.63473 .60119 L
s
.63839 .60125 m
.63645 .60257 L
s
.63666 .59986 m
.63839 .60125 L
s
.63473 .60119 m
.63666 .59986 L
s
.60178 .60066 m
.60367 .57183 L
s
.48629 .59883 m
.47895 .59871 L
s
.48999 .59752 m
.48629 .59883 L
s
.47895 .59871 m
.4753 .59729 L
s
.49372 .59486 m
.48999 .59752 L
s
.4753 .59729 m
.47166 .5945 L
s
.34295 .59655 m
.34842 .59527 L
s
.33006 .59634 m
.34295 .59655 L
s
.33006 .59634 m
.32886 .56738 L
s
.49563 .59215 m
.49372 .59486 L
s
.69606 .59262 m
.69055 .59254 L
s
.7017 .59135 m
.69606 .59262 L
s
.47166 .5945 m
.46986 .59174 L
s
.69055 .59254 m
.68518 .59108 L
s
.34842 .59527 m
.35201 .5926 L
s
.66486 .59212 m
.65935 .59204 L
s
.66865 .59082 m
.66486 .59212 L
s
.65935 .59204 m
.6558 .59061 L
s
.70383 .58864 m
.7017 .59135 L
s
.63731 .59168 m
.63885 .5724 L
s
.68518 .59108 m
.68361 .58831 L
s
.61711 .59136 m
.62088 .59005 L
s
.61159 .59127 m
.61711 .59136 L
s
.67258 .58814 m
.66865 .59082 L
s
.60801 .58985 m
.61159 .59127 L
s
.6558 .59061 m
.65236 .58781 L
s
.46986 .59174 m
.46807 .5876 L
s
.5785 .59074 m
.58226 .58943 L
s
.57299 .59065 m
.5785 .59074 L
s
.35201 .5926 m
.35377 .58989 L
s
.56938 .58923 m
.57299 .59065 L
s
.56563 .59054 m
.56712 .56147 L
s
.62088 .59005 m
.62302 .58597 L
s
.55275 .59033 m
.55365 .57102 L
s
.60276 .58564 m
.60801 .58985 L
s
.54539 .59021 m
.53987 .59012 L
s
.54914 .5889 m
.54539 .59021 L
s
.53987 .59012 m
.53625 .5887 L
s
.58226 .58943 m
.5861 .58675 L
s
.51595 .58974 m
.52147 .58983 L
s
.51231 .58831 m
.51595 .58974 L
s
.68361 .58831 m
.68572 .5856 L
s
.56584 .58643 m
.56938 .58923 L
s
.50674 .58959 m
.50728 .57027 L
s
.55294 .58622 m
.54914 .5889 L
s
.65236 .58781 m
.65087 .58366 L
s
.53625 .5887 m
.53267 .58589 L
s
.35377 .58989 m
.35548 .5858 L
s
.457 .5888 m
.44973 .56934 L
s
.5087 .58551 m
.51231 .58831 L
s
.44225 .58856 m
.44973 .56934 L
s
.44225 .58856 m
.43487 .5691 L
s
.4275 .58833 m
.43487 .5691 L
s
.5861 .58675 m
.58819 .58266 L
s
.41459 .58812 m
.41443 .56877 L
s
.46807 .5876 m
.46816 .58073 L
s
.40721 .588 m
.40167 .58791 L
s
.41089 .58669 m
.40721 .588 L
s
.68572 .5856 m
.68954 .58429 L
s
.40167 .58791 m
.39796 .58648 L
s
.62302 .58597 m
.62404 .57216 L
s
.37768 .58753 m
.38322 .58762 L
s
.37396 .5861 m
.37768 .58753 L
s
.36845 .58738 m
.36794 .56802 L
s
.53267 .58589 m
.53098 .58174 L
s
.41455 .584 m
.41089 .58669 L
s
.68954 .58429 m
.69888 .58306 L
s
.39796 .58648 m
.39423 .58367 L
s
.50697 .58135 m
.5087 .58551 L
s
.37019 .58329 m
.37396 .5861 L
s
.65087 .58366 m
.6511 .58091 L
s
.69888 .58306 m
.70271 .58174 L
s
.35548 .5858 m
.35527 .57891 L
s
.70271 .58174 m
.70484 .57901 L
s
.58819 .58266 m
.58836 .5799 L
s
.39423 .58367 m
.39231 .57951 L
s
.6511 .58091 m
.6533 .5768 L
s
.36823 .57912 m
.37019 .58329 L
s
.53098 .58174 m
.53108 .57898 L
s
.48665 .58102 m
.49589 .58117 L
s
.49598 .57703 m
.49589 .58117 L
s
.70484 .57901 m
.70499 .57763 L
s
.58836 .5799 m
.58676 .57572 L
s
.46816 .58073 m
.47007 .57661 L
s
.70499 .57763 m
.70344 .57484 L
s
.53108 .57898 m
.53309 .57486 L
s
.68681 .57457 m
.68469 .5773 L
s
.67017 .5743 m
.67361 .57713 L
s
.39231 .57951 m
.39226 .57674 L
s
.72191 .57513 m
.71991 .57649 L
s
.71991 .57649 m
.71821 .57507 L
s
.6533 .5768 m
.65723 .57409 L
s
.35527 .57891 m
.35328 .57473 L
s
.72021 .57372 m
.72191 .57513 L
s
.4942 .57423 m
.49598 .57703 L
s
.71821 .57507 m
.72021 .57372 L
s
.70344 .57484 m
.69804 .57336 L
s
.58676 .57572 m
.58322 .57289 L
s
.47007 .57661 m
.47196 .57387 L
s
.69249 .57327 m
.68681 .57457 L
s
.57025 .57268 m
.56641 .57539 L
s
.39226 .57674 m
.39405 .57261 L
s
.6666 .57285 m
.67017 .5743 L
s
.54988 .57235 m
.55345 .57519 L
s
.65723 .57409 m
.66105 .57276 L
s
.53309 .57486 m
.5369 .57214 L
s
.69804 .57336 m
.69249 .57327 L
s
.66105 .57276 m
.6666 .57285 L
s
.49055 .57139 m
.4942 .57423 L
s
.47196 .57387 m
.47571 .57115 L
s
.58322 .57289 m
.57959 .57144 L
s
.35328 .57473 m
.35133 .57192 L
s
.57403 .57135 m
.57025 .57268 L
s
.54623 .5709 m
.54988 .57235 L
s
.5369 .57214 m
.54067 .57081 L
s
.41072 .5701 m
.41446 .57294 L
s
.57959 .57144 m
.57403 .57135 L
s
.39405 .57261 m
.39772 .56989 L
s
.48687 .56994 m
.49055 .57139 L
s
.54067 .57081 m
.54623 .5709 L
s
.47571 .57115 m
.47944 .56982 L
s
.35133 .57192 m
.34752 .56908 L
s
.47944 .56982 m
.48687 .56994 L
s
.40699 .56865 m
.41072 .5701 L
s
.39772 .56989 m
.40142 .56856 L
s
.40142 .56856 m
.40699 .56865 L
s
.34752 .56908 m
.34189 .5676 L
s
.34189 .5676 m
.32886 .56738 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool4000001`0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0603oool300000200oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0503oool3000002<0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06T0oooo20000?l70?oo
o`030000o`3oool0oooo00X0oooo0`000?l00`3oool0003o0?ooo`060?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`0000000P00000V0?ooo`030000o`3oool0oooo0340oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000o`3oool0oooo00D0oooo0P000?l50?ooo`030000o`3oool0oooo00P0oooo0P000?l20?ooo`03
000000000?l0003o00L0oooo00<0003o0?ooo`3oool00P3oool00`000000003o000000070?ooo`L0
003o1@3oool00`000?l0oooo0?ooo`080?ooo`D0003o00<0oooo0000o`3oool00`3oool00`000?l0
oooo0?ooo`030000o`P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0K0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
J@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`030?ooo`03000000000?l0oooo00D0oooo00<0003o0?ooo`000?l0
0`0000020000o`L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`H0003o1@3oool70000o`030000003oool0oooo0080oooo
00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l000000000
o`030?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?oo
o`3oool0003o00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`80003o
1@3oool20000o`D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0003o00H0
oooo00<0003o0000003oool00`3oool20000oe@0oooo00<000000?ooo`3oool04`3oool002D0oooo
00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?ooo`80
000000@0003o0?ooo`3oool0003o0P3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0
oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool04@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo00000000
00020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0103oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo00<0003o0000003oool0F@3oool00`000000
oooo0?ooo`0C0?ooo`009@3oool2000006`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`80003o203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0000000<0oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0<0?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00X0oooo1P000?l2000000@0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0000o`040000o`@0oooo1`000?l01@3oool000000?ooo`3oool0003o
00D0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0P000?l7
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l00`3o
ool300000080oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`0E0?ooo`040000003oool0oooo0000o`D0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0003o00h0oooo00<0003o0?ooo`000?l00`000?l40?ooo`P0003o103oool70000o`H0
oooo00@0003o0?ooo`000?l0003o0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo100000030?ooo`040000o`3oool0oooo
00000080oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05P3oool00`00
0000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0903oool01000
0?l0oooo0?ooo`3oool30000o`L0oooo00<0003o0?ooo`3oool0103oool40000o`<0oooo0`000008
0000o`80oooo00@000000?ooo`3oool0003oEP3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`0F0?ooo`<000003P3oool00`000000003o0?ooo`1F0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo06`0oooo1`000?lJ0?ooo`030000003oool0oooo
0180oooo1`000?lX0?ooo`030000o`3oool0oooo01<0oooo0`00000B0?ooo`030000003oool0oooo
05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`110?ooo`030000o`3oool0oooo00X0oooo0P000?l40?ooo`<000005@3oool00`000?l0
00000?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0CP3oool00`000?l0oooo00000003000001P0oooo00<0003o0?ooo`000000
E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo04d0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1:0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0A03oool3000002X0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03P0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<0
0000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02h0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000580
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo
00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00
001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P000007
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000680oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?oo
o`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`80
0000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo
0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0
oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo
0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?oo
o`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`00
0000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo
0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool30000
06L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo
0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?oo
o`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?oo
o`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
5@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool30000
08L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080
oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`03
0000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000
oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo
0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`00
0000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?oo
o`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@00000
0?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`31
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?oo
o`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103o
ool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00
001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`03
0000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00
A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2
000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`03
0000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00
CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool0
10000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0
oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool40000
00<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0
oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@0
00000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<00000
0?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool0
0`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool20000
00030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?oo
o`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00
H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03o
ool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool0
06L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool40000
00T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo
0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?oo
o`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3o
ool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000
:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03o
ool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool0
07D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000
oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo
0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?oo
o`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo
001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo
100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00
000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?oo
o`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?oo
o`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`03
0000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0
L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3o
ool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0
oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool50000
07/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800
oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo
002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<00000
0?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?oo
o`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0
@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0
?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03o
ool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool5
00000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool40000
0;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo
00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo
001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo
0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo
0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?oo
o`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3o
ool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0
oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo
1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71736 .60522 m
.71908 .58293 L
s
.63669 .60552 m
.63494 .60391 L
s
.63861 .60397 m
.63669 .60552 L
s
.63687 .60235 m
.63861 .60397 L
s
.63494 .60391 m
.63687 .60235 L
s
.60194 .60338 m
.60355 .56981 L
s
.48626 .60155 m
.47891 .60143 L
s
.48997 .60002 m
.48626 .60155 L
s
.47891 .60143 m
.47526 .59978 L
s
.49371 .5969 m
.48997 .60002 L
s
.47526 .59978 m
.47163 .59654 L
s
.69619 .59375 m
.69068 .59367 L
s
.70181 .59225 m
.69619 .59375 L
s
.69068 .59367 m
.68528 .59199 L
s
.66497 .59326 m
.65946 .59317 L
s
.66875 .59172 m
.66497 .59326 L
s
.49562 .59374 m
.49371 .5969 L
s
.70388 .58909 m
.70181 .59225 L
s
.65946 .59317 m
.65588 .59151 L
s
.68528 .59199 m
.68366 .58877 L
s
.47163 .59654 m
.46983 .59333 L
s
.63741 .59281 m
.63868 .57038 L
s
.34268 .59927 m
.34819 .59776 L
s
.32978 .59906 m
.34268 .59927 L
s
.67263 .58859 m
.66875 .59172 L
s
.32978 .59906 m
.32907 .56536 L
s
.61718 .59249 m
.62095 .59096 L
s
.61167 .5924 m
.61718 .59249 L
s
.65588 .59151 m
.6524 .58826 L
s
.60807 .59075 m
.61167 .5924 L
s
.34819 .59776 m
.35183 .59464 L
s
.62095 .59096 m
.62304 .58619 L
s
.57856 .59187 m
.5823 .59034 L
s
.57304 .59179 m
.57856 .59187 L
s
.56942 .59013 m
.57304 .59179 L
s
.60278 .58587 m
.60807 .59075 L
s
.56567 .59167 m
.56698 .55789 L
s
.68366 .58877 m
.68572 .5856 L
s
.46983 .59333 m
.46806 .58851 L
s
.55279 .59146 m
.55358 .569 L
s
.54542 .59134 m
.5399 .59126 L
s
.54916 .58981 m
.54542 .59134 L
s
.5823 .59034 m
.58613 .5872 L
s
.5399 .59126 m
.53627 .5896 L
s
.56586 .58688 m
.56942 .59013 L
s
.6524 .58826 m
.65085 .58344 L
s
.51596 .59087 m
.52148 .59096 L
s
.35183 .59464 m
.35362 .59147 L
s
.51231 .58922 m
.51596 .59087 L
s
.55296 .58667 m
.54916 .58981 L
s
.50674 .59073 m
.50728 .56825 L
s
.53627 .5896 m
.53268 .58634 L
s
.68572 .5856 m
.68951 .58406 L
s
.5087 .58596 m
.51231 .58922 L
s
.58613 .5872 m
.58818 .58243 L
s
.45697 .58993 m
.4498 .56732 L
s
.62304 .58619 m
.62389 .57014 L
s
.44221 .58969 m
.4498 .56732 L
s
.44221 .58969 m
.43496 .56708 L
s
.68951 .58406 m
.69883 .58261 L
s
.35362 .59147 m
.3554 .58671 L
s
.42745 .58946 m
.43496 .56708 L
s
.46806 .58851 m
.46817 .5805 L
s
.41453 .58925 m
.41454 .56675 L
s
.53268 .58634 m
.53098 .58151 L
s
.40714 .58913 m
.40161 .58904 L
s
.41084 .58759 m
.40714 .58913 L
s
.69883 .58261 m
.70263 .58106 L
s
.40161 .58904 m
.39791 .58739 L
s
.65085 .58344 m
.65104 .58023 L
s
.50697 .58112 m
.5087 .58596 L
s
.3776 .58866 m
.38314 .58875 L
s
.37389 .587 m
.3776 .58866 L
s
.41453 .58445 m
.41084 .58759 L
s
.36836 .58851 m
.36811 .56599 L
s
.70263 .58106 m
.70471 .57789 L
s
.39791 .58739 m
.3942 .58412 L
s
.58818 .58243 m
.58832 .57922 L
s
.37016 .58374 m
.37389 .587 L
s
.65104 .58023 m
.65317 .57545 L
s
.3554 .58671 m
.35529 .57868 L
s
.70471 .57789 m
.70482 .57628 L
s
.53098 .58151 m
.53107 .5783 L
s
.3942 .58412 m
.39232 .57928 L
s
.58832 .57922 m
.58669 .57437 L
s
.48665 .5808 m
.49589 .58095 L
s
.49599 .57613 m
.49589 .58095 L
s
.36825 .57889 m
.37016 .58374 L
s
.70482 .57628 m
.70321 .57304 L
s
.6866 .57277 m
.68454 .57595 L
s
.72166 .57334 m
.7197 .57491 L
s
.7197 .57491 m
.71797 .57328 L
s
.46817 .5805 m
.47008 .57571 L
s
.66999 .5725 m
.67347 .57578 L
s
.53107 .5783 m
.53307 .57351 L
s
.65317 .57545 m
.65706 .57229 L
s
.71994 .5717 m
.72166 .57334 L
s
.71797 .57328 m
.71994 .5717 L
s
.70321 .57304 m
.69779 .57134 L
s
.69225 .57125 m
.6866 .57277 L
s
.39232 .57928 m
.39231 .57606 L
s
.58669 .57437 m
.58313 .57109 L
s
.6664 .57083 m
.66999 .5725 L
s
.4942 .57288 m
.49599 .57613 L
s
.65706 .57229 m
.66085 .57074 L
s
.69779 .57134 m
.69225 .57125 L
s
.57018 .57088 m
.56635 .57404 L
s
.35529 .57868 m
.35336 .57383 L
s
.47008 .57571 m
.47198 .57252 L
s
.54982 .57055 m
.55341 .57384 L
s
.66085 .57074 m
.6664 .57083 L
s
.53307 .57351 m
.53687 .57034 L
s
.39231 .57606 m
.39414 .57126 L
s
.58313 .57109 m
.5795 .56942 L
s
.49056 .56959 m
.4942 .57288 L
s
.57394 .56933 m
.57018 .57088 L
s
.47198 .57252 m
.47574 .56935 L
s
.54618 .56888 m
.54982 .57055 L
s
.5795 .56942 m
.57394 .56933 L
s
.53687 .57034 m
.54062 .56879 L
s
.35336 .57383 m
.35146 .57057 L
s
.54062 .56879 m
.54618 .56888 L
s
.41083 .5683 m
.41454 .57159 L
s
.48689 .56792 m
.49056 .56959 L
s
.39414 .57126 m
.39783 .56809 L
s
.47574 .56935 m
.47947 .5678 L
s
.47947 .5678 m
.48689 .56792 L
s
.35146 .57057 m
.34769 .56728 L
s
.40711 .56663 m
.41083 .5683 L
s
.39783 .56809 m
.40154 .56654 L
s
.40154 .56654 m
.40711 .56663 L
s
.34769 .56728 m
.34209 .56557 L
s
.34209 .56557 m
.32907 .56536 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<000006@3oool00`000?l0
oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000703oool00`000?l0oooo
0?ooo`0a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000803oool00`000?l0oooo0?oo
o`0a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0JP3oool50000o`T0oooo00<0003o0?ooo`3oool02P3oool30000o`030?ooo`000?l0
oooo0140oooo0`00000S0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo
0080oooo0P000?l70?ooo`030000o`3oool0oooo00P0oooo0P000?l00`3oool000000?ooo`020000
o`L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo00000002000000@0oooo1@000?l70?oo
o`030000o`3oool0oooo00T0oooo10000?l00`3oool0003o0?ooo`030?ooo`030000o`3oool0oooo
00<0003o;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo06X0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0003o00L0oooo00<0003o0?ooo`3o
ool00P3oool00`000000003o000000060?ooo`030000o`3oool0oooo00<0oooo0P000?l50?ooo`03
0000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo0`000?l30?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00D0oooo0`000?l90?ooo`<0003o0P3oool00`000000oooo0?ooo`020?ooo`03
0000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`040?ooo`03000000000?l0oooo00D0oooo00<0003o0?ooo`000?l0
0`0000020000o`L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo0P000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80003o1@3oool20000o`<0
oooo0P000?l00`000000oooo0?ooo`020?ooo`80003oE03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l000000000o`030?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool0
1`3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000o`H0
oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00@0003o0000003oool0oooo0P00000010000?l0oooo0?ooo`000?l2
0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?oo
o`3oool0003o00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0A0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0000000000080oooo00L0003o0?ooo`3oool0
oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool03P3oool30000o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo0P00001/0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool20000o`P0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo000000030?ooo`070000o`3oool0oooo0?oo
o`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool4
0000o`80oooo0P0000040?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`000?l0203oool00`000?l0oooo0?ooo`020?ooo`80003o00D0oooo0000
003oool0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000
o`0>0?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`80003o1P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool010000?l0oooo0?oo
o`3oool300000080oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00@0003o1@3oool40000o`040?ooo`000?l0oooo00000080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?oo
o`000?l03P3oool00`000?l0oooo0000o`030000o`@0oooo0P000?l40?ooo`80003o103oool20000
o`@0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0000o`000?l30?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0
oooo0?ooo`@000000`3oool010000?l0oooo0?ooo`0000020?ooo`030000o`3oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?oo
o`0G0?ooo`@0003o00<0oooo0000o`3oool00`3oool00`000?l0oooo0000o`030000o`L0oooo00@0
003o0?ooo`3oool0oooo0`000?l70?ooo`030000o`3oool0oooo00<0oooo1`000?l01@3oool00000
000000000000003o00H0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo01H0oooo0`0000040?ooo`H0
003o103oool00`000000003o0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo06`0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`030000
003oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0U0?ooo`030000
o`3oool0oooo01<0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0K03oool70000oaX0oooo00<000000?ooo`3oool04P3o
ool70000obP0oooo00<0003o0?ooo`3oool0403oool3000001D0oooo00<0003o0000003oool0E@3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0440oooo00<0003o0?ooo`3oool02P3oool20000o`@00000603oool00`000?l0oooo0000001E
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0C@3oool3000001`0oooo00<0003o0?ooo`000000EP3oool00`000000oooo0?ooo`0A0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?ooo`<00000:P3o
ool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00
000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool0
0`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
05/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo
0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00
002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3
000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`
0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3
000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo
000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B
0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3
000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c
0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3
000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E
0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000
Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3o
ool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo0000
06/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo0017
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80
000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@00000
0`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3o
ool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool01000
0000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000
oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`03
0000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`800000
00<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?oo
o`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00
I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@00000
2@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2
000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo
0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?oo
o`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?oo
o`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00
M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003o
ool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2
000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool0
06P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4
000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool20000
01@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo
00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo
00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<0
00000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a
0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?oo
o`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3o
ool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000
N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03o
ool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool0
0900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo
00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`11
0?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l
0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?oo
o`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D0
0000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000
/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool0
0`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool0
06D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0
oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo
00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3o
ool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool4
00000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71778 .60712 m
.71901 .58262 L
s
.63698 .60758 m
.63521 .60581 L
s
.63888 .60587 m
.63698 .60758 L
s
.63711 .60409 m
.63888 .60587 L
s
.63521 .60581 m
.63711 .60409 L
s
.60214 .60528 m
.60339 .56843 L
s
.69635 .59454 m
.69083 .59445 L
s
.70194 .59288 m
.69635 .59454 L
s
.69083 .59445 m
.6854 .59261 L
s
.70395 .5894 m
.70194 .59288 L
s
.48625 .60344 m
.47888 .60333 L
s
.48997 .60175 m
.48625 .60344 L
s
.6651 .59404 m
.65959 .59395 L
s
.66886 .59235 m
.6651 .59404 L
s
.6854 .59261 m
.68372 .58908 L
s
.65959 .59395 m
.65598 .59214 L
s
.47888 .60333 m
.47523 .60152 L
s
.49371 .59831 m
.48997 .60175 L
s
.67269 .5889 m
.66886 .59235 L
s
.63752 .5936 m
.63847 .569 L
s
.65598 .59214 m
.65245 .58858 L
s
.47523 .60152 m
.4716 .59796 L
s
.61728 .59328 m
.62102 .59158 L
s
.61176 .59319 m
.61728 .59328 L
s
.60814 .59138 m
.61176 .59319 L
s
.68372 .58908 m
.68572 .5856 L
s
.49562 .59484 m
.49371 .59831 L
s
.62102 .59158 m
.62306 .58635 L
s
.6028 .58602 m
.60814 .59138 L
s
.57862 .59266 m
.58236 .59096 L
s
.5731 .59257 m
.57862 .59266 L
s
.65245 .58858 m
.65082 .58328 L
s
.4716 .59796 m
.46981 .59443 L
s
.56947 .59076 m
.5731 .59257 L
s
.56573 .59245 m
.56679 .55545 L
s
.68572 .5856 m
.68948 .5839 L
s
.58236 .59096 m
.58615 .58751 L
s
.55284 .59225 m
.5535 .56762 L
s
.54547 .59213 m
.53994 .59204 L
s
.5492 .59043 m
.54547 .59213 L
s
.56588 .58719 m
.56947 .59076 L
s
.53994 .59204 m
.53629 .59023 L
s
.68948 .5839 m
.69877 .5823 L
s
.55298 .58698 m
.5492 .59043 L
s
.34241 .60116 m
.34794 .5995 L
s
.32948 .60096 m
.34241 .60116 L
s
.51597 .59166 m
.5215 .59174 L
s
.46981 .59443 m
.46804 .58913 L
s
.62306 .58635 m
.62371 .56876 L
s
.69877 .5823 m
.70253 .5806 L
s
.51232 .58984 m
.51597 .59166 L
s
.53629 .59023 m
.53269 .58666 L
s
.32948 .60096 m
.3293 .56398 L
s
.58615 .58751 m
.58816 .58227 L
s
.50675 .59151 m
.50726 .56687 L
s
.34794 .5995 m
.35163 .59605 L
s
.70253 .5806 m
.70454 .57711 L
s
.65082 .58328 m
.65096 .57977 L
s
.50871 .58627 m
.51232 .58984 L
s
.45694 .59071 m
.44986 .56594 L
s
.53269 .58666 m
.53097 .58135 L
s
.35163 .59605 m
.35347 .59257 L
s
.70454 .57711 m
.70463 .57535 L
s
.65096 .57977 m
.65302 .57452 L
s
.46804 .58913 m
.46817 .58034 L
s
.44217 .59048 m
.44986 .56594 L
s
.44217 .59048 m
.43504 .5657 L
s
.58816 .58227 m
.58828 .57876 L
s
.50697 .58097 m
.50871 .58627 L
s
.4274 .59024 m
.43504 .5657 L
s
.70463 .57535 m
.70295 .5718 L
s
.41447 .59003 m
.41465 .56537 L
s
.72138 .5721 m
.71945 .57383 L
s
.71945 .57383 m
.71769 .57204 L
s
.40708 .58992 m
.40153 .58983 L
s
.41078 .58822 m
.40708 .58992 L
s
.35347 .59257 m
.35532 .58733 L
s
.40153 .58983 m
.39785 .58801 L
s
.68636 .57154 m
.68436 .57503 L
s
.66977 .57127 m
.6733 .57485 L
s
.71963 .57031 m
.72138 .5721 L
s
.41451 .58476 m
.41078 .58822 L
s
.71769 .57204 m
.71963 .57031 L
s
.37751 .58944 m
.38305 .58953 L
s
.58828 .57876 m
.5866 .57345 L
s
.37381 .58763 m
.37751 .58944 L
s
.53097 .58135 m
.53106 .57784 L
s
.39785 .58801 m
.39417 .58444 L
s
.65302 .57452 m
.65686 .57106 L
s
.70295 .5718 m
.69751 .56995 L
s
.36826 .5893 m
.36828 .56461 L
s
.69197 .56986 m
.68636 .57154 L
s
.37012 .58405 m
.37381 .58763 L
s
.48665 .58064 m
.49589 .58079 L
s
.49599 .57551 m
.49589 .58079 L
s
.69751 .56995 m
.69197 .56986 L
s
.66615 .56944 m
.66977 .57127 L
s
.35532 .58733 m
.35531 .57853 L
s
.53106 .57784 m
.53303 .57258 L
s
.65686 .57106 m
.66062 .56935 L
s
.39417 .58444 m
.39234 .57913 L
s
.46817 .58034 m
.4701 .57509 L
s
.66062 .56935 m
.66615 .56944 L
s
.5866 .57345 m
.58302 .56986 L
s
.36827 .57874 m
.37012 .58405 L
s
.57008 .56965 m
.56629 .57312 L
s
.54975 .56932 m
.55335 .57291 L
s
.4942 .57195 m
.49599 .57551 L
s
.53303 .57258 m
.53681 .56911 L
s
.58302 .56986 m
.57937 .56804 L
s
.4701 .57509 m
.472 .57159 L
s
.39234 .57913 m
.39235 .5756 L
s
.57383 .56795 m
.57008 .56965 L
s
.57937 .56804 m
.57383 .56795 L
s
.5461 .5675 m
.54975 .56932 L
s
.49057 .56836 m
.4942 .57195 L
s
.53681 .56911 m
.54055 .56741 L
s
.35531 .57853 m
.35345 .57321 L
s
.472 .57159 m
.47576 .56812 L
s
.39235 .5756 m
.39423 .57034 L
s
.54055 .56741 m
.5461 .5675 L
s
.4869 .56654 m
.49057 .56836 L
s
.47576 .56812 m
.47949 .56642 L
s
.41093 .56707 m
.41461 .57067 L
s
.47949 .56642 m
.4869 .56654 L
s
.35345 .57321 m
.35159 .56965 L
s
.39423 .57034 m
.39795 .56686 L
s
.40723 .56524 m
.41093 .56707 L
s
.35159 .56965 m
.34787 .56605 L
s
.39795 .56686 m
.40167 .56515 L
s
.40167 .56515 m
.40723 .56524 L
s
.34787 .56605 m
.3423 .56419 L
s
.3423 .56419 m
.3293 .56398 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`00000F0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000I0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
1000000L0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`80003o603oool00`000000oooo0?oo
o`0H0?ooo`<00000803oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0000o`05
0000o`H0oooo00<0003o0?ooo`3oool02P3oool30000o`030?ooo`000?l0oooo00H0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`<000000`3oool30000oad0oooo00<0003o
0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00P0oooo0P000?l00`3oool000000?ooo`020000o`L0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo00000002000000@0oooo0P000?l30?ooo`80003o1@3oool00`00
0?l0oooo0?ooo`080?ooo`L0003o103oool00`000?l0oooo0?ooo`030000o`P0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo0`000?l>0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0003o00H0oooo00<0003o0?ooo`00
0?l00`3oool20000o`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool20000o`@0
oooo0`000?l30?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo0P000?l50?oo
o`L0003o00<000000?ooo`3oool00P3oool20000oe@0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`03000000000?l0oooo00D0
oooo00<0003o0?ooo`000?l00`0000000`000?l0oooo0000o`050?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20000o`H0
oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030000o`000000oooo00<0oooo00<0003o0?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l000000000o`030?ooo`03
0000o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o
00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`030000o`3oool0oooo
00D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0000003oool0oooo0P0000001`00
0?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0403oool00`000?l000000?ooo`1I0?ooo`030000003oool0oooo01<0oooo
000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0000
000000020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo10000?l00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00001/0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool20000o`P0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo000000030?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`03
0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool02P3oool30000o`<0oooo0P0000040?ooo`030000o`3o
ool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0J`3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l0203oool0
0`000?l0oooo0?ooo`020?ooo`80003o00D0oooo0000003oool0oooo0000o`050?ooo`030000o`3o
ool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`80003o1`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`80003o1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool300000080oooo00D000000?ooo`3o
ool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0
003o1@3oool40000o`040?ooo`000?l0oooo00000080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0000o`07
0?ooo`80003o103oool20000o`@0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`000?l0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool4000000<0oooo00@0003o0?ooo`3oool00000
0P3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0E0?ooo`030000003o
ool0oooo00l0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`030000o`H0oooo1000
0?l00`3oool0003o0?ooo`030?ooo`030000o`3oool0003o00<0003o1`3oool00`000?l0oooo0?oo
o`050000o`H0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo0P000?l0103oool000000000
000000020000o`D0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0T0?ooo`030000o`3oool0oooo01<0oooo0`000?l3000000D0oooo
1@000?l40?ooo`030000003oool0003o05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0K03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo01L0oooo00<0
00000?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02D0oooo00<0
003o0?ooo`3oool04`3oool300000180oooo00<000000000o`3oool0E@3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`P0003o6@3oool00`000000oooo0?ooo`0B
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0@
0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool04`3oool60000obP0oooo00<0003o0?oo
o`3oool02P3oool00`000?l0oooo00000003000001T0oooo00<0003o0000003oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0440
oooo00<0003o0?ooo`3oool02@3oool3000001d0oooo00<0003o0000003oool0E@3oool00`000000
oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo
0`0000000`3oool0003o0?ooo`0M0?ooo`030000o`3oool0000005D0oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool0
0`000000oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool40000
02h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?oo
o`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3o
ool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool0
0`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo
000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo
000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0E0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000
003oool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0
oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<0
00000P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0
QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0
oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=
0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<0
00008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003o
ool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool0
0`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0
oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo
0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?oo
o`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k
0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000
003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool0
0`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0
oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo
0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K
0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000
003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3
000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200
oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo
0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j
0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`09
0?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`03
0000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000
003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3o
ool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3
000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo
0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000
oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000
003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603o
ool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0
oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool20000
0100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo
00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo
000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P00
00000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool2
00000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0
oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo
00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo
000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?oo
o`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool00000
0?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0
oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0
oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo
0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00
001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?oo
o`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo
0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00
001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?oo
o`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`80
0000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3o
ool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000
003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool0
2P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3o
ool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo
0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`00
00000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool0
00000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000
003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?oo
o`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I
0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<0
00000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0
oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool40000
0180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0
oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo
001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<00000
0?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?oo
o`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3o
ool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5
000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool40000
03h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool20000
0340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo0000
0140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0
oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo
08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0
oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo
1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo0024
0?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo0025
0?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?oo
o`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003o
ool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3o
ool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580
oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo
1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?oo
o`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3o
ool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`00
00004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`800000
4@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003o
ool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000
[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3o
ool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool2
00000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool0
06H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`00
0000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool30000
0180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool300000003
0?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@0
0000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo
100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W
0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?oo
o`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool4
00000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0
oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71824 .60811 m
.71893 .58247 L
s
.63731 .60866 m
.63551 .6068 L
s
.63919 .60685 m
.63731 .60866 L
s
.63739 .60499 m
.63919 .60685 L
s
.69652 .59494 m
.69101 .59485 L
s
.70209 .5932 m
.69652 .59494 L
s
.63551 .6068 m
.63739 .60499 L
s
.70402 .58956 m
.70209 .5932 L
s
.69101 .59485 m
.68553 .59293 L
s
.68553 .59293 m
.68379 .58924 L
s
.66525 .59444 m
.65973 .59435 L
s
.66898 .59267 m
.66525 .59444 L
s
.60238 .60627 m
.60321 .56774 L
s
.67275 .58906 m
.66898 .59267 L
s
.65973 .59435 m
.6561 .59246 L
s
.68379 .58924 m
.68572 .5856 L
s
.6561 .59246 m
.6525 .58874 L
s
.68572 .5856 m
.68945 .58383 L
s
.69869 .58214 m
.70242 .58036 L
s
.68945 .58383 m
.69869 .58214 L
s
.63765 .594 m
.63824 .56831 L
s
.70242 .58036 m
.70436 .57673 L
s
.6525 .58874 m
.65079 .5832 L
s
.70436 .57673 m
.70441 .57489 L
s
.72106 .57149 m
.71917 .57329 L
s
.71917 .57329 m
.71738 .57143 L
s
.61739 .59368 m
.62112 .5919 L
s
.61187 .59359 m
.61739 .59368 L
s
.62112 .5919 m
.62308 .58643 L
s
.60822 .5917 m
.61187 .59359 L
s
.70441 .57489 m
.70266 .57119 L
s
.71927 .56962 m
.72106 .57149 L
s
.71738 .57143 m
.71927 .56962 L
s
.65079 .5832 m
.65088 .57953 L
s
.60281 .5861 m
.60822 .5917 L
s
.70266 .57119 m
.69719 .56926 L
s
.68609 .57092 m
.68416 .57456 L
s
.62308 .58643 m
.6235 .56807 L
s
.65088 .57953 m
.65285 .57406 L
s
.66952 .57065 m
.67311 .57438 L
s
.5787 .59306 m
.58243 .59128 L
s
.57317 .59297 m
.5787 .59306 L
s
.69719 .56926 m
.69166 .56917 L
s
.69166 .56917 m
.68609 .57092 L
s
.58243 .59128 m
.58619 .58767 L
s
.56952 .59108 m
.57317 .59297 L
s
.5658 .59285 m
.56657 .55426 L
s
.56591 .58735 m
.56952 .59108 L
s
.58619 .58767 m
.58815 .5822 L
s
.65285 .57406 m
.65663 .57044 L
s
.66588 .56876 m
.66952 .57065 L
s
.55289 .59265 m
.55339 .56693 L
s
.66035 .56867 m
.66588 .56876 L
s
.65663 .57044 m
.66035 .56867 L
s
.48625 .60443 m
.47887 .60431 L
s
.48998 .60265 m
.48625 .60443 L
s
.54552 .59253 m
.53998 .59244 L
s
.54924 .59075 m
.54552 .59253 L
s
.49373 .59904 m
.48998 .60265 L
s
.553 .58714 m
.54924 .59075 L
s
.53998 .59244 m
.53633 .59055 L
s
.47887 .60431 m
.47521 .60242 L
s
.58815 .5822 m
.58822 .57852 L
s
.53633 .59055 m
.53271 .58682 L
s
.49564 .5954 m
.49373 .59904 L
s
.47521 .60242 m
.47158 .59869 L
s
.516 .59206 m
.52154 .59215 L
s
.58822 .57852 m
.5865 .57298 L
s
.51234 .59016 m
.516 .59206 L
s
.53271 .58682 m
.53096 .58128 L
s
.50677 .59191 m
.50722 .56618 L
s
.47158 .59869 m
.46979 .59499 L
s
.50871 .58643 m
.51234 .59016 L
s
.5865 .57298 m
.58288 .56925 L
s
.46979 .59499 m
.46803 .58945 L
s
.50696 .58089 m
.50871 .58643 L
s
.53096 .58128 m
.53103 .5776 L
s
.56997 .56904 m
.5662 .57266 L
s
.58288 .56925 m
.57923 .56735 L
s
.53103 .5776 m
.53298 .57212 L
s
.57923 .56735 m
.5737 .56726 L
s
.54967 .56871 m
.55329 .57245 L
s
.5737 .56726 m
.56997 .56904 L
s
.46803 .58945 m
.46817 .58027 L
s
.45692 .59111 m
.44991 .56525 L
s
.48665 .58056 m
.49588 .58071 L
s
.49598 .5752 m
.49588 .58071 L
s
.44214 .59088 m
.44991 .56525 L
s
.44214 .59088 m
.43511 .56501 L
s
.53298 .57212 m
.53674 .5685 L
s
.54601 .56681 m
.54967 .56871 L
s
.42735 .59064 m
.43511 .56501 L
s
.54047 .56672 m
.54601 .56681 L
s
.53674 .5685 m
.54047 .56672 L
s
.49419 .57149 m
.49598 .5752 L
s
.46817 .58027 m
.47011 .57478 L
s
.41441 .59043 m
.41475 .56468 L
s
.40701 .59032 m
.40147 .59023 L
s
.41074 .58854 m
.40701 .59032 L
s
.41448 .58492 m
.41074 .58854 L
s
.34212 .60214 m
.34769 .6004 L
s
.32917 .60194 m
.34212 .60214 L
s
.40147 .59023 m
.39779 .58833 L
s
.49056 .56775 m
.49419 .57149 L
s
.34769 .6004 m
.35143 .59678 L
s
.47011 .57478 m
.47201 .57113 L
s
.39779 .58833 m
.39414 .58459 L
s
.32917 .60194 m
.32954 .5633 L
s
.35143 .59678 m
.35332 .59313 L
s
.37742 .58984 m
.38297 .58993 L
s
.48689 .56585 m
.49056 .56775 L
s
.47201 .57113 m
.47577 .56751 L
s
.37374 .58795 m
.37742 .58984 L
s
.35332 .59313 m
.35523 .58765 L
s
.39414 .58459 m
.39235 .57905 L
s
.36817 .58969 m
.36846 .56393 L
s
.4795 .56573 m
.48689 .56585 L
s
.47577 .56751 m
.4795 .56573 L
s
.37008 .58421 m
.37374 .58795 L
s
.35523 .58765 m
.35533 .57845 L
s
.36829 .57866 m
.37008 .58421 L
s
.39235 .57905 m
.3924 .57537 L
s
.3924 .57537 m
.39432 .56988 L
s
.41103 .56646 m
.41468 .5702 L
s
.35533 .57845 m
.35354 .5729 L
s
.39432 .56988 m
.39807 .56625 L
s
.40735 .56456 m
.41103 .56646 L
s
.40179 .56447 m
.40735 .56456 L
s
.39807 .56625 m
.40179 .56447 L
s
.35354 .5729 m
.35172 .56919 L
s
.35172 .56919 m
.34805 .56544 L
s
.34805 .56544 m
.34251 .56351 L
s
.34251 .56351 m
.32954 .5633 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`00000F0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000I0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
1000000L0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`H0003o203oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0oooo01P0oooo0`00000P0?ooo`030000o`3oool0oooo0340oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z
0?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo00P0oooo1`000?l7
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3000000<0oooo0`000?l7
0?ooo`030000o`3oool0oooo00T0oooo0`000?l70?ooo`030000o`3oool0oooo0340oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?oo
o`060000o`3oool0oooo0?ooo`000000oooo0P000?l70?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`0000000P0000040?ooo`80003o0`3oool20000o`D0oooo00<0003o0?ooo`3oool0203o
ool010000?l0oooo0?ooo`3oool30000o`@0oooo1`000?l70?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`<0003o2@3oool30000o`80oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`000?l01P3oool00`000?l0oooo0000
o`030?ooo`80003o00<000000?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`80003o103o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo
0P000?l50?ooo`80003o0`3oool20000o`040000003oool0oooo0?ooo`<0003oE03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo
00<000000000o`3oool01@3oool00`000?l0oooo0000o`03000000030000o`3oool0003o00D0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool20000o`H0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`03
0000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l000000000o`030?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3oool0
1`3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0A0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo
00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?ooo`80
000000L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0100oooo00<0003o0000003oool0F@3oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o
0?ooo`00000000000P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo1@000?l30?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0=0?ooo`@0003o00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000
K03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P000?l80?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`0000000`3oool01`000?l0oooo0?ooo`3oool0003o0?oo
o`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00`0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo0`000?l30?oo
o`800000103oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0003o00L0oooo00<0003o0?ooo`3oool00`3oool20000o`050?ooo`000000oooo0?oo
o`000?l01@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool2
0000o`P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0
oooo0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool010000?l40?ooo`L0003o00D0oooo0000003oool0oooo
0000o`050?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`03
0000o`3oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`050?ooo`80003o103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool40000
00<0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo00D0003o0?ooo`3oool0oooo0000o`0>
0?ooo`030000o`3oool0oooo00<0003o1P3oool40000o`030?ooo`000?l0oooo00<0oooo1`000?l7
0?ooo`040000o`3oool0003o0000o`80oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`80003o0`3oool20000o`060?ooo`00000000000000003oool0003o1@3oool010000?l0
oooo0?ooo`0000020?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0K03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01H0
oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02D0
oooo00@0003o0?ooo`3oool0oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo0`000?l30000
00D0oooo1@000?l40?ooo`030000003oool0003o05H0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0K03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01H0
oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02H0
oooo00<0003o0?ooo`3oool04P3oool300000180oooo00<000000000o`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00<0oooo
0P000?lI0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`0V0?ooo`030000o`3oool0oooo00l0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0K03oool60000oa/0oooo00<0
00000?ooo`3oool04P3oool30000o`<0oooo00<0003o0?ooo`3oool09`3oool00`000?l0oooo0?oo
o`0;0?ooo`@000006@3oool00`000?l000000?ooo`1D0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05@3oool30000obX0oooo00<0003o
0?ooo`3oool0203oool3000001d0oooo00<0003o0000003oool0E@3oool00`000000oooo0?ooo`0A
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`0000020?oo
o`030000o`3oool0oooo01/0oooo00<0003o0?ooo`000000E@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo04L0oooo0`00000V0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000
003oool0oooo04@0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000
00120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000
003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0
oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.7189 .56966 m
.72073 .57152 L
s
.71706 .57146 m
.7189 .56966 L
s
.72073 .57152 m
.71889 .57332 L
s
.71889 .57332 m
.71706 .57146 L
s
.69685 .5693 m
.69134 .56921 L
s
.70235 .57122 m
.69685 .5693 L
s
.70417 .57491 m
.70235 .57122 L
s
.69134 .56921 m
.68581 .57095 L
s
.70416 .57674 m
.70417 .57491 L
s
.68581 .57095 m
.68395 .57458 L
s
.70231 .58037 m
.70416 .57674 L
s
.66559 .56879 m
.66926 .57068 L
s
.66007 .5687 m
.66559 .56879 L
s
.66926 .57068 m
.67291 .5744 L
s
.65638 .57047 m
.66007 .5687 L
s
.71873 .60814 m
.71885 .58247 L
s
.69862 .58214 m
.70231 .58037 L
s
.65267 .57407 m
.65638 .57047 L
s
.63778 .594 m
.638 .56834 L
s
.68941 .58383 m
.69862 .58214 L
s
.56587 .59285 m
.56633 .55436 L
s
.65079 .57954 m
.65267 .57407 L
s
.62311 .58643 m
.62327 .5681 L
s
.68572 .5856 m
.68941 .58383 L
s
.7041 .58956 m
.70224 .5932 L
s
.68386 .58924 m
.68572 .5856 L
s
.60263 .6063 m
.60302 .56778 L
s
.65076 .58321 m
.65079 .57954 L
s
.70224 .5932 m
.69671 .59494 L
s
.68568 .59293 m
.68386 .58924 L
s
.57907 .56739 m
.57355 .5673 L
s
.58274 .56928 m
.57907 .56739 L
s
.65256 .58873 m
.65076 .58321 L
s
.58638 .573 m
.58274 .56928 L
s
.57355 .5673 m
.56984 .56907 L
s
.67282 .58906 m
.66911 .59267 L
s
.69671 .59494 m
.69119 .59486 L
s
.69119 .59486 m
.68568 .59293 L
s
.56984 .56907 m
.56611 .57267 L
s
.58817 .57853 m
.58638 .573 L
s
.55296 .59265 m
.55328 .56697 L
s
.65622 .59246 m
.65256 .58873 L
s
.66911 .59267 m
.66541 .59444 L
s
.5459 .56685 m
.54957 .56874 L
s
.54037 .56676 m
.5459 .56685 L
s
.54957 .56874 m
.55321 .57247 L
s
.53666 .56853 m
.54037 .56676 L
s
.66541 .59444 m
.65989 .59436 L
s
.65989 .59436 m
.65622 .59246 L
s
.58813 .5822 m
.58817 .57853 L
s
.62121 .5919 m
.62311 .58643 L
s
.53292 .57214 m
.53666 .56853 L
s
.58623 .58767 m
.58813 .5822 L
s
.60284 .5861 m
.60831 .5917 L
s
.5068 .59191 m
.50717 .56622 L
s
.531 .57761 m
.53292 .57214 L
s
.61751 .59368 m
.62121 .5919 L
s
.61198 .59359 m
.61751 .59368 L
s
.60831 .5917 m
.61198 .59359 L
s
.48688 .56589 m
.49054 .56778 L
s
.47949 .56577 m
.48688 .56589 L
s
.5825 .59128 m
.58623 .58767 L
s
.49054 .56778 m
.49417 .57151 L
s
.47577 .56755 m
.47949 .56577 L
s
.53095 .58128 m
.531 .57761 L
s
.49417 .57151 m
.49596 .57521 L
s
.47202 .57115 m
.47577 .56755 L
s
.56594 .58735 m
.56959 .59108 L
s
.57879 .59306 m
.5825 .59128 L
s
.53273 .58681 m
.53095 .58128 L
s
.63769 .60502 m
.63952 .60688 L
s
.63583 .60683 m
.63769 .60502 L
s
.55303 .58714 m
.54929 .59075 L
s
.57325 .59297 m
.57879 .59306 L
s
.56959 .59108 m
.57325 .59297 L
s
.49596 .57521 m
.49588 .58071 L
s
.4569 .59111 m
.44995 .56529 L
s
.44211 .59088 m
.44995 .56529 L
s
.63952 .60688 m
.63766 .60869 L
s
.47011 .57479 m
.47202 .57115 L
s
.63766 .60869 m
.63583 .60683 L
s
.44211 .59088 m
.43517 .56505 L
s
.42731 .59064 m
.43517 .56505 L
s
.50696 .58089 m
.50873 .58643 L
s
.53637 .59055 m
.53273 .58681 L
s
.54929 .59075 m
.54557 .59253 L
s
.46817 .58027 m
.47011 .57479 L
s
.48665 .58057 m
.49588 .58071 L
s
.54557 .59253 m
.54004 .59244 L
s
.54004 .59244 m
.53637 .59055 L
s
.41436 .59043 m
.41485 .56472 L
s
.50873 .58643 m
.51237 .59016 L
s
.40745 .5646 m
.41112 .5665 L
s
.40191 .56451 m
.40745 .5646 L
s
.41112 .5665 m
.41474 .57023 L
s
.39817 .56629 m
.40191 .56451 L
s
.46802 .58945 m
.46817 .58027 L
s
.51603 .59206 m
.52157 .59215 L
s
.51237 .59016 m
.51603 .59206 L
s
.3944 .5699 m
.39817 .56629 L
s
.36807 .58969 m
.36862 .56397 L
s
.39244 .57538 m
.3944 .5699 L
s
.49566 .59541 m
.49375 .59906 L
s
.46978 .595 m
.46802 .58945 L
s
.34272 .56355 m
.32976 .56334 L
s
.34823 .56548 m
.34272 .56355 L
s
.35185 .56921 m
.34823 .56548 L
s
.39237 .57905 m
.39244 .57538 L
s
.32887 .60196 m
.32976 .56334 L
s
.49375 .59906 m
.49 .60267 L
s
.35362 .57291 m
.35185 .56921 L
s
.47157 .5987 m
.46978 .595 L
s
.39411 .58459 m
.39237 .57905 L
s
.41446 .58492 m
.41069 .58853 L
s
.35535 .57845 m
.35362 .57291 L
s
.49 .60267 m
.48628 .60446 L
s
.47521 .60244 m
.47157 .5987 L
s
.36831 .57866 m
.37004 .58421 L
s
.48628 .60446 m
.47888 .60434 L
s
.39774 .58833 m
.39411 .58459 L
s
.47888 .60434 m
.47521 .60244 L
s
.41069 .58853 m
.40695 .59031 L
s
.35515 .58765 m
.35535 .57845 L
s
.40695 .59031 m
.4014 .59023 L
s
.4014 .59023 m
.39774 .58833 L
s
.37004 .58421 m
.37367 .58794 L
s
.37733 .58984 m
.38289 .58993 L
s
.37367 .58794 m
.37733 .58984 L
s
.35317 .59314 m
.35515 .58765 L
s
.35124 .59679 m
.35317 .59314 L
s
.34745 .60041 m
.35124 .59679 L
s
.34185 .60217 m
.34745 .60041 L
s
.32887 .60196 m
.34185 .60217 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`00000F0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000I0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
1000000L0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`H0003o203oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0oooo01P0oooo0`00000P0?ooo`030000o`3oool0oooo0340oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z
0?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo00P0oooo1P000?l0
0`3oool0003o0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3
000000<0oooo0`000?l70?ooo`030000o`3oool0oooo00T0oooo0`000?l70?ooo`030000o`3oool0
oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`00
0000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`070?ooo`090000o`3oool0oooo0?ooo`000000oooo0000o`3oool0003o00H0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo00000002000000@0oooo0P000?l30?ooo`80003o
1@3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?ooo`<0003o103oool70000o`L0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0
oooo0`000?l90?ooo`<0003o0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool010000000oooo
0000o`000?l50?ooo`030000o`3oool0003o00<0oooo0P000?l00`000000oooo0?ooo`040?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00<0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool01@000?l0oooo0?ooo`3oool0003o00H0oooo0P000?l30?ooo`80003o00@000000?oo
o`3oool0oooo0`000?mD0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0000o`050?ooo`030000o`3oool0003o
00<0000000<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool20000
o`<0oooo00<0003o0?ooo`3oool0103oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo
05<0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`03000000000?l0oooo00@0oooo00<0003o000000000?l00`3oool00`000?l0
oooo0000o`050?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`080?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0403oool00`000?l000000?ooo`1I0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool01@3oool010000?l000000?ooo`3oool2000000070000o`3oool0oooo0?ooo`000?l0oooo0000
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?oo
o`3oool0003o00P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0@0?ooo`030000
o`000000oooo05T0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0000000000080oooo00L0003o0?ooo`3oool0
oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool03@3oool40000o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool2000006/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`020?ooo`80003o203oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0000000<0
oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`0:0?ooo`<0003o0`3oool2000000@0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`070?ooo`030000o`3oool0oooo
00<0oooo0P000?l01@3oool000000?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool0
1@000?l0oooo0?ooo`3oool0003o00h0oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool02@3oool010000?l0oooo0?ooo`3oool300000080oooo00D000000?ooo`3oool0
oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0003o
103oool70000o`050?ooo`000000oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0000o`080?ooo`030000o`3oool0oooo
0080oooo0P000?l40?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool20000
o`D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00@0003o0?ooo`3oool0oooo100000030?ooo`040000o`3oool0oooo00000080oooo00<0
003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1Z
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`0;
0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`030000o`H0oooo1000
0?l00`3oool0003o0?ooo`030?ooo`L0003o1`3oool010000?l0oooo0000o`000?l30?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo0P000?l01P3oool00000
000000000000oooo0000o`D0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06/0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0U0?ooo`040000o`3oool0oooo0?ooo`<0003o1P3oool0
0`000?l0oooo0?ooo`050?ooo`<0003o0`0000050?ooo`D0003o103oool00`000000oooo0000o`1F
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06/0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo0180oooo0`00000B0?oo
o`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0J`3oool00`000?l0oooo0?ooo`040?ooo`80003o6@3oool00`000000oooo0?ooo`0A0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0?0?ooo`<0
00005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo06/0oooo1`000?lK0?ooo`030000003oool0oooo0180oooo0`000?l30?ooo`030000
o`3oool0oooo02L0oooo00<0003o0?ooo`3oool02`3oool4000001T0oooo00<0003o0000003oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo01D0oooo0`000?lZ0?ooo`030000o`3oool0oooo00P0oooo0`00000M0?ooo`030000o`00
0000oooo05D0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`1:0?ooo`<000000P3oool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0
000005D0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?ooo`<00000:P3oool00`000000
oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00
000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00000n0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3o
ool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo
0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo
000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3o
ool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@0
0000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000
T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4
000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h
0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<00000
7P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4
000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J
0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`03
0000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000
?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo
09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo
00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l
0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?oo
o`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000
GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`00
0000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M
0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?oo
o`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`03
0000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000
O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo
0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0
oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo
0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?oo
o`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool20000
08@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00
001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`80
0000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?oo
o`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`80
0000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003o
ool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool0
1@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0012
0?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3o
ool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo
0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3o
ool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0
oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3o
ool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool20000
00l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0
oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040
oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?oo
o`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F
0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0
oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000
003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`80
0000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3o
ool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool20000
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0
oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo
00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?oo
o`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D0
00008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool20000
03L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0
oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo
00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@0
00000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo
001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00
000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?oo
o`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?oo
o`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3o
ool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000
JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3o
ool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool5
00000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4
000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00
000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I
0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?oo
o`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000
VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000
WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3o
ool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool0
06D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0
oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo
0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@0
00000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo
1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`04
0?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?oo
o`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@0
0000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo
00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo
002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo
1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56596 .59245 m
.56607 .55574 L
s
.71853 .57041 m
.7204 .57218 L
s
.71673 .57212 m
.71853 .57041 L
s
.69651 .57005 m
.691 .56996 L
s
.70205 .57188 m
.69651 .57005 L
s
.7204 .57218 m
.7186 .5739 L
s
.691 .56996 m
.68552 .57162 L
s
.7186 .5739 m
.71673 .57212 L
s
.70394 .5754 m
.70205 .57188 L
s
.6653 .56955 m
.66899 .57135 L
s
.65979 .56946 m
.6653 .56955 L
s
.65613 .57114 m
.65979 .56946 L
s
.68552 .57162 m
.68373 .57508 L
s
.66899 .57135 m
.67271 .5749 L
s
.63792 .5936 m
.63774 .5691 L
s
.65249 .57457 m
.65613 .57114 L
s
.70397 .57715 m
.70394 .5754 L
s
.62313 .58635 m
.62304 .56886 L
s
.6029 .60536 m
.60282 .56853 L
s
.70219 .58062 m
.70397 .57715 L
s
.57891 .56814 m
.57339 .56805 L
s
.58259 .56995 m
.57891 .56814 L
s
.6507 .57979 m
.65249 .57457 L
s
.57339 .56805 m
.56971 .56974 L
s
.58627 .5735 m
.58259 .56995 L
s
.55303 .59225 m
.55315 .56773 L
s
.54579 .56761 m
.54946 .56941 L
s
.54026 .56752 m
.54579 .56761 L
s
.69854 .58231 m
.70219 .58062 L
s
.56971 .56974 m
.56601 .57317 L
s
.53657 .5692 m
.54026 .56752 L
s
.71923 .60721 m
.71876 .58263 L
s
.54946 .56941 m
.55312 .57297 L
s
.68937 .58391 m
.69854 .58231 L
s
.53286 .57264 m
.53657 .5692 L
s
.58811 .57878 m
.58627 .5735 L
s
.50683 .59151 m
.50712 .56698 L
s
.65073 .58329 m
.6507 .57979 L
s
.48685 .56665 m
.49051 .56846 L
s
.47948 .56653 m
.48685 .56665 L
s
.47576 .56822 m
.47948 .56653 L
s
.68572 .5856 m
.68937 .58391 L
s
.49051 .56846 m
.49415 .57201 L
s
.53097 .57786 m
.53286 .57264 L
s
.45689 .59071 m
.44998 .56605 L
s
.44208 .59047 m
.44998 .56605 L
s
.47202 .57165 m
.47576 .56822 L
s
.68393 .58908 m
.68572 .5856 L
s
.65262 .58857 m
.65073 .58329 L
s
.44208 .59047 m
.43522 .56581 L
s
.42727 .59024 m
.43522 .56581 L
s
.58811 .58228 m
.58811 .57878 L
s
.49415 .57201 m
.49595 .57554 L
s
.41431 .59003 m
.41493 .56548 L
s
.70418 .5894 m
.7024 .59288 L
s
.40754 .56536 m
.41119 .56717 L
s
.40201 .56527 m
.40754 .56536 L
s
.39827 .56696 m
.40201 .56527 L
s
.68582 .59261 m
.68393 .58908 L
s
.47011 .57512 m
.47202 .57165 L
s
.41119 .56717 m
.4148 .57073 L
s
.67288 .5889 m
.66924 .59235 L
s
.58626 .58751 m
.58811 .58228 L
s
.53094 .58136 m
.53097 .57786 L
s
.39448 .5704 m
.39827 .56696 L
s
.36799 .58929 m
.36877 .56474 L
s
.49595 .57554 m
.49588 .5808 L
s
.65634 .59214 m
.65262 .58857 L
s
.7024 .59288 m
.6969 .59455 L
s
.62132 .59158 m
.62313 .58635 L
s
.69137 .59446 m
.68582 .59261 L
s
.34291 .56432 m
.32997 .56411 L
s
.34839 .56615 m
.34291 .56432 L
s
.60286 .58602 m
.6084 .59137 L
s
.46817 .58035 m
.47011 .57512 L
s
.32859 .60101 m
.32997 .56411 L
s
.6969 .59455 m
.69137 .59446 L
s
.66924 .59235 m
.66558 .59404 L
s
.35197 .56971 m
.34839 .56615 L
s
.53275 .58665 m
.53094 .58136 L
s
.39248 .57562 m
.39448 .5704 L
s
.66005 .59396 m
.65634 .59214 L
s
.66558 .59404 m
.66005 .59396 L
s
.58257 .59096 m
.58626 .58751 L
s
.50695 .58097 m
.50874 .58627 L
s
.48664 .58065 m
.49588 .5808 L
s
.61763 .59328 m
.62132 .59158 L
s
.56597 .58718 m
.56965 .59075 L
s
.3537 .57325 m
.35197 .56971 L
s
.6084 .59137 m
.6121 .59319 L
s
.55305 .58698 m
.54934 .59043 L
s
.46802 .58913 m
.46817 .58035 L
s
.6121 .59319 m
.61763 .59328 L
s
.53641 .59022 m
.53275 .58665 L
s
.57888 .59266 m
.58257 .59096 L
s
.39238 .57913 m
.39248 .57562 L
s
.56965 .59075 m
.57334 .59257 L
s
.35537 .57854 m
.3537 .57325 L
s
.50874 .58627 m
.5124 .58984 L
s
.57334 .59257 m
.57888 .59266 L
s
.54934 .59043 m
.54564 .59213 L
s
.5401 .59204 m
.53641 .59022 L
s
.39408 .58443 m
.39238 .57913 L
s
.54564 .59213 m
.5401 .59204 L
s
.5124 .58984 m
.51607 .59166 L
s
.36833 .57874 m
.37001 .58404 L
s
.51607 .59166 m
.52162 .59174 L
s
.35507 .58732 m
.35537 .57854 L
s
.46978 .59444 m
.46802 .58913 L
s
.41444 .58475 m
.41065 .58821 L
s
.638 .60416 m
.63986 .60595 L
s
.63617 .60589 m
.638 .60416 L
s
.39769 .588 m
.39408 .58443 L
s
.63986 .60595 m
.63803 .60768 L
s
.63803 .60768 m
.63617 .60589 L
s
.37001 .58404 m
.37361 .58762 L
s
.49569 .59485 m
.49379 .59834 L
s
.41065 .58821 m
.4069 .58991 L
s
.40135 .58982 m
.39769 .588 L
s
.47157 .59799 m
.46978 .59444 L
s
.4069 .58991 m
.40135 .58982 L
s
.37361 .58762 m
.37726 .58944 L
s
.49379 .59834 m
.49004 .60181 L
s
.37726 .58944 m
.38282 .58953 L
s
.35304 .59257 m
.35507 .58732 L
s
.47522 .60157 m
.47157 .59799 L
s
.49004 .60181 m
.48631 .60351 L
s
.4789 .6034 m
.47522 .60157 L
s
.48631 .60351 m
.4789 .6034 L
s
.35106 .59607 m
.35304 .59257 L
s
.34723 .59954 m
.35106 .59607 L
s
.34159 .60122 m
.34723 .59954 L
s
.32859 .60101 m
.34159 .60122 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`00000F0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000I0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
1000000L0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`<0003o5`3oool00`000000oooo0?oo
o`0H0?ooo`<00000803oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`05
0000o`H0oooo00<0003o0?ooo`3oool02P3oool30000o`80oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo0`0000030?ooo`<0003o7@3oool0
0`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0203oool20000o`060?ooo`000000oooo0000o`3oool0003o1P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0000000800000103oool20000o`<0oooo0P00
0?l50?ooo`030000o`3oool0oooo00P0oooo1`000?l40?ooo`030000o`3oool0oooo00<0003o203o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`040000003oool0
003o0000o`D0oooo00<0003o0?ooo`000?l00`3oool20000o`030000003oool0oooo00@0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool00`3oool20000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`000?l00P000?l60?ooo`L0003o00@000000?ooo`3oool0oooo0`000?mD0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103o
ool00`000000oooo0000o`050?ooo`030000o`3oool0003o00<0000000<0003o0?ooo`000?l01@3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0000003oool00`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool0
0`000000003o0?ooo`040?ooo`030000o`000000003o00<0oooo00<0003o0?ooo`000?l01@3oool0
0`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`030000
o`000000oooo05T0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?ooo`80000000L0003o0?ooo`3oool0
oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?oo
o`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo0100oooo00<0003o0000003oool0F@3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`00000000000P3oool0
1`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo1@000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0=0?ooo`@0003o00<000000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000J`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo0080oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`0000000`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3oool01@000?l0
oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00X0oooo0`000?l30?ooo`800000103oool00`000?l0oooo0?ooo`1D0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00P0oooo00<0003o0?ooo`3o
ool00P3oool20000o`050?ooo`000000oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`020?oo
o`050000o`3oool0oooo0?ooo`000?l03P3oool20000o`P0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo0?ooo`<000000P3oool01@000000oooo0?oo
o`3oool0003o05H0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0JP3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01000
0?l50?ooo`@0003o00@0oooo0000o`3oool000000P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0003o00P0
oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo0P000?l40?ooo`030000o`3oool0oooo00D0
oooo0P000?l50?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`@000000`3oool010000?l0oooo0?ooo`000002
0?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01H0oooo00<000000?oo
o`3oool03`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0003o1P3oool40000
o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`000?l00`000?l80?ooo`030000o`3oool0003o
00D0003o1@3oool00`000?l0oooo0?ooo`030?ooo`80003o0`3oool20000o`060?ooo`0000000000
0000003oool0003o1@3oool010000?l0oooo0?ooo`0000020?ooo`030000o`3oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool04P3oool30000o`<000001@3o
ool50000o`@0oooo00<000000?ooo`000?l0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool05`3oool0
0`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool0
0`000?l0oooo0?ooo`0B0?ooo`<000004P3oool00`000000003o0?ooo`1E0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo06/0oooo20000?lJ0?ooo`030000003oool0oooo
0180oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0W0?ooo`030000o`3oool0oooo
00l0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0C0?ooo`H0003o:@3oool00`000?l0
oooo0?ooo`0:0?ooo`030000o`0000000000008000006@3oool00`000?l000000?ooo`1D0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
@P3oool00`000?l0oooo0?ooo`080?ooo`<000007@3oool00`000?l000000?ooo`1E0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0BP3o
ool300000080oooo00<0003o0?ooo`3oool06`3oool00`000?l0oooo0000001E0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3
000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool20000
08l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400
oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3
000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool30000
08h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?oo
o`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<0
0000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4
000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool30000
02/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?oo
o`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3o
ool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool30000
04/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?oo
o`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0
oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00
002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00
001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0
oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo
0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0013
0?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00
B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;
0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003o
ool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo
0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?oo
o`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003o
ool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0
f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`00
0000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0
oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo
1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000
000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?oo
o`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`80
0000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0
oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo
0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0
oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0
oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0
oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo
0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M
0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q
0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?oo
o`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3
000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo
0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A
0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?oo
o`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000
003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303o
ool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03o
ool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2
000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo
0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool50000
0;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0
oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0
oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo
0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:
0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo0000
00H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo
0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56604 .59167 m
.56581 .55832 L
s
.71817 .57184 m
.72008 .57346 L
s
.71641 .5734 m
.71817 .57184 L
s
.69618 .57149 m
.69068 .5714 L
s
.70175 .57316 m
.69618 .57149 L
s
.69068 .5714 m
.68524 .57289 L
s
.72008 .57346 m
.71832 .57501 L
s
.71832 .57501 m
.71641 .5734 L
s
.66501 .57098 m
.66873 .57262 L
s
.65951 .57089 m
.66501 .57098 L
s
.70371 .57636 m
.70175 .57316 L
s
.65589 .57242 m
.65951 .57089 L
s
.68524 .57289 m
.68353 .57603 L
s
.63806 .59282 m
.6375 .57054 L
s
.66873 .57262 m
.67251 .57585 L
s
.62316 .58619 m
.62282 .5703 L
s
.65231 .57553 m
.65589 .57242 L
s
.60317 .6035 m
.60262 .56997 L
s
.57874 .56958 m
.57323 .56949 L
s
.58244 .57123 m
.57874 .56958 L
s
.70378 .57794 m
.70371 .57636 L
s
.57323 .56949 m
.56957 .57102 L
s
.5531 .59146 m
.55302 .56917 L
s
.54567 .56905 m
.54935 .57069 L
s
.54015 .56896 m
.54567 .56905 L
s
.58615 .57446 m
.58244 .57123 L
s
.53647 .57048 m
.54015 .56896 L
s
.70208 .58109 m
.70378 .57794 L
s
.56957 .57102 m
.56592 .57413 L
s
.65061 .58026 m
.65231 .57553 L
s
.54935 .57069 m
.55304 .57392 L
s
.50687 .59072 m
.50705 .56842 L
s
.53279 .5736 m
.53647 .57048 L
s
.48681 .56809 m
.49047 .56974 L
s
.47945 .56797 m
.48681 .56809 L
s
.47574 .5695 m
.47945 .56797 L
s
.58805 .57925 m
.58615 .57446 L
s
.45689 .58992 m
.44999 .5675 L
s
.44207 .58968 m
.44999 .5675 L
s
.69847 .58262 m
.70208 .58109 L
s
.49047 .56974 m
.49412 .57297 L
s
.44207 .58968 m
.43526 .56726 L
s
.42725 .58945 m
.43526 .56726 L
s
.472 .57261 m
.47574 .5695 L
s
.71972 .60535 m
.71868 .58295 L
s
.41428 .58924 m
.41499 .56693 L
s
.40762 .56681 m
.41125 .56846 L
s
.40209 .56672 m
.40762 .56681 L
s
.53094 .57833 m
.53279 .5736 L
s
.68934 .58407 m
.69847 .58262 L
s
.39834 .56825 m
.40209 .56672 L
s
.6507 .58344 m
.65061 .58026 L
s
.41125 .56846 m
.41484 .57169 L
s
.36792 .5885 m
.3689 .56618 L
s
.49412 .57297 m
.49592 .57618 L
s
.39454 .57136 m
.39834 .56825 L
s
.68572 .5856 m
.68934 .58407 L
s
.47011 .57576 m
.472 .57261 L
s
.34307 .56576 m
.33015 .56556 L
s
.34853 .56744 m
.34307 .56576 L
s
.58809 .58244 m
.58805 .57925 L
s
.32834 .59913 m
.33015 .56556 L
s
.65268 .58826 m
.6507 .58344 L
s
.35207 .57068 m
.34853 .56744 L
s
.684 .58876 m
.68572 .5856 L
s
.49592 .57618 m
.49587 .58095 L
s
.53093 .58152 m
.53094 .57833 L
s
.39251 .5761 m
.39454 .57136 L
s
.46817 .58051 m
.47011 .57576 L
s
.5863 .58719 m
.58809 .58244 L
s
.70425 .58909 m
.70255 .59225 L
s
.35376 .57389 m
.35207 .57068 L
s
.68596 .59199 m
.684 .58876 L
s
.67295 .58858 m
.66937 .59172 L
s
.62142 .59095 m
.62316 .58619 L
s
.53277 .58634 m
.53093 .58152 L
s
.65646 .59151 m
.65268 .58826 L
s
.60288 .58586 m
.6085 .59075 L
s
.50695 .58113 m
.50875 .58595 L
s
.48664 .58081 m
.49587 .58095 L
s
.70255 .59225 m
.69708 .59376 L
s
.35538 .5787 m
.35376 .57389 L
s
.39239 .57929 m
.39251 .5761 L
s
.69155 .59367 m
.68596 .59199 L
s
.46803 .5885 m
.46817 .58051 L
s
.58265 .59033 m
.5863 .58719 L
s
.66937 .59172 m
.66574 .59326 L
s
.6602 .59317 m
.65646 .59151 L
s
.69708 .59376 m
.69155 .59367 L
s
.566 .58687 m
.56972 .59013 L
s
.55308 .58666 m
.5494 .5898 L
s
.66574 .59326 m
.6602 .59317 L
s
.61776 .59249 m
.62142 .59095 L
s
.53646 .58959 m
.53277 .58634 L
s
.6085 .59075 m
.61222 .59241 L
s
.39406 .58411 m
.39239 .57929 L
s
.50875 .58595 m
.51243 .58921 L
s
.57897 .59187 m
.58265 .59033 L
s
.36834 .5789 m
.36998 .58373 L
s
.61222 .59241 m
.61776 .59249 L
s
.56972 .59013 m
.57343 .59179 L
s
.35501 .58669 m
.35538 .5787 L
s
.5494 .5898 m
.54571 .59134 L
s
.57343 .59179 m
.57897 .59187 L
s
.54016 .59125 m
.53646 .58959 L
s
.51243 .58921 m
.51612 .59087 L
s
.54571 .59134 m
.54016 .59125 L
s
.41443 .58444 m
.41062 .58758 L
s
.51612 .59087 m
.52167 .59096 L
s
.39765 .58737 m
.39406 .58411 L
s
.46979 .59334 m
.46803 .5885 L
s
.36998 .58373 m
.37355 .58699 L
s
.41062 .58758 m
.40686 .58912 L
s
.4013 .58903 m
.39765 .58737 L
s
.37355 .58699 m
.37719 .58865 L
s
.49573 .59375 m
.49384 .59693 L
s
.40686 .58912 m
.4013 .58903 L
s
.35292 .59147 m
.35501 .58669 L
s
.47159 .59658 m
.46979 .59334 L
s
.6383 .60245 m
.6402 .60409 L
s
.63649 .60403 m
.6383 .60245 L
s
.37719 .58865 m
.38276 .58874 L
s
.6402 .60409 m
.63839 .60567 L
s
.63839 .60567 m
.63649 .60403 L
s
.49384 .59693 m
.49009 .60009 L
s
.47525 .59985 m
.47159 .59658 L
s
.35091 .59466 m
.35292 .59147 L
s
.49009 .60009 m
.48636 .60164 L
s
.47893 .60152 m
.47525 .59985 L
s
.48636 .60164 m
.47893 .60152 L
s
.34704 .59782 m
.35091 .59466 L
s
.34137 .59934 m
.34704 .59782 L
s
.32834 .59913 m
.34137 .59934 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<000006@3oool00`000?l0
oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000703oool00`000?l0oooo
0?ooo`0a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000803oool00`000?l0oooo0?oo
o`0a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0JP3oool60000o`P0oooo00<0003o0?ooo`3oool02P3oool30000oa@0oooo0`00000S
0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00<0oooo0P000?l60?oo
o`030000o`3oool0oooo00P0oooo0P000?l01P3oool000000?ooo`000?l0oooo0000o`H0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo00000002000000@0oooo1@000?l70?ooo`030000o`3o
ool0oooo00T0oooo0`000?l20?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o
<03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo06X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool010000000oooo0000o`000?l60?ooo`030000
o`3oool0oooo0080oooo00<000000000o`0000001P3oool00`000?l0oooo0?ooo`030?ooo`80003o
1@3oool00`000?l0oooo0?ooo`080?ooo`040000o`3oool0oooo0?ooo`<0003o103oool30000o`04
0?ooo`000?l0003o0000o`L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00D0oooo0`000?l80?ooo`@0003o0P3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0003o00D0oooo00<0003o0?ooo`00
0?l00`0000020000o`L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3o
ool00`3oool20000o`@0oooo0P000?l010000000oooo0?ooo`3oool20000oeD0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
000000000?l0oooo00@0oooo00<0003o000000000?l00`3oool00`000?l0oooo0000o`050?ooo`03
0000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo00<0003o0?ooo`3oool0103oool00`00
0?l000000?ooo`030?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?oo
o`80000000@0003o0?ooo`3oool0003o0P3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3o
ool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0403oool00`000?l000000?ooo`1I0?ooo`030000003oool0oooo01<0oooo
000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0000
000000020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo10000?l00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000J`3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo0080oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`00
00000`3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00X0oooo0`000?l30?ooo`800000103oool00`000?l0oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00P0oooo00<0003o0?oo
o`3oool00P3oool20000o`050?ooo`000000oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool20000o`P0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo0?ooo`<000000P3oool01@000000oooo
0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
10000?l50?ooo`@0003o00@0oooo0000o`3oool000000P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0003o
00<0003o1@3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool20000o`@0oooo0P000?l60?oo
o`<0003o103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0103oool010000?l0oooo0?ooo`3oool4000000@0oooo00<0003o0?ooo`0000000P3oool0
0`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo
0100oooo00<0003o0?ooo`3oool05`3oool40000o`030?ooo`000?l0oooo00<0oooo00<0003o0?oo
o`000?l00`000?l80?ooo`030000o`3oool0oooo00@0003o1P3oool00`000?l0oooo0?ooo`040?oo
o`H0003o00H0oooo00000000000000000?ooo`000?l50?ooo`040000o`3oool0oooo00000080oooo
00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?oo
o`0@0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?oo
o`0E0?ooo`<000001@3oool50000o`@0oooo00<000000?ooo`000?l0EP3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00@0oooo0P000?lI
0?ooo`030000003oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0V
0?ooo`030000o`3oool0oooo0180oooo0`00000B0?ooo`03000000000?l0oooo05D0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0J`3oool70000oa/0oooo00<000000?oo
o`3oool04P3oool70000obT0oooo00<0003o0?ooo`3oool03`3oool3000001H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo0480oooo00<0003o0?ooo`3oool02@3oool20000o`@000006@3oool00`000?l0
00000?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0C@3oool3000001d0oooo00<0003o0000003oool0E@3oool00`000000oooo
0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00
000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?oo
o`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00
001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?oo
o`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
7P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3o
ool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00
001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?oo
o`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool0
0200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`000009
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3
000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<0
00000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3
000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`000018
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3
000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z
0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`80
00009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3
000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;
0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000
T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?oo
o`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
0980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`00
8P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2
000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`24
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000
003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03o
ool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2
000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo
0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003o
ool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool20000
06T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool20000
0680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00
000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m
0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?oo
o`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3o
ool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00
001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P
0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080
oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo1000
00050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A
0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?oo
o`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool0
0`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80
oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo
1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000
000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?oo
o`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`80
00003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D0
0000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3o
ool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00
J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2
000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo
000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool00000
02H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000
oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<0
00000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O
0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?oo
o`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@0
0000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3o
ool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2
000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000
oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/
0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`00
00008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@0
0000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`03
0000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2
000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<0
00000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56612 .59053 m
.56556 .56199 L
s
.71784 .5739 m
.71978 .57528 L
s
.71612 .57522 m
.71784 .5739 L
s
.69588 .57354 m
.69039 .57345 L
s
.70147 .57498 m
.69588 .57354 L
s
.69039 .57345 m
.68499 .57472 L
s
.66475 .57304 m
.6685 .57445 L
s
.65925 .57295 m
.66475 .57304 L
s
.71978 .57528 m
.71806 .5766 L
s
.71806 .5766 m
.71612 .57522 L
s
.65567 .57424 m
.65925 .57295 L
s
.70351 .57772 m
.70147 .57498 L
s
.63819 .59168 m
.63727 .57259 L
s
.68499 .57472 m
.68334 .5774 L
s
.62318 .58596 m
.6226 .57235 L
s
.6685 .57445 m
.67233 .57722 L
s
.60342 .60078 m
.60243 .57203 L
s
.65215 .5769 m
.65567 .57424 L
s
.57859 .57164 m
.57308 .57155 L
s
.58229 .57306 m
.57859 .57164 L
s
.57308 .57155 m
.56944 .57285 L
s
.55317 .59032 m
.55289 .57123 L
s
.54555 .57111 m
.54924 .57252 L
s
.54004 .57102 m
.54555 .57111 L
s
.53638 .57231 m
.54004 .57102 L
s
.70361 .57908 m
.70351 .57772 L
s
.58604 .57583 m
.58229 .57306 L
s
.56944 .57285 m
.56582 .5755 L
s
.50691 .58958 m
.50698 .57048 L
s
.54924 .57252 m
.55295 .57529 L
s
.48677 .57016 m
.49043 .57157 L
s
.47941 .57004 m
.48677 .57016 L
s
.65053 .58095 m
.65215 .5769 L
s
.53272 .57497 m
.53638 .57231 L
s
.47571 .57133 m
.47941 .57004 L
s
.70198 .58177 m
.70361 .57908 L
s
.45689 .58878 m
.44999 .56956 L
s
.44207 .58855 m
.44999 .56956 L
s
.44207 .58855 m
.43528 .56932 L
s
.42723 .58831 m
.43528 .56932 L
s
.49043 .57157 m
.49408 .57434 L
s
.47199 .57399 m
.47571 .57133 L
s
.58799 .57994 m
.58604 .57583 L
s
.41425 .5881 m
.41503 .56899 L
s
.40767 .56888 m
.41129 .57029 L
s
.40215 .56879 m
.40767 .56888 L
s
.3984 .57008 m
.40215 .56879 L
s
.36786 .58736 m
.369 .56825 L
s
.6984 .58308 m
.70198 .58177 L
s
.53091 .57902 m
.53272 .57497 L
s
.41129 .57029 m
.41487 .57306 L
s
.3432 .56783 m
.3303 .56762 L
s
.34864 .56928 m
.3432 .56783 L
s
.39458 .57274 m
.3984 .57008 L
s
.32814 .5964 m
.3303 .56762 L
s
.49408 .57434 m
.4959 .57709 L
s
.72016 .60264 m
.71861 .5834 L
s
.65068 .58367 m
.65053 .58095 L
s
.68931 .58429 m
.6984 .58308 L
s
.47009 .57668 m
.47199 .57399 L
s
.35215 .57205 m
.34864 .56928 L
s
.58807 .58267 m
.58799 .57994 L
s
.68572 .5856 m
.68931 .58429 L
s
.39254 .57679 m
.39458 .57274 L
s
.4959 .57709 m
.49586 .58118 L
s
.65274 .5878 m
.65068 .58367 L
s
.53092 .58175 m
.53091 .57902 L
s
.46817 .58074 m
.47009 .57668 L
s
.35381 .5748 m
.35215 .57205 L
s
.68406 .58831 m
.68572 .5856 L
s
.58634 .58674 m
.58807 .58267 L
s
.70432 .58863 m
.70268 .59134 L
s
.53279 .58588 m
.53092 .58175 L
s
.3554 .57892 m
.35381 .5748 L
s
.68609 .59108 m
.68406 .58831 L
s
.62151 .59004 m
.62318 .58596 L
s
.50694 .58136 m
.50877 .58549 L
s
.3924 .57952 m
.39254 .57679 L
s
.67301 .58813 m
.66949 .59081 L
s
.48664 .58103 m
.49586 .58118 L
s
.6029 .58564 m
.60858 .58984 L
s
.65658 .59061 m
.65274 .5878 L
s
.46804 .58759 m
.46817 .58074 L
s
.70268 .59134 m
.69725 .59263 L
s
.58272 .58942 m
.58634 .58674 L
s
.69172 .59254 m
.68609 .59108 L
s
.56604 .58641 m
.56979 .58922 L
s
.39405 .58365 m
.3924 .57952 L
s
.66949 .59081 m
.66588 .59213 L
s
.55311 .58621 m
.54945 .58889 L
s
.66035 .59204 m
.65658 .59061 L
s
.36835 .57913 m
.36996 .58327 L
s
.53651 .58868 m
.53279 .58588 L
s
.69725 .59263 m
.69172 .59254 L
s
.35496 .58578 m
.3554 .57892 L
s
.50877 .58549 m
.51246 .5883 L
s
.61787 .59136 m
.62151 .59004 L
s
.66588 .59213 m
.66035 .59204 L
s
.60858 .58984 m
.61233 .59127 L
s
.57906 .59074 m
.58272 .58942 L
s
.56979 .58922 m
.57351 .59065 L
s
.61233 .59127 m
.61787 .59136 L
s
.54945 .58889 m
.54577 .5902 L
s
.54022 .59012 m
.53651 .58868 L
s
.41442 .58398 m
.4106 .58667 L
s
.57351 .59065 m
.57906 .59074 L
s
.51246 .5883 m
.51616 .58973 L
s
.39762 .58646 m
.39405 .58365 L
s
.54577 .5902 m
.54022 .59012 L
s
.36996 .58327 m
.37351 .58607 L
s
.46981 .59174 m
.46804 .58759 L
s
.51616 .58973 m
.52172 .58982 L
s
.4106 .58667 m
.40683 .58798 L
s
.40127 .58789 m
.39762 .58646 L
s
.37351 .58607 m
.37714 .58751 L
s
.35283 .58987 m
.35496 .58578 L
s
.40683 .58798 m
.40127 .58789 L
s
.37714 .58751 m
.38271 .5876 L
s
.49577 .59216 m
.49389 .59489 L
s
.47162 .59453 m
.46981 .59174 L
s
.63859 .59996 m
.64051 .60137 L
s
.6368 .60131 m
.63859 .59996 L
s
.49389 .59489 m
.49015 .59759 L
s
.47529 .59736 m
.47162 .59453 L
s
.64051 .60137 m
.63872 .60272 L
s
.35079 .5926 m
.35283 .58987 L
s
.63872 .60272 m
.6368 .60131 L
s
.49015 .59759 m
.48642 .59892 L
s
.47898 .5988 m
.47529 .59736 L
s
.34688 .59531 m
.35079 .5926 L
s
.48642 .59892 m
.47898 .5988 L
s
.34119 .59661 m
.34688 .59531 L
s
.32814 .5964 m
.34119 .59661 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
000P0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000S
0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`P0003o1P3oool00`000?l0oooo0?ooo`0:0?oo
o`<0003o0P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo0`00000V0?oo
o`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`080?ooo`80003o0P3oool010000000003o0?ooo`000?l60?oo
o`030000o`3oool0oooo0080oooo00<000000000o`0000001`3oool70000o`D0oooo00<0003o0?oo
o`3oool02@3oool30000o`80oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030000
o`P0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000000
003o0000o`050?ooo`030000o`3oool0003o00<0000000<0oooo0000o`3oool01P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool010000?l0
oooo0?ooo`3oool30000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1P000?l50?oo
o`D0003o0`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
000000000?l0oooo00@0oooo00<0003o000000000?l00`3oool00`000?l0oooo0000o`050?ooo`03
0000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`090?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool20000
o`030?ooo`000000oooo0080oooo0P000?mE0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l000000?ooo`3oool20000
00040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`08
0?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o01<0oooo
00<0003o0000003oool0F@3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`00000000000P3oool01`000?l0oooo
0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00@0oooo1@000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0C
0?ooo`030000o`000000oooo05T0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00001[0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`P0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo000000030?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool20000o`L0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`H0003o0P0000040?ooo`030000o`3o
ool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0JP3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l010000?l4
0?ooo`L0003o00D0oooo0000003oool0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00D0
003o0?ooo`3oool0oooo0000o`0>0?ooo`80003o203oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`<000000P3oool01@000000
oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01H0oooo00@000000?ooo`3o
ool0003o1@3oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool0
0`000?l0oooo0000o`030000o`D0oooo1`000?l40?ooo`P0003o1P3oool30000o`@0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`80003o103oool00`000?l0oooo0?ooo`02
0?ooo`@00000103oool00`000?l0oooo000000020?ooo`030000o`3oool0oooo05@0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0403oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool010000?l60?ooo`030000o`3oool0oooo
00D0oooo10000?l20?ooo`<0000000<0oooo0000o`000?l01@000?l20?ooo`040000003oool0oooo
0000oeH0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0J`3oool00`00
0?l0oooo0?ooo`040?ooo`80003o6@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0E0?ooo`<000003P3oool00`00
0000oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06/0
oooo1`000?lK0?ooo`030000003oool0oooo0180oooo1`000?lY0?ooo`030000o`3oool0oooo0180
oooo0`00000B0?ooo`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`120?ooo`030000o`3oool0oooo00T0oooo
0`000?l30?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0C`3oool00`000?l000000000
0002000001T0oooo00<0003o0000003oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000N0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo
00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000
000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3o
ool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo
00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?oo
o`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000
JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool3
00000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000
oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l
0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56619 .58909 m
.56532 .56659 L
s
.71756 .57648 m
.71953 .57757 L
s
.71587 .57751 m
.71756 .57648 L
s
.69562 .57612 m
.69013 .57603 L
s
.70123 .57728 m
.69562 .57612 L
s
.69013 .57603 m
.68476 .57701 L
s
.66452 .57562 m
.66829 .57674 L
s
.65903 .57553 m
.66452 .57562 L
s
.65547 .57654 m
.65903 .57553 L
s
.71953 .57757 m
.71784 .57861 L
s
.71784 .57861 m
.71587 .57751 L
s
.63831 .59025 m
.63706 .57517 L
s
.70333 .57945 m
.70123 .57728 L
s
.6232 .58567 m
.62241 .57494 L
s
.68476 .57701 m
.68317 .57912 L
s
.60365 .59732 m
.60226 .57461 L
s
.66829 .57674 m
.67217 .57894 L
s
.652 .57862 m
.65547 .57654 L
s
.57844 .57423 m
.57294 .57414 L
s
.58216 .57535 m
.57844 .57423 L
s
.57294 .57414 m
.56932 .57515 L
s
.55324 .58888 m
.55277 .57381 L
s
.54544 .57369 m
.54914 .57482 L
s
.53994 .5736 m
.54544 .57369 L
s
.53629 .57461 m
.53994 .5736 L
s
.58594 .57755 m
.58216 .57535 L
s
.50695 .58814 m
.50691 .57307 L
s
.56932 .57515 m
.56573 .57723 L
s
.70346 .58052 m
.70333 .57945 L
s
.48671 .57274 m
.49038 .57387 L
s
.47937 .57263 m
.48671 .57274 L
s
.54914 .57482 m
.55287 .57702 L
s
.47568 .57363 m
.47937 .57263 L
s
.53266 .57669 m
.53629 .57461 L
s
.45691 .58734 m
.44998 .57215 L
s
.44207 .5871 m
.44998 .57215 L
s
.65046 .58181 m
.652 .57862 L
s
.44207 .5871 m
.43528 .57191 L
s
.42723 .58687 m
.43528 .57191 L
s
.70189 .58263 m
.70346 .58052 L
s
.49038 .57387 m
.49404 .57607 L
s
.41424 .58666 m
.41505 .57159 L
s
.4077 .57147 m
.41132 .57259 L
s
.40218 .57138 m
.4077 .57147 L
s
.47196 .57571 m
.47568 .57363 L
s
.39843 .57239 m
.40218 .57138 L
s
.58794 .5808 m
.58594 .57755 L
s
.36782 .58591 m
.36906 .57084 L
s
.34329 .57043 m
.3304 .57022 L
s
.34872 .57158 m
.34329 .57043 L
s
.41132 .57259 m
.41488 .57479 L
s
.32799 .59293 m
.3304 .57022 L
s
.39461 .57447 m
.39843 .57239 L
s
.53087 .57988 m
.53266 .57669 L
s
.69834 .58365 m
.70189 .58263 L
s
.49404 .57607 m
.49587 .57824 L
s
.3522 .57378 m
.34872 .57158 L
s
.47008 .57783 m
.47196 .57571 L
s
.65065 .58396 m
.65046 .58181 L
s
.72055 .59919 m
.71855 .58398 L
s
.68928 .58458 m
.69834 .58365 L
s
.39255 .57765 m
.39461 .57447 L
s
.58805 .58295 m
.58794 .5808 L
s
.49587 .57824 m
.49586 .58147 L
s
.35385 .57596 m
.3522 .57378 L
s
.68572 .5856 m
.68928 .58458 L
s
.46817 .58103 m
.47008 .57783 L
s
.53091 .58203 m
.53087 .57988 L
s
.65279 .58723 m
.65065 .58396 L
s
.68412 .58773 m
.68572 .5856 L
s
.58638 .58616 m
.58805 .58295 L
s
.35541 .57921 m
.35385 .57596 L
s
.53281 .5853 m
.53091 .58203 L
s
.3924 .57981 m
.39255 .57765 L
s
.50693 .58165 m
.50879 .58492 L
s
.70438 .58806 m
.7028 .5902 L
s
.48663 .58132 m
.49586 .58147 L
s
.62159 .58889 m
.6232 .58567 L
s
.6862 .58993 m
.68412 .58773 L
s
.46805 .58643 m
.46817 .58103 L
s
.67306 .58755 m
.6696 .58966 L
s
.60292 .58535 m
.60866 .58869 L
s
.65668 .58946 m
.65279 .58723 L
s
.39404 .58308 m
.3924 .57981 L
s
.58279 .58827 m
.58638 .58616 L
s
.36836 .57942 m
.36995 .58269 L
s
.56607 .58584 m
.56985 .58806 L
s
.7028 .5902 m
.6974 .59119 L
s
.35492 .58462 m
.35541 .57921 L
s
.55314 .58563 m
.5495 .58774 L
s
.69186 .5911 m
.6862 .58993 L
s
.53656 .58753 m
.53281 .5853 L
s
.6696 .58966 m
.66601 .59069 L
s
.66047 .5906 m
.65668 .58946 L
s
.50879 .58492 m
.5125 .58715 L
s
.6974 .59119 m
.69186 .5911 L
s
.61798 .58992 m
.62159 .58889 L
s
.60866 .58869 m
.61243 .58983 L
s
.66601 .59069 m
.66047 .5906 L
s
.57914 .5893 m
.58279 .58827 L
s
.56985 .58806 m
.57359 .58921 L
s
.41442 .5834 m
.41059 .58551 L
s
.5495 .58774 m
.54583 .58876 L
s
.61243 .58983 m
.61798 .58992 L
s
.54028 .58868 m
.53656 .58753 L
s
.3976 .5853 m
.39404 .58308 L
s
.5125 .58715 m
.51621 .58829 L
s
.57359 .58921 m
.57914 .5893 L
s
.36995 .58269 m
.37348 .58492 L
s
.54583 .58876 m
.54028 .58868 L
s
.46984 .58972 m
.46805 .58643 L
s
.51621 .58829 m
.52176 .58838 L
s
.41059 .58551 m
.40682 .58654 L
s
.40125 .58645 m
.3976 .5853 L
s
.37348 .58492 m
.37711 .58606 L
s
.35276 .58785 m
.35492 .58462 L
s
.40682 .58654 m
.40125 .58645 L
s
.37711 .58606 m
.38268 .58615 L
s
.49582 .59014 m
.49395 .59229 L
s
.47165 .59194 m
.46984 .58972 L
s
.63884 .59679 m
.64079 .59792 L
s
.63708 .59786 m
.63884 .59679 L
s
.49395 .59229 m
.49022 .59442 L
s
.3507 .59 m
.35276 .58785 L
s
.47534 .59418 m
.47165 .59194 L
s
.64079 .59792 m
.63903 .59898 L
s
.63903 .59898 m
.63708 .59786 L
s
.49022 .59442 m
.48649 .59546 L
s
.34677 .59213 m
.3507 .59 L
s
.47904 .59534 m
.47534 .59418 L
s
.48649 .59546 m
.47904 .59534 L
s
.34106 .59314 m
.34677 .59213 L
s
.32799 .59293 m
.34106 .59314 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000008`3oool00`000?l0oooo0?ooo`0a
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000009P3oool00`000?l0oooo0?ooo`0a0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool80000o`H0oooo00<0003o0?ooo`3oool02P3oool30000o`80oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`020?ooo`03000000000?l0000002T0oooo00<0003o0?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo06X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00L0oooo0`000?l30?ooo`<0003o1@3oool20000o`040?ooo`000000000000000080
003o203oool70000o`D0oooo00<0003o0?ooo`3oool0203oool70000o`@0oooo00<0003o0?ooo`3o
ool00`000?l70?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<000000000o`3oool0103oool00`000?l000000000o`030?ooo`030000o`3oool0003o00H0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo
0P000?l60?ooo`030000o`3oool0oooo0080oooo0`000?l30?ooo`80003o1@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool60000o`D0oooo
1`000?l00`3oool000000?ooo`020?ooo`80003oE@3oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0000003oool0oooo
0P00000010000?l0oooo0?ooo`000?l20?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?oo
o`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`80003o0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`000000
oooo00<0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000
o`L0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0000000000020?ooo`070000o`3oool0
oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
103oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0140oooo00<0003o0000003oool0F@3oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000006/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0003o00L0oooo0P000?l40?ooo`80003o00D0oooo0000003oool0oooo0000o`040?ooo`80003o
103oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0P000?l80?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo0P000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0:0?ooo`H0003o0P0000040?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool010000?l50?ooo`@0003o00@0oooo0000o`3oool0
00000P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0000o`0>0?ooo`030000o`3oool0003o00P0oooo00<0003o0?ooo`3oool00P3oool20000
o`@0oooo0P000?l40?ooo`<0003o1@3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`03
0?ooo`<0000000<0oooo0000o`0000000`3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`040?ooo`<0003o1P3oool40000o`030?ooo`000?l0oooo00<0oooo00<0003o0?oo
o`000?l00`000?l80?ooo`030000o`3oool0003o00D0003o1@3oool00`000?l0oooo0?ooo`030?oo
o`L0003o103oool4000000<0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo2@000?lI0?oo
o`030000003oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0V0?oo
o`030000o`3oool0oooo01P0oooo0`0000020?ooo`D0003o0`3oool010000000oooo0?ooo`000?mF
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool04P3oool70000obT0oooo00<0003o0?ooo`3oool05@3oool3000000h0oooo00@000000?oo
o`3oool0003oE@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0480oooo00<0003o0?ooo`3oool02@3oool30000o`H0oooo0`00000B0?oo
o`030000003oool0003o05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000003o0?ooo`1D0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
D03oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000N0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo
1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool30000
04h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0
oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?
0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@0
0000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000
K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool40000
07X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?oo
o`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03o
ool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<00000
0?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<0
00006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3o
ool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003o
ool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0
oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<0
0000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0
UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool0
0`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool0
01`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo
0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0
oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?oo
o`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<0
0000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0
oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000
oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?oo
o`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<0
0000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0
Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003o
ool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0
oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000
oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo
0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool0
0`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool0
01P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000
oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3o
ool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo
0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<
0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`06
0?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?oo
o`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?oo
o`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo
0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0
oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo
00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo
000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?oo
o`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l
0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`05
0?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3o
ool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo
0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3o
ool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000
003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000
001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<00000
0?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?oo
o`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000
003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03o
ool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<00000
0?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?oo
o`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000
003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3o
ool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003o
ool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool0
10000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0
oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo
0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00
001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3o
ool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0
oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool0
0`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3o
ool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000
oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo
1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00
000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K
0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`03
0000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000
?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3o
ool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool0
0`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo
0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40
oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo
1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo
0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?oo
o`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo
001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo
0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?oo
o`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`22
0?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?oo
o`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?oo
o`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00
QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool01000
0000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool30000
01l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?oo
o`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>
0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?oo
o`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00
UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003o
ool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003o
ool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool2
00000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool01000
0000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool4
00000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool20000
00h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280
oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0
oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo
00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo
0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`00
00000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3o
ool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F
0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?oo
o`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000
003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0
oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00
003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56626 .58741 m
.56512 .5719 L
s
.71733 .57947 m
.71932 .58023 L
s
.71567 .58018 m
.71733 .57947 L
s
.6954 .57912 m
.68992 .57903 L
s
.70104 .57994 m
.6954 .57912 L
s
.68992 .57903 m
.68458 .57967 L
s
.66433 .57861 m
.66812 .57941 L
s
.65884 .57853 m
.66433 .57861 L
s
.65531 .5792 m
.65884 .57853 L
s
.71932 .58023 m
.71766 .58094 L
s
.71766 .58094 m
.71567 .58018 L
s
.6384 .58857 m
.63689 .57817 L
s
.70318 .58144 m
.70104 .57994 L
s
.62322 .58534 m
.62226 .57794 L
s
.68458 .57967 m
.68303 .58112 L
s
.60385 .59329 m
.60212 .57761 L
s
.66812 .57941 m
.67204 .58094 L
s
.65188 .58062 m
.65531 .5792 L
s
.57832 .57723 m
.57282 .57714 L
s
.58205 .57802 m
.57832 .57723 L
s
.57282 .57714 m
.56922 .57781 L
s
.5533 .58721 m
.55267 .57681 L
s
.54534 .5767 m
.54905 .57749 L
s
.53984 .57661 m
.54534 .5767 L
s
.53621 .57728 m
.53984 .57661 L
s
.50699 .58646 m
.50684 .57607 L
s
.58585 .57955 m
.58205 .57802 L
s
.56922 .57781 m
.56566 .57923 L
s
.48666 .57575 m
.49033 .57654 L
s
.47932 .57563 m
.48666 .57575 L
s
.47564 .57631 m
.47932 .57563 L
s
.70334 .58218 m
.70318 .58144 L
s
.54905 .57749 m
.5528 .57902 L
s
.5326 .5787 m
.53621 .57728 L
s
.45692 .58566 m
.44995 .57516 L
s
.44208 .58542 m
.44995 .57516 L
s
.44208 .58542 m
.43526 .57492 L
s
.42723 .58518 m
.43526 .57492 L
s
.6504 .58281 m
.65188 .58062 L
s
.41424 .58498 m
.41505 .57459 L
s
.49033 .57654 m
.494 .57807 L
s
.4077 .57447 m
.41132 .57527 L
s
.40219 .57439 m
.4077 .57447 L
s
.39844 .57506 m
.40219 .57439 L
s
.47193 .57772 m
.47564 .57631 L
s
.70181 .58364 m
.70334 .58218 L
s
.36781 .58423 m
.3691 .57385 L
s
.5879 .5818 m
.58585 .57955 L
s
.34335 .57344 m
.33047 .57323 L
s
.34876 .57426 m
.34335 .57344 L
s
.41132 .57527 m
.41488 .5768 L
s
.32791 .58888 m
.33047 .57323 L
s
.39462 .57647 m
.39844 .57506 L
s
.53084 .58089 m
.5326 .5787 L
s
.35223 .57579 m
.34876 .57426 L
s
.494 .57807 m
.49584 .57958 L
s
.47006 .57917 m
.47193 .57772 L
s
.69829 .58432 m
.70181 .58364 L
s
.65063 .58429 m
.6504 .58281 L
s
.72086 .59516 m
.71849 .58464 L
s
.39255 .57866 m
.39462 .57647 L
s
.68925 .58491 m
.69829 .58432 L
s
.58804 .58329 m
.5879 .5818 L
s
.35387 .5773 m
.35223 .57579 L
s
.49584 .57958 m
.49585 .58181 L
s
.46816 .58136 m
.47006 .57917 L
s
.68572 .5856 m
.68925 .58491 L
s
.5309 .58237 m
.53084 .58089 L
s
.65283 .58656 m
.65063 .58429 L
s
.68417 .58706 m
.68572 .5856 L
s
.5864 .58549 m
.58804 .58329 L
s
.35541 .57955 m
.35387 .5773 L
s
.39241 .58014 m
.39255 .57866 L
s
.53284 .58463 m
.5309 .58237 L
s
.50692 .58198 m
.5088 .58425 L
s
.48662 .58166 m
.49585 .58181 L
s
.70443 .58739 m
.7029 .58886 L
s
.62166 .58755 m
.62322 .58534 L
s
.46807 .58509 m
.46816 .58136 L
s
.6863 .58859 m
.68417 .58706 L
s
.60294 .58501 m
.60873 .58735 L
s
.67311 .58689 m
.66968 .58832 L
s
.65676 .58812 m
.65283 .58656 L
s
.39404 .58241 m
.39241 .58014 L
s
.36836 .57976 m
.36994 .58202 L
s
.3549 .58327 m
.35541 .57955 L
s
.58285 .58693 m
.5864 .58549 L
s
.56609 .58517 m
.5699 .58672 L
s
.55316 .58496 m
.54955 .5864 L
s
.7029 .58886 m
.69752 .58952 L
s
.5366 .58619 m
.53284 .58463 L
s
.69198 .58943 m
.6863 .58859 L
s
.66968 .58832 m
.66612 .58901 L
s
.5088 .58425 m
.51253 .5858 L
s
.66058 .58893 m
.65676 .58812 L
s
.61806 .58824 m
.62166 .58755 L
s
.69752 .58952 m
.69198 .58943 L
s
.60873 .58735 m
.61251 .58815 L
s
.66612 .58901 m
.66058 .58893 L
s
.57921 .58762 m
.58285 .58693 L
s
.5699 .58672 m
.57366 .58753 L
s
.41442 .58273 m
.41059 .58417 L
s
.54955 .5864 m
.54589 .58709 L
s
.3976 .58396 m
.39404 .58241 L
s
.61251 .58815 m
.61806 .58824 L
s
.54033 .587 m
.5366 .58619 L
s
.36994 .58202 m
.37347 .58357 L
s
.51253 .5858 m
.51625 .58661 L
s
.57366 .58753 m
.57921 .58762 L
s
.54589 .58709 m
.54033 .587 L
s
.46987 .58737 m
.46807 .58509 L
s
.51625 .58661 m
.52181 .5867 L
s
.41059 .58417 m
.40681 .58486 L
s
.40124 .58477 m
.3976 .58396 L
s
.37347 .58357 m
.3771 .58438 L
s
.35273 .58549 m
.3549 .58327 L
s
.40681 .58486 m
.40124 .58477 L
s
.3771 .58438 m
.38267 .58447 L
s
.49587 .58779 m
.49402 .58926 L
s
.4717 .58891 m
.46987 .58737 L
s
.35065 .58697 m
.35273 .58549 L
s
.49402 .58926 m
.49029 .59071 L
s
.63906 .59309 m
.64102 .59388 L
s
.63731 .59382 m
.63906 .59309 L
s
.47539 .59048 m
.4717 .58891 L
s
.64102 .59388 m
.63928 .59461 L
s
.63928 .59461 m
.63731 .59382 L
s
.34671 .58842 m
.35065 .58697 L
s
.49029 .59071 m
.48656 .59141 L
s
.47911 .59129 m
.47539 .59048 L
s
.48656 .59141 m
.47911 .59129 L
s
.34099 .58909 m
.34671 .58842 L
s
.32791 .58888 m
.34099 .58909 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000Y0?ooo`03
0000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`1Z0?ooo`P0003o1P3oool00`000?l0oooo0?ooo`0:0?ooo`<0003o
00<000000?ooo`000?l0203oool3000002`0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06/0oooo00<0
003o0?ooo`3oool01@3oool20000o`@0oooo00<0003o0?ooo`3oool01`3oool30000o`<0oooo0`00
0?l50?ooo`03000000000?l0000000@0oooo00<0003o0?ooo`3oool01P3oool70000o`D0oooo00<0
003o0?ooo`3oool0203oool70000o`@0oooo00<0003o0?ooo`000?l00`000?l^0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?ooo`<0000000<0003o0?ooo`000?l00`3o
ool20000o`H0oooo0P000?l70?ooo`80003o0`3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`020?ooo`80003o103oool20000o`D0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo1P000?l50?ooo`L0003o00<0
oooo0000003oool00P3oool20000oeD0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo0P000?l8
0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`00000000000P3oool01`000?l0oooo0?oo
o`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0
oooo1@000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000o`H0
oooo0P000?l30?ooo`030000o`3oool0oooo00@0oooo00<0003o0000003oool00`3oool00`000?l0
oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000J`3oool00`000?l0oooo
0?ooo`060?ooo`80003o103oool00`000?l0oooo0000o`040000o`@0oooo1`000?l01@3oool00000
0?ooo`3oool0003o00D0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo
00`0oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P000?l60?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`H0003o0P0000040?oo
o`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00H0003o0?ooo`3o
ool0oooo0000o`3oool40000o`D0oooo1`000?l40?ooo`P0003o1P3oool80000o`D0oooo00<0003o
0?ooo`3oool00P3oool30000o`D0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`<0000000<0
oooo0000o`0000000`3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo06X0oooo2@000?lI0?ooo`030000003oool0oooo0140oooo0P000?l5
0?ooo`80003o:03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo1@000?l4
0?ooo`@0000010000?l20?ooo`040000003oool0oooo0000oeH0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0C0?ooo`D0003o:P3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00/0oooo0`00000:0?ooo`050000003oool0
oooo0?ooo`000?l0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo04l0oooo0P000?l90?ooo`<000003P3oool010000000oooo0?ooo`00
0?mE0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0E`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05@0oooo0`00000F0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`1@0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?ooo`<00000:P3oool00`00
0000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo
0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00000n0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000
oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0
oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<000000?oo
o`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
2`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?oo
o`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`80
0000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03o
ool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<0
00000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<0
00007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3o
ool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?oo
o`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<0
0000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0
UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0
oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<0
0000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool0
0`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0
oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<00000
0?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?oo
o`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<0
0000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003o
ool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0
oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo
0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool20000
00T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000
08l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0
oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P000025
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2
000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0
oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?oo
o`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?oo
o`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<00000
0?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?oo
o`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000
003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03o
ool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo
00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?oo
o`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0
oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?oo
o`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003o
ool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2
000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool20000
05L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo
0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?oo
o`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003o
ool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo
0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?oo
o`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000
B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool2
00000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool0
06T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0
oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k
0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?oo
o`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00
L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2
000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool00000
03@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0
oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo
00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0
oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo
0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<00000
0?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<00000
0?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?oo
o`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@0
0000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000
KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03o
ool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03o
ool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool0
08h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo
0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000
000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<00000
0?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@0
0000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D0
0000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000
X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3o
ool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool0
06L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`00
0000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000
oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo
00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0
oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<00000
0?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?oo
o`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0
oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0
oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0
oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56631 .58557 m
.56495 .57772 L
s
.71716 .58275 m
.71918 .58315 L
s
.71552 .58309 m
.71716 .58275 L
s
.69525 .5824 m
.68977 .58231 L
s
.7009 .58286 m
.69525 .5824 L
s
.68977 .58231 m
.68445 .58259 L
s
.66419 .5819 m
.66799 .58233 L
s
.65871 .58181 m
.66419 .5819 L
s
.65519 .58212 m
.65871 .58181 L
s
.71918 .58315 m
.71753 .5835 L
s
.63847 .58673 m
.63677 .58145 L
s
.71753 .5835 m
.71552 .58309 L
s
.62323 .58497 m
.62214 .58122 L
s
.70307 .58364 m
.7009 .58286 L
s
.68445 .58259 m
.68293 .58331 L
s
.604 .58884 m
.60201 .5809 L
s
.66799 .58233 m
.67194 .58313 L
s
.57822 .58051 m
.57272 .58042 L
s
.58196 .58094 m
.57822 .58051 L
s
.65179 .58281 m
.65519 .58212 L
s
.57272 .58042 m
.56913 .58074 L
s
.55335 .58536 m
.55258 .5801 L
s
.54525 .57998 m
.54897 .58041 L
s
.53976 .57989 m
.54525 .57998 L
s
.53613 .58021 m
.53976 .57989 L
s
.50702 .58462 m
.50677 .57936 L
s
.58578 .58175 m
.58196 .58094 L
s
.56913 .58074 m
.56559 .58142 L
s
.4866 .57904 m
.49027 .57947 L
s
.47926 .57892 m
.4866 .57904 L
s
.47559 .57923 m
.47926 .57892 L
s
.54897 .58041 m
.55274 .58122 L
s
.70325 .58401 m
.70307 .58364 L
s
.53254 .58089 m
.53613 .58021 L
s
.45695 .58381 m
.44991 .57845 L
s
.4421 .58358 m
.44991 .57845 L
s
.4421 .58358 m
.43522 .57821 L
s
.42725 .58334 m
.43522 .57821 L
s
.41425 .58313 m
.41503 .57788 L
s
.49027 .57947 m
.49396 .58027 L
s
.40768 .57777 m
.4113 .5782 L
s
.40217 .57768 m
.40768 .57777 L
s
.65035 .58391 m
.65179 .58281 L
s
.39843 .57799 m
.40217 .57768 L
s
.4719 .57992 m
.47559 .57923 L
s
.70176 .58473 m
.70325 .58401 L
s
.36781 .58238 m
.36909 .57715 L
s
.34335 .57673 m
.33048 .57652 L
s
.34876 .57719 m
.34335 .57673 L
s
.58786 .5829 m
.58578 .58175 L
s
.32788 .58442 m
.33048 .57652 L
s
.4113 .5782 m
.41486 .579 L
s
.39461 .57867 m
.39843 .57799 L
s
.53082 .58199 m
.53254 .58089 L
s
.35224 .57799 m
.34876 .57719 L
s
.49396 .58027 m
.49582 .58105 L
s
.47004 .58063 m
.4719 .57992 L
s
.69826 .58505 m
.70176 .58473 L
s
.65062 .58466 m
.65035 .58391 L
s
.39255 .57976 m
.39461 .57867 L
s
.72109 .59072 m
.71846 .58538 L
s
.68924 .58528 m
.69826 .58505 L
s
.35387 .57877 m
.35224 .57799 L
s
.58803 .58365 m
.58786 .5829 L
s
.49582 .58105 m
.49584 .58217 L
s
.46816 .58173 m
.47004 .58063 L
s
.53089 .58274 m
.53082 .58199 L
s
.68572 .5856 m
.68924 .58528 L
s
.65286 .58583 m
.65062 .58466 L
s
.6842 .58633 m
.68572 .5856 L
s
.35541 .57992 m
.35387 .57877 L
s
.58643 .58476 m
.58803 .58365 L
s
.3924 .58051 m
.39255 .57976 L
s
.53285 .5839 m
.53089 .58274 L
s
.50691 .58235 m
.50882 .58351 L
s
.48662 .58203 m
.49584 .58217 L
s
.46809 .58361 m
.46816 .58173 L
s
.62172 .58608 m
.62323 .58497 L
s
.70447 .58665 m
.70297 .58738 L
s
.60295 .58465 m
.60878 .58587 L
s
.68636 .58712 m
.6842 .58633 L
s
.67314 .58615 m
.66975 .58685 L
s
.65682 .58664 m
.65286 .58583 L
s
.39404 .58167 m
.3924 .58051 L
s
.36836 .58012 m
.36994 .58128 L
s
.3549 .5818 m
.35541 .57992 L
s
.58289 .58546 m
.58643 .58476 L
s
.56611 .58443 m
.56994 .58525 L
s
.55318 .58422 m
.54959 .58492 L
s
.70297 .58738 m
.69761 .58768 L
s
.53663 .58471 m
.53285 .5839 L
s
.69207 .58759 m
.68636 .58712 L
s
.50882 .58351 m
.51256 .58433 L
s
.66975 .58685 m
.6662 .58717 L
s
.66066 .58708 m
.65682 .58664 L
s
.61813 .5864 m
.62172 .58608 L
s
.69761 .58768 m
.69207 .58759 L
s
.60878 .58587 m
.61258 .58631 L
s
.6662 .58717 m
.66066 .58708 L
s
.57927 .58578 m
.58289 .58546 L
s
.41442 .582 m
.4106 .58269 L
s
.56994 .58525 m
.57372 .58569 L
s
.39761 .58248 m
.39404 .58167 L
s
.54959 .58492 m
.54594 .58524 L
s
.54038 .58515 m
.53663 .58471 L
s
.61258 .58631 m
.61813 .5864 L
s
.36994 .58128 m
.37347 .5821 L
s
.51256 .58433 m
.51629 .58477 L
s
.57372 .58569 m
.57927 .58578 L
s
.46991 .58478 m
.46809 .58361 L
s
.54594 .58524 m
.54038 .58515 L
s
.51629 .58477 m
.52185 .58486 L
s
.4106 .58269 m
.40683 .58301 L
s
.40125 .58292 m
.39761 .58248 L
s
.37347 .5821 m
.3771 .58253 L
s
.35272 .5829 m
.3549 .5818 L
s
.40683 .58301 m
.40125 .58292 L
s
.3771 .58253 m
.38267 .58262 L
s
.49592 .5852 m
.49408 .58593 L
s
.47175 .58558 m
.46991 .58478 L
s
.35065 .58363 m
.35272 .5829 L
s
.49408 .58593 m
.49037 .58664 L
s
.63921 .58902 m
.6412 .58944 L
s
.63748 .58938 m
.63921 .58902 L
s
.47546 .5864 m
.47175 .58558 L
s
.6412 .58944 m
.63946 .58979 L
s
.63946 .58979 m
.63748 .58938 L
s
.3467 .58434 m
.35065 .58363 L
s
.49037 .58664 m
.48664 .58696 L
s
.47918 .58684 m
.47546 .5864 L
s
.48664 .58696 m
.47918 .58684 L
s
.34098 .58463 m
.3467 .58434 L
s
.32788 .58442 m
.34098 .58463 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06/0oooo20000?l60?ooo`030000o`3o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool3000006<0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0
oooo00D0oooo0P000?l40?ooo`030000o`3oool0oooo00H0oooo2P000?l20?ooo`<0000000<0oooo
0000o`3oool0103oool00`000?l0oooo0?ooo`050?ooo`P0003o1@3oool00`000?l0oooo0?ooo`08
0?ooo`@0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0340oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?oo
o`030000o`3oool0oooo00H0oooo0P000?l40?ooo`L0003o0P3oool50000o`80oooo0P000?l00`3o
ool00000000000020?ooo`80003o00@0oooo0000o`000?l0oooo0P000?l00`3oool0003o0?ooo`03
0?ooo`80003o1@3oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo0`000?l4
0?ooo`T0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool00`3oool70000o`D0oooo1`000?l00`3oool000000?ooo`020?ooo`030000o`3oool0
oooo05@0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00001[0?ooo`X0003o4`3oool20000
o`040?ooo`000?l0oooo00000080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`02
0?ooo`040000o`3oool0oooo0?ooo`<0003o203oool010000?l0oooo0?ooo`3oool60000o`@0oooo
20000?l40?ooo`80003o103oool30000o`@0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00P3oool20000o`H0oooo00<0003o0?ooo`3oool00P3oool70000o`800000
0`3oool20000oeH0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0B0?ooo`P0003o703oool40000o`P0oooo20000?l50?ooo`030000o`3o
ool0oooo0080oooo2@000?l30?ooo`@0003o0`0000020000o`050000003oool0oooo0?ooo`000?l0
EP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo0480oooo00<0003o0?ooo`3oool02P3oool20000o`l0oooo100000060?ooo`050000003o
ool0oooo0?ooo`000?l0E@3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo05d0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1J
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0E`3oool300000180oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo05@0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1@0?ooo`@00000
6P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo04X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000
oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k
0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000
@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000
oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100
oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K
0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H
0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?oo
o`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00
000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo
06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00
000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3o
ool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0
oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool20000
04T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000
001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3o
ool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000
001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3o
ool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool20000
09L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo
0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P00
00200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2
000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0
oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K
0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3o
ool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3o
ool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0
oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo
001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?oo
o`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000
003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool40000
03D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0
oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo
001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo
00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo
1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000
001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H
0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`04
0000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`03
0000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`800000
9P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo
000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`00
0000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@00
00280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=
0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`800000
5P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool0
0`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool0
06H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo
00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo
0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo
0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`00
0000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3o
ool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo10000036
0?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`80
0000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0
oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56635 .58364 m
.56483 .58378 L
s
.71707 .58617 m
.71909 .5862 L
s
.71544 .58614 m
.71707 .58617 L
s
.69516 .58582 m
.68968 .58573 L
s
.70082 .5859 m
.69516 .58582 L
s
.68968 .58573 m
.68437 .58564 L
s
.66411 .58532 m
.66791 .58538 L
s
.65862 .58523 m
.66411 .58532 L
s
.65511 .58517 m
.65862 .58523 L
s
.63852 .5848 m
.63669 .58488 L
s
.71909 .5862 m
.71746 .58616 L
s
.71746 .58616 m
.71544 .58614 L
s
.62324 .58459 m
.62206 .58465 L
s
.70301 .58592 m
.70082 .5859 L
s
.6041 .58419 m
.60194 .58432 L
s
.68437 .58564 m
.68288 .5856 L
s
.66791 .58538 m
.67189 .58542 L
s
.57815 .58394 m
.57266 .58385 L
s
.58189 .58399 m
.57815 .58394 L
s
.57266 .58385 m
.56907 .58379 L
s
.65174 .5851 m
.65511 .58517 L
s
.55338 .58343 m
.55251 .58353 L
s
.54519 .58341 m
.54891 .58346 L
s
.53969 .58332 m
.54519 .58341 L
s
.53608 .58326 m
.53969 .58332 L
s
.50706 .58269 m
.50671 .58279 L
s
.58573 .58404 m
.58189 .58399 L
s
.48654 .58247 m
.49022 .58252 L
s
.47921 .58235 m
.48654 .58247 L
s
.56907 .58379 m
.56555 .58372 L
s
.47554 .58229 m
.47921 .58235 L
s
.54891 .58346 m
.5527 .58351 L
s
.5325 .58319 m
.53608 .58326 L
s
.7032 .58592 m
.70301 .58592 L
s
.45698 .58189 m
.44986 .58188 L
s
.44213 .58165 m
.44986 .58188 L
s
.44213 .58165 m
.43518 .58164 L
s
.42728 .58141 m
.43518 .58164 L
s
.41428 .5812 m
.41498 .58132 L
s
.40764 .5812 m
.41126 .58125 L
s
.40213 .58111 m
.40764 .5812 L
s
.49022 .58252 m
.49392 .58257 L
s
.39839 .58105 m
.40213 .58111 L
s
.65033 .58505 m
.65174 .5851 L
s
.47186 .58221 m
.47554 .58229 L
s
.36783 .58045 m
.36906 .58058 L
s
.70173 .58588 m
.7032 .58592 L
s
.34332 .58017 m
.33045 .57996 L
s
.34873 .58025 m
.34332 .58017 L
s
.58784 .58405 m
.58573 .58404 L
s
.32793 .57976 m
.33045 .57996 L
s
.41126 .58125 m
.41483 .58129 L
s
.39458 .58097 m
.39839 .58105 L
s
.5308 .58313 m
.5325 .58319 L
s
.35221 .58029 m
.34873 .58025 L
s
.49392 .58257 m
.49579 .58258 L
s
.47001 .58217 m
.47186 .58221 L
s
.69824 .58582 m
.70173 .58588 L
s
.65061 .58504 m
.65033 .58505 L
s
.39254 .58091 m
.39458 .58097 L
s
.72121 .58608 m
.71844 .58614 L
s
.68923 .58566 m
.69824 .58582 L
s
.35386 .5803 m
.35221 .58029 L
s
.58802 .58404 m
.58784 .58405 L
s
.49579 .58258 m
.49584 .58256 L
s
.46815 .58211 m
.47001 .58217 L
s
.53089 .58312 m
.5308 .58313 L
s
.68572 .5856 m
.68923 .58566 L
s
.65288 .58506 m
.65061 .58504 L
s
.35541 .5803 m
.35386 .5803 L
s
.68422 .58556 m
.68572 .5856 L
s
.58644 .58399 m
.58802 .58404 L
s
.3924 .5809 m
.39254 .58091 L
s
.53287 .58313 m
.53089 .58312 L
s
.50691 .58274 m
.50883 .58274 L
s
.48661 .58241 m
.49584 .58256 L
s
.46812 .58207 m
.46815 .58211 L
s
.62175 .58454 m
.62324 .58459 L
s
.70449 .58589 m
.70301 .58585 L
s
.60296 .58426 m
.60881 .58433 L
s
.6864 .58558 m
.68422 .58556 L
s
.67316 .58538 m
.66979 .58531 L
s
.65686 .58511 m
.65288 .58506 L
s
.39405 .5809 m
.3924 .5809 L
s
.36836 .58051 m
.36995 .58051 L
s
.35491 .58025 m
.35541 .5803 L
s
.58292 .58392 m
.58644 .58399 L
s
.56613 .58366 m
.56998 .58371 L
s
.5532 .58346 m
.54962 .58338 L
s
.70301 .58585 m
.69766 .58575 L
s
.53666 .58317 m
.53287 .58313 L
s
.69212 .58566 m
.6864 .58558 L
s
.50883 .58274 m
.51259 .58279 L
s
.66979 .58531 m
.66625 .58525 L
s
.6607 .58516 m
.65686 .58511 L
s
.61817 .58448 m
.62175 .58454 L
s
.69766 .58575 m
.69212 .58566 L
s
.60881 .58433 m
.61262 .58439 L
s
.41443 .58123 m
.41062 .58115 L
s
.57931 .58385 m
.58292 .58392 L
s
.66625 .58525 m
.6607 .58516 L
s
.56998 .58371 m
.57375 .58376 L
s
.39763 .58094 m
.39405 .5809 L
s
.54962 .58338 m
.54597 .58332 L
s
.36995 .58051 m
.37349 .58055 L
s
.54042 .58323 m
.53666 .58317 L
s
.61262 .58439 m
.61817 .58448 L
s
.51259 .58279 m
.51633 .58284 L
s
.57375 .58376 m
.57931 .58385 L
s
.46996 .58208 m
.46812 .58207 L
s
.54597 .58332 m
.54042 .58323 L
s
.51633 .58284 m
.52189 .58293 L
s
.41062 .58115 m
.40685 .58108 L
s
.40128 .58099 m
.39763 .58094 L
s
.37349 .58055 m
.37712 .5806 L
s
.35275 .5802 m
.35491 .58025 L
s
.40685 .58108 m
.40128 .58099 L
s
.37712 .5806 m
.3827 .58069 L
s
.49596 .5825 m
.49414 .58245 L
s
.47181 .58209 m
.46996 .58208 L
s
.35069 .58015 m
.35275 .5802 L
s
.49414 .58245 m
.49044 .58238 L
s
.47553 .58214 m
.47181 .58209 L
s
.63931 .58477 m
.64131 .58479 L
s
.63759 .58473 m
.63931 .58477 L
s
.64131 .58479 m
.63958 .58476 L
s
.63958 .58476 m
.63759 .58473 L
s
.34674 .58007 m
.35069 .58015 L
s
.49044 .58238 m
.48672 .58231 L
s
.47926 .58219 m
.47553 .58214 L
s
.48672 .58231 m
.47926 .58219 L
s
.34102 .57997 m
.34674 .58007 L
s
.32793 .57976 m
.34102 .57997 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103o
ool3000006<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`1Z0?ooo`X0003o5`3oool00`000000oooo0?ooo`03000001P0oooo00<0003o
0?ooo`3oool0B`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo0740oooo10000?l40?ooo`L0003o0P3oool:0000o`80000000<0oooo0000
o`000?l02P000?l30?ooo``0003o0`3oool40000odH0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08P3oool20000o`<0
oooo2@000?l30?ooo`X0003o103oool90000o`@0oooo0`000?l20?ooo`X0003o0`3oool20000o`D0
oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0H03oool40000o`<000000P000?l00`000000oooo0?ooo`030000oeD0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`1P0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0G@3oool3000000X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo05X0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1G0?ooo`<0
00004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0E03oool3000001H0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0500oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1=0?ooo`<000007P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0BP3oool300000280oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo04L0
oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo
0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0h0?ooo`<0
0000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000A`3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0
oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo
0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000
001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
4@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3o
ool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0
oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`00
0000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo
0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3
000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo
0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool30000
04D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool30000
06D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool30000
08@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo000000020000
09@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo
0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?oo
o`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo
0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo
0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00
000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J
0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool01000
0000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0
oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo
00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?oo
o`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`33
0?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?oo
o`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00
L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3o
ool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000
oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo
0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?oo
o`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00
000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000
001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<00000
0?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@0
0000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@0
0000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000
I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0
oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<00000
0?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?oo
o`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D0
0000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000
UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool20000
00`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo
0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo
1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00
000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00
000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T
0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D0
0000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?oo
o`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00
003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P000004
0?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56637 .58172 m
.56476 .58984 L
s
.71706 .5896 m
.71908 .58924 L
s
.71543 .58918 m
.71706 .5896 L
s
.69514 .58924 m
.68966 .58916 L
s
.70081 .58895 m
.69514 .58924 L
s
.68966 .58916 m
.68435 .58869 L
s
.66408 .58875 m
.66789 .58842 L
s
.6586 .58866 m
.66408 .58875 L
s
.65509 .58822 m
.6586 .58866 L
s
.71908 .58924 m
.71745 .58883 L
s
.63853 .58288 m
.63666 .58831 L
s
.71745 .58883 m
.71543 .58918 L
s
.62325 .5842 m
.62203 .58807 L
s
.703 .58821 m
.70081 .58895 L
s
.68435 .58869 m
.68286 .58789 L
s
.60415 .57955 m
.6019 .58775 L
s
.66789 .58842 m
.67187 .58771 L
s
.57811 .58737 m
.57262 .58728 L
s
.58186 .58704 m
.57811 .58737 L
s
.65172 .58739 m
.65509 .58822 L
s
.57262 .58728 m
.56903 .58684 L
s
.55341 .58151 m
.55247 .58696 L
s
.54514 .58684 m
.54887 .58651 L
s
.53965 .58675 m
.54514 .58684 L
s
.53604 .58631 m
.53965 .58675 L
s
.50709 .58076 m
.50666 .58622 L
s
.58571 .58633 m
.58186 .58704 L
s
.56903 .58684 m
.56552 .58601 L
s
.48649 .5859 m
.49018 .58557 L
s
.47915 .58578 m
.48649 .5859 L
s
.47549 .58534 m
.47915 .58578 L
s
.54887 .58651 m
.55267 .5858 L
s
.70319 .58783 m
.703 .58821 L
s
.53247 .58548 m
.53604 .58631 L
s
.45701 .57996 m
.4498 .58531 L
s
.44216 .57972 m
.4498 .58531 L
s
.44216 .57972 m
.43511 .58508 L
s
.42731 .57948 m
.43511 .58508 L
s
.41432 .57927 m
.41492 .58475 L
s
.49018 .58557 m
.49389 .58486 L
s
.40757 .58463 m
.4112 .58431 L
s
.40206 .58455 m
.40757 .58463 L
s
.65032 .5862 m
.65172 .58739 L
s
.39833 .5841 m
.40206 .58455 L
s
.47182 .5845 m
.47549 .58534 L
s
.70172 .58703 m
.70319 .58783 L
s
.36787 .57852 m
.36898 .58402 L
s
.34324 .5836 m
.33037 .5834 L
s
.34866 .5833 m
.34324 .5836 L
s
.58783 .5852 m
.58571 .58633 L
s
.32804 .5751 m
.33037 .5834 L
s
.4112 .58431 m
.41479 .58359 L
s
.39454 .58326 m
.39833 .5841 L
s
.53078 .58428 m
.53247 .58548 L
s
.35216 .58258 m
.34866 .5833 L
s
.49389 .58486 m
.49577 .58411 L
s
.46999 .5837 m
.47182 .5845 L
s
.69824 .58658 m
.70172 .58703 L
s
.6506 .58543 m
.65032 .5862 L
s
.39251 .58206 m
.39454 .58326 L
s
.72123 .58144 m
.71843 .58691 L
s
.68923 .58605 m
.69824 .58658 L
s
.35382 .58183 m
.35216 .58258 L
s
.58801 .58442 m
.58783 .5852 L
s
.49577 .58411 m
.49583 .58294 L
s
.46814 .5825 m
.46999 .5837 L
s
.53088 .5835 m
.53078 .58428 L
s
.68572 .5856 m
.68923 .58605 L
s
.65288 .58429 m
.6506 .58543 L
s
.68422 .58479 m
.68572 .5856 L
s
.3554 .58069 m
.35382 .58183 L
s
.58645 .58322 m
.58801 .58442 L
s
.39239 .58128 m
.39251 .58206 L
s
.53288 .58236 m
.53088 .5835 L
s
.5069 .58312 m
.50884 .58197 L
s
.4866 .58279 m
.49583 .58294 L
s
.46814 .58053 m
.46814 .5825 L
s
.62177 .583 m
.62325 .5842 L
s
.70449 .58512 m
.70302 .58431 L
s
.60296 .58388 m
.60883 .58279 L
s
.68641 .58404 m
.68422 .58479 L
s
.67316 .58462 m
.6698 .58378 L
s
.65687 .58357 m
.65288 .58429 L
s
.39406 .58013 m
.39239 .58128 L
s
.36835 .58089 m
.36996 .57974 L
s
.35495 .57871 m
.3554 .58069 L
s
.58294 .58238 m
.58645 .58322 L
s
.56614 .58289 m
.56999 .58217 L
s
.55321 .58269 m
.54964 .58184 L
s
.70302 .58431 m
.69767 .58383 L
s
.53668 .58163 m
.53288 .58236 L
s
.69213 .58374 m
.68641 .58404 L
s
.50884 .58197 m
.51261 .58125 L
s
.6698 .58378 m
.66626 .58332 L
s
.66072 .58324 m
.65687 .58357 L
s
.61819 .58255 m
.62177 .583 L
s
.69767 .58383 m
.69213 .58374 L
s
.60883 .58279 m
.61264 .58246 L
s
.66626 .58332 m
.66072 .58324 L
s
.57933 .58193 m
.58294 .58238 L
s
.41445 .58046 m
.41065 .57961 L
s
.56999 .58217 m
.57378 .58184 L
s
.39766 .5794 m
.39406 .58013 L
s
.54964 .58184 m
.546 .58139 L
s
.54044 .5813 m
.53668 .58163 L
s
.61264 .58246 m
.61819 .58255 L
s
.36996 .57974 m
.37352 .57901 L
s
.51261 .58125 m
.51635 .58091 L
s
.57378 .58184 m
.57933 .58193 L
s
.47 .57938 m
.46814 .58053 L
s
.546 .58139 m
.54044 .5813 L
s
.51635 .58091 m
.52191 .581 L
s
.41065 .57961 m
.40689 .57915 L
s
.40132 .57906 m
.39766 .5794 L
s
.37352 .57901 m
.37716 .57867 L
s
.35281 .57749 m
.35495 .57871 L
s
.40689 .57915 m
.40132 .57906 L
s
.37716 .57867 m
.38274 .57876 L
s
.49601 .5798 m
.49419 .57897 L
s
.47186 .57861 m
.47 .57938 L
s
.35076 .57666 m
.35281 .57749 L
s
.49419 .57897 m
.4905 .57812 L
s
.63935 .58051 m
.64134 .58015 L
s
.63763 .58009 m
.63935 .58051 L
s
.4756 .57788 m
.47186 .57861 L
s
.64134 .58015 m
.63962 .57972 L
s
.63962 .57972 m
.63763 .58009 L
s
.34684 .5758 m
.35076 .57666 L
s
.4905 .57812 m
.48679 .57766 L
s
.47933 .57754 m
.4756 .57788 L
s
.48679 .57766 m
.47933 .57754 L
s
.34113 .57531 m
.34684 .5758 L
s
.32804 .5751 m
.34113 .57531 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06X0oooo2P000?lF0?ooo`030000003o
ool0oooo00@0oooo0`00000?0?ooo`030000o`3oool0oooo0540oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool00P3oool70000o`<0oooo20000?l01P000000oooo0?ooo`00
0000003o000000@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`@0003o
00<0oooo0000o`000?l010000?lW0?ooo`030000o`3oool0oooo00X0oooo0P000?lG0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`050?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00@0003o0?ooo`00000000000P3oool20000o`040?ooo`000?l0003o0?ooo`80
003o00<0oooo0000o`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80003o1P3oool60000o`@0
oooo20000?l40?ooo`L0003o1`3oool00`000?l0oooo0000o`030000o`L0oooo00<0003o0?ooo`3o
ool05P3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3o
ool04`3oool002D0oooo0P00001/0?ooo`P0003o1P3oool00`000?l0oooo0?ooo`070?ooo`T0003o
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
0`000?l50?ooo`<0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool30000o`@0oooo
0P000?l50?ooo`030000o`3oool0oooo0080oooo2@000?l30?ooo`L0003o0P0000040?ooo`030000
o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0C0?ooo`D0003o1P3oool00`000?l0oooo0?ooo`070?ooo`P0003o0`3o
ool90000o`D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo0`000?l50?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`000?l0003o
0`0000000`000?l0oooo000000030?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0c0?ooo`030000o`3o
ool0oooo01P0oooo00<0003o0?ooo`3oool01@3oool50000o`D0oooo100000030000o`<0oooo00@0
00000?ooo`000?l0003oEP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo05d0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1J
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0E`3oool300000180oooo00<000000?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo05@0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1@0?ooo`@00000
6P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo04X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000
oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k
0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000
@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000
oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100
oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K
0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H
0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?oo
o`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00
000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo
06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00
000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3o
ool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0
oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool20000
04T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000
001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3o
ool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000
001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3o
ool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool20000
09L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo
0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P00
00200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2
000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0
oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K
0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3o
ool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3o
ool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0
oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo
001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?oo
o`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000
003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool40000
03D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0
oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo
001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo
00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo
1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000
001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H
0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`04
0000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`03
0000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`800000
9P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo
000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`00
0000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@00
00280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=
0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`800000
5P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool0
0`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool0
06H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo
00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo
0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo
0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`00
0000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3o
ool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo10000036
0?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`80
0000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0
oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56638 .57988 m
.56474 .59564 L
s
.71712 .59287 m
.71914 .59216 L
s
.71548 .5921 m
.71712 .59287 L
s
.69519 .59252 m
.68971 .59243 L
s
.70085 .59186 m
.69519 .59252 L
s
.68971 .59243 m
.68439 .5916 L
s
.66412 .59202 m
.66793 .59134 L
s
.65863 .59193 m
.66412 .59202 L
s
.65512 .59113 m
.65863 .59193 L
s
.71914 .59216 m
.7175 .59138 L
s
.7175 .59138 m
.71548 .5921 L
s
.63852 .58104 m
.63668 .59158 L
s
.70304 .5904 m
.70085 .59186 L
s
.62324 .58384 m
.62204 .59135 L
s
.68439 .5916 m
.68289 .59008 L
s
.60413 .57512 m
.60191 .59103 L
s
.66793 .59134 m
.6719 .5899 L
s
.65174 .58958 m
.65512 .59113 L
s
.5781 .59065 m
.57261 .59056 L
s
.58186 .58996 m
.5781 .59065 L
s
.57261 .59056 m
.56903 .58975 L
s
.55342 .57967 m
.55246 .59024 L
s
.54512 .59012 m
.54886 .58943 L
s
.53963 .59003 m
.54512 .59012 L
s
.53602 .58922 m
.53963 .59003 L
s
.50711 .57892 m
.50662 .5895 L
s
.58571 .58852 m
.58186 .58996 L
s
.56903 .58975 m
.56551 .5882 L
s
.48644 .58918 m
.49013 .58849 L
s
.4791 .58906 m
.48644 .58918 L
s
.47544 .58825 m
.4791 .58906 L
s
.70322 .58965 m
.70304 .5904 L
s
.54886 .58943 m
.55266 .58799 L
s
.53245 .58767 m
.53602 .58922 L
s
.45705 .57812 m
.44973 .58859 L
s
.4422 .57788 m
.44973 .58859 L
s
.4422 .57788 m
.43504 .58836 L
s
.42736 .57764 m
.43504 .58836 L
s
.65033 .5873 m
.65174 .58958 L
s
.41436 .57743 m
.41483 .58803 L
s
.49013 .58849 m
.49386 .58705 L
s
.40748 .58792 m
.41112 .58722 L
s
.40197 .58783 m
.40748 .58792 L
s
.39825 .58702 m
.40197 .58783 L
s
.47179 .58669 m
.47544 .58825 L
s
.70174 .58812 m
.70322 .58965 L
s
.36793 .57668 m
.36888 .5873 L
s
.58783 .5863 m
.58571 .58852 L
s
.34313 .58689 m
.33025 .58668 L
s
.34856 .58622 m
.34313 .58689 L
s
.41112 .58722 m
.41473 .58578 L
s
.3282 .57066 m
.33025 .58668 L
s
.39447 .58546 m
.39825 .58702 L
s
.53077 .58538 m
.53245 .58767 L
s
.35209 .58478 m
.34856 .58622 L
s
.49386 .58705 m
.49575 .58557 L
s
.69825 .58731 m
.70174 .58812 L
s
.46996 .58516 m
.47179 .58669 L
s
.65061 .58579 m
.65033 .5873 L
s
.72115 .57701 m
.71845 .58764 L
s
.39248 .58316 m
.39447 .58546 L
s
.68923 .58641 m
.69825 .58731 L
s
.58801 .58479 m
.58783 .5863 L
s
.35377 .5833 m
.35209 .58478 L
s
.49575 .58557 m
.49583 .58331 L
s
.46814 .58286 m
.46996 .58516 L
s
.68572 .5856 m
.68923 .58641 L
s
.53088 .58387 m
.53077 .58538 L
s
.65288 .58356 m
.65061 .58579 L
s
.68421 .58406 m
.68572 .5856 L
s
.58645 .58249 m
.58801 .58479 L
s
.35539 .58105 m
.35377 .5833 L
s
.39238 .58165 m
.39248 .58316 L
s
.53288 .58163 m
.53088 .58387 L
s
.5069 .58348 m
.50885 .58124 L
s
.4866 .58316 m
.49583 .58331 L
s
.70448 .58439 m
.703 .58284 L
s
.62176 .58153 m
.62324 .58384 L
s
.46817 .57906 m
.46814 .58286 L
s
.68639 .58257 m
.68421 .58406 L
s
.60296 .58351 m
.60882 .58133 L
s
.67315 .58388 m
.66978 .58231 L
s
.65685 .5821 m
.65288 .58356 L
s
.39408 .57939 m
.39238 .58165 L
s
.36834 .58126 m
.36999 .57901 L
s
.58294 .58091 m
.58645 .58249 L
s
.355 .57724 m
.35539 .58105 L
s
.56614 .58216 m
.57 .5807 L
s
.55321 .58195 m
.54965 .58037 L
s
.703 .58284 m
.69764 .58199 L
s
.53669 .58016 m
.53288 .58163 L
s
.6921 .5819 m
.68639 .58257 L
s
.66978 .58231 m
.66624 .58149 L
s
.50885 .58124 m
.51263 .57978 L
s
.6607 .5814 m
.65685 .5821 L
s
.61818 .58071 m
.62176 .58153 L
s
.69764 .58199 m
.6921 .5819 L
s
.60882 .58133 m
.61263 .58062 L
s
.66624 .58149 m
.6607 .5814 L
s
.57933 .58009 m
.58294 .58091 L
s
.57 .5807 m
.57378 .58 L
s
.41446 .57972 m
.41069 .57814 L
s
.54965 .58037 m
.54601 .57955 L
s
.3977 .57793 m
.39408 .57939 L
s
.61263 .58062 m
.61818 .58071 L
s
.54045 .57946 m
.53669 .58016 L
s
.36999 .57901 m
.37357 .57754 L
s
.51263 .57978 m
.51637 .57907 L
s
.57378 .58 m
.57933 .58009 L
s
.54601 .57955 m
.54045 .57946 L
s
.47004 .5768 m
.46817 .57906 L
s
.51637 .57907 m
.52193 .57916 L
s
.41069 .57814 m
.40694 .57731 L
s
.40137 .57722 m
.3977 .57793 L
s
.37357 .57754 m
.37722 .57683 L
s
.3529 .57491 m
.355 .57724 L
s
.40694 .57731 m
.40137 .57722 L
s
.37722 .57683 m
.38279 .57692 L
s
.49604 .57722 m
.49423 .57565 L
s
.47192 .57529 m
.47004 .5768 L
s
.35088 .57334 m
.3529 .57491 L
s
.49423 .57565 m
.49056 .57405 L
s
.63932 .57646 m
.64131 .57572 L
s
.63759 .57566 m
.63932 .57646 L
s
.47566 .57381 m
.47192 .57529 L
s
.64131 .57572 m
.63959 .57492 L
s
.63959 .57492 m
.63759 .57566 L
s
.34698 .57173 m
.35088 .57334 L
s
.49056 .57405 m
.48686 .57322 L
s
.4794 .5731 m
.47566 .57381 L
s
.48686 .57322 m
.4794 .5731 L
s
.34129 .57087 m
.34698 .57173 L
s
.3282 .57066 m
.34129 .57087 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`1Y0?ooo`P0003o5P3oool00`000000oooo0?ooo`0<0?ooo`<0
0000G@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo06T0oooo00<0003o0?ooo`3oool01@3oool20000oaD0oooo00<000000?ooo`3oool0
203oool3000000X0oooo1`000?m?0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`80003o103o
ool00`000?l0oooo0000o`040000o`D0oooo10000?l00`3oool0003o0?ooo`050?ooo`<000002`3o
ool20000o`L0oooo0P000?lW0?ooo`030000o`3oool0oooo00X0oooo0P000?lG0?ooo`030000003o
ool0oooo00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool2
0000o`P0oooo0P000?l40?ooo`80003o00H000000?ooo`3oool000000000o`0000040?ooo`030000
o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0003o00<0
003o1@3oool40000o`80oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030000o`P0
oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0580
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`040000o`3oool0000000000080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0
003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`80003o203oool0
0`000?l0oooo0?ooo`020?ooo`<0003o103oool30000o`<0oooo0`000?l50?ooo`030000o`3oool0
003o00D0003o1@3oool00`000?l0oooo0?ooo`040?ooo`H0003o1@3oool70000o`030000003oool0
oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3oool20000
06`0oooo00<0003o0?ooo`3oool01@3oool20000o`@0oooo00<0003o0?ooo`3oool01P3oool20000
o`L0oooo00<0003o0000003oool00P3oool010000?l0oooo0?ooo`000?l20?ooo`040000o`3oool0
oooo0000o`D0oooo00<0003o0?ooo`3oool00`3oool50000o`<0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`<0003o1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo0P000?l60?ooo`040000o`3oool0oooo0?ooo`80003o1@3oool2000000@0oooo
00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`1[0?ooo`P0003o1P3oool00`000?l0oooo0?ooo`080?ooo`P0003o00<000000?ooo`3oool00P3o
ool00`000?l0oooo0000o`030?ooo`80003o1`3oool20000o`H0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo
0P000?l70?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo0080oooo0P000?l=0?ooo`80003o0`0000000`000?l0oooo
000000030?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool01`3oool60000o`D0oooo00<0003o0?ooo`3oool01`3oool80000o`<0oooo00<0
003o0?ooo`000?l01P000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool4000000<0oooo00@0003o0?ooo`3oool00000F@3oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool60000o`80oooo0`0000070000o`<0oooo00@000000?ooo`000?l0003oEP3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo00<0
003o0?ooo`3oool0903oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05L0oooo0`00000B
0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0D03oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000N0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3
000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool20000
08l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400
oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3
000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool30000
08h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?oo
o`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<0
0000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<00000
1@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4
000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000
KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool30000
02/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?oo
o`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3o
ool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3o
ool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0
oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool30000
04/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?oo
o`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3o
ool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0
oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<00000
0?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?oo
o`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3o
ool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000
oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`00
0000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0
oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00
002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<00000
0?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0
oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool20000
00@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo
0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00
001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0
oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo
0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0013
0?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`03
0000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00
B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;
0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`03
0000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00
C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3o
ool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003o
ool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo
0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo
0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?oo
o`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003o
ool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03o
ool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0
f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3o
ool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`00
0000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0
oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo
1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000
000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?oo
o`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`80
0000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0
oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo
0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0
oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0
oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo
0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0
oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000
oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo
0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?oo
o`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M
0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q
0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?oo
o`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool0
10000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3
000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo
0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?oo
o`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A
0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?oo
o`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000
003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000
003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303o
ool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool0
10000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03o
ool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2
000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo
0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool50000
0;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0
oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0
oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo
0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
6P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?oo
o`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:
0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`05
0000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo0000
00H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo
0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56636 .57821 m
.56478 .60094 L
s
.71726 .59586 m
.71926 .59481 L
s
.7156 .59475 m
.71726 .59586 L
s
.69531 .59551 m
.68983 .59542 L
s
.70096 .59452 m
.69531 .59551 L
s
.68983 .59542 m
.68449 .59426 L
s
.66421 .59501 m
.66802 .59399 L
s
.65872 .59492 m
.66421 .59501 L
s
.6552 .59379 m
.65872 .59492 L
s
.71926 .59481 m
.7176 .59371 L
s
.7176 .59371 m
.7156 .59475 L
s
.63848 .57937 m
.63676 .59457 L
s
.70312 .59239 m
.70096 .59452 L
s
.62324 .5835 m
.62211 .59434 L
s
.68449 .59426 m
.68297 .59207 L
s
.60407 .57109 m
.60196 .59401 L
s
.66802 .59399 m
.67197 .59189 L
s
.6518 .59157 m
.6552 .59379 L
s
.57813 .59363 m
.57263 .59355 L
s
.58189 .59262 m
.57813 .59363 L
s
.57263 .59355 m
.56905 .59241 L
s
.55341 .578 m
.55247 .59322 L
s
.54513 .59311 m
.54886 .59209 L
s
.53963 .59302 m
.54513 .59311 L
s
.53601 .59188 m
.53963 .59302 L
s
.58573 .59051 m
.58189 .59262 L
s
.50712 .57725 m
.5066 .59249 L
s
.56905 .59241 m
.56553 .59019 L
s
.70329 .59131 m
.70312 .59239 L
s
.4864 .59217 m
.4901 .59115 L
s
.47906 .59205 m
.4864 .59217 L
s
.54886 .59209 m
.55267 .58999 L
s
.4754 .59091 m
.47906 .59205 L
s
.53245 .58966 m
.53601 .59188 L
s
.45708 .57645 m
.44966 .59158 L
s
.44224 .57621 m
.44966 .59158 L
s
.65036 .5883 m
.6518 .59157 L
s
.44224 .57621 m
.43496 .59135 L
s
.4274 .57597 m
.43496 .59135 L
s
.70178 .58912 m
.70329 .59131 L
s
.4901 .59115 m
.49383 .58904 L
s
.41442 .57576 m
.41474 .59102 L
s
.47175 .58869 m
.4754 .59091 L
s
.40738 .59091 m
.41104 .58988 L
s
.40187 .59082 m
.40738 .59091 L
s
.39815 .58968 m
.40187 .59082 L
s
.58784 .58729 m
.58573 .59051 L
s
.368 .57501 m
.36875 .59029 L
s
.41104 .58988 m
.41467 .58778 L
s
.34298 .58988 m
.33009 .58967 L
s
.34843 .58888 m
.34298 .58988 L
s
.3944 .58745 m
.39815 .58968 L
s
.32842 .56663 m
.33009 .58967 L
s
.53077 .58638 m
.53245 .58966 L
s
.69827 .58798 m
.70178 .58912 L
s
.49383 .58904 m
.49573 .5869 L
s
.35199 .58677 m
.34843 .58888 L
s
.46994 .58649 m
.47175 .58869 L
s
.72096 .57299 m
.71848 .5883 L
s
.65062 .58613 m
.65036 .5883 L
s
.68924 .58675 m
.69827 .58798 L
s
.39244 .58416 m
.3944 .58745 L
s
.58802 .58512 m
.58784 .58729 L
s
.49573 .5869 m
.49582 .58364 L
s
.35371 .58463 m
.35199 .58677 L
s
.68572 .5856 m
.68924 .58675 L
s
.46813 .5832 m
.46994 .58649 L
s
.53088 .5842 m
.53077 .58638 L
s
.65286 .58289 m
.65062 .58613 L
s
.68419 .58339 m
.68572 .5856 L
s
.58644 .58182 m
.58802 .58512 L
s
.35537 .58139 m
.35371 .58463 L
s
.53288 .58096 m
.53088 .5842 L
s
.39237 .58198 m
.39244 .58416 L
s
.5069 .58382 m
.50886 .58057 L
s
.70445 .58372 m
.70294 .58151 L
s
.48659 .58349 m
.49582 .58364 L
s
.62173 .5802 m
.62324 .5835 L
s
.68634 .58124 m
.68419 .58339 L
s
.67313 .58321 m
.66973 .58097 L
s
.46819 .57772 m
.46813 .5832 L
s
.60295 .58318 m
.6088 .57999 L
s
.65681 .58076 m
.65286 .58289 L
s
.39411 .57873 m
.39237 .58198 L
s
.58293 .57957 m
.58644 .58182 L
s
.36832 .58159 m
.37002 .57834 L
s
.70294 .58151 m
.69757 .58032 L
s
.56614 .58149 m
.56999 .57936 L
s
.35506 .5759 m
.35537 .58139 L
s
.55321 .58129 m
.54964 .57904 L
s
.69203 .58023 m
.68634 .58124 L
s
.66973 .58097 m
.66619 .57982 L
s
.53669 .57883 m
.53288 .58096 L
s
.66064 .57973 m
.65681 .58076 L
s
.50886 .58057 m
.51264 .57844 L
s
.69757 .58032 m
.69203 .58023 L
s
.61815 .57904 m
.62173 .5802 L
s
.6088 .57999 m
.6126 .57895 L
s
.66619 .57982 m
.66064 .57973 L
s
.57932 .57842 m
.58293 .57957 L
s
.56999 .57936 m
.57377 .57833 L
s
.41449 .57905 m
.41073 .5768 L
s
.6126 .57895 m
.61815 .57904 L
s
.54964 .57904 m
.54601 .57788 L
s
.54045 .57779 m
.53669 .57883 L
s
.39775 .57659 m
.39411 .57873 L
s
.51264 .57844 m
.51638 .5774 L
s
.57377 .57833 m
.57932 .57842 L
s
.37002 .57834 m
.37362 .5762 L
s
.54601 .57788 m
.54045 .57779 L
s
.47009 .57445 m
.46819 .57772 L
s
.51638 .5774 m
.52194 .57749 L
s
.41073 .5768 m
.40699 .57564 L
s
.40142 .57555 m
.39775 .57659 L
s
.37362 .5762 m
.37729 .57516 L
s
.35301 .57256 m
.35506 .5759 L
s
.40699 .57564 m
.40142 .57555 L
s
.37729 .57516 m
.38286 .57525 L
s
.49607 .57487 m
.49427 .57264 L
s
.47197 .57228 m
.47009 .57445 L
s
.63922 .57277 m
.6412 .5717 L
s
.63749 .57164 m
.63922 .57277 L
s
.49427 .57264 m
.49061 .57037 L
s
.35102 .57032 m
.35301 .57256 L
s
.47572 .57012 m
.47197 .57228 L
s
.6412 .5717 m
.63947 .57056 L
s
.63947 .57056 m
.63749 .57164 L
s
.49061 .57037 m
.48691 .5692 L
s
.34716 .56804 m
.35102 .57032 L
s
.47946 .56908 m
.47572 .57012 L
s
.48691 .5692 m
.47946 .56908 L
s
.34149 .56684 m
.34716 .56804 L
s
.32842 .56663 m
.34149 .56684 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0J@3oool60000oaH0oooo00<000000?ooo`3oool0503oool3000005L0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y0?oo
o`030000o`3oool0oooo00<0oooo0P000?lE0?ooo`030000003oool0oooo0100oooo0`0000060?oo
o`<0003oD@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo06T0oooo00<0003o0?ooo`3oool01@3oool20000oa@0oooo00<000000?ooo`3o
ool0303oool3000000L0oooo0P000?l30?ooo`80003o:@3oool00`000?l0oooo0?ooo`0:0?ooo`80
003o5`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo06T0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo0`0000080?ooo`80003o1`3oool20000obL0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0
DP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`040000o`@0oooo1`00
0?l40?ooo`030000o`3oool000000080000000<0oooo0000o`3oool00`3oool01@000?l0oooo0?oo
o`3oool0003o00h0oooo00<0003o0?ooo`3oool00`000?lN0?ooo`030000o`3oool0oooo02<0oooo
00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo01<0oooo
000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`80003o203oool00`000?l0oooo0?ooo`040?ooo`070000o`000000oooo0?ooo`000000
003o000000030?ooo`80003o103oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?oo
o`000?l0203oool70000o`@0oooo1`000?l70?ooo`030000o`3oool0003o00D0003o1@3oool00`00
0?l0oooo0?ooo`050?ooo`<0003o2@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`00000000000P3oool01`00
0?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00`0oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool20000o`D0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`<0003o0`3oool20000o`D0oooo0P000?l00`3oool0003o0000
o`020000o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?oo
o`0C0?ooo`009@3oool2000006`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo00000003
0?ooo`040000o`3oool0oooo0000o`80oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo
0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
0P000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`040000o`3oool0oooo0?ooo`80003o1@3oool2000000@0oooo00<0003o0?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`000000103oool00`000?l0oooo0000o`030?ooo`030000
o`3oool0003o00D0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00P0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`80003o0`0000020?ooo`05
0000003oool0oooo0?ooo`000?l0EP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`1[0?ooo`P0003o1P3oool00`000?l0oooo0?ooo`080?ooo`L0003o00<0oooo0000003o
ool00`3oool20000o`@0oooo0P000?l70?ooo`80003o1P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool20000
o`H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`@000000P3oool20000
o`80oooo00@000000?ooo`3oool0003oEP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000o`3oool0000000D0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`070?ooo`H0003o1@3oool00`000?l0oooo0?ooo`070?ooo`P0003o0`3oool00`00
0?l0oooo0000o`050000o`H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo000000020000
00030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool00000F@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo00<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool50000o`<000000`3oool70000o`@0oooo00<000000000o`000?l0EP3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0
oooo00<0003o0?ooo`3oool08@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03<0oooo
00<0003o0?ooo`3oool07P3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0500oooo1000
000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`1=0?ooo`<000007P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0BP3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo04L0oooo0`00000V0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000
003oool0oooo04@0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3o
ool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000
00120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000
003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0
oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56634 .57678 m
.56486 .6055 L
s
.71746 .59842 m
.71944 .59709 L
s
.71578 .59704 m
.71746 .59842 L
s
.6955 .59807 m
.69 .59799 L
s
.70113 .5968 m
.6955 .59807 L
s
.69 .59799 m
.68464 .59654 L
s
.66436 .59758 m
.66815 .59628 L
s
.65887 .59749 m
.66436 .59758 L
s
.71944 .59709 m
.71776 .5957 L
s
.71776 .5957 m
.71578 .59704 L
s
.65532 .59607 m
.65887 .59749 L
s
.70325 .59411 m
.70113 .5968 L
s
.63841 .57794 m
.63688 .59714 L
s
.68464 .59654 m
.68308 .59378 L
s
.62322 .58322 m
.62222 .59691 L
s
.66815 .59628 m
.67207 .59361 L
s
.60395 .56766 m
.60204 .59658 L
s
.65189 .59328 m
.65532 .59607 L
s
.5782 .5962 m
.57269 .59612 L
s
.58195 .5949 m
.5782 .5962 L
s
.57269 .59612 m
.56909 .59469 L
s
.55339 .57657 m
.5525 .59579 L
s
.54516 .59568 m
.54889 .59437 L
s
.53965 .59559 m
.54516 .59568 L
s
.53603 .59417 m
.53965 .59559 L
s
.70339 .59274 m
.70325 .59411 L
s
.58578 .59223 m
.58195 .5949 L
s
.56909 .59469 m
.56556 .5919 L
s
.50713 .57582 m
.50659 .59506 L
s
.54889 .59437 m
.55269 .5917 L
s
.48637 .59474 m
.49008 .59343 L
s
.47902 .59462 m
.48637 .59474 L
s
.6504 .58915 m
.65189 .59328 L
s
.53246 .59138 m
.53603 .59417 L
s
.70185 .58998 m
.70339 .59274 L
s
.47536 .5932 m
.47902 .59462 L
s
.45711 .57502 m
.4496 .59415 L
s
.44229 .57478 m
.4496 .59415 L
s
.44229 .57478 m
.43488 .59392 L
s
.42746 .57454 m
.43488 .59392 L
s
.49008 .59343 m
.49382 .59076 L
s
.47172 .5904 m
.47536 .5932 L
s
.58786 .58815 m
.58578 .59223 L
s
.41447 .57433 m
.41463 .5936 L
s
.40727 .59348 m
.41094 .59217 L
s
.40175 .59339 m
.40727 .59348 L
s
.39805 .59196 m
.40175 .59339 L
s
.36809 .57358 m
.3686 .59286 L
s
.69832 .58855 m
.70185 .58998 L
s
.53078 .58724 m
.53246 .59138 L
s
.41094 .59217 m
.4146 .58949 L
s
.3428 .59245 m
.32989 .59224 L
s
.34828 .59117 m
.3428 .59245 L
s
.39432 .58917 m
.39805 .59196 L
s
.32868 .56319 m
.32989 .59224 L
s
.72068 .56956 m
.71852 .58887 L
s
.49382 .59076 m
.49572 .58805 L
s
.65063 .58641 m
.6504 .58915 L
s
.68926 .58703 m
.69832 .58855 L
s
.46992 .58763 m
.47172 .5904 L
s
.35188 .58849 m
.34828 .59117 L
s
.58803 .58541 m
.58786 .58815 L
s
.68572 .5856 m
.68926 .58703 L
s
.3924 .58502 m
.39432 .58917 L
s
.49572 .58805 m
.49582 .58393 L
s
.65283 .58232 m
.65063 .58641 L
s
.53088 .58449 m
.53078 .58724 L
s
.46813 .58348 m
.46992 .58763 L
s
.35364 .58577 m
.35188 .58849 L
s
.68415 .58282 m
.68572 .5856 L
s
.58643 .58125 m
.58803 .58541 L
s
.70441 .58315 m
.70286 .58036 L
s
.53288 .58039 m
.53088 .58449 L
s
.35535 .58167 m
.35364 .58577 L
s
.68626 .5801 m
.68415 .58282 L
s
.62168 .57905 m
.62322 .58322 L
s
.50689 .5841 m
.50886 .58 L
s
.6731 .58264 m
.66966 .57983 L
s
.39235 .58227 m
.3924 .58502 L
s
.48659 .58378 m
.49582 .58393 L
s
.60295 .58289 m
.60876 .57885 L
s
.65675 .57962 m
.65283 .58232 L
s
.46822 .57658 m
.46813 .58348 L
s
.70286 .58036 m
.69747 .57889 L
s
.5829 .57843 m
.58643 .58125 L
s
.69193 .5788 m
.68626 .5801 L
s
.56612 .58092 m
.56996 .57822 L
s
.39414 .57815 m
.39235 .58227 L
s
.66966 .57983 m
.6661 .57839 L
s
.5532 .58071 m
.54963 .57789 L
s
.66056 .5783 m
.65675 .57962 L
s
.36831 .58188 m
.37005 .57777 L
s
.53668 .57768 m
.53288 .58039 L
s
.69747 .57889 m
.69193 .5788 L
s
.35513 .57476 m
.35535 .58167 L
s
.61809 .57761 m
.62168 .57905 L
s
.50886 .58 m
.51264 .5773 L
s
.6661 .57839 m
.66056 .5783 L
s
.60876 .57885 m
.61255 .57752 L
s
.57928 .57699 m
.5829 .57843 L
s
.56996 .57822 m
.57373 .5769 L
s
.61255 .57752 m
.61809 .57761 L
s
.54963 .57789 m
.54599 .57645 L
s
.54044 .57636 m
.53668 .57768 L
s
.41451 .57848 m
.41078 .57565 L
s
.57373 .5769 m
.57928 .57699 L
s
.51264 .5773 m
.51638 .57597 L
s
.3978 .57545 m
.39414 .57815 L
s
.54599 .57645 m
.54044 .57636 L
s
.37005 .57777 m
.37369 .57506 L
s
.47012 .57245 m
.46822 .57658 L
s
.51638 .57597 m
.52193 .57606 L
s
.41078 .57565 m
.40706 .57421 L
s
.40149 .57412 m
.3978 .57545 L
s
.37369 .57506 m
.37737 .57373 L
s
.35314 .57056 m
.35513 .57476 L
s
.40706 .57421 m
.40149 .57412 L
s
.49608 .57287 m
.49429 .57006 L
s
.37737 .57373 m
.38294 .57382 L
s
.47202 .5697 m
.47012 .57245 L
s
.63907 .56962 m
.64103 .56826 L
s
.63733 .5682 m
.63907 .56962 L
s
.49429 .57006 m
.49064 .56722 L
s
.47577 .56698 m
.47202 .5697 L
s
.64103 .56826 m
.63929 .56684 L
s
.63929 .56684 m
.63733 .5682 L
s
.35119 .56775 m
.35314 .57056 L
s
.49064 .56722 m
.48695 .56576 L
s
.47951 .56564 m
.47577 .56698 L
s
.34738 .56489 m
.35119 .56775 L
s
.48695 .56576 m
.47951 .56564 L
s
.34173 .56341 m
.34738 .56489 L
s
.32868 .56319 m
.34173 .56341 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Y0?ooo`H0003o5@3oool00`000000oooo0?oo
o`0H0?ooo`<00000E03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool00`3oool20000oa@0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo0`000?lh0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y0?oo
o`030000o`3oool0oooo00D0oooo0P000?lC0?ooo`030000003oool0oooo0100oooo0`0000040?oo
o`80003o0`3oool20000obT0oooo00<0003o0?ooo`3oool02P3oool20000oaL0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`<0
00001P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3o
ool02P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<0003o0?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool30000o`H0
oooo0`000?l00`000000003o0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<000000000o`00
0000203oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool08`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo0080oooo00@0003o0?ooo`000?l0003o1`3oool20000o`<0oooo0P000?l40?ooo`03
0000o`3oool000000080000000<0oooo0000o`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o
00h0oooo00<0003o0?ooo`000?l00`000?l60?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0003o203oool010000?l0oooo0?ooo`000?lR0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool20000
o`P0oooo00<0003o0?ooo`3oool0103oool010000?l000000?ooo`3oool2000000040000o`3oool0
oooo0?ooo`80003o103oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0P000?l90?ooo`040000
o`3oool0oooo0?ooo`<0003o103oool30000o`<0oooo00<0003o0?ooo`3oool01@3oool010000?l0
oooo0000o`3oool40000o`D0oooo00<0003o0?ooo`3oool0103oool60000o`D0oooo1@000?l20?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`00
000000000P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo0P00
0?l50?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20000o`H0oooo00D0
003o0?ooo`3oool0oooo0000o`050?ooo`80003o00<000000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000K03oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0000000<0oooo00@0003o0?ooo`3oool0003o0P3oool010000?l0oooo
0?ooo`000?l40?ooo`030000o`3oool0oooo00@0oooo1@000?l30?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0
oooo0P0000040?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000@0oooo
00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo
00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool02`3oool20000o`<000000P3oool01@000000oooo0?ooo`3oool0003o05H0oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0000000@0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`070?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool4000000@0003o0P3oool010000000
oooo0?ooo`000?mF0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0
oooo20000?l60?ooo`030000o`3oool0oooo00P0oooo1`000?l00`3oool000000?ooo`040?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00@0003o00000000000000001`3oool010000?l0oooo0?ooo`00001I
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo1@000?l60?oo
o`030000o`3oool0oooo00L0oooo20000?l40?ooo`L0003o1P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?oo
o`<000000`3oool00`000?l0oooo0?ooo`040?ooo`070000o`3oool0oooo0?ooo`000000oooo0000
o`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0=03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`040000o`0000000000000000H0oooo1`00
0?l50?ooo`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01d0oooo0`00000F
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01T0oooo1000000J0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01H0oooo0`00000N0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3o
ool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2
000008l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00
000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03o
ool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3
000008h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool40000
05H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A
0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?oo
o`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<0
00001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103o
ool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000
003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3
000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo
08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<0
0000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3o
ool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3
000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D
0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000
A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3
000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f
0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000
I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo
00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H
0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000
Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000
U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool20000
00@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo
0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003o
ool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2
000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000
oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo
0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`800000
00<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0
oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo
00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3o
ool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000
003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0
oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool30000
0140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0
oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo
0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000
003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<0
00000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3o
ool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool0
0`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo
0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0
oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo
1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`
0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?oo
o`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003o
ool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0
oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo
09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo0000
00l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000
oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool40000
04/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`00
0000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000
oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000
001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000
001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U
0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`800000
0`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3o
ool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03o
ool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000
oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo
0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00
002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F
0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`04
0000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`03
0000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000
303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903o
ool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303o
ool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0
oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool5
00000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool20000
00/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo0000
02<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0
oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo
0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00
003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?oo
o`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo
000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool20000
0=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0
oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56629 .57565 m
.565 .60914 L
s
.71773 .60046 m
.71968 .59891 L
s
.71601 .59885 m
.71773 .60046 L
s
.69573 .60011 m
.69023 .60003 L
s
.70135 .59861 m
.69573 .60011 L
s
.69023 .60003 m
.68484 .59835 L
s
.71968 .59891 m
.71797 .59729 L
s
.71797 .59729 m
.71601 .59885 L
s
.66456 .59962 m
.66833 .59809 L
s
.65906 .59953 m
.66456 .59962 L
s
.70342 .59546 m
.70135 .59861 L
s
.65549 .59788 m
.65906 .59953 L
s
.68484 .59835 m
.68323 .59514 L
s
.63831 .57682 m
.63705 .59918 L
s
.66833 .59809 m
.67221 .59496 L
s
.62321 .58299 m
.62236 .59894 L
s
.65201 .59464 m
.65549 .59788 L
s
.60378 .56497 m
.60217 .59862 L
s
.70353 .59387 m
.70342 .59546 L
s
.57829 .59824 m
.57278 .59815 L
s
.58203 .59671 m
.57829 .59824 L
s
.57278 .59815 m
.56917 .59651 L
s
.55335 .57544 m
.55256 .59783 L
s
.54521 .59772 m
.54894 .59618 L
s
.5397 .59763 m
.54521 .59772 L
s
.58585 .59359 m
.58203 .59671 L
s
.53607 .59598 m
.5397 .59763 L
s
.70193 .59066 m
.70353 .59387 L
s
.56917 .59651 m
.56561 .59326 L
s
.65046 .58983 m
.65201 .59464 L
s
.54894 .59618 m
.55273 .59306 L
s
.50712 .5747 m
.50659 .5971 L
s
.53249 .59273 m
.53607 .59598 L
s
.48635 .59678 m
.49006 .59524 L
s
.47899 .59666 m
.48635 .59678 L
s
.47533 .59501 m
.47899 .59666 L
s
.5879 .58883 m
.58585 .59359 L
s
.69837 .589 m
.70193 .59066 L
s
.45715 .57389 m
.44953 .59619 L
s
.44233 .57365 m
.44953 .59619 L
s
.49006 .59524 m
.49381 .59212 L
s
.44233 .57365 m
.43479 .59596 L
s
.42751 .57341 m
.43479 .59596 L
s
.4717 .59176 m
.47533 .59501 L
s
.72032 .56686 m
.71858 .58933 L
s
.41454 .5732 m
.41453 .59563 L
s
.53079 .58791 m
.53249 .59273 L
s
.40715 .59552 m
.41084 .59398 L
s
.40162 .59543 m
.40715 .59552 L
s
.68929 .58726 m
.69837 .589 L
s
.39793 .59378 m
.40162 .59543 L
s
.65065 .58664 m
.65046 .58983 L
s
.41084 .59398 m
.41453 .59085 L
s
.49381 .59212 m
.49572 .58895 L
s
.36818 .57245 m
.36843 .5949 L
s
.39423 .59052 m
.39793 .59378 L
s
.68572 .5856 m
.68929 .58726 L
s
.4699 .58854 m
.4717 .59176 L
s
.3426 .59449 m
.32968 .59428 L
s
.34811 .59298 m
.3426 .59449 L
s
.58804 .58563 m
.5879 .58883 L
s
.32897 .5605 m
.32968 .59428 L
s
.65278 .58187 m
.65065 .58664 L
s
.6841 .58237 m
.68572 .5856 L
s
.35175 .58985 m
.34811 .59298 L
s
.49572 .58895 m
.49582 .58415 L
s
.53088 .58471 m
.53079 .58791 L
s
.39236 .5857 m
.39423 .59052 L
s
.46812 .58371 m
.4699 .58854 L
s
.58641 .5808 m
.58804 .58563 L
s
.70435 .5827 m
.70275 .57946 L
s
.35355 .58668 m
.35175 .58985 L
s
.68616 .57919 m
.6841 .58237 L
s
.67305 .58219 m
.66957 .57893 L
s
.62162 .57815 m
.62321 .58299 L
s
.53287 .57994 m
.53088 .58471 L
s
.65667 .57872 m
.65278 .58187 L
s
.60293 .58267 m
.6087 .57795 L
s
.50689 .58433 m
.50886 .57955 L
s
.48659 .584 m
.49582 .58415 L
s
.70275 .57946 m
.69733 .57777 L
s
.35533 .5819 m
.35355 .58668 L
s
.6918 .57768 m
.68616 .57919 L
s
.39234 .58249 m
.39236 .5857 L
s
.46823 .57568 m
.46812 .58371 L
s
.58285 .57753 m
.58641 .5808 L
s
.66957 .57893 m
.66599 .57726 L
s
.66045 .57717 m
.65667 .57872 L
s
.69733 .57777 m
.6918 .57768 L
s
.56611 .58047 m
.56992 .57732 L
s
.55318 .58026 m
.5496 .57699 L
s
.66599 .57726 m
.66045 .57717 L
s
.61801 .57649 m
.62162 .57815 L
s
.53667 .57678 m
.53287 .57994 L
s
.6087 .57795 m
.61247 .5764 L
s
.39417 .5777 m
.39234 .58249 L
s
.50886 .57955 m
.51263 .5764 L
s
.57923 .57586 m
.58285 .57753 L
s
.36829 .58211 m
.37009 .57732 L
s
.61247 .5764 m
.61801 .57649 L
s
.56992 .57732 m
.57368 .57577 L
s
.35522 .57386 m
.35533 .5819 L
s
.5496 .57699 m
.54596 .57532 L
s
.57368 .57577 m
.57923 .57586 L
s
.54041 .57524 m
.53667 .57678 L
s
.51263 .5764 m
.51637 .57485 L
s
.54596 .57532 m
.54041 .57524 L
s
.41453 .57803 m
.41083 .57475 L
s
.51637 .57485 m
.52192 .57494 L
s
.39786 .57454 m
.39417 .5777 L
s
.47015 .57088 m
.46823 .57568 L
s
.37009 .57732 m
.37376 .57416 L
s
.41083 .57475 m
.40712 .57308 L
s
.40156 .57299 m
.39786 .57454 L
s
.37376 .57416 m
.37745 .5726 L
s
.49609 .5713 m
.4943 .56804 L
s
.40712 .57308 m
.40156 .57299 L
s
.35329 .56899 m
.35522 .57386 L
s
.63886 .56715 m
.6408 .56557 L
s
.6371 .56551 m
.63886 .56715 L
s
.47206 .56768 m
.47015 .57088 L
s
.37745 .5726 m
.38302 .57269 L
s
.6408 .56557 m
.63904 .56392 L
s
.63904 .56392 m
.6371 .56551 L
s
.4943 .56804 m
.49066 .56475 L
s
.47582 .56451 m
.47206 .56768 L
s
.35138 .56572 m
.35329 .56899 L
s
.49066 .56475 m
.48698 .56307 L
s
.47955 .56295 m
.47582 .56451 L
s
.48698 .56307 m
.47955 .56295 L
s
.34761 .56242 m
.35138 .56572 L
s
.342 .56071 m
.34761 .56242 L
s
.32897 .5605 m
.342 .56071 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo06T0oooo
1P000?lD0?ooo`030000003oool0oooo01`0oooo1000001@0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0J@3oool00`000?l0oooo0?oo
o`030?ooo`80003o4`3oool00`000000oooo0?ooo`0H0?ooo`<000000`000?lh0?ooo`030000o`3o
ool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool0
0`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00D0oooo0P000?lB0?ooo`030000003oool0
oooo01@0oooo0`0000000`3oool0003o0000o`030?ooo`80003o:@3oool00`000?l0oooo0?ooo`09
0?ooo`030000o`3oool0003o01L0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0403oool00`000000oooo0?ooo`0@0?ooo`<000000`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo02H0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0F0?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool04@3oool00`000000oooo0?ooo`0<0?ooo`<000001@3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`030?ooo`03
0000o`3oool0oooo0580oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
J@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l0
10000?l40?ooo`L0003o103oool00`000?l0oooo0?ooo`020?ooo`03000000000?l0000000<0oooo
00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`040000o`3oool0oooo0000ob00oooo00<0003o0?oo
o`3oool08`3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0580oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo0080oooo0P000?l80?ooo`030000o`3oool0oooo00<0oooo0P000?l40?ooo`03
0000o`3oool000000080000000<0oooo0000o`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o
00h0oooo00@0003o0?ooo`000?l0oooo0P000?l50?ooo`L0003o103oool70000o`L0oooo00<0003o
0?ooo`3oool00`000?l70?ooo`030000o`3oool0oooo00D0oooo0`000?l>0?ooo`030000003oool0
oooo00<0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00@0003o0000003oool0oooo0P000000
10000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`0<0?ooo`80003o203oool00`000?l0oooo0?ooo`030?ooo`80003o103oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l00`3oool20000o`D0oooo00<0
003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3oool20000o`D0oooo1`000?l00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0000000000080oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool30000
o`D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool01@00
0?l0oooo0?ooo`3oool0003o00L0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000K03oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0000000<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`05
0?ooo`030000o`3oool0oooo00@0oooo1@000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo0P000004
0?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000@0oooo00<0003o0?oo
o`000?l00P3oool00`000?l0oooo0000o`050?ooo`030000o`3oool0oooo00P0oooo00D0003o0?oo
o`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool2
0000o`<000000P3oool01@000000oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
000000@0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0
oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool02P3oool4000000@0003o0P3oool010000000oooo0?ooo`000?mF0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3o
ool20000o`030?ooo`000000oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool3000000L0oooo00@0
003o0?ooo`3oool00000F@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`1/0?ooo`L0003o1`3oool00`000?l0oooo0?ooo`080?ooo`L0003o00<0oooo0000003oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P000?l40?ooo`80003o103o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3o
ool3000000<0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0000005P0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0C0?ooo`D0003o1P3oool00`000?l0oooo0?ooo`090?ooo`@0003o00<0oooo0000o`3oool00`3o
ool70000o`H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`0000000P0000020000o`@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`030?ooo`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0
oooo01L0oooo00<0003o0?ooo`3oool00`3oool3000000<0003o1`3oool50000o`L0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool06@3oool4000001X0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo03@0oooo00<0003o0?ooo`3oool05P3oool3000001h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03@0oooo00<0003o0?ooo`3oool04`3oool300000280oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo04L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000003<0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<0
0000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403o
ool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo
0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?
0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<0
0000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3o
ool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo10000023
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?oo
o`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@00000
1@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo
1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000
903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo
1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<00000
0?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo
0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?oo
o`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003o
ool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo
0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<00000
0?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?oo
o`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
3P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003o
ool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool30000
08d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2
000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool0
00P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0
oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<0
00000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3o
ool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0
oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j
0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00
>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?oo
o`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c
0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04
0?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000
003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000
oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo
0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`38
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool00000
0?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool0
0000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool0
04@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo0000
0580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo
00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0
e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?oo
o`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`03
0000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2
000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`00
0000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000
000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S
0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3o
ool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool0
0`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`00
0000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000
oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool00000
02d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0
oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?oo
o`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?oo
o`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e
0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?oo
o`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00
R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000
LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000
M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0
oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo
00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?oo
o`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`15
0?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?oo
o`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?oo
o`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00
S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3o
ool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool0
0`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0
oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo
0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000
oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool50000
0;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo
00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?oo
o`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?
0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool01000
0000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0
oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool50000
0080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0
oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.56623 .57488 m
.56518 .61168 L
s
.71804 .60188 m
.71996 .60017 L
s
.71629 .60011 m
.71804 .60188 L
s
.69602 .60153 m
.69051 .60144 L
s
.70161 .59987 m
.69602 .60153 L
s
.71996 .60017 m
.71821 .59839 L
s
.71821 .59839 m
.71629 .60011 L
s
.69051 .60144 m
.68508 .59961 L
s
.70361 .59641 m
.70161 .59987 L
s
.6648 .60104 m
.66855 .59935 L
s
.65929 .60095 m
.6648 .60104 L
s
.68508 .59961 m
.6834 .59608 L
s
.65569 .59914 m
.65929 .60095 L
s
.66855 .59935 m
.67238 .59591 L
s
.6382 .57604 m
.63725 .6006 L
s
.65216 .59558 m
.65569 .59914 L
s
.7037 .59466 m
.70361 .59641 L
s
.62319 .58284 m
.62254 .60036 L
s
.60357 .56313 m
.60232 .60004 L
s
.70203 .59113 m
.7037 .59466 L
s
.57841 .59966 m
.57289 .59957 L
s
.58214 .59797 m
.57841 .59966 L
s
.65054 .5903 m
.65216 .59558 L
s
.57289 .59957 m
.56926 .59776 L
s
.58593 .59453 m
.58214 .59797 L
s
.55331 .57467 m
.55265 .59925 L
s
.69843 .58931 m
.70203 .59113 L
s
.54528 .59913 m
.54901 .59744 L
s
.53976 .59905 m
.54528 .59913 L
s
.56926 .59776 m
.56568 .5942 L
s
.53612 .59724 m
.53976 .59905 L
s
.71989 .56502 m
.71865 .58964 L
s
.54901 .59744 m
.55279 .594 L
s
.68932 .58741 m
.69843 .58931 L
s
.53252 .59367 m
.53612 .59724 L
s
.58794 .5893 m
.58593 .59453 L
s
.50711 .57393 m
.50661 .59852 L
s
.65068 .58679 m
.65054 .5903 L
s
.48634 .5982 m
.49006 .5965 L
s
.47897 .59808 m
.48634 .5982 L
s
.68572 .5856 m
.68932 .58741 L
s
.47531 .59627 m
.47897 .59808 L
s
.49006 .5965 m
.49381 .59306 L
s
.5308 .58838 m
.53252 .59367 L
s
.68404 .58206 m
.68572 .5856 L
s
.47168 .5927 m
.47531 .59627 L
s
.45717 .57312 m
.44947 .59761 L
s
.44237 .57288 m
.44947 .59761 L
s
.65273 .58156 m
.65068 .58679 L
s
.44237 .57288 m
.43471 .59737 L
s
.42756 .57264 m
.43471 .59737 L
s
.58805 .58579 m
.58794 .5893 L
s
.70429 .58239 m
.70261 .57884 L
s
.49381 .59306 m
.49572 .58958 L
s
.4146 .57243 m
.41442 .59705 L
s
.40703 .59693 m
.41074 .59524 L
s
.4015 .59684 m
.40703 .59693 L
s
.39781 .59503 m
.4015 .59684 L
s
.68604 .57857 m
.68404 .58206 L
s
.46989 .58916 m
.47168 .5927 L
s
.67299 .58188 m
.66946 .57831 L
s
.41074 .59524 m
.41445 .59179 L
s
.58638 .58049 m
.58805 .58579 L
s
.53089 .58487 m
.5308 .58838 L
s
.39413 .59146 m
.39781 .59503 L
s
.65656 .5781 m
.65273 .58156 L
s
.70261 .57884 m
.69717 .57699 L
s
.36828 .57168 m
.36826 .59632 L
s
.49572 .58958 m
.49582 .58431 L
s
.62154 .57753 m
.62319 .58284 L
s
.69165 .57691 m
.68604 .57857 L
s
.60291 .58251 m
.60863 .57733 L
s
.34239 .5959 m
.32945 .5957 L
s
.34793 .59424 m
.34239 .5959 L
s
.46812 .58386 m
.46989 .58916 L
s
.69717 .57699 m
.69165 .57691 L
s
.66946 .57831 m
.66585 .57649 L
s
.32928 .55867 m
.32945 .5957 L
s
.53286 .57963 m
.53089 .58487 L
s
.66032 .5764 m
.65656 .5781 L
s
.35162 .59079 m
.34793 .59424 L
s
.39231 .58616 m
.39413 .59146 L
s
.66585 .57649 m
.66032 .5764 L
s
.5828 .57691 m
.58638 .58049 L
s
.5069 .58449 m
.50885 .57924 L
s
.48659 .58416 m
.49582 .58431 L
s
.61791 .57571 m
.62154 .57753 L
s
.56608 .58016 m
.56988 .5767 L
s
.35347 .5873 m
.35162 .59079 L
s
.60863 .57733 m
.61238 .57563 L
s
.55317 .57995 m
.54957 .57637 L
s
.46825 .57506 m
.46812 .58386 L
s
.61238 .57563 m
.61791 .57571 L
s
.53664 .57616 m
.53286 .57963 L
s
.57916 .57509 m
.5828 .57691 L
s
.39232 .58265 m
.39231 .58616 L
s
.56988 .5767 m
.57362 .575 L
s
.50885 .57924 m
.51262 .57578 L
s
.35531 .58205 m
.35347 .5873 L
s
.57362 .575 m
.57916 .57509 L
s
.54957 .57637 m
.54592 .57455 L
s
.54038 .57446 m
.53664 .57616 L
s
.3942 .57739 m
.39232 .58265 L
s
.54592 .57455 m
.54038 .57446 L
s
.51262 .57578 m
.51635 .57407 L
s
.36827 .58226 m
.37013 .57701 L
s
.51635 .57407 m
.5219 .57416 L
s
.3553 .57324 m
.35531 .58205 L
s
.47018 .5698 m
.46825 .57506 L
s
.41456 .57772 m
.41088 .57414 L
s
.63861 .56547 m
.64053 .56373 L
s
.63683 .56367 m
.63861 .56547 L
s
.39792 .57393 m
.3942 .57739 L
s
.64053 .56373 m
.63875 .56193 L
s
.63875 .56193 m
.63683 .56367 L
s
.37013 .57701 m
.37383 .57354 L
s
.49608 .57022 m
.4943 .56666 L
s
.41088 .57414 m
.40719 .57231 L
s
.40163 .57222 m
.39792 .57393 L
s
.47208 .5663 m
.47018 .5698 L
s
.40719 .57231 m
.40163 .57222 L
s
.37383 .57354 m
.37754 .57183 L
s
.4943 .56666 m
.49066 .56306 L
s
.37754 .57183 m
.3831 .57192 L
s
.35344 .56791 m
.3553 .57324 L
s
.47584 .56282 m
.47208 .5663 L
s
.49066 .56306 m
.48699 .56123 L
s
.47958 .56111 m
.47584 .56282 L
s
.48699 .56123 m
.47958 .56111 L
s
.35158 .56434 m
.35344 .56791 L
s
.34786 .56074 m
.35158 .56434 L
s
.34228 .55888 m
.34786 .56074 L
s
.32928 .55867 m
.34228 .55888 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0J@3oool20000oaH0oooo00<000000?ooo`3oool08@3oool3000004`0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`1Z0?ooo`030000o`3oool0003o00D0003o4@3oool00`000000oooo0?ooo`0L0?ooo`<0003o
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0@0?ooo`030000003oool0oooo01P0oooo00<000000000o`000?l00`3oool20000obT0oooo00<0
003o0?ooo`3oool02@3oool30000oaL0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool0403oool00`000000oooo0?ooo`0D0?ooo`<0000000<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool05P3oool0
0`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
0100oooo00<000000?ooo`3oool0403oool300000080oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0V0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06X0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?oo
o`<0003o203oool00`000000oooo0?ooo`0<0?ooo`<000001@3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`00
0?l0003o1`3oool70000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000000003o000000030?oo
o`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`030000o`H0oooo0`000?l2
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0S
0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool20000o`P0oooo00<0003o0?ooo`3oool00`3oool20000o`@0oooo00<0003o0?oo
o`0000000P0000000`3oool0003o0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool0
0`000?l0oooo0000o`080?ooo`040000o`3oool0oooo0?ooo`<0003o103oool70000o`L0oooo00<0
003o0?ooo`000?l01@000?l50?ooo`030000o`3oool0oooo00D0oooo0`000?l90?ooo`<0003o0P3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000
oooo0?ooo`80000000@0003o0?ooo`3oool0oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0303oool20000o`P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80
003o1@3oool20000o`<0oooo0P000?l00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo
0?ooo`050?ooo`040000o`3oool0000000000080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0
003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool00P3oool20000o`H0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`80003o1P3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<0
00000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`800000K03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000<0oooo00L0003o
0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`800000103oool00`000?l0oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00<0
003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l0
203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo0P000?l300000080oooo
00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo06/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000
o`3oool0003o0080oooo00<0003o0?ooo`000?l01P3oool00`000?l0oooo0?ooo`070?ooo`050000
o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00`0oooo100000020000
o`@0oooo00@000000?ooo`3oool0003oEP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000000103oool00`00
0?l0oooo0000o`030?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00T0oooo0`000006
0?ooo`80003o0P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo06`0oooo20000?l60?ooo`030000o`3oool0oooo00P0oooo00<0003o0?oo
o`3oool00P3oool20000o`030?ooo`000000oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool30000
00<0oooo00<0003o0?ooo`3oool0103oool01@000?l0oooo0?ooo`3oool0000005P0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0QP3oool40000o`040?ooo`000?l0oooo
000000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`H0003o1@3oool0
0`000?l0oooo0?ooo`070?ooo`80003o103oool20000o`@0oooo0P000?l40?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool00`0000000`3oool0003o0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000000003o0?ooo`1E0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool40000
o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`000?l00`000?l70?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`<0000010000?l50?oo
o`P0003o103oool00`000?l000000?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0I0?ooo`@0
00006@3oool00`000?l000000?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0F0?ooo`<00000
7P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0C0?ooo`<000008P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0@0?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@0
0000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`00
0000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E
0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo
0900oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<00000
0P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo
0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<00000
8@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0
oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo
0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2
000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo
1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?oo
o`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool30000
06X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo
1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?oo
o`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?oo
o`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
4@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool30000
08X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2
000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo
0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100
oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<0
00000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool0
01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P000000
0`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool20000
0100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo
0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<0
00000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?oo
o`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo
00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[
0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S
0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000
GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3o
ool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool0
04@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo
00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo
001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`000000
0`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool00000
0`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I
0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<00000
0P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo
0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180
oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo
001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^
0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?oo
o`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`03
0000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4
000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool50000
03T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0
oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340
oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo
00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0
oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo
1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00
001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?oo
o`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?oo
o`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`80
00009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0
oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool0
0`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo
1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000
002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`80
00005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`000000
4P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3o
ool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0
oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03o
ool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool0
0`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool20000
0140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000
oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180
oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?oo
o`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000
`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo1000
00360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?oo
o`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool40000
0=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71839 .60262 m
.72027 .60082 L
s
.7166 .60076 m
.71839 .60262 L
s
.72027 .60082 m
.71849 .59896 L
s
.71849 .59896 m
.7166 .60076 L
s
.69633 .60227 m
.69082 .60218 L
s
.7019 .60052 m
.69633 .60227 L
s
.70383 .59689 m
.7019 .60052 L
s
.69082 .60218 m
.68535 .60026 L
s
.70388 .59506 m
.70383 .59689 L
s
.68535 .60026 m
.6836 .59657 L
s
.70213 .59137 m
.70388 .59506 L
s
.66507 .60177 m
.6688 .6 L
s
.65956 .60168 m
.66507 .60177 L
s
.6688 .6 m
.67257 .59639 L
s
.65592 .59979 m
.65956 .60168 L
s
.71942 .56411 m
.71873 .5898 L
s
.6985 .58947 m
.70213 .59137 L
s
.65233 .59607 m
.65592 .59979 L
s
.68935 .58749 m
.6985 .58947 L
s
.63807 .57565 m
.63748 .60133 L
s
.65062 .59054 m
.65233 .59607 L
s
.56617 .57449 m
.56539 .61301 L
s
.62316 .58276 m
.62275 .6011 L
s
.68572 .5856 m
.68935 .58749 L
s
.70421 .58223 m
.70247 .57853 L
s
.68397 .5819 m
.68572 .5856 L
s
.60333 .56222 m
.6025 .60077 L
s
.65071 .58687 m
.65062 .59054 L
s
.70247 .57853 m
.697 .57661 L
s
.68591 .57826 m
.68397 .5819 L
s
.65268 .5814 m
.65071 .58687 L
s
.67293 .58172 m
.66934 .578 L
s
.57855 .60039 m
.57302 .60031 L
s
.58227 .59862 m
.57855 .60039 L
s
.697 .57661 m
.69148 .57652 L
s
.69148 .57652 m
.68591 .57826 L
s
.58603 .59501 m
.58227 .59862 L
s
.57302 .60031 m
.56937 .59841 L
s
.56937 .59841 m
.56576 .59469 L
s
.58799 .58954 m
.58603 .59501 L
s
.65645 .57779 m
.65268 .5814 L
s
.66934 .578 m
.6657 .5761 L
s
.55325 .57428 m
.55275 .59998 L
s
.6657 .5761 m
.66018 .57601 L
s
.66018 .57601 m
.65645 .57779 L
s
.54538 .59987 m
.5491 .59809 L
s
.53984 .59978 m
.54538 .59987 L
s
.5491 .59809 m
.55286 .59448 L
s
.53619 .59788 m
.53984 .59978 L
s
.62145 .57722 m
.62316 .58276 L
s
.58807 .58587 m
.58799 .58954 L
s
.53257 .59416 m
.53619 .59788 L
s
.58634 .58033 m
.58807 .58587 L
s
.60289 .58243 m
.60854 .57701 L
s
.6178 .57533 m
.62145 .57722 L
s
.53083 .58862 m
.53257 .59416 L
s
.50709 .57354 m
.50664 .59925 L
s
.61227 .57524 m
.6178 .57533 L
s
.60854 .57701 m
.61227 .57524 L
s
.58273 .5766 m
.58634 .58033 L
s
.48635 .59893 m
.49007 .59715 L
s
.47896 .59881 m
.48635 .59893 L
s
.49007 .59715 m
.49382 .59354 L
s
.5309 .58495 m
.53083 .58862 L
s
.4753 .59692 m
.47896 .59881 L
s
.56606 .58 m
.56982 .57639 L
s
.57908 .5747 m
.58273 .5766 L
s
.63833 .56463 m
.64021 .56282 L
s
.63653 .56276 m
.63833 .56463 L
s
.49382 .59354 m
.49573 .5899 L
s
.47167 .59319 m
.4753 .59692 L
s
.53284 .57947 m
.5309 .58495 L
s
.64021 .56282 m
.63841 .56096 L
s
.57355 .57461 m
.57908 .5747 L
s
.55314 .5798 m
.54952 .57606 L
s
.56982 .57639 m
.57355 .57461 L
s
.63841 .56096 m
.63653 .56276 L
s
.49573 .5899 m
.49582 .58439 L
s
.4572 .57273 m
.44942 .59834 L
s
.4424 .57249 m
.44942 .59834 L
s
.46988 .58948 m
.47167 .59319 L
s
.5366 .57585 m
.53284 .57947 L
s
.54952 .57606 m
.54587 .57416 L
s
.5069 .58456 m
.50884 .57908 L
s
.4424 .57249 m
.43464 .5981 L
s
.42761 .57225 m
.43464 .5981 L
s
.48659 .58424 m
.49582 .58439 L
s
.46812 .58394 m
.46988 .58948 L
s
.54587 .57416 m
.54033 .57408 L
s
.54033 .57408 m
.5366 .57585 L
s
.50884 .57908 m
.5126 .57547 L
s
.41465 .57205 m
.41431 .59778 L
s
.40692 .59766 m
.41064 .59589 L
s
.40137 .59757 m
.40692 .59766 L
s
.51633 .57369 m
.52187 .57378 L
s
.5126 .57547 m
.51633 .57369 L
s
.41064 .59589 m
.41439 .59227 L
s
.3977 .59568 m
.40137 .59757 L
s
.46826 .57475 m
.46812 .58394 L
s
.39404 .59195 m
.3977 .59568 L
s
.39226 .5864 m
.39404 .59195 L
s
.36837 .5713 m
.36808 .59705 L
s
.49607 .56968 m
.49429 .56597 L
s
.4702 .56926 m
.46826 .57475 L
s
.34218 .59663 m
.32922 .59643 L
s
.34775 .59488 m
.34218 .59663 L
s
.49429 .56597 m
.49065 .56223 L
s
.39231 .58273 m
.39226 .5864 L
s
.35149 .59127 m
.34775 .59488 L
s
.4721 .56561 m
.4702 .56926 L
s
.32959 .55777 m
.32922 .59643 L
s
.35338 .58762 m
.35149 .59127 L
s
.39423 .57724 m
.39231 .58273 L
s
.41458 .57756 m
.41093 .57383 L
s
.49065 .56223 m
.48698 .56033 L
s
.47586 .56199 m
.4721 .56561 L
s
.35529 .58213 m
.35338 .58762 L
s
.48698 .56033 m
.47959 .56021 L
s
.47959 .56021 m
.47586 .56199 L
s
.39798 .57362 m
.39423 .57724 L
s
.41093 .57383 m
.40725 .57193 L
s
.36825 .58234 m
.37016 .57685 L
s
.40725 .57193 m
.4017 .57184 L
s
.4017 .57184 m
.39798 .57362 L
s
.35539 .57293 m
.35529 .58213 L
s
.37016 .57685 m
.37391 .57323 L
s
.37763 .57145 m
.38319 .57154 L
s
.37391 .57323 m
.37763 .57145 L
s
.35359 .56737 m
.35539 .57293 L
s
.35178 .56366 m
.35359 .56737 L
s
.34811 .55991 m
.35178 .56366 L
s
.34257 .55798 m
.34811 .55991 L
s
.32959 .55777 m
.34257 .55798 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0J@3oool60000oa80oooo00<000000?ooo`3oool08@3oool3000004`0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`1Z0?ooo`030000o`3oool0oooo00<0oooo0P000?lA0?ooo`030000003oool0oooo01`0oooo
0`000?l00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`0300000000
0?l0003o00<0oooo0P000?lY0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`000?l05`3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0100oooo00<000000?ooo`3oool0503oool3000000030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo0`0000020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool09P3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool30000
o`H0oooo0`000?l00`3oool0003o0?ooo`0;0?ooo`<00000103oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`00
0?l0003o1`3oool20000o`<0oooo0P000?l40?ooo`030000o`3oool0oooo0080oooo00<000000000
o`0000000`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool00`000?l6
0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0003o203oool0
0`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3oool20000o`P0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool000000080000000<0oooo0000o`3oool00`3oool01@00
0?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`000?l0203oool010000?l0oooo0?ooo`3o
ool30000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l01@00
0?l50?ooo`030000o`3oool0oooo00D0oooo0`000?l90?ooo`<0003o0P3oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?ooo`80000000@0
003o0?ooo`3oool0oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
303oool20000o`P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool20000o`<0
oooo0P000?l00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000
o`3oool0000000000080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool20000o`D0oooo0P000?l30?ooo`030000o`3oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`800000K03oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000<0oooo00L0003o0?oo
o`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`800000103oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00<0003o
0?ooo`000?l01@3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l0203o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo0P000?l300000080oooo00D0
00000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo06/0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3o
ool0003o0080oooo00<0003o0?ooo`000?l01P3oool00`000?l0oooo0?ooo`070?ooo`050000o`3o
ool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo
100000020000o`@0oooo00@000000?ooo`3oool0003oEP3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000000
103oool00`000?l0oooo0000o`030?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo0`0000060?ooo`80003o0P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3oool00`3o
ool20000o`H0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`80003o00<0
oooo0000003oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`<000002P3oool01@000?l0oooo0?oo
o`3oool0000005P0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0K03o
ool60000o`P0oooo00<0003o0?ooo`3oool02@3oool40000o`040?ooo`000?l0oooo000000D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`L0003o1@3oool00`000?l0oooo
0?ooo`070?ooo`80003o103oool20000o`@0oooo0P000?l40?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00`0000020?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0
oooo0?ooo`020?ooo`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00T0oooo
10000?l00`3oool0003o0?ooo`030?ooo`030000o`3oool0003o00<0003o203oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3000000030000
o`3oool0oooo0080003o103oool20000o`D0oooo00<0003o0?ooo`3oool00P3oool00`000?l00000
0000o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0I0?ooo`@00000103oool20000o`P0oooo1@00
0?l60?ooo`030000o`000000oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01H0oooo0`00000N
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01<0oooo0`00000R0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0100oooo0`00000V0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000
003oool0oooo03@0oooo00<0003o0?ooo`3oool03@3oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0
oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`000017
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo
000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H
0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool40000
01@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?oo
o`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo
0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?oo
o`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool30000
05D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?oo
o`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3o
ool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool30000
07@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?oo
o`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool00000
00800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000
UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203o
ool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool0
02<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000
oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00
503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool0
0`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool0
0340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?oo
o`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?oo
o`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool20000
06`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo
0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?oo
o`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000
003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03o
ool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@00
0000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?oo
o`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<00000
0?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000
A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003o
ool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0
oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo
001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`03
0000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000
003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003o
ool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0
oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03o
ool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3o
ool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool0
0`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0
oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0
oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo
1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo0028
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?oo
o`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?oo
o`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?oo
o`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool0
0`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`00
0000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0
oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I
0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?oo
o`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`80
0000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000
003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
9`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3o
ool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0
oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3o
ool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140
oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo
002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003o
ool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool3
00000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3o
ool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2
000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71893 .56417 m
.71881 .5898 L
s
.63806 .56102 m
.6362 .56282 L
s
.63988 .56288 m
.63806 .56102 L
s
.63803 .56468 m
.63988 .56288 L
s
.6362 .56282 m
.63803 .56468 L
s
.69681 .57662 m
.69129 .57653 L
s
.70232 .57854 m
.69681 .57662 L
s
.70414 .58223 m
.70232 .57854 L
s
.69129 .57653 m
.68576 .57827 L
s
.68576 .57827 m
.6839 .58191 L
s
.60307 .56228 m
.60269 .60079 L
s
.66554 .57611 m
.66002 .57602 L
s
.66921 .57801 m
.66554 .57611 L
s
.67286 .58173 m
.66921 .57801 L
s
.66002 .57602 m
.65633 .5778 L
s
.6839 .58191 m
.68572 .5856 L
s
.65633 .5778 m
.65262 .5814 L
s
.68572 .5856 m
.68939 .58749 L
s
.63793 .57567 m
.63772 .60135 L
s
.69858 .58947 m
.70225 .59136 L
s
.68939 .58749 m
.69858 .58947 L
s
.70225 .59136 m
.70407 .59506 L
s
.65262 .5814 m
.65074 .58687 L
s
.61768 .57534 m
.62135 .57723 L
s
.61216 .57525 m
.61768 .57534 L
s
.70407 .59506 m
.70406 .5969 L
s
.62135 .57723 m
.62314 .58276 L
s
.60845 .57702 m
.61216 .57525 L
s
.72061 .60083 m
.71877 .59896 L
s
.71877 .59896 m
.71693 .60077 L
s
.70406 .5969 m
.7022 .60054 L
s
.71876 .60263 m
.72061 .60083 L
s
.60287 .58244 m
.60845 .57702 L
s
.71693 .60077 m
.71876 .60263 L
s
.65074 .58687 m
.65071 .59054 L
s
.62314 .58276 m
.62297 .60111 L
s
.7022 .60054 m
.69667 .60228 L
s
.68563 .60027 m
.68381 .59657 L
s
.57899 .57472 m
.58266 .57661 L
s
.57346 .57463 m
.57899 .57472 L
s
.65071 .59054 m
.65251 .59607 L
s
.58266 .57661 m
.58631 .58033 L
s
.56976 .5764 m
.57346 .57463 L
s
.66906 .60001 m
.67277 .5964 L
s
.69667 .60228 m
.69115 .6022 L
s
.69115 .6022 m
.68563 .60027 L
s
.56609 .57451 m
.56564 .61307 L
s
.56603 .58001 m
.56976 .5764 L
s
.58631 .58033 m
.58809 .58587 L
s
.55318 .5743 m
.55287 .6 L
s
.65251 .59607 m
.65616 .5998 L
s
.48696 .56039 m
.47958 .56027 L
s
.49062 .56229 m
.48696 .56039 L
s
.66536 .60178 m
.66906 .60001 L
s
.54581 .57418 m
.54028 .57409 L
s
.54947 .57607 m
.54581 .57418 L
s
.49426 .56601 m
.49062 .56229 L
s
.47958 .56027 m
.47586 .56205 L
s
.55312 .5798 m
.54947 .57607 L
s
.54028 .57409 m
.53656 .57586 L
s
.65984 .6017 m
.66536 .60178 L
s
.65616 .5998 m
.65984 .6017 L
s
.58809 .58587 m
.58805 .58954 L
s
.49605 .56971 m
.49426 .56601 L
s
.47586 .56205 m
.47211 .56565 L
s
.53656 .57586 m
.53282 .57947 L
s
.51629 .5737 m
.52183 .57379 L
s
.51258 .57548 m
.51629 .5737 L
s
.58805 .58954 m
.58615 .59501 L
s
.47211 .56565 m
.4702 .56929 L
s
.50707 .57355 m
.50669 .59926 L
s
.53282 .57947 m
.53091 .58495 L
s
.50883 .57909 m
.51258 .57548 L
s
.4702 .56929 m
.46827 .57476 L
s
.58615 .59501 m
.58242 .59863 L
s
.50691 .58456 m
.50883 .57909 L
s
.53091 .58495 m
.53086 .58862 L
s
.5695 .59842 m
.56585 .59469 L
s
.58242 .59863 m
.57871 .60041 L
s
.46827 .57476 m
.46811 .58394 L
s
.53086 .58862 m
.53263 .59416 L
s
.45721 .57275 m
.44938 .59835 L
s
.5492 .5981 m
.55293 .59448 L
s
.57871 .60041 m
.57317 .60032 L
s
.57317 .60032 m
.5695 .59842 L
s
.44243 .57251 m
.44938 .59835 L
s
.44243 .57251 m
.43458 .59811 L
s
.48659 .58424 m
.49583 .58439 L
s
.49574 .5899 m
.49583 .58439 L
s
.53263 .59416 m
.53627 .59789 L
s
.54548 .59988 m
.5492 .5981 L
s
.42765 .57227 m
.43458 .59811 L
s
.53994 .59979 m
.54548 .59988 L
s
.53627 .59789 m
.53994 .59979 L
s
.41471 .57206 m
.41422 .59779 L
s
.49384 .59354 m
.49574 .5899 L
s
.46811 .58394 m
.46987 .58948 L
s
.40731 .57194 m
.40176 .57185 L
s
.41097 .57384 m
.40731 .57194 L
s
.34284 .55805 m
.34835 .55997 L
s
.32989 .55784 m
.34284 .55805 L
s
.34835 .55997 m
.35197 .5637 L
s
.4146 .57757 m
.41097 .57384 L
s
.40176 .57185 m
.39803 .57363 L
s
.32989 .55784 m
.32899 .59643 L
s
.49009 .59716 m
.49384 .59354 L
s
.39803 .57363 m
.39426 .57724 L
s
.35197 .5637 m
.35374 .5674 L
s
.46987 .58948 m
.47166 .59319 L
s
.37772 .57146 m
.38327 .57155 L
s
.37398 .57324 m
.37772 .57146 L
s
.35374 .5674 m
.35547 .57294 L
s
.48636 .59894 m
.49009 .59716 L
s
.47166 .59319 m
.4753 .59692 L
s
.36847 .57131 m
.36792 .59705 L
s
.39426 .57724 m
.39229 .58272 L
s
.3702 .57685 m
.37398 .57324 L
s
.47897 .59882 m
.48636 .59894 L
s
.4753 .59692 m
.47897 .59882 L
s
.35547 .57294 m
.35527 .58213 L
s
.36823 .58234 m
.3702 .57685 L
s
.39229 .58272 m
.39222 .5864 L
s
.39222 .5864 m
.39396 .59195 L
s
.41055 .59589 m
.41432 .59227 L
s
.35527 .58213 m
.3533 .58762 L
s
.39396 .59195 m
.39759 .59568 L
s
.40681 .59767 m
.41055 .59589 L
s
.40126 .59758 m
.40681 .59767 L
s
.39759 .59568 m
.40126 .59758 L
s
.3533 .58762 m
.35136 .59127 L
s
.35136 .59127 m
.34757 .59489 L
s
.34757 .59489 m
.34197 .59664 L
s
.34197 .59664 m
.32899 .59643 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0J@3oool60000oa80oooo00<000000?ooo`3oool08@3oool3000004`0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`1Z0?ooo`030000o`3oool0oooo00<0oooo0P000?lA0?ooo`030000003oool0oooo01`0oooo
0`000?l00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0H0?ooo`0300000000
0?l0003o00<0oooo0P000?lY0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`000?l05`3o
ool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0100oooo00<000000?ooo`3oool0503oool3000000030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01H0oooo00<00000
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0@0?oo
o`030000003oool0oooo0100oooo0`0000020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool09P3oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0003o0?oo
o`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool30000
o`H0oooo0`000?l00`3oool0003o0?ooo`0;0?ooo`<00000103oool00`000?l0oooo0?ooo`080?oo
o`030000o`3oool0oooo02D0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`00
0?l0003o1`3oool20000o`<0oooo0P000?l40?ooo`030000o`3oool0oooo0080oooo00<000000000
o`0000000`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool00`000?l6
0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0003o203oool0
0`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3oool20000o`P0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool000000080000000<0oooo0000o`3oool00`3oool01@00
0?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`000?l0203oool010000?l0oooo0?ooo`3o
ool30000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000?l01@00
0?l50?ooo`030000o`3oool0oooo00D0oooo0`000?l90?ooo`<0003o0P3oool00`000000oooo0?oo
o`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000oooo0?ooo`80000000@0
003o0?ooo`3oool0oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
303oool20000o`P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool20000o`<0
oooo0P000?l00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`040000
o`3oool0000000000080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool20000o`D0oooo0P000?l30?ooo`030000o`3oool0oooo00@0oooo00<0003o
0000003oool00`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`800000J`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000<0oooo00L0003o0?oo
o`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`030?ooo`800000103oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00<0003o
0?ooo`000?l01@3oool00`000?l0oooo0?ooo`080?ooo`050000o`3oool0oooo0?ooo`000?l0203o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo0P000?l300000080oooo00D0
00000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3o
ool0003o0080oooo00<0003o0?ooo`000?l01P3oool00`000?l0oooo0?ooo`070?ooo`050000o`3o
ool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo
100000020000o`@0oooo00@000000?ooo`3oool0003oEP3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000000
103oool00`000?l0oooo0000o`030?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo0`0000060?ooo`80003o0P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool0103o
ool20000o`H0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?ooo`020?ooo`80003o00<0
oooo0000003oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`<000002P3oool01@000?l0oooo0?oo
o`3oool0000005P0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0J`3o
ool70000o`P0oooo00<0003o0?ooo`3oool02@3oool40000o`040?ooo`000?l0oooo000000D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`L0003o1@3oool00`000?l0oooo
0?ooo`070?ooo`80003o103oool20000o`@0oooo0P000?l40?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`0000000P0000020?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0
oooo0?ooo`020?ooo`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00T0oooo
10000?l00`3oool0003o0?ooo`030?ooo`030000o`3oool0003o00<0003o203oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3000000<0oooo
0P000?l50?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l00000
0000o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0I0?ooo`@000000`3oool30000o`P0oooo1@00
0?l60?ooo`030000o`000000oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01H0oooo0`00000N
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01<0oooo0`00000R0?oo
o`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0100oooo0`00000V0?ooo`03
0000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000
003oool0oooo03@0oooo00<0003o0?ooo`3oool03@3oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0
oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`000017
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo
000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H
0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool40000
01@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?oo
o`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo
0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?oo
o`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool30000
05D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?oo
o`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3o
ool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool30000
07@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?oo
o`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool00000
00800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000
UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203o
ool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool0
02<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000
oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00
503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool0
0`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool0
0340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?oo
o`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?oo
o`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool20000
06`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo
0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?oo
o`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000
003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03o
ool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@00
0000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?oo
o`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<00000
0?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000
A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003o
ool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0
oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo
001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`03
0000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000
003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003o
ool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0
oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03o
ool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3o
ool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool0
0`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0
oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0
oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo
1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo0028
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?oo
o`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?oo
o`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?oo
o`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool0
0`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`00
0000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0
oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I
0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?oo
o`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`80
0000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000
003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
9`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3o
ool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0
oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3o
ool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140
oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo
002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003o
ool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool3
00000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3o
ool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2
000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71843 .56518 m
.7189 .58964 L
s
.63769 .56213 m
.63587 .56384 L
s
.63954 .5639 m
.63769 .56213 L
s
.63772 .56561 m
.63954 .5639 L
s
.63587 .56384 m
.63772 .56561 L
s
.60281 .5633 m
.60289 .60008 L
s
.69662 .57703 m
.69111 .57694 L
s
.70216 .57887 m
.69662 .57703 L
s
.69111 .57694 m
.68562 .5786 L
s
.70406 .5824 m
.70216 .57887 L
s
.48692 .56142 m
.47956 .5613 L
s
.49058 .56322 m
.48692 .56142 L
s
.66538 .57653 m
.65986 .57644 L
s
.66908 .57833 m
.66538 .57653 L
s
.47956 .5613 m
.47585 .56298 L
s
.65986 .57644 m
.6562 .57813 L
s
.68562 .5786 m
.68383 .58207 L
s
.49422 .56677 m
.49058 .56322 L
s
.6728 .58189 m
.66908 .57833 L
s
.63779 .57608 m
.63797 .60064 L
s
.47585 .56298 m
.4721 .56641 L
s
.6562 .57813 m
.65256 .58157 L
s
.61756 .57575 m
.62125 .57756 L
s
.61204 .57567 m
.61756 .57575 L
s
.60836 .57735 m
.61204 .57567 L
s
.68383 .58207 m
.68572 .5856 L
s
.49602 .57029 m
.49422 .56677 L
s
.62125 .57756 m
.62311 .58284 L
s
.60285 .58252 m
.60836 .57735 L
s
.5789 .57513 m
.58258 .57694 L
s
.57338 .57504 m
.5789 .57513 L
s
.4721 .56641 m
.4702 .56988 L
s
.65256 .58157 m
.65077 .58679 L
s
.56969 .57673 m
.57338 .57504 L
s
.56601 .57492 m
.5659 .61184 L
s
.58258 .57694 m
.58627 .5805 L
s
.68572 .5856 m
.68943 .58741 L
s
.55311 .57471 m
.55299 .59928 L
s
.54574 .5746 m
.54022 .57451 L
s
.54942 .5764 m
.54574 .5746 L
s
.56599 .58017 m
.56969 .57673 L
s
.54022 .57451 m
.53652 .5762 L
s
.68943 .58741 m
.69866 .58931 L
s
.34309 .55908 m
.34857 .56091 L
s
.33016 .55887 m
.34309 .55908 L
s
.55309 .57996 m
.54942 .5764 L
s
.4702 .56988 m
.46827 .57509 L
s
.51625 .57412 m
.52178 .57421 L
s
.62311 .58284 m
.62321 .6004 L
s
.51255 .57581 m
.51625 .57412 L
s
.69866 .58931 m
.70237 .59112 L
s
.33016 .55887 m
.32879 .59572 L
s
.53652 .5762 m
.5328 .57964 L
s
.58627 .5805 m
.58811 .58579 L
s
.50703 .57397 m
.50675 .59855 L
s
.34857 .56091 m
.35214 .56447 L
s
.65077 .58679 m
.6508 .5903 L
s
.70237 .59112 m
.70427 .59466 L
s
.50882 .57925 m
.51255 .57581 L
s
.35214 .56447 m
.35387 .56799 L
s
.45722 .57317 m
.44935 .59763 L
s
.5328 .57964 m
.53092 .58487 L
s
.44245 .57293 m
.44935 .59763 L
s
.44245 .57293 m
.43452 .5974 L
s
.46827 .57509 m
.46811 .58386 L
s
.70427 .59466 m
.7043 .59642 L
s
.6508 .5903 m
.65269 .5956 L
s
.58811 .58579 m
.58811 .58929 L
s
.50691 .58448 m
.50882 .57925 L
s
.42768 .57269 m
.43452 .5974 L
s
.41475 .57248 m
.41414 .59707 L
s
.7043 .59642 m
.70251 .5999 L
s
.40736 .57236 m
.40182 .57227 L
s
.41101 .57417 m
.40736 .57236 L
s
.35387 .56799 m
.35555 .57328 L
s
.72094 .6002 m
.71906 .59841 L
s
.71906 .59841 m
.71726 .60014 L
s
.40182 .57227 m
.39808 .57396 L
s
.68592 .59964 m
.68403 .5961 L
s
.41462 .57774 m
.41101 .57417 L
s
.37779 .57188 m
.38334 .57197 L
s
.66932 .59938 m
.67297 .59592 L
s
.71913 .60193 m
.72094 .6002 L
s
.37404 .57357 m
.37779 .57188 L
s
.58811 .58929 m
.58626 .59454 L
s
.71726 .60014 m
.71913 .60193 L
s
.53092 .58487 m
.53089 .58838 L
s
.39808 .57396 m
.39428 .57741 L
s
.36855 .57173 m
.36777 .59634 L
s
.65269 .5956 m
.65641 .59917 L
s
.70251 .5999 m
.69701 .60158 L
s
.37023 .57702 m
.37404 .57357 L
s
.69148 .60149 m
.68592 .59964 L
s
.48659 .58416 m
.49583 .5843 L
s
.49576 .58957 m
.49583 .5843 L
s
.35555 .57328 m
.35525 .58205 L
s
.69701 .60158 m
.69148 .60149 L
s
.66566 .60108 m
.66932 .59938 L
s
.53089 .58838 m
.53269 .59368 L
s
.39428 .57741 m
.39228 .58264 L
s
.65641 .59917 m
.66012 .60099 L
s
.46811 .58386 m
.46987 .58916 L
s
.66012 .60099 m
.66566 .60108 L
s
.58626 .59454 m
.58257 .59799 L
s
.36821 .58226 m
.37023 .57702 L
s
.56964 .59779 m
.56595 .59421 L
s
.5493 .59746 m
.55302 .594 L
s
.49386 .59306 m
.49576 .58957 L
s
.53269 .59368 m
.53636 .59726 L
s
.58257 .59799 m
.57887 .5997 L
s
.39228 .58264 m
.39218 .58616 L
s
.46987 .58916 m
.47166 .59271 L
s
.57333 .59961 m
.56964 .59779 L
s
.57887 .5997 m
.57333 .59961 L
s
.5456 .59917 m
.5493 .59746 L
s
.49011 .59652 m
.49386 .59306 L
s
.35525 .58205 m
.35322 .58729 L
s
.53636 .59726 m
.54005 .59908 L
s
.47166 .59271 m
.47531 .59629 L
s
.39218 .58616 m
.39389 .59146 L
s
.54005 .59908 m
.5456 .59917 L
s
.48639 .59822 m
.49011 .59652 L
s
.47531 .59629 m
.47898 .59811 L
s
.41047 .59525 m
.41427 .59179 L
s
.47898 .59811 m
.48639 .59822 L
s
.35322 .58729 m
.35124 .59078 L
s
.39389 .59146 m
.3975 .59505 L
s
.40672 .59696 m
.41047 .59525 L
s
.35124 .59078 m
.34741 .59425 L
s
.3975 .59505 m
.40116 .59687 L
s
.40116 .59687 m
.40672 .59696 L
s
.34741 .59425 m
.34178 .59592 L
s
.34178 .59592 m
.32879 .59572 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo06X0oooo
20000?lA0?ooo`030000003oool0oooo01`0oooo0`000?l00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0JP3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool0603o
ool00`000000003o0000o`030?ooo`80003o:@3oool00`000?l0oooo0?ooo`090?ooo`80003o603o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo06X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0@0?ooo`030000003oool0
oooo01@0oooo0`0000000`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02H0oooo00<0003o
0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0080oooo00<0003o
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0403oool00`000000oooo0?ooo`0@0?oo
o`<000000P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02H0oooo00<0003o0?oo
o`3oool08`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0`000?l80?ooo`030000003oool0oooo
00`0oooo0`0000050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l70?ooo`L0003o103oool00`00
0?l0oooo0?ooo`020?ooo`03000000000?l0000000<0oooo00D0003o0?ooo`3oool0oooo0000o`0>
0?ooo`030000o`3oool0oooo00<0003o1P3oool30000o`80oooo00<0003o0?ooo`3oool0403oool0
0`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3oool20000o`P0oooo00<0003o0?ooo`3oool00`3oool20000
o`@0oooo00<0003o0?ooo`0000000P0000000`3oool0003o0?ooo`030?ooo`050000o`3oool0oooo
0?ooo`000?l03P3oool00`000?l0oooo0000o`080?ooo`040000o`3oool0oooo0?ooo`<0003o103o
ool70000o`L0oooo00<0003o0?ooo`000?l01@000?l50?ooo`030000o`3oool0oooo00D0oooo0`00
0?l90?ooo`<0003o0P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`040000o`000000oooo0?ooo`80000000@0003o0?ooo`3oool0oooo0P000?l30?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool20000o`P0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`050000
o`3oool0oooo0?ooo`000?l01P3oool20000o`<0oooo0P000?l00`000000oooo0?ooo`020?ooo`03
0000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
JP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0000000000080oooo00L0003o0?ooo`3o
ool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20000o`D0oooo0P000?l3
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0000003oool00`3oool00`000?l0oooo0?ooo`1C
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000J`3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0000000<0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`030?ooo`800000103oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo00000004
0?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`08
0?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00/0oooo0P000?l300000080oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l01P3o
ool00`000?l0oooo0?ooo`070?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00T0oooo100000020000o`@0oooo00@000000?ooo`3oool0
003oEP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`000000103oool00`000?l0oooo0000o`030?ooo`80003o
1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo0`0000060?ooo`80003o
0P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo06/0oooo20000?l70?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00P3o
ool20000o`030?ooo`000000oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool3000000<0oooo00<0
003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`00001H0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo07X0oooo00<0003o0?ooo`3oool02@3oool40000o`040?ooo`00
0?l0oooo000000D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`H0003o
1@3oool00`000?l0oooo0?ooo`070?ooo`80003o103oool20000o`@0oooo0P000?l40?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`0000000P0000000`3oool0003o0?ooo`030?ooo`030000
o`3oool0oooo00D0oooo00H0003o0?ooo`3oool0oooo000000000?mF0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool40000o`03
0?ooo`000?l0oooo00<0oooo00<0003o0?ooo`000?l00`000?l80?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`<0000010000?l60?ooo`L0
003o103oool00`000?l000000000o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0I0?ooo`@00000
6@3oool00`000?l000000?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0F0?ooo`<000007P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0C0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0@0?ooo`<000009P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000
oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k
0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000
@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000
oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100
oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K
0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H
0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?oo
o`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00
000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`00
7P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo
06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000
oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00
000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?oo
o`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`03
0000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3o
ool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0
oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool20000
04T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000
oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000
001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`03
0000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3o
ool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0
oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0
oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000
001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`03
0000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`00
6@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3o
ool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0
oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0
oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?oo
o`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0
oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool20000
09L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo
0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?oo
o`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`00
0000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3o
ool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P00
00200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<00000
0?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c
0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`04
0?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<0
00000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo0011
0?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`37
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0
b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?oo
o`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0
cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3o
ool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3o
ool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0
oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2
000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0
oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K
0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3o
ool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3o
ool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0
000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3o
ool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0
oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo
001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?oo
o`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`00
0000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000
003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool40000
03D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0
oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo
001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo
00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@0
00000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo
1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000
001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H
0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`04
0000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`03
0000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`800000
9P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo
000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`00
0000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@00
00280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=
0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`800000
5P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3o
ool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool0
0`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo
000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool0
06H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`00
0000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140
oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo
00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo
0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo
0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`00
0000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3o
ool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo10000036
0?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`80
0000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0
oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0
oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71795 .5671 m
.71898 .58932 L
s
.63734 .56422 m
.63554 .56576 L
s
.63921 .56582 m
.63734 .56422 L
s
.63742 .56737 m
.63921 .56582 L
s
.63554 .56576 m
.63742 .56737 L
s
.60254 .56523 m
.60309 .59867 L
s
.48688 .56335 m
.47952 .56323 L
s
.49053 .56499 m
.48688 .56335 L
s
.47952 .56323 m
.47582 .56475 L
s
.49417 .56821 m
.49053 .56499 L
s
.47582 .56475 m
.47209 .56786 L
s
.69644 .57783 m
.69093 .57774 L
s
.70201 .5795 m
.69644 .57783 L
s
.69093 .57774 m
.68548 .57924 L
s
.66522 .57732 m
.65971 .57723 L
s
.66895 .57897 m
.66522 .57732 L
s
.49598 .57141 m
.49417 .56821 L
s
.70398 .58271 m
.70201 .5795 L
s
.65971 .57723 m
.65608 .57876 L
s
.68548 .57924 m
.68376 .58239 L
s
.47209 .56786 m
.47019 .571 L
s
.34331 .56102 m
.34876 .56269 L
s
.3304 .56081 m
.34331 .56102 L
s
.63766 .57688 m
.63822 .59923 L
s
.67273 .58221 m
.66895 .57897 L
s
.3304 .56081 m
.3286 .5943 L
s
.61744 .57655 m
.62115 .5782 L
s
.61192 .57646 m
.61744 .57655 L
s
.65608 .57876 m
.6525 .58188 L
s
.60827 .57799 m
.61192 .57646 L
s
.34876 .56269 m
.35229 .56591 L
s
.62115 .5782 m
.62309 .583 L
s
.57881 .57593 m
.58251 .57757 L
s
.57329 .57584 m
.57881 .57593 L
s
.56962 .57737 m
.57329 .57584 L
s
.60283 .58267 m
.60827 .57799 L
s
.56593 .57572 m
.56616 .60936 L
s
.68376 .58239 m
.68572 .5856 L
s
.47019 .571 m
.46826 .57573 L
s
.55304 .57551 m
.55312 .59788 L
s
.54568 .57539 m
.54015 .5753 L
s
.54936 .57704 m
.54568 .57539 L
s
.58251 .57757 m
.58623 .58082 L
s
.54015 .5753 m
.53647 .57683 L
s
.56596 .58049 m
.56962 .57737 L
s
.6525 .58188 m
.65079 .58663 L
s
.51621 .57492 m
.52174 .57501 L
s
.35229 .56591 m
.35399 .56912 L
s
.51251 .57645 m
.51621 .57492 L
s
.55306 .58028 m
.54936 .57704 L
s
.507 .57477 m
.50681 .59714 L
s
.53647 .57683 m
.53278 .57996 L
s
.68572 .5856 m
.68946 .58725 L
s
.5088 .57957 m
.51251 .57645 L
s
.58623 .58082 m
.58813 .58563 L
s
.45722 .57396 m
.44933 .59622 L
s
.62309 .583 m
.62343 .599 L
s
.44247 .57373 m
.44933 .59622 L
s
.44247 .57373 m
.43449 .59599 L
s
.35399 .56912 m
.35561 .57392 L
s
.68946 .58725 m
.69873 .589 L
s
.42771 .57349 m
.43449 .59599 L
s
.46826 .57573 m
.46812 .5837 L
s
.41479 .57328 m
.41407 .59566 L
s
.4074 .57316 m
.40186 .57307 L
s
.41104 .57481 m
.4074 .57316 L
s
.53278 .57996 m
.53093 .58471 L
s
.69873 .589 m
.70248 .59065 L
s
.40186 .57307 m
.39811 .5746 L
s
.65079 .58663 m
.65089 .58983 L
s
.37786 .57268 m
.3834 .57277 L
s
.50692 .58432 m
.5088 .57957 L
s
.37409 .57421 m
.37786 .57268 L
s
.41463 .57805 m
.41104 .57481 L
s
.36862 .57253 m
.36764 .59492 L
s
.70248 .59065 m
.70446 .59388 L
s
.39811 .5746 m
.3943 .57773 L
s
.58813 .58563 m
.58817 .58882 L
s
.37026 .57734 m
.37409 .57421 L
s
.35561 .57392 m
.35523 .58189 L
s
.65089 .58983 m
.65287 .59466 L
s
.70446 .59388 m
.70452 .59548 L
s
.53093 .58471 m
.53092 .5879 L
s
.3943 .57773 m
.39227 .58248 L
s
.58817 .58882 m
.58638 .59359 L
s
.3682 .5821 m
.37026 .57734 L
s
.4866 .584 m
.49584 .58415 L
s
.49578 .58894 m
.49584 .58415 L
s
.70452 .59548 m
.70281 .59866 L
s
.6862 .59839 m
.68424 .59516 L
s
.46812 .5837 m
.46988 .58853 L
s
.72126 .59895 m
.71935 .59732 L
s
.71935 .59732 m
.71757 .59889 L
s
.66958 .59813 m
.67317 .59498 L
s
.53092 .5879 m
.53276 .59274 L
s
.65287 .59466 m
.65666 .59792 L
s
.71949 .60053 m
.72126 .59895 L
s
.71757 .59889 m
.71949 .60053 L
s
.70281 .59866 m
.69734 .60017 L
s
.39227 .58248 m
.39215 .58568 L
s
.6918 .60009 m
.6862 .59839 L
s
.58638 .59359 m
.58272 .59674 L
s
.66594 .59967 m
.66958 .59813 L
s
.4939 .59212 m
.49578 .58894 L
s
.65666 .59792 m
.6604 .59959 L
s
.69734 .60017 m
.6918 .60009 L
s
.35523 .58189 m
.35315 .58666 L
s
.56977 .59654 m
.56605 .59327 L
s
.46988 .58853 m
.47167 .59176 L
s
.54942 .59621 m
.55311 .59306 L
s
.6604 .59959 m
.66594 .59967 L
s
.53276 .59274 m
.53646 .59601 L
s
.39215 .58568 m
.39382 .59052 L
s
.58272 .59674 m
.57904 .59829 L
s
.49015 .59527 m
.4939 .59212 L
s
.57349 .5982 m
.56977 .59654 L
s
.47167 .59176 m
.47533 .59503 L
s
.54572 .59776 m
.54942 .59621 L
s
.57904 .59829 m
.57349 .5982 L
s
.53646 .59601 m
.54016 .59767 L
s
.35315 .58666 m
.35114 .58984 L
s
.54016 .59767 m
.54572 .59776 L
s
.41041 .594 m
.41423 .59084 L
s
.48642 .59681 m
.49015 .59527 L
s
.39382 .59052 m
.39742 .59379 L
s
.47533 .59503 m
.47901 .5967 L
s
.47901 .5967 m
.48642 .59681 L
s
.35114 .58984 m
.34727 .59299 L
s
.40664 .59554 m
.41041 .594 L
s
.39742 .59379 m
.40107 .59545 L
s
.40107 .59545 m
.40664 .59554 L
s
.34727 .59299 m
.34162 .59451 L
s
.34162 .59451 m
.3286 .5943 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo06X0oooo
1P000?lC0?ooo`030000003oool0oooo01`0oooo1000001@0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?oo
o`030?ooo`80003o4P3oool00`000000oooo0?ooo`0H0?ooo`<000000`000?mA0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0JP3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool0503oool3
000000030?ooo`000?l0003o00<0oooo0P000?lY0?ooo`030000o`3oool0oooo00T0oooo0P000?lH
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0100oooo00<000000?oo
o`3oool0403oool3000000<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0V0?oo
o`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`020?oo
o`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3o
ool0303oool3000000D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0U0?ooo`03
0000o`3oool0oooo02<0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00@0003o103oool70000o`@0oooo
00<0003o0?ooo`3oool00P3oool00`000000003o000000030?ooo`050000o`3oool0oooo0?ooo`00
0?l03P3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`80003o
203oool00`000?l0oooo0?ooo`030?ooo`80003o103oool00`000?l0oooo00000002000000030?oo
o`000?l0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0003o00<0
003o1@3oool70000o`@0oooo1`000?l70?ooo`030000o`3oool0oooo00<0003o1`3oool00`000?l0
oooo0?ooo`050?ooo`<0003o3P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`040?ooo`040000o`000000oooo0?ooo`80000000@0003o0?ooo`3oool0oooo0P000?l30?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool20000o`P0oooo00<0003o0?oo
o`3oool00`3oool20000o`@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0003o00<0oooo0P000?l50?ooo`030000o`3oool0oooo00@0oooo00D0003o0?oo
o`3oool0oooo0000o`060?ooo`L0003o00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool01@3oool010000?l0oooo0000000000020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo
0000o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0P000?l50?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool20000o`D0oooo0P000?l30?ooo`030000o`3oool0oooo00@0oooo
00<0003o0000003oool00`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01<0oooo
000U0?ooo`800000J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0000000<0oooo00@0
003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`050?ooo`030000o`3oool0oooo00@0oooo
1@000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo00<0oooo0P0000040?ooo`030000o`3oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0000000@0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000
o`050?ooo`030000o`3oool0oooo00P0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool20000o`<000000P3oool01@000000oooo
0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0000000@0oooo00<0003o0?ooo`000?l0
0P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0
oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02@3oool4000000@0
003o0P3oool010000000oooo0?ooo`000?mF0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo06X0oooo00<0003o0?ooo`3oool0103oool20000o`H0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`030?ooo`80003o00<0oooo0000003oool0103oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`<000001`3oool010000?l0oooo0?ooo`00001I0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo06/0oooo1`000?l80?ooo`030000o`3oool0oooo00P0
oooo1`000?l00`3oool000000?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool3000000<0oooo00<0003o0?ooo`3o
ool01@3oool010000?l0oooo0?ooo`00001H0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool04`3oool50000o`H0oooo00<0003o0?ooo`3o
ool02@3oool40000o`030?ooo`000?l0oooo00<0oooo1`000?l70?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`80003o0`0000000`3oool0
003o0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000000
003o0000o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0H0?ooo`030000o`3oool0oooo0080oooo
0`0000040000o`L0oooo1@000?l60?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3o
ool0oooo01T0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0
oooo01H0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo
01<0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo
0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo
000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71752 .56984 m
.71905 .58887 L
s
.63701 .56719 m
.63524 .56851 L
s
.6389 .56857 m
.63701 .56719 L
s
.63714 .56989 m
.6389 .56857 L
s
.63524 .56851 m
.63714 .56989 L
s
.60229 .56797 m
.60328 .59663 L
s
.48681 .5661 m
.47947 .56598 L
s
.49047 .56751 m
.48681 .5661 L
s
.47947 .56598 m
.47578 .56727 L
s
.49412 .57027 m
.49047 .56751 L
s
.47578 .56727 m
.47206 .56992 L
s
.34348 .56378 m
.34891 .56522 L
s
.3306 .56357 m
.34348 .56378 L
s
.3306 .56357 m
.32845 .59225 L
s
.49593 .57302 m
.49412 .57027 L
s
.47206 .56992 m
.47017 .5726 L
s
.69627 .57896 m
.69077 .57888 L
s
.70187 .58041 m
.69627 .57896 L
s
.69077 .57888 m
.68535 .58015 L
s
.34891 .56522 m
.35241 .56798 L
s
.66507 .57846 m
.65956 .57837 L
s
.66883 .57988 m
.66507 .57846 L
s
.65956 .57837 m
.65597 .57967 L
s
.70391 .58317 m
.70187 .58041 L
s
.63753 .57802 m
.63846 .59719 L
s
.68535 .58015 m
.6837 .58284 L
s
.61732 .57769 m
.62105 .57911 L
s
.61181 .5776 m
.61732 .57769 L
s
.67267 .58266 m
.66883 .57988 L
s
.60818 .5789 m
.61181 .5776 L
s
.65597 .57967 m
.65244 .58234 L
s
.47017 .5726 m
.46825 .57665 L
s
.57872 .57707 m
.58243 .57849 L
s
.5732 .57698 m
.57872 .57707 L
s
.35241 .56798 m
.35408 .57072 L
s
.56956 .57828 m
.5732 .57698 L
s
.56585 .57686 m
.56642 .60574 L
s
.62105 .57911 m
.62307 .58323 L
s
.55297 .57665 m
.55325 .59583 L
s
.60281 .5829 m
.60818 .5789 L
s
.54561 .57653 m
.54009 .57644 L
s
.54931 .57795 m
.54561 .57653 L
s
.54009 .57644 m
.53642 .57775 L
s
.58243 .57849 m
.58619 .58127 L
s
.51617 .57606 m
.52169 .57615 L
s
.51248 .57736 m
.51617 .57606 L
s
.6837 .58284 m
.68572 .5856 L
s
.56593 .58095 m
.56956 .57828 L
s
.50696 .57591 m
.50688 .59509 L
s
.55303 .58074 m
.54931 .57795 L
s
.65244 .58234 m
.65082 .58641 L
s
.53642 .57775 m
.53276 .58041 L
s
.35408 .57072 m
.35566 .57483 L
s
.45722 .57511 m
.44933 .59418 L
s
.50879 .58003 m
.51248 .57736 L
s
.44247 .57487 m
.44933 .59418 L
s
.44247 .57487 m
.43447 .59394 L
s
.42772 .57463 m
.43447 .59394 L
s
.58619 .58127 m
.58815 .5854 L
s
.41481 .57442 m
.41403 .59361 L
s
.46825 .57665 m
.46812 .58347 L
s
.40743 .5743 m
.4019 .57422 L
s
.41106 .57573 m
.40743 .5743 L
s
.68572 .5856 m
.6895 .58703 L
s
.4019 .57422 m
.39814 .57552 L
s
.62307 .58323 m
.62365 .59696 L
s
.37791 .57383 m
.38344 .57392 L
s
.37414 .57513 m
.37791 .57383 L
s
.36867 .57368 m
.36754 .59287 L
s
.53276 .58041 m
.53094 .58448 L
s
.41464 .57851 m
.41106 .57573 L
s
.6895 .58703 m
.6988 .58854 L
s
.39814 .57552 m
.39432 .57818 L
s
.50693 .5841 m
.50879 .58003 L
s
.37028 .5778 m
.37414 .57513 L
s
.65082 .58641 m
.65097 .58914 L
s
.6988 .58854 m
.70258 .58997 L
s
.35566 .57483 m
.35522 .58166 L
s
.70258 .58997 m
.70463 .59275 L
s
.58815 .5854 m
.58823 .58814 L
s
.39432 .57818 m
.39226 .58225 L
s
.36819 .58187 m
.37028 .5778 L
s
.65097 .58914 m
.65304 .59329 L
s
.53094 .58448 m
.53095 .58722 L
s
.4866 .58377 m
.49584 .58392 L
s
.49581 .58803 m
.49584 .58392 L
s
.70463 .59275 m
.70473 .59412 L
s
.58823 .58814 m
.58649 .59223 L
s
.46812 .58347 m
.46989 .58762 L
s
.70473 .59412 m
.70309 .59685 L
s
.53095 .58722 m
.53283 .59137 L
s
.68646 .59658 m
.68443 .5938 L
s
.39226 .58225 m
.39213 .585 L
s
.66983 .59631 m
.67335 .59362 L
s
.72156 .59714 m
.7196 .59573 L
s
.7196 .59573 m
.71787 .59708 L
s
.65304 .59329 m
.65688 .59611 L
s
.35522 .58166 m
.3531 .58575 L
s
.49393 .59075 m
.49581 .58803 L
s
.71983 .59849 m
.72156 .59714 L
s
.71787 .59708 m
.71983 .59849 L
s
.70309 .59685 m
.69765 .59814 L
s
.58649 .59223 m
.58287 .59493 L
s
.46989 .58762 m
.47169 .5904 L
s
.6921 .59805 m
.68646 .59658 L
s
.5699 .59472 m
.56614 .59191 L
s
.39213 .585 m
.39378 .58915 L
s
.66621 .59763 m
.66983 .59631 L
s
.54952 .59439 m
.55319 .5917 L
s
.65688 .59611 m
.66066 .59755 L
s
.53283 .59137 m
.53655 .59419 L
s
.69765 .59814 m
.6921 .59805 L
s
.66066 .59755 m
.66621 .59763 L
s
.4902 .59345 m
.49393 .59075 L
s
.47169 .5904 m
.47535 .59321 L
s
.58287 .59493 m
.5792 .59625 L
s
.3531 .58575 m
.35106 .58847 L
s
.57364 .59616 m
.5699 .59472 L
s
.54583 .59571 m
.54952 .59439 L
s
.53655 .59419 m
.54027 .59563 L
s
.41037 .59217 m
.4142 .58948 L
s
.5792 .59625 m
.57364 .59616 L
s
.39378 .58915 m
.39736 .59197 L
s
.48647 .59477 m
.4902 .59345 L
s
.54027 .59563 m
.54583 .59571 L
s
.47535 .59321 m
.47904 .59465 L
s
.35106 .58847 m
.34716 .59116 L
s
.47904 .59465 m
.48647 .59477 L
s
.40659 .59349 m
.41037 .59217 L
s
.39736 .59197 m
.40101 .59341 L
s
.40101 .59341 m
.40659 .59349 L
s
.34716 .59116 m
.34148 .59246 L
s
.34148 .59246 m
.32845 .59225 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`H0003o503oool00`000000oooo0?oo
o`0H0?ooo`<00000E03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool00`3oool20000oa<0oooo00<00000
0?ooo`3oool0503oool3000000<0oooo0`000?mA0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0403oool3000000@0oooo0P000?l30?oo
o`80003o:03oool00`000?l0oooo0?ooo`0:0?ooo`80003o603oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo0`0000060?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo01L0oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`<0003o1P3oool30000o`030000003oool0003o
00<0oooo00<0003o0?ooo`3oool00P3oool00`000000003o000000080?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0903oool00`000?l0oooo0?ooo`0T0?ooo`050000003oool0oooo
0?ooo`000?l0EP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l7
0?ooo`80003o0`3oool00`000?l000000000o`030?ooo`030000o`3oool000000080000000<0oooo
0000o`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`000?l00`00
0?l60?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0003o1`3o
ool00`000?l0oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000?l0EP3oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool00P3oool20000o`P0oooo00<0003o0?ooo`3oool0103oool20000o`80oooo0P00
000010000?l0oooo0?ooo`3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`80
003o2@3oool010000?l0oooo0?ooo`3oool30000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool01@000?l60?ooo`030000o`3oool0oooo00@0oooo1@000?l50?oo
o`H0003o0P3oool01@000000oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000o`0000000000
0080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3o
ool30000o`@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80003o1@3o
ool20000o`<0oooo00<0003o0?ooo`3oool00`3oool20000o`030000003oool0oooo0080oooo00<0
003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000006/0oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo000000030?ooo`040000o`3oool0oooo0000o`80oooo00@0
003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`030?ooo`800000103oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0000
00040?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l01P3oool00`000?l0oooo0?oo
o`070?ooo`050000o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00/0oooo0P000?l300000080oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l0
1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo100000040000o`80oooo
00@000000?ooo`3oool0003oEP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`1Z0?ooo`T0003o1P3oool00`000?l0oooo0?ooo`080?ooo`L0003o00<0oooo0000003oool0
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`050?ooo`040000o`0000000000000000P0oooo00<0003o0?ooo`00
0000F@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`D0003o
1P3oool00`000?l0oooo0?ooo`080?ooo`L0003o103oool80000o`H0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P000?l30?ooo`<00000
0`3oool00`000?l0oooo0?ooo`050?ooo`060000o`3oool0oooo0000003oool0003oEP3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03@0
oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool3000000030000o`3oool0oooo00@0oooo1`000?l40?ooo`03
000000000?l0003o05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01d0oooo0`00000F0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01T0oooo1000000J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo01H0oooo0`00000N0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo
00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000
000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3o
ool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo
00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo
0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<0
00000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?oo
o`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000
JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo
0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool3
00000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000
oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l
0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71714 .57328 m
.71912 .58829 L
s
.63671 .57092 m
.63497 .57195 L
s
.63863 .57201 m
.63671 .57092 L
s
.63689 .57304 m
.63863 .57201 L
s
.63497 .57195 m
.63689 .57304 L
s
.60207 .57142 m
.60345 .59404 L
s
.48675 .56955 m
.47941 .56943 L
s
.4904 .57067 m
.48675 .56955 L
s
.47941 .56943 m
.47573 .57044 L
s
.49406 .57286 m
.4904 .57067 L
s
.47573 .57044 m
.47202 .57251 L
s
.34361 .56723 m
.34902 .56839 L
s
.33074 .56703 m
.34361 .56723 L
s
.33074 .56703 m
.32834 .58965 L
s
.49589 .57503 m
.49406 .57286 L
s
.34902 .56839 m
.3525 .57058 L
s
.47202 .57251 m
.47014 .57461 L
s
.69612 .5804 m
.69062 .58031 L
s
.70175 .58156 m
.69612 .5804 L
s
.69062 .58031 m
.68524 .58129 L
s
.66494 .5799 m
.65944 .57981 L
s
.66872 .58103 m
.66494 .5799 L
s
.65944 .57981 m
.65587 .58082 L
s
.63742 .57945 m
.63866 .5946 L
s
.70385 .58374 m
.70175 .58156 L
s
.3525 .57058 m
.35414 .57274 L
s
.61722 .57913 m
.62097 .58026 L
s
.61171 .57904 m
.61722 .57913 L
s
.68524 .58129 m
.68364 .58341 L
s
.60811 .58005 m
.61171 .57904 L
s
.47014 .57461 m
.46824 .5778 L
s
.67262 .58324 m
.66872 .58103 L
s
.65587 .58082 m
.65239 .58291 L
s
.57864 .5785 m
.58237 .57964 L
s
.57313 .57842 m
.57864 .5785 L
s
.5695 .57943 m
.57313 .57842 L
s
.56578 .5783 m
.56666 .60113 L
s
.55291 .57809 m
.55337 .59324 L
s
.62097 .58026 m
.62304 .58352 L
s
.54555 .57797 m
.54003 .57788 L
s
.54926 .5791 m
.54555 .57797 L
s
.54003 .57788 m
.53638 .5789 L
s
.60279 .58319 m
.60811 .58005 L
s
.51612 .5775 m
.52164 .57759 L
s
.51245 .57851 m
.51612 .5775 L
s
.58237 .57964 m
.58616 .58185 L
s
.50692 .57735 m
.50696 .5925 L
s
.5659 .58152 m
.5695 .57943 L
s
.35414 .57274 m
.3557 .57599 L
s
.553 .58131 m
.54926 .5791 L
s
.68364 .58341 m
.68572 .5856 L
s
.53638 .5789 m
.53274 .58099 L
s
.45721 .57655 m
.44935 .59158 L
s
.65239 .58291 m
.65085 .58612 L
s
.50877 .5806 m
.51245 .57851 L
s
.44247 .57631 m
.44935 .59158 L
s
.44247 .57631 m
.43447 .59134 L
s
.42773 .57607 m
.43447 .59134 L
s
.41482 .57586 m
.414 .59102 L
s
.40745 .57575 m
.40192 .57566 L
s
.41107 .57688 m
.40745 .57575 L
s
.40192 .57566 m
.39816 .57667 L
s
.46824 .5778 m
.46812 .58318 L
s
.37794 .57527 m
.38347 .57536 L
s
.58616 .58185 m
.58817 .58511 L
s
.37416 .57628 m
.37794 .57527 L
s
.36871 .57512 m
.36747 .59027 L
s
.62304 .58352 m
.62384 .59437 L
s
.68572 .5856 m
.68952 .58674 L
s
.41465 .57909 m
.41107 .57688 L
s
.39816 .57667 m
.39433 .57876 L
s
.53274 .58099 m
.53095 .58419 L
s
.3703 .57837 m
.37416 .57628 L
s
.50694 .58381 m
.50877 .5806 L
s
.3557 .57599 m
.35521 .58137 L
s
.68952 .58674 m
.69886 .58797 L
s
.65085 .58612 m
.65104 .58828 L
s
.69886 .58797 m
.70267 .58911 L
s
.39433 .57876 m
.39226 .58197 L
s
.58817 .58511 m
.58828 .58728 L
s
.36818 .58158 m
.3703 .57837 L
s
.70267 .58911 m
.70478 .59131 L
s
.53095 .58419 m
.53099 .58636 L
s
.65104 .58828 m
.65318 .59157 L
s
.48661 .58348 m
.49585 .58363 L
s
.49583 .58688 m
.49585 .58363 L
s
.46812 .58318 m
.46991 .58646 L
s
.58828 .58728 m
.5866 .5905 L
s
.70478 .59131 m
.70492 .5924 L
s
.53099 .58636 m
.53289 .58964 L
s
.39226 .58197 m
.39211 .58413 L
s
.70492 .5924 m
.70333 .59455 L
s
.35521 .58137 m
.35306 .58459 L
s
.68669 .59428 m
.6846 .59207 L
s
.67004 .59401 m
.67351 .5919 L
s
.65318 .59157 m
.65709 .59381 L
s
.72182 .59484 m
.71983 .59372 L
s
.71983 .59372 m
.71813 .59478 L
s
.49397 .58902 m
.49583 .58688 L
s
.46991 .58646 m
.47172 .58867 L
s
.39211 .58413 m
.39375 .58742 L
s
.5866 .5905 m
.583 .59262 L
s
.72012 .5959 m
.72182 .59484 L
s
.71813 .59478 m
.72012 .5959 L
s
.57003 .59242 m
.56623 .59018 L
s
.70333 .59455 m
.69792 .59555 L
s
.54963 .59209 m
.55327 .58997 L
s
.69236 .59546 m
.68669 .59428 L
s
.53289 .58964 m
.53664 .59188 L
s
.66645 .59505 m
.67004 .59401 L
s
.65709 .59381 m
.66089 .59496 L
s
.49025 .59114 m
.49397 .58902 L
s
.69792 .59555 m
.69236 .59546 L
s
.35306 .58459 m
.351 .58673 L
s
.47172 .58867 m
.47539 .5909 L
s
.66089 .59496 m
.66645 .59505 L
s
.583 .59262 m
.57934 .59366 L
s
.57378 .59357 m
.57003 .59242 L
s
.41034 .58986 m
.41418 .58774 L
s
.54595 .59312 m
.54963 .59209 L
s
.53664 .59188 m
.54038 .59303 L
s
.39375 .58742 m
.39733 .58966 L
s
.57934 .59366 m
.57378 .59357 L
s
.48652 .59217 m
.49025 .59114 L
s
.351 .58673 m
.34708 .58885 L
s
.54038 .59303 m
.54595 .59312 L
s
.47539 .5909 m
.47909 .59205 L
s
.47909 .59205 m
.48652 .59217 L
s
.40656 .5909 m
.41034 .58986 L
s
.39733 .58966 m
.40098 .59081 L
s
.34708 .58885 m
.34139 .58986 L
s
.40098 .59081 m
.40656 .5909 L
s
.34139 .58986 m
.32834 .58965 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06X0oooo20000?lD0?oo
o`030000003oool0oooo0100oooo0`0000060?ooo`030000o`3oool0oooo0540oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`<0
00001`3oool20000o`030?ooo`000?l0003o0080003o:03oool00`000?l0oooo0?ooo`0:0?ooo`80
003o603oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0B0?ooo`030000
003oool0oooo00P0oooo0`0000080?ooo`80003o1`3oool00`000?l0oooo0?ooo`0U0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool05`3oool01@000000oooo0?ooo`3oool0003o05H0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l010000?l40?ooo`H0003o
00<000000000o`3oool00P3oool00`000?l0oooo00000002000000030?ooo`000?l0oooo00<0oooo
00D0003o0?ooo`3oool0oooo0000o`0:0?ooo`050000o`3oool0oooo0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`0M0?ooo`030000o`3oool0oooo02@0oooo00D000000?ooo`3oool0oooo0000o`1F
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`80003o203oool00`000?l0oooo0?ooo`040?oo
o`80003o0P3oool00`000000003o000000030?ooo`80003o0`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00`0oooo00@0003o0?ooo`000?l0oooo0P000?l50?ooo`L0003o103oool7
0000o`H0oooo00<0003o0?ooo`3oool010000?l70?ooo`030000o`3oool0oooo00D0oooo0`000?l>
0?ooo`050000003oool0oooo0?ooo`000?l0EP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00<0003o0000000000000P3oool0
1`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00`0oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l0
103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0`000?l30?ooo`030000
o`3oool0oooo00<0oooo20000?l01@000000oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3o
ool04`3oool002D0oooo0P00001[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`000000
0`3oool010000?l0oooo0?ooo`000?l20?ooo`030000o`3oool0003o00D0oooo00<0003o0?ooo`3o
ool0103oool50000o`<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo0P000?l30?ooo`80003o1@3oool2000000@0oooo00<0003o0?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`000000103oool00`000?l0oooo0000o`020?ooo`030000
o`3oool0003o00H0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00P0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`80003o0`0000020?ooo`05
0000003oool0oooo0?ooo`000?l0EP3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`1Z0?ooo`T0003o1P3oool00`000?l0oooo0?ooo`080?ooo`L0003o00<0oooo0000003o
ool00`3oool20000o`@0oooo00<0003o0?ooo`3oool01P3oool20000o`H0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool02@3oool4000000<0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08X0oooo00<0003o0?ooo`00
00001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo1P000?l50?ooo`03
0000o`3oool0oooo00P0oooo1`000?l40?ooo`@0003o0P3oool20000o`H0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01@3oool01@000?l00000000000000000003o00L0oooo00<0003o0?ooo`000000F@3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03@0
oooo00@0003o0?ooo`3oool0oooo0P000?l80?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`D0003o0`0000040?ooo`L0003o0`3oool01000
0000oooo0000o`000?mE0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0P0?ooo`<000004P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`0M0?ooo`<000005P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0D03oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00
000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool2000008l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03P0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000
oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00
00170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool0
8@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0
oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00
001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo
0`0000260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?oo
o`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo10000005
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000
003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4
000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4
000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo
09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000
oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;
0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?oo
o`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000
003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3
000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo
09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/
0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?oo
o`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000
003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3
000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo
0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo
00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>
0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?oo
o`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3o
ool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000
S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`80
0000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40
oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`03
0000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00
203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3o
ool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo
08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`00
0000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?oo
o`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?oo
o`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000
003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03o
ool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3o
ool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo
0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<0
00000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h
0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo
0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0
oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0
oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?oo
o`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D00000
0?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003o
ool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2
000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo
0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000
oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo
0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo0016
0?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`03
0000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00
A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000
DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool0
1@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G
0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo
04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<0
00000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`80
0000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000
003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0
oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool40000
01l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0
oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?oo
o`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`03
0000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000
003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003o
ool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03o
ool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000
;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3o
ool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool0
0`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo
07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo
07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0
oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo
00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo0029
0?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b
0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g
0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703o
ool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool0
0`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo
04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0
oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo
002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo
002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<
0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?oo
o`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`03
0000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3o
ool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool0
4@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003o
ool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000
_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool0
0`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo
0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0
oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000
003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3o
ool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D00000
0P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3o
ool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71683 .57727 m
.71917 .58762 L
s
.63647 .57524 m
.63475 .57594 L
s
.6384 .576 m
.63647 .57524 L
s
.63668 .5767 m
.6384 .576 L
s
.63475 .57594 m
.63668 .5767 L
s
.60188 .57541 m
.6036 .59102 L
s
.48667 .57355 m
.47935 .57343 L
s
.49033 .57434 m
.48667 .57355 L
s
.47935 .57343 m
.47567 .5741 L
s
.494 .57587 m
.49033 .57434 L
s
.47567 .5741 m
.47198 .57551 L
s
.34368 .57124 m
.34908 .57206 L
s
.33082 .57103 m
.34368 .57124 L
s
.33082 .57103 m
.32828 .58661 L
s
.34908 .57206 m
.35254 .57359 L
s
.49584 .57737 m
.494 .57587 L
s
.47198 .57551 m
.47011 .57695 L
s
.696 .58207 m
.69051 .58198 L
s
.70166 .58289 m
.696 .58207 L
s
.69051 .58198 m
.68515 .58263 L
s
.66484 .58156 m
.65934 .58148 L
s
.66864 .58236 m
.66484 .58156 L
s
.65934 .58148 m
.65579 .58216 L
s
.35254 .57359 m
.35418 .57508 L
s
.63732 .58112 m
.63884 .59158 L
s
.7038 .58441 m
.70166 .58289 L
s
.47011 .57695 m
.46822 .57914 L
s
.61713 .5808 m
.6209 .58159 L
s
.61163 .58071 m
.61713 .5808 L
s
.60804 .58139 m
.61163 .58071 L
s
.68515 .58263 m
.6836 .58408 L
s
.67257 .58391 m
.66864 .58236 L
s
.65579 .58216 m
.65235 .58358 L
s
.57857 .58017 m
.58231 .58097 L
s
.57306 .58009 m
.57857 .58017 L
s
.56944 .58077 m
.57306 .58009 L
s
.56571 .57997 m
.56687 .59573 L
s
.55285 .57976 m
.55348 .59021 L
s
.5455 .57964 m
.53998 .57955 L
s
.54921 .58044 m
.5455 .57964 L
s
.6209 .58159 m
.62303 .58385 L
s
.53998 .57955 m
.53634 .58023 L
s
.60277 .58352 m
.60804 .58139 L
s
.51608 .57917 m
.52159 .57926 L
s
.51241 .57985 m
.51608 .57917 L
s
.35418 .57508 m
.35572 .57733 L
s
.50688 .57902 m
.50703 .58947 L
s
.58231 .58097 m
.58613 .58252 L
s
.56587 .58219 m
.56944 .58077 L
s
.55298 .58198 m
.54921 .58044 L
s
.53634 .58023 m
.53272 .58166 L
s
.45719 .57822 m
.44937 .58855 L
s
.6836 .58408 m
.68572 .5856 L
s
.44246 .57798 m
.44937 .58855 L
s
.44246 .57798 m
.43449 .58831 L
s
.50875 .58127 m
.51241 .57985 L
s
.42772 .57775 m
.43449 .58831 L
s
.65235 .58358 m
.65087 .58578 L
s
.41482 .57754 m
.41401 .58798 L
s
.40745 .57742 m
.40192 .57733 L
s
.41108 .57822 m
.40745 .57742 L
s
.40192 .57733 m
.39816 .57801 L
s
.46822 .57914 m
.46813 .58285 L
s
.37795 .57694 m
.38348 .57703 L
s
.37418 .57762 m
.37795 .57694 L
s
.36873 .5768 m
.36743 .58724 L
s
.58613 .58252 m
.58818 .58478 L
s
.41465 .57976 m
.41108 .57822 L
s
.39816 .57801 m
.39433 .57943 L
s
.62303 .58385 m
.624 .59134 L
s
.53272 .58166 m
.53096 .58386 L
s
.68572 .5856 m
.68955 .58641 L
s
.3703 .57904 m
.37418 .57762 L
s
.35572 .57733 m
.35521 .58104 L
s
.50694 .58347 m
.50875 .58127 L
s
.68955 .58641 m
.69891 .5873 L
s
.65087 .58578 m
.6511 .58728 L
s
.39433 .57943 m
.39226 .58163 L
s
.69891 .5873 m
.70275 .58811 L
s
.36818 .58124 m
.3703 .57904 L
s
.58818 .58478 m
.58832 .58627 L
s
.70275 .58811 m
.70491 .58964 L
s
.53096 .58386 m
.53102 .58535 L
s
.6511 .58728 m
.65331 .58956 L
s
.48661 .58315 m
.49586 .58329 L
s
.49586 .58554 m
.49586 .58329 L
s
.46813 .58285 m
.46992 .58512 L
s
.58832 .58627 m
.58669 .58849 L
s
.70491 .58964 m
.70506 .59039 L
s
.39226 .58163 m
.39211 .58312 L
s
.53102 .58535 m
.53296 .58763 L
s
.35521 .58104 m
.35304 .58324 L
s
.70506 .59039 m
.70353 .59186 L
s
.68688 .5916 m
.68474 .59006 L
s
.67021 .59133 m
.67365 .58988 L
s
.65331 .58956 m
.65725 .59112 L
s
.49401 .58701 m
.49586 .58554 L
s
.72203 .59216 m
.72001 .59138 L
s
.72001 .59138 m
.71833 .5921 L
s
.46992 .58512 m
.47175 .58665 L
s
.39211 .58312 m
.39374 .5854 L
s
.58669 .58849 m
.58312 .58994 L
s
.72035 .59288 m
.72203 .59216 L
s
.57013 .58973 m
.56631 .58816 L
s
.71833 .5921 m
.72035 .59288 L
s
.54972 .5894 m
.55334 .58796 L
s
.70353 .59186 m
.69813 .59253 L
s
.53296 .58763 m
.53673 .58919 L
s
.69258 .59244 m
.68688 .5916 L
s
.66664 .59203 m
.67021 .59133 L
s
.35304 .58324 m
.35097 .58471 L
s
.65725 .59112 m
.66108 .59194 L
s
.4903 .58845 m
.49401 .58701 L
s
.47175 .58665 m
.47543 .58821 L
s
.69813 .59253 m
.69258 .59244 L
s
.66108 .59194 m
.66664 .59203 L
s
.58312 .58994 m
.57947 .59063 L
s
.5739 .59054 m
.57013 .58973 L
s
.41034 .58717 m
.41418 .58573 L
s
.54605 .5901 m
.54972 .5894 L
s
.39374 .5854 m
.39732 .58696 L
s
.53673 .58919 m
.54048 .59001 L
s
.35097 .58471 m
.34703 .58616 L
s
.57947 .59063 m
.5739 .59054 L
s
.48658 .58914 m
.4903 .58845 L
s
.47543 .58821 m
.47914 .58902 L
s
.54048 .59001 m
.54605 .5901 L
s
.40656 .58786 m
.41034 .58717 L
s
.47914 .58902 m
.48658 .58914 L
s
.39732 .58696 m
.40097 .58777 L
s
.34703 .58616 m
.34133 .58682 L
s
.40097 .58777 m
.40656 .58786 L
s
.34133 .58682 m
.32828 .58661 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`1Z0?ooo`P0003o5@3oool00`000000oooo0?ooo`0<0?ooo`<0
0000G@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo06X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0C0?ooo`030000
003oool0oooo00P0oooo0`00000:0?ooo`L0003oC`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`<0003o1P3oool30000o`030?oo
o`000000003o00D0oooo0`00000;0?ooo`80003o1`3oool20000obH0oooo00<0003o0?ooo`3oool0
2P3oool20000oaP0oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`020?ooo`@0003o1P3oool30000o`<0oooo0`000?l20?ooo`03000000000?l0000000@0oooo
00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`00
0?l00`000?l50?ooo`@0003o0P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0
003o1`3oool00`000?l0oooo0?ooo`0T0?ooo`050000003oool0oooo0?ooo`000?l0EP3oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0
oooo00@0003o0?ooo`00000000000P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`80003o203oool00`000?l0oooo0?ooo`02
0?ooo`<0003o103oool30000o`<0oooo0P000?l50?ooo`030000o`3oool0oooo00D0003o1P3oool0
0`000?l0oooo0?ooo`030?ooo`H0003o1@3oool80000o`050000003oool0oooo0?ooo`000?l0EP3o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool2000006/0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo0P000?l60?ooo`030000o`3oool0
000000<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`060?ooo`030000o`3o
ool0oooo00<0oooo1@000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3o
ool30000o`D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00@0oooo0P000?l30?ooo`80003o1@3oool2000000@0oooo00<0003o0?ooo`3oool0E03o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`T0003o1P3oool0
0`000?l0oooo0?ooo`080?ooo`L0003o00<0oooo0000003oool00`3oool00`000?l0oooo0000o`02
0?ooo`030000o`3oool0003o00L0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo0P000?l3
000000030000o`3oool0000000<0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`H0003o1@3oool00`000?l0oooo0?ooo`080?oo
o`L0003o103oool90000o`D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`3oool4
000000@0oooo00<0003o0?ooo`000000F@3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool02`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool60000
o`050?ooo`00000000000000003oool01`000?l20?ooo`030000003oool0oooo0080003oE@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03@0oooo00<0003o0?ooo`3oool08`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05L0
oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0D03oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000N
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool2000008l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0
oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`000017
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo
000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H
0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00001b
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3o
ool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00
00260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003o
ool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool40000
01@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?oo
o`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool40000
03@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo
0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?oo
o`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`03
0000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003o
ool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool30000
05D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0
oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<0
00000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?oo
o`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3o
ool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003o
ool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool30000
07@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0
oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<0
00000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?oo
o`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3o
ool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3o
ool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool00000
00800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000
UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000
003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203o
ool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool0
02<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000
oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`03
0000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00
503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003o
ool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool0
0`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool0
0340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<00000
0?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?oo
o`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo
00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo
000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`34
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?oo
o`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0
oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool20000
06`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?oo
o`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo
0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?oo
o`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?oo
o`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000
003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03o
ool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@00
0000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?oo
o`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<00000
0?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000
A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003o
ool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo
0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0
oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo
001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<00000
0?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`03
0000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000
003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003o
ool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0
oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool0
10000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03o
ool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3o
ool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool0
0`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0
oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0
oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo
1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo0028
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?oo
o`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?oo
o`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?oo
o`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool0
0`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`00
0000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0
oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo
1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I
0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?oo
o`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`80
0000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000
003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool0
9`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3o
ool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0
oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3o
ool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`00
0000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140
oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo
002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003o
ool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool3
00000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3o
ool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2
000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.63629 .57997 m
.63458 .58031 L
s
.63823 .58037 m
.63629 .57997 L
s
.71662 .58163 m
.7192 .58689 L
s
.63653 .58071 m
.63823 .58037 L
s
.63458 .58031 m
.63653 .58071 L
s
.60173 .57978 m
.60371 .58769 L
s
.48659 .57793 m
.47928 .57781 L
s
.49026 .57836 m
.48659 .57793 L
s
.47928 .57781 m
.47561 .57812 L
s
.49394 .57916 m
.49026 .57836 L
s
.47561 .57812 m
.47193 .5788 L
s
.34369 .57562 m
.34909 .57608 L
s
.33084 .57542 m
.34369 .57562 L
s
.33084 .57542 m
.32826 .58327 L
s
.34909 .57608 m
.35255 .57688 L
s
.49579 .57993 m
.49394 .57916 L
s
.47193 .5788 m
.47007 .57951 L
s
.69592 .58389 m
.69042 .5838 L
s
.70159 .58436 m
.69592 .58389 L
s
.69042 .5838 m
.68508 .58409 L
s
.35255 .57688 m
.35418 .57765 L
s
.66476 .58339 m
.65926 .5833 L
s
.66857 .58383 m
.66476 .58339 L
s
.65926 .5833 m
.65573 .58362 L
s
.63725 .58295 m
.63897 .58826 L
s
.47007 .57951 m
.4682 .5806 L
s
.70377 .58514 m
.70159 .58436 L
s
.61707 .58262 m
.62085 .58306 L
s
.61156 .58254 m
.61707 .58262 L
s
.60799 .58285 m
.61156 .58254 L
s
.68508 .58409 m
.68356 .58482 L
s
.67254 .58464 m
.66857 .58383 L
s
.57852 .582 m
.58227 .58244 L
s
.57301 .58192 m
.57852 .582 L
s
.65573 .58362 m
.65232 .58431 L
s
.5694 .58223 m
.57301 .58192 L
s
.56566 .5818 m
.56704 .58979 L
s
.5528 .58159 m
.55357 .58689 L
s
.54545 .58147 m
.53993 .58138 L
s
.54917 .58191 m
.54545 .58147 L
s
.53993 .58138 m
.5363 .5817 L
s
.62085 .58306 m
.62301 .58422 L
s
.60276 .58389 m
.60799 .58285 L
s
.51604 .581 m
.52155 .58109 L
s
.35418 .57765 m
.35572 .5788 L
s
.51238 .58131 m
.51604 .581 L
s
.50684 .58085 m
.5071 .58614 L
s
.58227 .58244 m
.5861 .58325 L
s
.56585 .58292 m
.5694 .58223 L
s
.55296 .58272 m
.54917 .58191 L
s
.45716 .58005 m
.44942 .58522 L
s
.5363 .5817 m
.5327 .58239 L
s
.44244 .57982 m
.44942 .58522 L
s
.44244 .57982 m
.43452 .58498 L
s
.68356 .58482 m
.68572 .5856 L
s
.50874 .58201 m
.51238 .58131 L
s
.4277 .57958 m
.43452 .58498 L
s
.41481 .57937 m
.41403 .58465 L
s
.40744 .57925 m
.40191 .57916 L
s
.41107 .57969 m
.40744 .57925 L
s
.65232 .58431 m
.65088 .58542 L
s
.40191 .57916 m
.39816 .57948 L
s
.4682 .5806 m
.46813 .58248 L
s
.37795 .57878 m
.38348 .57887 L
s
.37417 .57909 m
.37795 .57878 L
s
.36873 .57863 m
.36743 .5839 L
s
.5861 .58325 m
.58819 .58441 L
s
.41464 .58049 m
.41107 .57969 L
s
.39816 .57948 m
.39432 .58017 L
s
.62301 .58422 m
.62412 .58802 L
s
.3703 .57978 m
.37417 .57909 L
s
.5327 .58239 m
.53097 .58349 L
s
.68572 .5856 m
.68956 .58604 L
s
.35572 .5788 m
.35521 .58067 L
s
.50695 .5831 m
.50874 .58201 L
s
.68956 .58604 m
.69894 .58657 L
s
.65088 .58542 m
.65115 .58617 L
s
.39432 .58017 m
.39226 .58126 L
s
.36818 .58088 m
.3703 .57978 L
s
.69894 .58657 m
.7028 .587 L
s
.58819 .58441 m
.58836 .58517 L
s
.7028 .587 m
.70499 .5878 L
s
.53097 .58349 m
.53104 .58425 L
s
.48662 .58278 m
.49586 .58293 L
s
.49589 .58406 m
.49586 .58293 L
s
.65115 .58617 m
.6534 .58735 L
s
.46813 .58248 m
.46995 .58364 L
s
.58836 .58517 m
.58676 .58628 L
s
.39226 .58126 m
.39211 .58202 L
s
.70499 .5878 m
.70517 .58818 L
s
.53104 .58425 m
.53301 .58542 L
s
.35521 .58067 m
.35304 .58177 L
s
.70517 .58818 m
.70367 .58891 L
s
.68701 .58865 m
.68484 .58785 L
s
.67034 .58838 m
.67374 .58767 L
s
.49405 .58479 m
.49589 .58406 L
s
.6534 .58735 m
.65737 .58817 L
s
.39211 .58202 m
.39375 .58318 L
s
.72218 .58921 m
.72014 .5888 L
s
.72014 .5888 m
.71848 .58915 L
s
.46995 .58364 m
.47178 .58443 L
s
.58676 .58628 m
.58321 .58698 L
s
.57022 .58677 m
.56638 .58595 L
s
.72052 .58956 m
.72218 .58921 L
s
.5498 .58645 m
.5534 .58574 L
s
.71848 .58915 m
.72052 .58956 L
s
.70367 .58891 m
.69829 .58921 L
s
.53301 .58542 m
.5368 .58624 L
s
.69273 .58912 m
.68701 .58865 L
s
.35304 .58177 m
.35097 .58249 L
s
.66678 .5887 m
.67034 .58838 L
s
.49035 .58549 m
.49405 .58479 L
s
.65737 .58817 m
.66122 .58861 L
s
.47178 .58443 m
.47548 .58525 L
s
.69829 .58921 m
.69273 .58912 L
s
.66122 .58861 m
.66678 .5887 L
s
.58321 .58698 m
.57957 .5873 L
s
.41036 .58421 m
.4142 .58351 L
s
.574 .58721 m
.57022 .58677 L
s
.39375 .58318 m
.39733 .584 L
s
.54614 .58677 m
.5498 .58645 L
s
.5368 .58624 m
.54056 .58668 L
s
.35097 .58249 m
.34703 .58319 L
s
.57957 .5873 m
.574 .58721 L
s
.48664 .58581 m
.49035 .58549 L
s
.47548 .58525 m
.47919 .58569 L
s
.54056 .58668 m
.54614 .58677 L
s
.40658 .58453 m
.41036 .58421 L
s
.47919 .58569 m
.48664 .58581 L
s
.39733 .584 m
.40099 .58444 L
s
.34703 .58319 m
.34132 .58348 L
s
.40099 .58444 m
.40658 .58453 L
s
.34132 .58348 m
.32826 .58327 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06/0oooo2@000?lF0?ooo`030000003o
ool0oooo00@0oooo0`00001S0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0080oooo1`000?l30?ooo`L0003o00L0oooo0000o`3oool0oooo000000000?l0000000@0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`/0003o9P3oool00`000?l0oooo
0?ooo`0:0?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0oooo0P00
0?l40?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0000
000000020?ooo`80003o00H0oooo0000o`000?l0oooo0000o`3oool20000o`@0oooo00<0003o0?oo
o`3oool0103oool20000o`H0oooo1P000?l30?ooo`T0003o103oool70000o`H0oooo00<0003o0?oo
o`3oool010000?l60?ooo`80003o603oool01@000000oooo0?ooo`3oool0003o05H0oooo00<00000
0?ooo`3oool04`3oool002D0oooo0P00001[0?ooo`T0003o1P3oool00`000?l0oooo0?ooo`070?oo
o`P0003o00<0oooo0000003oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo0`000?l50?ooo`<0003o0`3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo0P000?l50?ooo`80003o103oool20000
o`D0oooo00<0003o0?ooo`3oool00P3oool90000o`<0oooo1`000?l2000000<0oooo00<0003o0?oo
o`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo01<0oooo1@000?l60?ooo`030000o`3oool0oooo00P0oooo1`000?l40?ooo`T0
003o1@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00P3oool30000o`D0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`<000000P000?l0
1@000000oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo0200oooo1@000?l4
0?ooo`@0000010000?l20?ooo`030000003oool0oooo0080003oE@3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo05d0oooo0`00000:0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`1J0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
E`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05@0oooo0`00000F0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`1@0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0C@3oool30000
01h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000R0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`170?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo
000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?oo
o`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00000n0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0a0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool30000
04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo
000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q
0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3o
ool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool30000
0780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3
000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0
oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@0
0000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0
oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@0
0000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0
U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003o
ool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0
oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000
oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<00000
0?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<0
0000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0
W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool0
0`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0
oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo
0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<00000
0?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<0
0000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0
Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool0
0`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0
oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo
0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?oo
o`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=
0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`00
00000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00
002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0008
0?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?oo
o`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0
R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000
003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo
00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo
000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<00000
0?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?oo
o`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?oo
o`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3o
ool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0
oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0
`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo
0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000
oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?oo
o`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`80
0000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0
oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003o
ool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0
oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo0000
05X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`00
0000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0
oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<0
00000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo0014
0?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`05
0000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0
oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0
BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`00
0000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P00
00140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<00000
0?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@00000
7`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3o
ool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`00
0000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo
00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<0
00000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<00000
0?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?oo
o`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?oo
o`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@
0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]
0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?oo
o`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0
OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0
NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3o
ool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool0
08P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0
oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780
oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0
oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?oo
o`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`03
0000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0
B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3o
ool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool0
09P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool0
09T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0
oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo
0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<0
00000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?oo
o`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A
0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?oo
o`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m
0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`03
0000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool0
4@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3o
ool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@00000
0?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?oo
o`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@000002
0?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L
0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?oo
o`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.63617 .5849 m
.63448 .58487 L
s
.63813 .58493 m
.63617 .5849 L
s
.71649 .58619 m
.71922 .58612 L
s
.63643 .58489 m
.63813 .58493 L
s
.63448 .58487 m
.63643 .58489 L
s
.60163 .58434 m
.60379 .58421 L
s
.48652 .58249 m
.4792 .58237 L
s
.49019 .58254 m
.48652 .58249 L
s
.4792 .58237 m
.47554 .58231 L
s
.49388 .58259 m
.49019 .58254 L
s
.47554 .58231 m
.47187 .58223 L
s
.34364 .5802 m
.34904 .58028 L
s
.3308 .57999 m
.34364 .5802 L
s
.3308 .57999 m
.32829 .57979 L
s
.34904 .58028 m
.35251 .58032 L
s
.49574 .5826 m
.49388 .58259 L
s
.47187 .58223 m
.47003 .58219 L
s
.69587 .5858 m
.69037 .58571 L
s
.70155 .58589 m
.69587 .5858 L
s
.69037 .58571 m
.68504 .58562 L
s
.35251 .58032 m
.35415 .58033 L
s
.66471 .5853 m
.65921 .58521 L
s
.66853 .58536 m
.66471 .5853 L
s
.65921 .58521 m
.65569 .58515 L
s
.47003 .58219 m
.46817 .58214 L
s
.63721 .58486 m
.63905 .58478 L
s
.70375 .58591 m
.70155 .58589 L
s
.61703 .58454 m
.62081 .58459 L
s
.61152 .58445 m
.61703 .58454 L
s
.60796 .58438 m
.61152 .58445 L
s
.68504 .58562 m
.68354 .58558 L
s
.67252 .5854 m
.66853 .58536 L
s
.57848 .58392 m
.58223 .58397 L
s
.57297 .58383 m
.57848 .58392 L
s
.56937 .58376 m
.57297 .58383 L
s
.65569 .58515 m
.6523 .58508 L
s
.56562 .58371 m
.56716 .58357 L
s
.55276 .5835 m
.55364 .58341 L
s
.54541 .58338 m
.5399 .5833 L
s
.54915 .58344 m
.54541 .58338 L
s
.5399 .5833 m
.53627 .58323 L
s
.62081 .58459 m
.623 .5846 L
s
.60275 .58427 m
.60796 .58438 L
s
.35415 .58033 m
.3557 .58033 L
s
.516 .58291 m
.52152 .583 L
s
.51235 .58285 m
.516 .58291 L
s
.50681 .58276 m
.50716 .58266 L
s
.58223 .58397 m
.58609 .58402 L
s
.56584 .58369 m
.56937 .58376 L
s
.55295 .58348 m
.54915 .58344 L
s
.45713 .58197 m
.44947 .58173 L
s
.53627 .58323 m
.53268 .58316 L
s
.44241 .58173 m
.44947 .58173 L
s
.44241 .58173 m
.43457 .58149 L
s
.68354 .58558 m
.68572 .5856 L
s
.50873 .58277 m
.51235 .58285 L
s
.42768 .58149 m
.43457 .58149 L
s
.41478 .58129 m
.41408 .58117 L
s
.40741 .58117 m
.40189 .58108 L
s
.41105 .58122 m
.40741 .58117 L
s
.40189 .58108 m
.39814 .58101 L
s
.6523 .58508 m
.65089 .58503 L
s
.46817 .58214 m
.46814 .5821 L
s
.37793 .58069 m
.38346 .58078 L
s
.37416 .58063 m
.37793 .58069 L
s
.36871 .58055 m
.36747 .58042 L
s
.58609 .58402 m
.5882 .58403 L
s
.41463 .58126 m
.41105 .58122 L
s
.39814 .58101 m
.39432 .58093 L
s
.37029 .58055 m
.37416 .58063 L
s
.623 .5846 m
.6242 .58454 L
s
.53268 .58316 m
.53097 .58311 L
s
.3557 .58033 m
.35521 .58028 L
s
.68572 .5856 m
.68957 .58565 L
s
.50696 .58272 m
.50873 .58277 L
s
.68957 .58565 m
.69896 .5858 L
s
.65089 .58503 m
.65117 .58502 L
s
.39432 .58093 m
.39226 .58088 L
s
.36818 .58049 m
.37029 .58055 L
s
.69896 .5858 m
.70283 .58585 L
s
.5882 .58403 m
.58838 .58401 L
s
.70283 .58585 m
.70505 .58587 L
s
.53097 .58311 m
.53106 .58309 L
s
.48663 .58239 m
.49587 .58254 L
s
.49592 .58252 m
.49587 .58254 L
s
.65117 .58502 m
.65345 .58503 L
s
.46814 .5821 m
.46997 .5821 L
s
.58838 .58401 m
.5868 .58396 L
s
.39226 .58088 m
.39213 .58086 L
s
.70505 .58587 m
.70523 .58587 L
s
.53106 .58309 m
.53305 .5831 L
s
.35521 .58028 m
.35306 .58022 L
s
.70523 .58587 m
.70375 .58583 L
s
.68709 .58556 m
.6849 .58554 L
s
.67042 .58529 m
.6738 .58536 L
s
.49409 .58247 m
.49592 .58252 L
s
.65345 .58503 m
.65745 .58508 L
s
.39213 .58086 m
.39378 .58086 L
s
.46997 .5821 m
.47182 .58212 L
s
.72226 .58612 m
.72021 .5861 L
s
.72021 .5861 m
.71856 .58607 L
s
.5868 .58396 m
.58327 .58389 L
s
.57028 .58368 m
.56642 .58364 L
s
.54986 .58335 m
.55345 .58343 L
s
.72061 .58609 m
.72226 .58612 L
s
.71856 .58607 m
.72061 .58609 L
s
.70375 .58583 m
.69838 .58573 L
s
.53305 .5831 m
.53686 .58315 L
s
.35306 .58022 m
.35099 .58018 L
s
.69282 .58564 m
.68709 .58556 L
s
.66687 .58523 m
.67042 .58529 L
s
.4904 .5824 m
.49409 .58247 L
s
.65745 .58508 m
.66131 .58514 L
s
.47182 .58212 m
.47553 .58216 L
s
.69838 .58573 m
.69282 .58564 L
s
.4104 .58111 m
.41423 .58119 L
s
.58327 .58389 m
.57965 .58383 L
s
.66131 .58514 m
.66687 .58523 L
s
.57407 .58374 m
.57028 .58368 L
s
.39378 .58086 m
.39737 .5809 L
s
.5462 .58329 m
.54986 .58335 L
s
.53686 .58315 m
.54063 .5832 L
s
.35099 .58018 m
.34706 .5801 L
s
.57965 .58383 m
.57407 .58374 L
s
.48669 .58233 m
.4904 .5824 L
s
.47553 .58216 m
.47925 .58221 L
s
.54063 .5832 m
.5462 .58329 L
s
.40662 .58105 m
.4104 .58111 L
s
.47925 .58221 m
.48669 .58233 L
s
.39737 .5809 m
.40103 .58096 L
s
.34706 .5801 m
.34136 .58 L
s
.40103 .58096 m
.40662 .58105 L
s
.34136 .58 m
.32829 .57979 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103o
ool3000006<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`1Z0?ooo`X0003o5`3oool00`000000oooo0?ooo`03000000d0oooo00<0003o
0?ooo`3oool0203oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0L@3oool40000o`@0oooo1`000?l20?oo
o`T0003o00@0oooo000000000000oooo30000?l30?ooo``0003o0`3oool40000odH0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?oo
o`3oool08P3oool20000o`<0oooo2@000?l40?ooo`T0003o103oool:0000o`80oooo0`000?l40?oo
o`T0003o0`3oool20000o`D0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0H03oool40000o`<000000P000?l00`000000
oooo0?ooo`030000oeD0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`1P0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0G@3o
ool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05X0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`1G0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0E03oool3000001H0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0500oooo1000000J0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`1=0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0BP3oool300000280oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo04L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3o
ool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000
003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
3`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
07l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`28
0?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.63613 .58984 m
.63444 .58943 L
s
.63809 .58948 m
.63613 .58984 L
s
.71647 .59074 m
.71923 .58536 L
s
.63639 .58907 m
.63809 .58948 L
s
.63444 .58943 m
.63639 .58907 L
s
.60159 .5889 m
.60382 .58074 L
s
.48645 .58705 m
.47913 .58694 L
s
.49012 .58673 m
.48645 .58705 L
s
.47913 .58694 m
.47547 .58649 L
s
.49383 .58602 m
.49012 .58673 L
s
.47547 .58649 m
.47182 .58566 L
s
.34354 .58477 m
.34895 .58447 L
s
.33069 .58456 m
.34354 .58477 L
s
.33069 .58456 m
.32837 .5763 L
s
.34895 .58447 m
.35244 .58375 L
s
.4957 .58527 m
.49383 .58602 L
s
.47182 .58566 m
.46998 .58486 L
s
.69586 .58771 m
.69036 .58762 L
s
.70154 .58741 m
.69586 .58771 L
s
.69036 .58762 m
.68503 .58715 L
s
.35244 .58375 m
.35409 .583 L
s
.6647 .58721 m
.6592 .58712 L
s
.66852 .58688 m
.6647 .58721 L
s
.6592 .58712 m
.65568 .58668 L
s
.63719 .58677 m
.63908 .58131 L
s
.46998 .58486 m
.46815 .58367 L
s
.70374 .58667 m
.70154 .58741 L
s
.61701 .58644 m
.6208 .58612 L
s
.6115 .58636 m
.61701 .58644 L
s
.60794 .58591 m
.6115 .58636 L
s
.68503 .58715 m
.68354 .58635 L
s
.67252 .58617 m
.66852 .58688 L
s
.57845 .58583 m
.58222 .5855 L
s
.57294 .58574 m
.57845 .58583 L
s
.65568 .58668 m
.6523 .58584 L
s
.56935 .58529 m
.57294 .58574 L
s
.5656 .58562 m
.56724 .57735 L
s
.55274 .58541 m
.55368 .57993 L
s
.54539 .5853 m
.53987 .58521 L
s
.54913 .58497 m
.54539 .5853 L
s
.53987 .58521 m
.53625 .58476 L
s
.6208 .58612 m
.623 .58498 L
s
.60275 .58466 m
.60794 .58591 L
s
.51598 .58482 m
.52149 .58491 L
s
.35409 .583 m
.35567 .58186 L
s
.51233 .58438 m
.51598 .58482 L
s
.50678 .58468 m
.50721 .57918 L
s
.58222 .5855 m
.58608 .58478 L
s
.56583 .58446 m
.56935 .58529 L
s
.55294 .58425 m
.54913 .58497 L
s
.4571 .58388 m
.44953 .57825 L
s
.53625 .58476 m
.53267 .58392 L
s
.44237 .58364 m
.44953 .57825 L
s
.44237 .58364 m
.43463 .57801 L
s
.68354 .58635 m
.68572 .5856 L
s
.50872 .58354 m
.51233 .58438 L
s
.42764 .58341 m
.43463 .57801 L
s
.41475 .5832 m
.41414 .57768 L
s
.40738 .58308 m
.40185 .58299 L
s
.41102 .58275 m
.40738 .58308 L
s
.6523 .58584 m
.65089 .58465 L
s
.40185 .58299 m
.39811 .58254 L
s
.46815 .58367 m
.46814 .58171 L
s
.37789 .58261 m
.38342 .5827 L
s
.37412 .58216 m
.37789 .58261 L
s
.36867 .58246 m
.36755 .57693 L
s
.58608 .58478 m
.5882 .58364 L
s
.41462 .58203 m
.41102 .58275 L
s
.39811 .58254 m
.3943 .5817 L
s
.623 .58498 m
.62423 .58107 L
s
.37028 .58132 m
.37412 .58216 L
s
.53267 .58392 m
.53098 .58272 L
s
.68572 .5856 m
.68958 .58527 L
s
.35567 .58186 m
.35522 .5799 L
s
.50696 .58234 m
.50872 .58354 L
s
.68958 .58527 m
.69896 .58503 L
s
.65089 .58465 m
.65118 .58387 L
s
.3943 .5817 m
.39227 .58049 L
s
.36819 .58011 m
.37028 .58132 L
s
.69896 .58503 m
.70284 .5847 L
s
.5882 .58364 m
.58839 .58286 L
s
.70284 .5847 m
.70505 .58395 L
s
.53098 .58272 m
.53108 .58194 L
s
.48663 .58201 m
.49587 .58216 L
s
.49594 .58098 m
.49587 .58216 L
s
.65118 .58387 m
.65347 .58272 L
s
.46814 .58171 m
.47 .58056 L
s
.58839 .58286 m
.58683 .58165 L
s
.39227 .58049 m
.39215 .5797 L
s
.70505 .58395 m
.70524 .58356 L
s
.53108 .58194 m
.53308 .58079 L
s
.35522 .5799 m
.35309 .57868 L
s
.70524 .58356 m
.70377 .58274 L
s
.68711 .58247 m
.68491 .58323 L
s
.67044 .58221 m
.67382 .58305 L
s
.49413 .58016 m
.49594 .58098 L
s
.65347 .58272 m
.65747 .582 L
s
.39215 .5797 m
.39383 .57855 L
s
.72228 .58304 m
.72023 .5834 L
s
.72023 .5834 m
.71858 .58298 L
s
.47 .58056 m
.47186 .5798 L
s
.58683 .58165 m
.58331 .5808 L
s
.57032 .58059 m
.56645 .58132 L
s
.72063 .58262 m
.72228 .58304 L
s
.5499 .58027 m
.55348 .58112 L
s
.71858 .58298 m
.72063 .58262 L
s
.70377 .58274 m
.6984 .58226 L
s
.53308 .58079 m
.5369 .58006 L
s
.69284 .58217 m
.68711 .58247 L
s
.35309 .57868 m
.35104 .57786 L
s
.66689 .58175 m
.67044 .58221 L
s
.49045 .57931 m
.49413 .58016 L
s
.65747 .582 m
.66133 .58166 L
s
.47186 .5798 m
.47558 .57907 L
s
.6984 .58226 m
.69284 .58217 L
s
.66133 .58166 m
.66689 .58175 L
s
.58331 .5808 m
.57968 .58035 L
s
.41046 .57802 m
.41427 .57888 L
s
.57411 .58026 m
.57032 .58059 L
s
.39383 .57855 m
.39743 .57781 L
s
.54625 .57981 m
.5499 .58027 L
s
.5369 .58006 m
.54067 .57972 L
s
.35104 .57786 m
.34713 .577 L
s
.57968 .58035 m
.57411 .58026 L
s
.48675 .57885 m
.49045 .57931 L
s
.47558 .57907 m
.47931 .57873 L
s
.54067 .57972 m
.54625 .57981 L
s
.40669 .57756 m
.41046 .57802 L
s
.47931 .57873 m
.48675 .57885 L
s
.39743 .57781 m
.4011 .57747 L
s
.34713 .577 m
.34143 .57651 L
s
.4011 .57747 m
.40669 .57756 L
s
.34143 .57651 m
.32837 .5763 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06X0oooo20000?l70?ooo`030000o`3o
ool0oooo00T0oooo0`000?l20?ooo`030000003oool0oooo00@0oooo0`00000_0?ooo`030000o`3o
ool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo0`000?l40?ooo`030000o`3oool0
oooo00H0oooo0`000?l30?ooo`<0003o00<000000?ooo`3oool00`0000000`3oool0003o0?ooo`03
0?ooo`030000o`3oool0oooo00H0oooo2@000?l40?ooo`030000o`3oool0oooo00P0oooo1@000?l0
0`3oool0003o0?ooo`030?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3oool70000o`80oooo0`000?l40?ooo`80003o00<0oooo0000
000000000P3oool20000o`060?ooo`000?l0003o0?ooo`000?l0oooo0P000?l40?ooo`80003o1@3o
ool50000o`<0oooo00<0003o0?ooo`3oool01P3oool20000o`D0oooo0P000?l40?ooo`T0003o1@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool70000o`D0oooo1`000?l00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo0580oooo00<0
00000?ooo`3oool04`3oool002D0oooo0P00001/0?ooo`X0003o403oool40000o`040?ooo`000?l0
oooo00000080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3o
ool0oooo0?ooo`80003o2@3oool010000?l0oooo0?ooo`3oool60000o`<0oooo2@000?l40?ooo`80
003o103oool30000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool70000
o`800000103oool20000oeD0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0A0?ooo`T0003o6P3oool00`000?l0oooo0000o`030000o`L0
oooo00<0003o0?ooo`000?l01@000?l50?ooo`030000o`3oool0oooo00<0oooo2@000?l30?ooo`@0
003o0`0000000`000?l0oooo000000020?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`110?ooo`030000
o`3oool0oooo00T0oooo0`000?l@0?ooo`@000001P3oool00`000000oooo0000o`1G0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0G@3o
ool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo05X0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`1G0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0E03oool3000001H0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0500oooo1000000J0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`1=0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0BP3oool300000280oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo04L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`03
0000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3o
ool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0
oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?oo
o`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000
003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
3`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
07l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`28
0?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71655 .5951 m
.71921 .58462 L
s
.63616 .59456 m
.63447 .59379 L
s
.63812 .59384 m
.63616 .59456 L
s
.63642 .59307 m
.63812 .59384 L
s
.63447 .59379 m
.63642 .59307 L
s
.6016 .59326 m
.60381 .57742 L
s
.48638 .59142 m
.47906 .5913 L
s
.49007 .59073 m
.48638 .59142 L
s
.47906 .5913 m
.47541 .5905 L
s
.49378 .5893 m
.49007 .59073 L
s
.47541 .5905 m
.47176 .58894 L
s
.34338 .58913 m
.34881 .58847 L
s
.33053 .58893 m
.34338 .58913 L
s
.33053 .58893 m
.3285 .57298 L
s
.34881 .58847 m
.35233 .58703 L
s
.49567 .58783 m
.49378 .5893 L
s
.47176 .58894 m
.46994 .58742 L
s
.69589 .58953 m
.69039 .58945 L
s
.70156 .58887 m
.69589 .58953 L
s
.69039 .58945 m
.68506 .58861 L
s
.66472 .58903 m
.65922 .58895 L
s
.66854 .58834 m
.66472 .58903 L
s
.65922 .58895 m
.65569 .58814 L
s
.35233 .58703 m
.35401 .58556 L
s
.6372 .58859 m
.63905 .57799 L
s
.70376 .5874 m
.70156 .58887 L
s
.46994 .58742 m
.46812 .58513 L
s
.61702 .58827 m
.6208 .58758 L
s
.61151 .58818 m
.61702 .58827 L
s
.60795 .58737 m
.61151 .58818 L
s
.68506 .58861 m
.68355 .58708 L
s
.67252 .5869 m
.66854 .58834 L
s
.65569 .58814 m
.65231 .58658 L
s
.57845 .58765 m
.58222 .58696 L
s
.57294 .58756 m
.57845 .58765 L
s
.56935 .58675 m
.57294 .58756 L
s
.56559 .58745 m
.56725 .57142 L
s
.55273 .58724 m
.5537 .57661 L
s
.54538 .58712 m
.53986 .58703 L
s
.54912 .58643 m
.54538 .58712 L
s
.6208 .58758 m
.623 .58535 L
s
.53986 .58703 m
.53624 .58622 L
s
.60275 .58502 m
.60795 .58737 L
s
.51596 .58665 m
.52147 .58674 L
s
.51232 .58584 m
.51596 .58665 L
s
.35401 .58556 m
.35562 .58333 L
s
.50676 .5865 m
.50725 .57586 L
s
.58222 .58696 m
.58608 .58551 L
s
.56583 .58519 m
.56935 .58675 L
s
.55293 .58498 m
.54912 .58643 L
s
.53624 .58622 m
.53267 .58466 L
s
.45707 .58571 m
.44959 .57493 L
s
.68355 .58708 m
.68572 .5856 L
s
.44234 .58547 m
.44959 .57493 L
s
.44234 .58547 m
.43471 .57469 L
s
.50871 .58427 m
.51232 .58584 L
s
.4276 .58523 m
.43471 .57469 L
s
.65231 .58658 m
.65089 .58428 L
s
.4147 .58503 m
.41423 .57436 L
s
.40733 .58491 m
.4018 .58482 L
s
.41098 .58421 m
.40733 .58491 L
s
.4018 .58482 m
.39807 .58401 L
s
.46812 .58513 m
.46815 .58135 L
s
.37783 .58444 m
.38336 .58452 L
s
.37408 .58362 m
.37783 .58444 L
s
.36861 .58429 m
.36765 .57361 L
s
.58608 .58551 m
.5882 .58328 L
s
.4146 .58276 m
.41098 .58421 L
s
.39807 .58401 m
.39428 .58243 L
s
.623 .58535 m
.62422 .57775 L
s
.53267 .58466 m
.53098 .58236 L
s
.68572 .5856 m
.68957 .5849 L
s
.37025 .58205 m
.37408 .58362 L
s
.35562 .58333 m
.35523 .57953 L
s
.50697 .58197 m
.50871 .58427 L
s
.68957 .5849 m
.69895 .5843 L
s
.65089 .58428 m
.65117 .58277 L
s
.39428 .58243 m
.39228 .58013 L
s
.69895 .5843 m
.70282 .5836 L
s
.3682 .57974 m
.37025 .58205 L
s
.5882 .58328 m
.58839 .58176 L
s
.70282 .5836 m
.70502 .58211 L
s
.53098 .58236 m
.53109 .58084 L
s
.65117 .58277 m
.65345 .58052 L
s
.48664 .58164 m
.49588 .58179 L
s
.49596 .57951 m
.49588 .58179 L
s
.46815 .58135 m
.47002 .57909 L
s
.58839 .58176 m
.58683 .57944 L
s
.70502 .58211 m
.70521 .58135 L
s
.39228 .58013 m
.39218 .5786 L
s
.53109 .58084 m
.5331 .57858 L
s
.35523 .57953 m
.35314 .57721 L
s
.70521 .58135 m
.70372 .5798 L
s
.68706 .57953 m
.68488 .58102 L
s
.6704 .57926 m
.67379 .58085 L
s
.65345 .58052 m
.65744 .57905 L
s
.49416 .57795 m
.49596 .57951 L
s
.72222 .5801 m
.72018 .58083 L
s
.72018 .58083 m
.71852 .58004 L
s
.47002 .57909 m
.47189 .57759 L
s
.39218 .5786 m
.39389 .57634 L
s
.58683 .57944 m
.58331 .57786 L
s
.72056 .5793 m
.72222 .5801 L
s
.57032 .57765 m
.56646 .57912 L
s
.71852 .58004 m
.72056 .5793 L
s
.54991 .57732 m
.55349 .57891 L
s
.70372 .5798 m
.69835 .57894 L
s
.5331 .57858 m
.53692 .57711 L
s
.69279 .57886 m
.68706 .57953 L
s
.66685 .57844 m
.6704 .57926 L
s
.35314 .57721 m
.35112 .57565 L
s
.65744 .57905 m
.66129 .57835 L
s
.49049 .57636 m
.49416 .57795 L
s
.47189 .57759 m
.47563 .57612 L
s
.69835 .57894 m
.69279 .57886 L
s
.66129 .57835 m
.66685 .57844 L
s
.58331 .57786 m
.57969 .57703 L
s
.57412 .57694 m
.57032 .57765 L
s
.41054 .57507 m
.41433 .57667 L
s
.54627 .57649 m
.54991 .57732 L
s
.39389 .57634 m
.39751 .57486 L
s
.53692 .57711 m
.54069 .5764 L
s
.35112 .57565 m
.34723 .57405 L
s
.57969 .57703 m
.57412 .57694 L
s
.4868 .57553 m
.49049 .57636 L
s
.47563 .57612 m
.47936 .57541 L
s
.54069 .5764 m
.54627 .57649 L
s
.40678 .57424 m
.41054 .57507 L
s
.47936 .57541 m
.4868 .57553 L
s
.39751 .57486 m
.40119 .57415 L
s
.34723 .57405 m
.34155 .57319 L
s
.40119 .57415 m
.40678 .57424 L
s
.34155 .57319 m
.3285 .57298 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000Y0?ooo`03
0000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`1Y0?ooo`P0003o1`3oool00`000?l0oooo0?ooo`080?ooo`D0003o
00<000000000o`3oool01P3oool00`000?l0oooo00000002000002`0oooo00<0003o0?ooo`3oool0
<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo06X0oooo00<0003o0?ooo`3oool01@3oool20000o`D0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`030?ooo`80003o1P3oool00`000?l000000000o`030?ooo`030000o`3o
ool0oooo00L0oooo1`000?l50?ooo`030000o`3oool0oooo00P0oooo1`000?l40?ooo`030000o`3o
ool0oooo00<0003o203oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`05
0?ooo`040000o`000000oooo0?ooo`80000000@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo
0000o`060?ooo`80003o1`3oool20000o`<0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo0`000?l30?ooo`<0003o1@3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103oool60000o`D0oooo
1`000?l00`000000oooo0?ooo`020?ooo`80003oE03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3o
ool20000o`P0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0000000000020?ooo`090000
o`3oool0oooo0?ooo`000?l0oooo0000o`3oool0003o00D0oooo00<0003o0?ooo`3oool0103oool5
0000o`<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool0
1@000?l0oooo0?ooo`3oool0003o00L0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1C0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000K03oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l010000?l40?ooo`L0003o00D0oooo
0000003oool0oooo0000o`050?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo
0?ooo`0<0?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool0103oool20000o`@0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`H0003o0P0000040?ooo`030000
o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0J`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00H0003o0?ooo`3oool0oooo
0000o`3oool40000o`@0oooo20000?l40?ooo`L0003o1P3oool00`000?l0oooo0000o`050000o`D0
oooo00<0003o0?ooo`3oool00`3oool20000o`H0oooo00D0003o0?ooo`3oool0oooo0000o`030?oo
o`<0000000<0003o0?ooo`0000000`3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo06/0oooo20000?lI0?ooo`030000003oool0oooo0140
oooo0P000?l50?ooo`80003o9`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0
oooo1P000?l40?ooo`@0000010000?l20?ooo`030000003oool0003o05L0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0C0?ooo`D0003o
:@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo00`0oooo0`00000:0?ooo`030000
003oool0003o05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`1=0?ooo`<0003o2P3oool3000000h0oooo00<000000000o`3oool0EP3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo05L0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0D03oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo
0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`1:0?ooo`<000008P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0A03oool3000002X0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo03P0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo
0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000580oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`00
8@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00001K0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool0603oool300000680oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo
0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000O`3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool40000
08<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900
oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo1000
00050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?oo
o`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`03
0000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03o
ool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000
000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3o
ool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0
oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`00
0000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo
03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0
oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H
0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`03
0000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03o
ool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0
oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<00000
0?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`03
0000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3o
ool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0
oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`00
0000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0
oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo
00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<00000
0?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<0
0000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0
[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?oo
o`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo
0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?oo
o`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?oo
o`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
1P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0
oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K
0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool0
0`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool0
01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P000024
0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`06
0?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`03
0000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000
O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
1@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool20000
07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo
000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0
oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool20000
07<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo
0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D0
00000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000
003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3o
ool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo
0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000
oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`00
0000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo
0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?oo
o`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo
00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo
00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?oo
o`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?oo
o`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool0
0000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3o
ool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?oo
o`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000
oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool20000
04/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo
00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P000002
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?oo
o`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`03
0000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000
003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4
000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool50000
02<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo
00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g
0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?oo
o`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`03
0000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000
003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00
J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3o
ool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`00
0000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000
;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0
oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0
oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo
07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0
oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo
00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00
001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000
001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000
703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3o
ool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0
oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0
oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0
oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo
002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U
0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?oo
o`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?oo
o`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3o
ool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000
003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D0
0000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103o
ool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0
oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool40000
0<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`04
0000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00
[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D0
00000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\[Theta] Variation - Changing the Longitude\
\>", "Subsection"],

Cell["\<\
The following routine produces one frame for a \[Theta] variation \
animation.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[Theta]frame[\[Phi]_, \[Psi]_]\)[\[Theta]_] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{AbsoluteThickness[1], 
            Blue, \[IndentingNewLine]Text3D["\<DrawGraphics!\>", {0, 0, 
                0}, {1, 1}, {\[Phi], \[Theta], \[Psi]}, 
              Font3D \[Rule] FuturaFont3D]}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                  1}, {\(-1\), 1}} 10, \[IndentingNewLine]ImageSize \[Rule] 
            400];\)\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(\[Theta]frame\\)\\\" is similar to existing \
symbols \\!\\({\[Phi]frame, \[Psi]frame}\\). \\!\\(\\*ButtonBox[\\\"More\
\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"]
}, Open  ]],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(\[Phi]\)]],
  " is zero, varying ",
  Cell[BoxData[
      \(\[Theta]\)]],
  " is no different than varying ",
  Cell[BoxData[
      \(\[Psi]\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Theta]frame[0, 0]\)[\[Theta]], {\[Theta], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37024 .64733 m
.38086 .64396 L
s
.37024 .64733 m
.35044 .62848 L
s
.38086 .64396 m
.3845 .64162 L
s
.3845 .64162 m
.38569 .63886 L
s
.38569 .63886 m
.38536 .63658 L
s
.38536 .63658 m
.3841 .63339 L
s
.3841 .63339 m
.37942 .62886 L
s
.39577 .63086 m
.38268 .61809 L
s
.37942 .62886 m
.37507 .62663 L
s
.39946 .62848 m
.40346 .62841 L
s
.39452 .62765 m
.39946 .62848 L
s
.36114 .62503 m
.35044 .62848 L
s
.40346 .62841 m
.40809 .62693 L
s
.39018 .62541 m
.39452 .62765 L
s
.37507 .62663 m
.37165 .6253 L
s
.37165 .6253 m
.36669 .62446 L
s
.36669 .62446 m
.36114 .62503 L
s
.41956 .62206 m
.41462 .62123 L
s
.42359 .62199 m
.41956 .62206 L
s
.42826 .6205 m
.42359 .62199 L
s
.41462 .62123 m
.41029 .61897 L
s
.43046 .61859 m
.42826 .6205 L
s
.41029 .61897 m
.40844 .61713 L
s
.43175 .61575 m
.43046 .61859 L
s
.43449 .61851 m
.42162 .60554 L
s
.40844 .61713 m
.40721 .61386 L
s
.44544 .61502 m
.43894 .59996 L
s
.40721 .61386 m
.40846 .61101 L
s
.45801 .61101 m
.45161 .59587 L
s
.45801 .61101 m
.43894 .59996 L
s
.40846 .61101 m
.41065 .60907 L
s
.41065 .60907 m
.41535 .60756 L
s
.41941 .60748 m
.42439 .60834 L
s
.41535 .60756 m
.41941 .60748 L
s
.49186 .60752 m
.4869 .60667 L
s
.49592 .60744 m
.49186 .60752 L
s
.50229 .60542 m
.49592 .60744 L
s
.47064 .60698 m
.45161 .59587 L
s
.4869 .60667 m
.48354 .60531 L
s
.5046 .60348 m
.50229 .60542 L
s
.48354 .60531 m
.47926 .60301 L
s
.50604 .60058 m
.5046 .60348 L
s
.47926 .60301 m
.47477 .59831 L
s
.50587 .59819 m
.50604 .60058 L
s
.47477 .59831 m
.47366 .59497 L
s
.47366 .59497 m
.47345 .59256 L
s
.51374 .59323 m
.50131 .57985 L
s
.49075 .59319 m
.49877 .59062 L
s
.47345 .59256 m
.47484 .58963 L
s
.5177 .59074 m
.5218 .59066 L
s
.51271 .58987 m
.5177 .59074 L
s
.5218 .59066 m
.52665 .58911 L
s
.4961 .58776 m
.49877 .59062 L
s
.50844 .58752 m
.51271 .58987 L
s
.47484 .58963 m
.47714 .58764 L
s
.4927 .58637 m
.4961 .58776 L
s
.47714 .58764 m
.48356 .58557 L
s
.48768 .58549 m
.4927 .58637 L
s
.48356 .58557 m
.48768 .58549 L
s
.53876 .58402 m
.53376 .58314 L
s
.54288 .58394 m
.53876 .58402 L
s
.54777 .58238 m
.54288 .58394 L
s
.53376 .58314 m
.5295 .58078 L
s
.55016 .58038 m
.54777 .58238 L
s
.5295 .58078 m
.52774 .57885 L
s
.5517 .5774 m
.55016 .58038 L
s
.5543 .5803 m
.5421 .56671 L
s
.52774 .57885 m
.52672 .57543 L
s
.56577 .57664 m
.54749 .55608 L
s
.52672 .57543 m
.52822 .57244 L
s
.5682 .57462 m
.57235 .57454 L
s
.56318 .57373 m
.5682 .57462 L
s
.57235 .57454 m
.57729 .57296 L
s
.57729 .57296 m
.57974 .57094 L
s
.60472 .57292 m
.58687 .55227 L
s
.52822 .57244 m
.53061 .57041 L
s
.57974 .57094 m
.58133 .56793 L
s
.53061 .57041 m
.53553 .56883 L
s
.53969 .56874 m
.54473 .56964 L
s
.53553 .56883 m
.53969 .56874 L
s
.58133 .56793 m
.58042 .56446 L
s
.55781 .56291 m
.55625 .56593 L
s
.58042 .56446 m
.5787 .5625 L
s
.63723 .56385 m
.63473 .5634 L
s
.63809 .56233 m
.63723 .56385 L
s
.60297 .56352 m
.60715 .56344 L
s
.59543 .56217 m
.60297 .56352 L
s
.60715 .56344 m
.61215 .56184 L
s
.63473 .5634 m
.63558 .56188 L
s
.56025 .56086 m
.55781 .56291 L
s
.5787 .5625 m
.57446 .56008 L
s
.63558 .56188 m
.63809 .56233 L
s
.61215 .56184 m
.61466 .55979 L
s
.56522 .55925 m
.56025 .56086 L
s
.57446 .56008 m
.56941 .55917 L
s
.61466 .55979 m
.61381 .55629 L
s
.56941 .55917 m
.56522 .55925 L
s
.61381 .55629 m
.60534 .54632 L
s
.6306 .55596 m
.61885 .54197 L
s
.64666 .54957 m
.64162 .54866 L
s
.65088 .54949 m
.64666 .54957 L
s
.65597 .54787 m
.65088 .54949 L
s
.64162 .54866 m
.63743 .5462 L
s
.65855 .54578 m
.65597 .54787 L
s
.63743 .5462 m
.63576 .54419 L
s
.66031 .54268 m
.65855 .54578 L
s
.63576 .54419 m
.63495 .54062 L
s
.67391 .54088 m
.67057 .5394 L
s
.67986 .54025 m
.67391 .54088 L
s
.63495 .54062 m
.63667 .53751 L
s
.68501 .5386 m
.67986 .54025 L
s
.67057 .5394 m
.67065 .53683 L
s
.71128 .53911 m
.70008 .52484 L
s
.68936 .53594 m
.68501 .5386 L
s
.63667 .53751 m
.63925 .53539 L
s
.67065 .53683 m
.67326 .53472 L
s
.68947 .53336 m
.68936 .53594 L
s
.63925 .53539 m
.64437 .53374 L
s
.67326 .53472 m
.68105 .53094 L
s
.64862 .53366 m
.65371 .53459 L
s
.64437 .53374 m
.64862 .53366 L
s
.66407 .52868 m
.664 .53128 L
s
.68105 .53094 m
.68368 .52881 L
s
.68368 .52881 m
.68378 .52621 L
s
.66841 .52599 m
.66407 .52868 L
s
.68378 .52621 m
.68297 .52518 L
s
.67359 .52432 m
.66841 .52599 L
s
.68297 .52518 m
.6796 .52368 L
s
.6796 .52368 m
.67359 .52432 L
s
.69697 .51809 m
.69604 .51968 L
s
.69604 .51968 m
.69348 .51921 L
s
.69348 .51921 m
.69441 .51761 L
s
.69441 .51761 m
.69697 .51809 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000K0?ooo`80
003o00<0oooo0000003oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000N0?ooo`040000o`3oool0oooo000005P0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1E0?ooo`<00000703oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`1A0?ooo`<000006`3oool40000o`030?ooo`000?l0003o00D0oooo00<0003o0000003oool0F03o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3
000001d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0B@3oool300000200oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`03000000000?l0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0
oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04D0
oooo0`00000K0?ooo`D0003o1`3oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000000
003o0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000703oool20000o`X0oooo
0P000?l50?ooo`030000o`3oool0oooo0080oooo00<000000?ooo`000?l0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?oo
o`0m0?ooo`<000007P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo0P00
0?l50?ooo`040000003oool0oooo0000oeH0oooo00<000000?ooo`3oool05@3oool002P0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000006`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool40000o`L0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo03D0oooo0`00000O0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?oo
o`<00000703oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0>0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<0
0000803oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1P000?lA0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0Y0?ooo`<000006`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000003`3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<000004`3oool0
0`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0703oool4000001L0oooo00<0003o0?ooo`3oool01P000?l60?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool07`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3o
ool0603oool3000001`0oooo0P000?l60?ooo`80003o1@3oool70000o`P0oooo0P000?lH0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
Q@3oool00`000000oooo0?ooo`0D0?ooo`<000006P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0U0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`0@0?ooo`<000006`3oool20000o`030?ooo`000?l0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02D0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000L0?ooo`80003o0P3oool30000o`@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo02@0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000N0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool00`3oool60000o`T0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool300000200oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo00<0003o0?ooo`3o
ool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08/0oooo00<000000?ooo`3oool00`00000J0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool01@3oool20000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007P3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00@0oooo0P000?l00`3oool0003o0?ooo`0f0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0
oooo01D0oooo0`000?l60?ooo`030000o`3oool0oooo00H0oooo1P000?lj0?ooo`800000F`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
01<0oooo0P000?l30?ooo`<0003o0`3oool00`000?l0oooo0?ooo`130?ooo`<000000P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`050?ooo`80003o0`3oool70000ocX0
oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo
0P000?l60?ooo`030000o`3oool0oooo03X0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`090?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0AP3oool3000000h0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo00T0oooo0`000?l60?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0=`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool010000?l0oooo0000o`000?l50?ooo`030000o`3oool0oooo00P0oooo00<0003o
0?ooo`3oool0<`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo0`000?l20?oo
o`040000o`3oool0oooo0?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0300oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000003o0?ooo`060?ooo`060000o`3oool0003o
0000o`3oool0003o103oool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?oo
o`0^0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo08X0oooo1P000?l60?ooo`040000o`3oool0oooo0?ooo`80003o2`3o
ool50000obh0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0RP3oool01@000?l0oooo0?ooo`3oool000000080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo03P0oooo0`00
000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002;
0?ooo`050000o`3oool0oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo03X0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0RP3oool01@000?l0oooo0?ooo`3oool0000000@0oooo00<0
003o0?ooo`3oool0>`3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`210?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`000000103oool00`000?l0oooo0000o`0i0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo0880oooo00<0003o0?oo
o`3oool01`3oool70000ocP0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0M`3oool60000o`H0oooo00<0003o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07D0oooo0`000?l60?ooo`80003o
1@3oool70000o`80oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1f0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000003o
ool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0M`3oool00`000?l0oooo0?ooo`070?ooo`80003o2`3oool0
0`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo07P0oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`090?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0N@3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0:03oool3000004h0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000007X0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
001m0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?oo
o`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q
0?ooo`030000003oool0oooo07d0oooo00<0003o0?ooo`3oool00P000?l=0?ooo`030000003oool0
oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo07h0oooo0P000?l?0?ooo`030000003oool0oooo
01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0
oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.34884 .62729 m
.3607 .62524 L
s
.34884 .62729 m
.33571 .60619 L
s
.3607 .62524 m
.36518 .62336 L
s
.36518 .62336 m
.36736 .62078 L
s
.36736 .62078 m
.36785 .61848 L
s
.36785 .61848 m
.36772 .61517 L
s
.36772 .61517 m
.36466 .61012 L
s
.3803 .61409 m
.37178 .59986 L
s
.38886 .6126 m
.39401 .61171 L
s
.38483 .61219 m
.38886 .6126 L
s
.3802 .61077 m
.38483 .61219 L
s
.37667 .60802 m
.3802 .61077 L
s
.36466 .61012 m
.3611 .60737 L
s
.4112 .60872 m
.40717 .60831 L
s
.41637 .60782 m
.4112 .60872 L
s
.40717 .60831 m
.40254 .60687 L
s
.41924 .60621 m
.41637 .60782 L
s
.3611 .60737 m
.35815 .60564 L
s
.40254 .60687 m
.39904 .60412 L
s
.42327 .60662 m
.4151 .59226 L
s
.42153 .60356 m
.41924 .60621 L
s
.3477 .60409 m
.33571 .60619 L
s
.35815 .60564 m
.35347 .6042 L
s
.43538 .60452 m
.43428 .58889 L
s
.35347 .6042 m
.3477 .60409 L
s
.39904 .60412 m
.39785 .60207 L
s
.4879 .60323 m
.48388 .60281 L
s
.49488 .60202 m
.4879 .60323 L
s
.48388 .60281 m
.4793 .60137 L
s
.44925 .60211 m
.44828 .58643 L
s
.44925 .60211 m
.43428 .58889 L
s
.39785 .60207 m
.39779 .5987 L
s
.49783 .60039 m
.49488 .60202 L
s
.4793 .60137 m
.47647 .59962 L
s
.50026 .59773 m
.49783 .60039 L
s
.46316 .59969 m
.44828 .58643 L
s
.47647 .59962 m
.47307 .59684 L
s
.39779 .5987 m
.40005 .59603 L
s
.50094 .59537 m
.50026 .59773 L
s
.47307 .59684 m
.4703 .59168 L
s
.40005 .59603 m
.40293 .59439 L
s
.41221 .5939 m
.41686 .59536 L
s
.40293 .59439 m
.40814 .59348 L
s
.40814 .59348 m
.41221 .5939 L
s
.4703 .59168 m
.47039 .58826 L
s
.51042 .59147 m
.50293 .57684 L
s
.51922 .58994 m
.52451 .58902 L
s
.51517 .58952 m
.51922 .58994 L
s
.51059 .58805 m
.51517 .58952 L
s
.48785 .58862 m
.49665 .58708 L
s
.47039 .58826 m
.47103 .58587 L
s
.50722 .58523 m
.51059 .58805 L
s
.49502 .58395 m
.49665 .58708 L
s
.54218 .58595 m
.53813 .58552 L
s
.5475 .58503 m
.54218 .58595 L
s
.47103 .58587 m
.47344 .58316 L
s
.53813 .58552 m
.53355 .58405 L
s
.55054 .58336 m
.5475 .58503 L
s
.53355 .58405 m
.53022 .58122 L
s
.49217 .58216 m
.49502 .58395 L
s
.55459 .58379 m
.54747 .56902 L
s
.55308 .58065 m
.55054 .58336 L
s
.47344 .58316 m
.47641 .58149 L
s
.60609 .58278 m
.59603 .5605 L
s
.48755 .58069 m
.49217 .58216 L
s
.56704 .58163 m
.55645 .55932 L
s
.47641 .58149 m
.48347 .58026 L
s
.53022 .58122 m
.52918 .57912 L
s
.48347 .58026 m
.48755 .58069 L
s
.57416 .58039 m
.57951 .57946 L
s
.5701 .57996 m
.57416 .58039 L
s
.56554 .57848 m
.5701 .57996 L
s
.57951 .57946 m
.58259 .57779 L
s
.52918 .57912 m
.52939 .57565 L
s
.64059 .57794 m
.63834 .5772 L
s
.64194 .57658 m
.64059 .57794 L
s
.58259 .57779 m
.58519 .57506 L
s
.63834 .5772 m
.63969 .57583 L
s
.63969 .57583 m
.64194 .57658 L
s
.52939 .57565 m
.53191 .57291 L
s
.58519 .57506 m
.58552 .57157 L
s
.61174 .57386 m
.61713 .57292 L
s
.60768 .57342 m
.61174 .57386 L
s
.60086 .57118 m
.60768 .57342 L
s
.61713 .57292 m
.62027 .57123 L
s
.53191 .57291 m
.53495 .57122 L
s
.5444 .57071 m
.549 .57221 L
s
.58552 .57157 m
.58454 .56944 L
s
.62027 .57123 m
.62067 .56773 L
s
.53495 .57122 m
.54031 .57028 L
s
.54031 .57028 m
.5444 .57071 L
s
.5641 .56726 m
.56153 .57002 L
s
.63696 .56947 m
.63051 .55445 L
s
.58454 .56944 m
.58127 .56656 L
s
.62067 .56773 m
.61596 .557 L
s
.56719 .56556 m
.5641 .56726 L
s
.58127 .56656 m
.57668 .56505 L
s
.65868 .5657 m
.65461 .56526 L
s
.66413 .56475 m
.65868 .5657 L
s
.57259 .56461 m
.56719 .56556 L
s
.65461 .56526 m
.65008 .56375 L
s
.57668 .56505 m
.57259 .56461 L
s
.66732 .56305 m
.66413 .56475 L
s
.65008 .56375 m
.64691 .56085 L
s
.71993 .56308 m
.7142 .54794 L
s
.67008 .56027 m
.66732 .56305 L
s
.64691 .56085 m
.646 .5587 L
s
.68962 .56032 m
.68371 .5602 L
s
.6951 .55937 m
.68962 .56032 L
s
.68371 .5602 m
.68103 .55836 L
s
.70017 .55733 m
.6951 .55937 L
s
.646 .5587 m
.64646 .55514 L
s
.68103 .55836 m
.68199 .55588 L
s
.70116 .55485 m
.70017 .55733 L
s
.68199 .55588 m
.68522 .55416 L
s
.64646 .55514 m
.6492 .55233 L
s
.68522 .55416 m
.69396 .55148 L
s
.6492 .55233 m
.65241 .5506 L
s
.66201 .55009 m
.66656 .55162 L
s
.69396 .55148 m
.69721 .54975 L
s
.65241 .5506 m
.6579 .54964 L
s
.6579 .54964 m
.66201 .55009 L
s
.69721 .54975 m
.69821 .54724 L
s
.67852 .54719 m
.67756 .54969 L
s
.69821 .54724 m
.69778 .54615 L
s
.6836 .54513 m
.67852 .54719 L
s
.69778 .54615 m
.69509 .54428 L
s
.68913 .54416 m
.6836 .54513 L
s
.69509 .54428 m
.68913 .54416 L
s
.71357 .54104 m
.71213 .54247 L
s
.71213 .54247 m
.70987 .54169 L
s
.70987 .54169 m
.7113 .54027 L
s
.7113 .54027 m
.71357 .54104 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool00P000?mE0?ooo`030000003oool0oooo
01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000003H0
oooo1@000?l20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<00000=`3oool20000o`D0oooo
00<0003o0?ooo`0000000`3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool300000300oooo1@00
0?l50?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`0000000`3oool00`000?l0oooo0?oo
o`1D0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0:@3oool300000380oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`07
0?ooo`80003o0P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000^0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool40000o`<0oooo00<0003o0000
003oool00`3oool00`000?l0oooo0?ooo`1C0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000002`0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool0103oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000
603oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0P3oool60000o`80oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1B0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000001`0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`1B0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
00000200oooo00<0003o0?ooo`3oool01`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`H0003o3P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000001l0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00L0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool05`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001d0oooo1`000?l3
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000O0?oo
o`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0
oooo00<0oooo1`000?lP0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000005`3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool02P3oool20000
oaL0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<000006P3oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo0`000?l30?ooo`80003o1`3oool00`00
0?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000004`3oool70000o`@0
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`000?l00P000?l:0?ooo`030000o`3oool0oooo0280oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`80003o2@3oool30000o`80
oooo0P000?l00`3oool0003o0?ooo`0e0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`060?ooo`80003o0`3oool20000o`/0oooo0P000?lg0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`000?l0oooo0000o`040000oc/0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0R03oool01@000?l0oooo0?ooo`000?l0000000D0oooo0P000?l30?ooo`030000o`3o
ool0003o00D0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0k0?ooo`<000002P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08H0oooo0`000?l00`3oool0003o0000o`020000o`D0oooo00<0003o0?ooo`000?l00P3oool0
0`000?l0oooo0?ooo`020000o`<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0k
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?oo
o`060000o`3oool0oooo0000o`3oool0003o103oool01@000?l0oooo0?ooo`3oool0003o00T0oooo
00<0003o0?ooo`3oool0>@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo00L0oooo00<0
003o0?ooo`3oool01@3oool00`000000003o0?ooo`030?ooo`040000o`3oool0oooo0?ooo`80003o
1@3oool010000?l0oooo0?ooo`3oool30000o`D0oooo00<0003o0?ooo`3oool0=`3oool3000001H0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`1a0?ooo`D0003o1P3oool00`000?l0oooo0?ooo`060?ooo`80003o1P3oool00`000000003o
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool50000ocH0oooo
1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0KP3oool30000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?oo
o`170?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T
0?ooo`030000003oool0oooo06l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00P0oooo1@000?l00`000000oooo0?ooo`1:0?ooo`<000008P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
0700oooo00<0003o0?ooo`3oool01P3oool20000o`@0oooo0`000?l30?ooo`030000o`3oool0oooo
00H0oooo00<000000?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool200000780oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0003o0080003o2@3oool00`000000oooo0?ooo`140?ooo`<0
0000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo0740oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0@0?ooo`030000
003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0LP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00l0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
07<0oooo00@0003o0?ooo`3oool0oooo10000?lB0?ooo`030000003oool0oooo03P0oooo0`00000j
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0M@3oool30000oaH0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000
A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240
oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.33453 .60481 m
.34718 .60423 L
s
.33453 .60481 m
.32889 .58225 L
s
.34718 .60423 m
.35235 .60292 L
s
.35235 .60292 m
.35547 .60063 L
s
.35547 .60063 m
.35678 .59842 L
s
.35678 .59842 m
.35785 .59512 L
s
.4815 .59811 m
.47768 .59721 L
s
.48879 .59778 m
.4815 .59811 L
s
.49227 .59655 m
.48879 .59778 L
s
.47768 .59721 m
.47369 .59524 L
s
.4956 .59423 m
.49227 .59655 L
s
.37083 .59561 m
.36739 .58047 L
s
.47369 .59524 m
.47151 .59317 L
s
.37992 .5952 m
.38538 .59495 L
s
.37604 .59429 m
.37992 .5952 L
s
.35785 .59512 m
.35658 .58974 L
s
.37192 .59231 m
.37604 .59429 L
s
.4971 .592 m
.4956 .59423 L
s
.4036 .59411 m
.39973 .5932 L
s
.40907 .59386 m
.4036 .59411 L
s
.4125 .59262 m
.40907 .59386 L
s
.41636 .59353 m
.41334 .57835 L
s
.39973 .5932 m
.39563 .59122 L
s
.47151 .59317 m
.46914 .59002 L
s
.42913 .59294 m
.4336 .57741 L
s
.41572 .5903 m
.4125 .59262 L
s
.60398 .59253 m
.60203 .56963 L
s
.36936 .58916 m
.37192 .59231 L
s
.44373 .59227 m
.44834 .57673 L
s
.44373 .59227 m
.4336 .57741 L
s
.63893 .59202 m
.63703 .59103 L
s
.6407 .59086 m
.63893 .59202 L
s
.45835 .59161 m
.44834 .57673 L
s
.39563 .59122 m
.39312 .58806 L
s
.63703 .59103 m
.63879 .58986 L
s
.63879 .58986 m
.6407 .59086 L
s
.46914 .59002 m
.46824 .58461 L
s
.35658 .58974 m
.354 .58658 L
s
.50777 .58934 m
.50559 .57409 L
s
.51694 .58892 m
.52244 .58867 L
s
.51312 .58801 m
.51694 .58892 L
s
.39312 .58806 m
.39266 .5859 L
s
.50914 .58601 m
.51312 .58801 L
s
.5408 .58783 m
.53699 .58692 L
s
.5463 .58758 m
.5408 .58783 L
s
.54985 .58633 m
.5463 .58758 L
s
.71991 .58725 m
.71967 .57196 L
s
.55365 .58724 m
.55189 .57195 L
s
.53699 .58692 m
.53304 .58492 L
s
.56652 .58665 m
.56404 .56359 L
s
.354 .58658 m
.35165 .5845 L
s
.55328 .58399 m
.54985 .58633 L
s
.57388 .58632 m
.5794 .58606 L
s
.57008 .5854 m
.57388 .58632 L
s
.5794 .58606 m
.58297 .58481 L
s
.50684 .58284 m
.50914 .58601 L
s
.39266 .5859 m
.3938 .58256 L
s
.56617 .5834 m
.57008 .5854 L
s
.53304 .58492 m
.53078 .58174 L
s
.58297 .58481 m
.58645 .58247 L
s
.46824 .58461 m
.46954 .58126 L
s
.61255 .58455 m
.61808 .58429 L
s
.60877 .58363 m
.61255 .58455 L
s
.35165 .5845 m
.34748 .58249 L
s
.61808 .58429 m
.62169 .58304 L
s
.48661 .58377 m
.49581 .58335 L
s
.60296 .58062 m
.60877 .58363 L
s
.63838 .58336 m
.63739 .568 L
s
.49532 .58008 m
.49581 .58335 L
s
.62169 .58304 m
.6233 .57968 L
s
.3938 .58256 m
.39702 .58021 L
s
.34748 .58249 m
.34172 .58166 L
s
.58645 .58247 m
.58799 .57911 L
s
.66054 .58235 m
.65679 .58143 L
s
.66609 .5821 m
.66054 .58235 L
s
.34172 .58166 m
.32889 .58225 L
s
.66974 .58084 m
.66609 .5821 L
s
.53078 .58174 m
.5305 .57956 L
s
.40988 .57961 m
.41399 .58162 L
s
.65679 .58143 m
.65297 .57942 L
s
.46954 .58126 m
.47102 .579 L
s
.69199 .58091 m
.6864 .58007 L
s
.69755 .58066 m
.69199 .58091 L
s
.67335 .57848 m
.66974 .58084 L
s
.70308 .57931 m
.69755 .58066 L
s
.39702 .58021 m
.40047 .57894 L
s
.49314 .57798 m
.49532 .58008 L
s
.6864 .58007 m
.68447 .57797 L
s
.6233 .57968 m
.62249 .56869 L
s
.40598 .57869 m
.40988 .57961 L
s
.5305 .57956 m
.53192 .57619 L
s
.65297 .57942 m
.65094 .57622 L
s
.70488 .57704 m
.70308 .57931 L
s
.58799 .57911 m
.58778 .57692 L
s
.47102 .579 m
.47435 .57664 L
s
.40047 .57894 m
.40598 .57869 L
s
.48912 .57595 m
.49314 .57798 L
s
.68447 .57797 m
.68625 .57569 L
s
.58778 .57692 m
.58561 .57371 L
s
.47435 .57664 m
.47787 .57537 L
s
.65094 .57622 m
.65081 .57402 L
s
.53192 .57619 m
.53535 .57382 L
s
.48525 .57503 m
.48912 .57595 L
s
.68625 .57569 m
.68993 .57443 L
s
.47787 .57537 m
.48525 .57503 L
s
.54831 .57322 m
.55227 .57525 L
s
.5687 .57228 m
.56523 .57465 L
s
.68993 .57443 m
.69919 .5729 L
s
.65081 .57402 m
.65249 .57063 L
s
.53535 .57382 m
.53891 .57255 L
s
.58561 .57371 m
.58169 .57168 L
s
.54447 .57229 m
.54831 .57322 L
s
.69919 .5729 m
.70289 .57162 L
s
.53891 .57255 m
.54447 .57229 L
s
.5723 .571 m
.5687 .57228 L
s
.58169 .57168 m
.57787 .57075 L
s
.70289 .57162 m
.7047 .56933 L
s
.57787 .57075 m
.5723 .571 L
s
.65249 .57063 m
.65609 .56824 L
s
.66914 .56764 m
.67297 .56968 L
s
.7047 .56933 m
.70467 .56822 L
s
.68594 .56687 m
.68415 .56917 L
s
.65609 .56824 m
.65976 .56696 L
s
.70467 .56822 m
.70275 .56609 L
s
.66536 .56671 m
.66914 .56764 L
s
.65976 .56696 m
.66536 .56671 L
s
.6915 .5655 m
.68594 .56687 L
s
.72144 .56523 m
.71959 .56642 L
s
.71959 .56642 m
.7177 .5654 L
s
.70275 .56609 m
.69711 .56524 L
s
.69711 .56524 m
.6915 .5655 L
s
.7177 .5654 m
.71955 .5642 L
s
.71955 .5642 m
.72144 .56523 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
000O0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000R
0?ooo`030000o`3oool0oooo02<0oooo00<0003o0?ooo`3oool01`3oool50000o`030000003oool0
oooo0080oooo0P000?mD0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0403oool3000002D0oooo00<0003o0?ooo`3oool04`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo0`000?l00`3oool0003o0?ooo`040?oo
o`<0003o1@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000002@0oooo00D0003o0?ooo`3o
ool0oooo0000o`020?ooo`D0003o1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool20000o`D0oooo0P000?l:0?ooo`030000o`000000oooo
00<0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000E0?ooo`030000o`3oool0oooo00P0
oooo1P000?l00`3oool0003o0?ooo`020?ooo`<0003o1@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00/0oooo1@000?l00`3oool000000?ooo`030?ooo`030000o`3oool0oooo05<0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`040?ooo`03000000000?l0000000<0oooo00<0003o0?ooo`3oool01`3oool60000o`D0oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`240?ooo`L0003o00<000000?ooo`3oool00`00
00000`3oool0003o0?ooo`030?ooo`80003o1P3oool20000o`H0oooo0`000?l20?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3o
ool0oooo0?ooo`80003o1@3oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo05<0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0JP3oool80000o`L0oooo00<0
003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool00000000000<0oooo
00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`060?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool00P000?l80?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0P000?l60?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool70000o`H0oooo1@000?l00`3oool00000
0?ooo`030?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00
001[0?ooo`030000o`3oool0oooo00D0oooo0P000?l50?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo000000040?ooo`030000o`3oool0003o0080oooo00@0
003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo
0P000?l60?ooo`P0003o1@3oool00`000?l0oooo0?ooo`0E0?ooo`800000103oool00`000?l0oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01P3oool00`000?l000000?ooo`030?ooo`060000o`3oool0oooo0000o`3oool0
003o0`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo0`000?l80?ooo`L0003o103oool00`00
0?l0oooo0000o`030000o`P0oooo00<0003o0?ooo`3oool07`3oool300000080oooo00D000000?oo
o`3oool0oooo0000o`1F0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
06/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l000000?ooo`020?ooo`040000o`3oool0oooo
0?ooo`80003o103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00/0oooo00<0003o
0?ooo`3oool010000?lM0?ooo`030000o`3oool0oooo00X0oooo0P000?l?0?ooo`@000001P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
06/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00H0oooo0`000?l40?ooo`80003o00D000000?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0
oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo02D0oooo00<0003o0?ooo`3oool02@3oool20000o`d0oooo0`00000:0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0K@3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo1`000?l50?ooo`@0003o0P3oool00`00
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0?@3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`1]0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0503oool00`000000
oooo0?ooo`0B0?ooo`P0003o?@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool05@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06h0oooo00<0
003o0?ooo`3oool010000?lH0?ooo`030000003oool0oooo0500oooo1000000J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0KP3oool3
0000oa`0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
04X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo
0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo
000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71156 .61056 m
.7166 .59578 L
s
.63244 .60548 m
.63095 .60429 L
s
.63455 .60457 m
.63244 .60548 L
s
.63306 .60337 m
.63455 .60457 L
s
.63095 .60429 m
.63306 .60337 L
s
.59854 .60176 m
.60464 .57925 L
s
.69254 .60152 m
.68715 .6011 L
s
.69828 .60088 m
.69254 .60152 L
s
.68715 .6011 m
.6821 .59961 L
s
.70078 .5989 m
.69828 .60088 L
s
.6821 .59961 m
.68098 .59735 L
s
.66197 .59913 m
.65656 .5987 L
s
.6659 .59835 m
.66197 .59913 L
s
.65656 .5987 m
.65328 .59736 L
s
.67017 .5965 m
.6659 .59835 L
s
.65328 .59736 m
.65031 .59495 L
s
.68098 .59735 m
.68347 .59536 L
s
.63492 .59701 m
.63931 .58199 L
s
.61504 .59546 m
.61895 .59468 L
s
.60961 .59503 m
.61504 .59546 L
s
.68347 .59536 m
.68742 .59458 L
s
.60628 .59368 m
.60961 .59503 L
s
.65031 .59495 m
.64947 .5916 L
s
.61895 .59468 m
.62167 .59161 L
s
.68742 .59458 m
.69678 .59422 L
s
.69678 .59422 m
.70074 .59343 L
s
.60171 .59005 m
.60628 .59368 L
s
.70074 .59343 m
.70326 .59144 L
s
.4843 .59288 m
.477 .59231 L
s
.48816 .59209 m
.4843 .59288 L
s
.57698 .59248 m
.58088 .5917 L
s
.57153 .59206 m
.57698 .59248 L
s
.477 .59231 m
.47356 .59095 L
s
.49225 .59023 m
.48816 .59209 L
s
.56816 .5907 m
.57153 .59206 L
s
.58088 .5917 m
.58507 .58984 L
s
.62167 .59161 m
.62472 .58083 L
s
.64947 .5916 m
.65011 .58946 L
s
.56426 .59149 m
.56993 .56869 L
s
.70326 .59144 m
.70361 .59037 L
s
.47356 .59095 m
.47032 .58852 L
s
.56506 .58827 m
.56816 .5907 L
s
.55153 .5905 m
.55517 .57535 L
s
.7206 .5895 m
.71843 .59043 L
s
.71843 .59043 m
.71699 .58922 L
s
.70361 .59037 m
.70252 .58808 L
s
.49452 .58823 m
.49225 .59023 L
s
.54425 .58993 m
.53878 .5895 L
s
.54814 .58914 m
.54425 .58993 L
s
.58507 .58984 m
.58774 .58676 L
s
.71916 .58828 m
.7206 .5895 L
s
.53878 .5895 m
.53538 .58814 L
s
.65011 .58946 m
.6529 .58637 L
s
.71699 .58922 m
.71916 .58828 L
s
.5523 .58727 m
.54814 .58914 L
s
.68622 .58679 m
.68372 .5888 L
s
.47032 .58852 m
.4689 .58623 L
s
.53538 .58814 m
.53223 .5857 L
s
.70252 .58808 m
.69744 .58657 L
s
.51507 .58765 m
.52054 .58807 L
s
.6699 .5855 m
.67285 .58794 L
s
.51165 .58628 m
.51507 .58765 L
s
.50593 .58693 m
.50917 .57172 L
s
.69201 .58614 m
.68622 .58679 L
s
.58774 .58676 m
.5883 .5846 L
s
.69744 .58657 m
.69201 .58614 L
s
.6529 .58637 m
.65718 .5845 L
s
.50845 .58384 m
.51165 .58628 L
s
.4689 .58623 m
.46768 .58285 L
s
.53223 .5857 m
.53114 .58232 L
s
.6666 .58414 m
.6699 .5855 L
s
.5883 .5846 m
.58732 .58121 L
s
.65718 .5845 m
.66115 .58371 L
s
.66115 .58371 m
.6666 .58414 L
s
.50731 .58045 m
.50845 .58384 L
s
.45647 .58307 m
.45184 .5672 L
s
.46768 .58285 m
.46871 .57742 L
s
.53114 .58232 m
.53163 .58015 L
s
.44177 .58192 m
.45184 .5672 L
s
.44177 .58192 m
.437 .56603 L
s
.34114 .58174 m
.34681 .58109 L
s
.3282 .58073 m
.34114 .58174 L
s
.58732 .58121 m
.58423 .57875 L
s
.34681 .58109 m
.35076 .5792 L
s
.42704 .58077 m
.437 .56603 L
s
.3282 .58073 m
.33063 .55764 L
s
.53163 .58015 m
.53421 .57703 L
s
.41415 .57976 m
.41655 .56441 L
s
.57141 .57774 m
.56721 .57963 L
s
.48711 .57886 m
.4963 .57958 L
s
.49697 .57632 m
.4963 .57958 L
s
.35076 .5792 m
.35287 .57717 L
s
.40677 .57918 m
.40123 .57875 L
s
.41063 .57838 m
.40677 .57918 L
s
.58423 .57875 m
.58085 .57737 L
s
.40123 .57875 m
.3977 .57737 L
s
.55124 .57615 m
.55439 .57862 L
s
.41466 .57649 m
.41063 .57838 L
s
.57535 .57694 m
.57141 .57774 L
s
.46871 .57742 m
.47117 .57429 L
s
.58085 .57737 m
.57535 .57694 L
s
.3977 .57737 m
.39432 .5749 L
s
.37721 .57687 m
.38276 .57731 L
s
.35287 .57717 m
.35512 .57404 L
s
.53421 .57703 m
.53838 .57514 L
s
.37365 .57549 m
.37721 .57687 L
s
.49558 .57399 m
.49697 .57632 L
s
.54783 .57477 m
.55124 .57615 L
s
.36796 .57615 m
.36994 .56074 L
s
.37023 .57302 m
.37365 .57549 L
s
.53838 .57514 m
.54231 .57433 L
s
.39432 .5749 m
.39294 .57147 L
s
.54231 .57433 m
.54783 .57477 L
s
.47117 .57429 m
.47344 .57224 L
s
.35512 .57404 m
.35578 .56856 L
s
.49233 .57151 m
.49558 .57399 L
s
.3688 .56958 m
.37023 .57302 L
s
.47344 .57224 m
.47756 .57034 L
s
.48886 .57012 m
.49233 .57151 L
s
.39294 .57147 m
.39326 .56928 L
s
.47756 .57034 m
.48147 .56953 L
s
.48147 .56953 m
.48886 .57012 L
s
.39326 .56928 m
.39559 .56612 L
s
.35578 .56856 m
.35432 .5651 L
s
.41266 .56523 m
.41603 .56773 L
s
.39559 .56612 m
.39963 .5642 L
s
.40911 .56383 m
.41266 .56523 L
s
.35432 .5651 m
.35272 .56274 L
s
.39963 .5642 m
.40352 .56339 L
s
.40352 .56339 m
.40911 .56383 L
s
.35272 .56274 m
.34924 .56023 L
s
.34924 .56023 m
.34375 .55867 L
s
.34375 .55867 m
.33063 .55764 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0J@3oool60000oa80oooo00<000000?ooo`3oool08@3oool3000004`0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`1Z0?ooo`030000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0oooo00L0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`080?ooo`04000000000?l0003o0000oaL0oooo
0`00001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0JP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool01P3oool30000o`030000003oool0oooo00<0003o1`3oool00`000?l0oooo0?oo
o`070?ooo`<00000E`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool01@000000oooo0?ooo`3o
ool0003o00H0oooo0P000?l40?ooo`030000o`3oool00000008000001P3oool20000oal0oooo00<0
003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool010000000oooo0?ooo`00
0?l60?ooo`030000o`3oool0003o0080oooo0P000?l00`000000oooo0?ooo`060?ooo`030000o`3o
ool0oooo00<0003o1P3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0300oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Y
0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`L0oooo00<0003o
0?ooo`3oool0103oool00`000000003o0?ooo`050?ooo`040000o`3oool0oooo0000o`80000000<0
003o0?ooo`000?l01P3oool20000o`H0oooo0P000?l40?ooo`030000o`3oool0oooo00T0oooo0`00
0?l70?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0000o`040000o`<0oooo0P000?l50?ooo`030000o`3oool0
oooo00<0oooo00L0003o00000000000000000000o`3oool0003o0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1P3oool30000o`<0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030000obh0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`1Z0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool03`3oool60000o`030000003o
ool0oooo0080000000<0003o0?ooo`3oool00P3oool20000o`80oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo0P000?l30?ooo`<0003o0`3oool20000o`H0oooo00<0003o0?ooo`3oool08`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo06X0oooo2@000?lI0?ooo`80000000<0oooo0000o`3oool0103oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01H0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<0
00000?ooo`3oool02`3oool01@000?l0oooo0?ooo`3oool0003o00h0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`H0003o2`3oool2000005/0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool60000o`<0oooo0`000?l50?ooo`040000o`3o
ool0oooo0?ooo`80003o1`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo
0?ooo`020?ooo`<0003o0`0000000`000?l0oooo000000030?ooo`030000o`3oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0@0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0?0?ooo`H0003o0`3oool00`000?l0oooo0000
o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02P3oool4000000<0oooo00D0
003o0?ooo`3oool000000?ooo`030000oeD0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0B0?ooo`H0003o6`3oool00`000?l0oooo0?oo
o`050000o`H0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`070?ooo`<000001P3oool20000o`80oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0440oooo00<0003o0?ooo`000?l01@000?l50?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool3000000<0oooo1P000?l50?ooo`03000000000?l0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`100?oo
o`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool30000o`<000000P000?l30?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0@03oool00`000?l0oooo0?ooo`0A0?ooo`<000000P000?l60?ooo`L0003o1@3oool00`000?l0
oooo0000001F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0@03oool00`000?l0oooo0?ooo`090?ooo`80003o0P3oool4000001L0oooo
00@0003o0?ooo`3oool00000E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000K0?ooo`040000o`3oool0oooo000005H0
oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`1:0?ooo`<000007@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`170?ooo`<00000803oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo0580oooo00<0
00000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3
000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?oo
o`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<0
0000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool00000
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000
003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo
00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3o
ool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool2
00000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo
0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?oo
o`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?oo
o`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3o
ool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo
0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo
0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<0
00000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<00000
0?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?oo
o`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3o
ool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03o
ool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3o
ool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000
oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo
00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<0
00000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<00000
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?oo
o`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3o
ool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0
<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03o
ool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000
oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00
001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?oo
o`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3o
ool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3o
ool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3o
ool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo
01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000
oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo
0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`00
00270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`03
0000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00
603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?oo
o`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@000002
0?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?oo
o`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<0
00000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=
0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3o
ool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000
003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3o
ool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3o
ool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0
`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03o
ool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103o
ool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700
oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0
oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool0
0000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool0
0`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool0
04L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000
oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo
0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool0
0`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool0
04h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo
00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000
oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo
0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo1000
00030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?
0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`04
0000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000
003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo
00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P00
00000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3o
ool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
06<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0
oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo
001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo1000
00090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?oo
o`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3o
ool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003o
ool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0
oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool40000
02P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0
oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo
001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<00000
0?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?oo
o`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3o
ool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?oo
o`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?oo
o`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?oo
o`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`80
0000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3o
ool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3o
ool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool0
0`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo
0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0
oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo
0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00
001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo10000020
0?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?oo
o`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000
003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3o
ool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo
0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo
03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0
oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo
1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000
002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;
0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?oo
o`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?oo
o`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?oo
o`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?oo
o`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3o
ool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0
oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C
0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?oo
o`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.69558 .63207 m
.70548 .61839 L
s
.68625 .62115 m
.68055 .62108 L
s
.68932 .61953 m
.68625 .62115 L
s
.68055 .62108 m
.67555 .62003 L
s
.67555 .62003 m
.67123 .618 L
s
.67123 .618 m
.67094 .61568 L
s
.62151 .61777 m
.62049 .61643 L
s
.62386 .61713 m
.62151 .61777 L
s
.62284 .61579 m
.62386 .61713 L
s
.62049 .61643 m
.62284 .61579 L
s
.67094 .61568 m
.67401 .61405 L
s
.65211 .61513 m
.64707 .61408 L
s
.65615 .61484 m
.65211 .61513 L
s
.66088 .61357 m
.65615 .61484 L
s
.68713 .61453 m
.69117 .61424 L
s
.67806 .61376 m
.68713 .61453 L
s
.69117 .61424 m
.69426 .61261 L
s
.64707 .61408 m
.64438 .61238 L
s
.67401 .61405 m
.67806 .61376 L
s
.71144 .61281 m
.70905 .61345 L
s
.70905 .61345 m
.7081 .61211 L
s
.71049 .61146 m
.71144 .61281 L
s
.69426 .61261 m
.69497 .61162 L
s
.64438 .61238 m
.64237 .60969 L
s
.7081 .61211 m
.71049 .61146 L
s
.69497 .61162 m
.69472 .60928 L
s
.59005 .61009 m
.60381 .58892 L
s
.62684 .60984 m
.63629 .59579 L
s
.64237 .60969 m
.64272 .60634 L
s
.69472 .60928 m
.69039 .60722 L
s
.6796 .60609 m
.67652 .60773 L
s
.69039 .60722 m
.68535 .60615 L
s
.64272 .60634 m
.64408 .60434 L
s
.68535 .60615 m
.6796 .60609 L
s
.6082 .60594 m
.61226 .60565 L
s
.60311 .60488 m
.6082 .60594 L
s
.61226 .60565 m
.61595 .603 L
s
.66443 .60288 m
.66642 .6056 L
s
.60036 .60316 m
.60311 .60488 L
s
.64408 .60434 m
.64783 .60168 L
s
.59721 .59907 m
.60036 .60316 L
s
.61595 .603 m
.62265 .5929 L
s
.66175 .60117 m
.66443 .60288 L
s
.64783 .60168 m
.65259 .60038 L
s
.65667 .60009 m
.66175 .60117 L
s
.65259 .60038 m
.65667 .60009 L
s
.57238 .59845 m
.57645 .59816 L
s
.56724 .59737 m
.57238 .59845 L
s
.57645 .59816 m
.58117 .59685 L
s
.56444 .59564 m
.56724 .59737 L
s
.58117 .59685 m
.58482 .59417 L
s
.56037 .59593 m
.57386 .5744 L
s
.56227 .59289 m
.56444 .59564 L
s
.58482 .59417 m
.58613 .59214 L
s
.54832 .59341 m
.55718 .57907 L
s
.58613 .59214 m
.58636 .58872 L
s
.54141 .59197 m
.53623 .59088 L
s
.54549 .59167 m
.54141 .59197 L
s
.5502 .59036 m
.54549 .59167 L
s
.53623 .59088 m
.53339 .58914 L
s
.53339 .58914 m
.53116 .58637 L
s
.58636 .58872 m
.58422 .58595 L
s
.48161 .58751 m
.47463 .58606 L
s
.48569 .58722 m
.48161 .58751 L
s
.51368 .58617 m
.51889 .58726 L
s
.49037 .5859 m
.48569 .58722 L
s
.53116 .58637 m
.53128 .58292 L
s
.51081 .58441 m
.51368 .58617 L
s
.47463 .58606 m
.47171 .5843 L
s
.58422 .58595 m
.58143 .58419 L
s
.49331 .58421 m
.49037 .5859 L
s
.57214 .5834 m
.56739 .58472 L
s
.50854 .58162 m
.51081 .58441 L
s
.50497 .58434 m
.51351 .56984 L
s
.47171 .5843 m
.46938 .58152 L
s
.58143 .58419 m
.57624 .5831 L
s
.57624 .5831 m
.57214 .5834 L
s
.53128 .58292 m
.53253 .58086 L
s
.55307 .57937 m
.55527 .58217 L
s
.50861 .57816 m
.50854 .58162 L
s
.46938 .58152 m
.46879 .57909 L
s
.53253 .58086 m
.53614 .57813 L
s
.55022 .5776 m
.55307 .57937 L
s
.46879 .57909 m
.46878 .57561 L
s
.53614 .57813 m
.54088 .5768 L
s
.545 .5765 m
.55022 .5776 L
s
.54088 .5768 m
.545 .5765 L
s
.48933 .57411 m
.49811 .57595 L
s
.49992 .57284 m
.49811 .57595 L
s
.46878 .57561 m
.47172 .57041 L
s
.45763 .57444 m
.45868 .55826 L
s
.49937 .57038 m
.49992 .57284 L
s
.44349 .57148 m
.45868 .55826 L
s
.44349 .57148 m
.44441 .55525 L
s
.47172 .57041 m
.47526 .56764 L
s
.49706 .56755 m
.49937 .57038 L
s
.4293 .56851 m
.44441 .55525 L
s
.47526 .56764 m
.47821 .56592 L
s
.49414 .56575 m
.49706 .56755 L
s
.47821 .56592 m
.48294 .56456 L
s
.41685 .56591 m
.4247 .55108 L
s
.48707 .56426 m
.49414 .56575 L
s
.48294 .56456 m
.48707 .56426 L
s
.40972 .56441 m
.40436 .56329 L
s
.41384 .56411 m
.40972 .56441 L
s
.41852 .56275 m
.41384 .56411 L
s
.40436 .56329 m
.40133 .56149 L
s
.40133 .56149 m
.39884 .55862 L
s
.38105 .55841 m
.38644 .55954 L
s
.34907 .55875 m
.35372 .55738 L
s
.34314 .55868 m
.34907 .55875 L
s
.33048 .55604 m
.34314 .55868 L
s
.39884 .55862 m
.39869 .55506 L
s
.37799 .5566 m
.38105 .55841 L
s
.35372 .55738 m
.35657 .55564 L
s
.37545 .55372 m
.37799 .5566 L
s
.37205 .55653 m
.37955 .54154 L
s
.33048 .55604 m
.34123 .53344 L
s
.35657 .55564 m
.35994 .55282 L
s
.39869 .55506 m
.39978 .55293 L
s
.42055 .55139 m
.42301 .55428 L
s
.37525 .55014 m
.37545 .55372 L
s
.39978 .55293 m
.40324 .55011 L
s
.35994 .55282 m
.36257 .54748 L
s
.41751 .54956 m
.42055 .55139 L
s
.40324 .55011 m
.40795 .54873 L
s
.41211 .54842 m
.41751 .54956 L
s
.40795 .54873 m
.41211 .54842 L
s
.36257 .54748 m
.36234 .54387 L
s
.36234 .54387 m
.36158 .54133 L
s
.36158 .54133 m
.359 .53839 L
s
.359 .53839 m
.35405 .53615 L
s
.35405 .53615 m
.34123 .53344 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo06`0oooo0`000?l80?ooo`030000003oool0oooo04D0oooo
0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<0
00000?ooo`0000008@3oool00`000000oooo0?ooo`1[0?ooo`040000o`3oool0oooo0?ooo`<0003o
1P3oool00`000000oooo0?ooo`110?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1[0?ooo`030000o`3o
ool0oooo00@0oooo0P000?l50?ooo`030000003oool0oooo03d0oooo0`00000g0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0JP3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0>@3oool3
000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`00
0000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l000000?ooo`0f0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo06X0oooo00<0003o0?ooo`3oool0203oool00`000?l0
oooo0?ooo`020?ooo`040000o`3oool0oooo000003<0oooo0`0000100?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0JP3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo000000050?oo
o`L0003o8`3oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1Y0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000?l01`3oool20000
oah0oooo0`0000160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo0`00001Z0?ooo`<0003o1`3oool00`000?l0oooo0?ooo`030?ooo`80003o1@3oool00`000000
oooo0000o`080?ooo`80003o1`3oool00`000?l0oooo0?ooo`0A0?ooo`<00000B@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo06`0oooo
1`000?l60?ooo`040000o`3oool0003o0000o`@0oooo00<000000?ooo`000?l01`3oool00`000?l0
oooo0?ooo`050?ooo`80003o103oool00`000?l0oooo0?ooo`090?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo07h0oooo
0P000?l30?ooo`03000000000?l0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0000o`030?ooo`80003o1`3oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`03000000000?l0003o0080oooo0`00
0?l50?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0000o`040?ooo`<00000E03o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08D0oooo00H000000?ooo`000?l0003o0?ooo`000?l50?ooo`060000o`3oool0oooo0?ooo`00
0?l0oooo0P000?l0103oool0003o0?ooo`3oool300000080oooo1`000?m>0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P000?l30?ooo`030000o`0000000000
00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`0:0?ooo`030000o`3oool000000080000000<0003o0?ooo`3oool00`3oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0A@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0203oool3000000<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`80003o0P3oool01@000?l0oooo0?ooo`3oool0003o01L0oooo00<0003o0?ooo`3o
ool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000000/0oooo00<0003o0?ooo`3oool0
1P3oool30000o`<0oooo00<0003o0?ooo`3oool02@3oool20000o`T0oooo00<0003o0?ooo`3oool0
;`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000>0?ooo`030000o`3oool0oooo00/0oooo0P00
0?l90?ooo`80003o0P3oool30000o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`3oool0;`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08`0oooo0P00000A0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool2
0000o`L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo
0140oooo00<0003o0?ooo`3oool01@3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l01`3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo1`000?l/0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo0180oooo1`000?l70?ooo`<0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0V0?ooo`<000000P3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
08`0oooo00<000000?ooo`3oool0:03oool20000o`@0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool06`3oool40000
00H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo10000?l50?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140
oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`80003o1`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`090?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03oool70000o`D0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo0`00
000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0o0?ooo`80003o1P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo0080oooo0P000?l300000080003o503oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0?`3oool00`000?l0oooo0000o`050?ooo`030000o`3oool0oooo0080oooo00@0003o0?oo
o`3oool0oooo100000050?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
03h0oooo00@0003o0?ooo`3oool0oooo1@000?l50?ooo`060000o`00000000000000003oool0003o
1`3oool00`000?l0oooo0?ooo`020?ooo`<0003o3@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3o
ool00`000?l0oooo0?ooo`090?ooo`<000000`3oool00`000?l0oooo0?ooo`0:0?ooo`040000o`3o
ool0oooo0?ooo`@0003o2P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?oo
o`070?ooo`<0000000<0oooo0000o`3oool0103oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3o
ool0oooo0080oooo0P000?l50?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000;0?ooo`040000o`3oool0
oooo0?ooo`80003o103oool90000o`@0oooo0P000?l60?ooo`030000003oool0oooo0540oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`10
0?ooo`@00000103oool30000o`P0oooo0`000?l50?ooo`030000o`3oool0oooo01@0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03h0oooo0`0000090?ooo`030000o`3oool0oooo00l0oooo0`000?l40?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>`3oool300000240oooo10000?l50?ooo`030000o`3oool0oooo00T0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03P0oooo0`00000/0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03D0oooo0`00000_0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0340oooo1000000a0?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02h0oooo0`00000d0?ooo`030000o`3oool0oooo0100oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?oo
o`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q
0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<0
0000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<0
0000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000
IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0
oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@0
00000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
3P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo
0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool40000
0440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo
0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.67289 .65099 m
.68708 .63892 L
s
.66775 .63933 m
.66232 .6386 L
s
.67125 .63813 m
.66775 .63933 L
s
.66232 .6386 m
.65789 .637 L
s
.65789 .637 m
.65445 .63452 L
s
.69469 .63423 m
.69219 .63457 L
s
.69219 .63457 m
.69175 .63316 L
s
.65445 .63452 m
.65498 .63223 L
s
.69425 .63282 m
.69469 .63423 L
s
.67485 .63323 m
.67836 .63202 L
s
.67088 .63303 m
.67485 .63323 L
s
.69175 .63316 m
.69425 .63282 L
s
.66246 .63122 m
.67088 .63303 L
s
.65498 .63223 m
.65849 .63102 L
s
.67836 .63202 m
.67938 .63114 L
s
.65849 .63102 m
.66246 .63122 L
s
.67938 .63114 m
.67995 .62885 L
s
.64107 .62968 m
.63709 .62948 L
s
.64606 .629 m
.64107 .62968 L
s
.63709 .62948 m
.63261 .62786 L
s
.67995 .62885 m
.67653 .62634 L
s
.60669 .62841 m
.60617 .62699 L
s
.60918 .62807 m
.60669 .62841 L
s
.60866 .62665 m
.60918 .62807 L
s
.63261 .62786 m
.63061 .62589 L
s
.60617 .62699 m
.60866 .62665 L
s
.67653 .62634 m
.67208 .62472 L
s
.63061 .62589 m
.62961 .62304 L
s
.6666 .62397 m
.66308 .6252 L
s
.67208 .62472 m
.6666 .62397 L
s
.62961 .62304 m
.63111 .61983 L
s
.65317 .61907 m
.65413 .62193 L
s
.61459 .62134 m
.62859 .60882 L
s
.63111 .61983 m
.63312 .61805 L
s
.65119 .61708 m
.65317 .61907 L
s
.63312 .61805 m
.63764 .61592 L
s
.57891 .61718 m
.59963 .59823 L
s
.64669 .61543 m
.65119 .61708 L
s
.63764 .61592 m
.64267 .61523 L
s
.60197 .61553 m
.60646 .61339 L
s
.59795 .61532 m
.60197 .61553 L
s
.64267 .61523 m
.64669 .61543 L
s
.59339 .61367 m
.59795 .61532 L
s
.59133 .61167 m
.59339 .61367 L
s
.60646 .61339 m
.61644 .60438 L
s
.5897 .60731 m
.59133 .61167 L
s
.56988 .60391 m
.57492 .60321 L
s
.56583 .60371 m
.56988 .60391 L
s
.5612 .60203 m
.56583 .60371 L
s
.57492 .60321 m
.57941 .60105 L
s
.55909 .60001 m
.5612 .60203 L
s
.57941 .60105 m
.58138 .59922 L
s
.55794 .59706 m
.55909 .60001 L
s
.55502 .5998 m
.57568 .58044 L
s
.58138 .59922 m
.58281 .59592 L
s
.58281 .59592 m
.5817 .59296 L
s
.54416 .59587 m
.55783 .58295 L
s
.54201 .59383 m
.53793 .59362 L
s
.54707 .59312 m
.54201 .59383 L
s
.53793 .59362 m
.53325 .59192 L
s
.5817 .59296 m
.5796 .59091 L
s
.53325 .59192 m
.53108 .58987 L
s
.5796 .59091 m
.57495 .58921 L
s
.53108 .58987 m
.52988 .58689 L
s
.57086 .589 m
.56578 .58971 L
s
.57495 .58921 m
.57086 .589 L
s
.52988 .58689 m
.53121 .58354 L
s
.51284 .58455 m
.51757 .58625 L
s
.55372 .58274 m
.55488 .58574 L
s
.51065 .58248 m
.51284 .58455 L
s
.53121 .58354 m
.53315 .58168 L
s
.55157 .58066 m
.55372 .58274 L
s
.5094 .57947 m
.51065 .58248 L
s
.48498 .58213 m
.48086 .58192 L
s
.49005 .58141 m
.48498 .58213 L
s
.48086 .58192 m
.47449 .57963 L
s
.50495 .58169 m
.51842 .56855 L
s
.53315 .58168 m
.53764 .57945 L
s
.49353 .58012 m
.49005 .58141 L
s
.54686 .57894 m
.55157 .58066 L
s
.47449 .57963 m
.47224 .57754 L
s
.5107 .57608 m
.5094 .57947 L
s
.53764 .57945 m
.54274 .57873 L
s
.54274 .57873 m
.54686 .57894 L
s
.47224 .57754 m
.47092 .57452 L
s
.47092 .57452 m
.4712 .57206 L
s
.49319 .56972 m
.50117 .57262 L
s
.50405 .56979 m
.50117 .57262 L
s
.4712 .57206 m
.47243 .56864 L
s
.50438 .56732 m
.50405 .56979 L
s
.47243 .56864 m
.47716 .5639 L
s
.50311 .56425 m
.50438 .56732 L
s
.46184 .5661 m
.46861 .55034 L
s
.50087 .56213 m
.50311 .56425 L
s
.47716 .5639 m
.48163 .56163 L
s
.49445 .55979 m
.50087 .56213 L
s
.48163 .56163 m
.48515 .56031 L
s
.44891 .56143 m
.46861 .55034 L
s
.44891 .56143 m
.45558 .54557 L
s
.48515 .56031 m
.49028 .55957 L
s
.49028 .55957 m
.49445 .55979 L
s
.43591 .55672 m
.45558 .54557 L
s
.42447 .55259 m
.43754 .53898 L
s
.42212 .55044 m
.41791 .55022 L
s
.42725 .54969 m
.42212 .55044 L
s
.41791 .55022 m
.41298 .54843 L
s
.41298 .54843 m
.4106 .54627 L
s
.4106 .54627 m
.40915 .54313 L
s
.40915 .54313 m
.41027 .5396 L
s
.39149 .54066 m
.39646 .54246 L
s
.4333 .53876 m
.43472 .54192 L
s
.38907 .53848 m
.39149 .54066 L
s
.41027 .5396 m
.41212 .53764 L
s
.43094 .53657 m
.4333 .53876 L
s
.38757 .53531 m
.38907 .53848 L
s
.38317 .53765 m
.39602 .5238 L
s
.41212 .53764 m
.41656 .53529 L
s
.35936 .53691 m
.36451 .53615 L
s
.35343 .53608 m
.35936 .53691 L
s
.42599 .53476 m
.43094 .53657 L
s
.36451 .53615 m
.36799 .53479 L
s
.34165 .53185 m
.35343 .53608 L
s
.38865 .53174 m
.38757 .53531 L
s
.41656 .53529 m
.42174 .53453 L
s
.36799 .53479 m
.37238 .53244 L
s
.42174 .53453 m
.42599 .53476 L
s
.37238 .53244 m
.37693 .52749 L
s
.34165 .53185 m
.36056 .51084 L
s
.37693 .52749 m
.37799 .52389 L
s
.37799 .52389 m
.37813 .52128 L
s
.37813 .52128 m
.3766 .51804 L
s
.3766 .51804 m
.37244 .51519 L
s
.37244 .51519 m
.36056 .51084 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool010000000oooo0?ooo`3oool3
0000of80oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
003o00<0oooo0`000?mL0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0EP3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1_0?ooo`030000o`3oool0000000L0
oooo00<0003o0?ooo`3oool0D@3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1^0?ooo`050000o`3oool0oooo0?ooo`00
00001P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04P0oooo0`00000U0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000
KP3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`160?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`800000KP3oool00`000?l0oooo0?ooo`050?ooo`050000003o
ool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`130?ooo`<00000:`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?oo
o`1/0?ooo`80003o203oool00`000000oooo0000o`050?ooo`030000o`3oool0oooo0440oooo0`00
000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<00000
0?ooo`000000803oool00`000000oooo0?ooo`1^0?ooo`80003o1`3oool00`000000003o0?ooo`03
0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0<P3oool300000340oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?oo
o`030000003oool0oooo0700oooo20000?l00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo
00P0oooo0P000?l00`3oool0003o0000o`020000obd0oooo0`00000d0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0
oooo00H000000?ooo`3oool0003o0?ooo`000?l70?ooo`80003o1P3oool00`000?l0oooo0000o`0X
0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool00P3oool30000o`<0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0T0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0280oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0F0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool01`3o
ool60000o`P0oooo0P000?l50?ooo`030000o`3oool0oooo00h0oooo0`0000130?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool0
0`000000oooo0?ooo`0:0?ooo`030000o`3oool0oooo00D0oooo0P000?l00`3oool0003o0?ooo`02
0?ooo`80003o3P3oool3000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool300000840oooo00<000000?ooo`3oool03`3oool20000o`80oooo00<0003o0?oo
o`3oool00P000?l00`3oool0003o0?ooo`0:0?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3o
ool0303oool20000o`@0oooo0`000?l20?ooo`030000o`3oool0oooo00L0oooo0`00001<0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
P`3oool00`000000oooo0?ooo`0@0?ooo`80003o103oool00`000?l0oooo0?ooo`030?ooo`800000
1@000?m=0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q03oool00`000000oooo0?ooo`0D0?ooo`040000o`3oool0oooo0?ooo`800000
0`000?l50?ooo`80003oB`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool04`3oool01P000?l000000000
00000000oooo0000o`T0oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000000<0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`0000060?ooo`030000o`3o
ool0oooo00D0oooo0P000?l20?ooo`050000o`3oool0oooo0?ooo`000?l0AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0203oool3000000P0oooo00<0003o0?ooo`3oool0203oool20000o`<0oooo00<0
003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000000`0oooo00<0003o
0?ooo`3oool02`3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`030000
0100oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`80003o2@3oool50000
ocX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`800000503oool60000o`@0oooo00<0003o0?ooo`000?l0203oool00`000?l0
oooo0?ooo`030?ooo`80003o203oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0200oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0003o00D0oooo
00<0003o0?ooo`3oool0;@3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0Q0?ooo`80003o0`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:`3oool300000080oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0103oool20000o`@0oooo1P000?lV
0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool20000o`<0oooo00<0003o0?oo
o`3oool00`3oool20000o`D0oooo00<0003o0?ooo`3oool0803oool3000000X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02X0oooo0`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool07@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01@0oooo0`00000B0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0`0?ooo`80003o1`3oool20000o`@0oooo00<0003o0?ooo`3oool04P3o
ool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo1`000?l50?ooo`030000o`3oool0
oooo00l0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00`3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03`0
oooo0P000?l80?ooo`040000o`3oool0oooo0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0>`3oool00`000?l0oooo0000o`060?ooo`80003o00D0oooo00000000000000000000o`0U0?oo
o`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`03
0000003oool0oooo03X0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`040000o`0000000000
00000080oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`000000000000800000103oool00`000?l0oooo0?ooo`040?oo
o`H0003o7@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000000L0oooo00<0003o0?ooo`3o
ool00P3oool30000o`D0oooo00<0003o0?ooo`3oool0703oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool3000000T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo01/0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000B0?ooo`030000o`3o
ool0oooo00T0oooo1@000?lG0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000303oool2
0000o`L0oooo0P000?l?0?ooo`030000o`3oool0oooo01D0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0340oooo1000000J0?ooo`D0003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
01D0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00000U0?ooo`030000o`3oool0003o00L0
003o103oool20000oa80oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00000X0?ooo`030000
o`3oool0oooo00/0oooo0P000?lB0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000;03o
ool30000o`80oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0
oooo02D0oooo0`00000b0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo
0240oooo1000000k0?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0
oooo0`00000n0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0K0?ooo`<00000@03oool00`000?l0oooo0?ooo`0K0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`0000120?ooo`030000o`3oool0oooo01d0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0
oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P
0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00
000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3o
ool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0
oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool20000
02D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00
001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3o
ool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900
oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool5
00000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P00
00090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo
00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo
0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00
001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`80
0000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo
0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`800000
2`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3o
ool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0
oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0
oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo
00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000
D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03o
ool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?oo
o`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@00000
1@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3o
ool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool0
06X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<0
00000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?oo
o`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000
<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool0
0`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool20000
00d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool50000
0480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo
09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00
000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V
0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?oo
o`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000
003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3o
ool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool4
00000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool40000
08@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo
00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00
000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?oo
o`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0
=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03o
ool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool00000
02<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool40000
0;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`00
0000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`800000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P00
00050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool5
00000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool30000
0080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.64461 .66669 m
.66239 .65664 L
s
.64372 .65479 m
.63876 .65344 L
s
.64749 .65403 m
.64372 .65479 L
s
.63876 .65344 m
.63505 .65137 L
s
.6713 .65298 m
.66879 .65302 L
s
.66879 .65302 m
.66886 .6516 L
s
.67136 .65156 m
.6713 .65298 L
s
.66886 .6516 m
.67136 .65156 L
s
.63505 .65137 m
.63261 .64856 L
s
.65264 .6497 m
.65643 .64894 L
s
.64891 .64904 m
.65264 .6497 L
s
.64146 .6463 m
.64891 .64904 L
s
.65643 .64894 m
.65772 .64821 L
s
.63261 .64856 m
.63391 .64641 L
s
.65772 .64821 m
.65905 .64605 L
s
.63391 .64641 m
.6377 .64564 L
s
.6377 .64564 m
.64146 .6463 L
s
.65905 .64605 m
.65665 .64322 L
s
.65665 .64322 m
.65294 .64112 L
s
.62141 .64229 m
.61764 .64163 L
s
.62645 .64222 m
.62141 .64229 L
s
.61764 .64163 m
.61389 .63953 L
s
.65294 .64112 m
.64794 .63976 L
s
.64794 .63976 m
.64414 .64053 L
s
.61389 .63953 m
.61264 .63738 L
s
.61264 .63738 m
.61267 .63449 L
s
.58864 .63701 m
.58863 .63556 L
s
.59117 .63697 m
.58864 .63701 L
s
.59116 .63552 m
.59117 .63697 L
s
.63675 .63342 m
.63667 .63632 L
s
.58863 .63556 m
.59116 .63552 L
s
.61267 .63449 m
.61524 .63155 L
s
.63553 .63126 m
.63675 .63342 L
s
.61524 .63155 m
.61779 .63006 L
s
.63177 .62913 m
.63553 .63126 L
s
.59875 .63106 m
.61664 .62055 L
s
.61779 .63006 m
.62289 .62853 L
s
.62797 .62845 m
.63177 .62913 L
s
.62289 .62853 m
.62797 .62845 L
s
.58857 .6239 m
.59366 .62236 L
s
.58474 .62322 m
.58857 .6239 L
s
.5809 .62107 m
.58474 .62322 L
s
.56562 .62277 m
.59234 .60679 L
s
.59366 .62236 m
.60646 .61478 L
s
.5796 .61888 m
.5809 .62107 L
s
.57955 .61443 m
.5796 .61888 L
s
.56149 .60874 m
.56663 .60866 L
s
.55761 .60804 m
.56149 .60874 L
s
.56663 .60866 m
.57175 .60709 L
s
.55369 .60585 m
.55761 .60804 L
s
.57175 .60709 m
.5743 .60555 L
s
.55234 .60362 m
.55369 .60585 L
s
.5743 .60555 m
.57684 .6025 L
s
.55226 .6006 m
.55234 .60362 L
s
.54845 .60292 m
.57534 .58655 L
s
.57684 .6025 m
.5768 .59948 L
s
.5768 .59948 m
.57548 .59723 L
s
.53924 .59777 m
.5571 .58682 L
s
.57548 .59723 m
.57156 .59501 L
s
.53786 .59551 m
.53395 .59481 L
s
.54305 .59543 m
.53786 .59551 L
s
.57156 .59501 m
.56766 .59431 L
s
.53395 .59481 m
.52997 .59258 L
s
.56766 .59431 m
.56247 .59438 L
s
.52997 .59258 m
.52858 .59031 L
s
.52858 .59031 m
.52845 .58724 L
s
.55317 .58611 m
.55325 .58918 L
s
.52845 .58724 m
.53093 .58413 L
s
.5518 .58382 m
.55317 .58611 L
s
.51259 .58286 m
.51662 .58511 L
s
.53093 .58413 m
.53348 .58255 L
s
.54782 .58156 m
.5518 .58382 L
s
.51117 .58056 m
.51259 .58286 L
s
.53348 .58255 m
.53865 .58092 L
s
.54388 .58085 m
.54782 .58156 L
s
.53865 .58092 m
.54388 .58085 L
s
.51101 .57746 m
.51117 .58056 L
s
.50586 .57909 m
.52369 .56789 L
s
.51347 .57431 m
.51101 .57746 L
s
.48608 .57705 m
.4821 .57633 L
s
.49132 .57698 m
.48608 .57705 L
s
.4952 .57614 m
.49132 .57698 L
s
.4821 .57633 m
.47664 .5733 L
s
.47664 .5733 m
.47516 .57097 L
s
.47516 .57097 m
.47493 .56784 L
s
.49854 .56591 m
.50534 .56974 L
s
.50917 .56732 m
.50534 .56974 L
s
.47493 .56784 m
.47607 .56546 L
s
.51036 .56494 m
.50917 .56732 L
s
.47607 .56546 m
.47849 .56226 L
s
.5102 .56178 m
.51036 .56494 L
s
.47849 .56226 m
.48483 .5582 L
s
.50875 .55942 m
.5102 .56178 L
s
.50328 .55632 m
.50875 .55942 L
s
.46894 .55844 m
.4812 .54381 L
s
.48483 .5582 m
.49003 .55652 L
s
.49003 .55652 m
.49395 .55567 L
s
.49926 .55559 m
.50328 .55632 L
s
.49395 .55567 m
.49926 .55559 L
s
.45783 .55222 m
.4812 .54381 L
s
.45783 .55222 m
.47003 .53748 L
s
.44663 .54595 m
.47003 .53748 L
s
.43677 .54044 m
.45455 .52871 L
s
.4352 .53802 m
.4311 .53727 L
s
.44056 .53794 m
.4352 .53802 L
s
.4311 .53727 m
.42684 .53488 L
s
.42684 .53488 m
.42525 .53245 L
s
.42525 .53245 m
.42492 .52916 L
s
.45044 .52795 m
.45072 .53124 L
s
.42492 .52916 m
.42729 .52583 L
s
.44888 .5255 m
.45044 .52795 L
s
.40823 .52447 m
.41254 .52688 L
s
.42729 .52583 m
.42983 .52413 L
s
.44461 .52308 m
.44888 .5255 L
s
.40661 .52201 m
.40823 .52447 L
s
.42983 .52413 m
.43507 .5224 L
s
.44048 .52231 m
.44461 .52308 L
s
.43507 .5224 m
.44048 .52231 L
s
.40624 .51868 m
.40661 .52201 L
s
.40101 .52043 m
.41875 .50843 L
s
.40858 .51531 m
.40624 .51868 L
s
.37749 .51662 m
.38291 .51654 L
s
.37185 .51504 m
.37749 .51662 L
s
.38291 .51654 m
.38688 .51564 L
s
.38688 .51564 m
.39211 .51389 L
s
.36156 .50932 m
.37185 .51504 L
s
.39211 .51389 m
.39842 .50959 L
s
.39842 .50959 m
.40076 .50617 L
s
.36156 .50932 m
.38802 .49101 L
s
.40076 .50617 m
.40184 .50361 L
s
.40184 .50361 m
.40146 .50022 L
s
.40146 .50022 m
.39833 .49686 L
s
.39833 .49686 m
.38802 .49101 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0C0?ooo`030000o`3oool0oooo06l0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0403oool20000o`03
0?ooo`000?l0003o06`0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0IP3oool3000000D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool03@3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0680oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`0:0?ooo`80003o2@3oool00`000?l0oooo0?ooo`1N0?ooo`<000002`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`1K0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`050?ooo`80003o2`3oool00`000?l0oooo0?ooo`1I0?ooo`<000004@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1?0?ooo`<00000503oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`030?ooo`80003o2@3oool00`00
0?l0oooo0?ooo`040?ooo`80003oC`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0103oool20000o`@0oooo0`000?l50?ooo`80003oCP3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`050?ooo`@0003o1P3oool20000odd0
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0=0?ooo`030000o`3oool0003o04T0oooo
1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`0>0?ooo`030000o`3oool0oooo00P0oooo1@00
0?lg0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X
0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`04
0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`0a0?ooo`<00000:03oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0>0?oo
o`80003o0`3oool00`000?l0oooo0?ooo`070?ooo`80003o;P3oool3000002/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0:P3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
1@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
4@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02P0oooo0`00000a0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0140oooo0`000?l30?ooo`80003o:03o
ool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0C0?ooo`<0003o2@3oool2
0000oa`0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo
00D0oooo10000?lJ0?ooo`<00000>P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool05`3oool30000o`80
oooo00<0003o0?ooo`3oool00P3oool20000oa80oooo0`00000m0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo
0?ooo`0D0?ooo`80003o1@3oool00`000?l0oooo0?ooo`030000oa00oooo0`0000100?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0I0?ooo`@0003o00<0oooo0000o`3oool03@3oool3000004<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o
0?ooo`030000003oool0oooo01L0oooo0P000?l40?ooo`030000o`3oool0oooo00T0oooo0`000016
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?oo
o`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool01@3oool30000o`800000B@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`030?ooo`<0003o0P0000000`3oool0
003o0000o`190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`80003o0P0000060?ooo`80003o
B03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08@0oooo00<000000?ooo`3oool0603oool2000000030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000030?ooo`000?l0
oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`180?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<00000103oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`@0oooo00<0
003o0?ooo`3oool0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000000L0oooo00<0003o
0?ooo`3oool0203oool20000o`<0oooo0P000?m40?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?oo
o`<000002`3oool00`000?l0oooo0?ooo`0:0?ooo`80003oAP3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool3000000l0oooo1`000?l30?ooo`80003oB03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000K0?ooo`030000o`3oool0003o04P0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000803oool20000o`L0oooo1P00
0?lj0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`04
0?ooo`80003o=`3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`000?l01@3oool00`000?l0oooo0?ooo`0Z0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool09P3oool00`000?l0oooo0?ooo`060?ooo`80003o103oool20000obT0oooo100000060?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00@0oooo0P000?l40?ooo`80003o
:03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo1P000?l50?ooo`D0003o8`3o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool00`3oool2
0000o`D0oooo00<0003o0?ooo`3oool07@3oool300000180oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02h0oooo0P000?l80?ooo`030000o`3oool0oooo01T0oooo0`00000F0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0]0?ooo`030000o`3oool0003o00P0oooo00<0003o0?ooo`3oool05@3oool4000001X0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo02l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00`0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0`0?ooo`L0003o1@3oool20000o``0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0j
0?ooo`80003o2`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0>@3oool00`000?l0oooo0?ooo`070?oo
o`040000o`0000000000000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03L0oooo0`000?l60?oo
o`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0=P3oool20000o`80oooo00@0003o0?ooo`3o
ool0oooo0`0000000`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0e0?ooo`03
0000o`3oool0oooo0080oooo00H0003o00000000000000000?ooo`000?l70?ooo`80003o:`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>03oool3000000@0003o1P3oool20000obh0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03D0oooo0`00000;0?ooo`80003o1`3oool00`000?l0oooo0?ooo`0W0?ooo`03
0000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0a0?ooo`@00000303oool20000o`D0oooo10000?l00`3oool0003o
0?ooo`0X0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<000005P3oool00`000?l0oooo0?oo
o`040?ooo`80003o:03oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000000l0oooo0P000?l7
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`1<
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0:03oool300000180oooo0P000?l70?ooo`030000o`3oool0oooo0300oooo00<000000?oo
o`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3o
ool09@3oool3000001l0oooo0P000?l90?ooo`@0003o903oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000
903oool30000o`X0oooo0P000?lS0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
3`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000;@3o
ool50000o`D0oooo00<0003o0?ooo`3oool08@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01/0oooo0`00000`0?ooo`030000o`3oool0oooo0080oooo1@000?lT0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000d0?ooo`030000o`3oool0
oooo00T0oooo0P000?lP0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool0
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01D0oooo0`00000h0?ooo`@0003o1`3oool20000ob40oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@00000A03oool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`0000160?ooo`80003o9`3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?oo
o`2@0?ooo`030000003oool0oooo00/0oooo0`0000170?ooo`80003o:@3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0203oool3000004P0oooo0P000?l/0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?oo
o`@00000BP3oool00`000?l0oooo0?ooo`0]0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
07l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`28
0?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?oo
o`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<00000
3`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0
oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo
0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y
0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000
;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`00
0000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0
oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000
oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo
0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?oo
o`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?oo
o`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000
CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`00
0000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000
oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo
0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?oo
o`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?oo
o`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000
K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`00
0000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0
oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000
oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo
0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?oo
o`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?oo
o`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool0
1P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003o
ool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool0
0`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`80
00002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000
oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`00
0000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0
/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?oo
o`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@0
0000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
08D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?oo
o`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0
oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`00
0000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0
oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`00
0000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0
oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<0
00000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo0010
0?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3o
ool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3o
ool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000
oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?oo
o`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P000000
0`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000
oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@00000
0?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000
001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?oo
o`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`80
0000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003o
ool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0
oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<00000
0?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3o
ool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680
oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P00
00190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?oo
o`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?oo
o`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000
@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo
0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0
oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo
001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?oo
o`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`00
0000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000
=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool00000
3P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03o
ool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000
A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503o
ool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`00
0000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`00
0000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000
oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo
1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000
001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X
0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T
0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?oo
o`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00
S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03o
ool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0
000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`00
0000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo
1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo
1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000
002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W
0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?oo
o`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`03
0000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000
003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3o
ool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool0
7P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000
oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`00
0000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0
oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00
ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000
g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61195 .67867 m
.63256 .67095 L
s
.64239 .66843 m
.63997 .66818 L
s
.64295 .66707 m
.64239 .66843 L
s
.63997 .66818 m
.64053 .66681 L
s
.64053 .66681 m
.64295 .66707 L
s
.61523 .667 m
.61091 .66512 L
s
.61913 .6667 m
.61523 .667 L
s
.61091 .66512 m
.60806 .66267 L
s
.6256 .66309 m
.62951 .66279 L
s
.62222 .66202 m
.6256 .66309 L
s
.62951 .66279 m
.631 .66223 L
s
.60806 .66267 m
.60668 .65966 L
s
.631 .66223 m
.63303 .66029 L
s
.616 .65849 m
.62222 .66202 L
s
.63303 .66029 m
.6317 .65727 L
s
.60668 .65966 m
.60869 .65771 L
s
.61261 .65741 m
.616 .65849 L
s
.60869 .65771 m
.61261 .65741 L
s
.6317 .65727 m
.62886 .6548 L
s
.62886 .6548 m
.62453 .65289 L
s
.62453 .65289 m
.62059 .6532 L
s
.60294 .65277 m
.59804 .65225 L
s
.59804 .65225 m
.59463 .65117 L
s
.59463 .65117 m
.59173 .64868 L
s
.59173 .64868 m
.59127 .64645 L
s
.61594 .64542 m
.61486 .64823 L
s
.59127 .64645 m
.59231 .64363 L
s
.61552 .64318 m
.61594 .64542 L
s
.59231 .64363 m
.59582 .64107 L
s
.5706 .64351 m
.56813 .64325 L
s
.5711 .6421 m
.5706 .64351 L
s
.56813 .64325 m
.56863 .64184 L
s
.61263 .64067 m
.61552 .64318 L
s
.56863 .64184 m
.5711 .6421 L
s
.59582 .64107 m
.59881 .63992 L
s
.6092 .63956 m
.61263 .64067 L
s
.59881 .63992 m
.60427 .63904 L
s
.60427 .63904 m
.6092 .63956 L
s
.58002 .63865 m
.601 .63054 L
s
.57265 .63047 m
.57813 .62957 L
s
.56917 .62935 m
.57265 .63047 L
s
.57813 .62957 m
.59317 .62371 L
s
.56618 .62679 m
.56917 .62935 L
s
.56569 .6245 m
.56618 .62679 L
s
.55072 .62662 m
.58229 .61424 L
s
.5672 .62016 m
.56569 .6245 L
s
.55665 .61297 m
.56219 .61206 L
s
.55162 .61243 m
.55665 .61297 L
s
.54809 .61129 m
.55162 .61243 L
s
.56219 .61206 m
.56521 .61086 L
s
.54504 .60867 m
.54809 .61129 L
s
.56521 .61086 m
.56874 .6082 L
s
.54451 .60633 m
.54504 .60867 L
s
.56874 .6082 m
.56976 .60525 L
s
.54549 .60337 m
.54451 .60633 L
s
.56976 .60525 m
.56926 .60289 L
s
.54096 .60518 m
.57287 .59246 L
s
.56926 .60289 m
.56623 .60025 L
s
.56623 .60025 m
.56268 .59909 L
s
.56268 .59909 m
.55761 .59854 L
s
.53377 .59902 m
.55503 .5905 L
s
.53831 .5972 m
.53322 .59665 L
s
.53322 .59665 m
.52964 .59548 L
s
.52964 .59548 m
.52653 .59282 L
s
.52653 .59282 m
.52597 .59043 L
s
.55146 .58933 m
.55046 .59233 L
s
.52597 .59043 m
.52692 .58741 L
s
.55093 .58692 m
.55146 .58933 L
s
.52692 .58741 m
.53045 .58467 L
s
.54784 .58423 m
.55093 .58692 L
s
.53045 .58467 m
.53349 .58344 L
s
.54424 .58305 m
.54784 .58423 L
s
.51294 .58117 m
.5161 .58387 L
s
.53349 .58344 m
.53911 .58249 L
s
.53911 .58249 m
.54424 .58305 L
s
.51236 .57875 m
.51294 .58117 L
s
.51329 .57569 m
.51236 .57875 L
s
.50767 .57665 m
.52908 .5679 L
s
.51682 .57291 m
.51329 .57569 L
s
.49414 .57278 m
.48896 .57221 L
s
.49825 .57244 m
.49414 .57278 L
s
.48896 .57221 m
.4853 .57101 L
s
.4853 .57101 m
.48099 .56735 L
s
.50513 .56283 m
.51046 .56743 L
s
.51506 .56554 m
.51046 .56743 L
s
.48099 .56735 m
.48035 .56488 L
s
.51707 .56336 m
.51506 .56554 L
s
.48035 .56488 m
.48124 .56178 L
s
.51802 .56024 m
.51707 .56336 L
s
.48124 .56178 m
.48321 .55958 L
s
.51744 .55776 m
.51802 .56024 L
s
.48321 .55958 m
.48671 .55675 L
s
.51317 .55404 m
.51744 .55776 L
s
.48671 .55675 m
.49439 .55356 L
s
.50948 .55281 m
.51317 .55404 L
s
.49439 .55356 m
.50008 .55257 L
s
.50424 .55223 m
.50948 .55281 L
s
.50008 .55257 m
.50424 .55223 L
s
.47866 .5518 m
.4959 .539 L
s
.46991 .54429 m
.4959 .539 L
s
.46991 .54429 m
.48715 .53138 L
s
.46107 .53672 m
.48715 .53138 L
s
.45327 .53004 m
.47499 .52079 L
s
.45791 .52807 m
.45258 .52746 L
s
.45258 .52746 m
.44879 .5262 L
s
.44879 .5262 m
.44541 .52331 L
s
.44541 .52331 m
.4447 .52071 L
s
.4712 .51952 m
.47032 .52278 L
s
.4447 .52071 m
.44554 .51744 L
s
.47053 .51691 m
.4712 .51952 L
s
.44554 .51744 m
.44907 .51446 L
s
.46718 .51399 m
.47053 .51691 L
s
.44907 .51446 m
.45219 .51312 L
s
.46337 .5127 m
.46718 .51399 L
s
.43065 .51066 m
.43408 .5136 L
s
.45219 .51312 m
.45799 .51209 L
s
.45799 .51209 m
.46337 .5127 L
s
.42992 .50803 m
.43065 .51066 L
s
.43073 .5047 m
.42992 .50803 L
s
.42492 .50575 m
.44679 .49623 L
s
.43426 .50168 m
.43073 .5047 L
s
.40829 .49956 m
.41256 .49919 L
s
.40286 .49894 m
.40829 .49956 L
s
.41256 .49919 m
.41839 .49814 L
s
.3978 .49663 m
.40286 .49894 L
s
.41839 .49814 m
.4262 .49472 L
s
.38956 .48964 m
.3978 .49663 L
s
.4262 .49472 m
.42974 .49167 L
s
.42974 .49167 m
.43173 .48929 L
s
.38956 .48964 m
.42248 .47506 L
s
.43173 .48929 m
.43256 .4859 L
s
.43256 .4859 m
.43065 .48217 L
s
.43065 .48217 m
.42248 .47506 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0?ooo`1U0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool08P3oool20000o`03
0?ooo`000?l0oooo06D0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0O0?ooo`80003o
103oool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0703o
ool20000o`L0oooo00<0003o0?ooo`3oool0HP3oool00`000000oooo0?ooo`040?ooo`<00000CP3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo01T0oooo0P000?l:0?ooo`030000o`3oool0oooo0640oooo00@000000?ooo`3oool0oooo0`00
001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool05P3oool20000o``0oooo00<0003o0?ooo`3oool0H@3oool4000005D0oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0C0?oo
o`80003o3@3oool20000of40oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0oooo06L0oooo00<000000?ooo`3oool04`3oool20000o`/0oooo00<0003o0?ooo`3o
ool0GP3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`3oool0
1`3oool20000o`H0oooo00<0003o0?ooo`3oool0E03oool3000000D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool05@3o
ool90000o`H0oooo0P000?mD0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool08@3oool2
0000oe<0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool07P3oool20000
oe80oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
01/0oooo0`000?m@0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`00
0000oooo0?ooo`0L0?ooo`030000o`3oool0oooo04/0oooo0`00000D0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1^0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool01@3oool60000
ocd0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
01/0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=`3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0oooo00H0
oooo00<0003o0?ooo`3oool0<`3oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool01`3oool20000obl0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`0M0?ooo`030000o`3oool0oooo00H0oooo0P000?l]0?ooo`<000009@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<00000
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`030?ooo`80003o;03oool3000002P0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?oo
o`3oool07@3oool50000ob/0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool07@3oool20000o`T0oooo0`000?lN0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0
M`3oool00`000000oooo0?ooo`0R0?ooo`L0003o703oool300000340oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool07P3oool30000o`@0oooo00<0003o0?ooo`3oool06@3o
ool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0
oooo0080oooo0`000?lB0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0803oool90000
oa00oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0
oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0N0?ooo`<0003o103oool00`000?l0
oooo0?ooo`0=0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo
0?ooo`0;0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0803oool20000o`/0oooo0`00
00130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00D0oooo1@000?l0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo0`0000210?ooo`030000003oool0oooo0280oooo0`000?l300000080oooo00<0003o0?oo
o`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool07`3oool20000o`<000001P3oool20000od@0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo01`0oooo00@000000000o`00000000002P3oool00`000?l0
oooo0?ooo`130?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<0000000<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo01@0oooo0`0000030?ooo`030000o`3oool0oooo00L0oooo00@0003o0?ooo`3oool0003o
AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0403oool3000000H0oooo00<0003o0?ooo`3oool0203o
ool20000o`@0oooo0P000?m10?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000002P3oool3
0000o`/0oooo0P000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000403oool40000
o`@0oooo0`000?m50?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000006@3oool40000odH0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00<000007P3oool00`000?l0oooo0?ooo`150?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03o
ool200000240oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0
oooo0240oooo00<0003o0?ooo`3oool00`3oool30000o`040?ooo`000?l0003o0000ocT0oooo0P00
001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool09@3oool20000o`L0oooo00<0003o0?ooo`3oool0<`3oool300000080oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01`3oool20000obl0oooo100000060?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00H0oooo0P000?l50?ooo`80
003o9P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0
0`3oool20000o`D0oooo0P000?lU0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09`3o
ool50000o`D0oooo0P000?lT0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool2
0000o`D0oooo0P000?l0103oool0003o0000o`000?lO0?ooo`<000005P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0;03oool30000o`H0oooo00<0003o0?ooo`3oool0603oool4000001X0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02/0oooo0P000?l80?ooo`030000o`3oool0oooo01D0oooo0`00000N0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool04P3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0
0P3oool30000oa80oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
4@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo02h0oooo10000?l70?ooo`80003o2@3o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03L0oooo0P000?l70?ooo`@00000;P3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0=@3oool30000o`H0oooo0`00000c0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0c0?ooo`<0003o1@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo
0P000?l20?ooo`030000o`3oool0oooo00<000000`3oool20000ocD0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02l0oooo0P000?l40?ooo`<000000`3oool30000ocP0oooo00<000000?ooo`3oool0CP3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0340oooo100000000`3oool0003o0000o`030000o`H0oooo0P000?ld0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0^0?ooo`<000003P3oool20000ocL0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00000>0?ooo`<0003o>@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000l0oooo
0P000?l70?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000h0oooo00<0
003o0?ooo`3oool01`3oool30000o`040?ooo`000?l0003o0000oc<0oooo00<000000?ooo`3oool0
BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3oool08@3o
ool400000140oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool07P3oool3000001d0oooo00<0003o0?ooo`3oool01`3oool0
0`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool30000
0240oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000U0?ooo`80003o>`3oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000:P3oool20000o`D0
oooo10000?la0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool400000300oooo
0P000?l60?ooo`030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool03P3oool3000003<0oooo00<0003o0?ooo`3oool00P000?l50?ooo`030000o`3o
ool0oooo02l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000=`3oool0
10000?l0oooo0?ooo`3oool50000oc80oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000k
0?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000o0?oo
o`<0003o1`3oool20000obl0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000B@3oool20000
oc@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940
oooo1000001:0?ooo`80003o=`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`800000T03oool3000004X0oooo0`000?li0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<0
00000?ooo`3oool0AP3oool20000ocd0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03o
ool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00
000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.57619 .68658 m
.59883 .68143 L
s
.6092 .68011 m
.60696 .67958 L
s
.61021 .67884 m
.6092 .68011 L
s
.60696 .67958 m
.60797 .67832 L
s
.60797 .67832 m
.61021 .67884 L
s
.58733 .67574 m
.58344 .67558 L
s
.58344 .67558 m
.57991 .67325 L
s
.57991 .67325 m
.578 .67054 L
s
.59873 .67313 m
.60036 .67276 L
s
.59484 .67298 m
.59873 .67313 L
s
.59195 .67154 m
.59484 .67298 L
s
.60036 .67276 m
.603 .67111 L
s
.58716 .66739 m
.59195 .67154 L
s
.603 .67111 m
.60276 .66802 L
s
.578 .67054 m
.57772 .66744 L
s
.60276 .66802 m
.60088 .66529 L
s
.57772 .66744 m
.58034 .66578 L
s
.58425 .66594 m
.58716 .66739 L
s
.58034 .66578 m
.58425 .66594 L
s
.60088 .66529 m
.59736 .66293 L
s
.59736 .66293 m
.59344 .66277 L
s
.5765 .6603 m
.57193 .65922 L
s
.57193 .65922 m
.569 .65776 L
s
.569 .65776 m
.56705 .655 L
s
.59166 .65466 m
.58964 .65726 L
s
.56705 .655 m
.56739 .65277 L
s
.59203 .65242 m
.59166 .65466 L
s
.56739 .65277 m
.56938 .65015 L
s
.59012 .64964 m
.59203 .65242 L
s
.56938 .65015 m
.57368 .64806 L
s
.58718 .64816 m
.59012 .64964 L
s
.58259 .64707 m
.58718 .64816 L
s
.57368 .64806 m
.57698 .64729 L
s
.5483 .64748 m
.54599 .64693 L
s
.54928 .64616 m
.5483 .64748 L
s
.57698 .64729 m
.58259 .64707 L
s
.54599 .64693 m
.54697 .64561 L
s
.54697 .64561 m
.54928 .64616 L
s
.55918 .64384 m
.58239 .63841 L
s
.55487 .63498 m
.56052 .63475 L
s
.55188 .63347 m
.55487 .63498 L
s
.56052 .63475 m
.57718 .63083 L
s
.54987 .63062 m
.55188 .63347 L
s
.55019 .62832 m
.54987 .63062 L
s
.53485 .62861 m
.56993 .6203 L
s
.55318 .62427 m
.55019 .62832 L
s
.54543 .61599 m
.55114 .61576 L
s
.54071 .61485 m
.54543 .61599 L
s
.55114 .61576 m
.5545 .61495 L
s
.5545 .61495 m
.55887 .61278 L
s
.53766 .61331 m
.54071 .61485 L
s
.5356 .61039 m
.53766 .61331 L
s
.55887 .61278 m
.5609 .61003 L
s
.53591 .60803 m
.5356 .61039 L
s
.5609 .61003 m
.56124 .60767 L
s
.5379 .60526 m
.53591 .60803 L
s
.56124 .60767 m
.55921 .60472 L
s
.53284 .60647 m
.5684 .59792 L
s
.55921 .60472 m
.55617 .60316 L
s
.55617 .60316 m
.55142 .60201 L
s
.52799 .59958 m
.55173 .59384 L
s
.53306 .59836 m
.52828 .59719 L
s
.52828 .59719 m
.52519 .59562 L
s
.52519 .59562 m
.52309 .59263 L
s
.54865 .59226 m
.54663 .59508 L
s
.52309 .59263 m
.52338 .59022 L
s
.54898 .58985 m
.54865 .59226 L
s
.52338 .59022 m
.52537 .58739 L
s
.54691 .58685 m
.54898 .58985 L
s
.52537 .58739 m
.52978 .58514 L
s
.54382 .58525 m
.54691 .58685 L
s
.53901 .58407 m
.54382 .58525 L
s
.52978 .58514 m
.53319 .58431 L
s
.53319 .58431 m
.53901 .58407 L
s
.51388 .57957 m
.51602 .5826 L
s
.51416 .57712 m
.51388 .57957 L
s
.51615 .57424 m
.51416 .57712 L
s
.5103 .57449 m
.53434 .56857 L
s
.52058 .57196 m
.51615 .57424 L
s
.50254 .5692 m
.49839 .56902 L
s
.49839 .56902 m
.4935 .56782 L
s
.4935 .56782 m
.49032 .56618 L
s
.49032 .56618 m
.48738 .56206 L
s
.51269 .56064 m
.51629 .5658 L
s
.52146 .56453 m
.51629 .5658 L
s
.52419 .56264 m
.52146 .56453 L
s
.52622 .55972 m
.52419 .56264 L
s
.48738 .56206 m
.48762 .55956 L
s
.52652 .55721 m
.52622 .55972 L
s
.48762 .55956 m
.48959 .55662 L
s
.52365 .55304 m
.52652 .55721 L
s
.48959 .55662 m
.4923 .55472 L
s
.4923 .55472 m
.49675 .55238 L
s
.52047 .55138 m
.52365 .55304 L
s
.49675 .55238 m
.50541 .55022 L
s
.51555 .55015 m
.52047 .55138 L
s
.50541 .55022 m
.51135 .54996 L
s
.51135 .54996 m
.51555 .55015 L
s
.49058 .54651 m
.51203 .53615 L
s
.48461 .53804 m
.51203 .53615 L
s
.48461 .53804 m
.50613 .52757 L
s
.47859 .52949 m
.50613 .52757 L
s
.47326 .52194 m
.49793 .51564 L
s
.47853 .52059 m
.47349 .51932 L
s
.47349 .51932 m
.4702 .51759 L
s
.4702 .51759 m
.46789 .51431 L
s
.49465 .51391 m
.49262 .517 L
s
.46789 .51431 m
.46811 .51167 L
s
.49491 .51127 m
.49465 .51391 L
s
.46811 .51167 m
.4701 .50857 L
s
.49264 .50797 m
.49491 .51127 L
s
.4701 .50857 m
.47464 .5061 L
s
.48935 .50622 m
.49264 .50797 L
s
.48427 .50492 m
.48935 .50622 L
s
.47464 .5061 m
.47818 .50518 L
s
.47818 .50518 m
.48427 .50492 L
s
.45778 .49998 m
.46013 .50331 L
s
.45799 .49729 m
.45778 .49998 L
s
.45998 .49413 m
.45799 .49729 L
s
.45385 .4944 m
.47884 .48791 L
s
.46454 .49163 m
.45998 .49413 L
s
.44394 .48634 m
.45009 .48607 L
s
.43958 .48614 m
.44394 .48634 L
s
.4344 .48482 m
.43958 .48614 L
s
.45009 .48607 m
.45903 .48373 L
s
.4302 .48188 m
.4344 .48482 L
s
.45903 .48373 m
.46362 .48119 L
s
.42451 .4739 m
.4302 .48188 L
s
.46362 .48119 m
.46643 .47912 L
s
.46643 .47912 m
.46845 .47589 L
s
.46845 .47589 m
.46789 .47198 L
s
.42451 .4739 m
.46233 .46391 L
s
.46789 .47198 m
.46233 .46391 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03L0oooo0P000?mH0?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0<P3oool40000o`80oooo00<0003o0?ooo`3oool0
E@3oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0;P3oool30000o`H0oooo00<0003o0?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0:@3oool40000o`X0oooo00<0003o0?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02H0oooo0P000?l>0?ooo`030000o`3oool0oooo
05@0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00d0
oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo02D0oooo
00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool09@3oool00`000?l0oooo0?ooo`070?ooo`@0003oE`3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo02D0oooo2@000?mK0?ooo`040000003oool0oooo0?ooo`<00000DP3o
ool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0
oooo03<0oooo0`000?mB0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`00
0000oooo0?ooo`1U0?ooo`030000003oool0oooo02h0oooo10000?mC0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo02X0
oooo10000?mC0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo
0?ooo`1?0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo04`0oooo0`00
00080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<00000
0?ooo`3oool0J@3oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo04T0oooo0`00000;
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`040?oo
o`<0003o?`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0;P3oool010000?l0oooo0?ooo`3oool20000ocX0oooo0`00000A0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02/0oooo0P000?l60?ooo`80003o=@3oool3
000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0:@3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0300oooo0`00000H0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool01`3oool3
0000obd0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`040?ooo`<0003o;03oool3000001h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo02P0
oooo1P000?l[0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool09`3oool20000ob`0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`1A0?ooo`<00000:03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0]
0?ooo`H0003o6P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0V0?oo
o`H0003o0`3oool20000oaP0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo02`0oooo0P000?lG0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0Y0?ooo`80003o0P3oool50000o`l0oooo0`00000d0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool09P3oool60000o`80oooo0P000?l=0?ooo`<00000=`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0:`3oool20000o``0oooo0`00000j0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`00
0000oooo0?ooo`0X0?ooo`80003o2`3oool3000003d0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo02D0
oooo0P000?l:0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0:03oool60000o`800000
@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003o
ool0oooo07l0oooo00<000000?ooo`3oool09@3oool20000o`80oooo0`000000103oool0003o0000
o`000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00
00210?ooo`030000003oool0oooo0280oooo0P000?l0103oool000000000000000060?ooo`030000
o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0200oooo00@0003o0000000000000000
2P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`<0000000<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0400oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01P0oooo0`0000030?ooo`030000o`3oool0oooo00H0oooo00D0003o
0?ooo`3oool0oooo0000o`130?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000001`3oool0
0`000?l0oooo0?ooo`060?ooo`<0003oA03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool30000
00/0oooo10000?l90?ooo`<0003o?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001L0
oooo10000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo
00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000005`3oool40000odD0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00@0oooo0`00000L0?ooo`030000o`3oool0oooo04@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo00<000007P3oool00`000?l0oooo0?ooo`150?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool20000
0280oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0V0?ooo`L0003o>P3oool2000005/0
oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0U0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=03oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0_0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo02d0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?oo
o`030000o`3oool0oooo00D0oooo0`000?lZ0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool09P3oool70000o`H0oooo0`000?lQ0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
9P3oool30000o`H0oooo10000?lQ0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3o
ool60000oal0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`<0003o1P3oool0
0`000?l0oooo0?ooo`0I0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:@3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01D0oooo0`00000R0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0Y0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04P3oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo
00<000000?ooo`3oool0:@3oool20000o`D0oooo0P000?lB0?ooo`<00000:P3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0:`3oool50000oa00oooo1000000^0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0e
0?ooo`80003o1`3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0380oooo0`000?l60?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0;P3oool40000o`H0oooo0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0[0?ooo`<0003o00<0oooo0000o`3oool0103oool3000003h0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo02T0oooo0P000?l40?ooo`030000o`3oool0000000<000000`3o
ool20000ocd0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000040?ooo`<0003o@03oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:`3oool3000000<0oooo10000?m30?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0X0?ooo`<000003P3oool30000ocd0oooo00<000000?ooo`3oool0B`3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000000d0oooo
10000?m10?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
002@0?ooo`030000003oool0oooo0240oooo1000000=0?ooo`<0003oAP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000000`0oooo0`000?l;0?ooo`030000o`3oool0oooo03h0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000403oool00`000?l0oooo0?ooo`070?oo
o`<0003o00@0oooo0000o`000?l0003o?@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0H0?ooo`<000006`3oool20000o`L0oooo00<0003o0?ooo`3oool0>`3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000007@3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@000008@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03h0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002H0oooo
0`000?m60?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`00
00050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000340oooo0`00
0?ln0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000;`3oool30000o`D0oooo00<0003o
0?ooo`3oool0?03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool400000340oooo00D0003o0?oo
o`3oool0oooo0000o`050?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo
0?ooo`<00000=@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0?@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?oo
o`800000T@3oool4000003T0oooo00<0003o0?ooo`3oool00P3oool40000od40oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000m0?ooo`<0
003oAP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`3oool0
?@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003o
ool0oooo08P0oooo100000050?ooo`030000003oool0oooo0400oooo0P000?l20?ooo`80003o@03o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08D0oooo0`0000090?ooo`030000003oool0oooo03`0oooo10000?m70?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool0>@3oool30000od`0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.53865 .69019 m
.56249 .68776 L
s
.57302 .68766 m
.57102 .6869 L
s
.57444 .68655 m
.57302 .68766 L
s
.57102 .6869 m
.57245 .68578 L
s
.57245 .68578 m
.57444 .68655 L
s
.55329 .68089 m
.54957 .68029 L
s
.54957 .68029 m
.54695 .67761 L
s
.56529 .67966 m
.567 .67949 L
s
.56157 .67906 m
.56529 .67966 L
s
.567 .67949 m
.57015 .67818 L
s
.55926 .67733 m
.56157 .67906 L
s
.57015 .67818 m
.571 .67514 L
s
.54695 .67761 m
.54604 .67474 L
s
.55606 .67272 m
.55926 .67733 L
s
.571 .67514 m
.57013 .67226 L
s
.54604 .67474 m
.54685 .67168 L
s
.55374 .67097 m
.55606 .67272 L
s
.57013 .67226 m
.56753 .66955 L
s
.54685 .67168 m
.54999 .67036 L
s
.54999 .67036 m
.55374 .67097 L
s
.56753 .66955 m
.56379 .66894 L
s
.54816 .66456 m
.54409 .66297 L
s
.56489 .66082 m
.56201 .66313 L
s
.54409 .66297 m
.54174 .66121 L
s
.54174 .66121 m
.54081 .65828 L
s
.56603 .65869 m
.56489 .66082 L
s
.56515 .65575 m
.56603 .65869 L
s
.54081 .65828 m
.54193 .65614 L
s
.54193 .65614 m
.54479 .65381 L
s
.56281 .65396 m
.56515 .65575 L
s
.55873 .65236 m
.56281 .65396 L
s
.54479 .65381 m
.54971 .65228 L
s
.55319 .65192 m
.55873 .65236 L
s
.54971 .65228 m
.55319 .65192 L
s
.52516 .64872 m
.52309 .64791 L
s
.52658 .64754 m
.52516 .64872 L
s
.52309 .64791 m
.52451 .64674 L
s
.52451 .64674 m
.52658 .64754 L
s
.53706 .64645 m
.56157 .64388 L
s
.54155 .63772 m
.55915 .63587 L
s
.53596 .63727 m
.54155 .63772 L
s
.53357 .63545 m
.53596 .63727 L
s
.53261 .63242 m
.53357 .63545 L
s
.53373 .63021 m
.53261 .63242 L
s
.53807 .6266 m
.53373 .63021 L
s
.51863 .62867 m
.55579 .62473 L
s
.53907 .61804 m
.54263 .61766 L
s
.53341 .61758 m
.53907 .61804 L
s
.54263 .61766 m
.54766 .61606 L
s
.5292 .6159 m
.53341 .61758 L
s
.54766 .61606 m
.55059 .61362 L
s
.52677 .61403 m
.5292 .6159 L
s
.52578 .61092 m
.52677 .61403 L
s
.55059 .61362 m
.55176 .61136 L
s
.55176 .61136 m
.55082 .60824 L
s
.52691 .60865 m
.52578 .61092 L
s
.52983 .60618 m
.52691 .60865 L
s
.55082 .60824 m
.54839 .60635 L
s
.52446 .60676 m
.56214 .60271 L
s
.54839 .60635 m
.54417 .60464 L
s
.52213 .59943 m
.54734 .59671 L
s
.52753 .59884 m
.52326 .59713 L
s
.54489 .59479 m
.54193 .59729 L
s
.52326 .59713 m
.52079 .59521 L
s
.52079 .59521 m
.51978 .59203 L
s
.54606 .59247 m
.54489 .59479 L
s
.5451 .58928 m
.54606 .59247 L
s
.51978 .59203 m
.52092 .58971 L
s
.52092 .58971 m
.52386 .58718 L
s
.54264 .58735 m
.5451 .58928 L
s
.53836 .5856 m
.54264 .58735 L
s
.52386 .58718 m
.52896 .58552 L
s
.53259 .58513 m
.53836 .5856 L
s
.52896 .58552 m
.53259 .58513 L
s
.51536 .57811 m
.51639 .58134 L
s
.5165 .57575 m
.51536 .57811 L
s
.51946 .57318 m
.5165 .57575 L
s
.52461 .57149 m
.51946 .57318 L
s
.51364 .5727 m
.53925 .56989 L
s
.5079 .56655 m
.50389 .56586 L
s
.50389 .56586 m
.49951 .56407 L
s
.52086 .55944 m
.52257 .56494 L
s
.52808 .56433 m
.52257 .56494 L
s
.53141 .56283 m
.52808 .56433 L
s
.49951 .56407 m
.49697 .56208 L
s
.53443 .56022 m
.53141 .56283 L
s
.49697 .56208 m
.49553 .55766 L
s
.5356 .55781 m
.53443 .56022 L
s
.53426 .55337 m
.5356 .55781 L
s
.49553 .55766 m
.49665 .55525 L
s
.49665 .55525 m
.49962 .55261 L
s
.53174 .55135 m
.53426 .55337 L
s
.49962 .55261 m
.50296 .55109 L
s
.52736 .54953 m
.53174 .55135 L
s
.50296 .55109 m
.50815 .54936 L
s
.52331 .54883 m
.52736 .54953 L
s
.50815 .54936 m
.51741 .54833 L
s
.51741 .54833 m
.52331 .54883 L
s
.50416 .54283 m
.52884 .53539 L
s
.50129 .53378 m
.52884 .53539 L
s
.50129 .53378 m
.52608 .52626 L
s
.49839 .52463 m
.52608 .52626 L
s
.49582 .51654 m
.52225 .51354 L
s
.50147 .5159 m
.49697 .51401 L
s
.51965 .51143 m
.51658 .51419 L
s
.49697 .51401 m
.49434 .51189 L
s
.49434 .51189 m
.49323 .50838 L
s
.52084 .50887 m
.51965 .51143 L
s
.51978 .50535 m
.52084 .50887 L
s
.49323 .50838 m
.49438 .50582 L
s
.49438 .50582 m
.49743 .50303 L
s
.51716 .50322 m
.51978 .50535 L
s
.51264 .50129 m
.51716 .50322 L
s
.49743 .50303 m
.50276 .5012 L
s
.50657 .50076 m
.51264 .50129 L
s
.50276 .5012 m
.50657 .50076 L
s
.48835 .49302 m
.48948 .49659 L
s
.4895 .49041 m
.48835 .49302 L
s
.49258 .48757 m
.4895 .49041 L
s
.49795 .4857 m
.49258 .48757 L
s
.48645 .48703 m
.51331 .48393 L
s
.48569 .47837 m
.49532 .47725 L
s
.47953 .47782 m
.48569 .47837 L
s
.47529 .47706 m
.47953 .47782 L
s
.49532 .47725 m
.50073 .47536 L
s
.47066 .47507 m
.47529 .47706 L
s
.50073 .47536 m
.50422 .47369 L
s
.46754 .47164 m
.47066 .47507 L
s
.50422 .47369 m
.50735 .4708 L
s
.46475 .46305 m
.46754 .47164 L
s
.50735 .4708 m
.50818 .4669 L
s
.50818 .4669 m
.50557 .45826 L
s
.46475 .46305 m
.50557 .45826 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`170?ooo`@0003oA`3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo03h0oooo20000?l30?ooo`030000o`3oool0oooo04D0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0i0?ooo`@0003o303oool00`000?l0oooo0?ooo`150?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0=0?ooo`030000
o`3oool0oooo04D0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo03P0oooo00<0003o0?ooo`3oool0303o
ool00`000?l0oooo0?ooo`150?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0
oooo00`0oooo00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
03L0oooo00<0003o0?ooo`3oool02@3oool20000odP0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`0g0?ooo`/0003oBP3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<0
00000?ooo`3oool0HP3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00
001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0?P3oool60000odD0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0>03oool6
0000odX0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0>03oool20000od/0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0=`3oool00`000?l0
oooo0?ooo`170?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0
oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo
0?ooo`140?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0>P3oool50000ocL0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0=`3oool20000o`D0oooo0P000?lb0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool0;03oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0=03oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02T0oooo0`00000D0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03<0oooo00<0003o0?oo
o`3oool01`3oool00`000?l0oooo0?ooo`0V0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0c0?ooo`<0003o0`3oool50000ob@0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0<P3oool60000obH0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0300oooo2`000?lF0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0e0?ooo`<0003o5@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0a0?ooo`<0003o5@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0;P3oool50000oa80oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo0380oooo1P000?l90?ooo`<00000=03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo0380oooo0`000?l80?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0;P3oool30000o`P0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0[0?ooo`80
003o203oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000100?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3o
ool00`000000oooo0?ooo`0Z0?ooo`T0003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool09P3oool3
0000o`<000001P3oool20000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool300000840oooo00<000000?ooo`3oool0903oool010000?l0000000000000000:
0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0P0000000`00
0?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0
oooo100000020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0m0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000001P3oool20000o`L0oooo
00D0003o0?ooo`3oool0oooo0000o`100?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000
2`3oool30000o`D0oooo0`000?m10?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000FP3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08L0oooo00<000000?ooo`3oool0303oool3000001T0oooo00<0003o0?ooo`000?l010000?lm
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000603oool60000od80oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo00@0oooo0`00000L0?ooo`80003oA@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0
0`00000O0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008P3oool00`000?l0oooo0?oo
o`140?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo02H0oooo1@000?ll0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo0P000?l50?oo
o`030000o`3oool0oooo03H0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0<@3oool4000000H0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0^0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool08`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo02/0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`<0003o0P3oool5
0000obT0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`D0003o:`3oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo1`000?lM0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0903oool:0000oal0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0U0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool06@3oool300000280oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0E
0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?oo
o`800000S`3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool04`3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo0`000?l20?ooo`<0
003o4P3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02X0oooo0P000?lB0?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02h0oooo10000?l60?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool09`3oool70000
o`L0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0S0?ooo`@0003o0P3oool20000o`H0
oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00<0oooo
0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`030000o`3oool00000008000000P3o
ool30000odD0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`0000050000odT0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?oo
o`3oool09@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?oo
o`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000000X0oooo1@000?m70?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<00000103oool00`000?l0oooo0?ooo`020?ooo`D0003o
C@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`0000070?ooo`80003oE@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000503o
ool40000odX0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3
000001D0oooo0P000?l40?ooo`80003oB@3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
0140oooo1000000G0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0A`3oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000006`3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo04P0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0;0?ooo`<000007P3oool20000o`D0oooo0`000?m:0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`080?ooo`<000008`3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`04
0?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?oo
o`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000[0?ooo`80003o0`3oool2
0000odd0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool20000
0940oooo1000000]0?ooo`040000o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool0B`3oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool30000
02l0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo04X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?oo
o`<000000P3oool00`000000oooo0?ooo`0^0?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool0
0`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0;`3oool20000
o`<0oooo0P000?m@0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo
0`00000<0?ooo`030000003oool0oooo03L0oooo0P000?m?0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0<03oool50000o`<0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo02`0oooo1@000?mI0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.53517 .69089 m
.5335 .68991 L
s
.53695 .68996 m
.53517 .69089 L
s
.53528 .68898 m
.53695 .68996 L
s
.5335 .68991 m
.53528 .68898 L
s
.50068 .68942 m
.52486 .68978 L
s
.53218 .68221 m
.5357 .68129 L
s
.53044 .68218 m
.53218 .68221 L
s
.52702 .68116 m
.53044 .68218 L
s
.51829 .682 m
.51486 .68098 L
s
.5357 .68129 m
.5376 .67842 L
s
.52537 .6792 m
.52702 .68116 L
s
.51486 .68098 m
.51324 .67805 L
s
.52386 .67432 m
.52537 .6792 L
s
.5376 .67842 m
.53776 .6755 L
s
.51324 .67805 m
.51336 .67513 L
s
.53776 .6755 m
.53618 .67255 L
s
.51336 .67513 m
.51522 .67223 L
s
.52221 .67234 m
.52386 .67432 L
s
.53618 .67255 m
.53274 .67152 L
s
.51876 .67131 m
.52221 .67234 L
s
.51522 .67223 m
.51876 .67131 L
s
.53667 .66371 m
.53305 .66563 L
s
.51902 .66542 m
.51559 .66339 L
s
.53853 .66176 m
.53667 .66371 L
s
.51559 .66339 m
.51391 .66138 L
s
.5387 .65878 m
.53853 .66176 L
s
.51391 .66138 m
.51403 .65841 L
s
.53705 .65677 m
.5387 .65878 L
s
.51403 .65841 m
.51588 .65644 L
s
.53362 .65472 m
.53705 .65677 L
s
.51588 .65644 m
.51949 .6545 L
s
.52838 .65364 m
.53362 .65472 L
s
.51949 .6545 m
.52484 .65358 L
s
.52484 .65358 m
.52838 .65364 L
s
.50205 .6472 m
.50031 .64616 L
s
.50386 .64622 m
.50205 .6472 L
s
.51452 .64638 m
.53937 .64677 L
s
.50212 .64518 m
.50386 .64622 L
s
.50031 .64616 m
.50212 .64518 L
s
.52199 .63838 m
.53983 .63866 L
s
.51667 .63728 m
.52199 .63838 L
s
.51497 .6352 m
.51667 .63728 L
s
.5151 .63213 m
.51497 .6352 L
s
.51697 .6301 m
.5151 .63213 L
s
.52249 .62708 m
.51697 .6301 L
s
.50272 .62678 m
.54046 .62737 L
s
.53009 .61888 m
.53556 .61792 L
s
.52648 .61883 m
.53009 .61888 L
s
.5211 .6177 m
.52648 .61883 L
s
.53556 .61792 m
.53929 .61589 L
s
.51758 .61555 m
.5211 .6177 L
s
.53929 .61589 m
.54122 .61382 L
s
.51585 .61342 m
.51758 .61555 L
s
.54122 .61382 m
.54139 .61066 L
s
.51598 .61026 m
.51585 .61342 L
s
.54139 .61066 m
.53969 .60852 L
s
.51788 .60817 m
.51598 .61026 L
s
.53969 .60852 m
.53617 .60634 L
s
.52161 .60611 m
.51788 .60817 L
s
.51615 .60602 m
.55436 .60663 L
s
.51645 .59856 m
.54205 .59897 L
s
.54034 .5968 m
.53656 .59888 L
s
.52194 .59865 m
.51837 .59645 L
s
.54229 .59468 m
.54034 .5968 L
s
.51837 .59645 m
.51663 .59427 L
s
.54247 .59145 m
.54229 .59468 L
s
.51663 .59427 m
.51676 .59103 L
s
.54075 .58925 m
.54247 .59145 L
s
.51676 .59103 m
.51868 .5889 L
s
.53719 .58703 m
.54075 .58925 L
s
.51868 .5889 m
.52246 .58679 L
s
.53172 .58585 m
.53719 .58703 L
s
.52246 .58679 m
.52803 .58579 L
s
.52803 .58579 m
.53172 .58585 L
s
.51733 .57687 m
.5172 .58016 L
s
.51927 .5747 m
.51733 .57687 L
s
.52308 .57255 m
.51927 .5747 L
s
.5287 .57154 m
.52308 .57255 L
s
.51755 .57136 m
.54357 .57178 L
s
.53462 .56496 m
.52902 .56487 L
s
.53841 .56391 m
.53462 .56496 L
s
.52928 .55928 m
.52902 .56487 L
s
.51409 .56463 m
.5104 .56345 L
s
.54226 .56173 m
.53841 .56391 L
s
.5104 .56345 m
.50674 .56116 L
s
.54426 .55952 m
.54226 .56173 L
s
.50674 .56116 m
.50494 .55888 L
s
.54451 .55502 m
.54426 .55952 L
s
.50494 .55888 m
.50509 .55438 L
s
.54275 .55274 m
.54451 .55502 L
s
.50509 .55438 m
.50704 .55215 L
s
.53912 .55041 m
.54275 .55274 L
s
.50704 .55215 m
.51088 .54995 L
s
.53541 .54921 m
.53912 .55041 L
s
.51088 .54995 m
.51469 .54887 L
s
.52981 .54798 m
.53541 .54921 L
s
.51469 .54887 m
.52039 .54783 L
s
.52039 .54783 m
.52981 .54798 L
s
.51878 .54094 m
.54553 .53678 L
s
.51916 .53172 m
.54553 .53678 L
s
.51916 .53172 m
.54605 .52751 L
s
.51953 .5224 m
.54605 .52751 L
s
.51987 .51415 m
.54677 .5146 L
s
.54498 .5122 m
.54101 .51451 L
s
.52563 .51425 m
.52189 .51182 L
s
.54704 .50986 m
.54498 .5122 L
s
.52189 .51182 m
.52006 .50941 L
s
.54724 .50629 m
.54704 .50986 L
s
.52006 .50941 m
.5202 .50583 L
s
.54544 .50386 m
.54724 .50629 L
s
.5202 .50583 m
.52223 .50347 L
s
.5417 .5014 m
.54544 .50386 L
s
.52223 .50347 m
.52621 .50114 L
s
.53595 .5001 m
.5417 .5014 L
s
.52621 .50114 m
.53207 .50004 L
s
.53207 .50004 m
.53595 .5001 L
s
.52084 .49017 m
.52069 .49381 L
s
.52289 .48776 m
.52084 .49017 L
s
.5269 .48539 m
.52289 .48776 L
s
.53282 .48427 m
.5269 .48539 L
s
.52108 .48407 m
.54845 .48453 L
s
.53322 .47565 m
.53918 .47452 L
s
.5234 .47549 m
.53322 .47565 L
s
.51755 .47415 m
.5234 .47549 L
s
.53918 .47452 m
.54317 .47335 L
s
.51366 .47284 m
.51755 .47415 L
s
.54317 .47335 m
.54724 .47093 L
s
.50981 .47029 m
.51366 .47284 L
s
.54724 .47093 m
.54942 .46723 L
s
.50796 .46652 m
.50981 .47029 L
s
.54942 .46723 m
.54991 .45845 L
s
.50825 .45773 m
.50796 .46652 L
s
.50825 .45773 m
.54991 .45845 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1;0?oooa40003o=P3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo04X0oooo00<0003o0?ooo`3oool03@3oool00`000?l0oooo0?ooo`0d0?oo
o`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0=0?ooo`03
0000o`3oool0oooo03D0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`180?ooo`030000
o`3oool0oooo00d0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0B03o
ool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0503o
ool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0
oooo04P0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0
oooo0140oooo0`0000110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0B03oool<0000ocT0oooo00<000000?ooo`3oool03P3oool30000
04@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H03oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<0
00000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`16
0?ooo`/0003o>03oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`160?ooo`030000o`3oool0
oooo03l0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0A03oool00`000?l0oooo0?ooo`0n0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04<0
oooo00<0003o0?ooo`3oool0>`3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo07d0oooo
0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00
001Y0?ooo`030000003oool0oooo07X0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`13
0?ooo`L0003o;03oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`110?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool09P3oool3000000h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0?`3oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo0280oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?oo
o`030000003oool0oooo03h0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0O0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0m0?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00<000000?ooo`3oool0?03oool;0000oa/0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3000001h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo05T0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0i0?ooo`<0003o6@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo03/0oooo10000?lB0?ooo`<00000:03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`0l0?ooo`D0003o303oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`0e0?ooo`H0003o3P3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo
00<000000?ooo`3oool0=`3oool50000o`T0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1h0?ooo`030000003oool0oooo03/0oooo0`000?l30?ooo`<00000=03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i
0?ooo`030000003oool0oooo03D0oooo1@000?l30?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0<@3oool30000o`D0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07d0oooo00<000000?ooo`3oool0<03oool50000ocl0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02/0oooo10000?l00`000000oooo0?ooo`020?ooo`<0003o?03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<00000
0?ooo`3oool0:@3oool00`000?l000000000000:0?ooo`030000o`3oool0oooo03T0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?oo
o`3oool09@3oool2000000030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0>03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool08@3oool300000080oooo00<0003o0?ooo`3oool0303oool00`000?l0
oooo0?ooo`0h0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000001@3oool20000o`L0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?oo
o`0H0?ooo`<000002`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`80003o
?03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000l0oooo0P000?l40?ooo`@0003o?P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo
00`0oooo0`00000G0?ooo`/0003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001X0
oooo10000?m20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo
00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007@3oool00`000?l0oooo
0?ooo`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0R`3oool00`000000oooo0?ooo`0300000200oooo00<0003o0?ooo`3oool0@`3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08`0oooo0P00001Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool60000ocX0
oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`80003o1P3oool20000oc@0oooo
100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0;`3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0/0?ooo`<000003P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool08@3oool;0000ob/0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1D0?ooo`<0
00005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0D03oool4000001X0oooo00<000000?ooo`3oool0
D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0240oooo40000?lL0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01d0oooo0`00000R0?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool06@3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo01H0
oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0R0?ooo`80003o1P3oool00`000?l0oooo
0?ooo`0C0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool60000oa<0oooo0`00
000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01d0oooo3`000?l90?ooo`<0
0000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool08`3oool20000o``0oooo100000120?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00T0oooo0`0000170?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo00H0oooo0`00001:0?ooo`030000003oool0
oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0S0?ooo`D0003o0`0000000`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0
oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo
0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0L0?ooo`80003o0`0000000`3oool0003o0000o`080000oe00oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0
oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0E0?ooo`<00000303oool60000oe@0oooo00<000000?ooo`3oool0A`3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0A0?ooo`@000003@3oool20000o`H0oooo00<0003o0?ooo`3oool0DP3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000004@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`0;0?ooo`<000004`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0580oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00P0oooo0`00000G0?ooo`80003o1@3oool20000oeH0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool30000
01l0oooo00<0003o0?ooo`3oool0G@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00h0oooo000P0?ooo`800000T@3oool400000240oooo00@0003o0?ooo`000?l0003o0`3oool20000
oeT0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900
oooo0`00000S0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`1G0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0S03oool300000080oooo00<000000?ooo`3oool08@3oool00`000?l0oooo0?ooo`020?ooo`05
0000o`3oool0oooo0?ooo`000?l0FP3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo0280
oooo0P000?l20?ooo`050000o`3oool0oooo0?ooo`000?l0F`3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`03
0000003oool0oooo02L0oooo0`000?mM0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo01d0oooo2P000?l20?ooo`80003oGP3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo07`0oooo0`00000A0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3oool0G@3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00
000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?oo
o`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo
00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00
001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.49702 .68971 m
.49572 .68855 L
s
.49909 .689 m
.49702 .68971 L
s
.4978 .68785 m
.49909 .689 L
s
.49572 .68855 m
.4978 .68785 L
s
.46361 .68428 m
.48729 .68743 L
s
.49714 .68084 m
.50092 .68036 L
s
.49545 .68062 m
.49714 .68084 L
s
.49244 .67922 m
.49545 .68062 L
s
.50092 .68036 m
.50379 .67776 L
s
.49152 .67711 m
.49244 .67922 L
s
.48358 .67903 m
.48056 .67763 L
s
.50379 .67776 m
.50498 .67492 L
s
.48056 .67763 m
.48 .67457 L
s
.49176 .67214 m
.49152 .67711 L
s
.50498 .67492 m
.50447 .67185 L
s
.48 .67457 m
.48115 .67172 L
s
.49083 .67001 m
.49176 .67214 L
s
.50447 .67185 m
.50146 .67044 L
s
.48115 .67172 m
.484 .66909 L
s
.48781 .6686 m
.49083 .67001 L
s
.484 .66909 m
.48781 .6686 L
s
.50806 .66324 m
.50384 .6647 L
s
.51057 .66155 m
.50806 .66324 L
s
.49014 .66285 m
.48749 .66046 L
s
.51178 .65866 m
.51057 .66155 L
s
.48749 .66046 m
.48655 .65829 L
s
.51087 .65649 m
.51178 .65866 L
s
.48655 .65829 m
.48772 .65539 L
s
.50824 .65408 m
.51087 .65649 L
s
.48772 .65539 m
.49022 .65368 L
s
.50348 .6524 m
.50824 .65408 L
s
.49022 .65368 m
.49446 .6522 L
s
.50003 .65193 m
.50348 .6524 L
s
.49446 .6522 m
.50003 .65193 L
s
.49244 .64365 m
.51667 .64697 L
s
.47989 .64298 m
.47854 .64175 L
s
.48202 .64223 m
.47989 .64298 L
s
.48067 .641 m
.48202 .64223 L
s
.47854 .64175 m
.48067 .641 L
s
.50259 .63669 m
.51997 .63909 L
s
.49777 .63498 m
.50259 .63669 L
s
.49682 .63274 m
.49777 .63498 L
s
.49803 .62974 m
.49682 .63274 L
s
.50059 .62798 m
.49803 .62974 L
s
.48776 .62301 m
.52456 .62811 L
s
.50707 .62569 m
.50059 .62798 L
s
.5174 .61857 m
.52309 .61829 L
s
.51388 .61808 m
.5174 .61857 L
s
.52309 .61829 m
.52745 .61675 L
s
.50901 .61633 m
.51388 .61808 L
s
.52745 .61675 m
.53006 .61495 L
s
.50631 .61379 m
.50901 .61633 L
s
.53006 .61495 m
.53134 .61189 L
s
.50537 .6115 m
.50631 .61379 L
s
.53134 .61189 m
.53044 .60959 L
s
.50661 .60842 m
.50537 .6115 L
s
.53044 .60959 m
.52776 .60703 L
s
.50827 .60429 m
.54542 .60951 L
s
.50921 .60661 m
.50661 .60842 L
s
.51359 .60504 m
.50921 .60661 L
s
.51119 .59702 m
.53609 .60054 L
s
.53518 .59821 m
.53076 .59979 L
s
.53783 .59637 m
.53518 .59821 L
s
.51654 .59778 m
.51382 .59519 L
s
.53914 .59324 m
.53783 .59637 L
s
.51382 .59519 m
.51288 .59284 L
s
.53824 .59088 m
.53914 .59324 L
s
.51288 .59284 m
.51414 .58969 L
s
.53554 .58827 m
.53824 .59088 L
s
.51414 .58969 m
.51678 .58784 L
s
.53061 .58645 m
.53554 .58827 L
s
.51678 .58784 m
.52122 .58623 L
s
.52703 .58594 m
.53061 .58645 L
s
.52122 .58623 m
.52703 .58594 L
s
.51969 .57589 m
.5184 .5791 L
s
.52236 .57401 m
.51969 .57589 L
s
.52185 .57053 m
.54712 .57415 L
s
.52684 .57238 m
.52236 .57401 L
s
.5327 .57208 m
.52684 .57238 L
s
.54078 .56639 m
.53535 .56561 L
s
.54485 .56583 m
.54078 .56639 L
s
.54937 .56419 m
.54485 .56583 L
s
.53757 .56018 m
.53535 .56561 L
s
.55209 .56228 m
.54937 .56419 L
s
.52083 .56352 m
.51763 .56191 L
s
.55392 .55792 m
.55209 .56228 L
s
.51763 .56191 m
.51485 .5592 L
s
.51485 .5592 m
.51389 .55675 L
s
.55301 .55546 m
.55392 .55792 L
s
.51389 .55675 m
.51562 .55236 L
s
.55028 .55274 m
.55301 .55546 L
s
.54709 .5511 m
.55028 .55274 L
s
.51562 .55236 m
.51832 .55042 L
s
.54206 .5492 m
.54709 .5511 L
s
.51832 .55042 m
.52286 .54875 L
s
.53291 .54787 m
.54206 .5492 L
s
.52286 .54875 m
.52697 .54818 L
s
.52697 .54818 m
.53291 .54787 L
s
.53376 .54094 m
.56131 .54024 L
s
.53736 .53197 m
.56131 .54024 L
s
.53736 .53197 m
.56506 .53127 L
s
.54101 .52291 m
.56506 .53127 L
s
.54423 .5149 m
.57029 .51877 L
s
.56939 .5162 m
.56472 .51794 L
s
.57221 .51418 m
.56939 .5162 L
s
.54982 .51573 m
.54702 .51287 L
s
.57366 .51072 m
.57221 .51418 L
s
.54702 .51287 m
.54609 .51029 L
s
.57276 .50813 m
.57366 .51072 L
s
.54609 .51029 m
.54748 .50681 L
s
.56998 .50525 m
.57276 .50813 L
s
.54748 .50681 m
.55029 .50477 L
s
.56484 .50324 m
.56998 .50525 L
s
.55029 .50477 m
.55499 .503 L
s
.56109 .50268 m
.56484 .50324 L
s
.55499 .503 m
.56109 .50268 L
s
.5536 .4916 m
.55218 .49513 L
s
.55645 .48952 m
.5536 .4916 L
s
.55599 .48567 m
.58246 .48968 L
s
.56119 .48772 m
.55645 .48952 L
s
.56735 .48739 m
.56119 .48772 L
s
.57076 .47905 m
.57695 .47872 L
s
.56125 .4776 m
.57076 .47905 L
s
.57695 .47872 m
.58124 .4781 L
s
.58124 .4781 m
.58604 .47628 L
s
.55602 .47553 m
.56125 .4776 L
s
.58604 .47628 m
.58945 .47295 L
s
.55269 .47375 m
.55602 .47553 L
s
.54982 .47075 m
.55269 .47375 L
s
.58945 .47295 m
.593 .46447 L
s
.54934 .46683 m
.54982 .47075 L
s
.55271 .45829 m
.54934 .46683 L
s
.55271 .45829 m
.593 .46447 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1L0?ooo`@0003o<P3oool00`000000oooo0?ooo`0Q
0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo05/0oooo00@0003o0?ooo`3oool0oooo20000?lZ0?ooo`030000003oool0
oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo
05X0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`0:0?ooo`@0003o9`3oool00`00
0000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo05P0oooo00<0003o0?ooo`3oool03@3oool00`000?l0
oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000003oool0oooo01P0
oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo00`0oooo
00<0003o0?ooo`3oool09P3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0EP3oool00`000?l0oooo0?oo
o`0<0?ooo`030000o`3oool0oooo02H0oooo00<000000?ooo`3oool04@3oool300000440oooo00<0
00000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1F
0?ooo`80003o2`3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo00h0oooo0`000014
0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0E`3oool30000o`H0oooo0P000?lZ0?ooo`030000003oool0oooo00X0oooo100000170?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0F@3oool60000ob`0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`2:0?ooo`030000
003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo06<0oooo00<000000?ooo`3oool0D`3oool30000oc<0oooo00@000000?ooo`3oool0oooo
0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<0
00000?ooo`3oool0E03oool60000obh0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[
0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0D03oool30000o`H0oooo0`000?lY
0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?oo
o`030000003oool0oooo04l0oooo00<0003o0?ooo`3oool0;`3oool300000080oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`03
0000003oool0oooo04h0oooo00<0003o0?ooo`3oool0;03oool3000000D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0
NP3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3o
ool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo07H0oooo0`00000;0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0B`3oool60000ob40oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`1[0?ooo`030000003oool0oooo04T0oooo00<0003o0?ooo`3oool0103oool2
0000oa`0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo04L0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0F0?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`170?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool04P3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0A@3oool30000o`L0oooo00<0003o0?ooo`3oool0403oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`170?ooo`L0003o403oool30000
01h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo04/0oooo0`000?l;0?ooo`@000008@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0@@3oool20000oa80oooo0`00000U0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`120?ooo`<0003o303oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0A03oool30000o`H0oooo0`00000[
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?03oool<0000o`040?ooo`0000000000
000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`00
0000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?@3oool20000
o`H0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03h0
oooo0P000?l0103oool0000000000000000d0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0?@3oool200000080003o=P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0=`3oool;0000oc@0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?oo
o`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a
0?ooo`<000000`000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`03000000000?l0003o
00<0003o0`3oool20000oc/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000000`000?l0
oooo0?ooo`080?ooo`<0003o>03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000000P3oool00`000?l0oooo
0?ooo`0<0?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00
00050?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool0=@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool0703oool4000000T0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000>0?oo
o`80003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03H0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo01@0oooo0`00000G0?ooo`L0003o>@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000H0?ooo`D0003o@03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0203oool3000001`0oooo0`000?l00`3oool0003o0000o`04
0000ocX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000N0?ooo`030000o`3oool0oooo
0480oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<00000803oool00`000?l0oooo0?ooo`130?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
S03oool2000006T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool0I`3oool2000005/0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`P0003o>P3oool3
00000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`0c0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0803oool00`000?l0
oooo0?ooo`070?ooo`030000o`3oool0oooo0300oooo0`00000:0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0P0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0;P3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01l0oooo1@000?l40?ooo`80003o;@3oool300000180oooo00<0
00000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02@0oooo1P000?lZ0?ooo`<000005P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool07P3oool40000obh0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`80
003o00<0oooo0000o`000?l01@000?lT0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0003o00<0003o7@3oool300000280oooo
00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo01d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`0M0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S
0?ooo`800000S`3oool00`000000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool06P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01l0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`0G0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool08@3oool60000oaL0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?ooo`@0003o
7`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0oooo1P000?lF0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool07@3oool20000o`<0oooo10000?l?0?ooo`<00000?P3oool0
0`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0B0?ooo`@00000@P3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0@0?ooo`<00000A`3oool00`000000
oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`0=0?ooo`<00000BP3oool00`000000oooo
0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0703oool90000o`<0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<0
00000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo01@0oooo0P000?l?
0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?oo
o`800000T03oool00`000000oooo0?ooo`0E0?ooo`80003o0P3oool50000o`<0oooo1000001F0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0N0?ooo`<000000`000?mH0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool06`3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0603oool3000000@0003oGP3oool00`000000oooo0?ooo`180?ooo`030000
003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0E0?ooo`<0000000<0oooo0000o`3oool0103oool00`000?l0oooo0?oo
o`1L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P000007
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000000<0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00h0oooo0`0000060?ooo`80003o203oool00`000?l0oooo0?ooo`1L0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000000/0oooo00<0003o0?ooo`3o
ool00`3oool20000oel0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000C0?ooo`030000
o`3oool0oooo0600oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000@0?ooo`030000o`3o
ool0oooo06L0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<000004P3oool20000o`030?ooo`00
0?l0oooo0080oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo00h0oooo000P0?ooo`800000T@3oool4000001@0oooo00D0003o0?ooo`3oool0oooo0000
o`040?ooo`030000o`3oool0oooo06<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool200000900oooo0`00000G0?ooo`050000o`3oool0oooo0?ooo`000?l0103o
ool00`000?l0oooo0?ooo`1S0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool05@3oool2
0000o`80oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool40000
00D0oooo00<000000?ooo`3oool06P3oool40000ofP0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000
oooo0?ooo`0?0?ooo`<0003oM@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo0180oooo
10000?mb0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool05P3oool30000o`80oooo0P00
0?m/0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3
000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo
0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool30000
04D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool30000
06D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool30000
08@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo000000020000
09@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo
0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?oo
o`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo
0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo
0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00
000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J
0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool01000
0000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0
oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo
00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?oo
o`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`33
0?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?oo
o`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00
L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3o
ool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000
oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo
0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?oo
o`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00
000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000
001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<00000
0?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@0
0000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@0
0000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000
I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0
oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<00000
0?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?oo
o`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D0
0000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000
UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool20000
00`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo
0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo
1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00
000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00
000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T
0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D0
0000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?oo
o`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00
003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P000004
0?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.4599 .68414 m
.45903 .68285 L
s
.4622 .68368 m
.4599 .68414 L
s
.46133 .6824 m
.4622 .68368 L
s
.45903 .68285 m
.46133 .6824 L
s
.42879 .67491 m
.4511 .68077 L
s
.46316 .67544 m
.46705 .6754 L
s
.46157 .67502 m
.46316 .67544 L
s
.46705 .6754 m
.47081 .67318 L
s
.4591 .6733 m
.46157 .67502 L
s
.45894 .67111 m
.4591 .6733 L
s
.47081 .67318 m
.47298 .67054 L
s
.45041 .67207 m
.44792 .67035 L
s
.46093 .66626 m
.45894 .67111 L
s
.47298 .67054 m
.47356 .66746 L
s
.44792 .67035 m
.44846 .66726 L
s
.47356 .66746 m
.47109 .66572 L
s
.44846 .66726 m
.4506 .6646 L
s
.46077 .66406 m
.46093 .66626 L
s
.4506 .6646 m
.45435 .66235 L
s
.45828 .66231 m
.46077 .66406 L
s
.45435 .66235 m
.45828 .66231 L
s
.48013 .65943 m
.47546 .66037 L
s
.4832 .65807 m
.48013 .65943 L
s
.48542 .65537 m
.4832 .65807 L
s
.46262 .65693 m
.46085 .65427 L
s
.48529 .65313 m
.48542 .65537 L
s
.46085 .65427 m
.46069 .65203 L
s
.48355 .65046 m
.48529 .65313 L
s
.46069 .65203 m
.46287 .64931 L
s
.47946 .64825 m
.48355 .65046 L
s
.46287 .64931 m
.46595 .64793 L
s
.47623 .64738 m
.47946 .64825 L
s
.46595 .64793 m
.47065 .64698 L
s
.47065 .64698 m
.47623 .64738 L
s
.47167 .63835 m
.49434 .64448 L
s
.48413 .63273 m
.50036 .63715 L
s
.45954 .63618 m
.45864 .63482 L
s
.46191 .6357 m
.45954 .63618 L
s
.46101 .63434 m
.46191 .6357 L
s
.45864 .63482 m
.46101 .63434 L
s
.47999 .63047 m
.48413 .63273 L
s
.47985 .62816 m
.47999 .63047 L
s
.4821 .62536 m
.47985 .62816 L
s
.47437 .61752 m
.50873 .62694 L
s
.48524 .62394 m
.4821 .62536 L
s
.49242 .62247 m
.48524 .62394 L
s
.51075 .61715 m
.51557 .61616 L
s
.50507 .61674 m
.51075 .61715 L
s
.50179 .61583 m
.50507 .61674 L
s
.51557 .61616 m
.51875 .61472 L
s
.49763 .61353 m
.50179 .61583 L
s
.51875 .61472 m
.52109 .61187 L
s
.49587 .61072 m
.49763 .61353 L
s
.52109 .61187 m
.52101 .60951 L
s
.50115 .60164 m
.53568 .61125 L
s
.49576 .60835 m
.49587 .61072 L
s
.52101 .60951 m
.51929 .60669 L
s
.49806 .60548 m
.49576 .60835 L
s
.50125 .60402 m
.49806 .60548 L
s
.5061 .60302 m
.50125 .60402 L
s
.50658 .59488 m
.52972 .60135 L
s
.52965 .59896 m
.52478 .59997 L
s
.53289 .59749 m
.52965 .59896 L
s
.53527 .59458 m
.53289 .59749 L
s
.51155 .59627 m
.5098 .5934 L
s
.53521 .59217 m
.53527 .59458 L
s
.5098 .5934 m
.5097 .59098 L
s
.5335 .58929 m
.53521 .59217 L
s
.5097 .59098 m
.51206 .58805 L
s
.52931 .5869 m
.5335 .58929 L
s
.51206 .58805 m
.5153 .58656 L
s
.52599 .58597 m
.52931 .5869 L
s
.5153 .58656 m
.52021 .58554 L
s
.52021 .58554 m
.52599 .58597 L
s
.52235 .57523 m
.51996 .57821 L
s
.52635 .57025 m
.54976 .57692 L
s
.52562 .57372 m
.52235 .57523 L
s
.53058 .57268 m
.52562 .57372 L
s
.5364 .57311 m
.53058 .57268 L
s
.54629 .56855 m
.54127 .56711 L
s
.55046 .56851 m
.54629 .56855 L
s
.55544 .56746 m
.55046 .56851 L
s
.55876 .56594 m
.55544 .56746 L
s
.54534 .56208 m
.54127 .56711 L
s
.56207 .56191 m
.55876 .56594 L
s
.52782 .56327 m
.52525 .56129 L
s
.56205 .5594 m
.56207 .56191 L
s
.52525 .56129 m
.52348 .5583 L
s
.56034 .5564 m
.56205 .5594 L
s
.52348 .5583 m
.52341 .55578 L
s
.55781 .55441 m
.56034 .5564 L
s
.52341 .55578 m
.52665 .55171 L
s
.55357 .55193 m
.55781 .55441 L
s
.54512 .54948 m
.55357 .55193 L
s
.52665 .55171 m
.52997 .55015 L
s
.52997 .55015 m
.535 .54908 L
s
.53921 .54904 m
.54512 .54948 L
s
.535 .54908 m
.53921 .54904 L
s
.54838 .54282 m
.57544 .5456 L
s
.55504 .53452 m
.57544 .5456 L
s
.55504 .53452 m
.58223 .53732 L
s
.56177 .52613 m
.58223 .53732 L
s
.56772 .51873 m
.59167 .52581 L
s
.59169 .5232 m
.58655 .5243 L
s
.59513 .52159 m
.59169 .5232 L
s
.59774 .51841 m
.59513 .52159 L
s
.57287 .52025 m
.57114 .51711 L
s
.59778 .51577 m
.59774 .51841 L
s
.57114 .51711 m
.57114 .51447 L
s
.59609 .51261 m
.59778 .51577 L
s
.57114 .51447 m
.57371 .51126 L
s
.59181 .51 m
.59609 .51261 L
s
.57371 .51126 m
.57716 .50963 L
s
.58837 .50898 m
.59181 .51 L
s
.57716 .50963 m
.58234 .50851 L
s
.58234 .50851 m
.58837 .50898 L
s
.58498 .49722 m
.58237 .50048 L
s
.58937 .49176 m
.6136 .49907 L
s
.58847 .49557 m
.58498 .49722 L
s
.5937 .49443 m
.58847 .49557 L
s
.59978 .4949 m
.5937 .49443 L
s
.6121 .48771 m
.61647 .48766 L
s
.606 .48723 m
.6121 .48771 L
s
.61647 .48766 m
.62174 .48651 L
s
.5973 .48459 m
.606 .48723 L
s
.62174 .48651 m
.62619 .48373 L
s
.59295 .4819 m
.5973 .48459 L
s
.62619 .48373 m
.63256 .47595 L
s
.59034 .47973 m
.59295 .4819 L
s
.58861 .47644 m
.59034 .47973 L
s
.58952 .47255 m
.58861 .47644 L
s
.59577 .46468 m
.63256 .47595 L
s
.59577 .46468 m
.58952 .47255 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo06X0oooo0P000?lU0?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`030000ob80oooo
00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00
001M0?ooo`030000003oool0oooo06L0oooo00<0003o0?ooo`3oool00`3oool20000ob00oooo00<0
00000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O
0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3oool01P3oool30000oad0oooo00<00000
0?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`1S0?ooo`030000o`3oool0oooo00X0oooo0`000?lJ0?oo
o`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0600oooo00<000000?ooo`3oool0HP3oool00`000?l0oooo0?ooo`0=0?ooo`80
003o603oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0680oooo00<0003o0?ooo`3oool0
2`3oool20000oaT0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000o`3o
ool0oooo00T0oooo00<0003o0?ooo`3oool06@3oool00`000000oooo0?ooo`040?ooo`<00000CP3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo0680oooo0`000?l70?ooo`030000o`3oool0oooo01X0oooo00@000000?ooo`3oool0oooo0`00
001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<00000
0?ooo`3oool0I03oool80000oa`0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0GP3oool20000obD0oooo0`00001H0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0GP3oool40000oal0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1K0?ooo`80003o
0P3oool50000oaT0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo05X0oooo00<0003o0?ooo`3oool01`3o
ool20000oa@0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0
oooo01/0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0LP3oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0KP3oool30000
0140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0D`3oool70000
oa00oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
0540oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1?0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool01P3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`1>0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool3000001h0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1a0?ooo`030000003oool0oooo04`0oooo0`000?l70?ooo`030000o`3oool0oooo00@00000
8@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0CP3oool40000o`80oooo0P000?l2000002D0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d
0?ooo`030000003oool0oooo04L0oooo00<0003o0?ooo`3oool01`3oool30000obP0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?oo
o`3oool0A`3oool20000o`@0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0B03oool20000o`800000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`120?ooo`D0003o00@000000?ooo`000?l0003o;P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`110?ooo`03000000000?l0003o0080oooo1P000?l/0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000000<0oooo00<0003o0?ooo`3oool0<@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0>@3oool3000000L0oooo00<0003o0?ooo`3oool0<03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo
07`0oooo00<000000?ooo`3oool0=@3oool3000000<0oooo1@000?l30?ooo`80003o<03oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0<@3oool3000000/0oooo1P000?l_0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<000000P3oool80000ocT0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00
00040?ooo`030000o`3oool0oooo00H0oooo0P000?lg0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`000006
0?ooo`030000o`3oool0oooo00T0oooo0P000?le0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?oo
o`<000002@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0380oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`03
0000003oool0oooo01`0oooo1000000=0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool0<`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000180oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo01@0oooo0`00000J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0=03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08H0oooo00<000000?ooo`3oool0403oool3000001d0oooo1P000?lg0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`00
0000oooo0?ooo`0<0?ooo`<000006P3oool30000od00oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0
oooo0`00000M0?ooo`L0003o?03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001l0oooo
00<0003o0?ooo`3oool01@3oool30000ocT0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008@3o
ool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08`3oool00`00
0?l0oooo0?ooo`110?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo0200oooo0`000?l0103oool0003o0000o`000?lm0?oo
o`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`050?ooo`80
003o=`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`0b0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07P3o
ool30000o`L0oooo00<0003o0?ooo`3oool0;`3oool3000000h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0200oooo10000?l20?ooo`<0003o;P3oool300000180oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
01`0oooo0P000?l60?ooo`<0003o;@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01`0
oooo1@000?l_0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo
0?ooo`030?ooo`@0003o:03oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01X0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0000o`020000ob80oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool2
0000oad0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool0
02<0oooo0P00002?0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0O0?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04P3oool20000o`L0
oooo1`000?lN0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05@3oool30000obH0oooo
0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?ooo`@0003o7`3oool3000003H0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01H0oooo0`000?l30?ooo`<0003o6@3oool3000003X0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01`3oool20000oa@0oooo0`00000n0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01T0oooo100000120?ooo`03
0000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0F0?ooo`80003o5P3oool3000004L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo00d0oooo0P000?l90?ooo`<0003o403oool3000004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo0180oooo0P000?l70?ooo`80003o2`3oool3000004h0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0503oool40000
o`d0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240
oooo0P00002@0?ooo`030000003oool0oooo01P0oooo0`000?l60?ooo`@00000EP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0:0?ooo`<00000F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00h0oooo0`000?l00`3oool0003o0000o`020000o`D0oooo0`00
001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@00000
0?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0000000200000680oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`<00000IP3oool0
0`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0003o0?ooo`3oool0100000020?oo
o`030000o`3oool0oooo06D0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool300000080oooo10000?mY0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
2`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`0000030?ooo`050000o`3o
ool0oooo0?ooo`000?l0KP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000000030?ooo`00
0?l0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`1_0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?oo
o`3oool3000000D0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo06h0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo
100000090?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool0L03oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000000@0oooo
0P000?l:0?ooo`<0003oL`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo00@0oooo1000
0?mm0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0203oool30000og/0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?oo
o`<000002@3oool00`000000oooo0?ooo`0=0?ooo`80003oN03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`03
0000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03o
ool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0
oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`00
0000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00
000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3o
ool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0
oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0
oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<00000
0?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`03
0000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3o
ool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo
02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0
oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<0
0000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000
003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803o
ool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0
oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<0
0000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0
Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?oo
o`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3o
ool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000
403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool0
0`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool0
01<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool20000
00030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`80
0000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3o
ool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool0
0`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool0
03<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000
oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3o
ool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103o
ool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool20000
06/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo
0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool20000
06<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo
0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00
001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?oo
o`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@00000
0?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:
0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?oo
o`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000
003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3o
ool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3o
ool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`00
00030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<00000
0?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`00
00020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3o
ool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@00000
4P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3o
ool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool0
06h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000
oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo
00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?oo
o`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D0
0000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000
?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000
<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool00000
4@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03o
ool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0
R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3o
ool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5
000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0
oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0
oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo
0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?oo
o`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?oo
o`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3o
ool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4
000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo
0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000
000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A
0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?oo
o`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/
0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?oo
o`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`80
00004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00
IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000
003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<00000
4P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0
oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo1000
00320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool4
00000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0
oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo
0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@0
0000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3o
ool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42516 .67433 m
.42475 .67297 L
s
.4276 .67416 m
.42516 .67433 L
s
.42719 .67279 m
.4276 .67416 L
s
.42475 .67297 m
.42719 .67279 L
s
.39752 .66157 m
.41762 .66998 L
s
.43535 .66657 m
.43985 .66482 L
s
.43148 .66615 m
.43535 .66657 L
s
.43005 .66555 m
.43148 .66615 L
s
.42821 .66356 m
.43005 .66555 L
s
.43985 .66482 m
.44294 .66247 L
s
.42883 .66139 m
.42821 .66356 L
s
.44294 .66247 m
.44461 .65951 L
s
.43253 .65684 m
.42883 .66139 L
s
.42003 .66133 m
.41817 .65933 L
s
.44461 .65951 m
.44278 .65751 L
s
.41817 .65933 m
.4198 .65636 L
s
.43315 .65465 m
.43253 .65684 L
s
.4198 .65636 m
.42287 .65398 L
s
.43131 .65264 m
.43315 .65465 L
s
.42287 .65398 m
.4274 .65221 L
s
.45395 .65239 m
.449 .65276 L
s
.4274 .65221 m
.43131 .65264 L
s
.45747 .65141 m
.45395 .65239 L
s
.46061 .64902 m
.45747 .65141 L
s
.46127 .64681 m
.46061 .64902 L
s
.43751 .64786 m
.4367 .64503 L
s
.46051 .64398 m
.46127 .64681 L
s
.4367 .64503 m
.43734 .6428 L
s
.45724 .64132 m
.46051 .64398 L
s
.43734 .6428 m
.44047 .64039 L
s
.45436 .64008 m
.45724 .64132 L
s
.44047 .64039 m
.444 .63939 L
s
.44899 .63902 m
.45436 .64008 L
s
.444 .63939 m
.44899 .63902 L
s
.45306 .63065 m
.47326 .63939 L
s
.46735 .62662 m
.48178 .6329 L
s
.44183 .62707 m
.44143 .62561 L
s
.44434 .62688 m
.44183 .62707 L
s
.44394 .62542 m
.44434 .62688 L
s
.46407 .6239 m
.46735 .62662 L
s
.44143 .62561 m
.44394 .62542 L
s
.46475 .62162 m
.46407 .6239 L
s
.46311 .6105 m
.49361 .6239 L
s
.46796 .61914 m
.46475 .62162 L
s
.47156 .61812 m
.46796 .61914 L
s
.47914 .61755 m
.47156 .61812 L
s
.49905 .61454 m
.50412 .61415 L
s
.49361 .61345 m
.49905 .61454 L
s
.50412 .61415 m
.50776 .61313 L
s
.49071 .61217 m
.49361 .61345 L
s
.50776 .61313 m
.51105 .61062 L
s
.48744 .6094 m
.49071 .61217 L
s
.49509 .59817 m
.52555 .61178 L
s
.51105 .61062 m
.5118 .6083 L
s
.4867 .60643 m
.48744 .6094 L
s
.5118 .6083 m
.51111 .60533 L
s
.48742 .6041 m
.4867 .60643 L
s
.4907 .60157 m
.48742 .6041 L
s
.49435 .60052 m
.4907 .60157 L
s
.50281 .59221 m
.5232 .60137 L
s
.49947 .60013 m
.49435 .60052 L
s
.52398 .59902 m
.51885 .59941 L
s
.52766 .59797 m
.52398 .59902 L
s
.53101 .59542 m
.52766 .59797 L
s
.5318 .59306 m
.53101 .59542 L
s
.5072 .59418 m
.50649 .59115 L
s
.53114 .59003 m
.5318 .59306 L
s
.50649 .59115 m
.50725 .58878 L
s
.52789 .58719 m
.53114 .59003 L
s
.50725 .58878 m
.51059 .5862 L
s
.52497 .58586 m
.52789 .58719 L
s
.51059 .5862 m
.51429 .58513 L
s
.51946 .58473 m
.52497 .58586 L
s
.51429 .58513 m
.51946 .58473 L
s
.53085 .57054 m
.55135 .57994 L
s
.52518 .57492 m
.5218 .57753 L
s
.52892 .57384 m
.52518 .57492 L
s
.53966 .57458 m
.53412 .57344 L
s
.53412 .57344 m
.52892 .57384 L
s
.55499 .57182 m
.55091 .57134 L
s
.56021 .57141 m
.55499 .57182 L
s
.56397 .57033 m
.56021 .57141 L
s
.55091 .57134 m
.54651 .56932 L
s
.5686 .56681 m
.56397 .57033 L
s
.55226 .56491 m
.54651 .56932 L
s
.56945 .56436 m
.5686 .56681 L
s
.56885 .56123 m
.56945 .56436 L
s
.53474 .56389 m
.53292 .56164 L
s
.53292 .56164 m
.53225 .5585 L
s
.56708 .55897 m
.56885 .56123 L
s
.56383 .55602 m
.56708 .55897 L
s
.53225 .5585 m
.53306 .55603 L
s
.53306 .55603 m
.53766 .55244 L
s
.55645 .55258 m
.56383 .55602 L
s
.55085 .55141 m
.55645 .55258 L
s
.56197 .54649 m
.58729 .55258 L
s
.57136 .53923 m
.58729 .55258 L
s
.53766 .55244 m
.54145 .55134 L
s
.54673 .55092 m
.55085 .55141 L
s
.54145 .55134 m
.54673 .55092 L
s
.57136 .53923 m
.59676 .54537 L
s
.58083 .53191 m
.59676 .54537 L
s
.58919 .52545 m
.60991 .53536 L
s
.61084 .53282 m
.60549 .53324 L
s
.61473 .53169 m
.61084 .53282 L
s
.61835 .52893 m
.61473 .53169 L
s
.61931 .52637 m
.61835 .52893 L
s
.59365 .52758 m
.59308 .52431 L
s
.61878 .52309 m
.61931 .52637 L
s
.59308 .52431 m
.59399 .52174 L
s
.61556 .52001 m
.61878 .52309 L
s
.59399 .52174 m
.59761 .51894 L
s
.61259 .51858 m
.61556 .52001 L
s
.59761 .51894 m
.60152 .51779 L
s
.60692 .51736 m
.61259 .51858 L
s
.60152 .51779 m
.60692 .51736 L
s
.61955 .50198 m
.64037 .51216 L
s
.61341 .50673 m
.60975 .50956 L
s
.61736 .50556 m
.61341 .50673 L
s
.62851 .50636 m
.6228 .50512 L
s
.6228 .50512 m
.61736 .50556 L
s
.64709 .50147 m
.65256 .50103 L
s
.64288 .50095 m
.64709 .50147 L
s
.65256 .50103 m
.6578 .4989 L
s
.63717 .49971 m
.64288 .50095 L
s
.6297 .49603 m
.63717 .49971 L
s
.6578 .4989 m
.66661 .49219 L
s
.62644 .49286 m
.6297 .49603 L
s
.62468 .49042 m
.62644 .49286 L
s
.63516 .47651 m
.66661 .49219 L
s
.62416 .487 m
.62468 .49042 L
s
.62639 .48334 m
.62416 .487 L
s
.63516 .47651 m
.62639 .48334 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3oool05@3oool00`000000
oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo
0?ooo`1Q0?ooo`030000003oool0oooo0740oooo0P000?l00`3oool0003o0000o`0E0?ooo`030000
003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0KP3oool20000o`D0oooo0P000?lC0?ooo`030000003o
ool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0
oooo06<0oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo0?ooo`060?ooo`80003o4@3oool0
10000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<00000
0?ooo`3oool0I03oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00P0oooo0P000?l?
0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool02P3oool20000o`/0oooo0`00001H0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3o
ool0JP3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00D0oooo0`0000020?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000
J03oool00`000000oooo0?ooo`1Z0?ooo`80003o2P3oool20000o`D0oooo0`0000050?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003o
ool0oooo06`0oooo0`000?l60?ooo`030000o`3oool0oooo0080oooo0`0000080?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo00D0oooo1P000?l20?ooo`<000002`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo06H0oooo0P000?l:0?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1R0?ooo`<0003o00@0oooo0000
o`000?l0003o1@3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F
0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool0G`3oool20000o`L0oooo0P000?l3000001@0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool0IP3oool300000080003o5P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?ooo`<000006`3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo05T0oooo1@000?l3000001h0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05L0
oooo00<0003o0?ooo`0000000`0000000`000?l0oooo0?ooo`0N0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1D0?ooo`80003o0P0000050?ooo`80003o7P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0D@3o
ool00`000000003o0000o`090?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3
00000080oooo0P000?l70?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`190?ooo`<0000000<0003o0?ooo`3oool0103oool20000o`@0oooo00<0003o0?oo
o`3oool07P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<0
0000103oool00`000?l0oooo0?ooo`050?ooo`@0003o8@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`110?ooo`<00000203oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0200oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<000001P3o
ool30000o`<0oooo0P000?lY0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000002P3oool0
0`000?l0oooo0000o`030000o`030?ooo`000?l0oooo02L0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
03D0oooo0`00000>0?ooo`030000o`3oool0oooo0080oooo0`000?lW0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`0a0?ooo`<000002`3oool30000o`@0oooo0P000?l/0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<000004@3oool50000o`030?ooo`000?l0oooo02X0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo02T0oooo0`0000080?ooo`T0003o203oool30000obX0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3
000000X0oooo00<0003o0?ooo`3oool01`3oool20000oc<0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000<0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0<@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0703oool4000000l0oooo00<0003o0?ooo`3oool02P3oool20000oc80
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000D0?ooo`030000o`3oool0oooo00X0oooo
00<0003o0?ooo`3oool0<03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000001h0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<000007`3oool20000o`D0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0303oool3000001`0oooo0P000?l50?ooo`H0003o=03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0203oool3000001h0oooo1@000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000
7P3oool30000o`D0oooo0P000?lk0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000002/0oooo0P00
0?li0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0S03oool2000006T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08@3oool30000od<0oooo0P00001K0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool07`3oool20000o`<0oooo0`000?lm0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03H0oooo100000060?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0L0?ooo`<0003o203oool00`000?l0oooo0?ooo`0c0?ooo`<000002P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool07P3oool20000o`L0oooo00<0003o0?ooo`3oool0<03oool3
000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo01T0oooo0P000?l50?ooo`<0003o0`3oool00`00
0?l0oooo0?ooo`0^0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0603oool50000o`D0
oooo10000?l^0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo
0?ooo`030?ooo`80003o<@3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01H0oooo00<0
003o0?ooo`3oool01P3oool30000ob/0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0G
0?ooo`030000o`3oool0oooo00H0oooo00@0003o0?ooo`000?l0003o9P3oool300000280oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo00h0oooo0P000?l80?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00P3oool20000ob40oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<00000
0?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo0100oooo0P000?l70?oo
o`H0003o9@3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0180oooo0`000?l[0?ooo`@0
0000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0403oool40000o`030?ooo`000?l0003o02L0oooo
0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00D0oooo0P00
0?lR0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01P3oool20000o`L0oooo00<0003o
0?ooo`3oool01`3oool20000oad0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?oo
o`80003o1`3oool20000ob<0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0;0?ooo`03
0000o`3oool0oooo00@0oooo0P000?lM0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
303oool20000o`H0oooo0P000?lH0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool03P3o
ool20000oa/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0
oooo00@0oooo0P000?lF0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`060?ooo`<0003o00@0oooo0000
o`000?l0003o1@3oool00`000?l0oooo0?ooo`0@0?ooo`<00000DP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo00D0oooo0P000?lB0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo0`00001K0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo00X0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`050000
003oool0oooo0?ooo`000?l02@3oool30000o`X0oooo0`00001R0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`050000003oool0oooo0000o`3oool00P000?l50?ooo`80003o2P3oool3000006H0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo
00<000000?ooo`3oool0S`3oool00`000000003o0000o`030?ooo`050000o`3oool0oooo0?ooo`00
0?l02@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00
603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000000o`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0`00001_0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo08T0oooo0P000?l50?ooo`03000000000?l0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool010000?l0oooo0?ooo`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2;0?ooo`80003o0`3oool00`000000oooo0?oo
o`020?ooo`060000o`3oool0oooo0?ooo`000?l0oooo0`00001f0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0S@3oool30000o`030000
003oool0oooo00<0oooo00<0003o0000000000000P00001j0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool20000o`80oooo0`00
001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A
0?ooo`@0000000<0003o0?ooo`3oool0P03oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00h0oooo000O0?ooo`800000T03oool300000080oooo0P000?n20?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080
oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`250?ooo`<000002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<00000
0?ooo`3oool0R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<0
00004@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0
oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<00000
0?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<0
0000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool0
0`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`00
0000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0
oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo
0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P00
00190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<00000
0?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@0
0000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool0
0`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0
oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<0
00000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z
0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`09
0?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?oo
o`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@0
0000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool0
0`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140
oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:
0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo
0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00
002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool0
0`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?oo
o`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000
003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3o
ool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0
oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?oo
o`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`80
0000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000
003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3o
ool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo
07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0
L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo
0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`03
0000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00
@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0
a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3o
ool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3o
ool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo
0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000
oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0
b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3o
ool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3o
ool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0
oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080
oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo
0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo
0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo0014
0?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`03
0000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00
F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0
oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0
oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo
000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3o
ool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080
oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<
0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?oo
o`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00
K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3o
ool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0
000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`00
0000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000
000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i
0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?oo
o`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?oo
o`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?oo
o`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?oo
o`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`04
0000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?oo
o`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@0
0000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000
F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool0
10000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool0
0`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool20000
02H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?oo
o`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<0
00000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D0
0000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000
S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool20000
01H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180
oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo
00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?oo
o`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo
001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<0
00000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A
0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?oo
o`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?oo
o`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?oo
o`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool0
00000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80
oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000
aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2
000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo
0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H
0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo
003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.3966 .66069 m
.39411 .66058 L
s
.39668 .65929 m
.3966 .66069 L
s
.39411 .66058 m
.39419 .65918 L
s
.39419 .65918 m
.39668 .65929 L
s
.37107 .64468 m
.38815 .65539 L
s
.40702 .65412 m
.41212 .65293 L
s
.40332 .65324 m
.40702 .65412 L
s
.40211 .65248 m
.40332 .65324 L
s
.41212 .65293 m
.41603 .65098 L
s
.40099 .6503 m
.40211 .65248 L
s
.41603 .65098 m
.41874 .64826 L
s
.40238 .64823 m
.40099 .6503 L
s
.41874 .64826 m
.41764 .64607 L
s
.40768 .64419 m
.40238 .64823 L
s
.39363 .64713 m
.3925 .64493 L
s
.3925 .64493 m
.39518 .64219 L
s
.40908 .6421 m
.40768 .64419 L
s
.43054 .64236 m
.4255 .64213 L
s
.43437 .64181 m
.43054 .64236 L
s
.39518 .64219 m
.39909 .64021 L
s
.40796 .63989 m
.40908 .6421 L
s
.43833 .63983 m
.43437 .64181 L
s
.39909 .64021 m
.40422 .639 L
s
.40422 .639 m
.40796 .63989 L
s
.43977 .63773 m
.43833 .63983 L
s
.44002 .63485 m
.43977 .63773 L
s
.41583 .63592 m
.41604 .63303 L
s
.43773 .63184 m
.44002 .63485 L
s
.41604 .63303 m
.41746 .63092 L
s
.43738 .62084 m
.45426 .63187 L
s
.43532 .63027 m
.43773 .63184 L
s
.41746 .63092 m
.42142 .62891 L
s
.43037 .62859 m
.43532 .63027 L
s
.42142 .62891 m
.42529 .62836 L
s
.42529 .62836 m
.43037 .62859 L
s
.45295 .6186 m
.46497 .62651 L
s
.45447 .60223 m
.47981 .61909 L
s
.45066 .61553 m
.45295 .6186 L
s
.43008 .61606 m
.42752 .61595 L
s
.43019 .61458 m
.43008 .61606 L
s
.42752 .61595 m
.42763 .61447 L
s
.45215 .61337 m
.45066 .61553 L
s
.42763 .61447 m
.43019 .61458 L
s
.4562 .61132 m
.45215 .61337 L
s
.46012 .61075 m
.4562 .61132 L
s
.46781 .61111 m
.46012 .61075 L
s
.49036 .59403 m
.51545 .61107 L
s
.49359 .6108 m
.49753 .61024 L
s
.48847 .61057 m
.49359 .6108 L
s
.48351 .60884 m
.48847 .61057 L
s
.49753 .61024 m
.50164 .60818 L
s
.48111 .60723 m
.48351 .60884 L
s
.50164 .60818 m
.5032 .606 L
s
.47886 .60411 m
.48111 .60723 L
s
.5032 .606 m
.50357 .603 L
s
.47918 .60111 m
.47886 .60411 L
s
.48072 .59891 m
.47918 .60111 L
s
.50005 .58913 m
.51682 .60059 L
s
.48484 .59682 m
.48072 .59891 L
s
.51841 .59839 m
.51325 .59815 L
s
.52238 .59781 m
.51841 .59839 L
s
.52655 .59573 m
.52238 .59781 L
s
.4888 .59625 m
.48484 .59682 L
s
.49397 .59649 m
.4888 .59625 L
s
.52816 .59351 m
.52655 .59573 L
s
.52857 .59047 m
.52816 .59351 L
s
.50366 .5916 m
.50403 .58855 L
s
.5264 .58729 m
.52857 .59047 L
s
.50403 .58855 m
.50561 .58631 L
s
.524 .58564 m
.5264 .58729 L
s
.50561 .58631 m
.5098 .5842 L
s
.51901 .58386 m
.524 .58564 L
s
.5098 .5842 m
.5138 .58361 L
s
.5138 .58361 m
.51901 .58386 L
s
.53514 .57137 m
.55185 .58308 L
s
.52806 .57495 m
.52383 .5771 L
s
.54233 .57641 m
.53732 .57461 L
s
.56346 .57585 m
.55823 .5756 L
s
.5675 .57526 m
.56346 .57585 L
s
.55823 .5756 m
.55443 .57464 L
s
.57323 .57239 m
.5675 .57526 L
s
.53209 .57436 m
.52806 .57495 L
s
.55443 .57464 m
.55086 .57212 L
s
.53732 .57461 m
.53209 .57436 L
s
.57491 .57012 m
.57323 .57239 L
s
.558 .56852 m
.55086 .57212 L
s
.57542 .56699 m
.57491 .57012 L
s
.57449 .56457 m
.57542 .56699 L
s
.54127 .56536 m
.54029 .56294 L
s
.57237 .56129 m
.57449 .56457 L
s
.54029 .56294 m
.54074 .55978 L
s
.5664 .55702 m
.57237 .56129 L
s
.5739 .55176 m
.59633 .56084 L
s
.58556 .54586 m
.59633 .56084 L
s
.54074 .55978 m
.5424 .55747 L
s
.5424 .55747 m
.54814 .55454 L
s
.56137 .55518 m
.5664 .55702 L
s
.55752 .55419 m
.56137 .55518 L
s
.58556 .54586 m
.608 .55501 L
s
.5973 .53992 m
.608 .55501 L
s
.54814 .55454 m
.55223 .55394 L
s
.55223 .55394 m
.55752 .55419 L
s
.60764 .53469 m
.62419 .54692 L
s
.62597 .54457 m
.62066 .54431 L
s
.63011 .54396 m
.62597 .54457 L
s
.63457 .54173 m
.63011 .54396 L
s
.63637 .53937 m
.63457 .54173 L
s
.63701 .53612 m
.63637 .53937 L
s
.6112 .53733 m
.61179 .53407 L
s
.63497 .53273 m
.63701 .53612 L
s
.61179 .53407 m
.61357 .53169 L
s
.63261 .53097 m
.63497 .53273 L
s
.61357 .53169 m
.61804 .52943 L
s
.62757 .52907 m
.63261 .53097 L
s
.61804 .52943 m
.62221 .52881 L
s
.62221 .52881 m
.62757 .52907 L
s
.64508 .51575 m
.66155 .52824 L
s
.63753 .51957 m
.63301 .52185 L
s
.65217 .52112 m
.64712 .5192 L
s
.64173 .51894 m
.63753 .51957 L
s
.64712 .5192 m
.64173 .51894 L
s
.67708 .519 m
.68283 .5176 L
s
.6717 .51873 m
.67708 .519 L
s
.66783 .5177 m
.6717 .51873 L
s
.66279 .51578 m
.66783 .5177 L
s
.68283 .5176 m
.69357 .51223 L
s
.6569 .51127 m
.66279 .51578 L
s
.66891 .49307 m
.69357 .51223 L
s
.65488 .50778 m
.6569 .51127 L
s
.65403 .50519 m
.65488 .50778 L
s
.65471 .50181 m
.65403 .50519 L
s
.65812 .49855 m
.65471 .50181 L
s
.66891 .49307 m
.65812 .49855 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo07X0oooo00<0003o0?ooo`3oool0103oool300000080
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0000001X0?ooo`030000003oool0oooo07L0oooo0P000?l0103oool0003o0000o`3oool3000000D0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo
00<000000?ooo`3oool0M@3oool20000o`<0oooo0P0000000`000?l0oooo0?ooo`060?ooo`030000
003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`1c0?ooo`030000o`3oool0oooo00<000000`3oool00`000?l0oooo0?oo
o`050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P000007
0?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0LP3oool00`000?l0000000000007
0?ooo`80003o1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^
0?ooo`<0000000<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06X0oooo0`0000030?ooo`030000o`3oool0
oooo00X0oooo0P000?l20?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo06H0oooo0`0000070?ooo`030000o`3oool0oooo00/0oooo00@0003o0?ooo`3oool00000F03o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0HP3oool3000000D0oooo00<0003o0?ooo`3oool00`3o
ool20000o`T0oooo0P000?l30?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3
000000T0oooo0P000?l50?ooo`80003o103oool30000o`D0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
05T0oooo100000090?ooo`H0003o1P3oool40000o`P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo05D0
oooo0`00000;0?ooo`80003o1P3oool00`000?l0oooo0?ooo`0?0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo
0?ooo`1A0?ooo`<000005`3oool20000o`l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool3000000d0oooo0`00
0?l<0?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`19
0?ooo`<000003@3oool30000o`<0oooo0P000?lI0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo04D0oooo0`00000=0?ooo`030000o`3oool0003o00P0oooo00<0003o0?oo
o`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`03
0000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<0
00004@3oool20000o`P0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo03d0oooo0`00000@0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<00000503o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool05P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool0=@3oool3000001L0oooo00<0003o0?ooo`3oool0103oool6
0000oaT0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`00000D0?ooo`80003o1@3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0
oooo0`00000H0?ooo`@0003o0`3oool00`000?l0oooo0?ooo`0Q0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0Y0?ooo`<000005P3oool20000o`@0oooo00<0003o0?ooo`3oool010000?lS0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo02D0oooo0`00000?0?ooo`H0003o1P3oool20000o`80oooo00<0003o0?ooo`3oool00`3o
ool20000ob80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000@0?ooo`80003o1P3oool2
0000o`H0oooo10000?lX0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000004`3oool00`00
0?l0oooo0?ooo`070?ooo`80003o1`3oool20000obP0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0
oooo0`00000F0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool0;`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0503oool3000001X0oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo
0?ooo`0^0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000008P3oool20000o`D0oooo00<0
003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001d0oooo00<0003o
0?ooo`3oool00`3oool20000o`L0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool3000001l0oooo10000?l40?ooo`80003o1@3oool20000oc00oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`03
0000003oool0oooo00@0oooo0`00000O0?ooo`<0003o0`3oool20000o`D0oooo1@000?lb0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`03000002X0oooo00<0003o0?ooo`3oool0>@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00
000^0?ooo`80003o>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`800000S@3oool00`000000oooo0?ooo`0O0?ooo`@0003o303oool00`000?l0oooo0?ooo`0e
0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo01d0oooo0P000?l40?ooo`<0003o?P3oool300000080oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo01/0oooo00<0003o0?ooo`000?l0203oool00`000?l0oooo0?ooo`0g0?ooo`@0
00001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0703oool20000o`P0oooo00<0003o0?ooo`3oool0
=03oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01L0oooo0P000?l50?ooo`80003o1@3o
ool00`000?l0oooo0?ooo`0b0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0503oool3
0000o`040?ooo`000?l0003o0000o`D0oooo1@000?lb0?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0503oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0;`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80003o<P3oool4000001X0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo00/0oooo0P000?l60?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`00
0?l0;P3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00d0oooo0P000?l50?ooo`80003o
1P3oool00`000?l0oooo0?ooo`020000obT0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0;0?ooo`D0003o1P3oool60000o`D0oooo00<0003o0?ooo`3oool08`3oool3000002H0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<00000
0?ooo`3oool00P000?l70?ooo`80003o1@3oool20000oc80oooo0`00000Z0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`020000o`L0oooo00<0003o0?ooo`3oool01P3oool20000ob`0oooo1000000^0?oo
o`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool09P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0/0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool01P3o
ool20000o`D0oooo0P000?lY0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00@000000?ooo`3oool0003o1`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02<0oooo0`00000n0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool3
0000o`030?ooo`000?l0003o0080003o103oool20000obH0oooo100000120?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0803oool30000
04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool08P3oool3000004X0
oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2:0?ooo`050000o`3oool0oooo0?ooo`000000203oool00`000?l0oooo0?ooo`0O0?ooo`<0
0000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000
R03oool20000o`050?ooo`000?l0oooo0?ooo`0000001P3oool20000oal0oooo0`00001B0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P0000280?ooo`80003o
0`3oool010000?l0oooo0?ooo`0000020?ooo`@0003o7@3oool4000005H0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`1n0?ooo`030000
o`3oool0oooo00D0oooo0P000?l30?ooo`060000o`3oool0oooo0?ooo`000000003o7`3oool30000
05/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0O`3oool20000o`T0oooo00<0003o0?ooo`3oool00P3oool00`000000
003o0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0
oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0P@3oool20000o`H0
oooo0P000?l40?ooo`030000o`3oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`230?ooo`80003o1@3oool50000o`030000003oool0oooo01D0oooo0`00001V0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08D0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0Q`3oool20000o`H0oooo00<000000?ooo`3oool03P3oool3
000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool30000
00D0oooo00<000000?ooo`3oool0R@3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo
00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000MP3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000
O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3o
ool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool2
00000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0Q@3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0
oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo
0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?oo
o`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?
0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`2:0?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3
000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0
oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo
0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000
003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3o
ool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3
000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0
oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>
0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000
003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3
000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo
00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]
0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000
003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3
000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo
00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`06
0?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?oo
o`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P00
00090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003o
ool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003o
ool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000
002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3o
ool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000
003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo
0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo1000
00040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
1P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo
0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]
0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3o
ool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03o
ool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000
003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3o
ool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`00
0000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400
oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?oo
o`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?oo
o`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003o
ool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool0
0`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool200000003
0?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003o
ool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool0
0`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000
oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool00000
05X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo
0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00
001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?oo
o`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3o
ool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000
oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool2000000030?oo
o`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3o
ool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool20000
04T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo
0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo
001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P000013
0?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0
^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3o
ool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool0
07<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo
0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000
000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d
0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?oo
o`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo10000017
0?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<00000
0?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?oo
o`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3o
ool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000
003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000
003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003o
ool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4
000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool40000
06h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0
oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0
oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo
002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?oo
o`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`00
00006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000
003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4
000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5
000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03oool40000
0:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0
oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo
001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<0
00000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<00000
0?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?oo
o`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N
0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003o
ool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000
003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3o
ool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z
0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L
0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X
0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L
0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37047 .6437 m
.36802 .64329 L
s
.37105 .64232 m
.37047 .6437 L
s
.36802 .64329 m
.3686 .64191 L
s
.3686 .64191 m
.37105 .64232 L
s
.38323 .63845 m
.38874 .63789 L
s
.37985 .63714 m
.38323 .63845 L
s
.38874 .63789 m
.39333 .63643 L
s
.35063 .62477 m
.36391 .63744 L
s
.37891 .63624 m
.37985 .63714 L
s
.39333 .63643 m
.39701 .63406 L
s
.37857 .63395 m
.37891 .63624 L
s
.39701 .63406 m
.39669 .63177 L
s
.3807 .63207 m
.37857 .63395 L
s
.38743 .62871 m
.3807 .63207 L
s
.37235 .62992 m
.372 .62761 L
s
.41086 .62965 m
.40593 .62882 L
s
.41486 .62958 m
.41086 .62965 L
s
.4195 .6281 m
.41486 .62958 L
s
.38958 .62682 m
.38743 .62871 L
s
.42168 .62621 m
.4195 .6281 L
s
.372 .62761 m
.37566 .62522 L
s
.38925 .6245 m
.38958 .62682 L
s
.42295 .6234 m
.42168 .62621 L
s
.37566 .62522 m
.38028 .62374 L
s
.38584 .62317 m
.38925 .6245 L
s
.38028 .62374 m
.38584 .62317 L
s
.42175 .62016 m
.42295 .6234 L
s
.42531 .60927 m
.43813 .62218 L
s
.39851 .62153 m
.39975 .6187 L
s
.41991 .61832 m
.42175 .62016 L
s
.39975 .6187 m
.40192 .61679 L
s
.41559 .61606 m
.41991 .61832 L
s
.44154 .60896 m
.45063 .6182 L
s
.40192 .61679 m
.40658 .61529 L
s
.41062 .61521 m
.41559 .61606 L
s
.40658 .61529 m
.41062 .61521 L
s
.44886 .59303 m
.46792 .61271 L
s
.48716 .58939 m
.50581 .60915 L
s
.44037 .60566 m
.44154 .60896 L
s
.48443 .60624 m
.48849 .60616 L
s
.47947 .60538 m
.48443 .60624 L
s
.48849 .60616 m
.49327 .60465 L
s
.44261 .60371 m
.44037 .60566 L
s
.47519 .60309 m
.47947 .60538 L
s
.49327 .60465 m
.49557 .6027 L
s
.44735 .60219 m
.44261 .60371 L
s
.41976 .60367 m
.41726 .60324 L
s
.4204 .60223 m
.41976 .60367 L
s
.4589 .6034 m
.45142 .60211 L
s
.41726 .60324 m
.4179 .6018 L
s
.47339 .60121 m
.47519 .60309 L
s
.49557 .6027 m
.49699 .5998 L
s
.4179 .6018 m
.4204 .60223 L
s
.45142 .60211 m
.44735 .60219 L
s
.47228 .59788 m
.47339 .60121 L
s
.49842 .58577 m
.51084 .59906 L
s
.47366 .59497 m
.47228 .59788 L
s
.51317 .59709 m
.5082 .59623 L
s
.51726 .59701 m
.51317 .59709 L
s
.52209 .59548 m
.51726 .59701 L
s
.52443 .59351 m
.52209 .59548 L
s
.47595 .59299 m
.47366 .59497 L
s
.52591 .59058 m
.52443 .59351 L
s
.48075 .59145 m
.47595 .59299 L
s
.48985 .59224 m
.48485 .59137 L
s
.48485 .59137 m
.48075 .59145 L
s
.5249 .58721 m
.52591 .59058 L
s
.5011 .58864 m
.50254 .58569 L
s
.52314 .5853 m
.5249 .58721 L
s
.53904 .57272 m
.55123 .58621 L
s
.50254 .58569 m
.50488 .5837 L
s
.51887 .58294 m
.52314 .5853 L
s
.50488 .5837 m
.50973 .58214 L
s
.51386 .58206 m
.51887 .58294 L
s
.50973 .58214 m
.51386 .58206 L
s
.56507 .58058 m
.56007 .57969 L
s
.5692 .5805 m
.56507 .58058 L
s
.57577 .57841 m
.5692 .5805 L
s
.56007 .57969 m
.55671 .57829 L
s
.54429 .57853 m
.54004 .57615 L
s
.5782 .5764 m
.57577 .57841 L
s
.55671 .57829 m
.55411 .57539 L
s
.53087 .57535 m
.52598 .57692 L
s
.57979 .57341 m
.5782 .5764 L
s
.54004 .57615 m
.53501 .57527 L
s
.56232 .57276 m
.55411 .57539 L
s
.53501 .57527 m
.53087 .57535 L
s
.57974 .57094 m
.57979 .57341 L
s
.57882 .56748 m
.57974 .57094 L
s
.58364 .55839 m
.60219 .57 L
s
.597 .5541 m
.60219 .57 L
s
.54714 .5676 m
.54703 .56512 L
s
.57452 .56258 m
.57882 .56748 L
s
.597 .5541 m
.61551 .56577 L
s
.61042 .54978 m
.61551 .56577 L
s
.54703 .56512 m
.54858 .56209 L
s
.57027 .56016 m
.57452 .56258 L
s
.54858 .56209 m
.551 .56004 L
s
.56688 .55872 m
.57027 .56016 L
s
.551 .56004 m
.55763 .5579 L
s
.62223 .54599 m
.63393 .55991 L
s
.56182 .55781 m
.56688 .55872 L
s
.55763 .5579 m
.56182 .55781 L
s
.63646 .55786 m
.63144 .55695 L
s
.64065 .55777 m
.63646 .55786 L
s
.64571 .55616 m
.64065 .55777 L
s
.64827 .5541 m
.64571 .55616 L
s
.65 .55103 m
.64827 .5541 L
s
.64923 .54749 m
.65 .55103 L
s
.62475 .54899 m
.62645 .54591 L
s
.64757 .54549 m
.64923 .54749 L
s
.66482 .5323 m
.67626 .54645 L
s
.62645 .54591 m
.629 .54381 L
s
.64338 .54302 m
.64757 .54549 L
s
.629 .54381 m
.63409 .54218 L
s
.63832 .54209 m
.64338 .54302 L
s
.63409 .54218 m
.63832 .54209 L
s
.6943 .53945 m
.70027 .53881 L
s
.68926 .53852 m
.6943 .53945 L
s
.70027 .53881 m
.71235 .53497 L
s
.68592 .53704 m
.68926 .53852 L
s
.66975 .53839 m
.66558 .5359 L
s
.68177 .53455 m
.68592 .53704 L
s
.65625 .53506 m
.65112 .5367 L
s
.66558 .5359 m
.6605 .53497 L
s
.6605 .53497 m
.65625 .53506 L
s
.69546 .51337 m
.71235 .53497 L
s
.67769 .52945 m
.68177 .53455 L
s
.67696 .52582 m
.67769 .52945 L
s
.67705 .52321 m
.67696 .52582 L
s
.67887 .52003 m
.67705 .52321 L
s
.68326 .51731 m
.67887 .52003 L
s
.69546 .51337 m
.68326 .51731 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000005`3oool20000o`80oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?oo
o`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1N0?ooo`<0
00005`3oool30000o`80oooo00<0003o0?ooo`000000F03oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000H0?ooo`80003o
1P3oool00`000?l000000?ooo`1G0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0E@3oool3000001/0oooo00<0003o0?ooo`3oool01`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0
000007@0oooo00<000000?ooo`3oool0D@3oool3000001h0oooo00<0003o0?ooo`3oool01`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`00
0000oooo0?ooo`1=0?ooo`<000008@3oool00`000?l0oooo0?ooo`070?ooo`03000000000?l0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0B@3oool3000002D0oooo00<0003o0?ooo`3oool01P3oool00`000000
oooo0000o`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<000008`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00@000000?ooo`3oool0003oEP3oool00`000000
oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo
00<000000?ooo`3oool0@@3oool300000240oooo1`000?l50?ooo`80003o1@3oool00`000000oooo
0000o`020000oeD0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000002X0oooo0P000?l60?ooo`D0003o00<0
00000000o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j
0?ooo`030000003oool0oooo03T0oooo0`00000P0?ooo`<0003o2`3oool00`000?l0oooo0?ooo`09
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?oo
o`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<000008@3oool20000o`<0oooo0P000?l:0?oo
o`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`00000R0?ooo`80
003o1`3oool20000o`T0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0
;@3oool300000240oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00000T0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0A0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0
oooo02D0oooo0`00000Q0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000E0?ooo`D0003o1P3oool010000?l0oooo0?ooo`3oool30000o`<0oooo00<0003o
0?ooo`3oool0103oool70000oa@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000F0?oo
o`80003o1@3oool20000o`D0oooo00H0003o0?ooo`3oool0oooo0000o`3oool20000o`80oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0H0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H
0?ooo`<000006@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`3oool0003o0`3oool30000ob40oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000L
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool30000o`D0oooo00<0003o
0?ooo`3oool07`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001l0oooo00<0003o0?oo
o`3oool02@3oool00`000?l0oooo0?ooo`040?ooo`80003o9P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000002h0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0T0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<000008P3oool00`000?l0oooo0?ooo`050?ooo`80003o
1@3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000803o
ool70000o`<0oooo0`000?l60?ooo`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00<00000:@3oool20000o`<0oooo0`000?l40?ooo`80003o;`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000P0?oo
o`80003o2`3oool00`000?l0oooo0?ooo`040?ooo`@0003o<@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`0M0?ooo`80
003o0P3oool40000o`P0oooo00<0003o0?ooo`3oool0=`3oool2000005/0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0K0?ooo`80003o
203oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03<0oooo0`0000020?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0h0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0203oool0
0`000?l0oooo0?ooo`070?ooo`L0003o103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo03H0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool20000o`D0oooo00<0003o
0?ooo`3oool0<`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00X0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`H0003o<`3oool3
00000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<P3oool30000
01H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2<0?ooo`<0003o1`3oool70000o`D0oooo00<0003o0?ooo`3oool01@3oool20000oc@0
oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0103oool70000o`80oooo00<0003o0?ooo`3oool0;P3oool3000001h0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0003o00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0=0?ooo`030000o`3oool0oooo02X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool010000000oooo0?ooo`00
0?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0=P3oool3000002H0oooo00<0
00000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00D00000
0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0<P3o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`280?ooo`H0003o00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo03D0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0Q`3oool00`000?l0oooo0?ooo`030?oo
o`03000000000?l0003o00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0a0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08H0oooo00<0003o0?ooo`3oool0103oool00`000000oooo0000o`050?ooo`03
0000o`3oool0oooo03<0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0M@3oool00`000?l0oooo0?ooo`060?ooo`H0003o
2@3oool010000000oooo0?ooo`000?lg0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07L0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo00<000000000o`000?l0
=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`1h0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`040?ooo`D0003o<`3oool400000480oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1i0?ooo`030000o`3oool0
oooo00D0oooo0P000?l40?ooo`030000o`3oool0oooo00@0oooo00<000000?ooo`3oool0;P3oool3
000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`1j0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool30000
o`H0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1k0?ooo`030000o`3oool0oooo0080
oooo1@000?l90?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
001n0?ooo`80003o403oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.35037 .62372 m
.34806 .62302 L
s
.35145 .62243 m
.35037 .62372 L
s
.34806 .62302 m
.34914 .62173 L
s
.34914 .62173 m
.35145 .62243 L
s
.37077 .62018 m
.37588 .6193 L
s
.36505 .62007 m
.37077 .62018 L
s
.36212 .61836 m
.36505 .62007 L
s
.37588 .6193 m
.3804 .61741 L
s
.36151 .61736 m
.36212 .61836 L
s
.3804 .61741 m
.3809 .6151 L
s
.36199 .61505 m
.36151 .61736 L
s
.33723 .60253 m
.34603 .61672 L
s
.39981 .61515 m
.39579 .61474 L
s
.40495 .61426 m
.39981 .61515 L
s
.36479 .61345 m
.36199 .61505 L
s
.39579 .61474 m
.39117 .61332 L
s
.4078 .61265 m
.40495 .61426 L
s
.37274 .61095 m
.36479 .61345 L
s
.41007 .61003 m
.4078 .61265 L
s
.37556 .60934 m
.37274 .61095 L
s
.41745 .59639 m
.42558 .61068 L
s
.3572 .6103 m
.35767 .60797 L
s
.41003 .60669 m
.41007 .61003 L
s
.37606 .60701 m
.37556 .60934 L
s
.43367 .59807 m
.43939 .60829 L
s
.35767 .60797 m
.3622 .60606 L
s
.37312 .60527 m
.37606 .60701 L
s
.40885 .60465 m
.41003 .60669 L
s
.48566 .58445 m
.49702 .6061 L
s
.3622 .60606 m
.36735 .60515 L
s
.36735 .60515 m
.37312 .60527 L
s
.38638 .6052 m
.38862 .60256 L
s
.44657 .5833 m
.45844 .60499 L
s
.40535 .60189 m
.40885 .60465 L
s
.38862 .60256 m
.39147 .60093 L
s
.40071 .60045 m
.40535 .60189 L
s
.48105 .60107 m
.48628 .60016 L
s
.47701 .60065 m
.48105 .60107 L
s
.39147 .60093 m
.39665 .60003 L
s
.47243 .5992 m
.47701 .60065 L
s
.39665 .60003 m
.40071 .60045 L
s
.48628 .60016 m
.48923 .59853 L
s
.46902 .59642 m
.47243 .5992 L
s
.48923 .59853 m
.49165 .59586 L
s
.43368 .59468 m
.43367 .59807 L
s
.49801 .58228 m
.50552 .59682 L
s
.46791 .59436 m
.46902 .59642 L
s
.51253 .59561 m
.50849 .59518 L
s
.5178 .59469 m
.51253 .59561 L
s
.50849 .59518 m
.50392 .59373 L
s
.45282 .59473 m
.44588 .59254 L
s
.52079 .59305 m
.5178 .59469 L
s
.43659 .59304 m
.43368 .59468 L
s
.468 .59095 m
.46791 .59436 L
s
.52327 .59037 m
.52079 .59305 L
s
.44182 .59212 m
.43659 .59304 L
s
.44588 .59254 m
.44182 .59212 L
s
.47039 .58826 m
.468 .59095 L
s
.52346 .58694 m
.52327 .59037 L
s
.41392 .59018 m
.41158 .58945 L
s
.41507 .58884 m
.41392 .59018 L
s
.41158 .58945 m
.41273 .58811 L
s
.54238 .57452 m
.54953 .58919 L
s
.41273 .58811 m
.41507 .58884 L
s
.47335 .5866 m
.47039 .58826 L
s
.4873 .58757 m
.48269 .58611 L
s
.52242 .58486 m
.52346 .58694 L
s
.47862 .58568 m
.47335 .5866 L
s
.48269 .58611 m
.47862 .58568 L
s
.56902 .58581 m
.56497 .58539 L
s
.57613 .58458 m
.56902 .58581 L
s
.49963 .58542 m
.50208 .58271 L
s
.56497 .58539 m
.56042 .58391 L
s
.51907 .58203 m
.52242 .58486 L
s
.5792 .58292 m
.57613 .58458 L
s
.56042 .58391 m
.55764 .58213 L
s
.58179 .5802 m
.5792 .58292 L
s
.50208 .58271 m
.50508 .58105 L
s
.55764 .58213 m
.55613 .57898 L
s
.51447 .58055 m
.51907 .58203 L
s
.50508 .58105 m
.51039 .58012 L
s
.54546 .58084 m
.54214 .578 L
s
.51039 .58012 m
.51447 .58055 L
s
.58259 .57779 m
.58179 .5802 L
s
.59076 .56605 m
.60467 .57963 L
s
.60519 .56352 m
.60467 .57963 L
s
.56504 .57743 m
.55613 .57898 L
s
.54214 .578 m
.53755 .57651 L
s
.58292 .57431 m
.58259 .57779 L
s
.60519 .56352 m
.619 .57715 L
s
.61966 .56099 m
.619 .57715 L
s
.53347 .57608 m
.52814 .57701 L
s
.53755 .57651 m
.53347 .57608 L
s
.58046 .569 m
.58292 .57431 L
s
.63236 .55877 m
.63878 .57372 L
s
.64599 .57247 m
.64193 .57203 L
s
.65141 .57153 m
.64599 .57247 L
s
.64193 .57203 m
.63742 .57054 L
s
.65458 .56984 m
.65141 .57153 L
s
.55207 .57052 m
.55284 .56808 L
s
.65731 .56708 m
.65458 .56984 L
s
.57718 .56612 m
.58046 .569 L
s
.55284 .56808 m
.5554 .56532 L
s
.65779 .56356 m
.65731 .56708 L
s
.57439 .5643 m
.57718 .56612 L
s
.67799 .55078 m
.68404 .56587 L
s
.5554 .56532 m
.55849 .56361 L
s
.56979 .56279 m
.57439 .5643 L
s
.55849 .56361 m
.56568 .56235 L
s
.6569 .56141 m
.65779 .56356 L
s
.56568 .56235 m
.56979 .56279 L
s
.63375 .56199 m
.63646 .55921 L
s
.70956 .56145 m
.72238 .55923 L
s
.70367 .56132 m
.70956 .56145 L
s
.65374 .5585 m
.6569 .56141 L
s
.69918 .55981 m
.70367 .56132 L
s
.6965 .55797 m
.69918 .55981 L
s
.71376 .5363 m
.72238 .55923 L
s
.63646 .55921 m
.63963 .5575 L
s
.64919 .55698 m
.65374 .5585 L
s
.6934 .55505 m
.6965 .55797 L
s
.63963 .5575 m
.6451 .55654 L
s
.6806 .55728 m
.67747 .55436 L
s
.6451 .55654 m
.64919 .55698 L
s
.69127 .54962 m
.6934 .55505 L
s
.67747 .55436 m
.67293 .55283 L
s
.66883 .55238 m
.66334 .55335 L
s
.67293 .55283 m
.66883 .55238 L
s
.69183 .54603 m
.69127 .54962 L
s
.69282 .54351 m
.69183 .54603 L
s
.69566 .54066 m
.69282 .54351 L
s
.70078 .53859 m
.69566 .54066 L
s
.71376 .5363 m
.70078 .53859 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`000?l00P000?mE0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool0
0`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0oooo0`00000f0?ooo`030000o`000000
003o0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`00
0000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo0`00000g0?ooo`80003o00<0oooo0000
003oool00`3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo000W0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000003T0oooo00D0003o0?ooo`3o
ool0oooo000000040?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<00000?03oool01@000?l0
oooo0?ooo`3oool0000000@0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`00000o0?ooo`05
0000o`3oool0oooo0?ooo`0000001@3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo
01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000003L0
oooo1@000?l00`3oool0003o0?ooo`030?ooo`050000o`3oool0oooo0?ooo`0000001@3oool00`00
0?l0oooo0?ooo`1B0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000
oooo0?ooo`0U0?ooo`<00000?`3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo000000050?oo
o`030000o`3oool0oooo0580oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000<P3oool00`000?l0oooo0000o`060000o`T0
oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`000000oooo00D0oooo00<0003o0?ooo`3o
ool0D@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo01`0oooo1000000`0?ooo`030000o`3oool0oooo0080oooo0P000?l70?ooo`030000
o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103oool20000o`03000000000?l0003o00@0003o
D`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003o
ool0oooo01P0oooo0`00000M0?ooo`D0003o3@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo0P000?l70?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0503oool3000001l0oooo00<0003o0?ooo`3oool00`3oool3
0000o`@0oooo00<0003o0?ooo`3oool00`3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0403oool300000240oooo00<0003o0?ooo`3oool01`3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0303oool3000002@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0
oooo0?ooo`030?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`000?l01P3oool20000
o`<0oooo0P000?lB0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000008`3oool00`000?l0
oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l0103oool20000o`H0
oooo00<0003o0?ooo`000?l00P000?lD0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000
8@3oool40000o`030?ooo`000?l0oooo00H0oooo0P000?l50?ooo`030000o`3oool0oooo00@0oooo
0P000?l50?ooo`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000007@3o
ool00`000?l0oooo0?ooo`080?ooo`<0003o0`3oool30000o`L0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`0S0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000001`0oooo10000?l0103oool0003o0000o`00
0?l90?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0/0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=
0?ooo`030000003oool0oooo00L0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00D0oooo0P000?l80?ooo`030000o`3oool0oooo0080oooo0`000?l2
0?ooo`80003o;P3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0RP3oool00`000?l0oooo0000000:0?ooo`030000o`3oool0oooo00D0oooo20000?l40?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`80003o;@3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`290?ooo`<0003o00<000000?ooo`3oool0203oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0;`3oool4000000H0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo00@0oooo1P000?l50?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03L0oooo
0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P00
0?l40?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool60000ocL0oooo0`00
000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S03oool00`000?l000000?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?ooo`0g
0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08<0oooo10000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`H0003o0P3oool00`000?l0oooo0?ooo`0h0?oo
o`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo06l0oooo00<0003o0?ooo`3oool0403oool00`000?l0oooo0?ooo`020?ooo`80
003o103oool00`000000003o0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool02`3oool00`000?l0oooo0?ooo`0d0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`3oool0
1@3oool60000o`<0oooo00<0003o0?ooo`3oool01@3oool20000o`80oooo00<000000000o`3oool0
103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0
<03oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo00<0oooo0P000?l50?ooo`030000o`3o
ool0oooo00X0oooo00H0003o0?ooo`3oool000000?ooo`000?l50?ooo`030000o`3oool0oooo0480
oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0LP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo
0P000?l=0?ooo`040000o`3oool0oooo00000080oooo00<0003o0?ooo`3oool0A03oool3000002H0
oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000007<0oooo
00<0003o0?ooo`3oool0103oool30000o`P0oooo0P000?l30?ooo`80003o0`3oool00`000000oooo
0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo07<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo0`000?l50?ooo`030000003oool0oooo0400oooo1000
000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0N@3oool70000o`d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`1d0?oo
o`80003o5`3oool00`000000oooo0?ooo`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo07@0oooo00<0003o0?ooo`3o
ool05P3oool00`000000oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
=@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool30000
04X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo
0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00
002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N
0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool30000
07H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000
oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo
0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00
803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0
3P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0
oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?oo
o`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<0
0000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3o
ool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48594 .57941 m
.48945 .60205 L
s
.33735 .60146 m
.33528 .60048 L
s
.3389 .60031 m
.33735 .60146 L
s
.33528 .60048 m
.33683 .59933 L
s
.3591 .60047 m
.36454 .60022 L
s
.35341 .59965 m
.3591 .60047 L
s
.33683 .59933 m
.3389 .60031 L
s
.36454 .60022 m
.36974 .5989 L
s
.35108 .5976 m
.35341 .59965 L
s
.38995 .59906 m
.38608 .59816 L
s
.3954 .59881 m
.38995 .59906 L
s
.36974 .5989 m
.37107 .59668 L
s
.39881 .59758 m
.3954 .59881 L
s
.38608 .59816 m
.38198 .59618 L
s
.41421 .58271 m
.41721 .59781 L
s
.35083 .59653 m
.35108 .5976 L
s
.402 .59527 m
.39881 .59758 L
s
.42972 .58638 m
.43177 .59715 L
s
.35213 .5943 m
.35083 .59653 L
s
.44776 .57344 m
.4518 .59623 L
s
.40315 .59196 m
.402 .59527 L
s
.47551 .59515 m
.48099 .5949 L
s
.47169 .59425 m
.47551 .59515 L
s
.48099 .5949 m
.48447 .59366 L
s
.35552 .59306 m
.35213 .5943 L
s
.46767 .59226 m
.47169 .59425 L
s
.49884 .57881 m
.50108 .59398 L
s
.33174 .57881 m
.3355 .59398 L
s
.48447 .59366 m
.48779 .59134 L
s
.50839 .59365 m
.50458 .59274 L
s
.51387 .5934 m
.50839 .59365 L
s
.51738 .59216 m
.51387 .5934 L
s
.36438 .59156 m
.35552 .59306 L
s
.50458 .59274 m
.5006 .59076 L
s
.4653 .58911 m
.46767 .59226 L
s
.52075 .58984 m
.51738 .59216 L
s
.40271 .58981 m
.40315 .59196 L
s
.545 .57669 m
.54682 .5919 L
s
.36778 .59032 m
.36438 .59156 L
s
.56699 .59098 m
.5632 .59007 L
s
.57432 .59064 m
.56699 .59098 L
s
.57788 .58939 m
.57432 .59064 L
s
.36912 .58808 m
.36778 .59032 L
s
.5632 .59007 m
.55929 .58807 L
s
.52215 .58651 m
.52075 .58984 L
s
.40021 .58665 m
.40271 .58981 L
s
.58134 .58706 m
.57788 .58939 L
s
.59499 .57438 m
.6037 .5893 L
s
.60982 .5737 m
.6037 .5893 L
s
.46494 .58695 m
.4653 .58911 L
s
.34903 .589 m
.35034 .58675 L
s
.60982 .5737 m
.61841 .58863 L
s
.62467 .57302 m
.61841 .58863 L
s
.3668 .58599 m
.36912 .58808 L
s
.55929 .58807 m
.55721 .58599 L
s
.63768 .57242 m
.63866 .5877 L
s
.38008 .58757 m
.38327 .58524 L
s
.64602 .58737 m
.64227 .58645 L
s
.65155 .58711 m
.64602 .58737 L
s
.65518 .58586 m
.65155 .58711 L
s
.58297 .58481 m
.58134 .58706 L
s
.46622 .58361 m
.46494 .58695 L
s
.35034 .58675 m
.35557 .58542 L
s
.39609 .58465 m
.40021 .58665 L
s
.52186 .58434 m
.52215 .58651 L
s
.64227 .58645 m
.63845 .58445 L
s
.43094 .58304 m
.42972 .58638 L
s
.36106 .58516 m
.3668 .58599 L
s
.55721 .58599 m
.55684 .58273 L
s
.65875 .58352 m
.65518 .58586 L
s
.68419 .57027 m
.68475 .5856 L
s
.44989 .58546 m
.4438 .58245 L
s
.35557 .58542 m
.36106 .58516 L
s
.38327 .58524 m
.3867 .58398 L
s
.5845 .58146 m
.58297 .58481 L
s
.3922 .58373 m
.39609 .58465 L
s
.71061 .58442 m
.72356 .58383 L
s
.70504 .58359 m
.71061 .58442 L
s
.51958 .58116 m
.52186 .58434 L
s
.3867 .58398 m
.3922 .58373 L
s
.72326 .56068 m
.72356 .58383 L
s
.46954 .58126 m
.46622 .58361 L
s
.70128 .58158 m
.70504 .58359 L
s
.66043 .58017 m
.65875 .58352 L
s
.54578 .58324 m
.54355 .58005 L
s
.43441 .58178 m
.43094 .58304 L
s
.56605 .58231 m
.55684 .58273 L
s
.48644 .58268 m
.48242 .58067 L
s
.4438 .58245 m
.43992 .58153 L
s
.49932 .58209 m
.50269 .57974 L
s
.43992 .58153 m
.43441 .58178 L
s
.69937 .57948 m
.70128 .58158 L
s
.58397 .57599 m
.5845 .58146 L
s
.47304 .58 m
.46954 .58126 L
s
.51559 .57914 m
.51958 .58116 L
s
.48242 .58067 m
.47857 .57975 L
s
.66032 .57798 m
.66043 .58017 L
s
.54355 .58005 m
.53959 .57804 L
s
.47857 .57975 m
.47304 .58 L
s
.50269 .57974 m
.50622 .57847 L
s
.69743 .57628 m
.69937 .57948 L
s
.51175 .57822 m
.51559 .57914 L
s
.50622 .57847 m
.51175 .57822 L
s
.53959 .57804 m
.53576 .57711 L
s
.6583 .57478 m
.66032 .57798 L
s
.53576 .57711 m
.53022 .57737 L
s
.68443 .57688 m
.68245 .57367 L
s
.69727 .57078 m
.69743 .57628 L
s
.41291 .57616 m
.41084 .57514 L
s
.41453 .57497 m
.41291 .57616 L
s
.5818 .57278 m
.58397 .57599 L
s
.63789 .57572 m
.64146 .57335 L
s
.41084 .57514 m
.41247 .57396 L
s
.41247 .57396 m
.41453 .57497 L
s
.65447 .57275 m
.6583 .57478 L
s
.55585 .57398 m
.55745 .57169 L
s
.68245 .57367 m
.67865 .57164 L
s
.64146 .57335 m
.64511 .57207 L
s
.57973 .57066 m
.5818 .57278 L
s
.65069 .57182 m
.65447 .57275 L
s
.64511 .57207 m
.65069 .57182 L
s
.55745 .57169 m
.56092 .56931 L
s
.67865 .57164 m
.67488 .5707 L
s
.67488 .5707 m
.66929 .57096 L
s
.69904 .56737 m
.69727 .57078 L
s
.57579 .56862 m
.57973 .57066 L
s
.56092 .56931 m
.56452 .56803 L
s
.57196 .56769 m
.57579 .56862 L
s
.56452 .56803 m
.57196 .56769 L
s
.70085 .56507 m
.69904 .56737 L
s
.70453 .56267 m
.70085 .56507 L
s
.71013 .56129 m
.70453 .56267 L
s
.72326 .56068 m
.71013 .56129 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`000?l01@000?mB0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000005@0oooo00<000000000o`3oool0103oool00`000?l0oooo0?ooo`1@0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3
000005D0oooo0P000?l00`000000oooo0?ooo`040?ooo`030000o`3oool0oooo0540oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?oo
o`<00000903oool70000obd0oooo00<0003o0?ooo`0000001P3oool00`000?l0oooo0?ooo`1A0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000002H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0E0?ooo`@0
003o1@3oool50000o`030?ooo`000?l0oooo00<0oooo00@0003o0?ooo`3oool000001P3oool00`00
0?l0oooo0?ooo`1A0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0
oooo00<000000000o`3oool0203oool3000000030000o`3oool0oooo02D0oooo00<0003o0?ooo`3o
ool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o103oool20000o`P0oooo0P000?l40?ooo`04
0000o`3oool0oooo000000H0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0C0?oo
o`009@3oool00`000000oooo0?ooo`290?ooo`80003o1P3oool3000000<0oooo00<0003o0?ooo`3o
ool0703oool30000o`80oooo00<0003o0?ooo`3oool0303oool01@000?l0oooo0?ooo`3oool0003o
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo
000000H0oooo00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`1/0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool00`0000060?oo
o`030000o`3oool0oooo00H0oooo0`000?l20?ooo`030000o`3oool0oooo0080oooo1`000?l80?oo
o`<0003o3P3oool00`000?l0oooo0?ooo`020?ooo`060000o`3oool0oooo0000o`3oool0003o0`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0000000H0oooo00<0003o0?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0
oooo01/0oooo00@0003o0?ooo`0000000000103oool60000o`L0oooo00@0003o0?ooo`3oool0oooo
0`000?l40?ooo`030000o`3oool0oooo00@0oooo0P000?l80?ooo`030000o`3oool0oooo0080oooo
10000?l60?ooo`030000o`3oool0oooo0080oooo00H0003o0?ooo`3oool0003o0?ooo`000?l20?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`0000001P3oool00`000?l0oooo0?ooo`1A0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000K@3oool00`000?l0oooo0?ooo`050?ooo`@0
003o1`3oool60000o`D0oooo00<0003o0?ooo`000000103oool00`000?l0oooo0?ooo`030?ooo`80
003o1@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`00
0?l01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool0103oool2000000L0003oE03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo
0?ooo`1/0?ooo`030000o`3oool0oooo00<0oooo0P000?l40?ooo`80003o103oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`0000000`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo
0?ooo`3oool0003o00P0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo0P000?l70?ooo`P0
003o3@3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`1]0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0:0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo000000030?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo0P000?l20?ooo`@0003o203oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01H0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo0?ooo`040?ooo`D0
003o3@3oool00`000?l0oooo0?ooo`020?ooo`030000o`000000oooo0080oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool20000o`80oooo0`000?l:0?ooo`030000o`3oool0oooo00@0oooo0P000?lW0?ooo`<0
00002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo06h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`080?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l000000?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool80000o`@0oooo00@0003o0?ooo`000?l0
003o>P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`1d0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool20000o`80oooo0`000?l50?ooo`030000o`000000oooo00<0oooo00<0003o0?ooo`3oool0
4P3oool00`000?l0oooo0?ooo`0m0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06h0oooo0P000?l50?ooo`H0003o1`3o
ool20000o`T0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0j0?ooo`<000005P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool05`3oool00`000?l0oooo0?ooo`0f0?ooo`@000006P3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0
oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000oooo
0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?oo
o`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<0
0000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0
oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo
0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?oo
o`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q
0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<0
0000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<0
0000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000
IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0
oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@0
00000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
3P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`00
0000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo
0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?oo
o`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?oo
o`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool40000
0440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo
0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.70369 .60671 m
.71621 .60769 L
s
.72389 .58534 m
.71621 .60769 L
s
.69867 .60524 m
.70369 .60671 L
s
.69578 .60285 m
.69867 .60524 L
s
.68337 .58987 m
.67861 .60476 L
s
.69468 .6006 m
.69578 .60285 L
s
.64628 .60224 m
.64088 .60182 L
s
.65019 .60146 m
.64628 .60224 L
s
.64088 .60182 m
.63759 .60048 L
s
.65444 .59962 m
.65019 .60146 L
s
.63804 .58631 m
.63368 .60126 L
s
.69393 .59727 m
.69468 .6006 L
s
.63759 .60048 m
.63461 .59808 L
s
.61075 .58416 m
.61385 .59971 L
s
.62532 .58531 m
.61385 .59971 L
s
.65721 .59658 m
.65444 .59962 L
s
.59617 .58301 m
.5994 .59859 L
s
.61075 .58416 m
.5994 .59859 L
s
.69568 .59194 m
.69393 .59727 L
s
.48798 .5745 m
.48345 .59714 L
s
.65786 .59445 m
.65721 .59658 L
s
.57045 .59633 m
.5632 .59576 L
s
.57434 .59555 m
.57045 .59633 L
s
.68132 .59629 m
.68054 .59294 L
s
.5632 .59576 m
.55983 .59441 L
s
.57852 .5937 m
.57434 .59555 L
s
.65703 .5911 m
.65786 .59445 L
s
.55983 .59441 m
.55672 .59199 L
s
.5468 .57913 m
.54323 .59421 L
s
.58088 .5917 m
.57852 .5937 L
s
.68054 .59294 m
.67761 .59052 L
s
.55672 .59199 m
.55543 .58971 L
s
.69855 .58887 m
.69568 .59194 L
s
.58354 .58862 m
.58088 .5917 L
s
.51049 .59165 m
.50502 .59123 L
s
.51436 .59087 m
.51049 .59165 L
s
.50502 .59123 m
.5016 .58987 L
s
.65406 .58867 m
.65703 .5911 L
s
.51848 .58901 m
.51436 .59087 L
s
.50088 .57552 m
.49772 .59066 L
s
.67761 .59052 m
.67432 .58916 L
s
.5016 .58987 m
.49839 .58744 L
s
.55543 .58971 m
.55621 .58648 L
s
.6371 .58953 m
.64136 .58767 L
s
.67432 .58916 m
.66889 .58873 L
s
.47763 .58909 m
.4815 .5883 L
s
.47215 .58867 m
.47763 .58909 L
s
.52102 .58592 m
.51848 .58901 L
s
.70106 .58686 m
.69855 .58887 L
s
.65076 .58731 m
.65406 .58867 L
s
.4687 .58731 m
.47215 .58867 L
s
.58494 .58323 m
.58354 .58862 L
s
.4815 .5883 m
.48559 .58644 L
s
.64136 .58767 m
.64531 .58688 L
s
.64531 .58688 m
.65076 .58731 L
s
.46544 .58486 m
.4687 .58731 L
s
.56533 .5872 m
.55621 .58648 L
s
.7054 .58499 m
.70106 .58686 L
s
.45243 .56388 m
.44835 .58681 L
s
.5215 .58376 m
.52102 .58592 L
s
.54526 .58562 m
.5442 .58224 L
s
.72389 .58534 m
.7112 .58434 L
s
.42997 .57438 m
.42817 .58524 L
s
.7112 .58434 m
.7054 .58499 L
s
.46421 .58148 m
.46544 .58486 L
s
.41586 .56883 m
.41347 .58409 L
s
.52039 .58037 m
.5215 .58376 L
s
.58395 .57984 m
.58494 .58323 L
s
.39138 .58237 m
.38585 .58194 L
s
.39522 .58157 m
.39138 .58237 L
s
.5442 .58224 m
.54104 .57978 L
s
.38585 .58194 m
.38231 .58057 L
s
.39923 .57969 m
.39522 .58157 L
s
.46462 .5793 m
.46421 .58148 L
s
.38231 .58057 m
.37891 .57811 L
s
.51719 .57791 m
.52039 .58037 L
s
.36001 .57992 m
.36569 .57927 L
s
.35446 .57949 m
.36001 .57992 L
s
.58268 .57752 m
.58395 .57984 L
s
.54104 .57978 m
.53763 .57841 L
s
.40156 .57657 m
.39923 .57969 L
s
.34904 .57797 m
.35446 .57949 L
s
.46707 .57618 m
.46462 .5793 L
s
.36569 .57927 m
.36782 .57724 L
s
.5002 .57878 m
.50433 .5769 L
s
.53763 .57841 m
.53212 .57797 L
s
.34744 .57565 m
.34904 .57797 L
s
.51375 .57653 m
.51719 .57791 L
s
.55832 .57782 m
.56068 .57578 L
s
.48733 .57777 m
.48408 .5753 L
s
.33225 .57776 m
.33051 .57653 L
s
.33422 .57682 m
.33225 .57776 L
s
.57958 .57505 m
.58268 .57752 L
s
.50433 .5769 m
.50824 .57609 L
s
.33248 .57558 m
.33422 .57682 L
s
.40188 .57439 m
.40156 .57657 L
s
.50824 .57609 m
.51375 .57653 L
s
.33051 .57653 m
.33248 .57558 L
s
.47117 .57429 m
.46707 .57618 L
s
.45028 .57597 m
.44532 .57226 L
s
.56068 .57578 m
.56489 .57389 L
s
.34757 .57456 m
.34744 .57565 L
s
.48408 .5753 m
.48061 .57392 L
s
.57618 .57366 m
.57958 .57505 L
s
.34968 .57251 m
.34757 .57456 L
s
.40052 .57096 m
.40188 .57439 L
s
.43236 .57124 m
.42997 .57438 L
s
.47507 .57349 m
.47117 .57429 L
s
.48061 .57392 m
.47507 .57349 L
s
.56489 .57389 m
.56883 .57308 L
s
.56883 .57308 m
.57618 .57366 L
s
.35353 .57171 m
.34968 .57251 L
s
.44532 .57226 m
.44181 .57087 L
s
.36295 .57134 m
.35353 .57171 L
s
.3668 .57053 m
.36295 .57134 L
s
.43625 .57043 m
.43236 .57124 L
s
.39713 .56847 m
.40052 .57096 L
s
.44181 .57087 m
.43625 .57043 L
s
.36894 .56848 m
.3668 .57053 L
s
.33474 .55458 m
.33307 .57011 L
s
.3801 .56935 m
.38412 .56744 L
s
.36737 .56613 m
.36894 .56848 L
s
.39357 .56707 m
.39713 .56847 L
s
.38412 .56744 m
.38799 .56663 L
s
.38799 .56663 m
.39357 .56707 L
s
.34846 .56687 m
.35059 .56481 L
s
.36191 .56458 m
.36737 .56613 L
s
.35059 .56481 m
.35632 .56414 L
s
.35632 .56414 m
.36191 .56458 L
s
.4169 .5622 m
.41521 .56094 L
s
.41894 .56124 m
.4169 .5622 L
s
.41725 .55998 m
.41894 .56124 L
s
.41521 .56094 m
.41725 .55998 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00001/0?ooo`030000o`3oool0oooo
0180oooo00<000000?ooo`3oool09@3oool3000004T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo01<0
oooo00<000000?ooo`3oool08@3oool3000004`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo01@0oooo
00<000000?ooo`3oool0103oool20000oaH0oooo1000001@0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0;0?ooo`030000o`3oool0oooo00@0oooo0`00001D0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`04
0?ooo`80003o00<0oooo0000o`000?l00P000?l60?ooo`80003o103oool00`000000oooo0?ooo`0@
0?ooo`040000o`3oool0oooo0?ooo`<00000E`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000V0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P000?l20?ooo`<0003o0P3oool0
1@000000oooo0?ooo`3oool0003o00d0oooo00@0003o0000000000000000FP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06/0oooo00<0
003o0?ooo`3oool01@3oool60000o`/0oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo
0?ooo`030?ooo`D0003o00@0oooo000000000?l00000G@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo0700oooo0`000?lB0?ooo`060000
o`3oool0oooo0000003oool0003o103oool010000?l0oooo0?ooo`3oool2000000030000o`3oool0
003o00L0oooo10000?l20?ooo`030000o`3oool0oooo01X0oooo1@000?l_0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool20000
o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0:0?ooo`050000o`3oool0oooo
0?ooo`000?l01@3oool010000?l000000000000000030?ooo`80003o1@3oool20000o`@0oooo00<0
003o0?ooo`000?l0103oool50000oa40oooo0P000?l50?ooo`80003o;@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06`0oooo00<0003o
0?ooo`3oool00`3oool70000o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`070000o`000000oooo0?ooo`000000003o000000070?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01@3oool20000o`<0oooo0P000?l40?ooo`80003o103oool50000o`030?oo
o`000?l0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0OP3o
ool70000o`D0oooo00H0003o0?ooo`00000000000?ooo`000?l70?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool01P3oool20000o`d0oooo00<0003o0?ooo`3oool0:P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000R`3oool00`000?l0oooo
000000020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00`0oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool06P3oool2000000L0003oE03oool00`000000
oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo00P0oooo
00<0003o0?ooo`3oool0103oool20000o`D0oooo00@0003o0?ooo`3oool0oooo0P000?l70?ooo`03
0000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool0oooo1@000?l50?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o0?ooo`3oool00`3oool60000
o`l0oooo0`0000000`000?l0oooo000000050?ooo`030000o`3oool0oooo0580oooo00<000000?oo
o`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0A0?ooo`H0
003o0`3oool00`000?l0oooo0000o`040?ooo`80003o2@3oool01@000?l0oooo0?ooo`3oool0003o
00T0oooo00<0003o0?ooo`3oool00P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`000?l00`3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?ooo`D0003o00<0
oooo0000000000000P0000000`3oool0003o0?ooo`030?ooo`050000003oool0oooo0?ooo`000?l0
E@3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo01D0oooo00<0003o0?ooo`3oool01@3oool40000o`X0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`000?l00P3o
ool010000?l0oooo0?ooo`000?l50?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
103oool3000000050000o`3oool0oooo0?ooo`000?l01@3oool01@000000oooo0?ooo`3oool0003o
05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0E0?ooo`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool40000o`80
oooo0`000?l60?ooo`80003o103oool20000o`H0oooo00<0003o0?ooo`3oool01@3oool010000?l0
oooo0?ooo`3oool300000080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?oo
o`040000003oool0oooo0000oeD0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0oooo01d0oooo0P000?l90?oo
o`030000o`3oool0oooo00<0oooo0P000?l50?ooo`80003o1`3oool010000?l00000000000000005
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000000003o0?ooo`1E
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0AP3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o00<0oooo00@0003o0000
000000000000203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0500oooo1000000:0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l000000?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0C@3oool3000000h0oooo00<0003o0?ooo`3o
ool0103oool50000o`80oooo00<0003o0?ooo`000000EP3oool00`000000oooo0?ooo`0A0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000M0?ooo`<0003o
0P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0A`3oool3000002H0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0A03oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000000^0?ooo`030000003oool0oooo
0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000003H0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03P0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0e
0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02h0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<00000
BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3oool0B`3o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3
00000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool20000
0900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0
oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000005h0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?oo
o`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000680oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0
oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P
0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3o
ool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3o
ool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00
000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00
000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E
0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000
003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03o
ool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M
0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3o
ool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0
oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool20000
02D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00
001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3o
ool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0
oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900
oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool5
00000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_
0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B
0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool0
0`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`00
0000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P00
00090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3o
ool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03o
ool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3o
ool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0
oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000
oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo
00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo
0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00
001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?oo
o`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`80
0000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo
0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`03
0?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`03
0000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00
B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R
0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3o
ool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`800000
2`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`03
0000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000
003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3o
ool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0
oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0
oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo
00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000
D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03o
ool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0000
00020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo00000002
0?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?oo
o`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@00000
1@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3o
ool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool0
06X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<0
00000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<00000
0?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?oo
o`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D0
0000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000
<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool0
0`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool20000
00d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000
oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool50000
0480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo
09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo
02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo0000
0180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0
oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00
000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00
000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V
0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?oo
o`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000
003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3o
ool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool4
00000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool40000
08@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo
00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00
000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?oo
o`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?oo
o`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3o
ool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0
=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03o
ool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0
000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool00000
02<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool40000
0;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`00
0000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`800000
00<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P00
00050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<00000
0?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool5
00000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool30000
0080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o
0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.6894 .62743 m
.70099 .62985 L
s
.716 .60919 m
.70099 .62985 L
s
.68512 .62541 m
.6894 .62743 L
s
.68319 .62276 m
.68512 .62541 L
s
.68292 .62045 m
.68319 .62276 L
s
.67582 .60873 m
.66611 .62257 L
s
.68335 .61714 m
.68292 .62045 L
s
.68686 .6122 m
.68335 .61714 L
s
.63596 .61628 m
.63091 .61522 L
s
.63999 .61599 m
.63596 .61628 L
s
.64471 .61471 m
.63999 .61599 L
s
.63091 .61522 m
.62821 .61353 L
s
.64843 .61209 m
.64471 .61471 L
s
.67164 .61469 m
.67205 .61136 L
s
.63357 .59983 m
.62417 .61382 L
s
.62821 .61353 m
.62617 .61084 L
s
.69066 .60957 m
.68686 .6122 L
s
.6498 .6101 m
.64843 .61209 L
s
.67205 .61136 m
.67008 .60866 L
s
.65016 .60676 m
.6498 .6101 L
s
.60801 .59444 m
.60557 .60994 L
s
.62166 .59732 m
.60557 .60994 L
s
.69375 .60793 m
.69066 .60957 L
s
.716 .60919 m
.70428 .60671 L
s
.67008 .60866 m
.66741 .60696 L
s
.69853 .60664 m
.69375 .60793 L
s
.5943 .59155 m
.59199 .6071 L
s
.60801 .59444 m
.59199 .6071 L
s
.66741 .60696 m
.66235 .60589 L
s
.64815 .60405 m
.65016 .60676 L
s
.70428 .60671 m
.69853 .60664 L
s
.64545 .60233 m
.64815 .60405 L
s
.63154 .60285 m
.63629 .60155 L
s
.64036 .60126 m
.64545 .60233 L
s
.63629 .60155 m
.64036 .60126 L
s
.56469 .6014 m
.55784 .59997 L
s
.56875 .60111 m
.56469 .6014 L
s
.57345 .59981 m
.56875 .60111 L
s
.55784 .59997 m
.55503 .59825 L
s
.57645 .59816 m
.57345 .59981 L
s
.55503 .59825 m
.55285 .59551 L
s
.5801 .59548 m
.57645 .59816 L
s
.54769 .58173 m
.53892 .59603 L
s
.55285 .59551 m
.55239 .59312 L
s
.58334 .5904 m
.5801 .59548 L
s
.55239 .59312 m
.55429 .59007 L
s
.56291 .59187 m
.55429 .59007 L
s
.49173 .56994 m
.47926 .59159 L
s
.58357 .58697 m
.58334 .5904 L
s
.50778 .58953 m
.50256 .58844 L
s
.51186 .58923 m
.50778 .58953 L
s
.51655 .58792 m
.51186 .58923 L
s
.50256 .58844 m
.49968 .58669 L
s
.52012 .58521 m
.51655 .58792 L
s
.54391 .58789 m
.54407 .58445 L
s
.50404 .57253 m
.4956 .58699 L
s
.58315 .58456 m
.58357 .58697 L
s
.49968 .58669 m
.49739 .58391 L
s
.52135 .58315 m
.52012 .58521 L
s
.581 .58177 m
.58315 .58456 L
s
.54407 .58445 m
.54185 .58166 L
s
.52145 .5797 m
.52135 .58315 L
s
.47639 .58298 m
.48048 .58268 L
s
.47113 .58188 m
.47639 .58298 L
s
.48048 .58268 m
.48516 .58135 L
s
.4682 .58012 m
.47113 .58188 L
s
.55937 .58187 m
.56239 .58017 L
s
.57819 .58001 m
.581 .58177 L
s
.54185 .58166 m
.539 .5799 L
s
.56239 .58017 m
.56714 .57884 L
s
.46586 .57732 m
.4682 .58012 L
s
.57126 .57854 m
.57819 .58001 L
s
.539 .5799 m
.53377 .5788 L
s
.51919 .57689 m
.52145 .5797 L
s
.56714 .57884 m
.57126 .57854 L
s
.46584 .57384 m
.46586 .57732 L
s
.46044 .55508 m
.44827 .57711 L
s
.51631 .57512 m
.51919 .57689 L
s
.50222 .57565 m
.50694 .57431 L
s
.51106 .57401 m
.51631 .57512 L
s
.50694 .57431 m
.51106 .57401 L
s
.46701 .57175 m
.46584 .57384 L
s
.48993 .57307 m
.48761 .57024 L
s
.43448 .56258 m
.42883 .57306 L
s
.47054 .56899 m
.46701 .57175 L
s
.48761 .57024 m
.48468 .56846 L
s
.42245 .55534 m
.41463 .57009 L
s
.47526 .56764 m
.47054 .56899 L
s
.48468 .56846 m
.47938 .56734 L
s
.47938 .56734 m
.47526 .56764 L
s
.45403 .56669 m
.45044 .56242 L
s
.39324 .56563 m
.38787 .56451 L
s
.39736 .56533 m
.39324 .56563 L
s
.40202 .56397 m
.39736 .56533 L
s
.38787 .56451 m
.38483 .56271 L
s
.40546 .56118 m
.40202 .56397 L
s
.38483 .56271 m
.38231 .55985 L
s
.43797 .55979 m
.43448 .56258 L
s
.45044 .56242 m
.44746 .56061 L
s
.40656 .55907 m
.40546 .56118 L
s
.44746 .56061 m
.44211 .55949 L
s
.44211 .55949 m
.43797 .55979 L
s
.36866 .55933 m
.37152 .55759 L
s
.36273 .55926 m
.36866 .55933 L
s
.35733 .55814 m
.36273 .55926 L
s
.40642 .55551 m
.40656 .55907 L
s
.35243 .55595 m
.35733 .55814 L
s
.35166 .55344 m
.35243 .55595 L
s
.40393 .55263 m
.40642 .55551 L
s
.33563 .55361 m
.33432 .55216 L
s
.33795 .55292 m
.33563 .55361 L
s
.35218 .55237 m
.35166 .55344 L
s
.33665 .55148 m
.33795 .55292 L
s
.40089 .5508 m
.40393 .55263 L
s
.35504 .55062 m
.35218 .55237 L
s
.33432 .55216 m
.33665 .55148 L
s
.38663 .55135 m
.39132 .54997 L
s
.36876 .55114 m
.35918 .55031 L
s
.37291 .55083 m
.36876 .55114 L
s
.37579 .54907 m
.37291 .55083 L
s
.39548 .54966 m
.40089 .5508 L
s
.35918 .55031 m
.35504 .55062 L
s
.39132 .54997 m
.39548 .54966 L
s
.37505 .54654 m
.37579 .54907 L
s
.42584 .54894 m
.42461 .54749 L
s
.4282 .54825 m
.42584 .54894 L
s
.42697 .5468 m
.4282 .54825 L
s
.42461 .54749 m
.42697 .5468 L
s
.37014 .54432 m
.37505 .54654 L
s
.34646 .53094 m
.33921 .54612 L
s
.35584 .54488 m
.35871 .5431 L
s
.36469 .54317 m
.37014 .54432 L
s
.35871 .5431 m
.36469 .54317 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool01@3oool00`000000
oooo0?ooo`190?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0K@3oool00`000?l0oooo
0?ooo`070?ooo`030000003oool0oooo04D0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?oo
o`1]0?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0K03oool00`000?l0oooo0?ooo`0:0?ooo`030000003oool0oooo03d0oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0K03oool00`000?l0oooo0?ooo`0;0?ooo`030000003oool0oooo03T0oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0K03oool00`000?l0oooo0?ooo`030?ooo`L0003o0`3oool00`000000oooo0?ooo`0e0?ooo`<0
0000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo06`0oooo00<0003o0?ooo`3oool02P3oool20000o`80oooo00<000000?ooo`3oool0
303oool20000ob<0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0LP3oool40000o`@0oooo00H0003o0?ooo`3oool0oooo
0000003oool20000o`/0oooo00<0003o0?ooo`3oool07P3oool3000004<0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1Z0?ooo`<0003o
103oool00`000?l0oooo0?ooo`020?ooo`@0003o103oool20000o`80oooo0`000?lV0?ooo`<00000
AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000K03o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<000000?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00`0oooo00<0003o0?ooo`3oool02`3o
ool3000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1b0?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`050000003oool0
oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00T0oooo0`00
001<0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0M@3oool40000o`@0oooo00<0003o0?ooo`3oool00`3oool010000000oooo0?ooo`00
0?l40?ooo`030000o`3oool0oooo00@0oooo1@000?l30?ooo`030000o`3oool0oooo00D0oooo1000
001@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0OP3oool00`000?l0oooo0?ooo`030?ooo`03000000000?l0oooo00<0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0003o00D0oooo0`00001D
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0O`3oool60000o`030000003oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00@000000?oo
o`3oool0003o1P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000000000000080oooo1`00
0?mA0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0000o`050?ooo`030000o`3oool0oooo00@0oooo00<00000
0000o`000000103oool00`000?l0oooo0?ooo`050?ooo`80003oC`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0103oool010000?l0oooo0?ooo`3oool3000000030?ooo`000?l0oooo00@0oooo00<0003o
0?ooo`3oool01@3oool20000o`@0oooo0`000?m80?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<000000`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool20000o`80oooo0`000?m50?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000000d0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00P3oool30000o`P0oooo1P000?l_0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool200000140oooo
0P000?l20?ooo`<0003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`000?l00`3oool20000o`H0oooo0P000?l]0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0180oooo0P00
0?l00`3oool0003o0?ooo`030?ooo`80003o1`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool0:P3oool2000005/0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0E0?ooo`030000o`3oool0
oooo0080oooo0P000?l50?ooo`80003o2@3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0
oooo02L0oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool0
02D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00D0oooo1@000?l:0?ooo`030000o`3oool0oooo0080oooo0P000?l80?ooo`030000o`3oool0oooo
02<0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo01@0
oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003o1@3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01`0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Z0?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool04`3oool3000000h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo0300oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo0P000?l40?ooo`030000o`3oool0oooo00/0oooo0`00000B0?ooo`030000
003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0a0?ooo`L0003o1P3oool01`000?l0oooo0?ooo`3oool0003o0?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`020?ooo`@0003o0`3oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo03h0oooo00H0003o0?ooo`000?l0003o0?ooo`000?l30?ooo`030000o`3oool0oooo
0080oooo0P000?l20?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool20000o`<0
oooo00@0003o0?ooo`000?l0003o1@3oool010000?l000000000000000030?ooo`030000o`3oool0
oooo0080oooo0`000?l:0?ooo`D0003o103oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool00`00
0?l0oooo0?ooo`020?ooo`80003o1@3oool3000000H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0000o`040?ooo`<0003o1@3oool30000o`80oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo04<0
oooo00@0003o0?ooo`3oool0oooo0`0000020000o`L0oooo00<0003o0?ooo`3oool01P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`00
0000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000
oooo0?ooo`140?ooo`<000000`3oool20000o`D0oooo0P000?l80?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`100?ooo`@00000203oool50000o`X0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00
000J0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`070?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`<00000703oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0203oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool0>03oool3000002H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0:0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0e0?ooo`<00000:P3oool30000o`<0oooo00<0003o0?ooo`3o
ool02`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000300oooo0`000?l?0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0^0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3
000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0
oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo
0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3
000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000
oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool30000
00T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?oo
o`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool30000
02P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?oo
o`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool30000
04P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?oo
o`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo
0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?oo
o`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000
002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0
oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo
000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?oo
o`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`
0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?oo
o`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3o
ool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@00000
0?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`80
0000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`80
0000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003o
ool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2
000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool0
0`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
03d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B
0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool2
00000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool0
0600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?oo
o`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`800000
0P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4
000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0
oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?oo
o`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0
/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool4
00000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0
oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo
0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo
1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo
0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo
001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo0021
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?oo
o`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3o
ool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`00
00009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000
003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo
05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0
oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo
100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B
0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?oo
o`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000
003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003o
ool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0
oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo
1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo
00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?oo
o`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0
oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo
0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.66859 .64578 m
.67884 .64947 L
s
.70028 .63127 m
.67884 .64947 L
s
.66519 .64333 m
.66859 .64578 L
s
.66426 .64053 m
.66519 .64333 L
s
.6648 .63826 m
.66426 .64053 L
s
.66206 .62608 m
.64796 .63834 L
s
.66636 .63512 m
.6648 .63826 L
s
.67143 .63074 m
.66636 .63512 L
s
.65599 .63136 m
.65754 .62818 L
s
.70028 .63127 m
.68997 .62749 L
s
.67597 .62865 m
.67143 .63074 L
s
.62513 .62887 m
.62115 .62867 L
s
.63012 .6282 m
.62513 .62887 L
s
.62115 .62867 m
.61665 .62705 L
s
.67949 .62743 m
.67597 .62865 L
s
.63461 .62609 m
.63012 .6282 L
s
.65754 .62818 m
.65658 .62533 L
s
.68997 .62749 m
.6845 .62675 L
s
.6845 .62675 m
.67949 .62743 L
s
.61665 .62705 m
.61463 .62508 L
s
.63661 .62433 m
.63461 .62609 L
s
.65658 .62533 m
.65461 .62336 L
s
.61463 .62508 m
.6136 .62223 L
s
.62457 .61242 m
.61063 .62488 L
s
.63812 .62112 m
.63661 .62433 L
s
.65461 .62336 m
.65013 .62173 L
s
.63713 .61825 m
.63812 .62112 L
s
.60177 .60411 m
.59401 .61889 L
s
.61396 .60855 m
.59401 .61889 L
s
.63513 .61626 m
.63713 .61825 L
s
.63061 .61462 m
.63513 .61626 L
s
.62156 .6151 m
.62659 .61441 L
s
.62659 .61441 m
.63061 .61462 L
s
.58951 .59964 m
.58184 .6145 L
s
.60177 .60411 m
.58184 .6145 L
s
.56136 .60587 m
.55731 .60566 L
s
.56639 .60517 m
.56136 .60587 L
s
.55731 .60566 m
.55114 .60343 L
s
.56988 .60391 m
.56639 .60517 L
s
.57436 .60175 m
.56988 .60391 L
s
.55114 .60343 m
.54901 .60141 L
s
.57929 .59719 m
.57436 .60175 L
s
.54901 .60141 m
.54785 .59847 L
s
.54785 .59847 m
.54824 .59608 L
s
.54765 .58439 m
.53407 .59728 L
s
.58071 .59388 m
.57929 .59719 L
s
.55892 .59614 m
.55115 .59333 L
s
.54824 .59608 m
.55115 .59333 L
s
.58115 .59148 m
.58071 .59388 L
s
.58003 .5885 m
.58115 .59148 L
s
.5418 .58994 m
.54316 .5866 L
s
.57793 .58644 m
.58003 .5885 L
s
.50997 .58733 m
.50587 .58711 L
s
.51504 .58661 m
.50997 .58733 L
s
.50587 .58711 m
.50114 .58541 L
s
.51949 .5844 m
.51504 .58661 L
s
.54316 .5866 m
.54198 .5836 L
s
.57171 .58416 m
.57793 .58644 L
s
.55898 .58595 m
.56251 .58466 L
s
.49702 .56594 m
.47711 .58563 L
s
.50114 .58541 m
.49892 .58334 L
s
.56251 .58466 m
.5676 .58395 L
s
.52141 .58254 m
.51949 .5844 L
s
.5676 .58395 m
.57171 .58416 L
s
.54198 .5836 m
.53981 .58153 L
s
.49892 .58334 m
.49766 .58033 L
s
.50819 .57001 m
.49481 .58313 L
s
.52273 .57917 m
.52141 .58254 L
s
.53981 .58153 m
.5351 .57981 L
s
.52151 .57615 m
.52273 .57917 L
s
.48145 .57704 m
.48653 .57631 L
s
.47732 .57682 m
.48145 .57704 L
s
.47252 .57509 m
.47732 .57682 L
s
.51931 .57406 m
.52151 .57615 L
s
.47026 .573 m
.47252 .57509 L
s
.51455 .57232 m
.51931 .57406 L
s
.46894 .56995 m
.47026 .573 L
s
.50531 .57284 m
.51041 .57211 L
s
.51041 .57211 m
.51455 .57232 L
s
.47016 .56653 m
.46894 .56995 L
s
.49415 .56878 m
.49286 .56572 L
s
.47147 .54743 m
.45164 .56756 L
s
.47205 .56464 m
.47016 .56653 L
s
.49286 .56572 m
.49062 .5636 L
s
.4765 .56236 m
.47205 .56464 L
s
.49062 .5636 m
.4858 .56185 L
s
.48163 .56163 m
.4765 .56236 L
s
.4858 .56185 m
.48163 .56163 L
s
.44314 .55154 m
.43382 .56114 L
s
.46102 .55804 m
.45899 .55339 L
s
.43378 .54289 m
.42077 .55644 L
s
.45899 .55339 m
.45668 .55124 L
s
.44759 .54923 m
.44314 .55154 L
s
.45668 .55124 m
.45179 .54945 L
s
.40528 .54955 m
.40107 .54933 L
s
.41041 .54881 m
.40528 .54955 L
s
.45179 .54945 m
.44759 .54923 L
s
.40107 .54933 m
.39612 .54755 L
s
.41482 .54649 m
.41041 .54881 L
s
.39612 .54755 m
.39372 .54538 L
s
.41667 .54455 m
.41482 .54649 L
s
.39372 .54538 m
.39223 .54224 L
s
.4178 .54102 m
.41667 .54455 L
s
.41636 .53786 m
.4178 .54102 L
s
.37877 .53999 m
.38226 .53863 L
s
.37287 .53917 m
.37877 .53999 L
s
.36786 .53736 m
.37287 .53917 L
s
.41397 .53567 m
.41636 .53786 L
s
.36373 .53456 m
.36786 .53736 L
s
.43942 .53702 m
.43872 .53543 L
s
.44201 .53664 m
.43942 .53702 L
s
.44131 .53505 m
.44201 .53664 L
s
.409 .53386 m
.41397 .53567 L
s
.43872 .53543 m
.44131 .53505 L
s
.36386 .53199 m
.36373 .53456 L
s
.39957 .53439 m
.40474 .53363 L
s
.40474 .53363 m
.409 .53386 L
s
.38606 .53213 m
.3818 .5319 L
s
.38957 .53076 m
.38606 .53213 L
s
.36476 .531 m
.36386 .53199 L
s
.3818 .5319 m
.37252 .52985 L
s
.36825 .52963 m
.36476 .531 L
s
.38973 .52817 m
.38957 .53076 L
s
.3477 .53009 m
.34691 .52849 L
s
.35028 .52971 m
.3477 .53009 L
s
.37252 .52985 m
.36825 .52963 L
s
.34949 .52811 m
.35028 .52971 L
s
.34691 .52849 m
.34949 .52811 L
s
.38562 .52534 m
.38973 .52817 L
s
.38058 .5235 m
.38562 .52534 L
s
.37111 .52405 m
.37462 .52266 L
s
.37462 .52266 m
.38058 .5235 L
s
.36671 .50905 m
.35399 .52314 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo0680oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo00<0oooo00<0003o0?ooo`3oool0H03oool3000001P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo06l0oooo00D000000?ooo`3oool0oooo0000o`1P0?ooo`<000006`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0003o05h0oooo0`00000N0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000?l0
oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`030000003oool0oooo0700oooo00<0003o0?ooo`0000001@3oool30000odl0oooo
0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<0
00000?ooo`000000M03oool00`000000oooo0?ooo`020000o`<0oooo0P000?m:0?ooo`<00000:03o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000K`3oool2
0000o`D0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`140?ooo`<00000:`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`00
0000oooo0?ooo`1^0?ooo`80003o103oool80000o`80oooo00<0003o0?ooo`3oool0@@3oool30000
02h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000
oooo0000000P0?ooo`030000003oool0oooo07@0oooo00@0003o0?ooo`3oool00000103oool20000
o`@0oooo10000?li0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0M@3oool20000o`03
0?ooo`000000oooo00`0oooo0P000?l80?ooo`<0003o:@3oool3000003@0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0
M`3oool50000o``0oooo00<0003o0?ooo`3oool0;P3oool3000003L0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003o
ool0oooo0080oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`<00000>P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0
oooo07`0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool08@3oool3000003d0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo
0080oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
00`0oooo00<0003o0?ooo`3oool0403oool300000400oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080
oooo1P000?l50?ooo`030000o`3oool0oooo00@0oooo0P000?l60?ooo`030000o`3oool0oooo00h0
oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0oooo
0P000?l20?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0<0?ooo`<00000AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?oo
o`090?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000
o`0<0?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0203oool3000004`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`@00000D03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`03
0000003oool0oooo08@0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`80
00001P000?m?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0@0?ooo`040000o`3oool0oooo0?ooo`80
00000`000?l60?ooo`80003oC@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo
0000000200000080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1<0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`0<0?ooo`<000001@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00<0oooo0P000?m80?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<00000203oool0
0`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0P000?l00`3oool0003o0000o`02
0000od@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000<0?ooo`H0003o1@3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
0000503oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00D0003o0?ooo`3o
ool0oooo0000o`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0S03oool2000001H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo0P000?lm0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo01@0oooo
00<0003o0?ooo`3oool00P3oool010000?l0oooo0000o`000?l60?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`000?l01@3oool40000oc00oooo0P00001K0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo
0?ooo`070?ooo`H0003o203oool20000o`@0oooo0P000?l40?ooo`80003o:`3oool300000080oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?oo
o`0T0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0:P3oool010000?l0oooo0?ooo`3o
ool20000o`X0oooo00<0003o0?ooo`3oool0803oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02T0oooo00D0003o0?ooo`3oool0oooo0000o`020?ooo`80003o1`3oool00`000?l0oooo0?oo
o`0N0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool06`3oool300000180oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02h0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01@0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`80
003o1@3oool30000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`@0
00006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0<03oool50000o`L0oooo00<0003o0?ooo`3oool0
0P000?l<0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool01P000?l0oooo0000
o`000?l0oooo0000o`D0oooo00@0003o0?ooo`3oool0oooo0`00000R0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0k0?ooo`80003o0P3oool00`000?l0oooo0?ooo`020?ooo`80003o00@0oooo00000000
000000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`80
0000S`3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool00P000?l3000000<0oooo0`000?lT0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0n0?ooo`030000
o`3oool0000000<000001@3oool20000o`80oooo0P000?lS0?ooo`030000003oool0oooo0500oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0n0?ooo`<000001`3oool20000o`D0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0>`3oool3000000T0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo0?ooo`3o
ool0003o01l0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`00000;0?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`030?ooo`<0003o7@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool30000
0100oooo00<0003o0?ooo`3oool00P3oool30000o`L0oooo00<0003o0?ooo`000?l01@3oool50000
oa80oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000000D0?ooo`@0003o2P3oool20000o`<0
oooo0`000?l50?ooo`80003o4@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000002D0oooo
0P000?l30?ooo`030000o`3oool0oooo00P0oooo0P000?l@0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0[0?ooo`<000009`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00T0oooo00<0
003o0?ooo`3oool03`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000002T0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`80003o4`3oool00`000000oooo0?ooo`1;
0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?oo
o`<00000<P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01@0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool08@3oool4000003D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0F0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<00000>P3oool20000o`<0oooo0P000?lJ0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool06`3oool3000003l0oooo0`000?lL0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3
000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool20000
0940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<0
00003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700
oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<0
0000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool0
01d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580
oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<0
0000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0
oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W
0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<0
0000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool0
0`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0
oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`000027
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?oo
o`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<00000
0?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;
0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003o
ool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool0
0`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool0
03/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo
00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000
J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`00
0000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P00
00000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`00
0000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@0
00000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?oo
o`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo10000003
0?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?oo
o`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000
003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003o
ool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<0
00000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P000000
0`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
0680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo
0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W
0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo10000009
0?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`80
0000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0
oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo
0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0
oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo
001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e
0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?oo
o`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`80
0000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00
J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@0
0000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000
503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool0
0`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool0
0`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740
oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k
0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?oo
o`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00
T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003o
ool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool0
0`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440
oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0
oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo
1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00
002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`
0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`03
0000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00
I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3o
ool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo
00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?oo
o`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@0
0000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.64229 .66114 m
.65084 .6659 L
s
.67767 .65076 m
.65084 .6659 L
s
.63988 .65836 m
.64229 .66114 L
s
.63995 .65555 m
.63988 .65836 L
s
.64126 .65341 m
.63995 .65555 L
s
.64384 .65054 m
.64126 .65341 L
s
.64285 .64127 m
.62503 .65151 L
s
.67767 .65076 m
.66911 .6459 L
s
.65023 .64689 m
.64384 .65054 L
s
.65531 .64539 m
.65023 .64689 L
s
.66911 .6459 m
.66414 .64455 L
s
.63519 .64568 m
.63778 .64278 L
s
.65911 .64462 m
.65531 .64539 L
s
.66414 .64455 m
.65911 .64462 L
s
.63778 .64278 m
.63785 .6399 L
s
.63785 .6399 m
.63664 .63776 L
s
.60632 .63964 m
.60253 .63897 L
s
.61136 .63956 m
.60632 .63964 L
s
.61643 .63805 m
.61136 .63956 L
s
.60253 .63897 m
.59875 .63686 L
s
.61897 .63657 m
.61643 .63805 L
s
.63664 .63776 m
.6329 .63565 L
s
.59875 .63686 m
.59748 .63471 L
s
.62154 .63364 m
.61897 .63657 L
s
.59748 .63471 m
.59749 .63181 L
s
.6115 .62357 m
.59369 .63404 L
s
.62159 .63073 m
.62154 .63364 L
s
.62035 .62856 m
.62159 .63073 L
s
.61657 .62643 m
.62035 .62856 L
s
.61276 .62575 m
.61657 .62643 L
s
.59236 .61276 m
.57968 .62623 L
s
.6026 .61854 m
.57968 .62623 L
s
.60767 .62582 m
.61276 .62575 L
s
.58204 .60694 m
.5694 .6205 L
s
.59236 .61276 m
.5694 .6205 L
s
.55251 .60961 m
.54863 .60892 L
s
.55765 .60954 m
.55251 .60961 L
s
.56149 .60874 m
.55765 .60954 L
s
.54863 .60892 m
.54339 .606 L
s
.5666 .60716 m
.56149 .60874 L
s
.57298 .60331 m
.5666 .60716 L
s
.54339 .606 m
.54203 .60377 L
s
.54203 .60377 m
.54193 .60075 L
s
.57552 .60026 m
.57298 .60331 L
s
.54193 .60075 m
.54315 .59847 L
s
.57678 .59797 m
.57552 .60026 L
s
.55353 .59983 m
.54696 .59613 L
s
.54315 .59847 m
.54696 .59613 L
s
.57674 .59493 m
.57678 .59797 L
s
.54668 .58697 m
.52889 .59792 L
s
.57542 .59267 m
.57674 .59493 L
s
.57017 .58969 m
.57542 .59267 L
s
.53903 .59168 m
.54152 .58858 L
s
.55717 .58988 m
.56106 .58906 L
s
.56626 .58898 m
.57017 .58969 L
s
.56106 .58906 m
.56626 .58898 L
s
.54152 .58858 m
.54142 .58551 L
s
.54142 .58551 m
.54003 .58322 L
s
.5088 .58523 m
.50485 .58452 L
s
.51401 .58515 m
.5088 .58523 L
s
.51916 .58353 m
.51401 .58515 L
s
.50485 .58452 m
.5008 .58226 L
s
.5217 .58195 m
.51916 .58353 L
s
.54003 .58322 m
.53603 .58096 L
s
.5008 .58226 m
.49936 .57996 L
s
.52417 .57881 m
.5217 .58195 L
s
.49936 .57996 m
.49918 .57686 L
s
.50364 .56267 m
.47709 .57952 L
s
.51316 .56805 m
.49539 .57924 L
s
.52404 .57571 m
.52417 .57881 L
s
.52262 .57339 m
.52404 .57571 L
s
.51857 .5711 m
.52262 .57339 L
s
.48441 .57162 m
.48966 .57154 L
s
.48041 .57089 m
.48441 .57162 L
s
.51459 .57038 m
.51857 .5711 L
s
.4763 .5686 m
.48041 .57089 L
s
.50933 .57046 m
.51459 .57038 L
s
.47481 .56626 m
.4763 .5686 L
s
.47458 .56311 m
.47481 .56626 L
s
.49981 .5651 m
.49963 .56194 L
s
.477 .5599 m
.47458 .56311 L
s
.49963 .56194 m
.49817 .55958 L
s
.47953 .55828 m
.477 .5599 L
s
.49817 .55958 m
.49405 .55726 L
s
.48505 .54132 m
.45835 .5586 L
s
.48472 .5566 m
.47953 .55828 L
s
.49405 .55726 m
.49003 .55652 L
s
.49003 .55652 m
.48472 .5566 L
s
.471 .55041 m
.47064 .54559 L
s
.45563 .54177 m
.443 .55004 L
s
.47064 .54559 m
.46912 .54319 L
s
.44944 .53208 m
.43173 .54376 L
s
.46912 .54319 m
.46493 .54082 L
s
.46085 .54007 m
.45563 .54177 L
s
.46493 .54082 m
.46085 .54007 L
s
.41879 .535 m
.41468 .53425 L
s
.42416 .53492 m
.41879 .535 L
s
.42936 .5332 m
.42416 .53492 L
s
.41468 .53425 m
.41039 .53186 L
s
.43189 .53152 m
.42936 .5332 L
s
.41039 .53186 m
.40877 .52941 L
s
.43427 .5282 m
.43189 .53152 L
s
.40877 .52941 m
.40841 .52612 L
s
.43396 .5249 m
.43427 .5282 L
s
.45711 .52702 m
.45697 .52537 L
s
.4598 .52698 m
.45711 .52702 L
s
.45967 .52533 m
.4598 .52698 L
s
.45697 .52537 m
.45967 .52533 L
s
.43237 .52244 m
.43396 .5249 L
s
.42807 .52001 m
.43237 .52244 L
s
.39579 .52217 m
.39975 .52128 L
s
.39019 .5206 m
.39579 .52217 L
s
.38583 .51816 m
.39019 .5206 L
s
.42393 .51924 m
.42807 .52001 L
s
.41851 .51933 m
.42393 .51924 L
s
.38271 .51487 m
.38583 .51816 L
s
.40587 .51535 m
.40171 .51457 L
s
.40985 .51445 m
.40587 .51535 L
s
.38375 .51234 m
.38271 .51487 L
s
.40171 .51457 m
.39317 .51135 L
s
.41094 .51191 m
.40985 .51445 L
s
.38501 .51148 m
.38375 .51234 L
s
.40785 .5086 m
.41094 .51191 L
s
.38899 .51057 m
.38501 .51148 L
s
.39317 .51135 m
.38899 .51057 L
s
.40349 .50613 m
.40785 .5086 L
s
.36826 .50837 m
.36803 .50668 L
s
.37098 .50833 m
.36826 .50837 L
s
.37076 .50664 m
.37098 .50833 L
s
.36803 .50668 m
.37076 .50664 L
s
.39784 .50452 m
.40349 .50613 L
s
.39384 .50543 m
.39784 .50452 L
s
.3948 .49005 m
.37704 .5023 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`0E0?ooo`030000o`3oool0oooo06d0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool04P3oool20000ofd0
oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
00<000000?ooo`000000J03oool00`000000oooo0?ooo`0?0?ooo`80003oK03oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool03@3oool20000of/0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0;
0?ooo`030000o`3oool0oooo06P0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`1M0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`060?ooo`80003o203oool010000?l0oooo0000o`000?mJ
0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`05
0?ooo`80003o1P3oool00`000?l0oooo0?ooo`030?ooo`80003oE@3oool3000001@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02P3oool20000o`030?ooo`000?l0
003o00D0oooo00<0003o0?ooo`3oool0C`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?ooo`020?ooo`H0003oCP3oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo
0580oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0
oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`090?ooo`050000o`3oool0oooo0?oo
o`000?l01P3oool40000od40oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`090?ooo`<0
003o2`3oool20000oc`0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0>0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20000obl0oooo0`00000X0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003o
ool0oooo00d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`80003o;03o
ool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0<0?ooo`80003o1`3oool0
0`000?l0oooo0?ooo`0a0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`0=0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0X0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000
oooo0?ooo`0=0?ooo`D0003o1@3oool20000obP0oooo0`00000d0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo
00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`0U0?ooo`<00000=`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool04P3oool20000o`H0oooo10000?l70?ooo`030000o`3oool0oooo0140oooo0`00
000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<00000
0?ooo`3oool0O03oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo00@0oooo0P000?l4
0?ooo`80003o0`3oool20000oa40oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0D0?oo
o`80003o1`3oool010000?l0oooo0000o`000?l@0?ooo`<00000@03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?oo
o`3oool04P3oool00`000?l0oooo0?ooo`070?ooo`80003o3`3oool3000004<0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`03
0000003oool0oooo01X0oooo0P000?l=0?ooo`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0G0?ooo`80003o
303oool3000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3o
ool60000o`030000003oool0oooo04X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01/0oooo00<0003o
0000000000000P0000020?ooo`80003oC03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool00`00
0000003o000000070?ooo`030000o`3oool0003o04X0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0
oooo0`0000000`3oool0003o0?ooo`070?ooo`80003oB`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000000@0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo00<0003o0?ooo`3oool0
A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08L0oooo00<000000?ooo`3oool0303oool3000000P0oooo1P000?l50?ooo`D0003oA@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0203oool3000000h0oooo0P000?l50?ooo`030000o`3oool0
oooo00<0oooo0P000?m30?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool0
02D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000003`3oool20000
o`D0oooo0P000?l70?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
00004@3oool00`000?l0oooo0?ooo`040?ooo`80003o203oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
S03oool2000001d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool07@3oool60000o`L0oooo0P000?lk0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02/0oooo00<0003o0?ooo`000?l0=P3oool300000080oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02/0oooo0P000?l40?ooo`D0003o:P3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0
oooo0P000?l;0?ooo`80003o9@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo
0P000?l40?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool07`3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool00P3oool20000o`030?ooo`00
0?l0oooo00P0oooo00<0003o0?ooo`3oool0703oool300000180oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02/0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`030000o`3oool0oooo01X0oooo0`00
000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo00T0oooo00<0003o
0?ooo`3oool05P3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B
0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo00<0003o0?oo
o`3oool01`3oool20000o`<0oooo00<0003o0?ooo`3oool0403oool3000001h0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02`0oooo2@000?l40?ooo`030000o`3oool0oooo00h0oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo00`0oooo0`00000V0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003o
ool0oooo03L0oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo0`00000Z0?ooo`030000003o
ool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo00@0003o0P3oool4000002h0oooo00<00000
0?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo03L0oooo10000?l20?ooo`050000o`00000000000000003oool00P000?l`
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0f0?ooo`80003o0`3oool3000000040?ooo`000?l0003o
0000oc80oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03P0oooo0`0000040000o`L0oooo00<0003o0?oo
o`3oool0;03oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool300000080oooo0P000?l80?ooo`80
003o00<0oooo0000o`000?l0;@3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool4000000d0oooo
0P000?l50?ooo`80003o;03oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000l0oooo0P00
0?l80?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00000A
0?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0W
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000005P3oool30000o`@0oooo0P000?l50?oo
o`030000o`3oool0oooo02L0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?oo
o`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool3000001`0oooo10000?l80?ooo`03
0000o`3oool0003o02L0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`00
8@3oool200000900oooo00<000000?ooo`3oool08@3oool4000002/0oooo0P000?l80?ooo`030000
o`3oool0oooo01h0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000]0?ooo`80003o103o
ool60000o`030?ooo`000?l0oooo01l0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K
0?ooo`<00000;P3oool20000o`D0oooo00<0003o0?ooo`3oool01P3oool20000oah0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`000006
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool300000300oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`090?ooo`80003o7@3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000>@3oool00`000?l0oooo0?ooo`090?oo
o`80003o7`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`80
00001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000l0?ooo`03
0000o`3oool0oooo00L0oooo0P000?lR0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo00h0oooo0`0000100?ooo`030000o`3oool0oooo00D0oooo0P000?lU0?ooo`030000
003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool02`3oool3000004<0oooo0P000?l40?ooo`80003o9`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0203oool3000004P0oooo10000?lZ0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`00
0000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?oo
o`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@0
0000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000
T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4
000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0
oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo
08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo
000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h
0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<00000
7P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4
000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J
0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?oo
o`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`03
0000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3o
ool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000
?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo
09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo
00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l
0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?oo
o`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000
GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`00
0000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo
00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<0
00000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M
0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?oo
o`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`03
0000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000
O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`00
0000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo
0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?oo
o`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0
oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00
oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3o
ool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?oo
o`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo
0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?oo
o`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?oo
o`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool20000
08@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo
00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00
001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`80
0000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3o
ool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103o
ool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?oo
o`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`80
0000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003o
ool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool0
1@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo0012
0?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3o
ool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000
003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo
0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3o
ool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000
003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0
oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3o
ool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3o
ool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool20000
00l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0
oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040
oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?oo
o`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F
0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0
oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000
003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`80
0000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3o
ool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool20000
0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0
oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo
00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<00000
0?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?oo
o`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D0
00008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool20000
03L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0
oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo
00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@0
00000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo
001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00
000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?oo
o`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?oo
o`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3o
ool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000
JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3o
ool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool5
00000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4
000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo
00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00
000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I
0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?oo
o`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000
VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000
WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3o
ool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool0
06D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0
oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000
oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo
0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@0
00000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo
1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`04
0?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?oo
o`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@0
0000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo
00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo
002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo
1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo
002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.61164 .673 m
.61823 .67862 L
s
.64927 .66702 m
.61823 .67862 L
s
.61028 .67003 m
.61164 .673 L
s
.61133 .6673 m
.61028 .67003 L
s
.61334 .66537 m
.61133 .6673 L
s
.64927 .66702 m
.64275 .66132 L
s
.61683 .66288 m
.61334 .66537 L
s
.62425 .66008 m
.61683 .66288 L
s
.6191 .65376 m
.59833 .66165 L
s
.64275 .66132 m
.63844 .65942 L
s
.62966 .65921 m
.62425 .66008 L
s
.63844 .65942 m
.63358 .65891 L
s
.63358 .65891 m
.62966 .65921 L
s
.61017 .65715 m
.61368 .65464 L
s
.61368 .65464 m
.61475 .65185 L
s
.61475 .65185 m
.61433 .64963 L
s
.61433 .64963 m
.61145 .64713 L
s
.58927 .64842 m
.58436 .6479 L
s
.5947 .64754 m
.58927 .64842 L
s
.58436 .6479 m
.58092 .6468 L
s
.59768 .6464 m
.5947 .64754 L
s
.58092 .6468 m
.57799 .6443 L
s
.60119 .64385 m
.59768 .6464 L
s
.57799 .6443 m
.57752 .64206 L
s
.60224 .64103 m
.60119 .64385 L
s
.57752 .64206 m
.57853 .63923 L
s
.6018 .63877 m
.60224 .64103 L
s
.59499 .63286 m
.57407 .64096 L
s
.59889 .63625 m
.6018 .63877 L
s
.59544 .63514 m
.59889 .63625 L
s
.59049 .63461 m
.59544 .63514 L
s
.58022 .62006 m
.56319 .63168 L
s
.58812 .62691 m
.56319 .63168 L
s
.57224 .61315 m
.5552 .62487 L
s
.58022 .62006 m
.5552 .62487 L
s
.5476 .61275 m
.54256 .61221 L
s
.55162 .61243 m
.5476 .61275 L
s
.55715 .61151 m
.55162 .61243 L
s
.54256 .61221 m
.53902 .61106 L
s
.5647 .60852 m
.55715 .61151 L
s
.53902 .61106 m
.53493 .60758 L
s
.56824 .60585 m
.5647 .60852 L
s
.53493 .60758 m
.53439 .60523 L
s
.57027 .60377 m
.56824 .60585 L
s
.53439 .60523 m
.53535 .60227 L
s
.5713 .60081 m
.57027 .60377 L
s
.547 .60277 m
.54188 .59836 L
s
.53535 .60227 m
.53734 .60018 L
s
.5708 .59844 m
.5713 .60081 L
s
.53734 .60018 m
.54188 .59836 L
s
.56675 .5949 m
.5708 .59844 L
s
.54482 .58938 m
.5236 .59791 L
s
.56319 .59373 m
.56675 .5949 L
s
.5581 .59317 m
.56319 .59373 L
s
.55403 .5935 m
.5581 .59317 L
s
.5357 .59305 m
.53922 .59032 L
s
.53922 .59032 m
.5402 .58731 L
s
.5402 .58731 m
.53966 .5849 L
s
.53966 .5849 m
.53654 .5822 L
s
.51353 .58359 m
.50839 .58303 L
s
.51914 .58264 m
.51353 .58359 L
s
.50839 .58303 m
.50476 .58184 L
s
.52218 .5814 m
.51914 .58264 L
s
.50476 .58184 m
.50159 .57914 L
s
.5257 .57864 m
.52218 .5814 L
s
.50159 .57914 m
.50098 .5767 L
s
.52666 .57559 m
.5257 .57864 L
s
.50098 .5767 m
.5019 .57364 L
s
.5261 .57314 m
.52666 .57559 L
s
.51871 .56675 m
.49734 .57551 L
s
.51127 .5603 m
.47923 .57351 L
s
.52294 .57041 m
.5261 .57314 L
s
.5193 .56921 m
.52294 .57041 L
s
.51411 .56863 m
.5193 .56921 L
s
.48923 .56667 m
.49443 .56724 L
s
.48556 .56546 m
.48923 .56667 L
s
.48232 .5627 m
.48556 .56546 L
s
.48168 .56022 m
.48232 .5627 L
s
.50667 .5622 m
.5076 .55908 L
s
.48257 .55709 m
.48168 .56022 L
s
.5076 .55908 m
.507 .55659 L
s
.48608 .55425 m
.48257 .55709 L
s
.507 .55659 m
.50378 .5538 L
s
.48915 .55297 m
.48608 .55425 L
s
.50378 .5538 m
.50008 .55257 L
s
.49485 .55199 m
.48915 .55297 L
s
.50008 .55257 m
.49485 .55199 L
s
.50056 .53705 m
.46816 .55063 L
s
.48353 .54419 m
.48488 .53941 L
s
.47144 .53376 m
.45603 .54027 L
s
.48488 .53941 m
.48423 .53686 L
s
.48423 .53686 m
.48094 .534 L
s
.48094 .534 m
.47719 .53275 L
s
.47719 .53275 m
.47144 .53376 L
s
.46876 .52344 m
.44711 .53267 L
s
.44274 .523 m
.43739 .5224 L
s
.44851 .52198 m
.44274 .523 L
s
.43739 .5224 m
.43358 .52113 L
s
.45161 .52065 m
.44851 .52198 L
s
.43358 .52113 m
.43017 .51822 L
s
.45514 .51769 m
.45161 .52065 L
s
.48124 .51813 m
.48079 .51977 L
s
.48079 .51977 m
.47811 .51946 L
s
.47811 .51946 m
.47857 .51783 L
s
.43017 .51822 m
.42943 .5156 L
s
.47857 .51783 m
.48124 .51813 L
s
.456 .5144 m
.45514 .51769 L
s
.42943 .5156 m
.43024 .51231 L
s
.4553 .51178 m
.456 .5144 L
s
.45191 .50884 m
.4553 .51178 L
s
.44808 .50755 m
.45191 .50884 L
s
.44269 .50693 m
.44808 .50755 L
s
.41911 .50679 m
.42336 .50642 L
s
.41409 .50451 m
.41911 .50679 L
s
.41062 .50154 m
.41409 .50451 L
s
.40868 .49788 m
.41062 .50154 L
s
.43155 .50137 m
.42769 .50007 L
s
.43583 .501 m
.43155 .50137 L
s
.43781 .49865 m
.43583 .501 L
s
.42769 .50007 m
.42035 .49578 L
s
.43593 .49498 m
.43781 .49865 L
s
.41063 .49552 m
.40868 .49788 L
s
.42035 .49578 m
.41647 .49447 L
s
.41219 .49484 m
.41063 .49552 L
s
.43247 .49198 m
.43593 .49498 L
s
.41647 .49447 m
.41219 .49484 L
s
.42743 .48966 m
.43247 .49198 L
s
.42313 .49004 m
.42743 .48966 L
s
.39932 .48989 m
.39659 .48958 L
s
.39971 .4882 m
.39932 .48989 L
s
.39659 .48958 m
.39697 .48788 L
s
.39697 .48788 m
.39971 .4882 L
s
.42957 .475 m
.40752 .48475 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0:03oool00`00
0?l0oooo0?ooo`1R0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool09@3oool20000ofD0
oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0R0?ooo`80003oI`3oool00`000000oooo
0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo01l0oooo0P000?mY0?ooo`030000003oool0oooo00@0oooo0`00
001>0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<00000
0?ooo`3oool0703oool20000of/0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool05`3oool2
0000ofl0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool05P3oool20000o`P0oooo0P000?mS0?ooo`<00000F03oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo01`0
oooo00<0003o0?ooo`3oool00P3oool20000oeh0oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`0I0?ooo`80003o00<0oooo0000o`000?l0103oool00`000?l0oooo0?ooo`1H0?ooo`<00000
1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3o
ool00`000000oooo0?ooo`0H0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`1D0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0603oool0
0`000?l0oooo0?ooo`030?ooo`@0003oE03oool3000000/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`0H0?ooo`030000o`3oool0oooo05L0oooo0`00000>0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo01P0oooo10000?l60?ooo`<0003oB@3oool30000
0140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0903oool00`00
0?l0oooo0?ooo`130?ooo`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`00
0000oooo0?ooo`0K0?ooo`030000o`3oool0oooo00H0oooo0P000?m00?ooo`<00000603oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool0>`3oool3000001/0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`0I0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool01@3oool20000oc40
oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0I0?ooo`80003o1@3oool20000o`P0oooo
0P000?l]0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06P3oool50000o`L0oooo00<0
003o0?ooo`3oool0;03oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo02<0oooo0P000?l/
0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`800000MP3oool00`000000oooo0?ooo`0P0?ooo`80003o:`3oool3000002/0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`0M0?ooo`80003o:P3oool3000002h0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000
003oool0oooo07L0oooo00<000000?ooo`3oool06P3oool20000o`L0oooo10000?lN0?ooo`<00000
<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003o
ool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0P0?ooo`80003o103o
ool00`000?l0oooo0?ooo`030?ooo`80003o4`3oool3000003@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool0
0`000000oooo0?ooo`0M0?ooo`80003o1`3oool00`000?l0oooo0?ooo`020000oa80oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0J0?ooo`80003o203oool40000oa40oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0Q0?ooo`<0003o4@3oool3000003d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo01h0oooo0P000?lA0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool06`3o
ool20000oa00oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0R0?ooo`D0003o0P3oool3
000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool30000
0840oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020?ooo`03000000000?l0003o
04T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool00`0000030?ooo`03
0000o`3oool0oooo04H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo00@0003o000000000000
00001P3oool30000odL0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000000`3oool0003o
0?ooo`060?ooo`80003oB@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000D0oooo0P00
0?l30?ooo`80003o1@3oool00`000?l0oooo0?ooo`130?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@
0?ooo`<000002P3oool30000o`D0oooo0`000?m50?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?oo
o`<000002`3oool20000o`H0oooo0P000?l30?ooo`80003o@`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0203oool3000000`0oooo0P000?l60?ooo`80003o1`3oool00`000?l0oooo0?ooo`100?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`040?ooo`<000005@3oool30000o`P0oooo00<0003o0?ooo`3oool0
@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000J0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08`0oooo0P00000N0?ooo`030000o`3oool0oooo0080oooo0`000?l4
0?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool07P3oool40000o`P0oooo00<0003o0?oo
o`3oool0>P3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo03L0oooo0`0000020?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0Z0?ooo`<0003o<`3oool4000000H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02T0oooo0P000?l40?ooo`<0003o:`3oool3000000X0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo02H0oooo0`000?l90?ooo`<0003o9@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02@0oooo0P000?l50?ooo`030000o`3oool0oooo00L0oooo0P000?lP0?ooo`<000004P3oool00`00
0000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0:@3oool20000o`030?ooo`000?l0oooo00P0oooo00<0003o0?ooo`3o
ool06`3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01L0oooo1000000J0?ooo`030000
003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3o
ool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool05@3o
ool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o0?ooo`3oool0203oool2
0000oaD0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0Y0?ooo`<0003o1@3oool20000
oa@0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0
oooo0P00002?0?ooo`030000003oool0oooo02`0oooo1@000?l50?ooo`030000o`3oool0oooo00/0
oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0d0?ooo`80003o2P3oool4000002h0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03@0oooo00@0003o0?ooo`3oool0oooo0`000?l30?ooo`<00000
<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0<P3oool60000o`030?ooo`000?l0oooo00<00000=P3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0<@3oool30000o`@0oooo0`00000j0?ooo`030000003oool0
oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0e0?ooo`<000000`3oool30000ocP0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340
oooo100000000`000?l0oooo0000o`030000oc`0oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo
0`0000030?ooo`<0003o203oool20000ocL0oooo00<000000?ooo`3oool0C03oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00
000?0?ooo`D0003o=P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000000l0oooo0`000?l5
0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000100oooo0`000?l70?oo
o`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?oo
o`008@3oool200000900oooo00<000000?ooo`3oool08@3oool4000001@0oooo00<0003o0?ooo`3o
ool01P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000
6@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
<`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000M0?ooo`H0003o1P3o
ool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3o
ool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01P0oooo0`00000/0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool05@3oool3000002l0oooo0`000?ld0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool04@3oool400000300oooo0`000?lg0?ooo`030000003oool0oooo
04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000b0?ooo`<0003o103oool70000obl0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000<`3oool20000o`D0oooo
0P000?l70?ooo`80003o;@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000003`0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`04
0?ooo`@00000?P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o;@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?oo
o`3oool0oooo0`0000110?ooo`030000o`3oool0oooo00P0oooo0`000?l`0?ooo`030000003oool0
oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000A@3oool00`00
0?l0oooo0?ooo`040?ooo`<0003o=03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
00h0oooo000O0?ooo`800000T03oool3000004T0oooo00<0003o0?ooo`3oool00`000?lg0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool0B03oool20000oc/0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.57787 .68102 m
.58229 .68725 L
s
.61632 .67952 m
.58229 .68725 L
s
.57758 .67797 m
.57787 .68102 L
s
.61632 .67952 m
.61202 .67323 L
s
.57956 .67543 m
.57758 .67797 L
s
.58217 .67378 m
.57956 .67543 L
s
.58643 .67176 m
.58217 .67378 L
s
.61202 .67323 m
.60853 .6709 L
s
.59458 .66989 m
.58643 .67176 L
s
.60853 .6709 m
.60401 .66983 L
s
.60012 .66967 m
.59458 .66989 L
s
.60401 .66983 m
.60012 .66967 L
s
.5918 .66315 m
.56892 .66841 L
s
.58198 .66541 m
.58625 .66336 L
s
.58625 .66336 m
.58826 .66078 L
s
.58826 .66078 m
.58863 .65856 L
s
.58863 .65856 m
.58672 .6558 L
s
.56475 .65446 m
.56016 .65337 L
s
.57033 .65423 m
.56475 .65446 L
s
.57362 .65347 m
.57033 .65423 L
s
.57792 .6514 m
.57362 .65347 L
s
.56016 .65337 m
.5572 .6519 L
s
.5572 .6519 m
.55523 .64911 L
s
.57993 .64877 m
.57792 .6514 L
s
.55523 .64911 m
.55555 .64687 L
s
.58029 .64652 m
.57993 .64877 L
s
.55555 .64687 m
.55753 .64423 L
s
.57834 .64372 m
.58029 .64652 L
s
.57574 .63996 m
.55258 .64539 L
s
.57539 .64223 m
.57834 .64372 L
s
.57077 .64113 m
.57539 .64223 L
s
.56588 .62573 m
.54524 .63504 L
s
.57116 .63335 m
.54524 .63504 L
s
.56055 .61803 m
.53984 .62743 L
s
.56588 .62573 m
.53984 .62743 L
s
.54071 .61485 m
.53667 .61468 L
s
.54642 .61462 m
.54071 .61485 L
s
.53667 .61468 m
.53194 .61354 L
s
.55483 .61261 m
.54642 .61462 L
s
.53194 .61354 m
.52889 .612 L
s
.55921 .61043 m
.55483 .61261 L
s
.52889 .612 m
.52611 .60809 L
s
.56191 .60864 m
.55921 .61043 L
s
.56395 .60588 m
.56191 .60864 L
s
.52611 .60809 m
.52641 .60573 L
s
.5643 .60351 m
.56395 .60588 L
s
.52641 .60573 m
.52839 .60295 L
s
.53959 .60485 m
.53614 .59993 L
s
.5616 .59956 m
.5643 .60351 L
s
.52839 .60295 m
.53107 .60115 L
s
.53107 .60115 m
.53614 .59993 L
s
.55854 .59799 m
.5616 .59956 L
s
.55378 .59683 m
.55854 .59799 L
s
.54217 .5915 m
.51843 .59726 L
s
.5497 .59665 m
.55378 .59683 L
s
.53197 .59397 m
.53637 .59174 L
s
.53637 .59174 m
.53839 .58892 L
s
.53839 .58892 m
.5387 .5865 L
s
.5387 .5865 m
.53661 .58348 L
s
.5136 .58201 m
.50876 .58082 L
s
.51943 .58177 m
.5136 .58201 L
s
.52284 .58093 m
.51943 .58177 L
s
.52726 .57866 m
.52284 .58093 L
s
.50876 .58082 m
.50562 .57922 L
s
.50562 .57922 m
.50346 .57617 L
s
.52928 .57579 m
.52726 .57866 L
s
.50346 .57617 m
.50373 .57371 L
s
.52958 .57334 m
.52928 .57579 L
s
.50373 .57371 m
.50571 .57082 L
s
.52746 .57027 m
.52958 .57334 L
s
.52461 .56616 m
.50057 .57209 L
s
.52431 .56864 m
.52746 .57027 L
s
.51944 .56744 m
.52431 .56864 L
s
.5196 .55893 m
.48347 .56788 L
s
.49572 .56242 m
.50063 .56363 L
s
.49254 .56077 m
.49572 .56242 L
s
.49033 .55766 m
.49254 .56077 L
s
.51441 .56021 m
.51643 .55728 L
s
.49058 .55515 m
.49033 .55766 L
s
.51643 .55728 m
.51671 .55476 L
s
.49255 .5522 m
.49058 .55515 L
s
.51671 .55476 m
.51454 .55163 L
s
.49701 .54985 m
.49255 .5522 L
s
.51454 .55163 m
.51135 .54996 L
s
.51135 .54996 m
.50642 .54873 L
s
.50048 .54898 m
.49701 .54985 L
s
.50642 .54873 m
.50048 .54898 L
s
.51729 .53482 m
.48066 .54404 L
s
.49805 .53966 m
.50107 .53515 L
s
.50107 .53515 m
.50134 .53257 L
s
.50134 .53257 m
.49911 .52935 L
s
.48985 .5279 m
.47236 .53234 L
s
.49911 .52935 m
.49586 .52764 L
s
.49586 .52764 m
.48985 .5279 L
s
.49086 .51745 m
.46625 .52373 L
s
.50501 .51384 m
.50398 .51538 L
s
.50398 .51538 m
.50146 .51474 L
s
.50146 .51474 m
.50248 .5132 L
s
.50248 .5132 m
.50501 .51384 L
s
.46535 .51367 m
.46028 .51239 L
s
.47141 .51341 m
.46535 .51367 L
s
.47494 .51251 m
.47141 .51341 L
s
.47948 .51005 m
.47494 .51251 L
s
.46028 .51239 m
.45696 .51065 L
s
.45696 .51065 m
.45462 .50734 L
s
.48149 .50694 m
.47948 .51005 L
s
.45462 .50734 m
.45482 .50468 L
s
.48173 .50427 m
.48149 .50694 L
s
.45482 .50468 m
.4568 .50155 L
s
.47943 .50095 m
.48173 .50427 L
s
.47611 .49918 m
.47943 .50095 L
s
.471 .49787 m
.47611 .49918 L
s
.44773 .49467 m
.45208 .49486 L
s
.44357 .49177 m
.44773 .49467 L
s
.44118 .4884 m
.44357 .49177 L
s
.46632 .49116 m
.46197 .49097 L
s
.46912 .48911 m
.46632 .49116 L
s
.46197 .49097 m
.45861 .48918 L
s
.45861 .48918 m
.45287 .484 L
s
.46856 .48526 m
.46912 .48911 L
s
.44056 .48454 m
.44118 .4884 L
s
.4662 .48186 m
.46856 .48526 L
s
.44333 .48248 m
.44056 .48454 L
s
.45287 .484 m
.44949 .4822 L
s
.44512 .48201 m
.44333 .48248 L
s
.44949 .4822 m
.44512 .48201 L
s
.46204 .47892 m
.4662 .48186 L
s
.45766 .47872 m
.46204 .47892 L
s
.43411 .47545 m
.43151 .47477 L
s
.4351 .47383 m
.43411 .47545 L
s
.43151 .47477 m
.43249 .47316 L
s
.43249 .47316 m
.4351 .47383 L
s
.46936 .46479 m
.44408 .47146 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo03X0oooo0P000?mE0?ooo`03
0000003oool0oooo01X0oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000
003oool0oooo05/0oooo00<000000?ooo`3oool0=P3oool30000oeL0oooo00<000000?ooo`3oool0
5`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003o
ool0oooo0340oooo10000?mJ0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`0^0?ooo`80003oGP3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02T0oooo0P000?mR0?ooo`030000003oool0oooo
00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0300oooo
0`000?mH0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0:P3oool30000o`D0oooo0P00
0?mF0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0?ooo`3o
ool20000o`D0oooo00<0003o0?ooo`3oool0D`3oool010000000oooo0?ooo`3oool300000580oooo
00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?oo
o`0W0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`1C0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool00`3oool40000oe@0oooo0`00001H
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool09`3oool00`000?l0oooo0?ooo`1G0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3o
ool09`3oool20000oe@0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02l0oooo0`000?m80?ooo`<00000
203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003o
ool0oooo06T0oooo00<000000?ooo`3oool0:@3oool00`000?l0oooo0?ooo`050?ooo`80003o@`3o
ool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0?P3oool3000000h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo03/0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0
oooo02D0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0h0?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0U0?ooo`80003o1@3oool2
0000o`P0oooo00<0003o0?ooo`3oool0;@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool09P3oool50000o`X0oooo0P000?l[0?ooo`<000006`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo02h0oooo0`000?l]0?ooo`<000007P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0:@3oool40000ob`0oooo1000000Q0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`0U0?ooo`<0003o;@3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00
000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f
0?ooo`030000003oool0oooo02/0oooo10000?lN0?ooo`<00000:`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?oo
o`030000003oool0oooo02H0oooo10000?l40?ooo`030000o`3oool0oooo01P0oooo0`00000^0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`00
0000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02<0oooo0P000?l90?ooo`03
0000o`3oool0oooo01@0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000
003oool0oooo02d0oooo00@0003o0?ooo`3oool0oooo0`000?l=0?ooo`<00000=03oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo
0?ooo`1i0?ooo`030000003oool0oooo02/0oooo1@000?l=0?ooo`<00000=`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool09P3oool50000o`h0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0R
0?ooo`<0003o403oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000100?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0OP3oool00`000000oooo0?ooo`0V0?ooo`L0003o0`0000130?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0T0?ooo`030000o`3oool0oooo0080oooo0`0000000`000?l0oooo0?ooo`130?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo0280oooo00<0003o0?ooo`3oool00`0000040?ooo`030000o`3oool0oooo0480oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo0240oooo00<0003o0000000000001P3oool00`000?l0oooo0?ooo`13
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@0000000<0oooo0000o`3oool01P3oool30000
od@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000060?ooo`L0003oA`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0503oool3000000L0oooo1@000?l60?ooo`80003o@`3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0403oool3000000L0oooo0`000?l70?ooo`H0003o@`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<00000
0?ooo`3oool0303oool300000140oooo0`000?l60?ooo`80003o@@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool3000001D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0o0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<00000603oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000006`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo0400oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000007`3oool70000od<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0k0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo00<0003o0?oo
o`3oool0=`3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02X0oooo00<0003o0?ooo`3o
ool0<`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo0`000?la0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09@3oool40000oc40oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0R0?ooo`<0003o2@3oool40000obD0oooo0`00000B0?ooo`030000003oool0
oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0W0?ooo`<0003o203oool00`000?l0oooo0?ooo`0O0?ooo`<000005P3oool00`00
0000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool09P3oool010000?l0oooo0?ooo`000?l90?ooo`030000o`3oool0oooo
01X0oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0G0?ooo`<000007P3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo01D0oooo
0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00P0oooo00<0
003o0?ooo`3oool04`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool09`3oool:0000oa<0oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0<P3oool20000o`X0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0`0?ooo`80003o
2@3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo0`000?l00`3oool0003o0000
o`030000o`80oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`H0003o0P3oool2
0000o`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02h0oooo0`0000020?ooo`D0003o@03oool00`000000oooo0?ooo`1<0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
:`3oool3000000D0003oA@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<00000
0?ooo`3oool09@3oool3000000l0oooo0`000?m00?ooo`030000003oool0oooo04X0oooo00<00000
0?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000=0?oo
o`D0003o00@0oooo0000o`000?l0003o@03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
00l0oooo0`000?l70?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0K0?ooo`<000004`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03l0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000001L0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000K0?ooo`H0003oA@3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo0140oooo1000000X0?ooo`030000o`3oool0oooo03l0oooo00<0
00000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000002`0oooo00<0003o
0?ooo`3oool0@03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?oo
o`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000_0?oo
o`<0003o@03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000002h0oooo10000?m40?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`040?ooo`@00000;P3oool30000odT0oooo00<000000?ooo`3oool0
A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003o
ool0oooo0?ooo`<00000>`3oool70000ocd0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0>0?ooo`00803oool200000940oooo1000000j0?ooo`@0003o1`3oool00`000?l0oooo0?oo
o`0k0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@
0?ooo`<00000?03oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo03X0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?oo
o`<000000P3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?oo
o`3oool0>`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`03
0000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3o
ool02@3oool40000ocd0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0j0?ooo`030000
o`3oool0oooo0080oooo1P000?m20?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0>`3o
ool40000odT0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool30000
0140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N
0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?oo
o`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0
IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool30000
0340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0
oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<0
00000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<00000
0?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?oo
o`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3o
ool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000
B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003o
ool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool40000
0540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<0
00000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?oo
o`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000
003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3o
ool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3o
ool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool40000
0700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<0
00000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I
0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?oo
o`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3o
ool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo
0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000
U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2
000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000
oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo
1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?oo
o`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000
003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403o
ool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool20000
0800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000
oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo
00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`04
0?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0
oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0
oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04
0?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`00
0000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440
oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`39
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo
00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo
001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?oo
o`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?oo
o`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3o
ool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`80
0000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03o
ool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0
oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?oo
o`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?oo
o`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`00
00000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J
0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?oo
o`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000
003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03o
ool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool0
06`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo
0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000
000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<00000
0?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?oo
o`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000
=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3o
ool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool0
06P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool0
0`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5
000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool40000
05@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0
oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@0
00000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<0
00000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V
0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool0
00007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000
003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0
oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool50000
08P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0
oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F
0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B
0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?oo
o`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`03
0000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool0
00003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00
IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000
003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3o
ool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool0
0`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0
oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2
000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo0000
00000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?oo
o`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0
oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P00
00040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3o
ool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03o
ool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001
\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.54223 .68496 m
.54436 .69155 L
s
.58013 .68791 m
.54436 .69155 L
s
.58013 .68791 m
.57815 .68129 L
s
.54303 .68194 m
.54223 .68496 L
s
.54584 .67969 m
.54303 .68194 L
s
.57815 .68129 m
.57558 .67861 L
s
.54897 .67838 m
.54584 .67969 L
s
.57558 .67861 m
.57157 .67705 L
s
.55381 .6769 m
.54897 .67838 L
s
.57157 .67705 m
.56785 .67645 L
s
.5624 .67602 m
.55381 .6769 L
s
.56785 .67645 m
.5624 .67602 L
s
.56206 .66912 m
.53793 .6716 L
s
.55171 .67018 m
.55658 .66869 L
s
.55658 .66869 m
.55944 .66639 L
s
.55944 .66639 m
.56058 .66428 L
s
.56058 .66428 m
.55968 .66136 L
s
.54429 .65791 m
.53877 .65748 L
s
.54776 .65755 m
.54429 .65791 L
s
.55267 .65603 m
.54776 .65755 L
s
.53877 .65748 m
.53467 .65588 L
s
.55554 .6537 m
.55267 .65603 L
s
.53467 .65588 m
.5323 .65409 L
s
.5323 .65409 m
.53135 .65114 L
s
.55668 .65155 m
.55554 .6537 L
s
.55577 .64859 m
.55668 .65155 L
s
.53135 .65114 m
.53245 .64898 L
s
.53245 .64898 m
.53531 .64663 L
s
.55342 .64679 m
.55577 .64859 L
s
.55456 .64461 m
.53007 .64718 L
s
.5493 .64516 m
.55342 .64679 L
s
.55241 .63762 m
.52653 .63619 L
s
.54994 .62955 m
.52653 .63619 L
s
.54994 .62955 m
.52393 .6281 L
s
.54745 .62139 m
.52393 .6281 L
s
.53487 .61636 m
.5292 .6159 L
s
.54377 .61541 m
.53487 .61636 L
s
.5292 .6159 m
.52531 .61525 L
s
.54881 .61381 m
.54377 .61541 L
s
.52531 .61525 m
.52109 .61356 L
s
.55207 .61239 m
.54881 .61381 L
s
.52109 .61356 m
.51864 .61168 L
s
.55502 .60994 m
.55207 .61239 L
s
.51864 .61168 m
.5173 .60753 L
s
.55619 .60766 m
.55502 .60994 L
s
.55494 .60349 m
.55619 .60766 L
s
.5173 .60753 m
.51842 .60525 L
s
.53162 .60599 m
.52998 .60075 L
s
.51842 .60525 m
.52134 .60277 L
s
.55252 .60158 m
.55494 .60349 L
s
.52134 .60277 m
.52459 .60134 L
s
.54829 .59987 m
.55252 .60158 L
s
.52459 .60134 m
.52998 .60075 L
s
.54437 .5992 m
.54829 .59987 L
s
.53883 .59326 m
.51359 .59599 L
s
.528 .59443 m
.53309 .59278 L
s
.53309 .59278 m
.53605 .59027 L
s
.53605 .59027 m
.5372 .58794 L
s
.5372 .58794 m
.53622 .58473 L
s
.52002 .58095 m
.51423 .58047 L
s
.52366 .58055 m
.52002 .58095 L
s
.52878 .57888 m
.52366 .58055 L
s
.51423 .58047 m
.50991 .57871 L
s
.53176 .57632 m
.52878 .57888 L
s
.50991 .57871 m
.50739 .57675 L
s
.50739 .57675 m
.50635 .5735 L
s
.53292 .57395 m
.53176 .57632 L
s
.53192 .57069 m
.53292 .57395 L
s
.50635 .5735 m
.50747 .57112 L
s
.50747 .57112 m
.51043 .56854 L
s
.52942 .56871 m
.53192 .57069 L
s
.53058 .56632 m
.50494 .56914 L
s
.52508 .56693 m
.52942 .56871 L
s
.52823 .55862 m
.48963 .56289 L
s
.5036 .55906 m
.50798 .56086 L
s
.5227 .55923 m
.5257 .55661 L
s
.50105 .55705 m
.5036 .55906 L
s
.49998 .55373 m
.50105 .55705 L
s
.5257 .55661 m
.52687 .55419 L
s
.52687 .55419 m
.52585 .55085 L
s
.50111 .55129 m
.49998 .55373 L
s
.50409 .54865 m
.50111 .55129 L
s
.52585 .55085 m
.52331 .54883 L
s
.52331 .54883 m
.51891 .547 L
s
.5093 .54691 m
.50409 .54865 L
s
.51891 .547 m
.513 .5465 L
s
.513 .5465 m
.5093 .54691 L
s
.53445 .53477 m
.49529 .53915 L
s
.51391 .53707 m
.51846 .53303 L
s
.51846 .53303 m
.51963 .53054 L
s
.51963 .53054 m
.51858 .52711 L
s
.51858 .52711 m
.516 .52502 L
s
.51001 .52451 m
.49125 .52663 L
s
.516 .52502 m
.51001 .52451 L
s
.51469 .5144 m
.48828 .5174 L
s
.52982 .51269 m
.52827 .51406 L
s
.52827 .51406 m
.52603 .51311 L
s
.52603 .51311 m
.52757 .51173 L
s
.52757 .51173 m
.52982 .51269 L
s
.49701 .50795 m
.49096 .50743 L
s
.5008 .50752 m
.49701 .50795 L
s
.50613 .50569 m
.5008 .50752 L
s
.49096 .50743 m
.48642 .50551 L
s
.5092 .50291 m
.50613 .50569 L
s
.48642 .50551 m
.48377 .50337 L
s
.48377 .50337 m
.48263 .49983 L
s
.51038 .50033 m
.5092 .50291 L
s
.50929 .49677 m
.51038 .50033 L
s
.48263 .49983 m
.48377 .49724 L
s
.48377 .49724 m
.48682 .49443 L
s
.50665 .49461 m
.50929 .49677 L
s
.50209 .49267 m
.50665 .49461 L
s
.48032 .4865 m
.48453 .48725 L
s
.47724 .48311 m
.48032 .4865 L
s
.49987 .48548 m
.49566 .48472 L
s
.50334 .48384 m
.49987 .48548 L
s
.49566 .48472 m
.49298 .48253 L
s
.50415 .47999 m
.50334 .48384 L
s
.47608 .47948 m
.47724 .48311 L
s
.49298 .48253 m
.48916 .4767 L
s
.50304 .47635 m
.50415 .47999 L
s
.47683 .47562 m
.47608 .47948 L
s
.48916 .4767 m
.48647 .4745 L
s
.49998 .47292 m
.50304 .47635 L
s
.4803 .47395 m
.47683 .47562 L
s
.48647 .4745 m
.48223 .47373 L
s
.48223 .47373 m
.4803 .47395 L
s
.49574 .47215 m
.49998 .47292 L
s
.47369 .46583 m
.47136 .46483 L
s
.47523 .46438 m
.47369 .46583 L
s
.47136 .46483 m
.4729 .46337 L
s
.4729 .46337 m
.47523 .46438 L
s
.51216 .46005 m
.48493 .46324 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0B03oool50000od@0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0l0?ooo`80
003o0`3oool60000odX0oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`0k0?ooo`030000
o`3oool0oooo0580oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0503o
ool3000003h0oooo00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0
oooo0480oooo0P000?m:0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0>P3oool40000
o`@0oooo00<0003o0?ooo`3oool0B03oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo03P0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04L0
oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo00L0oooo
0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0=`3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0
B03oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo03H0oooo00<0003o0?ooo`3oool0103o
ool40000odP0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo
000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0=P3oool30000odl0oooo1000
001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0Q@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?oo
o`3oool0I`3oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0@P3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3o
ool01@3oool30000och0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo03@0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0i0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0<`3o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo03H0oooo0`00000;0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo03<0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo0380oooo0`000?l30?ooo`<0003o<`3oool300000140oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0=03oool30000oc<0oooo0`00000D0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1^0?ooo`030000003oool0oooo03l0oooo0P000?lU0?ooo`<00000603oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0f0?ooo`D0003o103oool0
0`000?l0oooo0?ooo`0P0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo
02l0oooo1P000?lY0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0F@3oool400000240
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo05D0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`0]0?ooo`X0003o6P3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?ooo`0D
0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?oo
o`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo03H0oooo00<0003o0?oo
o`3oool0403oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3o
ool0=03oool00`000?l0oooo0?ooo`0>0?ooo`<00000<@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0
N03oool00`000000oooo0?ooo`0a0?ooo`T0003o1`3oool3000003@0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3o
ool00`000000oooo0?ooo`0Z0?ooo`P0003o2`3oool3000003L0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0
oooo03T0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0;03oool40000o`040?ooo`000000000000000400oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo02T0oooo0P000?l20?ooo`8000000P000?m20?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0W0?ooo`030000o`3oool0000000800000103oool00`000?l0oooo0?ooo`0o0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003o
ool0oooo02D0oooo00<0003o0000000000001`3oool00`000?l0oooo0?ooo`0o0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`0Q0?ooo`<0000000<0oooo0000o`3oool01@3oool40000od00oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?oo
o`030000003oool0oooo01`0oooo100000030?ooo`P0003o00<0oooo0000o`3oool0@P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0
oooo00<000000?ooo`3oool0603oool3000000<0oooo10000?m=0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`0D0?ooo`<000004P3oool50000od00oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00
000?0?ooo`H0003o0P3oool20000od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000C
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0203oool3000001H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0m0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<000006@3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000007@3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008@3oool60000od80oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0k0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo00<0003o0?oo
o`3oool0>03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02T0oooo00<0003o0?ooo`3o
ool0=03oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0oooo1@000?lb0?ooo`<00000
2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0803oool80000oc80oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`1G0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0903oool30000
o`D0oooo10000?lT0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool010000?l0
oooo0?ooo`000?l90?ooo`030000o`3oool0oooo01d0oooo1000000J0?ooo`030000003oool0oooo
05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0R0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0J0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo
0?ooo`0;0?ooo`030000o`3oool0oooo01L0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0R0?ooo`030000o`3oool0oooo00X0oooo0P000?lF0?ooo`<000009P3oool00`000000oooo0?oo
o`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0S
0?ooo`030000o`3oool0oooo00P0oooo00<0003o0?ooo`3oool04`3oool3000002X0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo02@0oooo2P000?lB0?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo0`000?l<0?ooo`<00000
=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0:03oool40000o``0oooo0`00000j0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0U0?ooo`D0003o2`3oool3000003h0oooo00<000000?ooo`3oool0CP3oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02X0oooo1P000?l00`3oool000000000000200000480oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02T0
oooo10000?l0103oool000000000000000170?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`D0
003o0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<000001P000?m80?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003o
ool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`030000003oool0
oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0N0?ooo`<000001`3oool:0000odX0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0K0?ooo`<000002P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo04P0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000000d0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000@0?ooo`030000o`3oool0oooo00H0oooo
00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo
000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000
000D0?ooo`P0003oCP3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>
0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?oo
o`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000U0?oo
o`030000o`3oool0oooo04X0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000X0?ooo`03
0000o`3oool0oooo04/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000Z0?ooo`030000
o`3oool0oooo04d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000:`3oool50000odl0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000
000Y0?ooo`D0003oE@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`800000T03oool3000003D0oooo10000?m=0?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?oo
o`3oool0;`3oool40000o`@0oooo0`000?m;0?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3o
ool0;03oool30000o`X0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000
003oool0oooo02`0oooo00<0003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`1;0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3o
ool3000000`0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo04/0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0/0?ooo`030000o`3oool0
oooo00D0oooo1`000?m>0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0;P3oool70000
oeD0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`
0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3
000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo
000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B
0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3
000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c
0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3
000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E
0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000
Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3o
ool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo0000
06/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo0017
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80
000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@00000
0`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3o
ool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool01000
0000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000
oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`03
0000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`800000
00<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?oo
o`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00
I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@00000
2@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2
000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo
0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?oo
o`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?oo
o`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00
M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003o
ool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2
000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool0
06P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4
000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool20000
01@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo
00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo
00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<0
00000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a
0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?oo
o`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3o
ool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000
N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03o
ool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool0
0900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo
00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`11
0?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l
0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?oo
o`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D0
0000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000
/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool0
0`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool0
06D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0
oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo
00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3o
ool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool4
00000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.54202 .69195 m
.54242 .68525 L
s
.54202 .69195 m
.50579 .69141 L
s
.50603 .6847 m
.50579 .69141 L
s
.54242 .68525 m
.54085 .68234 L
s
.50787 .68184 m
.50603 .6847 L
s
.54085 .68234 m
.53749 .68035 L
s
.51142 .67996 m
.50787 .68184 L
s
.53749 .68035 m
.53407 .67933 L
s
.51494 .67904 m
.51142 .67996 L
s
.53407 .67933 m
.5289 .67829 L
s
.5202 .67815 m
.51494 .67904 L
s
.5289 .67829 m
.5202 .67815 L
s
.53099 .67149 m
.50652 .67112 L
s
.52051 .67134 m
.5258 .67044 L
s
.5258 .67044 m
.52939 .66853 L
s
.52939 .66853 m
.53124 .66659 L
s
.53124 .66659 m
.5314 .66363 L
s
.52108 .65851 m
.51756 .65846 L
s
.52642 .6576 m
.52108 .65851 L
s
.51756 .65846 m
.51231 .65738 L
s
.53004 .65566 m
.52642 .6576 L
s
.51231 .65738 m
.50886 .65534 L
s
.53191 .65369 m
.53004 .65566 L
s
.50886 .65534 m
.50716 .65331 L
s
.53206 .65068 m
.53191 .65369 L
s
.50716 .65331 m
.50727 .6503 L
s
.5304 .64865 m
.53206 .65068 L
s
.50727 .6503 m
.50912 .64832 L
s
.52695 .64658 m
.5304 .64865 L
s
.50912 .64832 m
.51274 .64636 L
s
.53227 .64666 m
.50742 .64627 L
s
.53264 .63956 m
.50782 .63509 L
s
.53306 .63138 m
.50782 .63509 L
s
.53306 .63138 m
.50811 .62686 L
s
.53349 .62311 m
.50811 .62686 L
s
.532 .61682 m
.52296 .61668 L
s
.53748 .61586 m
.532 .61682 L
s
.52296 .61668 m
.51758 .61555 L
s
.54116 .61487 m
.53748 .61586 L
s
.51758 .61555 m
.514 .61444 L
s
.5449 .61282 m
.54116 .61487 L
s
.514 .61444 m
.51045 .61228 L
s
.54684 .61074 m
.5449 .61282 L
s
.51045 .61228 m
.50872 .61014 L
s
.54709 .60651 m
.54684 .61074 L
s
.50872 .61014 m
.50887 .60591 L
s
.54539 .60436 m
.54709 .60651 L
s
.52343 .60614 m
.52367 .60082 L
s
.50887 .60591 m
.51077 .60381 L
s
.54187 .60217 m
.54539 .60436 L
s
.51077 .60381 m
.5145 .60174 L
s
.53828 .60105 m
.54187 .60217 L
s
.5145 .60174 m
.51819 .60073 L
s
.51819 .60073 m
.52367 .60082 L
s
.53496 .59456 m
.50929 .59415 L
s
.52396 .59439 m
.52951 .5934 L
s
.52951 .5934 m
.53329 .5913 L
s
.53329 .5913 m
.53524 .58916 L
s
.53524 .58916 m
.5354 .58591 L
s
.52459 .58028 m
.5209 .58022 L
s
.53019 .57927 m
.52459 .58028 L
s
.5209 .58022 m
.51539 .57903 L
s
.534 .57714 m
.53019 .57927 L
s
.51539 .57903 m
.51177 .57678 L
s
.53597 .57497 m
.534 .57714 L
s
.51177 .57678 m
.51 .57455 L
s
.53614 .57166 m
.53597 .57497 L
s
.51 .57455 m
.51012 .57123 L
s
.53439 .56941 m
.53614 .57166 L
s
.51012 .57123 m
.51206 .56905 L
s
.53078 .56713 m
.53439 .56941 L
s
.51206 .56905 m
.51587 .56689 L
s
.53637 .56722 m
.51028 .5668 L
s
.53677 .5594 m
.49745 .55876 L
s
.53115 .55931 m
.53501 .55712 L
s
.51251 .55676 m
.51618 .55907 L
s
.53501 .55712 m
.537 .5549 L
s
.51072 .55447 m
.51251 .55676 L
s
.537 .5549 m
.53718 .55151 L
s
.51084 .55108 m
.51072 .55447 L
s
.53718 .55151 m
.53541 .54921 L
s
.51281 .54884 m
.51084 .55108 L
s
.53541 .54921 m
.53175 .54688 L
s
.51667 .54663 m
.51281 .54884 L
s
.53175 .54688 m
.52615 .54564 L
s
.52237 .54558 m
.51667 .54663 L
s
.52615 .54564 m
.52237 .54558 L
s
.55122 .53688 m
.51138 .53622 L
s
.53035 .53653 m
.53622 .53316 L
s
.53622 .53316 m
.53824 .53088 L
s
.53824 .53088 m
.53842 .52739 L
s
.53842 .52739 m
.53663 .52502 L
s
.53663 .52502 m
.53095 .52376 L
s
.53095 .52376 m
.51184 .52344 L
s
.55445 .51473 m
.55246 .51588 L
s
.55246 .51588 m
.55061 .51467 L
s
.5526 .51352 m
.55445 .51473 L
s
.55061 .51467 m
.5526 .51352 L
s
.53908 .51448 m
.51218 .51403 L
s
.52793 .50596 m
.52407 .5059 L
s
.53378 .50487 m
.52793 .50596 L
s
.52407 .5059 m
.51832 .50461 L
s
.53776 .50254 m
.53378 .50487 L
s
.51832 .50461 m
.51454 .50215 L
s
.53982 .50017 m
.53776 .50254 L
s
.51454 .50215 m
.51269 .49971 L
s
.54001 .49655 m
.53982 .50017 L
s
.51269 .49971 m
.51282 .49609 L
s
.53819 .4941 m
.54001 .49655 L
s
.51282 .49609 m
.51485 .49371 L
s
.53442 .49161 m
.53819 .4941 L
s
.51485 .49371 m
.51884 .49135 L
s
.53477 .4843 m
.53092 .48301 L
s
.53874 .48314 m
.53477 .4843 L
s
.51526 .48274 m
.51913 .48403 L
s
.54089 .47949 m
.53874 .48314 L
s
.53092 .48301 m
.52907 .48052 L
s
.51344 .47902 m
.51526 .48274 L
s
.52907 .48052 m
.52738 .47432 L
s
.54108 .47579 m
.54089 .47949 L
s
.51357 .47532 m
.51344 .47902 L
s
.5393 .47204 m
.54108 .47579 L
s
.51567 .47163 m
.51357 .47532 L
s
.52738 .47432 m
.52552 .4718 L
s
.53542 .47073 m
.5393 .47204 L
s
.52552 .4718 m
.52163 .47049 L
s
.51966 .47046 m
.51567 .47163 L
s
.52163 .47049 m
.51966 .47046 L
s
.51604 .46164 m
.51411 .46035 L
s
.51807 .46042 m
.51604 .46164 L
s
.55571 .46107 m
.52798 .46059 L
s
.51614 .45913 m
.51807 .46042 L
s
.51411 .46035 m
.51614 .45913 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1>0?ooo`030000o`3oool0oooo0440oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1=0?ooo`80003o0`3oool;0000oc@0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`0G0?ooo`<00000>`3oool00`000000oooo0?ooo`0H0?ooo`00;03o
ool2000005d0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0D0?ooo`<00000?P3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<000000?ooo`3oool0B@3oool5
0000o`<0oooo0P000?lk0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l0>`3oool00`000000oooo0?ooo`0>
0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`150?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0h0?ooo`03
0000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000
003oool0oooo0680oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`030?ooo`040000
o`3oool0oooo0000oc/0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3o
ool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`150?ooo`030000
o`3oool0oooo00<0oooo0P000?ll0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000
oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo08P0oooo
1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0@`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03T0oooo0`00
001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`050?ooo`80003o=P3oool300000080oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?oo
o`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0a0?oo
o`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`80
0000J@3oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0;P3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0
1@3oool20000obd0oooo0`00000;0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02X0oooo0`00000>0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo03l0oooo1@000?lZ0?ooo`<000004@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?ooo`<00000503o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?ooo`<00000603o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0
oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0i0?ooo`/0003o0`3o
ool30000oaP0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3
000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000Q0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`000000
oooo0?ooo`0f0?ooo`P0003o5`3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo03d0oooo
0P000?lB0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
000X0?ooo`800000MP3oool00`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo00`0oooo0`00
000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`09
0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?oo
o`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0k0?oo
o`030000o`3oool0oooo00L0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo0340oooo3`000?l0103oool0000000000000000d0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0
oooo00<000000?ooo`3oool0?@3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo
0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<0
00000?ooo`3oool0O03oool00`000000oooo0?ooo`0e0?ooo`<00000?@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<00000
0?ooo`3oool0;`3oool60000ocl0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D
0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02`0oooo0P000?l20000
00@0oooo0P000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`03000000000?l0000000P0
oooo00<0003o0?ooo`3oool0>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<0000000<0oooo0000o`3oool0
203oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`8000002000
0?l60?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo10000009
0?ooo`T0003o?P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000005@0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`03
0000003oool0oooo01@0oooo0`00000>0?ooo`D0003oA03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool300000180oooo0P000?l20?ooo`H0003o?P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303o
ool3000001@0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0l0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`080?ooo`<000005`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000K0?ooo`030000o`3oool0oooo
00D0oooo0P000?ln0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000001l0oooo0`000?l20?ooo`80
003o@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08`0oooo0P00000U0?ooo`80003o@P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo02T0oooo00<0003o0?ooo`3oool0>03oool300000080oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
02P0oooo00<0003o0?ooo`3oool0=@3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02H0
oooo0`000?ld0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool:0000oc40oooo
0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`1G0?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool08P3oool30000o`D0oooo00<0003o0?ooo`3oool09`3oool3000001H0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01l0oooo0`000?l20?ooo`030000o`3oool0oooo00@0oooo0P000?lS0?oo
o`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool07@3oool3000001h0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo01l0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0J0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool07`3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3o
ool0oooo01L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo0200oooo0P000?l90?ooo`80003o5`3oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0280oooo2@000?lE0?ooo`@00000;P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0?P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo
0`000?lA0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool50000oa40oooo0`00
000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0O0?ooo`<0003o4`3oool3000003h0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0280oooo1@000?l:0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool09@3oool50000o`@0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0O0?ooo`H0003o
1P3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0280oooo10000?l20?ooo`<00000CP3o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool0
0`000000oooo0?ooo`0U0?ooo`<0000000<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?oo
o`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool3000000P0003oD`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`0000020?ooo`030000o`3oool0oooo00@0oooo
0P000?mC0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@0
00000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo
0`0000040?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<000001`3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?oo
o`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A
0?ooo`@000002`3oool20000o`@0oooo0`000?mF0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00h0oooo0`00000A0?ooo`@0003oFP3oool00`000000oooo0?ooo`150?oo
o`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000
7@3oool00`000?l0oooo0?ooo`1F0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000007`3o
ool20000oeT0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<000006`3oool80000oe`0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000S
0?ooo`D0003oF`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?oo
o`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0R0?ooo`P0
003oF`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo01l0oooo0`000?l80?ooo`030000
o`3oool0oooo05T0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00T0oooo0P000?mJ0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool07`3oool0
0`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo05T0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`00
0000oooo0?ooo`0N0?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0FP3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0
oooo0`00000A0?ooo`030000003oool0oooo01l0oooo3`000?mL0?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo
00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<0
0000KP3oool300000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3o
ool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3
000002/0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo
00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<0
00000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D
0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3o
ool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000
A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0
2`3oool001`0oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3
000004/0oooo00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo
09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo
00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f
0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?oo
o`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000
I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3o
ool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0
oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo
0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo
00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H
0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?oo
o`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000
Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`00
0000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000
U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
1`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool0
0`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool0
00T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0
oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0
oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool20000
00@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000
oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo
0P00002<0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`060?ooo`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<0
00000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`080?ooo`80000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?oo
o`2h0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003o
ool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2
000000@0oooo0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo
0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
00D0oooo000^0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000
oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo
0`00001l0?ooo`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?oo
o`030000003oool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`800000
00<0oooo0000003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<00000
0?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?oo
o`030000003oool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?oo
o`030000003oool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0
oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo
00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo
00130?ooo`800000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?oo
o`030000003oool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?oo
o`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo
00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo
001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?oo
o`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?oo
o`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
@`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3o
ool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000
003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0040oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0
oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool30000
0140oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`00
0000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0
oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`010?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo
0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000
003oool0oooo000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
f03oool00`000000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<0
00000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<00000
0?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3o
ool0f@3oool300000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool0
0`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo
0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0
oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo
1000000K0?ooo`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`
0?ooo`030000003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?oo
o`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3o
ool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0
=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003o
ool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0
oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo
09d0oooo1000000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo0000
00l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000
oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool40000
04/0oooo001X0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`00
0000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000
oooo0?ooo`270?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000
001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000
001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U
0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`800000
0`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3o
ool010000000oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03o
ool3000001l0oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000
oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo
0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00
002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F
0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`04
0000003oool0oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`03
0000003oool000000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000
303oool200000140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903o
ool010000000oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
<03oool400000:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303o
ool2000000h0oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0
oooo0280oooo0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool5
00000;@0oooo001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool20000
00/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo0000
02<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0
oooo0`0000000`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool06P3oool400000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo
0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00
003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?oo
o`050000003oool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo
000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool20000
0=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0
oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.50336 .69153 m
.50611 .68501 L
s
.50336 .69153 m
.46795 .68682 L
s
.47056 .68026 m
.46795 .68682 L
s
.50611 .68501 m
.5056 .68198 L
s
.5056 .68198 m
.50301 .67964 L
s
.47338 .67767 m
.47056 .68026 L
s
.50301 .67964 m
.50001 .67825 L
s
.50001 .67825 m
.49531 .67662 L
s
.47754 .67623 m
.47338 .67767 L
s
.49531 .67662 m
.48681 .67548 L
s
.48132 .67574 m
.47754 .67623 L
s
.48681 .67548 m
.48132 .67574 L
s
.49975 .67021 m
.47584 .66698 L
s
.48952 .66883 m
.49503 .66856 L
s
.49503 .66856 m
.49923 .66711 L
s
.49923 .66711 m
.50173 .66543 L
s
.50173 .66543 m
.50292 .66255 L
s
.4946 .65632 m
.49116 .65586 L
s
.50016 .65605 m
.4946 .65632 L
s
.5044 .65458 m
.50016 .65605 L
s
.49116 .65586 m
.48638 .65418 L
s
.50692 .65287 m
.5044 .65458 L
s
.48638 .65418 m
.48371 .65176 L
s
.50814 .64994 m
.50692 .65287 L
s
.48371 .65176 m
.48276 .64958 L
s
.50722 .64775 m
.50814 .64994 L
s
.48276 .64958 m
.48393 .64664 L
s
.50457 .64531 m
.50722 .64775 L
s
.48393 .64664 m
.48644 .64491 L
s
.50976 .64603 m
.48549 .6427 L
s
.48644 .64491 m
.4907 .64342 L
s
.51261 .63912 m
.48984 .63178 L
s
.51591 .63116 m
.48984 .63178 L
s
.51591 .63116 m
.49303 .62374 L
s
.51923 .62311 m
.49303 .62374 L
s
.51999 .61678 m
.51119 .61555 L
s
.52569 .6165 m
.51999 .61678 L
s
.52964 .61597 m
.52569 .6165 L
s
.53401 .61442 m
.52964 .61597 L
s
.51119 .61555 m
.50631 .61379 L
s
.53663 .61263 m
.53401 .61442 L
s
.50631 .61379 m
.50319 .61228 L
s
.53836 .60852 m
.53663 .61263 L
s
.50319 .61228 m
.50048 .60973 L
s
.50048 .60973 m
.49952 .60743 L
s
.53746 .60621 m
.53836 .60852 L
s
.49952 .60743 m
.50117 .6033 L
s
.53479 .60365 m
.53746 .60621 L
s
.51536 .60529 m
.51747 .60011 L
s
.53168 .60211 m
.53479 .60365 L
s
.50117 .6033 m
.50377 .60147 L
s
.50377 .60147 m
.50816 .5999 L
s
.51214 .59936 m
.51747 .60011 L
s
.50816 .5999 m
.51214 .59936 L
s
.53071 .59537 m
.50573 .59183 L
s
.52002 .59385 m
.5258 .59356 L
s
.5258 .59356 m
.53023 .59197 L
s
.53023 .59197 m
.53288 .59012 L
s
.53288 .59012 m
.53419 .58696 L
s
.5256 .58013 m
.522 .57961 L
s
.53143 .57983 m
.5256 .58013 L
s
.5359 .57821 m
.53143 .57983 L
s
.522 .57961 m
.51703 .57777 L
s
.53859 .57633 m
.5359 .57821 L
s
.51703 .57777 m
.51428 .57512 L
s
.53992 .57312 m
.53859 .57633 L
s
.51428 .57512 m
.51333 .57272 L
s
.539 .57071 m
.53992 .57312 L
s
.51333 .57272 m
.51461 .56949 L
s
.53627 .56803 m
.539 .57071 L
s
.51461 .56949 m
.51728 .56759 L
s
.5417 .56881 m
.51633 .56516 L
s
.51728 .56759 m
.52178 .56595 L
s
.54484 .56123 m
.50658 .5557 L
s
.53939 .56044 m
.54392 .55878 L
s
.54392 .55878 m
.54664 .55686 L
s
.52206 .55562 m
.52483 .55833 L
s
.54664 .55686 m
.548 .55357 L
s
.52111 .55316 m
.52206 .55562 L
s
.548 .55357 m
.54709 .5511 L
s
.52242 .54985 m
.52111 .55316 L
s
.54709 .5511 m
.54434 .54836 L
s
.52513 .54791 m
.52242 .54985 L
s
.54434 .54836 m
.5393 .54646 L
s
.52969 .54623 m
.52513 .54791 L
s
.5393 .54646 m
.53563 .54592 L
s
.53563 .54592 m
.52969 .54623 L
s
.56681 .54105 m
.52818 .53538 L
s
.54661 .53809 m
.55351 .53553 L
s
.55351 .53553 m
.55628 .53356 L
s
.55628 .53356 m
.55768 .53018 L
s
.55768 .53018 m
.55677 .52764 L
s
.55677 .52764 m
.55168 .52569 L
s
.55168 .52569 m
.53312 .52295 L
s
.57771 .51987 m
.57538 .52074 L
s
.57538 .52074 m
.574 .51932 L
s
.57634 .51845 m
.57771 .51987 L
s
.574 .51932 m
.57634 .51845 L
s
.56286 .51766 m
.53676 .51379 L
s
.55497 .50793 m
.55123 .50737 L
s
.56106 .50761 m
.55497 .50793 L
s
.56576 .50585 m
.56106 .50761 L
s
.55123 .50737 m
.54607 .50537 L
s
.56859 .5038 m
.56576 .50585 L
s
.54607 .50537 m
.54325 .50248 L
s
.57004 .5003 m
.56859 .5038 L
s
.54325 .50248 m
.5423 .49986 L
s
.56913 .49768 m
.57004 .5003 L
s
.5423 .49986 m
.5437 .49635 L
s
.56633 .49476 m
.56913 .49768 L
s
.5437 .49635 m
.54652 .49428 L
s
.54652 .49428 m
.55124 .49249 L
s
.56924 .48768 m
.56594 .48592 L
s
.57351 .48706 m
.56924 .48768 L
s
.57687 .48378 m
.57351 .48706 L
s
.56594 .48592 m
.56501 .48325 L
s
.55077 .48362 m
.55409 .48539 L
s
.57835 .4802 m
.57687 .48378 L
s
.5503 .47975 m
.55077 .48362 L
s
.56501 .48325 m
.56554 .47698 L
s
.57794 .47632 m
.57835 .4802 L
s
.55173 .47616 m
.5503 .47975 L
s
.56554 .47698 m
.56461 .47429 L
s
.57463 .47454 m
.57794 .47632 L
s
.55508 .47284 m
.55173 .47616 L
s
.56461 .47429 m
.56128 .4725 L
s
.55938 .47221 m
.55508 .47284 L
s
.56128 .4725 m
.55938 .47221 L
s
.59771 .46778 m
.57094 .46368 L
s
.55894 .46313 m
.55751 .46162 L
s
.56135 .46221 m
.55894 .46313 L
s
.55992 .46069 m
.56135 .46221 L
s
.55751 .46162 m
.55992 .46069 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0G@3oool20000oc80oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1L0?ooo`03
0000o`3oool0oooo0080oooo0`000?l]0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
H`3oool50000obP0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo06L0oooo0`000?lU0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`1H0?ooo`<0003o<`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool0
0`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo
05H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3oool0oooo02`0oooo00<00000
0?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?oo
o`3oool0H03oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo0080oooo00D0003o0?oo
o`3oool0oooo0000o`0]0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0D`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:P3oool00`00
0000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1R0?ooo`030000003oool0oooo0580oooo00<0003o0?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0003o02d0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`1B0?ooo`03
0000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o;P3oool010000000oooo0?ooo`3oool3
00000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool00`00
0000oooo0?ooo`1G0?ooo`<0003o;P3oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0
oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`250?ooo`<00000F03oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo04d0oooo
0P000?lb0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo02L0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo04X0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0S0?ooo`<00000203oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0B@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0200oooo0`00000;0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`070?ooo`03
0000o`3oool0oooo01d0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo04P0oooo0`000?l30?ooo`<0003o7@3oool300000140oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`03
0000003oool0oooo06d0oooo00<000000?ooo`3oool0BP3oool30000oad0oooo0`00000D0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06H0oooo0`00000H0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool0
00001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0480oooo1@000?lK0?ooo`<0
00006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`800000
1P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo04H0oooo1P000?l40?ooo`030000
o`3oool0oooo00/0oooo0`00000N0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`1>0?ooo`80003o2@3o
ool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool0
0`000000oooo0?ooo`1b0?ooo`030000003oool0oooo03h0oooo10000?lC0?ooo`<000009@3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool00000
07@0oooo00<000000?ooo`3oool0@@3oool40000o``0oooo0`00000X0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo04@0
oooo00<0003o0?ooo`3oool01P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo
0?ooo`140?ooo`030000o`3oool0oooo0080oooo0`00000^0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0480oooo00<0003o0?ooo`3oool00`00000a0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool0
0`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03L0oooo10000?l50?ooo`040000o`000000
0000000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0j0?ooo`L0003o=P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0>@3oool3000000@0oooo10000?lb0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0e0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool00`000000003o
0000o`040000oc`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3o
ool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000000`000?l0oooo0?oo
o`040?ooo`80003o>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool300000080oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000040000
o`80oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0g0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`0Q0?ooo`<000001`3oool70000o`<0oooo0P000?li0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo
0?ooo`0L0?ooo`@000004@3oool40000oc/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000403oool50000od80oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0100oooo0`00000C0?ooo`80003o0`3oool60000oc`0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00`0oooo0`00000E0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3o
ool0>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001P0oooo00<0003o0?ooo`3oool0
1`3oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000703o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00<00000803oool80000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`800000J@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`80
0000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000
003oool0oooo02P0oooo00<0003o0?ooo`3oool0>@3oool300000080oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003o
ool0oooo02P0oooo00<0003o0?ooo`3oool0=@3oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01d0oooo1@000?l30?ooo`<0003o=@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
0280oooo1P000?lb0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0E`3oool300000180
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01d0oooo1P000?la0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0703oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0P00
0?lW0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool08@3oool3000001h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`0M0?oo
o`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool06`3oool20000o``0oooo00<0003o0?ooo`3o
ool06`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool2000008l0oooo00<000000?ooo`3oool07@3oool20000o`T0oooo0P000?lJ0?ooo`<00000
:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool07`3oool90000oaP0oooo1000000^0?ooo`030000003o
ool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool50000
oaL0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0J0?ooo`D0003o6@3oool3000003X0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo01`0oooo0P000?lG0?ooo`<00000?P3oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool07P3oool30000oa00oooo100000120?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0I
0?ooo`X0003o2`3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01/0oooo10000?l<0?oo
o`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool07`3oool30000o`H0oooo0`00001>0?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000
003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
403oool00240oooo0P00002@0?ooo`030000003oool0oooo01L0oooo1@000?l50?ooo`@00000EP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool05P3oool30000o`<0oooo0P000?l3000005/0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0F0?ooo`030000o`3oool0oooo0080oooo0`0000000`3o
ool0003o0?ooo`1K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01H0oooo00<0003o0?ooo`0000000P0000040?ooo`030000o`3oool0oooo05/0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000000H0oooo0P000?mN0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000000<0oooo1P000?mQ0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool3000000l0oooo00<0003o0?ooo`3oool0H03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0203oool300000180oooo00<0003o0?ooo`3oool0H@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0103oool4000000/0oooo1@000?l20?ooo`<0003oI@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00000D0?ooo`D0003oIP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000F0?ooo`P0003oJ03o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08`0oooo0`0000020?ooo`030000003oool0oooo0180oooo0P000?l80?ooo`030000o`3oool0
oooo06H0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`00
0000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`0A0?ooo`030000o`3oool0oooo
00T0oooo0P000?mW0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0
oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0403oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo06H0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`0@0?ooo`@0003o2`3oool00`000?l0oooo0?ooo`1V0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0503oool70000o`<0oooo00<0003o0?ooo`3oool0J03oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo01`0oooo10000?mZ0?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?oo
o`3oool0R`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<00000
6`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool3
00000240oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0
oooo00`0oooo000N0?ooo`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000
oooo0?ooo`1V0?ooo`<00000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo
00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo
000M0?ooo`030000003oool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<0
00000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N
0?ooo`<00000<@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?oo
o`3oool0T`3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05L0oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3o
ool0=P3oool00`000000oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000
>`3oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool0
2`3oool001`0oooo00<000000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3o
ool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04h0oooo100000110?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`00
0000oooo0?ooo`2G0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0
oooo0P0000190?ooo`<00000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo
00<000000?ooo`3oool0V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o
0?ooo`@00000D@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03T0oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000
F`3oool00`000000oooo0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3o
ool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo02l0oooo1000001Q0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`00
0000oooo0?ooo`2O0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo
0`00001Z0?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo
0?ooo`090?ooo`006P3oool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P
0?ooo`@00000L03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?oo
o`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo01X0oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000
NP3oool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0
2@3oool001T0oooo00<000000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0
oooo0140oooo100000200?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`00
0000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo
0`00002:0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo
0?ooo`080?ooo`00603oool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?oo
o`2[0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<00000
0?ooo`3oool00P3oool400000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0
oooo0P00002G0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`070?ooo`001`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo
0?ooo`2^0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
T`3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00
000@0?ooo`800000S`3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01`3oool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?oo
o`030000003oool0oooo0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?oo
o`004`3oool500000080oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80
000000<0oooo0000003oool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo
0P00000@0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<0
00000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^
0?ooo`800000P03oool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool01@3oool00300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?oo
o`00<`3oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0
_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003o
ool0oooo07L0oooo00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00@0oooo000g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000
003oool0L`3oool00`000000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool0103oool003X0oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo00@0oooo000n0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[
0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`04
0?ooo`00@@3oool010000000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`80
0000J`3oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool00`3oool004D0oooo0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003o
ool0oooo0<T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool0
0`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`030?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`80
0000H`3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00P3oool004`0oooo0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003o
ool0oooo0<h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2
000005h0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0080oooo00140?ooo`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool01000
0000oooo0?ooo`00000;0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo
00X0oooo0P00001J0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`020?ooo`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040
oooo00140?ooo`030000003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool00@3oool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C
0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`01
0?ooo`00F`3oool200000580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0
000000<0oooo001M0?ooo`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo
000000<0oooo001O0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`00
0000oooo000000030?ooo`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0
f@3oool00`000000oooo000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo0=X0oooo0P0000020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool3
00000080oooo001V0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`00
0000oooo0?ooo`3E0?ooo`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo
0?ooo`3<0?ooo`D000003@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000
000B0?ooo`00K03oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F
0?ooo`00K@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?oo
o`00KP3oool2000003l0oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000
003oool0000003`0oooo00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03o
ool00`000000oooo0?ooo`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`2]0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`2Z0?ooo`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0
oooo1000000e0?ooo`00M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo
1@00000i0?ooo`00J@3oool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000
000n0?ooo`00J03oool010000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool0V03oool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00
000a0?ooo`030000003oool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00
000A0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X
0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?oo
o`2;0?ooo`D00000C`3oool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`27
0?ooo`@00000E03oool00840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?oo
o`D00000F03oool00880oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00
Q03oool010000000oooo0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00
Q@3oool00`000000oooo0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3o
ool2000002H0oooo00<000000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000
oooo0?ooo`00000O0?ooo`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0
oooo00<000000?ooo`3oool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool0F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0E`3oool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B
0?ooo`D00000R03oool00980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?oo
o`@00000S@3oool009<0oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00
U@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3o
ool2000001H0oooo00<000000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool0
00000180oooo00<000000?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool20000
0140oooo00<000000?ooo`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000
oooo0?ooo`00000=0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool40000
0:`0oooo001V0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0
oooo00<000000?ooo`3oool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo
0P00000A0?ooo`030000003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo
001V0?ooo`030000003oool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<0
00000?ooo`3oool08`3oool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00
000B0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`000000
0`3oool000000000000i0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool4
00000<80oooo002T0?ooo`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?oo
o`@00000aP3oool00:H0oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00
Y`3oool2000000@0oooo00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003o
ool0oooo0?ooo`0000002P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo
1000003H0?ooo`00Z`3oool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oo
oi40oooo003o0?oooi40oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O
0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.46551 .68666 m
.47052 .68058 L
s
.46551 .68666 m
.43218 .67792 L
s
.47052 .68058 m
.4711 .67754 L
s
.43709 .67177 m
.43218 .67792 L
s
.4711 .67754 m
.46936 .67494 L
s
.46936 .67494 m
.4669 .67322 L
s
.4669 .67322 m
.46284 .67107 L
s
.44081 .66954 m
.43709 .67177 L
s
.46284 .67107 m
.45486 .66896 L
s
.44543 .66861 m
.44081 .66954 L
s
.45486 .66896 m
.44935 .66858 L
s
.44935 .66858 m
.44543 .66861 L
s
.46949 .66529 m
.44703 .65932 L
s
.46542 .66313 m
.47007 .66219 L
s
.45989 .66274 m
.46542 .66313 L
s
.47007 .66219 m
.47313 .66083 L
s
.47313 .66083 m
.47532 .65814 L
s
.4749 .65144 m
.46933 .65105 L
s
.47959 .6505 m
.4749 .65144 L
s
.46933 .65105 m
.4661 .65018 L
s
.48268 .64912 m
.47959 .6505 L
s
.4661 .65018 m
.46198 .64797 L
s
.48491 .64639 m
.48268 .64912 L
s
.46198 .64797 m
.4602 .64528 L
s
.48478 .64413 m
.48491 .64639 L
s
.4602 .64528 m
.46004 .64302 L
s
.48303 .64142 m
.48478 .64413 L
s
.46004 .64302 m
.46223 .64027 L
s
.48788 .64274 m
.46517 .63659 L
s
.46223 .64027 m
.46532 .63887 L
s
.46532 .63887 m
.47005 .63791 L
s
.49313 .6363 m
.47331 .62638 L
s
.49917 .62889 m
.4793 .61887 L
s
.49917 .62889 m
.47331 .62638 L
s
.50527 .62141 m
.4793 .61887 L
s
.51393 .61571 m
.50824 .6153 L
s
.51798 .61567 m
.51393 .61571 L
s
.5228 .61468 m
.51798 .61567 L
s
.50824 .6153 m
.50004 .61303 L
s
.526 .61324 m
.5228 .61468 L
s
.52913 .60943 m
.526 .61324 L
s
.50004 .61303 m
.49587 .61072 L
s
.49587 .61072 m
.49334 .60885 L
s
.52907 .60706 m
.52913 .60943 L
s
.49334 .60885 m
.49157 .60603 L
s
.52735 .60423 m
.52907 .60706 L
s
.49157 .60603 m
.49145 .60365 L
s
.52485 .60235 m
.52735 .60423 L
s
.49145 .60365 m
.49452 .5998 L
s
.50776 .60348 m
.51165 .59866 L
s
.49452 .5998 m
.49772 .59833 L
s
.50668 .59728 m
.51165 .59866 L
s
.49772 .59833 m
.50259 .59732 L
s
.50259 .59732 m
.50668 .59728 L
s
.52628 .59563 m
.50305 .58912 L
s
.52211 .59327 m
.527 .59225 L
s
.51635 .59285 m
.52211 .59327 L
s
.527 .59225 m
.53025 .59077 L
s
.53025 .59077 m
.53263 .58784 L
s
.53244 .58053 m
.52664 .5801 L
s
.53738 .5795 m
.53244 .58053 L
s
.52664 .5801 m
.5233 .57916 L
s
.54066 .57799 m
.53738 .5795 L
s
.5233 .57916 m
.51908 .57674 L
s
.54309 .57502 m
.54066 .57799 L
s
.51908 .57674 m
.51732 .57381 L
s
.54304 .57255 m
.54309 .57502 L
s
.51732 .57381 m
.51724 .57134 L
s
.54132 .5696 m
.54304 .57255 L
s
.51724 .57134 m
.51963 .56834 L
s
.54634 .57103 m
.52284 .56432 L
s
.51963 .56834 m
.52291 .56681 L
s
.52291 .56681 m
.52789 .56576 L
s
.55206 .56401 m
.51662 .55384 L
s
.54702 .56256 m
.55203 .56151 L
s
.55203 .56151 m
.55535 .55997 L
s
.55535 .55997 m
.55783 .55693 L
s
.5318 .55569 m
.53355 .5587 L
s
.55783 .55693 m
.55781 .55441 L
s
.53173 .55317 m
.5318 .55569 L
s
.55781 .55441 m
.55609 .55139 L
s
.53418 .5501 m
.53173 .55317 L
s
.55609 .55139 m
.55185 .5489 L
s
.53751 .54854 m
.53418 .5501 L
s
.55185 .5489 m
.54846 .54792 L
s
.54255 .54747 m
.53751 .54854 L
s
.54846 .54792 m
.54255 .54747 L
s
.58051 .54707 m
.54488 .53669 L
s
.5619 .54165 m
.56951 .54003 L
s
.56951 .54003 m
.5729 .53845 L
s
.5729 .53845 m
.57544 .53533 L
s
.57544 .53533 m
.57544 .53274 L
s
.57544 .53274 m
.57118 .5302 L
s
.57118 .5302 m
.55408 .52517 L
s
.59848 .52782 m
.59591 .52837 L
s
.59591 .52837 m
.59508 .52682 L
s
.59764 .52627 m
.59848 .52782 L
s
.59508 .52682 m
.59764 .52627 L
s
.58485 .52379 m
.56084 .5167 L
s
.58662 .51377 m
.5806 .51331 L
s
.59179 .51266 m
.58662 .51377 L
s
.5806 .51331 m
.57716 .51229 L
s
.59525 .51103 m
.59179 .51266 L
s
.57716 .51229 m
.57285 .50968 L
s
.59788 .50781 m
.59525 .51103 L
s
.57285 .50968 m
.57112 .5065 L
s
.59791 .50514 m
.59788 .50781 L
s
.57112 .5065 m
.57111 .50383 L
s
.59622 .50194 m
.59791 .50514 L
s
.57111 .50383 m
.5737 .50058 L
s
.5737 .50058 m
.57717 .49893 L
s
.57717 .49893 m
.58238 .49779 L
s
.60151 .49542 m
.59893 .49329 L
s
.60586 .49538 m
.60151 .49542 L
s
.61026 .49262 m
.60586 .49538 L
s
.59893 .49329 m
.59897 .49057 L
s
.61294 .48933 m
.61026 .49262 L
s
.58503 .48909 m
.58763 .49124 L
s
.59897 .49057 m
.60167 .48454 L
s
.6139 .4855 m
.61294 .48933 L
s
.58592 .48526 m
.58503 .48909 L
s
.61132 .48334 m
.6139 .4855 L
s
.58857 .48195 m
.58592 .48526 L
s
.60167 .48454 m
.60171 .4818 L
s
.59298 .47915 m
.58857 .48195 L
s
.60171 .4818 m
.59911 .47963 L
s
.63595 .47977 m
.61154 .47231 L
s
.59911 .47963 m
.59736 .4791 L
s
.59736 .4791 m
.59298 .47915 L
s
.60012 .47021 m
.59926 .46855 L
s
.60277 .46963 m
.60012 .47021 L
s
.60191 .46797 m
.60277 .46963 L
s
.59926 .46855 m
.60191 .46797 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1Y0?ooo`<0003o8`3o
ool00`000000oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2
000005l0oooo00<000000?ooo`3oool0K@3oool20000oal0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`1^0?ooo`<0003o703oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0700
oooo0`000?lI0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0H`3oool30000o``0oooo
0P000?lG0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0H03oool20000o`<0oooo00D0
003o0?ooo`3oool0oooo0000o`0P0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0GP3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool07@3o
ool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<0
00000?ooo`3oool0I03oool00`000000oooo0?ooo`1M0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0N0?ooo`@00000E@3oool00`000000oooo0?oo
o`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo05d0oooo00D0003o
0?ooo`3oool0oooo0000o`040?ooo`030000o`3oool0oooo01`0oooo0`00001H0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0H03oool0
1@000?l0oooo0?ooo`3oool0003o01`0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1P
0?ooo`<0003o6P3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool2000006T0oooo00<000000?ooo`3oool0E`3oool30000ob00oooo0`0000080?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3o
ool0J@3oool00`000000oooo0?ooo`1E0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool05P3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
8@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1C0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool04P3oool3000000h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000
003oool0oooo06/0oooo00<000000?ooo`3oool0DP3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00l0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000
003oool0oooo0540oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0=0?ooo`<00000
503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1A0?ooo`80003o
1@3oool20000o``0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000
003oool0oooo0580oooo1@000?l;0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo04X0oooo0`000?lA0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0C03oool4
0000o`T0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
02T0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1?0?ooo`<0003o0`3oool30000
02D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000
oooo0000001d0?ooo`030000003oool0oooo04@0oooo0P000?l;0?ooo`<0000000<0oooo0000o`3o
ool09@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000
MP3oool00`000000oooo0?ooo`150?ooo`@0003o103oool3000000<0oooo0P000?lV0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0B03oool20000o`800000;P3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<0000000<0oooo0000o`3oool0;P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool00000
0240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0m0?ooo`80003o0P3oool30000
00@0oooo00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03d0
oooo00@000000000o`000?l0003o0`3oool40000obl0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0
oooo0`0000040?ooo`@0003o<P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0
oooo000W0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000000/0oooo
0`000?l_0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<00000103oool30000o`X0oooo0P00
0?l]0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<00000103oool30000o`<0oooo0P000?lg
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<000001P3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000<0oooo0`000?l30?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool0
8@3oool3000000T0oooo1@000?l80?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003o
ool0oooo01`0oooo1000000@0?ooo`D0003o0`3oool00`000?l0oooo0?ooo`0e0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool0
0`000000oooo0?ooo`0H0?ooo`<000006@3oool30000ocP0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo
01@0oooo0`00000C0?ooo`<0003o@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001D0
oooo00@0003o0?ooo`3oool0oooo10000?lm0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<0
00005`3oool00`000?l0oooo0?ooo`060?ooo`<0003o>P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
203oool3000001X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0j0?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`040?ooo`<000007@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo03X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008@3oool30000o`<0oooo0P000?lm
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0S03oool2000002L0oooo0`000?lo0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
9`3oool00`000?l0oooo0?ooo`0j0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0703o
ool30000o`P0oooo00<0003o0?ooo`3oool0=P3oool4000000H0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01l0oooo20000?lf0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool30000
oc@0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0J0?ooo`L0003o=P3oool300000180
oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0b0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0603oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo0P000?lY0?ooo`@000006P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo02@0oooo0`00000N
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?oo
o`3oool08@3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01X0oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0?ooo`0O0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0K0?ooo`80003o
1`3oool20000oah0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0
4@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0M0?ooo`L0003o703o
ool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01D0oooo1@000?lT0?ooo`<00000<`3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool05P3oool20000o`80oooo1@000?lL0?ooo`<00000=P3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0603oool20000oah0oooo0`00000j0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0B0?ooo`D0003o0`3oool20000oaT0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0D0?ooo`80003o00<0oooo0000o`000?l010000?lD0?ooo`@00000@P3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool05P3oool30000oaD0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0I0?oo
o`80003o403oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00l0oooo0`000?lF0?ooo`<0
0000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000
SP3oool00`000000oooo0?ooo`0>0?ooo`040000o`3oool0oooo0?ooo`D0003o3P3oool300000580
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo
00<000000?ooo`3oool03@3oool00`000?l0oooo0?ooo`060?ooo`<0003o203oool4000005H0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`040?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H
0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`<00000GP3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0?0?ooo`L0003o0P3oool300000680oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`090?ooo`80003o0`3oool300000080oooo00<0003o0?ooo`3oool0
JP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`0000050000ofd0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00P0oooo0`0000040?ooo`<0003oK`3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool400000080003oN03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`0000020?oo
o`80003o0P3oool50000og@0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo100000040?ooo`030000o`3oool0oooo00L0oooo0P000?mc0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000
1P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo0700oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`030?ooo`80003o3@3oool00`000?l0oooo0?ooo`1`0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4
000000D0oooo00<000000?ooo`3oool01@3oool40000o`P0oooo00<0003o0?ooo`3oool0LP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo
08D0oooo0`0000090?ooo`030000003oool0oooo00T0oooo10000?l30?ooo`030000o`3oool0oooo
07@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0=0?ooo`<0003oN03oool00`000000
oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo
0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<00000
0?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`0m
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?oo
o`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0
oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0>P3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<00000:03oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo0640oooo
0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0oooo0`00000h0?oo
o`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0;0?oo
o`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo0?ooo`2E0?ooo`03
0000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo100000110?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0
oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<00000B03oool00`00
0000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0V@3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0480oooo
0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0oooo0`00001H0?oo
o`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo0?ooo`2M0?ooo`03
0000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0:P3oool30000
06L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000003oool0oooo0:80
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3oool2000002D0oooo
0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool00`000000oooo0?oo
o`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0oooo0`00001g0?oo
o`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`090?oo
o`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo0?ooo`2V0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
5@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo100000200?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool02`3oool30000
08L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000003oool0oooo0:X0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool400000900oooo00<0
00000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`001`3oool500000080
oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo0?ooo`2_0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool000T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00002B0?ooo`03
0000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0303oool00`000000
oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3oool00`000000oooo
0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3oool00280oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo0;@0oooo00<00000
0?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080oooo0P0000090?oo
o`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0]@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003oool0Q03oool00`00
0000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool000d0
oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?oo
o`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000003oool0oooo0840
oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0
oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool00`000000oooo0?oo
o`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool00300oooo00@00000
0?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo0;d0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000oooo0?ooo`1j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0
_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g0?ooo`030000003o
ool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`000000oooo0?ooo`31
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0oooo0P00001d0?oo
o`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?oo
o`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0
``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n0?ooo`800000L03o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0103o
ool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0oooo0<D0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool010000000oooo0?ooo`00
001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo0P00001Y0?ooo`03
0000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`030?ooo`00
A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`00B@3oool2
000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo0P00001R0?ooo`03
0000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`00
CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<000000?ooo`3oool0c`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?ooo`8000002`3oool0
10000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?ooo`030000003oool0
oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`00?@3oool40000
00<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0dP3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000003oool0oooo00l0
oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3oool005T0oooo00@0
00000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool200000580oooo00<00000
0?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?ooo`800000D03oool0
0`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?ooo`030000003oool0
oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?ooo`00H03oool20000
00030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?oo
o`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo000000020?ooo`00
H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P0000020?ooo`00I03o
ool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?ooo`@000001@3oool0
06L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0d@3oool40000
00T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D000003@3oool006X0oooo
0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0oooo00<000000?oo
o`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo00<000000?ooo`3o
ool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?ooo`2b0?ooo`@00000
:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]0?ooo`D00000;03o
ool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?ooo`@00000<@3oool0
07D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00M`3oool00`000000
oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3oool2000000d0oooo
0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool010000000oooo0?oo
o`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03oool500000480oooo
001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003oool0oooo09@0oooo
100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003oool0oooo02h0oooo
00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0oooo00000180oooo
00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3oool006T0oooo0P00
000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool00840oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880oooo0P00000Z0?oo
o`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo0?ooo`00000V0?oo
o`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo0000000V0?ooo`03
0000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<000000?ooo`3oool0
L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0K@3o
ool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?ooo`030000003oool0
oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3oool0G`3oool50000
07/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0F`3oool400000800
oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3oool4000008@0oooo
002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool00980oooo00<00000
0?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0oooo0P00000I0?oo
o`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<000000?ooo`3oool0
@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<000000?ooo`3oool0
?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<000000?ooo`3oool0>03o
ool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?ooo`3oool0=03oool5
00000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3oool0;03oool40000
0;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000003oool0000000/0
oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003oool0000002<0oooo
00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3oool400000;T0oooo
001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3oool00`000000oooo
0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?ooo`80000000<0oooo
0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0oooo0P0000050?oo
o`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo00<000000?ooo`3o
ool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`0000002P3oool500000=<0
oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3oool300000080oooo
1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42982 .67748 m
.43695 .67207 L
s
.42982 .67748 m
.39983 .66495 L
s
.43695 .67207 m
.4386 .66914 L
s
.4386 .66914 m
.4378 .66639 L
s
.4378 .66639 m
.43597 .6644 L
s
.40691 .65946 m
.39983 .66495 L
s
.43597 .6644 m
.43272 .66181 L
s
.43272 .66181 m
.42555 .65879 L
s
.4114 .6577 m
.40691 .65946 L
s
.42555 .65879 m
.42022 .65776 L
s
.42022 .65776 m
.41632 .65733 L
s
.41632 .65733 m
.4114 .6577 L
s
.44135 .6569 m
.42121 .64835 L
s
.43809 .65429 m
.44303 .65392 L
s
.43275 .65325 m
.43809 .65429 L
s
.44303 .65392 m
.44653 .65294 L
s
.44653 .65294 m
.44965 .65056 L
s
.45161 .64392 m
.44624 .64287 L
s
.45658 .64354 m
.45161 .64392 L
s
.46012 .64255 m
.45658 .64354 L
s
.44624 .64287 m
.44336 .64163 L
s
.46328 .64014 m
.46012 .64255 L
s
.44336 .64163 m
.44006 .63896 L
s
.46396 .6379 m
.46328 .64014 L
s
.44006 .63896 m
.43925 .6361 L
s
.46319 .63503 m
.46396 .6379 L
s
.46751 .6369 m
.44725 .62814 L
s
.43925 .6361 m
.4399 .63385 L
s
.4399 .63385 m
.44304 .63141 L
s
.44304 .63141 m
.4466 .6304 L
s
.47495 .63121 m
.45892 .61908 L
s
.4466 .6304 m
.45161 .63002 L
s
.48352 .62466 m
.46749 .61243 L
s
.48352 .62466 m
.45892 .61908 L
s
.49216 .61805 m
.46749 .61243 L
s
.50666 .61396 m
.50268 .61351 L
s
.51174 .61358 m
.50666 .61396 L
s
.51538 .61255 m
.51174 .61358 L
s
.50268 .61351 m
.49724 .61242 L
s
.51979 .6092 m
.51538 .61255 L
s
.49724 .61242 m
.48998 .60921 L
s
.48998 .60921 m
.4867 .60643 L
s
.52055 .60688 m
.51979 .6092 L
s
.51988 .6039 m
.52055 .60688 L
s
.4867 .60643 m
.48487 .60429 L
s
.48487 .60429 m
.48412 .60131 L
s
.51809 .60176 m
.51988 .6039 L
s
.48412 .60131 m
.48484 .59896 L
s
.50093 .60078 m
.50644 .59654 L
s
.48484 .59896 m
.48923 .59556 L
s
.50206 .59457 m
.50644 .59654 L
s
.48923 .59556 m
.49289 .59451 L
s
.52185 .59536 m
.50137 .58613 L
s
.49803 .59411 m
.50206 .59457 L
s
.49289 .59451 m
.49803 .59411 L
s
.5186 .59253 m
.52374 .59214 L
s
.5131 .59142 m
.5186 .59253 L
s
.52374 .59214 m
.52744 .59108 L
s
.52744 .59108 m
.53081 .58851 L
s
.53319 .58134 m
.52767 .58021 L
s
.53838 .58094 m
.53319 .58134 L
s
.54211 .57987 m
.53838 .58094 L
s
.52767 .58021 m
.52473 .57887 L
s
.54552 .57726 m
.54211 .57987 L
s
.52473 .57887 m
.52145 .57599 L
s
.54634 .57485 m
.54552 .57726 L
s
.52145 .57599 m
.52076 .5729 L
s
.54569 .57175 m
.54634 .57485 L
s
.55008 .57377 m
.5295 .5643 L
s
.52076 .5729 m
.52155 .57047 L
s
.52155 .57047 m
.52495 .56783 L
s
.52495 .56783 m
.5287 .56675 L
s
.55812 .56762 m
.52711 .55327 L
s
.5287 .56675 m
.53393 .56634 L
s
.55372 .56559 m
.55897 .56518 L
s
.55897 .56518 m
.56274 .56409 L
s
.56274 .56409 m
.56622 .56143 L
s
.56622 .56143 m
.56708 .55897 L
s
.54128 .55699 m
.54194 .56014 L
s
.56708 .55897 m
.56647 .55582 L
s
.54211 .55451 m
.54128 .55699 L
s
.56647 .55582 m
.56321 .55285 L
s
.59168 .55464 m
.56071 .54007 L
s
.54557 .55182 m
.54211 .55451 L
s
.56321 .55285 m
.56026 .55147 L
s
.54937 .55072 m
.54557 .55182 L
s
.56026 .55147 m
.55466 .5503 L
s
.55466 .5503 m
.54937 .55072 L
s
.57553 .54704 m
.58348 .54641 L
s
.58348 .54641 m
.58732 .5453 L
s
.58732 .5453 m
.59088 .54258 L
s
.59088 .54258 m
.59178 .54006 L
s
.59178 .54006 m
.58854 .53705 L
s
.61578 .53817 m
.61311 .53838 L
s
.61311 .53838 m
.61285 .53677 L
s
.61552 .53655 m
.61578 .53817 L
s
.58854 .53705 m
.57369 .53 L
s
.61285 .53677 m
.61552 .53655 L
s
.60401 .53254 m
.58323 .52259 L
s
.60922 .52302 m
.60356 .52181 L
s
.61461 .52259 m
.60922 .52302 L
s
.61852 .52145 m
.61461 .52259 L
s
.60356 .52181 m
.60059 .52037 L
s
.62218 .51865 m
.61852 .52145 L
s
.60059 .52037 m
.59732 .51729 L
s
.62314 .51606 m
.62218 .51865 L
s
.59732 .51729 m
.59676 .51398 L
s
.62262 .51274 m
.62314 .51606 L
s
.59676 .51398 m
.59768 .51137 L
s
.59768 .51137 m
.60133 .50854 L
s
.60133 .50854 m
.60526 .50738 L
s
.6342 .5076 m
.62999 .50709 L
s
.6394 .50548 m
.6342 .5076 L
s
.60526 .50738 m
.6107 .50694 L
s
.62999 .50709 m
.62825 .50468 L
s
.64312 .50264 m
.6394 .50548 L
s
.62825 .50468 m
.62923 .50205 L
s
.64537 .49905 m
.64312 .50264 L
s
.62923 .50205 m
.63393 .49655 L
s
.61629 .49883 m
.61806 .50125 L
s
.64364 .49662 m
.64537 .49905 L
s
.61849 .49522 m
.61629 .49883 L
s
.63393 .49655 m
.63493 .49389 L
s
.66853 .49632 m
.64769 .48595 L
s
.6222 .49234 m
.61849 .49522 L
s
.63493 .49389 m
.63318 .49145 L
s
.62743 .49019 m
.6222 .49234 L
s
.63318 .49145 m
.63168 .49071 L
s
.63168 .49071 m
.62743 .49019 L
s
.63742 .48245 m
.63717 .48072 L
s
.64018 .48222 m
.63742 .48245 L
s
.63993 .4805 m
.64018 .48222 L
s
.63717 .48072 m
.63993 .4805 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`1c0?ooo`<0003o5@3oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000oooo
0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo07<0oooo0P00
0?lE0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0oooo01P0oooo000[
0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0M@3oool00`000?l0oooo0?ooo`0A
0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool0
0`000000oooo0?ooo`1T0?ooo`030000003oool0oooo07D0oooo0P000?lA0?ooo`@00000E@3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
06`0oooo0`000?l70?ooo`80003o3@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`1Y0?ooo`80003o0`3oool00`000?l0
oooo0?ooo`060?ooo`80003o203oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo06L0oooo
00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo0P000?l30?ooo`<0
00001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000
J@3oool00`000000oooo0?ooo`1V0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`060?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0I@3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0103o
ool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2
000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0
oooo00<0oooo00@0003o0?ooo`3oool0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo05l0oooo0`000?l60?ooo`D0003o00@0oooo0000000000000000
4@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1L0?ooo`80003o
303oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803o
ool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0
FP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00<00000603oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0000000000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo
000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05P0oooo00<0
003o0?ooo`3oool00`3oool3000000030000o`3oool0oooo01/0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo05P0oooo00<0003o0000000000000P0000030?ooo`030000o`3oool0oooo01/0oooo00<00000
0?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?oo
o`030000003oool0oooo0500oooo00<0003o0?ooo`3oool00P3oool3000000L0003o7P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0
oooo00<000000?ooo`3oool0D03oool20000o`800000:03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=0?ooo`<00000
00<0oooo0000o`000?l0:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04T0oooo00<0
00000000o`000?l01P3oool20000obH0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<00000
0?ooo`3oool0A@3oool3000000<0oooo0P000?l60?ooo`80003o903oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000203oool20000o`P0oooo0P000?lP0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`03
0000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000000d0oooo00<0003o0?ooo`3o
ool01P3oool20000oal0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo0`0000050?ooo`80003o
2@3oool20000obP0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000:0?ooo`80003o1P3o
ool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?ooo`<000003`3oool6
0000ob/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`00000:0?ooo`<0003o1`3oool30000
ob`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000040?ooo`030000o`3oool0oooo00@0
oooo0P000?l30?ooo`<0003o1`3oool20000obX0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000000P0oooo
0P000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool20000obP0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`210?ooo`030000003oool0oooo0240oooo0`00000=0?ooo`80003o00<0oooo0000o`3oool01`3o
ool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000004P3oool2
0000o`P0oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool30000
01P0oooo0P000?l50?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0
oooo0`00000E0?ooo`<0003o1@3oool50000ocD0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo
0`00000G0?ooo`030000o`3oool0oooo0080003o1P3oool20000ocH0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo00`0oooo0`00000H0?ooo`80003o1@3oool30000oc/0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo00P0oooo0`00000K0?ooo`030000o`3oool0oooo00L0oooo0P000?li0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`00
0000oooo0?ooo`040?ooo`<000007P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo
03T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool30000o`@0oooo00<0003o0?ooo`3o
ool0>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000
003oool0oooo08`0oooo0P00000X0?ooo`@0003o?@3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo0?ooo`1W0?ooo`800000F`3o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo01`0oooo0P000?m60?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool07P3oool20000
o`L0oooo00<0003o0?ooo`3oool0=P3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0200
oooo1`000?lf0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05`3oool60000o`D0oooo
0P000?lf0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05P3oool00`000?l0oooo0?oo
o`040?ooo`80003o>03oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01D0oooo00<0003o
0?ooo`3oool0103oool20000ocH0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0F0?oo
o`030000o`3oool0oooo00T0oooo0P000?l/0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool05P3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02L0oooo0`00000N0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0G0?ooo`80003o2P3oool00`000?l0oooo0?ooo`0T0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0280oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3o
ool002<0oooo0P00002?0?ooo`030000003oool0oooo00l0oooo0`000?l80?ooo`P0003o8P3oool3
000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo0100oooo1P000?lZ0?ooo`@00000;P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool03@3oool30000o`<0oooo00@0003o0?ooo`3oool0oooo0`000?lT0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0000o`050000obD0
oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo0080oooo
0`000?lQ0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool02@3oool00`000?l0oooo0?oo
o`040?ooo`80003o8`3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00P0oooo10000?l6
0?ooo`030000o`3oool0oooo01`0oooo100000120?ooo`030000003oool0oooo04d0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`070?oo
o`030000o`3oool0oooo0080oooo0P000?l50?ooo`030000o`3oool0oooo01P0oooo0`0000170?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo0P000?lK0?ooo`<0
0000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80003o
5`3oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool3000008h0oooo00<000000?ooo`3oool01`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo01<0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00240oooo0P00002@0?ooo`030000003oool0oooo00P0oooo1`000?lB0?ooo`@00000EP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool010000000
oooo0000o`000?lJ0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool01000
0000oooo0?ooo`3oool20000o`L0oooo00<0003o0?ooo`3oool02`3oool300000680oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool00`3oool70000o`/0oooo0`00001V0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`03
0000003oool0oooo08d0oooo1@000?l50?ooo`80003o2P3oool4000006X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08`0oooo00@0003o0?ooo`3oool000000P3oool20000o``0oooo0`00001_0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000
003oool0oooo08/0oooo0P000?l30?ooo`030000003oool0oooo0080oooo0P000?l70?ooo`<00000
LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo08X0oooo0P000?l40?ooo`030000003oool0oooo00@0oooo00@0003o0?ooo`3oool0oooo
0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<0
00000?ooo`3oool0S03oool20000o`80oooo00<000000?ooo`3oool0103oool4000007X0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2>
0?ooo`80003o00@000000?ooo`3oool0oooo0`0000000`3oool0003o0?ooo`1l0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`040000o`000000
0000000000@0oooo00<0003o0?ooo`3oool0O03oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`800000T03oool3000000030?ooo`000?l0003o0080oooo0P000?mo
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0S03oool300000080oooo00@000000?ooo`3oool0oooo0P000?n20?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool40000
00D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?oo
o`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3o
ool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303o
ool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool40000
02@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo
00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900
oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<00000
0?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?oo
o`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3o
ool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000
003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0
=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0
oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<0
00000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?oo
o`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3o
ool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3o
ool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000
oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<0
00000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?oo
o`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3o
ool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3o
ool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000
oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo
00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00
002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?oo
o`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo
0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0
803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0
/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`06
0?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?oo
o`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3o
ool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`03
0000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0
oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0
oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo
0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<0
00000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l
0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`05
0?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000
NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool0
0`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool0
03P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3o
ool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000
L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0
oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@00
0000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<00000
0?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?oo
o`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0
b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003o
ool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000
003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0
c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003o
ool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo
000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo
00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo
00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00
001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?oo
o`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo
0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`00
0000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003o
ool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000
B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool0
0`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080
oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo
0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<0
00000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<00000
0?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?oo
o`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@0
00007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D00000
8`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`00
0000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0
oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo
00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<0
00000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@00000
0?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X
0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000
000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]
0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3o
ool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3o
ool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0
M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3o
ool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool0
08T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool50000
0780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool40000
07L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L
0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?oo
o`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3o
ool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3o
ool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3o
ool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool0
08`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0
oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo
00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo
0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?oo
o`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@00000
0?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00
002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?oo
o`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3o
ool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000
c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@0
00000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]
0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@00
00020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y
0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.39764 .66423 m
.40665 .65974 L
s
.39764 .66423 m
.37217 .64829 L
s
.40665 .65974 m
.40933 .65705 L
s
.40933 .65705 m
.40952 .65423 L
s
.40952 .65423 m
.40842 .65206 L
s
.40842 .65206 m
.4061 .64911 L
s
.4061 .64911 m
.40004 .64527 L
s
.38121 .64371 m
.37217 .64829 L
s
.41643 .6453 m
.39944 .63445 L
s
.40004 .64527 m
.3951 .64362 L
s
.38632 .64251 m
.38121 .64371 L
s
.3951 .64362 m
.39136 .64273 L
s
.39136 .64273 m
.38632 .64251 L
s
.41915 .64256 m
.42298 .64201 L
s
.41412 .64233 m
.41915 .64256 L
s
.40918 .64067 m
.41412 .64233 L
s
.42298 .64201 m
.42693 .64003 L
s
.43629 .63395 m
.43123 .63372 L
s
.44014 .6334 m
.43629 .63395 L
s
.43123 .63372 m
.42628 .63205 L
s
.44413 .6314 m
.44014 .6334 L
s
.42628 .63205 m
.42385 .63048 L
s
.44559 .62928 m
.44413 .6314 L
s
.42385 .63048 m
.42153 .62745 L
s
.44585 .62637 m
.44559 .62928 L
s
.44946 .62873 m
.43252 .61766 L
s
.42153 .62745 m
.42175 .62453 L
s
.42175 .62453 m
.42318 .6224 L
s
.45883 .62403 m
.44729 .61016 L
s
.42318 .6224 m
.42718 .62037 L
s
.42718 .62037 m
.43106 .61981 L
s
.43106 .61981 m
.43617 .62004 L
s
.46961 .61862 m
.45812 .60466 L
s
.46961 .61862 m
.44729 .61016 L
s
.48046 .61318 m
.45812 .60466 L
s
.50128 .61116 m
.49616 .61092 L
s
.50521 .61059 m
.50128 .61116 L
s
.49616 .61092 m
.4924 .61 L
s
.51071 .60785 m
.50521 .61059 L
s
.4924 .61 m
.48744 .60827 L
s
.48744 .60827 m
.48143 .60423 L
s
.51228 .60567 m
.51071 .60785 L
s
.51267 .60267 m
.51228 .60567 L
s
.48143 .60423 m
.47918 .60111 L
s
.51167 .60035 m
.51267 .60267 L
s
.47918 .60111 m
.47814 .59879 L
s
.47814 .59879 m
.47846 .59576 L
s
.49518 .59731 m
.50209 .59382 L
s
.47846 .59576 m
.48 .59355 L
s
.51761 .59454 m
.50078 .583 L
s
.49848 .59136 m
.50209 .59382 L
s
.48 .59355 m
.48551 .59075 L
s
.5206 .59163 m
.52458 .59105 L
s
.51542 .59138 m
.5206 .59163 L
s
.51043 .58962 m
.51542 .59138 L
s
.49468 .59041 m
.49848 .59136 L
s
.52458 .59105 m
.52878 .58894 L
s
.48551 .59075 m
.48949 .59017 L
s
.48949 .59017 m
.49468 .59041 L
s
.53884 .58247 m
.53363 .58222 L
s
.54285 .58188 m
.53884 .58247 L
s
.53363 .58222 m
.52863 .58043 L
s
.5471 .57975 m
.54285 .58188 L
s
.52863 .58043 m
.52624 .57877 L
s
.54875 .57749 m
.5471 .57975 L
s
.52624 .57877 m
.52404 .57554 L
s
.5492 .57439 m
.54875 .57749 L
s
.55278 .5769 m
.53601 .56511 L
s
.52404 .57554 m
.52445 .57243 L
s
.52445 .57243 m
.52607 .57016 L
s
.56276 .5719 m
.53756 .55403 L
s
.52607 .57016 m
.53033 .568 L
s
.56443 .56962 m
.56849 .56902 L
s
.55919 .56937 m
.56443 .56962 L
s
.56849 .56902 m
.5728 .56686 L
s
.53033 .568 m
.53437 .5674 L
s
.53437 .5674 m
.53963 .56765 L
s
.5728 .56686 m
.57449 .56457 L
s
.57449 .56457 m
.575 .56142 L
s
.59986 .5634 m
.57493 .54535 L
s
.55009 .55943 m
.54962 .56259 L
s
.575 .56142 m
.57288 .55813 L
s
.55176 .55712 m
.55009 .55943 L
s
.57288 .55813 m
.57049 .55641 L
s
.55608 .55492 m
.55176 .55712 L
s
.57049 .55641 m
.56546 .55457 L
s
.56017 .55432 m
.55608 .55492 L
s
.56546 .55457 m
.56017 .55432 L
s
.5948 .55437 m
.5989 .55377 L
s
.58687 .55399 m
.5948 .55437 L
s
.5989 .55377 m
.60329 .55157 L
s
.60329 .55157 m
.60504 .54923 L
s
.62887 .55038 m
.62623 .55025 L
s
.62918 .54878 m
.62887 .55038 L
s
.62623 .55025 m
.62653 .54865 L
s
.60504 .54923 m
.60296 .54589 L
s
.62653 .54865 m
.62918 .54878 L
s
.60296 .54589 m
.59104 .53717 L
s
.61948 .54344 m
.60286 .53117 L
s
.63316 .53511 m
.62782 .53485 L
s
.63732 .53449 m
.63316 .53511 L
s
.62782 .53485 m
.62278 .53296 L
s
.64182 .53224 m
.63732 .53449 L
s
.62278 .53296 m
.62041 .5312 L
s
.64364 .52985 m
.64182 .53224 L
s
.62041 .5312 m
.61834 .52779 L
s
.64429 .52657 m
.64364 .52985 L
s
.61834 .52779 m
.61895 .5245 L
s
.61895 .5245 m
.62075 .52209 L
s
.65721 .52304 m
.65335 .52202 L
s
.66293 .52165 m
.65721 .52304 L
s
.62075 .52209 m
.62525 .5198 L
s
.65335 .52202 m
.65251 .51947 L
s
.66748 .51936 m
.66293 .52165 L
s
.62525 .5198 m
.62945 .51917 L
s
.65251 .51947 m
.65436 .51704 L
s
.62945 .51917 m
.63483 .51944 L
s
.67088 .51617 m
.66748 .51936 L
s
.65436 .51704 m
.66078 .51231 L
s
.69398 .51647 m
.67764 .5038 L
s
.67007 .51361 m
.67088 .51617 L
s
.64304 .51227 m
.6439 .51485 L
s
.66078 .51231 m
.66266 .50986 L
s
.64641 .50906 m
.64304 .51227 L
s
.66266 .50986 m
.66183 .50727 L
s
.65098 .50674 m
.64641 .50906 L
s
.66183 .50727 m
.66064 .50637 L
s
.65675 .50532 m
.65098 .50674 L
s
.66064 .50637 m
.65675 .50532 L
s
.6721 .49753 m
.67174 .49923 L
s
.67174 .49923 m
.66902 .4991 L
s
.66902 .4991 m
.66938 .4974 L
s
.66938 .4974 m
.6721 .49753 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1i0?ooo`<0003o00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`00
0000oooo0?ooo`1b0?ooo`<000001P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`1[0?ooo`030000003oool0oooo06h0oooo0P0000050000o`H0oooo00<0003o0?oo
o`3oool0103oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<000000P000?l40?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?ooo`<000000P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00L0oooo0P000?l40?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`00
0000oooo0?ooo`1_0?ooo`030000003oool0oooo0680oooo0`0000050?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo
0?ooo`000000F03oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?oo
o`3oool0L03oool00`000000oooo0?ooo`1N0?ooo`<00000303oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00H0oooo00@0003o0?ooo`3oool00000F03oool00`000000oooo0?ooo`0F
0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo100000040?oo
o`D0003o1@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00X0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo05D0oooo0`0000060?ooo`80003o2`3oool50000o`d0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000
003oool0oooo0540oooo0`0000090?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
4`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3o
ool00`000000oooo0?ooo`1=0?ooo`<000002`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3o
ool0oooo01<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool4
00000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`190?ooo`<000002@3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool04`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool00000
0200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<000003@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo0P000?lF0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo0440oooo0`00000:0?ooo`030000o`3oool0oooo00@0
oooo00<0003o0?ooo`3oool00`3oool50000oaP0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`0m0?ooo`<000003P3oool00`000?l0oooo0?ooo`040?ooo`80003o803oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0>@3oool300000180oooo0P000?l60?ooo`030000o`3oool0oooo01d0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l
0?ooo`030000003oool0oooo03D0oooo0`00000=0?ooo`030000o`3oool0oooo00L0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0a0?oo
o`<000004@3oool20000o`P0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0;@3oool3000001H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`<0
003o6P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000001X0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000;0?ooo`030000o`3o
ool0oooo00@0oooo1@000?l70?ooo`H0003o9@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3
000000l0oooo0P000?l30?ooo`030000o`3oool0oooo00<0oooo0P000?l70?ooo`030000o`3oool0
oooo02H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`00
0000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000D0?ooo`<0003o203oool00`00
0?l0oooo0?ooo`050?ooo`80003o9`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000001X0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02@0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000H0?ooo`030000o`3oool0oooo00<0oooo
0P000?l60?ooo`030000o`3oool0oooo02h0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00
000I0?ooo`D0003o1@3oool20000o`80oooo0P000?la0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<
0?ooo`<000006P3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool30000oc<0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000L0?ooo`030000o`3oool0oooo00H0oooo0P000?li0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<000007`3oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0003o03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008`3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009`3oool70000oc/0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0703oool00`000?l0oooo0?ooo`180?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01d0oooo0P000?m50?oo
o`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool05P3oool40000o`D0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`0g0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
503oool20000o`@0oooo0P000?l40?ooo`H0003o=`3oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo01<0oooo00<0003o0?ooo`3oool01@3oool20000o`D0oooo00<0003o0?ooo`3oool0=@3o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool2
0000oc`0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0D0?ooo`030000o`3oool0oooo
00T0oooo00<0003o0?ooo`3oool0<@3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01@0
oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0]0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0303oool20000o`L0oooo0P000?l90?ooo`030000o`3oool0oooo02X0oooo
0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0=0?ooo`<0003o1`3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo02P0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`08
0?ooo`80003o103oool00`000?l0oooo0000o`020000o`D0oooo1`000?lX0?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`090?ooo`<0003o0P3oool00`000?l0oooo0?ooo`020?ooo`80003o;`3oool30000
02X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0000o`030000oc00oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool010000000oooo0?ooo`3oool40000o`H0
oooo00<0003o0?ooo`3oool00P3oool20000ob`0oooo0`00000c0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool010000000oooo
0?ooo`000?l40?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0;03oool3000003H0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0003o00H0oooo0P000?l50?ooo`030000o`3oool0oooo02P0oooo
0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0SP3oool00`000000oooo0000o`080?ooo`030000o`3oool0oooo02X0oooo0`00
000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool010000000oooo0?ooo`000?l70?ooo`80003o9`3oool400000480oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`040000003oool0oooo0?ooo`<0003o0P3oool20000obH0oooo0`0000170?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0R03oool0
0`000?l0oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P000?lU0?ooo`<00000BP3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08T0oooo0P000?l30?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002;0?ooo`040000o`3oool0oooo0000
00<0oooo00<0003o0?ooo`3oool08@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0@0?ooo`008@3oool2000008<0oooo1P000?l50?ooo`H0003o803oool4000005H0
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo
0?ooo`200?ooo`80003o1P3oool20000o`D0oooo00<0003o0?ooo`3oool07P3oool3000005/0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<0
00000?ooo`3oool0O`3oool00`000?l0oooo0?ooo`080?ooo`80003o0`3oool00`000000oooo0?oo
o`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0P03oool20000o`X0oooo00@0
003o0?ooo`3oool000006P3oool300000680oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0880oooo00<0
003o0?ooo`3oool0203oool00`000?l0oooo0000000G0?ooo`<00000IP3oool00`000000oooo0?oo
o`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`23
0?ooo`80003o1`3oool010000?l0oooo0?ooo`00000C0?ooo`@00000JP3oool00`000000oooo0?oo
o`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0Q@3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000000403o
ool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3
000000D0oooo00<000000?ooo`3oool0Q`3oool20000o`030?ooo`000?l0003o00@0oooo00<00000
0?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?
0?ooo`00803oool00`000000oooo0?ooo`290?ooo`030000o`3oool0oooo00@0oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]],

Cell["\<\
In the following the text is first rotated to be along the y-axis and then \
tilted to be vertical.\
\>", "Text"],

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Theta]frame[\[Pi]/2, \[Pi]/2]\)[\[Theta]], {\[Theta], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[TextData[{
  "In the following the text is only tilted to ",
  Cell[BoxData[
      \(45  \[Degree]\)]],
  " from the vertical."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(\[Theta]frame[\[Pi]/4, \[Pi]/2]\)[\[Theta]], {\[Theta], 0, 
        2  \[Pi] - del, del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.62234 .66768 m
.6205 .66817 L
s
.62264 .66547 m
.62234 .66768 L
s
.62079 .66596 m
.62264 .66547 L
s
.6205 .66817 m
.62079 .66596 L
s
.6001 .69385 m
.61514 .67492 L
s
.61317 .66263 m
.61454 .65906 L
s
.61209 .66398 m
.61317 .66263 L
s
.60915 .66583 m
.61209 .66398 L
s
.61454 .65906 m
.61326 .65509 L
s
.60649 .66546 m
.60915 .66583 L
s
.60455 .67347 m
.6016 .67532 L
s
.6016 .67532 m
.59813 .6741 L
s
.61326 .65509 m
.6109 .65248 L
s
.60145 .66248 m
.60649 .66546 L
s
.59813 .6741 m
.59574 .67151 L
s
.6109 .65248 m
.60744 .65121 L
s
.59877 .6621 m
.60145 .66248 L
s
.59574 .67151 m
.59443 .66755 L
s
.60744 .65121 m
.60448 .65306 L
s
.5958 .66395 m
.59877 .6621 L
s
.59443 .66755 m
.5958 .66395 L
s
.60028 .64329 m
.5997 .64779 L
s
.59977 .64015 m
.60028 .64329 L
s
.59098 .65872 m
.58719 .6597 L
s
.59736 .63749 m
.59977 .64015 L
s
.58719 .6597 m
.58447 .65932 L
s
.58447 .65932 m
.58204 .65668 L
s
.59465 .63708 m
.59736 .63749 L
s
.59085 .63803 m
.59465 .63708 L
s
.58204 .65668 m
.5815 .65354 L
s
.58675 .64126 m
.59085 .63803 L
s
.5815 .65354 m
.58207 .64902 L
s
.58455 .64401 m
.58675 .64126 L
s
.58207 .64902 m
.58455 .64401 L
s
.57221 .64604 m
.58765 .62674 L
s
.5653 .6566 m
.56336 .65709 L
s
.56557 .65433 m
.5653 .6566 L
s
.56364 .65482 m
.56557 .65433 L
s
.56336 .65709 m
.56364 .65482 L
s
.57002 .63332 m
.5811 .61949 L
s
.56586 .63658 m
.57002 .63332 L
s
.56308 .63616 m
.56586 .63658 L
s
.56057 .63344 m
.56308 .63616 L
s
.56001 .63023 m
.56057 .63344 L
s
.56084 .62332 m
.56001 .63023 L
s
.54853 .63866 m
.572 .60942 L
s
.55858 .61038 m
.56111 .60527 L
s
.55634 .61318 m
.55858 .61038 L
s
.56111 .60527 m
.56167 .60062 L
s
.55212 .61645 m
.55634 .61318 L
s
.56167 .60062 m
.5611 .59735 L
s
.54817 .6174 m
.55212 .61645 L
s
.5611 .59735 m
.55856 .59454 L
s
.54534 .61695 m
.54817 .6174 L
s
.54277 .61417 m
.54534 .61695 L
s
.55856 .59454 m
.55574 .59406 L
s
.55574 .59406 m
.55178 .59499 L
s
.53933 .61045 m
.56306 .58097 L
s
.54218 .61091 m
.54277 .61417 L
s
.54273 .60623 m
.54218 .61091 L
s
.53327 .60389 m
.54918 .58416 L
s
.54633 .58366 m
.54578 .58838 L
s
.54574 .58035 m
.54633 .58366 L
s
.53669 .59966 m
.53267 .6006 L
s
.54315 .57748 m
.54574 .58035 L
s
.53267 .6006 m
.52979 .60012 L
s
.52979 .60012 m
.52717 .59729 L
s
.54028 .57698 m
.54315 .57748 L
s
.53625 .57789 m
.54028 .57698 L
s
.52717 .59729 m
.52656 .59397 L
s
.53195 .58118 m
.53625 .57789 L
s
.52656 .59397 m
.5271 .58923 L
s
.52966 .58402 m
.53195 .58118 L
s
.5271 .58923 m
.52966 .58402 L
s
.5157 .58487 m
.51836 .58775 L
s
.51507 .58152 m
.5157 .58487 L
s
.5156 .57673 m
.51507 .58152 L
s
.51124 .58005 m
.52742 .56006 L
s
.51818 .57147 m
.5156 .57673 L
s
.51631 .56133 m
.51283 .56562 L
s
.51773 .55748 m
.51631 .56133 L
s
.51827 .55265 m
.51773 .55748 L
s
.50834 .56071 m
.51283 .56562 L
s
.51764 .54924 m
.51827 .55265 L
s
.50353 .57709 m
.5003 .57899 L
s
.5003 .57899 m
.49616 .57992 L
s
.51406 .54527 m
.51764 .54924 L
s
.49616 .57992 m
.49318 .57941 L
s
.51109 .54471 m
.51406 .54527 L
s
.49318 .57941 m
.48952 .5755 L
s
.50695 .5456 m
.51109 .54471 L
s
.48952 .5755 m
.48886 .57209 L
s
.5037 .54748 m
.50695 .5456 L
s
.49928 .55081 m
.5037 .54748 L
s
.48886 .57209 m
.48937 .56723 L
s
.49341 .55803 m
.49928 .55081 L
s
.48937 .56723 m
.4908 .56335 L
s
.4908 .56335 m
.49341 .55803 L
s
.48672 .5535 m
.49954 .5292 L
s
.4793 .54547 m
.49954 .5292 L
s
.4793 .54547 m
.49218 .52105 L
s
.47182 .53737 m
.49218 .52105 L
s
.46521 .53021 m
.48194 .50972 L
s
.47887 .50911 m
.47836 .51411 L
s
.47819 .50556 m
.47887 .50911 L
s
.4688 .52582 m
.46451 .52669 L
s
.47536 .50243 m
.47819 .50556 L
s
.46451 .52669 m
.4614 .5261 L
s
.4614 .5261 m
.45854 .523 L
s
.47227 .50181 m
.47536 .50243 L
s
.46796 .50265 m
.47227 .50181 L
s
.45854 .523 m
.45783 .51945 L
s
.4634 .50602 m
.46796 .50265 L
s
.45783 .51945 m
.45833 .51443 L
s
.46099 .50896 m
.4634 .50602 L
s
.45833 .51443 m
.46099 .50896 L
s
.44601 .50944 m
.44892 .51259 L
s
.44528 .50585 m
.44601 .50944 L
s
.44577 .50077 m
.44528 .50585 L
s
.44114 .50417 m
.45817 .48341 L
s
.44845 .49526 m
.44577 .50077 L
s
.44161 .48779 m
.4443 .48225 L
s
.43549 .49524 m
.44161 .48779 L
s
.4443 .48225 m
.44577 .4782 L
s
.44577 .4782 m
.44626 .47306 L
s
.43083 .49865 m
.43549 .49524 L
s
.44626 .47306 m
.44455 .46832 L
s
.42739 .50057 m
.43083 .49865 L
s
.42294 .50142 m
.42739 .50057 L
s
.44455 .46832 m
.43764 .46068 L
s
.41872 .49971 m
.42294 .50142 L
s
.41168 .49219 m
.41872 .49971 L
s
.41168 .49219 m
.43764 .46068 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0<03oool00`000?l0oooo0?ooo`1N0?ooo`030000003oool0oooo01h0oooo0`00000d0?oo
o`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool0;P3oool00`000?l0oooo0000o`1P0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
;03oool01@000?l0oooo0?ooo`3oool0003o05l0oooo00<000000?ooo`3oool05`3oool3000003/0
oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo02X0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1L0?ooo`030000003oool0oooo01@0oooo
0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?oo
o`0Y0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?oo
o`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N
0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1L
0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?oo
o`030000003oool0oooo0600oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`050?oo
o`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0S0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?ooo`070?ooo`<0
0000B`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000
003oool0oooo0240oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo05L0oooo00<000000?ooo`3oool0103oool3000004h0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0H`3oool00`000000oooo0?ooo`0O0?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1H0?ooo`040000003o
ool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo01h0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?oo
o`3oool0003o05/0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`070?ooo`050000o`3o
ool0oooo0?ooo`000?l0FP3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo00L0oooo00D0
003o0?ooo`3oool0oooo0000o`1H0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool06P3o
ool20000o`H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1C0?ooo`<000001@3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool0
0`000000oooo0?ooo`0L0?ooo`040000o`3oool0oooo0?ooo`80003o103oool00`000?l0oooo0?oo
o`1A0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0703oool30000o`D0oooo0P000?l9
0?ooo`80003oA@3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0R0?oo
o`030000o`3oool0003o00L0oooo0P000?l00`3oool0003o0?ooo`110?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0l0?ooo`<000004@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000o`0i0?ooo`<00000503oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0R0?ooo`050000o`3oool0oooo
0?ooo`000?l01P3oool20000ocL0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0c
0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?oo
o`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo02@0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0a0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3o
ool08`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool09`3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`030?ooo`80003o9P3oool3000002D0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003o
ool0oooo0280oooo00@0003o0?ooo`3oool0003o1@3oool20000ob@0oooo0`00000X0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003o
ool0oooo0280oooo0P000?l40?ooo`80003o00<0oooo0000o`3oool00P3oool00`000?l0oooo0?oo
o`0K0?ooo`<00000:`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0004
0?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0240oooo00<0003o
0?ooo`3oool00P3oool010000?l0oooo0?ooo`000?l30?ooo`030000o`3oool0oooo01T0oooo0`00
000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo00<00000
0?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo02@0oooo00D0003o
0?ooo`3oool0oooo0000o`020?ooo`80003o603oool300000340oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0
oooo07P0oooo00<000000?ooo`3oool08P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0
003o0000oaH0oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool09@3oool0
1@000?l0oooo0000o`3oool0003o01<0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0T
0?ooo`80003o00<0oooo0000o`3oool0403oool3000003X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo
0280oooo0P000?l20?ooo`030000o`3oool0oooo00@0oooo0`000?l50?ooo`<00000?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool08@3oool010000?l0oooo0?ooo`000?l50?ooo`80003o0P3oool00`00
0?l0oooo0?ooo`0300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`020?ooo`03000000000?l0000004<0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0240oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`03000000030?oo
o`000?l0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool300000840oooo00<000000?ooo`3oool0803oool01@000?l0oooo0?ooo`3oool0003o00<00000
103oool00`000?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`0300000000
0?l0000000L0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4
000000030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?oo
o`0o0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000103oool00`000?l0oooo0?ooo`04
0?ooo`80003o103oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?oo
o`<000001P3oool00`000?l0oooo0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0@`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo
08H0oooo00<000000?ooo`3oool0403oool3000000T0oooo00<0003o0?ooo`3oool02@3oool00`00
0?l0oooo0?ooo`120?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<00000303oool00`000?l0
oooo0?ooo`080?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo
0`00000?0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<0
00000?ooo`3oool0103oool300000180oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`020000o`P0oooo0P000?ll0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000001H0oooo1@000?l2
0?ooo`030000o`3oool0003o00L0oooo00<0003o0?ooo`000?l0?03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000R0?oo
o`030000o`3oool0oooo00<0oooo0P000?l30?ooo`030000o`3oool0oooo00@0oooo00<0003o0?oo
o`3oool0<P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`80
0000S@3oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool20000o`<0oooo00<0003o0?ooo`3oool0<P3oool2000005/0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`040000
o`3oool0oooo0000o`H0oooo0P000?l30?ooo`030000o`3oool0oooo0300oooo0`0000020?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`0/0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0:P3o
ool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00`3oool0
10000?l0oooo0?ooo`3oool30000obP0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0U
0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`030000o`3o
ool0oooo0280oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`@0003o0`3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01l0oooo0`00000F0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0X0?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`0K
0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool20000o`D0oooo00<0003o0?oo
o`3oool0603oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0140oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0Z0?ooo`80003o1@3oool01@000?l0oooo0?ooo`3oool0003o0140
oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo
0P00002?0?ooo`030000003oool0oooo02/0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo
0?ooo`3oool0003o00l0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0/0?ooo`@0003o
103oool00`000?l0oooo0?ooo`090?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=03o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<00000<`3oool00`000000oooo0?oo
o`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0<`3oool00`000?l0oooo0?ooo`040?ooo`040000o`0000000000000003H0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo0380oooo0P000?l40?ooo`<00000>P3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0<@3oool010000?l0oooo0000o`3oool3000000030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0=P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<03oool00`000?l00000000000020000
0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0h0?ooo`030000003oool0oooo
04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0^0?ooo`<000000P3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo
03X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000000`3oool0003o0?ooo`030?ooo`80
003o103oool00`000?l0oooo0?ooo`0k0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000
0`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0
oooo10000?lg0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo
0`00002>0?ooo`030000003oool0oooo02D0oooo0`00000A0?ooo`050000o`3oool0oooo0?ooo`00
0?l0103oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3o
ool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000C0?ooo`050000
o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo04X0
oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0N0?ooo`<000005P3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3o
ool0=`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000M0?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0=`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0H0?ooo`<00000803oool00`000?l0oooo0?ooo`060?ooo`<0003o
=P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000703o
ool20000o`D0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o03H0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@000007`3oool20000o`D0oooo00<0
003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0e0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00h0oooo0`00000[0?ooo`<0003o203oool00`000?l0oooo0?ooo`0f
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000003<0oooo0P000?l40?oo
o`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000e0?ooo`03
0000o`3oool0oooo00@0003o0P3oool20000ocH0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo
1000000h0?ooo`030000o`3oool0oooo00H0oooo0P000?lg0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?oo
o`3oool3000003`0oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000003l0oooo00@0003o0?ooo`3oool0003o
@03oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03o
ool3000004<0oooo0P000?l40?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`160?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`00
0000oooo0?ooo`160?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0@03oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000
oooo0?ooo`150?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`140?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?oo
o`130?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`14
0?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`130?oo
o`030000o`3oool0oooo04D0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3
000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo
0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool30000
04D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool30000
06D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool30000
08@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo000000020000
09@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo
0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?oo
o`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo
0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo
0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00
000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J
0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool01000
0000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0
oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo
00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?oo
o`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`33
0?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?oo
o`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00
L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3o
ool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000
oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo
0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?oo
o`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00
000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000
001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<00000
0?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@0
0000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@0
0000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000
I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0
oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<00000
0?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?oo
o`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D0
0000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000
UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool20000
00`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo
0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo
1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00
000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00
000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T
0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D0
0000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?oo
o`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00
003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P000004
0?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.58732 .67691 m
.58571 .67719 L
s
.58803 .67477 m
.58732 .67691 L
s
.58641 .67506 m
.58803 .67477 L
s
.58571 .67719 m
.58641 .67506 L
s
.56355 .70027 m
.57989 .68325 L
s
.58088 .67097 m
.58276 .6676 L
s
.57971 .67218 m
.58088 .67097 L
s
.57691 .67368 m
.57971 .67218 L
s
.58276 .6676 m
.58255 .66358 L
s
.57481 .67303 m
.57691 .67368 L
s
.57152 .6807 m
.56871 .68221 L
s
.58255 .66358 m
.58117 .66075 L
s
.56871 .68221 m
.56612 .68064 L
s
.57131 .66956 m
.57481 .67303 L
s
.58117 .66075 m
.57861 .65914 L
s
.56612 .68064 m
.56471 .67784 L
s
.57861 .65914 m
.57579 .66063 L
s
.56919 .66891 m
.57131 .66956 L
s
.56471 .67784 m
.56447 .6738 L
s
.56636 .67041 m
.56919 .66891 L
s
.56447 .6738 m
.56636 .67041 L
s
.57441 .65058 m
.57299 .65494 L
s
.57466 .64744 m
.57441 .65058 L
s
.56352 .66474 m
.56019 .6653 L
s
.57325 .64456 m
.57466 .64744 L
s
.56019 .6653 m
.55804 .66463 L
s
.57112 .64386 m
.57325 .64456 L
s
.55804 .66463 m
.5566 .66177 L
s
.56779 .64439 m
.57112 .64386 L
s
.5566 .66177 m
.55683 .65863 L
s
.56374 .64711 m
.56779 .64439 L
s
.55683 .65863 m
.55825 .65424 L
s
.56135 .64958 m
.56374 .64711 L
s
.55825 .65424 m
.56135 .64958 L
s
.55077 .65023 m
.56756 .63293 L
s
.54283 .65989 m
.54113 .66017 L
s
.54355 .65768 m
.54283 .65989 L
s
.54184 .65796 m
.54355 .65768 L
s
.54113 .66017 m
.54184 .65796 L
s
.55167 .63748 m
.56372 .62508 L
s
.54755 .64022 m
.55167 .63748 L
s
.54535 .63951 m
.54755 .64022 L
s
.54386 .63656 m
.54535 .63951 L
s
.54408 .63334 m
.54386 .63656 L
s
.53283 .64038 m
.55838 .61416 L
s
.54624 .62662 m
.54408 .63334 L
s
.54713 .61362 m
.55029 .60887 L
s
.54469 .61613 m
.54713 .61362 L
s
.55029 .60887 m
.55174 .60435 L
s
.54051 .61888 m
.54469 .61613 L
s
.55174 .60435 m
.55197 .60107 L
s
.53705 .61938 m
.54051 .61888 L
s
.55197 .60107 m
.55048 .59802 L
s
.53481 .61863 m
.53705 .61938 L
s
.55048 .59802 m
.54825 .59723 L
s
.53328 .6156 m
.53481 .61863 L
s
.53123 .61154 m
.55707 .58516 L
s
.54825 .59723 m
.54479 .5977 L
s
.53349 .61231 m
.53328 .6156 L
s
.53494 .60776 m
.53349 .61231 L
s
.52762 .6044 m
.54496 .58673 L
s
.54271 .58592 m
.54125 .59051 L
s
.54293 .58259 m
.54271 .58592 L
s
.53135 .60061 m
.52783 .60108 L
s
.54141 .57947 m
.54293 .58259 L
s
.52783 .60108 m
.52555 .60029 L
s
.53914 .57865 m
.54141 .57947 L
s
.52555 .60029 m
.52398 .59719 L
s
.53563 .57909 m
.53914 .57865 L
s
.52398 .59719 m
.52419 .59385 L
s
.53137 .58184 m
.53563 .57909 L
s
.52419 .59385 m
.52564 .58923 L
s
.52887 .58438 m
.53137 .58184 L
s
.52564 .58923 m
.52887 .58438 L
s
.51714 .58364 m
.51873 .58679 L
s
.51734 .58026 m
.51714 .58364 L
s
.51448 .57837 m
.53213 .5605 L
s
.5188 .57559 m
.51734 .58026 L
s
.52205 .5707 m
.5188 .57559 L
s
.52267 .56047 m
.51887 .56431 L
s
.52467 .55684 m
.52267 .56047 L
s
.52614 .55213 m
.52467 .55684 L
s
.5162 .55894 m
.51887 .56431 L
s
.52635 .54869 m
.52614 .55213 L
s
.52423 .54436 m
.52635 .54869 L
s
.50872 .57457 m
.50563 .57608 L
s
.50563 .57608 m
.502 .57652 L
s
.52189 .54347 m
.52423 .54436 L
s
.502 .57652 m
.49963 .57568 L
s
.51827 .54386 m
.52189 .54347 L
s
.49963 .57568 m
.49743 .57139 L
s
.51518 .54534 m
.51827 .54386 L
s
.5108 .54811 m
.51518 .54534 L
s
.49743 .57139 m
.49761 .56795 L
s
.49761 .56795 m
.49907 .5632 L
s
.50439 .55457 m
.5108 .54811 L
s
.49907 .5632 m
.50109 .55953 L
s
.50109 .55953 m
.50439 .55457 L
s
.4998 .54932 m
.51564 .5268 L
s
.49536 .54051 m
.51564 .5268 L
s
.49536 .54051 m
.51128 .51788 L
s
.49086 .53162 m
.51128 .51788 L
s
.4869 .52376 m
.5052 .50547 L
s
.50278 .50449 m
.50129 .50938 L
s
.50297 .50091 m
.50278 .50449 L
s
.49083 .51983 m
.48707 .52019 L
s
.50129 .49747 m
.50297 .50091 L
s
.48707 .52019 m
.48461 .51923 L
s
.49886 .49649 m
.50129 .49747 L
s
.48461 .51923 m
.48289 .51582 L
s
.4951 .4968 m
.49886 .49649 L
s
.48289 .51582 m
.48306 .51223 L
s
.49057 .49959 m
.4951 .4968 L
s
.48306 .51223 m
.48455 .50731 L
s
.48794 .50222 m
.49057 .49959 L
s
.48455 .50731 m
.48794 .50222 L
s
.47535 .5009 m
.4771 .50436 L
s
.47551 .49725 m
.47535 .5009 L
s
.47242 .49509 m
.49107 .47658 L
s
.47701 .49228 m
.47551 .49725 L
s
.48043 .48714 m
.47701 .49228 L
s
.47633 .47892 m
.47976 .47376 L
s
.46962 .48556 m
.47633 .47892 L
s
.47976 .47376 m
.48185 .46992 L
s
.48185 .46992 m
.48337 .46489 L
s
.46499 .48837 m
.46962 .48556 L
s
.48337 .46489 m
.48295 .45998 L
s
.4617 .48986 m
.46499 .48837 L
s
.48295 .45998 m
.47884 .45157 L
s
.45779 .49018 m
.4617 .48986 L
s
.45462 .48797 m
.45779 .49018 L
s
.45035 .47965 m
.45462 .48797 L
s
.45035 .47965 m
.47884 .45157 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`130?ooo`030000o`3oool0oooo04l0
oooo00<000000?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`110?ooo`80003oD@3oool00`000000oooo
0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo03l0oooo00@0003o0?ooo`3oool0003oD03oool00`000000oooo
0?ooo`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo03d0oooo00D0003o0?ooo`3oool0oooo0000o`1@0?ooo`030000
003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003o
ool0oooo05T0oooo00<000000?ooo`3oool0>`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo04d0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3o
ool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool0CP3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool0
0`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo
03P0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1>0?ooo`030000003oool0oooo
01L0oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000
oooo0?ooo`0f0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0CP3oool00`000000
oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo
00<000000?ooo`3oool0=03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo04l0oooo
00<000000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`0b0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo0300oooo00<0003o
0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04/0oooo00<00000
0?ooo`3oool02P3oool4000004L0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`0^0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo00L0oooo0`00001;0?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3o
ool0;@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0C@3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00
:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04h0oooo00@000000?ooo`3oool0
oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0;03oool010000?l0oooo0?ooo`3oool20000o`@0oooo00<0003o0?ooo`3o
ool0C`3oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0
I@3oool00`000000oooo0?ooo`0/0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`1>0?ooo`<00000
F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`030000003o
ool0oooo0380oooo0P000?m=0?ooo`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?ooo`3oool0<03oool2
0000o`H0oooo0`000?m20?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`0a0?ooo`030000o`3oool0oooo
00<0oooo00D0003o0?ooo`3oool0oooo0000o`0n0?ooo`<00000203oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?oo
o`3oool0<03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0>@3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0`0?ooo`04
0000o`3oool0oooo0000o`D0oooo00<0003o0?ooo`3oool0=P3oool3000000h0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`030?oo
o`80003o=03oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool0<03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0300oooo0`00000D0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo02l0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0^0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0^0?ooo`040000o`3oool0oooo0?ooo`80003o;P3oool3
000001/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool20000
00H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`0]0?ooo`040000o`3oool0oooo
0000o`L0oooo00<0003o0?ooo`3oool08`3oool3000001h0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo
02d0oooo0`000?l50?ooo`80003o8P3oool400000240oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo02`0
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000o`0O0?ooo`<000009@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo
00<000000?ooo`3oool0<03oool20000o`030?ooo`000?l0oooo01`0oooo0`00000X0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003o
ool0oooo02d0oooo0P000?l20?ooo`050000o`3oool0oooo0?ooo`000?l05`3oool3000002/0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo0080oooo00@0
003o0?ooo`000?l0003o5@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0;P3oool010000?l0oooo0000o`000?lC0?ooo`<00000<@3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<0
00000?ooo`3oool0N03oool00`000000oooo0?ooo`0/0?ooo`050000o`3oool0003o0?ooo`000?l0
403oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0[0?ooo`80003o00<0
oooo0000o`3oool03@3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo02T0oooo00@0003o
0?ooo`3oool0003o303oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02X0oooo00<0003o
0?ooo`3oool00P3oool40000o`80oooo0`00000m0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`0Y0?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l00000000000100?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0W0?ooo`060000o`3oool0oooo0?ooo`000?l0oooo0`0000000`3oool0003o0?oo
o`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<00000
0?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`030000o`000000000000@0oooo00<0003o
0?ooo`3oool0?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`80000000<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<0000000<0oooo0000o`3o
ool01`3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000
103oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`80oooo00<0003o0?ooo`3o
ool0?P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000
003oool0oooo08@0oooo00<000000?ooo`3oool0603oool3000000L0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003o
ool0oooo01@0oooo0`0000090?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0003o
@P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08H0oooo00<000000?ooo`3oool0403oool3000000`0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000003`3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0440oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
00P0oooo0`00000B0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`14
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?oo
o`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000005P3oool40000o`<0oooo00<0003o0?oo
o`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000O0?ooo`80003o1P3oool30000oc`0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo
0?ooo`2<0?ooo`8000008`3oool00`000?l0oooo0?ooo`020?ooo`80003o0P3oool00`000?l0oooo
0?ooo`0j0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00
002=0?ooo`030000003oool0oooo0280oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0<`3oool2000005/0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`040000o`3o
ool0oooo0000o`D0oooo0P000?l30?ooo`030000o`3oool0oooo0340oooo0`0000020?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo
0000o`0`0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?oo
o`030?ooo`050000o`3oool0oooo0?ooo`000?l0;P3oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02@0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o02`0oooo
0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`000?lX0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool4
0000o`80oooo00D0003o0?ooo`3oool0oooo0000o`0T0?ooo`<000005P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool09`3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo01h0oooo1000
000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0V0?ooo`040000o`3oool0oooo0000o`@0oooo00<0
003o0?ooo`3oool0703oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?oo
o`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02P0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0I0?ooo`<000008P3oool00`000000oooo0?ooo`1C
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool09`3oool20000o`@0oooo00<0003o0?ooo`3oool05`3oool3000002H0oooo00<000000?oo
o`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3o
ool0:03oool00`000?l0oooo0?ooo`020?ooo`050000o`3oool0oooo0?ooo`000?l04P3oool30000
02X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo00D0003o0?ooo`3oool0oooo0000o`030?oo
o`030000o`3oool0oooo00d0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`@0
003o0`3oool00`000?l0oooo0?ooo`0;0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
;`3oool00`000?l0oooo0?ooo`090?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;P3o
ool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo0?ooo`<00000>P3oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0;@3oool20000o`@0oooo00<0003o0?ooo`0000000P00000n0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0]0?ooo`040000o`3oool0oooo0?ooo`@00000@P3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0;03oool20000o`<0000000<0oooo0000o`3oool00P3oool00`000?l0oooo0?ooo`0o
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000000`3oool01@000?l0oooo0?ooo`3oool0
003o0480oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`0000020?ooo`040000o`3oool0oooo
0000o`<0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<0000000<0oooo0000
o`3oool00P3oool30000o`<0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@0
00003@3oool010000?l0oooo0?ooo`3oool20000od<0oooo00<000000?ooo`3oool0BP3oool00`00
0000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0
oooo0`00000@0?ooo`030000o`3oool0oooo0080003o0P3oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool300000180oooo00@0003o0?ooo`3oool0
003o103oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo01P0oooo0`00000D0?ooo`040000o`3oool0oooo0000o`D0oooo00<0003o0?oo
o`3oool0@P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
00006P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0A0?ooo`@00000603oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo04X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3o
ool3000001/0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`80003oA@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000S0?ooo`030000o`3oool0
oooo00L0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool30000
02L0oooo0`000?l60?ooo`030000o`3oool0oooo04<0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0
oooo1000000c0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<0
0000<@3oool30000o`80oooo00<0003o0?ooo`3oool0AP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000003<0oooo00@0003o0?ooo`3oool0
oooo0`000?m90?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo
0P00002@0?ooo`<00000=P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo04@0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0d0?ooo`030000o`3oool0oooo00D0oooo0P00
0?m70?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0=@3oool00`000?l0oooo0000o`1>
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0=P3oool01@000?l0oooo0?ooo`3oool0
003o04`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo
04`0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo04h0
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo04l0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?oo
o`1h0?ooo`@00000503oool00`000000oooo0?ooo`0g0?ooo`030000o`3oool0oooo0540oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f
0?ooo`<00000603oool00`000000oooo0?ooo`0f0?ooo`030000o`3oool0oooo05<0oooo00<00000
0?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?oo
o`<000006`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0oooo05D0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<0
00007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3o
ool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003o
ool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<00000
0?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?oo
o`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?oo
o`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<0
0000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0
UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0
oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<00000
0?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<0
0000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool0
0`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0
oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<00000
0?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?oo
o`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<0
0000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003o
ool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool0
0`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0
oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo
0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3o
ool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool20000
00T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?oo
o`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool00000
08l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo
0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<00000
0?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<00000
0?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0
oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool40000
00@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P000025
0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2
000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`00
0000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0
oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo
00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?oo
o`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<00000
0?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?oo
o`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0
MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<0
00000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<00000
0?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?oo
o`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000
003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03o
ool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo
00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo
00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?oo
o`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0
oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?oo
o`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`03
0000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003o
ool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2
000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool20000
05L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo
0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?oo
o`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003o
ool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3o
ool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo
0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?oo
o`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000
B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool2
00000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool0
06T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0
oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k
0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?oo
o`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00
L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03o
ool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2
000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool00000
03@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0
oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo
00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0
oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000
oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo
0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<00000
0?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<00000
0?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?oo
o`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@0
0000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000
KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03o
ool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03o
ool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool0
08h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo
0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000
000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<00000
0?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@0
0000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D0
0000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000
X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3o
ool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3o
ool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool0
06L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`00
0000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000
oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo
00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0
oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?oo
o`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<00000
0?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?oo
o`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0
oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0
oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0
oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.55012 .68187 m
.54879 .68198 L
s
.55121 .67984 m
.55012 .68187 L
s
.54988 .67995 m
.55121 .67984 L
s
.54879 .68198 m
.54988 .67995 L
s
.52568 .70238 m
.54273 .68733 L
s
.54661 .67536 m
.54892 .67226 L
s
.54539 .67644 m
.54661 .67536 L
s
.54892 .67226 m
.54978 .66828 L
s
.54283 .67762 m
.54539 .67644 L
s
.54136 .67676 m
.54283 .67762 L
s
.54978 .66828 m
.54942 .66536 L
s
.53686 .68396 m
.53428 .68515 L
s
.53951 .67299 m
.54136 .67676 L
s
.54942 .66536 m
.54783 .6635 L
s
.53428 .68515 m
.53266 .68333 L
s
.54783 .6635 m
.54526 .66468 L
s
.53266 .68333 m
.53227 .68043 L
s
.53803 .67212 m
.53951 .67299 L
s
.53227 .68043 m
.53311 .67644 L
s
.53544 .6733 m
.53803 .67212 L
s
.53311 .67644 m
.53544 .6733 L
s
.54673 .65466 m
.54452 .65879 L
s
.54771 .6516 m
.54673 .65466 L
s
.54735 .64862 m
.54771 .6516 L
s
.53466 .66743 m
.53192 .66763 L
s
.54586 .6477 m
.54735 .64862 L
s
.53192 .66763 m
.53041 .66675 L
s
.54314 .64787 m
.54586 .6477 L
s
.53041 .66675 m
.53001 .66378 L
s
.53929 .65012 m
.54314 .64787 L
s
.53001 .66378 m
.53098 .66071 L
s
.53681 .65229 m
.53929 .65012 L
s
.53098 .66071 m
.53321 .65655 L
s
.53321 .65655 m
.53681 .65229 L
s
.52838 .65181 m
.54586 .63658 L
s
.53232 .63936 m
.54485 .62846 L
s
.51973 .66048 m
.51833 .66057 L
s
.52085 .65838 m
.51973 .66048 L
s
.51945 .65847 m
.52085 .65838 L
s
.51833 .66057 m
.51945 .65847 L
s
.52841 .64162 m
.53232 .63936 L
s
.52687 .64068 m
.52841 .64162 L
s
.52645 .63762 m
.52687 .64068 L
s
.51685 .6402 m
.54345 .61716 L
s
.52744 .63447 m
.52645 .63762 L
s
.53083 .6281 m
.52744 .63447 L
s
.53849 .61108 m
.54077 .60679 L
s
.53482 .61541 m
.53849 .61108 L
s
.53228 .61761 m
.53482 .61541 L
s
.54077 .60679 m
.54178 .60359 L
s
.52832 .61987 m
.53228 .61761 L
s
.54178 .60359 m
.54139 .60043 L
s
.52549 .61998 m
.52832 .61987 L
s
.54139 .60043 m
.53985 .59941 L
s
.52293 .61164 m
.54977 .58852 L
s
.52392 .619 m
.52549 .61998 L
s
.53985 .59941 m
.53703 .59949 L
s
.5235 .61585 m
.52392 .619 L
s
.5245 .61264 m
.5235 .61585 L
s
.52678 .60832 m
.5245 .61264 L
s
.52192 .60421 m
.53994 .58873 L
s
.53839 .58769 m
.53609 .59204 L
s
.53941 .58443 m
.53839 .58769 L
s
.53901 .5812 m
.53941 .58443 L
s
.52579 .60088 m
.52292 .60097 L
s
.53745 .58014 m
.53901 .5812 L
s
.52292 .60097 m
.52134 .59994 L
s
.53459 .58018 m
.53745 .58014 L
s
.52134 .59994 m
.5209 .59672 L
s
.53057 .58242 m
.53459 .58018 L
s
.5209 .59672 m
.52191 .59345 L
s
.52797 .58464 m
.53057 .58242 L
s
.52191 .59345 m
.52422 .58906 L
s
.52422 .58906 m
.52797 .58464 L
s
.51898 .58262 m
.51943 .58589 L
s
.51824 .57713 m
.53657 .56151 L
s
.52 .57931 m
.51898 .58262 L
s
.52233 .57487 m
.52 .57931 L
s
.52611 .57042 m
.52233 .57487 L
s
.52919 .56042 m
.52525 .56377 L
s
.53167 .55707 m
.52919 .56042 L
s
.53402 .55261 m
.53167 .55707 L
s
.53505 .54925 m
.53402 .55261 L
s
.52452 .55819 m
.52525 .56377 L
s
.5345 .54475 m
.53505 .54925 L
s
.51469 .57274 m
.51189 .57389 L
s
.5329 .5436 m
.5345 .54475 L
s
.51189 .57389 m
.50893 .57392 L
s
.52997 .54358 m
.5329 .5436 L
s
.50893 .57392 m
.50728 .57282 L
s
.52718 .54469 m
.52997 .54358 L
s
.50728 .57282 m
.50665 .56835 L
s
.52305 .54692 m
.52718 .54469 L
s
.51639 .55255 m
.52305 .54692 L
s
.50665 .56835 m
.50767 .56498 L
s
.50767 .56498 m
.51002 .56046 L
s
.51254 .55707 m
.51639 .55255 L
s
.51002 .56046 m
.51254 .55707 L
s
.51413 .54686 m
.53224 .52649 L
s
.51288 .53768 m
.53224 .52649 L
s
.51288 .53768 m
.53109 .51722 L
s
.51162 .5284 m
.53109 .51722 L
s
.51051 .5202 m
.52949 .5043 L
s
.52785 .50306 m
.52544 .50769 L
s
.52891 .49955 m
.52785 .50306 L
s
.52847 .49598 m
.52891 .49955 L
s
.51459 .51678 m
.51155 .5167 L
s
.52681 .49472 m
.52847 .49598 L
s
.51155 .5167 m
.50986 .51548 L
s
.52379 .4946 m
.52681 .49472 L
s
.50986 .51548 m
.50938 .51192 L
s
.51954 .49681 m
.52379 .4946 L
s
.50938 .51192 m
.51043 .50839 L
s
.5168 .49909 m
.51954 .49681 L
s
.51043 .50839 m
.51285 .50372 L
s
.51285 .50372 m
.5168 .49909 L
s
.50726 .49632 m
.50775 .49995 L
s
.50644 .49025 m
.52577 .47421 L
s
.50832 .49275 m
.50726 .49632 L
s
.51076 .48802 m
.50832 .49275 L
s
.51475 .48336 m
.51076 .48802 L
s
.51763 .47009 m
.52025 .46656 L
s
.51362 .47477 m
.51763 .47009 L
s
.52025 .46656 m
.52271 .46179 L
s
.50667 .48053 m
.51362 .47477 L
s
.52271 .46179 m
.52363 .45691 L
s
.50231 .48276 m
.50667 .48053 L
s
.52363 .45691 m
.52255 .44813 L
s
.49935 .48384 m
.50231 .48276 L
s
.49619 .48369 m
.49935 .48384 L
s
.49426 .48114 m
.49619 .48369 L
s
.49302 .47242 m
.52255 .44813 L
s
.49302 .47242 m
.49426 .48114 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
05D0oooo00<0003o0?ooo`3oool0?P3oool00`000000oooo0?ooo`0]0?ooo`<000009@3oool00`00
0000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo05<0
oooo0P000?m00?ooo`030000003oool0oooo02X0oooo0`00000X0?ooo`030000003oool0oooo01T0
oooo000]0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0D03oool20000o`030?oo
o`000?l0oooo03l0oooo00<000000?ooo`3oool09`3oool3000002/0oooo00<000000?ooo`3oool0
6@3oool002d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`1>0?ooo`050000o`3o
ool0oooo0?ooo`000?l0@03oool00`000000oooo0?ooo`0T0?ooo`<00000;P3oool00`000000oooo
0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo04`0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo0240oooo0`00
000a0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<00000
0?ooo`3oool0BP3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03h0oooo00<00000
0?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`180?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0@03oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo04D0oooo0P000?l60?ooo`03
0000o`3oool0oooo0400oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3o
ool0603oool002`0oooo0P00001M0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`110?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`110?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0@P3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3o
ool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0400oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo03h0oooo00<000000?ooo`3oool03P3oool3000004@0oooo00<000000?ooo`3oool0603oool0
02/0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`0o0?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0oooo
00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640
oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`070?ooo`<00000B`3oool00`000000
oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo03d0oooo
0P000?l00`3oool0003o0000o`030?ooo`80003o@`3oool00`000000oooo0?ooo`040?ooo`<00000
CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003o
ool0oooo03h0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`130?ooo`040000003o
ool0oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?oo
o`1T0?ooo`030000003oool0oooo0440oooo00<0003o0?ooo`3oool0A03oool4000005D0oooo00<0
00000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0o
0?ooo`030000o`3oool0oooo04<0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?oo
o`030000003oool0oooo06L0oooo00<000000?ooo`3oool0?P3oool00`000?l0oooo0?ooo`100?oo
o`<000000P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`03
0000003oool0000006P0oooo00<000000?ooo`3oool0?@3oool00`000?l0oooo0?ooo`020?ooo`@0
003o=`3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool2000006T0oooo00<000000?ooo`3oool0?@3oool01@000?l0oooo0?ooo`3oool0003o00<0
oooo00<0003o0?ooo`3oool0<P3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo03`0oooo
00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`0_0?ooo`<000002`3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000oooo
0?ooo`1Z0?ooo`030000003oool0oooo03d0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`0/0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000P0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo
0?ooo`0k0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0:P3oool300000140oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?oo
o`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo02P0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo
0?ooo`1^0?ooo`030000003oool0oooo03T0oooo00<0003o0?ooo`3oool00P000?lX0?ooo`<00000
603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003o
ool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0h0?ooo`030000
o`3oool0003o02L0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0>03o
ool20000o`D0oooo00<0003o0?ooo`3oool0703oool3000001h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0
oooo03H0oooo00<0003o0?ooo`3oool00`3oool20000oa/0oooo1000000Q0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0LP3oool00`00
0000oooo0?ooo`0i0?ooo`<0003o6@3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo03H0
oooo0P000?l01@3oool0003o0?ooo`3oool0003o01@0oooo0`00000X0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo03@0
oooo00D0003o0?ooo`3oool0003o0?ooo`020000oa80oooo0`00000[0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0
oooo00<000000?ooo`3oool0=P3oool30000oa00oooo0`00000^0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo
0?ooo`1g0?ooo`030000003oool0oooo03@0oooo0P000?l00`3oool0003o0?ooo`0<0?ooo`<00000
<@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003o
ool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0b0?ooo`80003o00<0
oooo0000o`3oool02P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0`
0?ooo`040000o`3oool0oooo0000o`T0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0a
0?ooo`030000o`3oool0oooo00D0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0`0?oo
o`030000o`3oool0oooo00@0003o00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool0;P3oool010000?l0oooo0?ooo`000?l2000000030?ooo`000?l0oooo03d0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`03
0000003oool0oooo02d0oooo00<000000000o`000?l0103oool00`000?l0oooo0?ooo`0l0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O`3oool00`000000oooo0?ooo`0Y0?ooo`<0000000<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0l0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00
00210?ooo`030000003oool0oooo02D0oooo0`0000020?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000D0oooo00D0003o
0?ooo`3oool0oooo0000o`020?ooo`030000o`3oool0oooo03d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0
oooo01`0oooo100000070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`000?l0@@3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08@0oooo00<000000?ooo`3oool0603oool3000000X0oooo00<0003o0?ooo`3oool0103oool01@00
0?l0oooo0?ooo`3oool0003o03h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000=0?oo
o`030000o`3oool0oooo00H0oooo0P000?lo0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<0
0000403oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00`0oooo0`00000C0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003o
ool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001H0oooo10000?l00`3oool0003o0000
o`130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007@3oool20000od@0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo00<000008@3oool00`000?l0oooo0?ooo`020?ooo`80003o?P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0
oooo0P00000S0?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o?@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000
oooo0?ooo`0R0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0j0?oo
o`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo02<0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`0g0?ooo`<0
00000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0903oool00`000?l0oooo0?ooo`020?ooo`80003o
0`3oool00`000?l0oooo0?ooo`0_0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool08`3o
ool00`000?l0oooo0?ooo`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`0]0?ooo`<000002P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool08`3oool01@000?l0oooo0?ooo`3oool0003o00<0oooo0P00
0?l]0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08`3oool010000?l0oooo0?ooo`00
0?l30?ooo`030000o`3oool0oooo02X0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<0
00000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S
0?ooo`<0003o0`3oool30000obP0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0S0?oo
o`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0003o903oool4000001X0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02H0oooo0P000?l30?ooo`030000o`3oool0oooo01l0oooo0`00000N0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool07@3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0J0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000
003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0T0?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0603oool3000002X0oooo00<000000?ooo`3oool0D@3o
ool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02@0oooo00<0003o0?ooo`3oool00P000?l30?ooo`030000o`3oool0oooo0140oooo1000000^
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0U0?ooo`<0003o103oool00`000?l0oooo0?ooo`0?0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0:`3oool00`000?l0oooo0?ooo`0=0?ooo`<0
0000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0;0?ooo`<00000
>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:03oool20000o`<0oooo00<0003o0?ooo`3oool01@3o
ool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02L0oooo0P000?l30?ooo`030000o`3oool0
oooo0080oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0V0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`03000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`00
0?l00P3oool010000?l0000000000000001:0?ooo`030000003oool0oooo04`0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0T0?ooo`04
0000o`3oool0003o0?ooo`<000000P3oool00`000?l0oooo0?ooo`190?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02<0
oooo00<0003o0?ooo`0000000P0000001@000?l0oooo0?ooo`3oool0003o04d0oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo00<000000?ooo`3o
ool08@3oool4000000H0oooo00<0003o0?ooo`3oool0C@3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
7P3oool3000000P0oooo0P000?mA0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3o
ool3000000X0oooo00@0003o0?ooo`3oool0oooo0`000?m=0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000<0?ooo`030000o`3oool0oooo0080003o
0P3oool00`000?l0oooo0?ooo`1<0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
3`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01D0oooo0`00000A0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0C@3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000D0?ooo`050000o`3oool0
oooo0?ooo`000?l0D@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>
0?ooo`<000004P3oool20000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1@
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool3000001X0oooo00<0003o0?oo
o`3oool0E@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000001`0oooo00<0003o0?ooo`3o
ool00`3oool30000oe40oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000P0?ooo`80003o
1@3oool00`000?l0oooo0?ooo`1@0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
3P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000002/0oooo
00<0003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo
000P0?ooo`800000T@3oool4000002T0oooo0P000?l30?ooo`030000o`3oool0oooo0580oooo00<0
00000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000[
0?ooo`040000o`3oool0003o0?ooo`80003oE@3oool00`000000oooo0?ooo`120?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0
oooo02P0oooo00D0003o0?ooo`3oool0oooo0000o`1H0?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<00000
0?ooo`3oool0:03oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo05@0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?oo
o`<000002@3oool00`000000oooo0?ooo`0X0?ooo`030000o`3oool0003o05`0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<0
0000303oool00`000000oooo0?ooo`0Y0?ooo`040000o`3oool0oooo0000oe/0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<0
00003`3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo05/0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<00000
4@3oool00`000000oooo0?ooo`0[0?ooo`030000o`3oool0oooo05`0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503o
ool00`000000oooo0?ooo`0Z0?ooo`030000o`3oool0oooo05h0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool0
0`000000oooo0?ooo`0Y0?ooo`030000o`3oool0oooo0600oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`00
0000oooo0?ooo`0X0?ooo`030000o`3oool0oooo0680oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000
oooo0?ooo`0W0?ooo`030000o`3oool0oooo06@0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<0
0000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool0
01d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580
oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<0
0000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0
oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W
0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<0
0000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool0
0`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0
oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`000027
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?oo
o`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<00000
0?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;
0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003o
ool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool0
0`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool0
03/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo
00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000
J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`00
0000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P00
00000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`00
0000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@0
00000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?oo
o`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo10000003
0?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?oo
o`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000
003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003o
ool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<0
00000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P000000
0`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
0680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo
0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W
0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo10000009
0?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`80
0000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0
oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo
0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0
oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo
001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e
0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?oo
o`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`80
0000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00
J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@0
0000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000
503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool0
0`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool0
0`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740
oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k
0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?oo
o`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00
T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003o
ool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool0
0`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440
oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0
oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo
1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00
002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`
0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`03
0000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00
I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3o
ool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo
00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?oo
o`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@0
0000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.51207 .68243 m
.51108 .6824 L
s
.51351 .68055 m
.51207 .68243 L
s
.51251 .68052 m
.51351 .68055 L
s
.51108 .6824 m
.51251 .68052 L
s
.48784 .70012 m
.50499 .68704 L
s
.51427 .67288 m
.51615 .66906 L
s
.51161 .67569 m
.51427 .67288 L
s
.51039 .67662 m
.51161 .67569 L
s
.50816 .67752 m
.51039 .67662 L
s
.51615 .66906 m
.51682 .66616 L
s
.50737 .67653 m
.50816 .67752 L
s
.50181 .68314 m
.49957 .68405 L
s
.51682 .66616 m
.51626 .66418 L
s
.50723 .67264 m
.50737 .67653 L
s
.49957 .68405 m
.49897 .68211 L
s
.51626 .66418 m
.51403 .66507 L
s
.49897 .68211 m
.49961 .67922 L
s
.50643 .67164 m
.50723 .67264 L
s
.50418 .67254 m
.50643 .67164 L
s
.49961 .67922 m
.50149 .67538 L
s
.50149 .67538 m
.50418 .67254 L
s
.51828 .65539 m
.51537 .65922 L
s
.51997 .65249 m
.51828 .65539 L
s
.52065 .64953 m
.51997 .65249 L
s
.50548 .66669 m
.50344 .66661 L
s
.51987 .64849 m
.52065 .64953 L
s
.51785 .64837 m
.51987 .64849 L
s
.50344 .66661 m
.50263 .66559 L
s
.50263 .66559 m
.50328 .66264 L
s
.51435 .65018 m
.51785 .64837 L
s
.50328 .66264 m
.50496 .65972 L
s
.51186 .65206 m
.51435 .65018 L
s
.5079 .65586 m
.51186 .65206 L
s
.50496 .65972 m
.5079 .65586 L
s
.50592 .65072 m
.5234 .63758 L
s
.51273 .6389 m
.52526 .62952 L
s
.49689 .65834 m
.49584 .65829 L
s
.49836 .6564 m
.49689 .65834 L
s
.49732 .65634 m
.49836 .6564 L
s
.49584 .65829 m
.49732 .65634 L
s
.50918 .64072 m
.51273 .6389 L
s
.50837 .63964 m
.50918 .64072 L
s
.50126 .63813 m
.52784 .61829 L
s
.50904 .63659 m
.50837 .63964 L
s
.51076 .63361 m
.50904 .63659 L
s
.51524 .6277 m
.51076 .63361 L
s
.52619 .61181 m
.5292 .60785 L
s
.52216 .61568 m
.52619 .61181 L
s
.5292 .60785 m
.53094 .60482 L
s
.51962 .61756 m
.52216 .61568 L
s
.51604 .61936 m
.51962 .61756 L
s
.53094 .60482 m
.53166 .60168 L
s
.51476 .61072 m
.54149 .59091 L
s
.51396 .61918 m
.51604 .61936 L
s
.53166 .60168 m
.53088 .60053 L
s
.53088 .60053 m
.52882 .60031 L
s
.51314 .61805 m
.51396 .61918 L
s
.51383 .61492 m
.51314 .61805 L
s
.51558 .61187 m
.51383 .61492 L
s
.51861 .60787 m
.51558 .61187 L
s
.5164 .60333 m
.53434 .59007 L
s
.53355 .58888 m
.53051 .5929 L
s
.53532 .5858 m
.53355 .58888 L
s
.53606 .58259 m
.53532 .5858 L
s
.52026 .60048 m
.51816 .60026 L
s
.53527 .58139 m
.53606 .58259 L
s
.5332 .58112 m
.53527 .58139 L
s
.51816 .60026 m
.51734 .59908 L
s
.51734 .59908 m
.51805 .59587 L
s
.52958 .58289 m
.5332 .58112 L
s
.51805 .59587 m
.51982 .59278 L
s
.527 .58479 m
.52958 .58289 L
s
.52288 .58872 m
.527 .58479 L
s
.51982 .59278 m
.52288 .58872 L
s
.52236 .57638 m
.54056 .56305 L
s
.52115 .58184 m
.52043 .5851 L
s
.52294 .5787 m
.52115 .58184 L
s
.53018 .57065 m
.52603 .57461 L
s
.52603 .57461 m
.52294 .5787 L
s
.53844 .55817 m
.53558 .56118 L
s
.54155 .55406 m
.53844 .55817 L
s
.53558 .56118 m
.53167 .56404 L
s
.54336 .55088 m
.54155 .55406 L
s
.53292 .5585 m
.53167 .56404 L
s
.54439 .54641 m
.54336 .55088 L
s
.5436 .54512 m
.54439 .54641 L
s
.52119 .5717 m
.5188 .57251 L
s
.5415 .54477 m
.5436 .54512 L
s
.5188 .57251 m
.51665 .57223 L
s
.53913 .54555 m
.5415 .54477 L
s
.51665 .57223 m
.51581 .57097 L
s
.53544 .54729 m
.53913 .54555 L
s
.51581 .57097 m
.51677 .56652 L
s
.52884 .55209 m
.53544 .54729 L
s
.51677 .56652 m
.51858 .56332 L
s
.52462 .5561 m
.52884 .55209 L
s
.51858 .56332 m
.52173 .55915 L
s
.52173 .55915 m
.52462 .5561 L
s
.52902 .54626 m
.54856 .5283 L
s
.53104 .53713 m
.54856 .5283 L
s
.53104 .53713 m
.55068 .5191 L
s
.53308 .52789 m
.55068 .5191 L
s
.53489 .51973 m
.55363 .50628 L
s
.55284 .50489 m
.54963 .50915 L
s
.55471 .50158 m
.55284 .50489 L
s
.55553 .49803 m
.55471 .50158 L
s
.53892 .51684 m
.53676 .51642 L
s
.55474 .49661 m
.55553 .49803 L
s
.5526 .49615 m
.55474 .49661 L
s
.53676 .51642 m
.53593 .51503 L
s
.53593 .51503 m
.53671 .51149 L
s
.54884 .49784 m
.5526 .49615 L
s
.53671 .51149 m
.53859 .50816 L
s
.54614 .49977 m
.54884 .49784 L
s
.54182 .50385 m
.54614 .49977 L
s
.53859 .50816 m
.54182 .50385 L
s
.54148 .48994 m
.5605 .47644 L
s
.54014 .49598 m
.53935 .49959 L
s
.54204 .4926 m
.54014 .49598 L
s
.54966 .48414 m
.5453 .48825 L
s
.5453 .48825 m
.54204 .4926 L
s
.55895 .46833 m
.56224 .46394 L
s
.55595 .47148 m
.55895 .46833 L
s
.55158 .4756 m
.55595 .47148 L
s
.56224 .46394 m
.56445 .45928 L
s
.54474 .48045 m
.55158 .4756 L
s
.56445 .45928 m
.56646 .45057 L
s
.54089 .48214 m
.54474 .48045 L
s
.5384 .48286 m
.54089 .48214 L
s
.53617 .48235 m
.5384 .48286 L
s
.53747 .47095 m
.56646 .45057 L
s
.53559 .47963 m
.53617 .48235 L
s
.53747 .47095 m
.53559 .47963 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1T0?ooo`030000o`3oool0oooo02h0
oooo00<000000?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1Q0?ooo`<0003o<03oool00`000000oooo
0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo05l0oooo00<0003o0?ooo`000?l0<@3oool00`000000oooo0?oo
o`0T0?ooo`<00000;P3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo05d0oooo00@0003o0?ooo`3oool0003o<@3oool00`000000oooo0?oo
o`0Q0?ooo`<00000<@3oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1I
0?ooo`030000003oool0oooo05X0oooo0P000?l30?ooo`030000o`3oool0oooo02l0oooo00<00000
0?ooo`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0FP3oool00`000000oooo0?ooo`1H0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool0<03oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`03
0000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`1C0?ooo`80003o
1@3oool00`000?l0oooo0?ooo`0b0?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`1A0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3o
ool00`000000oooo0?ooo`0H0?ooo`00;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0
oooo0500oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0
oooo00h0oooo0`0000140?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0C`3oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o
0?ooo`3oool0<@3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H
0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo04h0oooo00@0003o0?oo
o`3oool0003o0`3oool20000oc@0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<00000
0?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1=0?oo
o`<0003o0`3oool00`000?l0oooo0?ooo`0d0?ooo`030000003oool0oooo00@0oooo0`00001>0?oo
o`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3o
ool0D@3oool00`000?l0oooo0?ooo`0e0?ooo`040000003oool0oooo0?ooo`<00000DP3oool00`00
0000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo04h0
oooo0P000?lh0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo
0?ooo`1U0?ooo`030000003oool0oooo04`0oooo00<0003o0?ooo`3oool0=P3oool3000005P0oooo
00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`1;0?ooo`030000o`3oool0oooo03<0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`19
0?ooo`030000o`3oool0oooo0080oooo0P000?l]0?ooo`<000001@3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?ooo`190?oo
o`030000o`3oool0oooo0080003o00<0oooo0000o`3oool0:@3oool3000000P0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`03
0000003oool0oooo04X0oooo00D0003o0?ooo`3oool0oooo0000o`0W0?ooo`<000002`3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo04P0oooo00D0003o0?ooo`3oool0oooo0000o`0U0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`160?oo
o`040000o`3oool0oooo0?ooo`80003o8P3oool300000140oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06d0oooo00<000000?ooo`3oool0A@3oool00`000?l0oooo0?ooo`020000ob00oooo0`00000D
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?oo
o`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo04<0oooo00@0003o
0?ooo`3oool0003o7`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<0
00000?ooo`3oool0@P3oool00`000?l0oooo0000o`0M0?ooo`<000006`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0oooo0440oooo0P000?lK0?ooo`<000007P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?oo
o`3oool0?`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0140oooo1000000Q0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`120?ooo`80003o4@3oool3000002D0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000
003oool0oooo03l0oooo0`000?l?0?ooo`<00000:03oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0l0?ooo`@0003o00<0
oooo0000o`3oool02P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`0l
0?ooo`040000o`3oool0003o0000o`T0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g
0?ooo`030000003oool0oooo03X0oooo10000?l70?ooo`<00000<@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo00<000000?oo
o`3oool0N03oool00`000000oooo0?ooo`0h0?ooo`80003o00<0oooo0000o`3oool0103oool30000
03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0i0?ooo`040000o`3oool0oooo0?oo
o`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0=`3oool00`000?l0oooo00000002000003X0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo
0?ooo`1l0?ooo`030000003oool0oooo03D0oooo00@0003o000000000000oooo0P000?lj0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`80000000<0003o0?ooo`3oool00P000?l00`3oool0003o
0?ooo`0i0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<000000`3oool20000o`80oooo00<0
003o0?ooo`3oool0>@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000000D0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000060?oo
o`80003o1@3oool00`000?l0oooo0?ooo`0i0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<0
0000203oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o03`0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000
003oool0oooo01`0oooo1000000;0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0n0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000003P3oool00`000?l0oooo0?ooo`020?ooo`80
003o00<0oooo0000o`3oool0?03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool300000140oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0l0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?oo
o`0@0?ooo`<000004`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo03d0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`27
0?ooo`030000003oool0oooo00`0oooo0`00000F0?ooo`030000o`3oool0003o0080oooo0P000?m0
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000006P3oool00`000?l0oooo0?ooo`020000
od40oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000O0?ooo`030000o`3oool0oooo0440
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool00`000?l0oooo0?ooo`110?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03o
ool2000002@0oooo00<0003o0?ooo`3oool010000?ln0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo02<0oooo00<0003o
0?ooo`000?l00P3oool00`000?l0oooo0?ooo`0l0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo00D0003o0?oo
o`3oool0oooo0000o`0k0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0903oool01@00
0?l0oooo0?ooo`3oool0003o0080oooo00<0003o0?ooo`3oool0<P3oool4000000H0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool00P000?l20?ooo`030000o`3oool0oooo
0300oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`040000o`3oool0oooo0000
o`80oooo0P000?l`0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool08P3oool00`000?l0
oooo0000o`020?ooo`030000o`3oool0oooo02d0oooo0`00000B0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0R0?ooo`80003o0P3oool20000ob`0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0Q0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`0X0?ooo`@000006P3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool08`3oool20000o`80oooo00<0003o0?ooo`3oool08`3oool3000001h0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo0280oooo00D0003o0?ooo`3oool0oooo0000o`0S0?ooo`<00000
8P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool08@3oool01@000?l0oooo0?ooo`3oool0003o0240oooo
0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool002<0oooo0P00
002?0?ooo`030000003oool0oooo0200oooo00D0003o0?ooo`3oool0oooo0000o`0O0?ooo`<00000
:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0?ooo`020000oa/0oooo1000
000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0Q0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`0D
0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool09@3oool20000oa@0oooo0`00000f0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0140oooo0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0R0?ooo`80003o4@3oool3000003h0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0240oooo0P000?l30?ooo`030000o`3oool0oooo00P0oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0P0?ooo`040000o`3oool0oooo0?ooo`80003o203oool3000004L0oooo00<0
00000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo01h0oooo0`000?l00`3oool0003o0000o`070?ooo`<00000BP3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool07@3oool00`000?l0oooo0?ooo`020000o`<0oooo00<0003o0?oo
o`3oool00`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280
oooo0`00002>0?ooo`030000003oool0oooo01l0oooo0P000?l30?ooo`040000o`00000000000000
0580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900
oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000
oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo
0`0000020000oeT0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<000000P3o
ool00`000?l0oooo0?ooo`020000oeL0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool0603oool3000000@0oooo00H0003o0?ooo`000?l0003o0?ooo`000?mH0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`0000080?ooo`040000
o`3oool0oooo0000oeX0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000
1P3oool20000o`80oooo00D0003o0?ooo`3oool0oooo0000o`1K0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000:0?ooo`040000o`3oool0oooo0000o`<0
oooo00<0003o0?ooo`3oool0F`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo
0`00000@0?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00
000B0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0G03oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<00000
0?ooo`3oool0103oool4000001H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1L
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0T03oool010000000oooo0?ooo`3oool3000001h0oooo00<0003o0?ooo`3oool0GP3oool0
0`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool40000
01d0oooo0P000?l20?ooo`030000o`3oool0oooo05l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`0>0?ooo`007`3oool200000900oooo0`00000O0?ooo`030000o`3oool0003o0080
003oHP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo01`0oooo00@0003o0?ooo`3oool0
003oI@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo01`0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0703o
ool20000o`80oooo0P000?mU0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool07P3oool0
0`000?l0oooo0?ooo`1W0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`1Y0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool07@3oool00`000?l0
oooo0?ooo`1Z0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool06`3oool20000ofh0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1f0?ooo`<00000603oool00`000000oooo0?ooo`0J0?ooo`030000o`3oool0oooo06l0oooo00<0
00000?ooo`3oool0?03oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c
0?ooo`<000006`3oool00`000000oooo0?ooo`0I0?ooo`030000o`3oool0oooo0740oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?oo
o`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0
J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000
003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0
oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool30000
02h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<0
00000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M
0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<00000
0?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?oo
o`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?oo
o`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3o
ool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0
<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003o
ool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0
oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool30000
04h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0
oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<0
00000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?oo
o`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3o
ool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3o
ool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool30000
06d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<0
00000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I
0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?oo
o`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3o
ool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000
003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool0
9P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3o
ool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo
00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000
oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3o
ool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2
000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<00000
0?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0
oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0
oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<0
00000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003o
ool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4
000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P00
00250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3o
ool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool0
02d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo
0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d
0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3o
ool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3o
ool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<0
00000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k
0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`03
0000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00
@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0
oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0
oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<00000
0?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?oo
o`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3o
ool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`800000
00<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<00000
0?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?oo
o`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000
003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`00
0000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0
d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3o
ool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2
000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000
oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo
0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000
003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0
oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R
0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`80
0000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3o
ool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3o
ool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool20000
04<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400
oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?oo
o`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f
0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?oo
o`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00
M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3o
ool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0
000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool20000
03@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo0000
00h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0
oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool40000
04L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`00
0000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`00
0000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0
oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<0
00000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<0
00000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<00000
0?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?oo
o`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@0
0000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0
I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3o
ool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool0
08l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900
oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo
0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<0
00000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?oo
o`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?oo
o`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@0
0000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000
Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03o
ool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool0
0`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`00
0000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0
oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo
01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool00000
0?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<0
00000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=
0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool0
0:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool40000
0=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.47453 .67857 m
.47391 .67845 L
s
.47626 .67687 m
.47453 .67857 L
s
.47563 .67675 m
.47626 .67687 L
s
.47391 .67845 m
.47563 .67675 L
s
.45136 .69356 m
.46801 .6824 L
s
.48005 .66945 m
.48289 .6659 L
s
.47713 .67194 m
.48005 .66945 L
s
.47595 .67273 m
.47713 .67194 L
s
.47414 .6734 m
.47595 .67273 L
s
.48289 .6659 m
.48457 .66314 L
s
.47406 .67235 m
.47414 .6734 L
s
.48457 .66314 m
.48506 .66115 L
s
.47564 .66854 m
.47406 .67235 L
s
.46765 .67828 m
.46582 .67896 L
s
.48506 .66115 m
.48326 .6618 L
s
.46582 .67896 m
.46628 .677 L
s
.47557 .66748 m
.47564 .66854 L
s
.46628 .677 m
.46793 .67423 L
s
.47374 .66814 m
.47557 .66748 L
s
.46793 .67423 m
.47079 .67066 L
s
.49013 .65276 m
.48663 .65621 L
s
.49245 .6501 m
.49013 .65276 L
s
.47079 .67066 m
.47374 .66814 L
s
.49416 .64728 m
.49245 .6501 L
s
.49411 .64618 m
.49416 .64728 L
s
.47709 .66256 m
.47581 .66228 L
s
.49287 .64587 m
.49411 .64618 L
s
.47581 .66228 m
.47573 .6612 L
s
.48986 .64729 m
.49287 .64587 L
s
.47573 .6612 m
.47742 .65838 L
s
.48747 .64888 m
.48986 .64729 L
s
.47742 .65838 m
.47976 .6557 L
s
.4833 .65221 m
.48747 .64888 L
s
.48424 .647 m
.50105 .63589 L
s
.47976 .6557 m
.4833 .65221 L
s
.49368 .63613 m
.5057 .62821 L
s
.47518 .65356 m
.47453 .65341 L
s
.47697 .6518 m
.47518 .65356 L
s
.49063 .63755 m
.49368 .63613 L
s
.47632 .65165 m
.47697 .6518 L
s
.47453 .65341 m
.47632 .65165 L
s
.48668 .63424 m
.51216 .61752 L
s
.49058 .63642 m
.49063 .63755 L
s
.49232 .63351 m
.49058 .63642 L
s
.4947 .63076 m
.49232 .63351 L
s
.5001 .62544 m
.4947 .63076 L
s
.5139 .61105 m
.51751 .60749 L
s
.50967 .61441 m
.5139 .61105 L
s
.51751 .60749 m
.51991 .60472 L
s
.50725 .616 m
.50967 .61441 L
s
.51991 .60472 m
.52172 .60173 L
s
.50708 .60884 m
.53258 .59224 L
s
.50419 .61739 m
.50725 .616 L
s
.52172 .60173 m
.52172 .60052 L
s
.50294 .61701 m
.50419 .61739 L
s
.52172 .60052 m
.5205 .6001 L
s
.5029 .61582 m
.50294 .61701 L
s
.50469 .61284 m
.5029 .61582 L
s
.5113 .6018 m
.5284 .59069 L
s
.50711 .61005 m
.50469 .61284 L
s
.51076 .60645 m
.50711 .61005 L
s
.52841 .58946 m
.52475 .59306 L
s
.53085 .58664 m
.52841 .58946 L
s
.53269 .58359 m
.53085 .58664 L
s
.53271 .58234 m
.53269 .58359 L
s
.51498 .59941 m
.51374 .59898 L
s
.53151 .58188 m
.53271 .58234 L
s
.51374 .59898 m
.51373 .59775 L
s
.52845 .58323 m
.53151 .58188 L
s
.51373 .59775 m
.51555 .5947 L
s
.526 .58481 m
.52845 .58323 L
s
.51555 .5947 m
.51801 .59186 L
s
.5217 .58822 m
.526 .58481 L
s
.51801 .59186 m
.5217 .58822 L
s
.52666 .57615 m
.54391 .56505 L
s
.52355 .58135 m
.52169 .58445 L
s
.52603 .57848 m
.52355 .58135 L
s
.53408 .57138 m
.52975 .5748 L
s
.52975 .5748 m
.52603 .57848 L
s
.54466 .56009 m
.54156 .56273 L
s
.54839 .55641 m
.54466 .56009 L
s
.55089 .55352 m
.54839 .55641 L
s
.54156 .56273 m
.53786 .5651 L
s
.55346 .54928 m
.55089 .55352 L
s
.54102 .55984 m
.53786 .5651 L
s
.55351 .54794 m
.55346 .54928 L
s
.55233 .54739 m
.55351 .54794 L
s
.52792 .57148 m
.52606 .57203 L
s
.5505 .5479 m
.55233 .54739 L
s
.52606 .57203 m
.52481 .57153 L
s
.54742 .54921 m
.5505 .5479 L
s
.52481 .57153 m
.52481 .57022 L
s
.54118 .55319 m
.54742 .54921 L
s
.52481 .57022 m
.52734 .56598 L
s
.54379 .54754 m
.56383 .53213 L
s
.54898 .53887 m
.56383 .53213 L
s
.53679 .55665 m
.54118 .55319 L
s
.52734 .56598 m
.52986 .56305 L
s
.53364 .55932 m
.53679 .55665 L
s
.52986 .56305 m
.53364 .55932 L
s
.54898 .53887 m
.5691 .52343 L
s
.55422 .53012 m
.5691 .52343 L
s
.55885 .52238 m
.57643 .51131 L
s
.57653 .50987 m
.57269 .51367 L
s
.57912 .50686 m
.57653 .50987 L
s
.58115 .50351 m
.57912 .50686 L
s
.58125 .50206 m
.58115 .50351 L
s
.56264 .52 m
.56145 .51936 L
s
.5801 .50138 m
.58125 .50206 L
s
.56145 .51936 m
.56152 .51793 L
s
.57701 .50262 m
.5801 .50138 L
s
.56152 .51793 m
.56353 .51458 L
s
.57449 .5042 m
.57701 .50262 L
s
.56353 .51458 m
.56614 .51154 L
s
.57002 .5077 m
.57449 .5042 L
s
.56614 .51154 m
.57002 .5077 L
s
.57574 .49418 m
.59348 .48313 L
s
.57232 .49989 m
.57028 .5033 L
s
.57496 .49682 m
.57232 .49989 L
s
.58338 .48942 m
.57888 .49294 L
s
.57888 .49294 m
.57496 .49682 L
s
.59596 .47511 m
.5999 .47122 L
s
.59273 .47784 m
.59596 .47511 L
s
.5999 .47122 m
.60327 .46695 L
s
.58822 .48136 m
.59273 .47784 L
s
.58185 .48532 m
.58822 .48136 L
s
.60327 .46695 m
.60824 .45874 L
s
.5787 .48655 m
.58185 .48532 L
s
.57682 .48698 m
.5787 .48655 L
s
.58132 .47533 m
.60824 .45874 L
s
.57563 .48625 m
.57682 .48698 L
s
.57643 .48355 m
.57563 .48625 L
s
.58132 .47533 m
.57643 .48355 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`1a0?ooo`030000o`3oool0oooo01h0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1^0?ooo`80003o8@3oool00`000000oooo0?ooo`0N0?oo
o`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo06/0oooo0P000?l00`3oool0003o0?ooo`0Q0?ooo`030000003oool0oooo01X0
oooo0`00000g0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo
00<000000?ooo`3oool0J@3oool010000?l0oooo0?ooo`000?lS0?ooo`030000003oool0oooo01L0
oooo0`00000k0?ooo`030000003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo
0?ooo`1V0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo01@0oooo
0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?oo
o`1S0?ooo`80003o103oool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo0140oooo0`00
00110?ooo`030000003oool0oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0H@3oool00`000?l0oooo0?ooo`020?ooo`80003o9@3oool00`000000oooo0?ooo`0>
0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?oo
o`030000003oool0oooo05l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0U0?oo
o`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0640oooo00<000000?ooo`3oool0GP3oool01@000?l0oooo0?ooo`3oool0003o
02P0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0
oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1L0?ooo`070000o`3oool0oooo0?oo
o`000?l0oooo0000o`0W0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0F`3oool00`00
0?l0oooo0000o`030000obP0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0
oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0FP3oool20000
o`030?ooo`000?l0oooo02T0oooo1000001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`03
0000003oool0oooo06D0oooo00<000000?ooo`3oool0FP3oool20000obT0oooo0`00001H0?ooo`03
0000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
F03oool20000obL0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`1F0?ooo`80003o9@3o
ool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2
000006T0oooo00<000000?ooo`3oool0E@3oool00`000?l0oooo0?ooo`0R0?ooo`<00000203oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo
06T0oooo00<000000?ooo`3oool0E03oool00`000?l0oooo0?ooo`020000oad0oooo0`00000;0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0D`3oool30000o`030?ooo`000?l0oooo01T0
oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo
00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo0540
oooo0P000?l20?ooo`030000o`3oool0oooo01H0oooo0`00000A0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000
oooo0?ooo`1]0?ooo`030000003oool0oooo04l0oooo00D0003o0?ooo`3oool0oooo0000o`0F0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1>0?oo
o`030000o`3oool0oooo0080003o4`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo
06l0oooo00<000000?ooo`3oool0C03oool00`000?l0oooo0?ooo`020000oa40oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0BP3oool010000?l0oooo0000o`000?l@0?oo
o`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`03
0000003oool0oooo0740oooo00<000000?ooo`3oool0B@3oool20000o`h0oooo1000000Q0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
LP3oool00`000000oooo0?ooo`170?ooo`050000o`3oool0oooo0?ooo`000?l02@3oool3000002D0
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo
0000001d0?ooo`030000003oool0oooo04P0oooo0P000?l70?ooo`<00000:03oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?oo
o`150?ooo`<0003o1@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`13
0?ooo`<0003o0`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?oo
o`3oool0@P3oool010000?l0oooo0000o`000?l200000340oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool0@03oool40000oc@0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0m0?ooo`04000000000?l0003o0000ocH0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0
oooo0`0000020?ooo`030000o`3oool0oooo03D0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo
0`0000030?ooo`80003o>03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool3000000D0oooo00@0
003o0?ooo`000?l0003o=`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool3000000T0oooo00<0
003o0?ooo`000?l0=`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000000X0oooo0P000?l0
0`3oool0003o0?ooo`0g0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`00000<0?ooo`050000o`3oool0oooo
0?ooo`000?l0>03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000h0oooo00D0003o0?oo
o`3oool0oooo0000o`0i0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool0
02H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000403oool00`00
0?l0oooo0?ooo`020000oc/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000B0?ooo`80
003o0P3oool20000oc`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000D0?ooo`040000
o`3oool0oooo0?ooo`80003o00<0oooo0000o`3oool0>P3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0
403oool3000001L0oooo00<0003o0?ooo`3oool00P3oool20000oc`0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003o
ool0oooo00`0oooo0`00000J0?ooo`80003o00<0oooo0000o`000?l0?P3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<00000
0?ooo`3oool0203oool3000001h0oooo0P000?m00?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?oo
o`<00000803oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03000002<0
oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000U0?ooo`030000o`3oool0oooo0080003o
?`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3o
ool00`000000oooo0?ooo`0S0?ooo`030000o`3oool0003o0080003o?`3oool2000005/0oooo00<0
00000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0S
0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0j0?ooo`<000000P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o03T0oooo100000060?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`00
0000oooo0?ooo`0R0?ooo`060000o`3oool0oooo0000o`3oool0003o=@3oool3000000X0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool00`000?lc0?ooo`<000003P3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0803oool00`000?l0oooo0000o`020000oc80oooo0`00000B0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0Q0?ooo`<0003o<03oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo0200oooo0P000?l00`3oool0003o0?ooo`0[0?ooo`@000006P3oool00`000000oooo
0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool07`3oool20000o`80oooo00<0003o0?ooo`3oool09`3oool3000001h0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01h0oooo00D0003o0?ooo`3oool0oooo0000o`0W0?ooo`<000008P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool07P3oool010000?l0oooo0000o`000?lU0?ooo`<000009P3o
ool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool0
0`000000oooo0?ooo`0M0?ooo`030000o`3oool0003o02@0oooo0`00000Z0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`00
0000oooo0?ooo`0L0?ooo`<0003o00<0oooo0000o`3oool07P3oool4000002h0oooo00<000000?oo
o`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo01l0oooo0P000?lM0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
7P3oool00`000?l0oooo0?ooo`0J0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0703o
ool20000oaX0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0K0?ooo`80003o00<0oooo
0000o`3oool05@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01X0oooo00@0003o0?oo
o`3oool0003o4`3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01P0oooo0P000?l00`3o
ool0003o0000o`0A0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool05`3oool010000?l0
oooo0000o`000?l20?ooo`030000o`3oool0oooo00/0oooo0`00001:0?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0I0?ooo`040000o`3oool0003o0000o`/0oooo0`00001>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo01T0
oooo0P000?l:0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100
oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0G0?ooo`80003o203oool4000005H0oooo
00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01H0oooo00D0003o0?ooo`3oool0oooo0000o`030?ooo`<00000
F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`000?l3000005h0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`00
00060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04`3oool20000o`030?ooo`00
0?l0003o00<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0C
0?ooo`030000o`3oool000000080000000<0oooo0000o`3oool0H`3oool00`000000oooo0?ooo`17
0?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo0140oooo1000000010000?l0oooo0000o`000?mV0?ooo`030000003oool0
oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`0000030?ooo`030000o`3oool0oooo
06T0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<000001@3oool20000o`03
0?ooo`000?l0003o06P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000;0?ooo`030000
o`3oool0oooo06P0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000000:0?ooo`80003o00<0
oooo0000o`3oool0J`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P
0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo0`00000=0?ooo`050000o`3o
ool0003o0?ooo`000?l0K@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo
000P0?ooo`800000T@3oool4000000l0oooo00<0003o0?ooo`3oool00P000?m_0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<000004P3oool0
0`000?l0oooo0?ooo`1a0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0403oool01000
0?l0oooo0?ooo`000?ma0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo0100oooo00<0003o0?ooo`3oool0M03oool00`000000
oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo
0`00000<0?ooo`030000003oool0oooo00h0oooo0P000?mh0?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<0
00000?ooo`3oool03@3oool00`000?l0oooo0?ooo`1i0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<00000
0?ooo`3oool0303oool20000og`0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo07d0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0
L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3
000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo
0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0
E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003o
ool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool30000
04D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000
oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo
0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?oo
o`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`03
0000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003o
ool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool30000
06D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40
oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?oo
o`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`03
0000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0
603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003o
ool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0
oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool30000
08@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo000000020000
09@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo
00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P00
00040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?oo
o`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3o
ool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000
oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo
0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?oo
o`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<00000
0?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?oo
o`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000
003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3o
ool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0
oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool20000
00030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3o
ool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo
0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`36
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?oo
o`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?oo
o`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3o
ool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3o
ool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?oo
o`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3o
ool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3o
ool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool0
0`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool0
04<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0
oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`00
0000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo
0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00
000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<0
00000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J
0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?oo
o`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool01000
0000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo
0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`03
0000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0
oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo
00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?oo
o`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`33
0?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?oo
o`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00
L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3o
ool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000
oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo
0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?oo
o`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00
000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@00000
0?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000
001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<0
00000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<00000
0?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?oo
o`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@0
0000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@0
0000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000
I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool20000
00<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0
oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0
oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<00000
0?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?oo
o`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D0
0000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000
UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool0
0`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool20000
00`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0
oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0
oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo
0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo
1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00
000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00
000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T
0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?oo
o`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D0
0000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3o
ool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?oo
o`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA
0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00
003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P000004
0?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.44079 .66891 m
.43884 .6704 L
s
.44056 .66874 m
.44079 .66891 L
s
.43884 .6704 m
.4386 .67023 L
s
.4386 .67023 m
.44056 .66874 L
s
.41758 .68288 m
.43311 .67353 L
s
.44751 .66207 m
.45122 .6589 L
s
.44444 .66422 m
.44751 .66207 L
s
.44335 .66488 m
.44444 .66422 L
s
.45122 .6589 m
.45385 .65637 L
s
.44202 .66536 m
.44335 .66488 L
s
.45385 .65637 m
.45539 .6545 L
s
.44266 .66435 m
.44202 .66536 L
s
.44593 .6608 m
.44266 .66435 L
s
.45539 .6545 m
.45408 .65496 L
s
.43563 .66951 m
.43428 .67001 L
s
.43428 .67001 m
.43579 .66815 L
s
.44658 .65977 m
.44593 .6608 L
s
.43579 .66815 m
.43841 .66562 L
s
.44525 .66025 m
.44658 .65977 L
s
.46335 .64685 m
.45938 .64987 L
s
.46622 .64449 m
.46335 .64685 L
s
.4689 .64192 m
.46622 .64449 L
s
.43841 .66562 m
.44215 .66242 L
s
.44215 .66242 m
.44525 .66025 L
s
.46959 .64086 m
.4689 .64192 L
s
.46919 .64045 m
.46959 .64086 L
s
.45055 .65515 m
.4501 .65477 L
s
.46678 .64155 m
.46919 .64045 L
s
.4501 .65477 m
.45077 .65372 L
s
.46457 .64287 m
.46678 .64155 L
s
.45077 .65372 m
.45344 .65114 L
s
.46421 .64076 m
.47969 .63156 L
s
.46035 .64571 m
.46457 .64287 L
s
.45344 .65114 m
.45634 .64876 L
s
.45634 .64876 m
.46035 .64571 L
s
.47592 .63113 m
.48696 .62458 L
s
.4735 .63223 m
.47592 .63113 L
s
.47372 .62868 m
.49706 .61488 L
s
.4575 .64475 m
.45548 .64629 L
s
.45728 .64455 m
.4575 .64475 L
s
.45548 .64629 m
.45526 .64609 L
s
.47421 .63113 m
.4735 .63223 L
s
.45526 .64609 m
.45728 .64455 L
s
.47696 .62848 m
.47421 .63113 L
s
.47991 .62605 m
.47696 .62848 L
s
.48601 .62141 m
.47991 .62605 L
s
.50618 .60572 m
.50915 .60327 L
s
.50211 .60881 m
.50618 .60572 L
s
.49786 .61166 m
.50211 .60881 L
s
.50022 .60607 m
.5234 .59244 L
s
.50915 .60327 m
.51197 .60057 L
s
.49565 .61296 m
.49786 .61166 L
s
.51197 .60057 m
.51275 .59941 L
s
.49325 .61403 m
.49565 .61296 L
s
.51275 .59941 m
.51243 .59889 L
s
.49289 .61355 m
.49325 .61403 L
s
.49364 .61241 m
.49289 .61355 L
s
.50684 .59968 m
.52237 .59058 L
s
.49645 .6097 m
.49364 .61241 L
s
.52317 .58939 m
.51906 .59252 L
s
.52618 .58692 m
.52317 .58939 L
s
.49945 .60723 m
.49645 .6097 L
s
.52906 .58416 m
.52618 .58692 L
s
.50356 .6041 m
.49945 .60723 L
s
.52987 .58296 m
.52906 .58416 L
s
.52959 .5824 m
.52987 .58296 L
s
.51019 .59772 m
.50986 .59719 L
s
.52723 .58341 m
.52959 .5824 L
s
.50986 .59719 m
.51065 .59601 L
s
.52502 .58471 m
.52723 .58341 L
s
.51065 .59601 m
.51352 .59325 L
s
.52071 .58759 m
.52502 .58471 L
s
.51352 .59325 m
.51656 .59075 L
s
.51656 .59075 m
.52071 .58759 L
s
.53094 .57646 m
.54649 .56742 L
s
.52607 .58116 m
.52316 .58396 L
s
.53763 .57257 m
.53332 .57545 L
s
.52913 .57863 m
.52607 .58116 L
s
.55423 .55957 m
.55005 .56274 L
s
.55731 .55703 m
.55423 .55957 L
s
.55005 .56274 m
.54685 .56497 L
s
.53332 .57545 m
.52913 .57863 L
s
.56128 .55321 m
.55731 .55703 L
s
.54685 .56497 m
.54352 .56691 L
s
.54846 .56216 m
.54352 .56691 L
s
.56217 .55194 m
.56128 .55321 L
s
.56196 .5513 m
.56217 .55194 L
s
.56074 .55162 m
.56196 .5513 L
s
.53458 .57209 m
.53332 .57245 L
s
.55841 .55258 m
.56074 .55162 L
s
.53332 .57245 m
.53304 .57185 L
s
.55283 .5558 m
.55841 .55258 L
s
.53304 .57185 m
.53388 .5706 L
s
.55774 .55064 m
.57734 .53779 L
s
.56584 .54284 m
.57734 .53779 L
s
.53388 .5706 m
.53785 .56677 L
s
.54847 .55871 m
.55283 .5558 L
s
.54522 .56097 m
.54847 .55871 L
s
.53785 .56677 m
.54097 .5642 L
s
.54097 .5642 m
.54522 .56097 L
s
.56584 .54284 m
.58549 .52998 L
s
.57401 .53496 m
.58549 .52998 L
s
.58123 .52801 m
.5968 .51911 L
s
.59777 .51775 m
.59349 .521 L
s
.60095 .51513 m
.59777 .51775 L
s
.60408 .51212 m
.60095 .51513 L
s
.60506 .51075 m
.60408 .51212 L
s
.60495 .50999 m
.60506 .51075 L
s
.58459 .52609 m
.58442 .52537 L
s
.60267 .51088 m
.60495 .50999 L
s
.58442 .52537 m
.58538 .52401 L
s
.60044 .51214 m
.60267 .51088 L
s
.58538 .52401 m
.5885 .521 L
s
.59605 .51505 m
.60044 .51214 L
s
.5885 .521 m
.59171 .51834 L
s
.59171 .51834 m
.59605 .51505 L
s
.60748 .50271 m
.62306 .4939 L
s
.60217 .50783 m
.599 .51088 L
s
.61419 .49891 m
.60978 .50183 L
s
.60541 .50515 m
.60217 .50783 L
s
.60978 .50183 m
.60541 .50515 L
s
.63375 .48319 m
.6381 .47945 L
s
.62939 .48651 m
.63375 .48319 L
s
.62609 .48879 m
.62939 .48651 L
s
.62168 .49171 m
.62609 .48879 L
s
.6381 .47945 m
.64572 .47214 L
s
.6161 .49486 m
.62168 .49171 L
s
.6138 .49572 m
.6161 .49486 L
s
.62225 .4853 m
.64572 .47214 L
s
.61263 .49595 m
.6138 .49572 L
s
.61252 .49514 m
.61263 .49595 L
s
.61464 .49265 m
.61252 .49514 L
s
.62225 .4853 m
.61464 .49265 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo0140oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`1g0?ooo`80003o503oool00`000000oooo0?ooo`0>0?ooo`<00000A03oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo07@0
oooo0`000?lE0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool0L@3oool20000o`030?oo
o`000?l0oooo01D0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1^0?ooo`80003o00<0
oooo0000o`000?l05`3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo06`0oooo00@0003o
0?ooo`3oool0003o6@3oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool0
5`3oool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`1Z0?ooo`030000o`3o
ool0003o0080003o6@3oool4000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`1X0?ooo`030000o`3oool0003o01X0oooo0`00001H
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool0IP3oool010000?l0oooo0000o`000?lG0?ooo`<000000P3oool00`000000oooo0?ooo`1F
0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo00<000000?oo
o`3oool0I03oool40000oaD0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo06D0oooo00<0003o0?ooo`3o
ool04P3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo0680oooo0P000?lB0?ooo`<00000
2`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0600oooo00<0003o0?ooo`3oool03`3o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0G@3o
ool20000o`l0oooo0`00000A0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3o
ool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003o
ool0oooo05/0oooo00<0003o0?ooo`000?l0303oool3000001@0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06h0oooo00<000000?ooo`3oool0FP3oool40000o`P0oooo0`00000H0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3o
ool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo05P0oooo0`000?l70?ooo`<000006`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05H0oooo00<0003o0?ooo`000?l01@3oool3
000001h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`00
0000oooo0?ooo`1a0?ooo`030000003oool0oooo05<0oooo10000?l20?ooo`@000008@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0D@3oool010000?l0oooo0000o`000?l3000002D0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`03
0000003oool0oooo0500oooo0P000?l2000002P0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool00`000000003o
0000000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000
000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool300000080oooo00<0
003o0?ooo`3oool0:@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo0005
0?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`15
0?ooo`<000000`3oool20000ob`0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?oo
o`3oool0@@3oool3000000@0oooo0P000?l^0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3o
ool0?@3oool3000000L0oooo0P000?l^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool05@3oool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<00000
203oool30000obl0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3o
ool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000:0?ooo`80003o<@3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0
oooo07d0oooo00<000000?ooo`3oool0<@3oool3000000/0oooo0P000?lc0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`00
0000oooo0?ooo`0]0?ooo`<000003@3oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000
oooo0?ooo`0Y0?ooo`<00000403oool20000oc@0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool300000140oooo
0`000?le0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<000004P3oool20000o`80oooo00<0
003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0703oool4000001@0oooo00D0003o
0?ooo`3oool0oooo0000o`0g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000005`3oool0
0`000?l0oooo0000o`020000ocP0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000H0?oo
o`D0003o>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`03
0000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool3000001X0oooo00@0003o0?ooo`3o
ool0oooo0P000?lj0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000007@3oool00`000?l0
oooo0?ooo`020000oc/0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000P0?ooo`<0003o
?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0103oool300000280oooo0P000?lo0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`03000002@0oooo0P000?m00?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000002H0oooo0P000?m10?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`03
0000003oool0oooo02@0oooo0`000?m00?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02<0oooo0`000?ln0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool08@3oool20000o`030?ooo`000?l0oooo03X0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0P0?ooo`030000o`3oool0003o0080003o>03oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo01l0oooo00<0003o0?ooo`000?l00P000?lf0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool30000ocD0oooo0`00000B0?ooo`03
0000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0
S@3oool00`000000oooo0?ooo`0N0?ooo`<0003o<`3oool3000001H0oooo00<000000?ooo`3oool0
E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo01`0oooo0P000?l00`3oool0003o0?ooo`0_0?ooo`@000006P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool06`3oool20000o`030?ooo`000?l0oooo02d0oooo0`00000N0?ooo`030000003oool0
oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0J0?ooo`@0003o;03oool300000280oooo00<000000?ooo`3oool0D`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01T0
oooo0`000?l[0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140
oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0I0?ooo`80003o:@3oool3000002X0oooo
00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo01P0oooo0P000?lV0?ooo`@00000;P3oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0603oool00`000?l0oooo0?ooo`0S0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool05P3oool20000ob<0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0E0?ooo`<0
003o803oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01<0oooo10000?lN0?ooo`<00000
?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool04P3oool30000oa`0oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0B0?ooo`040000o`3oool0oooo0000oaP0oooo0`0000170?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0C0?ooo`80003o5P3oool3000004X0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
0140oooo0P000?lE0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0?0?ooo`<0003o4`3oool300000580
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3oool200000900oooo
00<000000?ooo`3oool0303oool00`000?l0oooo0?ooo`030000o`l0oooo1000001F0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0<0?ooo`@0003o3P3oool3000005/0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0<0?ooo`<0003o303oool3000005h0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`0:0?ooo`<00000HP3oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0:0?ooo`<0003o203oool30000
06H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo00<0
oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00P0oooo
00<0003o0?ooo`000?l00`3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?oo
o`070?ooo`<0003o00@0oooo0000000000000000LP3oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool01@3o
ool30000o`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?oo
o`040000003oool0oooo0?ooo`<000000`000?ml0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@000000P3oool00`000?l0oooo0?ooo`1n0?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000103oool00`000?l0oooo0?ooo`1o0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0
0P000?n30?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`000?l0QP3oool00`000000oooo0?oo
o`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`000009
0?ooo`03000000000?l0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000
003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3
000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<0
00000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?oo
o`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3
000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0
oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo
09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000
oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0
oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo
00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`000018
0?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3o
ool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000
003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003o
ool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3
000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo
09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo
00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z
0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?oo
o`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`80
00009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000
003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3o
ool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3
000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0
oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo
0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000
oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo
00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo
000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;
0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?oo
o`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`03
0000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000
T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<00000
0?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?oo
o`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?oo
o`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool20000
0980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`03
0000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`00
8P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2
000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`24
0?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`06
0?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?oo
o`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000
003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03o
ool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0
oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003o
ool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2
000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo
0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0
a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003o
ool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0
oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool20000
06T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo
00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo
00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0
oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool20000
0680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo
0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00
000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo
00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<0
00000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m
0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?oo
o`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`03
0000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00
F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3o
ool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00
001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P
0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool0
00000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080
oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo1000
00050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A
0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?oo
o`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool0
0`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`00
0000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80
oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo
1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000
000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?oo
o`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`80
00003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000
003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D0
0000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3o
ool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3o
ool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00
J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3o
ool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2
000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo
000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool00000
02H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000
oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<0
00000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O
0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?oo
o`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@0
0000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3o
ool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2
000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo
01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000
oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000
oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo
0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?oo
o`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/
0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?oo
o`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`00
00008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@0
0000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`03
0000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P00
00000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2
000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`00
0000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?oo
o`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<0
00000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool0
0?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.40843 .65689 m
.40631 .65814 L
s
.40861 .65671 m
.40843 .65689 L
s
.40631 .65814 m
.40649 .65797 L
s
.40649 .65797 m
.40861 .65671 L
s
.38779 .66838 m
.40161 .66068 L
s
.41787 .65095 m
.42233 .64825 L
s
.41477 .65276 m
.41787 .65095 L
s
.42233 .64825 m
.42583 .64607 L
s
.4138 .6533 m
.41477 .65276 L
s
.41302 .65366 m
.4138 .6533 L
s
.42583 .64607 m
.42837 .64443 L
s
.41437 .65275 m
.41302 .65366 L
s
.42837 .64443 m
.42761 .64478 L
s
.41924 .64966 m
.41437 .65275 L
s
.40696 .6571 m
.40616 .65747 L
s
.40616 .65747 m
.40868 .65584 L
s
.42061 .64875 m
.41924 .64966 L
s
.43896 .63785 m
.43467 .64039 L
s
.44229 .63585 m
.43896 .63785 L
s
.44584 .63364 m
.44229 .63585 L
s
.41983 .6491 m
.42061 .64875 L
s
.40868 .65584 m
.41219 .65366 L
s
.44725 .6327 m
.44584 .63364 L
s
.41669 .65092 m
.41983 .6491 L
s
.41219 .65366 m
.41669 .65092 L
s
.44771 .63229 m
.44725 .6327 L
s
.44601 .63315 m
.44771 .63229 L
s
.4269 .64471 m
.42731 .64432 L
s
.44664 .63224 m
.46015 .62475 L
s
.42731 .64432 m
.42871 .64339 L
s
.44407 .63422 m
.44601 .63315 L
s
.43997 .63658 m
.44407 .63422 L
s
.42871 .64339 m
.43227 .64117 L
s
.43563 .63915 m
.43997 .63658 L
s
.43227 .64117 m
.43563 .63915 L
s
.46018 .62408 m
.46978 .61876 L
s
.46291 .62166 m
.48314 .61046 L
s
.45849 .62494 m
.46018 .62408 L
s
.45995 .62397 m
.45849 .62494 L
s
.44077 .63549 m
.43859 .63679 L
s
.441 .63529 m
.44077 .63549 L
s
.43859 .63679 m
.43881 .63658 L
s
.49445 .60251 m
.51435 .59152 L
s
.43881 .63658 m
.441 .63529 L
s
.4636 .62169 m
.45995 .62397 L
s
.49569 .6026 m
.4991 .60055 L
s
.49132 .60518 m
.49569 .6026 L
s
.4991 .60055 m
.50281 .59824 L
s
.48723 .60753 m
.49132 .60518 L
s
.47358 .61576 m
.46701 .61964 L
s
.46701 .61964 m
.4636 .62169 L
s
.50281 .59824 m
.50435 .59722 L
s
.48532 .60859 m
.48723 .60753 L
s
.48368 .60941 m
.48532 .60859 L
s
.50435 .59722 m
.50494 .59672 L
s
.48423 .60894 m
.48368 .60941 L
s
.50322 .59706 m
.51651 .58973 L
s
.48574 .60793 m
.48423 .60894 L
s
.51807 .58869 m
.51368 .59129 L
s
.52152 .58661 m
.51807 .58869 L
s
.5253 .58427 m
.52152 .58661 L
s
.48947 .60561 m
.48574 .60793 L
s
.52688 .58322 m
.5253 .58427 L
s
.49733 .60093 m
.49292 .60353 L
s
.49292 .60353 m
.48947 .60561 L
s
.52753 .58268 m
.52688 .58322 L
s
.52597 .58345 m
.52753 .58268 L
s
.50609 .59548 m
.50669 .59497 L
s
.50669 .59497 m
.50826 .59393 L
s
.52409 .58449 m
.52597 .58345 L
s
.51997 .58685 m
.52409 .58449 L
s
.50826 .59393 m
.51205 .59158 L
s
.53502 .57729 m
.54817 .57006 L
s
.51553 .58947 m
.51997 .58685 L
s
.51205 .59158 m
.51553 .58947 L
s
.55882 .56337 m
.55438 .566 L
s
.56234 .56125 m
.55882 .56337 L
s
.56753 .55803 m
.56234 .56125 L
s
.54068 .57418 m
.53657 .57653 L
s
.55438 .566 m
.55122 .56783 L
s
.5286 .58129 m
.52476 .58367 L
s
.55122 .56783 m
.54841 .56937 L
s
.53657 .57653 m
.53211 .57917 L
s
.53211 .57917 m
.5286 .58129 L
s
.56921 .55692 m
.56753 .55803 L
s
.55489 .56535 m
.54841 .56937 L
s
.56996 .55631 m
.56921 .55692 L
s
.56942 .55652 m
.56996 .55631 L
s
.56793 .55724 m
.56942 .55652 L
s
.54087 .57352 m
.54026 .57376 L
s
.57022 .55541 m
.58849 .545 L
s
.58083 .54881 m
.58849 .545 L
s
.54026 .57376 m
.54096 .57319 L
s
.56326 .5598 m
.56793 .55724 L
s
.54096 .57319 m
.54261 .57209 L
s
.58083 .54881 m
.59909 .53842 L
s
.59152 .54216 m
.59909 .53842 L
s
.55912 .56217 m
.56326 .5598 L
s
.54261 .57209 m
.54784 .56884 L
s
.55592 .56402 m
.55912 .56217 L
s
.55141 .56669 m
.55592 .56402 L
s
.54784 .56884 m
.55141 .56669 L
s
.60095 .5363 m
.6138 .52927 L
s
.61558 .5281 m
.61107 .53077 L
s
.61919 .52593 m
.61558 .5281 L
s
.62324 .52341 m
.61919 .52593 L
s
.62505 .52222 m
.62324 .52341 L
s
.62595 .52152 m
.62505 .52222 L
s
.62458 .52216 m
.62595 .52152 L
s
.60372 .53479 m
.60458 .53411 L
s
.60458 .53411 m
.60636 .53294 L
s
.62276 .52316 m
.62458 .52216 L
s
.61865 .52551 m
.62276 .52316 L
s
.60636 .53294 m
.61044 .5304 L
s
.63514 .51504 m
.64783 .50813 L
s
.61408 .52821 m
.61865 .52551 L
s
.61044 .5304 m
.61408 .52821 L
s
.64061 .51206 m
.6365 .51441 L
s
.62824 .51934 m
.62411 .5219 L
s
.66217 .49915 m
.66725 .49606 L
s
.6576 .50185 m
.66217 .49915 L
s
.65441 .50369 m
.6576 .50185 L
s
.66725 .49606 m
.67706 .48996 L
s
.6365 .51441 m
.63191 .51712 L
s
.63191 .51712 m
.62824 .51934 L
s
.65032 .50603 m
.65441 .50369 L
s
.64578 .5085 m
.65032 .50603 L
s
.65817 .50023 m
.67706 .48996 L
s
.64444 .50912 m
.64578 .5085 L
s
.64401 .50925 m
.64444 .50912 L
s
.64498 .5085 m
.64401 .50925 L
s
.64828 .50638 m
.64498 .5085 L
s
.65817 .50023 m
.64828 .50638 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00@0oooo0`00001H0?ooo`030000003oool0oooo
01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0N`3oool20000o`@0
oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo
00<000000?ooo`000000J03oool00`000000oooo0?ooo`1h0?ooo`80003o0`3oool3000000D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool2000006T0oooo00<0
00000?ooo`3oool0MP3oool30000o`040?ooo`0000000000000000P0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo07@0oooo0P000?l3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1a
0?ooo`80003o0P00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo06h0oooo00<000000000o`000?l04@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool0
0`000000oooo0?ooo`1Z0?ooo`8000000P000?lC0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^
0?ooo`030000003oool0oooo06H0oooo0`0000000`3oool0003o0000o`0E0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0680oooo0`0000020?ooo`80003o5`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`0000040?ooo`030000o`3oool0oooo
01L0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo100000050?ooo`80003o6P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo
00<000000?ooo`3oool0E@3oool3000000L0oooo0P000?lL0?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?oo
o`1A0?ooo`<000002@3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo04d0oooo0`00000:
0?ooo`80003o7`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?oo
o`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04T0oooo0`00000;0?oo
o`80003o8@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`150?ooo`<0
0000303oool30000ob80oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
103oool00`000000oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0
@@3oool3000000h0oooo0P000?lT0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
5@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3o
ool3000000l0oooo0P000?lV0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool002P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<00000403oool3
0000obL0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000B0?ooo`80003o:@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0
oooo00<000000?ooo`3oool0<@3oool3000001<0oooo0P000?l[0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo
0?ooo`0]0?ooo`<000005@3oool00`000?l0oooo0?ooo`0[0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0Y0?ooo`<000005P3oool20000obh0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000001P0oooo00<0003o
0?ooo`3oool0;P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000001T0oooo0P000?la0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3o
ool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000006`3oool20000oc<0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000
003oool0oooo01P0oooo0`00000L0?ooo`<0003o=@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503o
ool3000001d0oooo0`000?lg0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<000007`3oool3
0000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000P0?ooo`<0003o>P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0203oool300000280oooo0P000?ll0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`040?ooo`<000008`3oool20000och0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000009@3o
ool20000ocl0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`8000009`3oool00`000?l0oooo0?ooo`0o0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo
02@0oooo0P000?m10?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo02<0oooo0P000?lo0?ooo`<000000P3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool08@3oool20000ocd0oooo100000060?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0O0?ooo`<0003o>`3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01d0oooo10000?li
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0703oool30000ocP0oooo0`00000B0?oo
o`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0J0?ooo`<0003o=`3oool3000001H0oooo00<000000?ooo`3o
ool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo01T0oooo0P000?le0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool05`3o
ool30000oc<0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3o
ool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0E0?ooo`<0003o<P3oool3
00000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0;`3oool30000
02H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0
oooo00<000000?ooo`3oool04`3oool20000obl0oooo0`00000Z0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0A0?ooo`80003o;@3oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo
0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0100oooo0P00
0?l/0?ooo`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool03P3oool30000obX0oooo0`00000f
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0=0?ooo`80003o:@3oool3000003X0oooo00<000000?oo
o`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo00/0oooo0P000?lX0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
2@3oool20000obH0oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`080?ooo`80003o903o
ool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00H0oooo0P000?lS0?ooo`<00000BP3oool0
0`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0103oool30000ob40oooo0`00001>0?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo00<0
oooo0`000?lO0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100
oooo000Q0?ooo`800000T03oool010000000oooo0?ooo`3oool20000oah0oooo1000001F0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool01@000000oooo0?ooo`3oool0003o01`0oooo0`00001K0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00@000000000o`000?l0003o6P3oool3000005h0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0
oooo0P000?lI0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0
oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0SP3oool20000oaL0oooo
0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P00
00070?ooo`030000003oool0oooo08/0oooo0`000?l00`3oool000000?ooo`0B0?ooo`@00000JP3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0R`3oool01@000?l0oooo0?ooo`3oool000000100oooo0`00
001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`000005
0?ooo`030000003oool0oooo08X0oooo0P000?l40?ooo`030000003oool0oooo00/0oooo0`00001b
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0Q`3oool30000o`H0oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`250?ooo`80
003o2@3oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0
oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo
0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo
000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?oo
o`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`03
0000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`00
7`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3o
ool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo
03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0
oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?oo
o`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?oo
o`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3o
ool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0
oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0
oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo
00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<0
00000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<00000
0?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`03
0000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3o
ool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0
oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo
0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0
oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo
00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<00000
0?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<0
0000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0
XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3o
ool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0
oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0
oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0
oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?oo
o`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<00000
0?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?oo
o`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?oo
o`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<0
0000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0
ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003o
ool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool0
0`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3o
ool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D00000
0P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool0
8@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000
003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo
00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003o
ool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0
oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`03
0000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`00
3@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0
oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0
P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0
1@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0
oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool01000
0000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0
oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?oo
o`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0
oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0
oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`
0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`04
0?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo
000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo
00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo
00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?oo
o`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo
00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo
001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?oo
o`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<00000
0?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?oo
o`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@0
00000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool0
3`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003o
ool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool0
10000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`00
0000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?oo
o`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?oo
o`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80
000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T
0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?oo
o`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@0
00002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3o
ool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo
03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000
oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo
0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000
000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/
0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?oo
o`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000
003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3o
ool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0
oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3o
ool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03o
ool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3o
ool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2
000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0
oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0
oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo
00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?oo
o`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]
0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?oo
o`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D0
0000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000
P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03o
ool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`00
0000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0
oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?oo
o`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?oo
o`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h
0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?oo
o`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@0
0000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`000000
2`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3o
ool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3o
ool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003o
ool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0
oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo
0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000
d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3o
ool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.38044 .64116 m
.37823 .64217 L
s
.38104 .64103 m
.38044 .64116 L
s
.37823 .64217 m
.37883 .64204 L
s
.37883 .64204 m
.38104 .64103 L
s
.39233 .63645 m
.39737 .63429 L
s
.3893 .6379 m
.39233 .63645 L
s
.39737 .63429 m
.40163 .63256 L
s
.36324 .65051 m
.37476 .64425 L
s
.3885 .63834 m
.3893 .6379 L
s
.40163 .63256 m
.4051 .63127 L
s
.3883 .63864 m
.3885 .63834 L
s
.4051 .63127 m
.40493 .63156 L
s
.39033 .63793 m
.3883 .63864 L
s
.39665 .63549 m
.39033 .63793 L
s
.41796 .62606 m
.41351 .62808 L
s
.42161 .62446 m
.41796 .62606 L
s
.42592 .62271 m
.42161 .62446 L
s
.38283 .64143 m
.38262 .64174 L
s
.3987 .63477 m
.39665 .63549 L
s
.42801 .62198 m
.42592 .62271 L
s
.38262 .64174 m
.38608 .64045 L
s
.39852 .63507 m
.3987 .63477 L
s
.42933 .62167 m
.42801 .62198 L
s
.38608 .64045 m
.39037 .63872 L
s
.39547 .63653 m
.39852 .63507 L
s
.42841 .62238 m
.42933 .62167 L
s
.39037 .63872 m
.39547 .63653 L
s
.43227 .62174 m
.44324 .61569 L
s
.40713 .63158 m
.4084 .63129 L
s
.42684 .62325 m
.42841 .62238 L
s
.44712 .61526 m
.45488 .61097 L
s
.4084 .63129 m
.41049 .63056 L
s
.42301 .62514 m
.42684 .62325 L
s
.41049 .63056 m
.41482 .62881 L
s
.41852 .62719 m
.42301 .62514 L
s
.41482 .62881 m
.41852 .62719 L
s
.45475 .61345 m
.47098 .60443 L
s
.49004 .59833 m
.50579 .58952 L
s
.44624 .61596 m
.44712 .61526 L
s
.48646 .59827 m
.49018 .59665 L
s
.48199 .60032 m
.48646 .59827 L
s
.49018 .59665 m
.49464 .59484 L
s
.47822 .60219 m
.48199 .60032 L
s
.4484 .6152 m
.44624 .61596 L
s
.49464 .59484 m
.49687 .59405 L
s
.45282 .61341 m
.4484 .6152 L
s
.46331 .60869 m
.45655 .61178 L
s
.4767 .60304 m
.47822 .60219 L
s
.4275 .62437 m
.42524 .6254 L
s
.42817 .62421 m
.4275 .62437 L
s
.49687 .59405 m
.49835 .59368 L
s
.42524 .6254 m
.4259 .62525 L
s
.45655 .61178 m
.45282 .61341 L
s
.4259 .62525 m
.42817 .62421 L
s
.47589 .60371 m
.4767 .60304 L
s
.50059 .59405 m
.51106 .58818 L
s
.47733 .60336 m
.47589 .60371 L
s
.51332 .58738 m
.50884 .58943 L
s
.51707 .58574 m
.51332 .58738 L
s
.52159 .58391 m
.51707 .58574 L
s
.52387 .5831 m
.52159 .58391 L
s
.47955 .60258 m
.47733 .60336 L
s
.52542 .5827 m
.52387 .5831 L
s
.48404 .60076 m
.47955 .60258 L
s
.49232 .59705 m
.4878 .59912 L
s
.4878 .59912 m
.48404 .60076 L
s
.52473 .58333 m
.52542 .5827 L
s
.50285 .59278 m
.50437 .5924 L
s
.52325 .58416 m
.52473 .58333 L
s
.5387 .57861 m
.54889 .57283 L
s
.50437 .5924 m
.50664 .5916 L
s
.51951 .58603 m
.52325 .58416 L
s
.50664 .5916 m
.51119 .58976 L
s
.51498 .58811 m
.51951 .58603 L
s
.51119 .58976 m
.51498 .58811 L
s
.56197 .56765 m
.55746 .56971 L
s
.56576 .56599 m
.56197 .56765 L
s
.57192 .56349 m
.56576 .56599 L
s
.55746 .56971 m
.55448 .57115 L
s
.57431 .56264 m
.57192 .56349 L
s
.5431 .57612 m
.53937 .57798 L
s
.55448 .57115 m
.55232 .57238 L
s
.57599 .56219 m
.57431 .56264 L
s
.53103 .58172 m
.52643 .58358 L
s
.53937 .57798 m
.53483 .58006 L
s
.56004 .56925 m
.55232 .57238 L
s
.53483 .58006 m
.53103 .58172 L
s
.57613 .56237 m
.57599 .56219 L
s
.57556 .56296 m
.57613 .56237 L
s
.58068 .5616 m
.59678 .55341 L
s
.59328 .5565 m
.59678 .55341 L
s
.57199 .565 m
.57556 .56296 L
s
.5465 .57569 m
.54658 .5759 L
s
.59328 .5565 m
.60932 .54832 L
s
.60595 .55136 m
.60932 .54832 L
s
.54658 .5759 m
.54822 .57547 L
s
.56827 .56687 m
.57199 .565 L
s
.54822 .57547 m
.5506 .57463 L
s
.61711 .54684 m
.62668 .54128 L
s
.56527 .56833 m
.56827 .56687 L
s
.5506 .57463 m
.55684 .5721 L
s
.62918 .54039 m
.62465 .54246 L
s
.63303 .53871 m
.62918 .54039 L
s
.63781 .53677 m
.63303 .53871 L
s
.56069 .57042 m
.56527 .56833 L
s
.55684 .5721 m
.56069 .57042 L
s
.64033 .53587 m
.63781 .53677 L
s
.64219 .53535 m
.64033 .53587 L
s
.64178 .53587 m
.64219 .53535 L
s
.61918 .54564 m
.621 .54514 L
s
.64043 .53666 m
.64178 .53587 L
s
.65744 .5305 m
.66669 .52505 L
s
.621 .54514 m
.62351 .54424 L
s
.6368 .5385 m
.64043 .53666 L
s
.62351 .54424 m
.62833 .54229 L
s
.63222 .54059 m
.6368 .5385 L
s
.62833 .54229 m
.63222 .54059 L
s
.68389 .5182 m
.68942 .51583 L
s
.67934 .52028 m
.68389 .5182 L
s
.68942 .51583 m
.70088 .51118 L
s
.67641 .52171 m
.67934 .52028 L
s
.66143 .52815 m
.65781 .52998 L
s
.67282 .52353 m
.67641 .52171 L
s
.64931 .53379 m
.64445 .53576 L
s
.65781 .52998 m
.65323 .53208 L
s
.68737 .51923 m
.70088 .51118 L
s
.65323 .53208 m
.64931 .53379 L
s
.66953 .52547 m
.67282 .52353 L
s
.66919 .52598 m
.66953 .52547 L
s
.66951 .5261 m
.66919 .52598 L
s
.67148 .52555 m
.66951 .5261 L
s
.67577 .52393 m
.67148 .52555 L
s
.68737 .51923 m
.67577 .52393 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<000005P3oool20000o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
0680oooo0`00000F0?ooo`@0003o00<0oooo0000003oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`008@3oool2000000H0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1N0?ooo`<0
00005`3oool40000o`<0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0oooo1000000H0?ooo`@0003o
1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0E@3oool3000001X0oooo10000?l70?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000M03oool0
0`000000oooo0?ooo`1A0?ooo`<000006`3oool30000o`X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00:03oool2000007H0oooo00<000000?ooo`3oool0C@3oool30000
01`0oooo0P000?l=0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000001d0
oooo0P000?l?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000D0oooo
00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo04D0oooo
0`00000M0?ooo`<0003o4@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
00040?ooo`030000003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?oo
o`110?ooo`<00000703oool40000oa@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m
0?ooo`<000007@3oool30000oaL0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`00:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo03T0oooo0`00000M0?oo
o`@0003o6@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`03
0000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool3000001h0oooo0`000?lL0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000803oool20000oah0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003o
ool0oooo02d0oooo0`00000P0?ooo`030000o`3oool0oooo0200oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0
oooo02T0oooo0`00000N0?ooo`030000o`3oool0oooo0080003o8`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?oo
o`<000007`3oool20000o`030?ooo`000?l0003o02D0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000Q0?ooo`040000o`3oool0003o0000obL0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0
oooo1000000R0?ooo`80003o;03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603oool300000280oooo
10000?l^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<0
00000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000008`3oool30000oc40oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0100oooo0`00000T0?ooo`@0003o<P3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0303oool3000002D0oooo10000?ld0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<0
00009P3oool20000ocP0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000V0?ooo`<0003o
>P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool00`00000V0?ooo`@0003o?03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000V
0?ooo`030000o`3oool0003o0400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool08`3oool40000od00oooo0P00001K0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool07`3oool50000od00oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0M0?ooo`@0003o
?`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01/0oooo10000?ln0?ooo`<000002P3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool06@3oool40000ocd0oooo0`00000>0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0F0?ooo`<0003o?P3oool300000180oooo00<000000?ooo`3oool0E@3oool00`00
0000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01D0
oooo0`000?ll0?ooo`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180
oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool04P3oool30000oc/0oooo
1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0@0?ooo`030000o`3oool0oooo03X0oooo0`00
000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0=0?ooo`<0003o>P3oool300000280oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo00X0oooo10000?li0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?oo
o`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`090?ooo`<0
003o>03oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo00H0oooo10000?lf0?ooo`@00000
;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool01@3oool20000ocL0oooo0`00000c0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool0
10000000oooo0?ooo`3oool40000ocH0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0000o`02
0000ocH0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool0
0280oooo00<000000?ooo`3oool0S@3oool40000ocD0oooo0`00000n0?ooo`030000003oool0oooo
04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0S03oool30000oc<0
oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo
00<000000?ooo`3oool0R@3oool30000o`80oooo00<000000?ooo`3oool0;P3oool3000004L0oooo
00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`250?ooo`@0003o1@3oool00`000000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08@0oooo0`000?l7
0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0403oool00280oooo0`0000210?ooo`<0003o2P3oool00`000000oooo0?ooo`0U0?oo
o`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000P@3oool20000o`d0oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3o
ool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`1n0?ooo`80003o
3`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`1l0?ooo`80003o4@3o
ool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0N`3o
ool00`000?l0oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000
oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo
000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<00000
0?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3
000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool20000
0940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0
oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<00000
0?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<0
00003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0
RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3o
ool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool0
01h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700
oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?oo
o`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?oo
o`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<0
0000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool0
0`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool0
01d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`00
0000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580
oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo
0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?oo
o`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<00000
0?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<0
0000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0
V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool0
0`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0
oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo
0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W
0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<0
0000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0
Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool0
0`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool0
01T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0
oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo
0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<0
00000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?oo
o`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`000027
0?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3o
ool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000
003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?oo
o`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?oo
o`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool0
0`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<00000
0?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?oo
o`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2
000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;
0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?oo
o`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003o
ool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo
0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3o
ool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool0
0`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool0
03/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo
00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo
00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000
J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
0`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`00
0000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0
oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo
0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P00
00000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`00
0000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0
oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@0
00000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo
0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?oo
o`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo10000003
0?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?oo
o`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000
003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003o
ool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<0
00000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?oo
o`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P000000
0`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool0
0680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo
0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W
0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo10000009
0?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`80
0000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0
oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo
0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0
oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo
001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e
0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?oo
o`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`80
0000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool0
00003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00
J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@0
0000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`03
0000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000
503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool0
0`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool0
0`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`00
0000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740
oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo
1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?oo
o`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k
0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?oo
o`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00
T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003o
ool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool0
0`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440
oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0
oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo
1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00
002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`
0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?oo
o`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`03
0000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00
I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3o
ool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`00
0000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool0
0`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo
00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?oo
o`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@0
0000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.35804 .62222 m
.35582 .62297 L
s
.35904 .62219 m
.35804 .62222 L
s
.35582 .62297 m
.35682 .62294 L
s
.35682 .62294 m
.35904 .62219 L
s
.37743 .61748 m
.38229 .61629 L
s
.37197 .61903 m
.37743 .61748 L
s
.36915 .62014 m
.37197 .61903 L
s
.38229 .61629 m
.38657 .61546 L
s
.36855 .62049 m
.36915 .62014 L
s
.36896 .62082 m
.36855 .62049 L
s
.38657 .61546 m
.38702 .61577 L
s
.34507 .62986 m
.35376 .62474 L
s
.37161 .62038 m
.36896 .62082 L
s
.40509 .61072 m
.40124 .61187 L
s
.40999 .60952 m
.40509 .61072 L
s
.40124 .61187 m
.39681 .61338 L
s
.4127 .60907 m
.40999 .60952 L
s
.37916 .61875 m
.37161 .62038 L
s
.41484 .60897 m
.4127 .60907 L
s
.38183 .61831 m
.37916 .61875 L
s
.3643 .62302 m
.36472 .62335 L
s
.42176 .60964 m
.42969 .60471 L
s
.41476 .60963 m
.41484 .60897 L
s
.38227 .61863 m
.38183 .61831 L
s
.36472 .62335 m
.36901 .62251 L
s
.43733 .60498 m
.44288 .60148 L
s
.37944 .61975 m
.38227 .61863 L
s
.36901 .62251 m
.37392 .62132 L
s
.41362 .61034 m
.41476 .60963 L
s
.37392 .62132 m
.37944 .61975 L
s
.39212 .61623 m
.39422 .61615 L
s
.48719 .59368 m
.4981 .5865 L
s
.41023 .61181 m
.41362 .61034 L
s
.4496 .60438 m
.46111 .59703 L
s
.39422 .61615 m
.39693 .6157 L
s
.40577 .61333 m
.41023 .61181 L
s
.39693 .6157 m
.40188 .61449 L
s
.40188 .61449 m
.40577 .61333 L
s
.48278 .59173 m
.4878 .5905 L
s
.47891 .59289 m
.48278 .59173 L
s
.4745 .5944 m
.47891 .59289 L
s
.4878 .5905 m
.49063 .59003 L
s
.47123 .59584 m
.4745 .5944 L
s
.43731 .60563 m
.43733 .60498 L
s
.49063 .59003 m
.49295 .58989 L
s
.47016 .59653 m
.47123 .59584 L
s
.49907 .59078 m
.50627 .58599 L
s
.44009 .60517 m
.43731 .60563 L
s
.45568 .6005 m
.44901 .60278 L
s
.51301 .58434 m
.50913 .5855 L
s
.51808 .5831 m
.51301 .58434 L
s
.50913 .5855 m
.50474 .58701 L
s
.47023 .59717 m
.47016 .59653 L
s
.52096 .58261 m
.51808 .5831 L
s
.4451 .60395 m
.44009 .60517 L
s
.44901 .60278 m
.4451 .60395 L
s
.52335 .58246 m
.52096 .58261 L
s
.41831 .61179 m
.41606 .61256 L
s
.4194 .61174 m
.41831 .61179 L
s
.47252 .59704 m
.47023 .59717 L
s
.41606 .61256 m
.41716 .61251 L
s
.41716 .61251 m
.4194 .61174 L
s
.52355 .58306 m
.52335 .58246 L
s
.47536 .59657 m
.47252 .59704 L
s
.54184 .58035 m
.54862 .57564 L
s
.48877 .59264 m
.48434 .59416 L
s
.48042 .59533 m
.47536 .59657 L
s
.52255 .58374 m
.52355 .58306 L
s
.48434 .59416 m
.48042 .59533 L
s
.50063 .58975 m
.50299 .58961 L
s
.56743 .57104 m
.56353 .57221 L
s
.57429 .56936 m
.56743 .57104 L
s
.51934 .58518 m
.52255 .58374 L
s
.56353 .57221 m
.55916 .57371 L
s
.57727 .56885 m
.57429 .56936 L
s
.55916 .57371 m
.5565 .5748 L
s
.50299 .58961 m
.50588 .58912 L
s
.51492 .5867 m
.51934 .58518 L
s
.5798 .56867 m
.57727 .56885 L
s
.5565 .5748 m
.55507 .5758 L
s
.50588 .58912 m
.51099 .58787 L
s
.51099 .58787 m
.51492 .5867 L
s
.54477 .57832 m
.54159 .57975 L
s
.58061 .56891 m
.5798 .56867 L
s
.56368 .5737 m
.55507 .5758 L
s
.58864 .56893 m
.60188 .56262 L
s
.60263 .56552 m
.60188 .56262 L
s
.54159 .57975 m
.53717 .58127 L
s
.53325 .58244 m
.5281 .5837 L
s
.58096 .56948 m
.58061 .56891 L
s
.53717 .58127 m
.53325 .58244 L
s
.60263 .56552 m
.61576 .55923 L
s
.61668 .56209 m
.61576 .55923 L
s
.57865 .57115 m
.58096 .56948 L
s
.62902 .55908 m
.63494 .55454 L
s
.64194 .55283 m
.63802 .55401 L
s
.6472 .55154 m
.64194 .55283 L
s
.63802 .55401 m
.63368 .5555 L
s
.55122 .5785 m
.55198 .57876 L
s
.6503 .551 m
.6472 .55154 L
s
.57552 .57258 m
.57865 .57115 L
s
.65301 .55078 m
.6503 .551 L
s
.55198 .57876 m
.55449 .57859 L
s
.57284 .57367 m
.57552 .57258 L
s
.65355 .55131 m
.65301 .55078 L
s
.55449 .57859 m
.55748 .57809 L
s
.56841 .5752 m
.57284 .57367 L
s
.67344 .54824 m
.67892 .54379 L
s
.55748 .57809 m
.56445 .57639 L
s
.56445 .57639 m
.56841 .5752 L
s
.65273 .55195 m
.65355 .55131 L
s
.6303 .5581 m
.63298 .55789 L
s
.64973 .55335 m
.65273 .55195 L
s
.70379 .53771 m
.7163 .53466 L
s
.69807 .53933 m
.70379 .53771 L
s
.69376 .54083 m
.69807 .53933 L
s
.63298 .55789 m
.63609 .55735 L
s
.69122 .54189 m
.69376 .54083 L
s
.64536 .55487 m
.64973 .55335 L
s
.70862 .54125 m
.7163 .53466 L
s
.63609 .55735 m
.6414 .55606 L
s
.68829 .54327 m
.69122 .54189 L
s
.6414 .55606 m
.64536 .55487 L
s
.6758 .54632 m
.67284 .54771 L
s
.68637 .54486 m
.68829 .54327 L
s
.67284 .54771 m
.66848 .54923 L
s
.66451 .55042 m
.65917 .55172 L
s
.66848 .54923 m
.66451 .55042 L
s
.68701 .54538 m
.68637 .54486 L
s
.68804 .54558 m
.68701 .54538 L
s
.69088 .54535 m
.68804 .54558 L
s
.69592 .54434 m
.69088 .54535 L
s
.70862 .54125 m
.69592 .54434 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00@000000?ooo`3oool0oooo0P000?mD0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000
003oool000000240oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<00000
=03oool00`000000oooo0000o`020000oeD0oooo00<000000?ooo`3oool05@3oool000@0oooo1000
000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0?@3oool3000003D0oooo0P00
0?l010000000003o0?ooo`000?mF0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003o
ool0oooo07X0oooo00<000000?ooo`3oool0>@3oool3000003H0oooo0P000?l20?ooo`0300000000
0?l0003o05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool0
0`000000oooo0?ooo`0e0?ooo`<00000=03oool00`000?l0oooo0?ooo`060000o`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`00
0000oooo0?ooo`0a0?ooo`<00000=@3oool20000o`<0oooo0P000?l40?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000
oooo0?ooo`0]0?ooo`<00000=@3oool40000o`X0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo
0`00000_0?ooo`H0003o00<0oooo0000o`000?l03P3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<00000;`3o
ool60000oa@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`@0003o5`3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo
08<0oooo00<000000?ooo`3oool0703oool4000002h0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0J0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0
oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<00000;03oool20000o`80
oooo0P000?l00`3oool0003o0?ooo`0O0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000
;@3oool20000o`80oooo0P000?lT0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000:03o
ool50000o`030?ooo`000?l0003o02X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000X
0?ooo`<0003o0`3oool00`000?l0oooo0?ooo`0/0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?oo
o`<00000:03oool40000o`80oooo0`000?l_0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<0
0000:03oool00`000?l0oooo0?ooo`020000o`040?ooo`000?l0003o0000oc80oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`03
0000003oool0oooo00<00000:@3oool20000o`030?ooo`000?l0003o00<0003o=@3oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo
0P00000T0?ooo`80003o0`3oool40000oc`0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3oool07`3oool60000o`030?ooo`00
0?l0003o03l0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0000o`050000od40oooo0`000002
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0G0?ooo`P0003o@@3oool4000000H0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo01<0oooo1`000?m30?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
4@3oool20000o`030?ooo`000?l0003o0080003o@P3oool3000000h0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo00d0oooo00<0003o0?ooo`3oool010000?m30?ooo`<000004P3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool01P3oool010000?l0oooo0?ooo`3oool30000odL0oooo0`00000F0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`050?ooo`030000o`3oool0003o00<0003oA@3oool4000001X0oooo00<00000
0?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo0080003o0P3oool30000o`030?ooo`000?l0oooo04<0oooo0`00000N0?oo
o`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3o
ool0RP3oool30000o`03000000000?l0003o04X0oooo0`00000R0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0Q`3oool60000o`030?oo
o`000?l0oooo04P0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
4@3oool002<0oooo0P0000270?ooo`030000o`3oool0003o0080003o0P3oool00`000?l000000?oo
o`150?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo07l0oooo10000?l00`3oool0003o0000o`020000o`H0oooo00<00000
0?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A
0?ooo`008`3oool00`000000oooo0?ooo`1k0?ooo`H0003o303oool00`000000oooo0?ooo`0n0?oo
o`<00000<`3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo07H0oooo0`000?l00`3oool0003o0000o`030000o`h0oooo00<000000?ooo`3o
ool0>`3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`00
8`3oool00`000000oooo0?ooo`1f0?ooo`050000o`3oool0oooo0?ooo`000?l04P3oool00`000000
oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo07D0oooo0P000?lG0?ooo`030000003oool0oooo03D0oooo
0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0L`3oool20000oaT0oooo00<000000?ooo`3oool0<@3oool400000480oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo02h0oooo0`0000170?ooo`030000003oool0oooo04`0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0[0?oo
o`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0:03oool3000004h0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0
9@3oool300000580oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3o
ool200000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool06`3oool30000
05h0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000
oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool30000
0680oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000006H0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0A0?ooo`@00000JP3oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?oo
o`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000
003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0
oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<0
00002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0
oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?oo
o`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<0
0000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0
oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo10000011
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<0
0000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0
oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo
0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q
0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000
003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3o
ool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0
oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<0
00000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo10000020
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool4
00000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00
1`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3o
ool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo
0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080
oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003o
ool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool0
0300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`00
0000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0
oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n
0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0
oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool01000
0000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo
0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000
oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo
0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<00000
0?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?oo
o`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?oo
o`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000
003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3o
ool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0
oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool20000
0580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?oo
o`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?oo
o`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P00
00020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?oo
o`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D00000
3@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0
oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo
00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?oo
o`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]
0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?oo
o`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00
M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3o
ool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool0
10000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03o
ool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003o
ool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3o
ool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool0
0840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880
oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo
0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo
0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<0
00000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?oo
o`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3o
ool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3o
ool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool0
0980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0
oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<0
00000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<0
00000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<00000
0?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?oo
o`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3o
ool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000
003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003o
ool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3o
ool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3o
ool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?oo
o`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0
oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo
00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`000000
2P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3o
ool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.3423 .60072 m
.34016 .60121 L
s
.34368 .60083 m
.3423 .60072 L
s
.34016 .60121 m
.34155 .60132 L
s
.34155 .60132 m
.34368 .60083 L
s
.36344 .59841 m
.36874 .59783 L
s
.35779 .59929 m
.36344 .59841 L
s
.36874 .59783 m
.37368 .59755 L
s
.35529 .60009 m
.35779 .59929 L
s
.37368 .59755 m
.37475 .59796 L
s
.35492 .60039 m
.35529 .60009 L
s
.3935 .59513 m
.38962 .59582 L
s
.39881 .59455 m
.3935 .59513 L
s
.40203 .59446 m
.39881 .59455 L
s
.38962 .59582 m
.38539 .5968 L
s
.35596 .6008 m
.35492 .60039 L
s
.48604 .58877 m
.49159 .58259 L
s
.40492 .59467 m
.40203 .59446 L
s
.41563 .59643 m
.42012 .59223 L
s
.33428 .60717 m
.33966 .60284 L
s
.35914 .60072 m
.35596 .6008 L
s
.43127 .59366 m
.43435 .59067 L
s
.40572 .59538 m
.40492 .59467 L
s
.36765 .60006 m
.35914 .60072 L
s
.44776 .59483 m
.45397 .58853 L
s
.37085 .59998 m
.36765 .60006 L
s
.47721 .586 m
.48259 .58541 L
s
.47336 .58668 m
.47721 .586 L
s
.40506 .59598 m
.40572 .59538 L
s
.37192 .60039 m
.37085 .59998 L
s
.48259 .58541 m
.48591 .58531 L
s
.46922 .58766 m
.47336 .58668 L
s
.35234 .60252 m
.35338 .60294 L
s
.48591 .58531 m
.48897 .58551 L
s
.49874 .58739 m
.50233 .58326 L
s
.40227 .59709 m
.40506 .59598 L
s
.46658 .58875 m
.46922 .58766 L
s
.36942 .6012 m
.37192 .60039 L
s
.50952 .58247 m
.50567 .58316 L
s
.51492 .58188 m
.50952 .58247 L
s
.35338 .60294 m
.35835 .60267 L
s
.51828 .58178 m
.51492 .58188 L
s
.38262 .59923 m
.3855 .59945 L
s
.50567 .58316 m
.50157 .58413 L
s
.3637 .60209 m
.36942 .6012 L
s
.52141 .58197 m
.51828 .58178 L
s
.35835 .60267 m
.3637 .60209 L
s
.39802 .59808 m
.40227 .59709 L
s
.46601 .58934 m
.46658 .58875 L
s
.3855 .59945 m
.38873 .59936 L
s
.54429 .58243 m
.54739 .57834 L
s
.43213 .59437 m
.43127 .59366 L
s
.3941 .59878 m
.39802 .59808 L
s
.5225 .58265 m
.52141 .58197 L
s
.38873 .59936 m
.3941 .59878 L
s
.46696 .59004 m
.46601 .58934 L
s
.5673 .57617 m
.56347 .57685 L
s
.57455 .57538 m
.5673 .57617 L
s
.45104 .59151 m
.44474 .593 L
s
.57798 .57527 m
.57455 .57538 L
s
.56347 .57685 m
.55942 .57783 L
s
.58123 .57545 m
.57798 .57527 L
s
.43542 .59428 m
.43213 .59437 L
s
.55942 .57783 m
.55718 .5786 L
s
.52202 .58324 m
.5225 .58265 L
s
.47001 .59025 m
.46696 .59004 L
s
.59379 .57704 m
.60363 .57221 L
s
.60852 .57544 m
.60363 .57221 L
s
.44474 .593 m
.44083 .59369 L
s
.44083 .59369 m
.43542 .59428 L
s
.60852 .57544 m
.61821 .57062 L
s
.62328 .57383 m
.61821 .57062 L
s
.58267 .57583 m
.58123 .57545 L
s
.55718 .5786 m
.55655 .57948 L
s
.51948 .58432 m
.52202 .58324 L
s
.48684 .58788 m
.48268 .58887 L
s
.47335 .59015 m
.47001 .59025 L
s
.49952 .5865 m
.50263 .58669 L
s
.63621 .57242 m
.6383 .56842 L
s
.48268 .58887 m
.47879 .58956 L
s
.58392 .57649 m
.58267 .57583 L
s
.54563 .58067 m
.54314 .58174 L
s
.64562 .56762 m
.64182 .56831 L
s
.65112 .56703 m
.64562 .56762 L
s
.47879 .58956 m
.47335 .59015 L
s
.65465 .56691 m
.65112 .56703 L
s
.64182 .56831 m
.63786 .56927 L
s
.56566 .57848 m
.55655 .57948 L
s
.51535 .58531 m
.51948 .58432 L
s
.41368 .59827 m
.41155 .59877 L
s
.41516 .59838 m
.41368 .59827 L
s
.50263 .58669 m
.50601 .5866 L
s
.65805 .56707 m
.65465 .56691 L
s
.41155 .59877 m
.41303 .59888 L
s
.41303 .59888 m
.41516 .59838 L
s
.51147 .586 m
.51535 .58531 L
s
.54314 .58174 m
.53904 .58273 L
s
.50601 .5866 m
.51147 .586 L
s
.58296 .57795 m
.58392 .57649 L
s
.68259 .56738 m
.68417 .56342 L
s
.6595 .56772 m
.65805 .56707 L
s
.53904 .58273 m
.53516 .58342 L
s
.53516 .58342 m
.52969 .58402 L
s
.70997 .5606 m
.72291 .55919 L
s
.70434 .56149 m
.70997 .5606 L
s
.70045 .56245 m
.70434 .56149 L
s
.72118 .56511 m
.72291 .55919 L
s
.65924 .56829 m
.6595 .56772 L
s
.6984 .56321 m
.70045 .56245 L
s
.58054 .57903 m
.58296 .57795 L
s
.55483 .58183 m
.55624 .58222 L
s
.65699 .56935 m
.65924 .56829 L
s
.69624 .56426 m
.6984 .56321 L
s
.63667 .57156 m
.64006 .57173 L
s
.57831 .57982 m
.58054 .57903 L
s
.55624 .58222 m
.55949 .58241 L
s
.68327 .56567 m
.68108 .56672 L
s
.65301 .57032 m
.65699 .56935 L
s
.69573 .56567 m
.69624 .56426 L
s
.64006 .57173 m
.64362 .57162 L
s
.57422 .58081 m
.57831 .57982 L
s
.55949 .58241 m
.56296 .58231 L
s
.64917 .57101 m
.65301 .57032 L
s
.68108 .56672 m
.67713 .5677 L
s
.64362 .57162 m
.64917 .57101 L
s
.57033 .58151 m
.57422 .58081 L
s
.56296 .58231 m
.57033 .58151 L
s
.67713 .5677 m
.67329 .56839 L
s
.67329 .56839 m
.66772 .569 L
s
.69729 .56633 m
.69573 .56567 L
s
.69895 .56669 m
.69729 .56633 L
s
.7025 .56686 m
.69895 .56669 L
s
.70803 .56654 m
.7025 .56686 L
s
.72118 .56511 m
.70803 .56654 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000000o`000?l010000?mC0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000004`0oooo00<0003o0?ooo`3oool00P3oool30000o`030000003oool0oooo00<0oooo00<0
003o0?ooo`3oool0D@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo01@0oooo0`00001>0?ooo`80003o0`3oool30000o`030?ooo`000000
003o00D0003oE03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0100oooo0`0000110?ooo`T0003o0P3oool60000o`L0oooo00<0003o0000
003oool0F@3oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00`0oooo0`00000g0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0103oool80000oa80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000h0?ooo`80003o
00<0oooo0000o`3oool00P000?l00`3oool0003o0000o`040?ooo`030000o`3oool0oooo01L0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?oo
o`2:0?ooo`030000003oool0oooo00@0oooo0`00000^0?ooo`T0003o0P3oool20000o`@0oooo00<0
003o0?ooo`3oool08@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000[0?ooo`030000o`3oool0
oooo00D0003o103oool20000obd0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000006@3oool00`000?l0oooo0?ooo`040?oo
o`H0003o1@3oool30000o`<0oooo2@000?l_0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo01D0oooo0`000?l40?ooo`<0
003o0P3oool40000o`030?ooo`000?l0003o0080003o?@3oool2000005/0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0@0?ooo`D0003o
00<0oooo0000o`000?l00`3oool60000od<0oooo0`0000020?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool80000odT0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo0`000?mC
0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo0880oooo1`000?l30?ooo`030000o`000000oooo00<0oooo1@000?l00`3o
ool0003o0?ooo`1@0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo07P0oooo1P000?l30?ooo`030000o`3oool0oooo00@0
003o0P3oool30000o`030000003oool0oooo05L0oooo0`00000B0?ooo`030000003oool0oooo05D0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0L03oool20000o`<0oooo
1`000?l30?ooo`D0003o2@3oool00`000000oooo0?ooo`1D0?ooo`<000005P3oool00`000000oooo
0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06l0oooo00<0
003o0?ooo`3oool00P3oool60000oa<0oooo00<000000?ooo`3oool0D03oool4000001X0oooo00<0
00000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1^
0?ooo`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<00000
0?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`1]0?oo
o`030000o`3oool0oooo01d0oooo00<000000?ooo`3oool0BP3oool300000280oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo04L0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo04@0oooo0`00000Z0?ooo`030000
003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3o
ool00`000000oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3
000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0h0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo
00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^
0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3o
ool0403oool00280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003o
ool0oooo0240oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3o
ool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`00
0000oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<0
00000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;
0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo
100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00
002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?oo
o`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3o
ool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000
003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3o
ool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`00
0000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000
oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00
000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?oo
o`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3o
ool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000
003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0
>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000
oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo
00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo
0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00
000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3o
ool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3o
ool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool0
0`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000
oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00
001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O
0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`03
0000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000
003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3o
ool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3o
ool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000
oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo
00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00
001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`03
0000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3o
ool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0
oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`800000
2@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0
/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo
0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000
S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3o
ool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000
103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0
oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`80
0000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000
003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo
000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo
0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`04
0?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000
oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo
0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<00000
0?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?oo
o`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool0
0`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool0
0480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo
0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<0
00000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3o
ool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo
0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?oo
o`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J
0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`02
0?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`80
00003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000
E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0
oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo
0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?oo
o`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?oo
o`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool0
00000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo
0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P000019
0?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`80
00000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00
J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3o
ool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0
oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo
1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c
0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?oo
o`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`80
0000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000
=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03o
ool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool0
10000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3o
ool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2
000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000
oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000
oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo
0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000
001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^
0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?oo
o`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?oo
o`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00
SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2
000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool00000
01T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000
oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000
002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00
002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S
0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?oo
o`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00
I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000
003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003o
ool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool0
10000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3o
ool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo
00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000
oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo
1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3o
ool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03o
ool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03o
ool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03o
ool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.48664 .58381 m
.48656 .57796 L
s
.70801 .58345 m
.72079 .58366 L
s
.72484 .58963 m
.72079 .58366 L
s
.7027 .58364 m
.70801 .58345 L
s
.68469 .58699 m
.68244 .58304 L
s
.64954 .58251 m
.64406 .58242 L
s
.65333 .58285 m
.64954 .58251 L
s
.64406 .58242 m
.64053 .58264 L
s
.63849 .58625 m
.63674 .5823 L
s
.69939 .58414 m
.7027 .58364 L
s
.61074 .58581 m
.61663 .58198 L
s
.62554 .58604 m
.61663 .58198 L
s
.59594 .58557 m
.60199 .58174 L
s
.61074 .58581 m
.60199 .58174 L
s
.5727 .58127 m
.56538 .58116 L
s
.57644 .58161 m
.5727 .58127 L
s
.65727 .58347 m
.65333 .58285 L
s
.56538 .58116 m
.56178 .58137 L
s
.64053 .58264 m
.63711 .58314 L
s
.54595 .58477 m
.54524 .58083 L
s
.51225 .5803 m
.50675 .58021 L
s
.51595 .58064 m
.51225 .5803 L
s
.50675 .58021 m
.50311 .58043 L
s
.49962 .58402 m
.49942 .58009 L
s
.58026 .58223 m
.57644 .58161 L
s
.47925 .57977 m
.48292 .58011 L
s
.47375 .57968 m
.47925 .57977 L
s
.56178 .58137 m
.55824 .58187 L
s
.47007 .5799 m
.47375 .57968 L
s
.69791 .58468 m
.69939 .58414 L
s
.44935 .58521 m
.4499 .5793 L
s
.51967 .58125 m
.51595 .58064 L
s
.42928 .58176 m
.42971 .57897 L
s
.50311 .58043 m
.49946 .58093 L
s
.41426 .58265 m
.41502 .57874 L
s
.65953 .58434 m
.65727 .58347 L
s
.48292 .58011 m
.4866 .58072 L
s
.39298 .57838 m
.38746 .57829 L
s
.39658 .57872 m
.39298 .57838 L
s
.38746 .57829 m
.38371 .57851 L
s
.46637 .5804 m
.47007 .5799 L
s
.36174 .57788 m
.36716 .57824 L
s
.35622 .57779 m
.36174 .57788 L
s
.3506 .57798 m
.35622 .57779 L
s
.33415 .57743 m
.3322 .57768 L
s
.33588 .57774 m
.33415 .57743 L
s
.58226 .58282 m
.58026 .58223 L
s
.40013 .57933 m
.39658 .57872 L
s
.55824 .58187 m
.55652 .5824 L
s
.38371 .57851 m
.37987 .57901 L
s
.36716 .57824 m
.36882 .57883 L
s
.69659 .58549 m
.69791 .58468 L
s
.52161 .58212 m
.51967 .58125 L
s
.34855 .5785 m
.3506 .57798 L
s
.33392 .57799 m
.33588 .57774 L
s
.3322 .57768 m
.33392 .57799 L
s
.46449 .5812 m
.46637 .5804 L
s
.58434 .58369 m
.58226 .58282 L
s
.65981 .5849 m
.65953 .58434 L
s
.40178 .5802 m
.40013 .57933 L
s
.55652 .5824 m
.5567 .58325 L
s
.34844 .57878 m
.34855 .5785 L
s
.69745 .58692 m
.69659 .58549 L
s
.52167 .58268 m
.52161 .58212 L
s
.68372 .58529 m
.68236 .58611 L
s
.35007 .57936 m
.34844 .57878 L
s
.6584 .58572 m
.65981 .5849 L
s
.46446 .58176 m
.46449 .5812 L
s
.58475 .58511 m
.58434 .58369 L
s
.40165 .58075 m
.40178 .5802 L
s
.56592 .58339 m
.5567 .58325 L
s
.54564 .58307 m
.54395 .58389 L
s
.51992 .5835 m
.52167 .58268 L
s
.35366 .5797 m
.35007 .57936 L
s
.46627 .58264 m
.46446 .58176 L
s
.36281 .58013 m
.35366 .5797 L
s
.68236 .58611 m
.67899 .58662 L
s
.33163 .58332 m
.33332 .57938 L
s
.65499 .58623 m
.6584 .58572 L
s
.3996 .58157 m
.40165 .58075 L
s
.63811 .5854 m
.64206 .58603 L
s
.36642 .58047 m
.36281 .58013 L
s
.54395 .58389 m
.54034 .58439 L
s
.36809 .58106 m
.36642 .58047 L
s
.44964 .58209 m
.444 .58285 L
s
.69982 .5878 m
.69745 .58692 L
s
.51627 .58401 m
.51992 .5835 L
s
.43101 .58264 m
.42928 .58176 L
s
.67899 .58662 m
.67545 .58684 L
s
.49957 .58317 m
.50331 .5838 L
s
.65143 .58646 m
.65499 .58623 L
s
.48663 .58296 m
.48293 .58347 L
s
.64206 .58603 m
.64588 .58637 L
s
.46995 .58326 m
.46627 .58264 L
s
.67545 .58684 m
.66991 .58676 L
s
.58315 .58593 m
.58475 .58511 L
s
.64588 .58637 m
.65143 .58646 L
s
.39575 .58207 m
.3996 .58157 L
s
.37921 .58124 m
.38276 .58186 L
s
.54034 .58439 m
.53668 .58462 L
s
.36605 .58159 m
.36809 .58106 L
s
.51259 .58423 m
.51627 .58401 L
s
.34769 .58073 m
.34933 .58133 L
s
.50331 .5838 m
.50703 .58414 L
s
.48293 .58347 m
.47922 .58369 L
s
.47365 .58361 m
.46995 .58326 L
s
.53668 .58462 m
.53113 .58453 L
s
.70203 .58841 m
.69982 .5878 L
s
.444 .58285 m
.44025 .58307 L
s
.43468 .58298 m
.43101 .58264 L
s
.50703 .58414 m
.51259 .58423 L
s
.39197 .58229 m
.39575 .58207 L
s
.47922 .58369 m
.47365 .58361 L
s
.38276 .58186 m
.38639 .5822 L
s
.36037 .58179 m
.36605 .58159 L
s
.44025 .58307 m
.43468 .58298 L
s
.34933 .58133 m
.3548 .5817 L
s
.58145 .58647 m
.58315 .58593 L
s
.38639 .5822 m
.39197 .58229 L
s
.55718 .58551 m
.55916 .58611 L
s
.70609 .58904 m
.70203 .58841 L
s
.3548 .5817 m
.36037 .58179 L
s
.57789 .58699 m
.58145 .58647 L
s
.55916 .58611 m
.56301 .58675 L
s
.71184 .58942 m
.70609 .58904 L
s
.72484 .58963 m
.71184 .58942 L
s
.57425 .58721 m
.57789 .58699 L
s
.56301 .58675 m
.5668 .5871 L
s
.5668 .5871 m
.57425 .58721 L
s
.41393 .58436 m
.41201 .58461 L
s
.41574 .58467 m
.41393 .58436 L
s
.41382 .58493 m
.41574 .58467 L
s
.41201 .58461 m
.41382 .58493 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q0?ooo`<00000C03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo
00<000000?ooo`3oool0703oool400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00
001D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<00000E`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00001M0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`080?ooo`<00000H03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3oool06`3o
ool00`000000oooo0?ooo`040?ooo`<00000H`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`030000003oool0oooo06`0oooo0P000?l40?ooo`P0003o0`3oool:
0000o`@0oooo00<0003o0?ooo`3oool00P0000000`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00@0oooo1`000?l40?ooo`040000o`3oool0oooo0000odT0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0
oooo00<0oooo2@000?l30?ooo`X0003o0`3oool010000?l0oooo0000000000020?ooo`80003o0`3o
ool40000o`@0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo0`000?l00`3oool0003o0000
o`030000o`P0oooo00@0003o0?ooo`3oool0oooo2`000?l60?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0000o`050000oa80oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000006`0oooo00<0003o0?ooo`3oool06`3o
ool30000o`030000003oool0oooo00<0oooo0`000?l20?ooo`030000o`3oool0oooo00D0oooo1`00
0?l40?ooo`T0003o0`3oool60000o`<0oooo1@000?l60?ooo`040000o`3oool0oooo0?ooo`80003o
00<0oooo0000o`000?l00P3oool010000?l0oooo0000o`000?l40?ooo`80003o1P3oool20000o`L0
oooo0P000?l40?ooo`80003o0P0000060000oeD0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0a0?ooo`X0003o2@3oool20000o`@0oooo
00<0003o0?ooo`3oool00P3oool80000o`@0oooo1P000?l30?ooo`<000000P3oool00`000000oooo
0?ooo`020?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`1P0?ooo`@000000`3oool30000o`0300000000
0?l0003o00<0003oE03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo05d0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1J0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0E`3oool300000180oooo00<000000?ooo`3o
ool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000
003oool0oooo05@0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1@0?ooo`@000006P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0C@3oool3000001h0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0A0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
04X0oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool00`000000
oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo
0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo
000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000
003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@00000@P3o
ool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo
02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000
oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo
0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo
000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?
0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?oo
o`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?oo
o`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
0000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0
oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo
00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.6983 .60527 m
.7104 .60699 L
s
.71981 .61371 m
.7104 .60699 L
s
.69354 .60484 m
.6983 .60527 L
s
.69093 .60497 m
.69354 .60484 L
s
.6799 .60621 m
.67403 .6018 L
s
.69005 .60535 m
.69093 .60497 L
s
.68959 .60605 m
.69005 .60535 L
s
.64268 .59733 m
.63744 .59658 L
s
.64657 .59814 m
.64268 .59733 L
s
.63744 .59658 m
.63433 .59639 L
s
.65086 .59926 m
.64657 .59814 L
s
.63585 .59994 m
.63044 .59558 L
s
.63433 .59639 m
.63159 .59651 L
s
.65381 .60044 m
.65086 .59926 L
s
.69174 .60764 m
.68959 .60605 L
s
.60926 .59615 m
.61116 .59283 L
s
.62346 .59818 m
.61116 .59283 L
s
.67737 .60431 m
.67688 .60501 L
s
.65461 .60107 m
.65381 .60044 L
s
.59503 .59413 m
.5971 .59082 L
s
.60926 .59615 m
.5971 .59082 L
s
.65406 .60176 m
.65461 .60107 L
s
.67688 .60501 m
.67421 .60515 L
s
.69479 .60885 m
.69174 .60764 L
s
.56886 .58679 m
.56178 .58578 L
s
.57274 .5876 m
.56886 .58679 L
s
.57696 .58872 m
.57274 .5876 L
s
.56178 .58578 m
.55857 .58558 L
s
.67421 .60515 m
.67112 .60496 L
s
.65135 .60189 m
.65406 .60176 L
s
.48898 .57902 m
.48323 .57279 L
s
.55857 .58558 m
.55567 .58568 L
s
.57942 .58958 m
.57696 .58872 L
s
.69742 .60974 m
.69479 .60885 L
s
.54674 .58725 m
.54227 .583 L
s
.67112 .60496 m
.66584 .60421 L
s
.58223 .59075 m
.57942 .58958 L
s
.63468 .599 m
.639 .60013 L
s
.64822 .6017 m
.65135 .60189 L
s
.55567 .58568 m
.55455 .58603 L
s
.70181 .61089 m
.69742 .60974 L
s
.71981 .61371 m
.70753 .61196 L
s
.639 .60013 m
.64292 .60095 L
s
.64292 .60095 m
.64822 .6017 L
s
.70753 .61196 m
.70181 .61089 L
s
.5102 .57842 m
.50483 .57766 L
s
.51406 .57923 m
.5102 .57842 L
s
.55455 .58603 m
.55553 .58694 L
s
.58398 .59229 m
.58223 .59075 L
s
.50483 .57766 m
.50154 .57744 L
s
.51823 .58034 m
.51406 .57923 L
s
.50167 .58083 m
.49768 .57663 L
s
.50154 .57744 m
.49852 .57753 L
s
.52092 .58149 m
.51823 .58034 L
s
.56444 .58822 m
.55553 .58694 L
s
.47795 .57382 m
.48181 .57463 L
s
.47255 .57305 m
.47795 .57382 L
s
.46922 .57283 m
.47255 .57305 L
s
.48181 .57463 m
.48595 .57573 L
s
.54481 .58542 m
.54398 .58608 L
s
.52152 .5821 m
.52092 .58149 L
s
.58325 .59297 m
.58398 .59229 L
s
.46613 .5729 m
.46922 .57283 L
s
.45436 .57595 m
.44913 .56971 L
s
.52063 .58275 m
.52152 .5821 L
s
.54398 .58608 m
.54103 .58618 L
s
.4651 .57353 m
.46613 .5729 L
s
.58216 .59334 m
.58325 .59297 L
s
.43155 .56979 m
.42924 .56687 L
s
.54103 .58618 m
.53775 .58597 L
s
.51763 .58284 m
.52063 .58275 L
s
.41782 .56889 m
.41473 .5648 L
s
.57928 .59345 m
.58216 .59334 L
s
.46562 .57413 m
.4651 .57353 L
s
.55817 .5894 m
.56063 .59027 L
s
.53775 .58597 m
.53235 .5852 L
s
.5008 .57992 m
.505 .58104 L
s
.51432 .58263 m
.51763 .58284 L
s
.39289 .56168 m
.38742 .5609 L
s
.39674 .56249 m
.39289 .56168 L
s
.46821 .57528 m
.46562 .57413 L
s
.56063 .59027 m
.5649 .59141 L
s
.57604 .59325 m
.57928 .59345 L
s
.38742 .5609 m
.38397 .56066 L
s
.4008 .56359 m
.39674 .56249 L
s
.48815 .57812 m
.48508 .57821 L
s
.505 .58104 m
.5089 .58186 L
s
.5089 .58186 m
.51432 .58263 L
s
.56884 .59223 m
.57604 .59325 L
s
.38397 .56066 m
.3807 .56072 L
s
.5649 .59141 m
.56884 .59223 L
s
.40326 .56472 m
.4008 .56359 L
s
.47237 .5764 m
.46821 .57528 L
s
.36182 .55725 m
.3675 .55832 L
s
.35632 .55646 m
.36182 .55725 L
s
.48508 .57821 m
.48172 .57799 L
s
.3675 .55832 m
.3697 .55915 L
s
.35099 .55596 m
.35632 .55646 L
s
.4516 .57265 m
.44687 .57276 L
s
.47627 .57721 m
.47237 .5764 L
s
.48172 .57799 m
.47627 .57721 L
s
.40368 .5653 m
.40326 .56472 L
s
.34949 .55627 m
.35099 .55596 L
s
.43408 .57094 m
.43155 .56979 L
s
.33428 .55331 m
.33259 .55333 L
s
.33627 .55386 m
.33428 .55331 L
s
.40248 .56591 m
.40368 .5653 L
s
.33459 .55388 m
.33627 .55386 L
s
.33259 .55333 m
.33459 .55388 L
s
.44687 .57276 m
.44346 .57254 L
s
.34966 .55655 m
.34949 .55627 L
s
.35184 .55738 m
.34966 .55655 L
s
.43798 .57176 m
.43408 .57094 L
s
.44346 .57254 m
.43798 .57176 L
s
.39922 .56598 m
.40248 .56591 L
s
.3557 .5582 m
.35184 .55738 L
s
.3651 .5598 m
.3557 .5582 L
s
.36896 .56061 m
.3651 .5598 L
s
.37118 .56146 m
.36896 .56061 L
s
.38224 .56303 m
.38632 .56414 L
s
.39574 .56575 m
.39922 .56598 L
s
.3376 .55934 m
.33537 .5553 L
s
.3697 .56177 m
.37118 .56146 L
s
.38632 .56414 m
.39021 .56496 L
s
.39021 .56496 m
.39574 .56575 L
s
.35084 .55856 m
.35304 .5594 L
s
.36433 .56127 m
.3697 .56177 L
s
.35877 .56048 m
.36433 .56127 L
s
.35304 .5594 m
.35877 .56048 L
s
.41916 .57067 m
.41754 .57071 L
s
.42123 .57123 m
.41916 .57067 L
s
.41961 .57127 m
.42123 .57123 L
s
.41754 .57071 m
.41961 .57127 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo0180oooo00<000000?ooo`3oool0:@3oool3
000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool30000
06`0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<0?ooo`030000003oool0oooo
02D0oooo0`0000190?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`020?ooo`P0003o2@3oool00`000000
oooo0?ooo`0Q0?ooo`<00000C03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo06d0oooo00<0003o0?ooo`3oool00P3oool80000o`<0oooo
0`000?l30?ooo`030000003oool0oooo01`0oooo1000001@0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0N03oool20000o`<0oooo2000
0?lJ0?ooo`<00000E03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`030000003oool0oooo0800oooo1P000?l30?ooo`030000o`3oool0oooo0100oooo0`00001G
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0QP3oool010000000oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool01`3oool3
000005X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`00
0000oooo0?ooo`270?ooo`040000003oool0oooo0?ooo`80003o0`3oool30000o`<0oooo00<0003o
000000000000G@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool50000o`@0oooo20000?mB0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<000001@3oool00`000?l0oooo0?ooo`020?ooo`@0
003o0`3oool010000?l0oooo0?ooo`3oool30000od/0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<0
00004@3oool50000o`<0oooo1`000?m60?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001d0oooo20000?m40?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003o
ool0oooo02L0oooo00@0003o0?ooo`3oool0oooo0P000?l40?ooo`030000o`3oool0oooo03<0oooo
0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<0
00000?ooo`3oool0:03oool60000o`80oooo1`000?l]0?ooo`<000000P3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<00000
0?ooo`3oool0<@3oool20000o`@0oooo10000?l50?ooo`030000o`3oool0oooo01d0oooo10000006
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?oo
o`3oool0S03oool00`000000oooo0?ooo`0c0?ooo`T0003o0`3oool010000?l0oooo0000o`000?l2
0?ooo`030000o`3oool0oooo01D0oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0o0?oo
o`040000o`3oool0oooo0?ooo`80003o00<0oooo0000o`000?l0103oool00`000?l0oooo0?ooo`0;
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0B03oool20000o`80oooo1`000?l40?oo
o`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0CP3oool40000o`030?ooo`000?l000000080
00005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0D03oool400000080003o0`3oool00`000?l0oooo
0?ooo`020000oa00oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04d0oooo0`00000:0?ooo`D0003o0`3o
ool90000o`<0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo04X0oooo0`00000F0?ooo`80003o1P3oool0
1@000?l0oooo0?ooo`3oool0000005D0oooo00<000000?ooo`3oool04@3oool002<0oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000006`3oool60000o`030?ooo`000?l0
oooo0080oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool20000
08l0oooo00<000000?ooo`3oool0A03oool3000002@0oooo0`000?l30?ooo`030000003oool0oooo
0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`100?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140
oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000003<0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0h
0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0=@3oool3000003h0oooo00<000000?oo
o`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo0340oooo100000120?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0^0?ooo`<00000
A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0:`3oool3000004X0oooo00<000000?ooo`3oool0C03o
ool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool0
0280oooo0`00002>0?ooo`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240
oooo1000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<0
00000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?oo
o`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3o
ool03P3oool3000006l0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003o
ool0oooo0900oooo00<000000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00@0oooo1000001j0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool0
0200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?oo
o`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<0
0000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3o
ool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3o
ool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000
oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo
00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo
0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000
000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?oo
o`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303o
ool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000
oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000
000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D
0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?oo
o`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`03
0000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00
703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3o
ool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool0
0`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo
04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000
oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo
0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00
001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L
0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`03
0000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03o
ool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0
oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`00
0000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000
oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00
001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U
0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?oo
o`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`03
0000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3o
ool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003o
ool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0
oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0
oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0
oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0000
0002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool20000
09H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`00
0000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`00
0000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0
oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo
00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo
000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`29
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool0
0`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<00000
0?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool0
0`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool0
01@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000
oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo
00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo
000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?oo
o`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?oo
o`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000
003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03o
ool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`32
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0
a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003o
ool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo
0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00
001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3o
ool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?oo
o`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3o
ool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000
FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
0P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000
003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3o
ool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`00
0000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0
oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580
oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040
oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3o
ool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003o
ool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?oo
o`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000
003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool20000
04@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000
oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?oo
o`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O
0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?oo
o`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000
003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool0
0`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`00
0000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000
oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo
0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo
00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900
oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0
oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo
00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n
0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j
0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?oo
o`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00
R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3o
ool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3o
ool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3o
ool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo
00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<0
00000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`19
0?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?oo
o`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00
V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00
V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03o
ool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2
000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`00
0000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo
02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140
oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo
0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0
oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<0
00000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A
0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?oo
o`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000
oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo
0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080
oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0
oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo
0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.68156 .6252 m
.6925 .62829 L
s
.70668 .63634 m
.6925 .62829 L
s
.67751 .62424 m
.68156 .6252 L
s
.67567 .6241 m
.67751 .62424 L
s
.67541 .62441 m
.67567 .6241 L
s
.66865 .62424 m
.65953 .61897 L
s
.67581 .6251 m
.67541 .62441 L
s
.67911 .627 m
.67581 .6251 L
s
.63097 .61088 m
.62618 .60953 L
s
.63479 .61216 m
.63097 .61088 L
s
.63924 .6138 m
.63479 .61216 L
s
.62618 .60953 m
.62361 .60899 L
s
.66472 .62196 m
.66509 .62265 L
s
.64274 .61536 m
.63924 .6138 L
s
.62855 .61291 m
.61978 .60772 L
s
.62361 .60899 m
.62165 .60882 L
s
.6827 .62859 m
.67911 .627 L
s
.64401 .61611 m
.64274 .61536 L
s
.66509 .62265 m
.66321 .62251 L
s
.64433 .61678 m
.64401 .61611 L
s
.68562 .62981 m
.6827 .62859 L
s
.70668 .63634 m
.69559 .63321 L
s
.60421 .60604 m
.60212 .60272 L
s
.61722 .60971 m
.60212 .60272 L
s
.66321 .62251 m
.66067 .62198 L
s
.69015 .63148 m
.68562 .62981 L
s
.69559 .63321 m
.69015 .63148 L
s
.66067 .62198 m
.65588 .62063 L
s
.64241 .61663 m
.64433 .61678 L
s
.59115 .60235 m
.58921 .59907 L
s
.60421 .60604 m
.58921 .59907 L
s
.63983 .6161 m
.64241 .61663 L
s
.62665 .61179 m
.63114 .61345 L
s
.635 .61473 m
.63983 .6161 L
s
.63114 .61345 m
.635 .61473 L
s
.5632 .59171 m
.55667 .58986 L
s
.56705 .59299 m
.5632 .59171 L
s
.57149 .59464 m
.56705 .59299 L
s
.55667 .58986 m
.55397 .58929 L
s
.57431 .59582 m
.57149 .59464 L
s
.57773 .59737 m
.57431 .59582 L
s
.55397 .58929 m
.55184 .58908 L
s
.54664 .58977 m
.53862 .58475 L
s
.58072 .5992 m
.57773 .59737 L
s
.55184 .58908 m
.55135 .58933 L
s
.55135 .58933 m
.55309 .59041 L
s
.56133 .59274 m
.55309 .59041 L
s
.49299 .57462 m
.48176 .5673 L
s
.58088 .59984 m
.58072 .5992 L
s
.50884 .57633 m
.50384 .57491 L
s
.51271 .57762 m
.50884 .57633 L
s
.51714 .57926 m
.51271 .57762 L
s
.50384 .57491 m
.50105 .57432 L
s
.54318 .58761 m
.54325 .58822 L
s
.52047 .58079 m
.51714 .57926 L
s
.58044 .60011 m
.58088 .59984 L
s
.50481 .57796 m
.49717 .57303 L
s
.50105 .57432 m
.4988 .57407 L
s
.52159 .58151 m
.52047 .58079 L
s
.57835 .59992 m
.58044 .60011 L
s
.54325 .58822 m
.54107 .588 L
s
.5216 .5821 m
.52159 .58151 L
s
.47875 .56782 m
.48264 .56911 L
s
.47371 .56639 m
.47875 .56782 L
s
.57564 .59936 m
.57835 .59992 L
s
.48264 .56911 m
.48706 .57076 L
s
.55776 .59331 m
.5606 .59451 L
s
.54107 .588 m
.53832 .58742 L
s
.47086 .56578 m
.47371 .56639 L
s
.5606 .59451 m
.5651 .59618 L
s
.56902 .59749 m
.57564 .59936 L
s
.53832 .58742 m
.53332 .58601 L
s
.51938 .58187 m
.5216 .5821 L
s
.46853 .56552 m
.47086 .56578 L
s
.5651 .59618 m
.56902 .59749 L
s
.51658 .58128 m
.51938 .58187 L
s
.46841 .56607 m
.46853 .56552 L
s
.46262 .56746 m
.45175 .56018 L
s
.50316 .57689 m
.50762 .57855 L
s
.51154 .57986 m
.51658 .58128 L
s
.50762 .57855 m
.51154 .57986 L
s
.46946 .56677 m
.46841 .56607 L
s
.49136 .57356 m
.48906 .57331 L
s
.43805 .55829 m
.43305 .55488 L
s
.47273 .56829 m
.46946 .56677 L
s
.48906 .57331 m
.48622 .5727 L
s
.42627 .55577 m
.41937 .55101 L
s
.47719 .56996 m
.47273 .56829 L
s
.48622 .5727 m
.48112 .57127 L
s
.48112 .57127 m
.47719 .56996 L
s
.45688 .56362 m
.4533 .56321 L
s
.39874 .54518 m
.39356 .54371 L
s
.40266 .54649 m
.39874 .54518 L
s
.40707 .54813 m
.40266 .54649 L
s
.39356 .54371 m
.39057 .54306 L
s
.41024 .54963 m
.40707 .54813 L
s
.44129 .55981 m
.43805 .55829 L
s
.4533 .56321 m
.45039 .56259 L
s
.39057 .54306 m
.38803 .54275 L
s
.41121 .5503 m
.41024 .54963 L
s
.45039 .56259 m
.44524 .56113 L
s
.44524 .56113 m
.44129 .55981 L
s
.41093 .55083 m
.41121 .5503 L
s
.37494 .53864 m
.3776 .5398 L
s
.36926 .53684 m
.37494 .53864 L
s
.36403 .53536 m
.36926 .53684 L
s
.35924 .5342 m
.36403 .53536 L
s
.40843 .55053 m
.41093 .55083 L
s
.35838 .53436 m
.35924 .5342 L
s
.34301 .52941 m
.34169 .52924 L
s
.34521 .53023 m
.34301 .52941 L
s
.35882 .53469 m
.35838 .53436 L
s
.40543 .54989 m
.40843 .55053 L
s
.34388 .53006 m
.34521 .53023 L
s
.36147 .53584 m
.35882 .53469 L
s
.34169 .52924 m
.34388 .53006 L
s
.39179 .54542 m
.39623 .54708 L
s
.37466 .53997 m
.36544 .53716 L
s
.37862 .54129 m
.37466 .53997 L
s
.4002 .54841 m
.40543 .54989 L
s
.3813 .54246 m
.37862 .54129 L
s
.36544 .53716 m
.36147 .53584 L
s
.39623 .54708 m
.4002 .54841 L
s
.42927 .55784 m
.42803 .5577 L
s
.43151 .55868 m
.42927 .55784 L
s
.38048 .54263 m
.3813 .54246 L
s
.43027 .55854 m
.43151 .55868 L
s
.42803 .5577 m
.43027 .55854 L
s
.37567 .54148 m
.38048 .54263 L
s
.35228 .53632 m
.34607 .53169 L
s
.36197 .53699 m
.36464 .53816 L
s
.37038 .53999 m
.37567 .54148 L
s
.36464 .53816 m
.37038 .53999 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001]0?ooo`030000o`3oool0oooo
00H0oooo00<000000?ooo`3oool0C@3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0K@3oool20000o`L0
oooo00<000000?ooo`3oool0B@3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo06l0oooo
00<0003o0?ooo`3oool00P000?l30?ooo`030000003oool0oooo04D0oooo0`00000a0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3o
ool00`000000oooo0?ooo`1`0?ooo`040000o`3oool0oooo0?ooo`@0003o00<000000?ooo`3oool0
@@3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0M@3oool60000och0oooo0`00000g0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3oool0N03oool4
0000ocX0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`050000oc00oooo0`00000m0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3o
ool0O@3oool00`000000oooo0?ooo`030000o`030?ooo`000?l0oooo02/0oooo0`0000100?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
OP3oool00`000000oooo0?ooo`020?ooo`D0003o9P3oool3000004<0oooo00<000000?ooo`3oool0
F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P000?lO0?ooo`<00000AP3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`09
0?ooo`80003o00<0oooo0000o`3oool05`3oool3000004T0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
00T0oooo1@000?lC0?ooo`<00000C03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool03@3oool30000o`03
0?ooo`000?l0oooo00T0oooo1000001@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0?0?ooo`@0003o
1@3oool3000005@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0140oooo0P000?l00`3oool000000000
00020000oeH0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool0
0`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0P00000010000?l0oooo0?ooo`3o
ool50000oe80oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool0
0`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`0000070?ooo`<0003o00<0oooo
0000o`000?l0D03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000000d0oooo20000?m;0?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0RP3oool00`000000oooo0?ooo`040?ooo`<000005P3oool50000odP0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000
003oool0oooo00<000006`3oool60000odD0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000008P3oool30000od@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0j0?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02P0oooo1@000?lg0?oo
o`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`03
0000003oool0oooo08`0oooo00<000000?ooo`3oool0;@3oool50000obh0oooo100000060?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0a0?ooo`@0003o:03oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo0380oooo1P000?lR0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=@3oool2
0000o`030?ooo`000?l0oooo01d0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0g0?oo
o`<0003o0`3oool20000oaD0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?oo
o`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0m0?ooo`03
0000o`3oool0003o00<0003o3@3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0440oooo
1@000?l70?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0AP3oool40000o`<000008P3o
ool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0A`3oool3000000D0003o8@3oool00`000000oooo0?ooo`1B
0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`140?oo
o`<00000103oool50000ob40oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0400oooo1000000;0?ooo`<0
003o803oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool3000001L0oooo00<0003o0?ooo`3oool0
6@3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool3000001P0oooo1@000?lI0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0h0?ooo`<00000803oool00`000?l0oooo0?ooo`040000oa<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03D0oooo0`00000W0?ooo`030000o`3oool0oooo00<0003o4@3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0<@3oool4000002/0oooo0`000?l20?ooo`80003o403oool00`000000
oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo
00<000000?ooo`3oool0;P3oool300000380oooo1P000?l?0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0[0?ooo`<00000>@3oool30000o`h0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00001>
0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>0?oo
o`030000003oool0oooo02D0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0403oool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000001F0?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3o
ool001L0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3o
ool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01D0oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool40000
06X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo
00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?oo
o`3oool0T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000
oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo
0`0000020?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<00000
0?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?oo
o`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003o
ool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool30000
01/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo
0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo
0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?oo
o`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool30000
03/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0
oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<0
00000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?oo
o`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0
oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool30000
05/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<00000
0?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?oo
o`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool30000
07X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo
00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?oo
o`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3o
ool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<0
00000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H
0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?oo
o`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`05
0000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`80
0000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0
/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03o
ool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3o
ool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0
oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`06
0?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2
000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?oo
o`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?oo
o`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`03
0000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00
;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0
_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03o
ool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3o
ool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo
0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000
oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`00
0000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo
0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000
oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000
J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003o
ool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2
000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo
00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003o
ool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2
000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000
oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo
0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo
0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@0
00000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?oo
o`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`01
0?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`03
0000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3o
ool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000
D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo
000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?oo
o`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<0
00000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0
oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo
0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo
0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<0
00000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?oo
o`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@0
00004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D00000
5P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3o
ool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`00
0000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0
oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo
00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V
0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?oo
o`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@0
0000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`80
0000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool0
00004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00
J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3o
ool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0
Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3o
ool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool0
08@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool0
08D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0
oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@00000
0?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O
0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0
DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3o
ool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool0
09D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0
oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo
0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo
0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00
000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@00000
0?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000
002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>
0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?oo
o`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?oo
o`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`03
0000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<0
00004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<00000
00<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo
100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3o
ool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool0
0:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000
oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?oo
o`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00
ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000
g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.65869 .64251 m
.6681 .64679 L
s
.6863 .65667 m
.6681 .64679 L
s
.65548 .64113 m
.65869 .64251 L
s
.65448 .64083 m
.65548 .64113 L
s
.65482 .64114 m
.65448 .64083 L
s
.6516 .64036 m
.6397 .63388 L
s
.65603 .64191 m
.65482 .64114 L
s
.66032 .64425 m
.65603 .64191 L
s
.64648 .63757 m
.64766 .63834 L
s
.66427 .64628 m
.66032 .64425 L
s
.6863 .65667 m
.6768 .65236 L
s
.61859 .62436 m
.615 .62265 L
s
.62302 .62653 m
.61859 .62436 L
s
.615 .62265 m
.61085 .62076 L
s
.62692 .62853 m
.62302 .62653 L
s
.66737 .64784 m
.66427 .64628 L
s
.64766 .63834 m
.64663 .63803 L
s
.61085 .62076 m
.6089 .61995 L
s
.67184 .65002 m
.66737 .64784 L
s
.6768 .65236 m
.67184 .65002 L
s
.6286 .62945 m
.62692 .62853 L
s
.6089 .61995 m
.60778 .6196 L
s
.61698 .62463 m
.60529 .61824 L
s
.64663 .63803 m
.64473 .63724 L
s
.62975 .6302 m
.6286 .62945 L
s
.64473 .63724 m
.6406 .63536 L
s
.62867 .62987 m
.62975 .6302 L
s
.59587 .61504 m
.58994 .61126 L
s
.60716 .62017 m
.58994 .61126 L
s
.62674 .62907 m
.62867 .62987 L
s
.62256 .62717 m
.62674 .62907 L
s
.58452 .60988 m
.57869 .60614 L
s
.59587 .61504 m
.57869 .60614 L
s
.61445 .62325 m
.61893 .62544 L
s
.61893 .62544 m
.62256 .62717 L
s
.55965 .59756 m
.55599 .59582 L
s
.56411 .59975 m
.55965 .59756 L
s
.55599 .59582 m
.55026 .59322 L
s
.56716 .60129 m
.56411 .59975 L
s
.57103 .60328 m
.56716 .60129 L
s
.55026 .59322 m
.5482 .59235 L
s
.5482 .59235 m
.54692 .59193 L
s
.57513 .60554 m
.57103 .60328 L
s
.54692 .59193 m
.54709 .59216 L
s
.54565 .59222 m
.53444 .58602 L
s
.57617 .60625 m
.57513 .60554 L
s
.54709 .59216 m
.5495 .5935 L
s
.55671 .59677 m
.5495 .5935 L
s
.57639 .60651 m
.57617 .60625 L
s
.57516 .60611 m
.57639 .60651 L
s
.54082 .58955 m
.54178 .59022 L
s
.51195 .57587 m
.50824 .57411 L
s
.51645 .57808 m
.51195 .57587 L
s
.50824 .57411 m
.50383 .57211 L
s
.57311 .60526 m
.57516 .60611 L
s
.52028 .58006 m
.51645 .57808 L
s
.49849 .5708 m
.48223 .56173 L
s
.54178 .59022 m
.54047 .58979 L
s
.50383 .57211 m
.50167 .5712 L
s
.56733 .60264 m
.57311 .60526 L
s
.55599 .59708 m
.55907 .59864 L
s
.52186 .58093 m
.52028 .58006 L
s
.50167 .5712 m
.50028 .57073 L
s
.55907 .59864 m
.56361 .60087 L
s
.50891 .57553 m
.49795 .56943 L
s
.54047 .58979 m
.53836 .58891 L
s
.56361 .60087 m
.56733 .60264 L
s
.52277 .58159 m
.52186 .58093 L
s
.53836 .58891 m
.53397 .58692 L
s
.52142 .58114 m
.52277 .58159 L
s
.4854 .5638 m
.48991 .56602 L
s
.48166 .56202 m
.4854 .5638 L
s
.47719 .55999 m
.48166 .56202 L
s
.47497 .55906 m
.47719 .55999 L
s
.51927 .58024 m
.52142 .58114 L
s
.47351 .55856 m
.47497 .55906 L
s
.51484 .57822 m
.51927 .58024 L
s
.50654 .57421 m
.51108 .57644 L
s
.51108 .57644 m
.51484 .57822 L
s
.47431 .55916 m
.47351 .55856 L
s
.49614 .56948 m
.49472 .569 L
s
.47381 .56016 m
.45771 .55113 L
s
.47585 .56002 m
.47431 .55916 L
s
.49472 .569 m
.49251 .56808 L
s
.47967 .562 m
.47585 .56002 L
s
.49251 .56808 m
.48801 .56603 L
s
.48422 .56423 m
.47967 .562 L
s
.44858 .54779 m
.44106 .54357 L
s
.48801 .56603 m
.48422 .56423 L
s
.46531 .5554 m
.46306 .55462 L
s
.43933 .54392 m
.42886 .53802 L
s
.46306 .55462 m
.46078 .55366 L
s
.45239 .54977 m
.44858 .54779 L
s
.46078 .55366 m
.45621 .55159 L
s
.41424 .53145 m
.41042 .52963 L
s
.41879 .53368 m
.41424 .53145 L
s
.41042 .52963 m
.40578 .52752 L
s
.42255 .53564 m
.41879 .53368 L
s
.45621 .55159 m
.45239 .54977 L
s
.40578 .52752 m
.4034 .52652 L
s
.42403 .53647 m
.42255 .53564 L
s
.4034 .52652 m
.40175 .52594 L
s
.42472 .53703 m
.42403 .53647 L
s
.42311 .53646 m
.42472 .53703 L
s
.38938 .52015 m
.39239 .52168 L
s
.38397 .51761 m
.38938 .52015 L
s
.37926 .51547 m
.38397 .51761 L
s
.37526 .51373 m
.37926 .51547 L
s
.42075 .53547 m
.42311 .53646 L
s
.44388 .54648 m
.4431 .54621 L
s
.44619 .54761 m
.44388 .54648 L
s
.44541 .54734 m
.44619 .54761 L
s
.37511 .51382 m
.37526 .51373 L
s
.41607 .53335 m
.42075 .53547 L
s
.4431 .54621 m
.44541 .54734 L
s
.4076 .52925 m
.41221 .53151 L
s
.41221 .53151 m
.41607 .53335 L
s
.37582 .51423 m
.37511 .51382 L
s
.39517 .52344 m
.3913 .5216 L
s
.3982 .52498 m
.39517 .52344 L
s
.3913 .5216 m
.38271 .51761 L
s
.37883 .51576 m
.37582 .51423 L
s
.36032 .50686 m
.35944 .50654 L
s
.36261 .50798 m
.36032 .50686 L
s
.3981 .5251 m
.3982 .52498 L
s
.36173 .50766 m
.36261 .50798 L
s
.38271 .51761 m
.37883 .51576 L
s
.35944 .50654 m
.36173 .50766 L
s
.3941 .52337 m
.3981 .5251 L
s
.38936 .52121 m
.3941 .52337 L
s
.38085 .51709 m
.38388 .51864 L
s
.37532 .51543 m
.36527 .50968 L
s
.38388 .51864 m
.38936 .52121 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`030?oo
o`80003oJ@3oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool00`3oool20000ofD0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo00@0oooo0P000?mP0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`050?ooo`<0003oFP3oool3000001/0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`070?ooo`80003oE@3oool3000001h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo00L0oooo0`000?m?0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool02@3o
ool20000odX0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0:0?ooo`030000o`3oool0
003o04@0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo0P00001f0?ooo`030000003oool0oooo00`0oooo0P000?lo0?ooo`<00000:`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo00`0oooo0`000?lj0?ooo`<00000;P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0>0?ooo`80003o=@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool03P3oool30000oc00oooo0`00
000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0Y
0?ooo`<00000=`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?oo
o`030000003oool0oooo07X0oooo00<000000?ooo`3oool04@3oool20000obH0oooo0`00000j0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`0B0?ooo`<0003o803oool3000003d0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000
003oool0oooo01<0oooo0`000?lK0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool05@3o
ool20000oaH0oooo0`0000130?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503o
ool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0F0?ooo`80003o4@3oool3
000004H0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool30000
0840oooo00<000000?ooo`3oool05P3oool30000o``0oooo0`0000190?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000
oooo0?ooo`0H0?ooo`<0003o1P3oool3000004`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01T0oooo
0`000?l400000500oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0P0000040000oe40oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`25
0?ooo`030000003oool0oooo01@0oooo0`0000040?ooo`@0003oC`3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0403oool3000000X0oooo10000?m<0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<0
00003`3oool40000odX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000E0?ooo`80003o
B@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0103oool3000001X0oooo0P000?m70?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool0
0`000000oooo0?ooo`03000001h0oooo10000?m40?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000002@0oooo0P000?m30?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`03
0000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool0:03oool00`000?l0oooo0?ooo`0i0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool0:@3oool30000oc@0oooo100000060?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0[0?ooo`@0003o;P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02l0oooo0P000?lY0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<03oool30000ob@0
oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?ooo`<0003o7`3oool3000001H0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03@0oooo0`000?lI0?ooo`@000006P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0=P3oool40000oa<0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0j0?oo
o`80003o3P3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo0`000?l90?ooo`<0
00009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000
S`3oool00`000000oooo0?ooo`0n0?ooo`80003o103oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo0400oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0n0?ooo`<000000P3oool3
0000obh0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0oooo0`0000070?ooo`<0003o;03oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0>03oool3000000`0oooo0`000?l[0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0e0?ooo`<000004P3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0a0?ooo`@000005P3oool30000obT0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`000017
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000008P3oool20000obH0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02P0oooo0`00000W0?ooo`80003o9@3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000
;03oool30000ob<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3o
ool200000900oooo00<000000?ooo`3oool08@3oool400000380oooo0`000?lQ0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`0N0?ooo`<00000>03oool30000ob00oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0K0?ooo`<00000?@3oool30000oah0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool300000440oooo10000?lM0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`0000170?ooo`<0003o703oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001<0?ooo`80003o703oool00`000000oooo
0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?oo
o`<00000MP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`03
0000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000007X0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000
003oool0oooo0?ooo`<00000O`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0
oooo000P0?ooo`800000T@3oool4000008<0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool200000900oooo0`0000260?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<00000
0?ooo`3oool0Q@3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?oo
o`030000003oool0oooo08P0oooo100000050?ooo`030000003oool0oooo08H0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<0
00002@3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3000000`0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003o
ool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0?P3o
ool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?ooo`<000004@3oool0
0`000000oooo0?ooo`2:0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool0
01l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<000000?ooo`3oool0R`3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0
oooo0`00000H0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0?03oool00`000000
oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1c0?ooo`<000006`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<0
00000?ooo`3oool0L03oool3000001h0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0k0?ooo`030000003oool0oooo00`0oooo000M0?ooo`<00000KP3oool300000240oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00`0oooo000N0?oo
o`030000003oool0oooo06T0oooo1000000T0?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0>P3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1V0?ooo`<0
0000:03oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0303oool001d0oooo00<000000?ooo`3oool0I03oool3000002/0oooo00<000000?ooo`3oool0
T@3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003o
ool0oooo0640oooo0`00000^0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1N0?ooo`<00000<@3oool0
0`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool0
01d0oooo00<000000?ooo`3oool0FP3oool4000003@0oooo00<000000?ooo`3oool0T`3oool00`00
0000oooo0?ooo`0f0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05L0
oooo0`00000h0?ooo`030000003oool0oooo09@0oooo00<000000?ooo`3oool0=P3oool00`000000
oooo0?ooo`0;0?ooo`007@3oool00`000000oooo0?ooo`1D0?ooo`<00000>`3oool00`000000oooo
0?ooo`2E0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0DP3oool3000003h0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?oo
o`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04h0oooo10000011
0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;
0?ooo`00703oool00`000000oooo0?ooo`1;0?ooo`<00000A@3oool00`000000oooo0?ooo`2G0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool02`3oool001`0oooo0P0000190?ooo`<0
0000B03oool00`000000oooo0?ooo`2H0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0A@3oool3000004/0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0480oooo0`00001>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0<@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0o0?ooo`@00000D@3oool0
0`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0?03oool3000005D0oooo00<000000?ooo`3oool0V`3oool00`00
0000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03T0
oooo0`00001H0?ooo`030000003oool0oooo09`0oooo00<000000?ooo`3oool0;`3oool00`000000
oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0f0?ooo`<00000F`3oool00`000000oooo
0?ooo`2M0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02P3oool001/0oooo00<0
00000?ooo`3oool0<`3oool3000005h0oooo00<000000?ooo`3oool0WP3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02l0oooo1000001Q
0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0/0?ooo`<00000I@3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool0:P3oool3000006L0oooo00<000000?ooo`3oool0X@3oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02L0oooo0`00001Z0?ooo`030000
003oool0oooo0:80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`090?ooo`006P3o
ool2000002D0oooo0`00001]0?ooo`030000003oool0oooo0:<0oooo00<000000?ooo`3oool0:P3o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`@00000L03oool0
0`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool0
01X0oooo00<000000?ooo`3oool07@3oool3000007@0oooo00<000000?ooo`3oool0Y03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01X0
oooo0`00001g0?ooo`030000003oool0oooo0:D0oooo00<000000?ooo`3oool0:03oool00`000000
oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0H0?ooo`<00000NP3oool00`000000oooo
0?ooo`2V0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool001T0oooo00<0
00000?ooo`3oool05@3oool3000007d0oooo00<000000?ooo`3oool0Y`3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo0140oooo10000020
0?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`08
0?ooo`006@3oool00`000000oooo0?ooo`0>0?ooo`<00000Q03oool00`000000oooo0?ooo`2X0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3o
ool02`3oool3000008L0oooo00<000000?ooo`3oool0Z@3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00P0oooo0`00002:0?ooo`030000
003oool0oooo0:X0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`080?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`<00000S@3oool00`000000oooo0?ooo`2[0?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool00P3oool4
00000900oooo00<000000?ooo`3oool0[03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00P0oooo000H0?ooo`030000003oool0000000800000U03oool00`000000oooo0?ooo`2]0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool001P0oooo0P00002G0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00
1`3oool500000080oooo0P0000090?ooo`800000UP3oool00`000000oooo0?ooo`2^0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0T`3oool00`000000oooo
0?ooo`2_0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool01`3oool000T0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
TP3oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P00002B0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool07P3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
303oool00`000000oooo0000002?0?ooo`030000003oool0oooo0;40oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`070?ooo`00203oool2000000@0oooo0P00000@0?ooo`800000S`3o
ool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool01`3o
ool00280oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`2c0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool01P3oool002<0oooo0P00002<0?ooo`030000003oool0oooo
0;@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`060?ooo`004`3oool500000080
oooo0P0000090?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3oool0]@3oool00`000000
oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3o
ool0]@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`80000000<0oooo0000003o
ool0Q03oool00`000000oooo0?ooo`2g0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01P3oool000d0oooo100000040?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0:0?ooo`800000Q@3oool00`000000oooo0?ooo`2h0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00/0oooo0P0000240?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`060?ooo`00503oool2000000@0oooo0P00000@0?ooo`030000
003oool0oooo0840oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00D0oooo000]0?ooo`030000003oool0oooo0800oooo00<000000?ooo`3oool0^P3o
ool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00D0oooo000^0?ooo`800000P03oool0
0`000000oooo0?ooo`2k0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool01@3oool0
0300oooo00@000000?ooo`3oool00000O03oool00`000000oooo0?ooo`2l0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool01@3oool00340oooo0`00001l0?ooo`030000003oool0oooo
0;d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`00<`3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`050?ooo`00=03oool2000007X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000f0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0_`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo000g
0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0`03oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo00@0oooo000h0?ooo`80000000<0oooo0000003oool0L`3oool00`00
0000oooo0?ooo`310?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0103oool003X0
oooo0P00001d0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`040?ooo`00>`3oool2000007<0oooo00<000000?ooo`3oool0``3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000m0?ooo`030000003oool0oooo0700oooo00<0
00000?ooo`3oool0``3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00@0oooo000n
0?ooo`800000L03oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool0103oool00400oooo00D000000?ooo`3oool0oooo0000001[0?ooo`030000003oool0
oooo0<D0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`00@@3oool01000
0000oooo0?ooo`00001[0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`030?ooo`00@P3oool2000006`0oooo00<000000?ooo`3oool0a`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00130?ooo`800000J`3oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004D0oooo
0P00001Y0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`030?ooo`00A`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0<T0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`030?ooo`00B03oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`03
0?ooo`00B@3oool2000000030?ooo`000000oooo0680oooo00<000000?ooo`3oool0b`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo001;0?ooo`800000H`3oool00`000000
oooo0?ooo`3;0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool004`0oooo
0P00001R0?ooo`030000003oool0oooo0<`0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`020?ooo`00CP3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0<h0oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`00C`3oool2000005h0oooo00<00000
0?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0080oooo00140?oo
o`8000002`3oool010000000oooo0?ooo`00001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00@`3oool010000000oooo0?ooo`00000;
0?ooo`030000003oool0000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0080oooo00160?ooo`030000003oool0oooo00X0oooo0P00001J0?oo
o`030000003oool0oooo0=40oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?oo
o`00?@3oool4000000<0oooo0P00000?0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3o
ool0dP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0040oooo00140?ooo`030000
003oool0oooo00l0oooo0P00001G0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`010?ooo`00A03oool300000140oooo00<000000?ooo`3oool0E03o
ool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00@3o
ool005T0oooo00@000000?ooo`3oool00000DP3oool00`000000oooo0?ooo`3E0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool00@3oool005X0oooo0P00001C0?ooo`030000003oool0
oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00F`3oool20000
0580oooo00<000000?ooo`3oool0eP3oool01@000000oooo0?ooo`3oool0000000<0oooo001M0?oo
o`800000D03oool00`000000oooo0?ooo`3G0?ooo`040000003oool0oooo000000<0oooo001O0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0f03oool00`000000oooo000000030?oo
o`00H03oool2000000030?ooo`000000oooo04X0oooo00<000000?ooo`3oool0f@3oool00`000000
oooo000000020?ooo`00HP3oool2000004/0oooo00<000000?ooo`3oool0f@3oool00`000000oooo
000000020?ooo`00H`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo0=X0oooo0P00
00020?ooo`00I03oool2000004T0oooo00<000000?ooo`3oool0f@3oool300000080oooo001V0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3E0?oo
o`@000001@3oool006L0oooo0P0000020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool0d@3oool4000000T0oooo001Y0?ooo`800000A03oool00`000000oooo0?ooo`3<0?ooo`D00000
3@3oool006X0oooo0P0000130?ooo`030000003oool0oooo0<P0oooo1000000B0?ooo`00K03oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo0<<0oooo1@00000F0?ooo`00K@3oool00`00
0000oooo0?ooo`0o0?ooo`030000003oool0oooo0;l0oooo1000000K0?ooo`00KP3oool2000003l0
oooo00<000000?ooo`3oool0^`3oool4000001l0oooo001`0?ooo`030000003oool0000003`0oooo
00<000000?ooo`3oool0]P3oool5000002<0oooo001a0?ooo`800000?03oool00`000000oooo0?oo
o`2b0?ooo`@00000:03oool007<0oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`2]
0?ooo`D00000;03oool007@0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`2Z0?oo
o`@00000<@3oool007D0oooo0P00000g0?ooo`030000003oool0oooo0:H0oooo1000000e0?ooo`00
M`3oool00`000000oooo0000000d0?ooo`030000003oool0oooo0:40oooo1@00000i0?ooo`00J@3o
ool2000000d0oooo0P00000d0?ooo`030000003oool0oooo09d0oooo1000000n0?ooo`00J03oool0
10000000oooo0?ooo`00000>0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool0V03o
ool500000480oooo001X0?ooo`040000003oool0oooo000000l0oooo0P00000a0?ooo`030000003o
ool0oooo09@0oooo100000170?ooo`00J03oool010000000oooo0?ooo`00000A0?ooo`030000003o
ool0oooo02h0oooo00<000000?ooo`3oool0T03oool4000004/0oooo001X0?ooo`040000003oool0
oooo00000180oooo00<000000?ooo`000000;@3oool00`000000oooo0?ooo`2;0?ooo`D00000C`3o
ool006T0oooo0P00000D0?ooo`800000;@3oool00`000000oooo0?ooo`270?ooo`@00000E03oool0
0840oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`220?ooo`D00000F03oool00880
oooo0P00000Z0?ooo`030000003oool0oooo07h0oooo1000001M0?ooo`00Q03oool010000000oooo
0?ooo`00000V0?ooo`030000003oool0oooo07X0oooo1000001Q0?ooo`00Q@3oool00`000000oooo
0000000V0?ooo`030000003oool0oooo07D0oooo1@00001U0?ooo`00QP3oool2000002H0oooo00<0
00000?ooo`3oool0L@3oool4000006X0oooo00280?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool0K@3oool4000006h0oooo00290?ooo`8000000`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo06P0oooo1@00001b0?ooo`00R`3oool010000000oooo0?ooo`00000O0?oo
o`030000003oool0oooo06@0oooo1000001g0?ooo`00S03oool3000001l0oooo00<000000?ooo`3o
ool0G`3oool5000007/0oooo002>0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
F`3oool400000800oooo002?0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0E`3o
ool4000008@0oooo002@0?ooo`800000703oool00`000000oooo0?ooo`1B0?ooo`D00000R03oool0
0980oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`1>0?ooo`@00000S@3oool009<0
oooo0P00000I0?ooo`030000003oool0oooo04T0oooo1@00002A0?ooo`00U@3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo04D0oooo1000002F0?ooo`00UP3oool2000001H0oooo00<0
00000?ooo`3oool0@@3oool4000009X0oooo002H0?ooo`040000003oool0oooo00000180oooo00<0
00000?ooo`3oool0?03oool5000009h0oooo002I0?ooo`030000003oool000000180oooo00<00000
0?ooo`3oool0>03oool400000:<0oooo002<0?ooo`800000303oool200000140oooo00<000000?oo
o`3oool0=03oool500000:L0oooo001U0?ooo`800000903oool010000000oooo0?ooo`00000=0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<03oool400000:`0oooo001V0?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool0303oool2000000h0oooo00<000000?ooo`3o
ool0;03oool400000;00oooo001W0?ooo`030000003oool0oooo0280oooo0P00000A0?ooo`030000
003oool0000000/0oooo00<000000?ooo`3oool09`3oool500000;@0oooo001V0?ooo`030000003o
ool0000002<0oooo00<000000?ooo`3oool04@3oool2000000/0oooo00<000000?ooo`3oool08`3o
ool400000;T0oooo001U0?ooo`040000003oool0oooo000002<0oooo0`00000B0?ooo`8000002P3o
ool00`000000oooo0?ooo`0N0?ooo`D00000_@3oool006@0oooo0`0000000`3oool000000000000i
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool06P3oool400000<80oooo002T0?oo
o`80000000<0oooo0000003oool0103oool00`000000oooo0?ooo`0F0?ooo`@00000aP3oool00:H0
oooo0P0000050?ooo`030000003oool0oooo0140oooo1@00003:0?ooo`00Y`3oool2000000@0oooo
00<000000?ooo`3oool03@3oool400000<l0oooo002Y0?ooo`050000003oool0oooo0?ooo`000000
2P3oool500000=<0oooo002Z0?ooo`040000003oool0oooo000000H0oooo1000003H0?ooo`00Z`3o
ool300000080oooo1000003L0?ooo`00[@3oool300000>00oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40oooo003o0?oooi40
oooo003o0?oooi40oooo002X0?ooo`D000000P3oool200000=l0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00Z@3oool2000000@0oooo0P00003O0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.63076 .65663 m
.63833 .66187 L
s
.65973 .67399 m
.63833 .66187 L
s
.6285 .65494 m
.63076 .65663 L
s
.62834 .65456 m
.6285 .65494 L
s
.62926 .65495 m
.62834 .65456 L
s
.6312 .6559 m
.62926 .65495 L
s
.62961 .65401 m
.61546 .64603 L
s
.63629 .65877 m
.6312 .6559 L
s
.65973 .67399 m
.65213 .66871 L
s
.64044 .66126 m
.63629 .65877 L
s
.62352 .65057 m
.62546 .65152 L
s
.64359 .66318 m
.64044 .66126 L
s
.65213 .66871 m
.64783 .66586 L
s
.64783 .66586 m
.64359 .66318 L
s
.62546 .65152 m
.62528 .65114 L
s
.59873 .6343 m
.59549 .63219 L
s
.60296 .63698 m
.59873 .6343 L
s
.60709 .63945 m
.60296 .63698 L
s
.59549 .63219 m
.59213 .62986 L
s
.62528 .65114 m
.62409 .65018 L
s
.60911 .64058 m
.60709 .63945 L
s
.59213 .62986 m
.59088 .62886 L
s
.62409 .65018 m
.62076 .64787 L
s
.61103 .64152 m
.60911 .64058 L
s
.59088 .62886 m
.59063 .62843 L
s
.60171 .63466 m
.58763 .62674 L
s
.61082 .64111 m
.61103 .64152 L
s
.60959 .64012 m
.61082 .64111 L
s
.60622 .63778 m
.60959 .64012 L
s
.58464 .62282 m
.57517 .61811 L
s
.59378 .62915 m
.57517 .61811 L
s
.60295 .63565 m
.60622 .63778 L
s
.59867 .63295 m
.60295 .63565 L
s
.57544 .61643 m
.56603 .61177 L
s
.58464 .62282 m
.56603 .61177 L
s
.55084 .60112 m
.54752 .59895 L
s
.55515 .60384 m
.55084 .60112 L
s
.5583 .60576 m
.55515 .60384 L
s
.54752 .59895 m
.54285 .59571 L
s
.56246 .60824 m
.5583 .60576 L
s
.54285 .59571 m
.5415 .59464 L
s
.56748 .61104 m
.56246 .60824 L
s
.5415 .59464 m
.54113 .59412 L
s
.56934 .61193 m
.56748 .61104 L
s
.54113 .59412 m
.54194 .59441 L
s
.55079 .60015 m
.54492 .59607 L
s
.54382 .5945 m
.52991 .58675 L
s
.54194 .59441 m
.54492 .59607 L
s
.5702 .61225 m
.56934 .61193 L
s
.56989 .61177 m
.5702 .61225 L
s
.56857 .61071 m
.56989 .61177 L
s
.53783 .59116 m
.53964 .592 L
s
.56388 .60745 m
.56857 .61071 L
s
.55293 .60055 m
.55613 .60249 L
s
.53964 .592 m
.53926 .59147 L
s
.56051 .60525 m
.56388 .60745 L
s
.55613 .60249 m
.56051 .60525 L
s
.51181 .57407 m
.50843 .57186 L
s
.51618 .57683 m
.51181 .57407 L
s
.52034 .57931 m
.51618 .57683 L
s
.50843 .57186 m
.50481 .56935 L
s
.53926 .59147 m
.53788 .59037 L
s
.52233 .58041 m
.52034 .57931 L
s
.50481 .56935 m
.50337 .56822 L
s
.53788 .59037 m
.53429 .58789 L
s
.50524 .56773 m
.48465 .55633 L
s
.5241 .58123 m
.52233 .58041 L
s
.50337 .56822 m
.50291 .56763 L
s
.51379 .57366 m
.49997 .566 L
s
.52369 .58067 m
.5241 .58123 L
s
.52227 .57955 m
.52369 .58067 L
s
.48998 .55894 m
.49438 .56172 L
s
.48655 .5567 m
.48998 .55894 L
s
.51864 .57703 m
.52227 .57955 L
s
.48287 .55415 m
.48655 .5567 L
s
.51522 .5748 m
.51864 .57703 L
s
.48138 .55298 m
.48287 .55415 L
s
.5108 .57201 m
.51522 .5748 L
s
.48087 .55235 m
.48138 .55298 L
s
.50226 .56608 m
.50179 .56548 L
s
.48256 .55312 m
.48087 .55235 L
s
.50179 .56548 m
.50033 .56433 L
s
.48453 .5542 m
.48256 .55312 L
s
.48743 .55439 m
.46678 .543 L
s
.50033 .56433 m
.49663 .56176 L
s
.48872 .55669 m
.48453 .5542 L
s
.49663 .56176 m
.49317 .5595 L
s
.49317 .5595 m
.48872 .55669 L
s
.46272 .5388 m
.453 .53345 L
s
.47654 .54838 m
.47574 .54741 L
s
.45649 .53391 m
.44287 .52644 L
s
.47574 .54741 m
.47421 .54621 L
s
.47421 .54621 m
.47044 .54359 L
s
.46693 .5413 m
.46272 .5388 L
s
.47044 .54359 m
.46693 .5413 L
s
.43107 .51812 m
.42754 .51581 L
s
.43556 .52095 m
.43107 .51812 L
s
.43974 .52343 m
.43556 .52095 L
s
.42754 .51581 m
.42367 .51313 L
s
.44168 .52449 m
.43974 .52343 L
s
.42367 .51313 m
.42205 .51187 L
s
.44332 .5252 m
.44168 .52449 L
s
.42205 .51187 m
.42138 .51112 L
s
.4427 .52449 m
.44332 .5252 L
s
.4624 .53716 m
.46212 .53682 L
s
.46467 .53859 m
.4624 .53716 L
s
.46439 .53825 m
.46467 .53859 L
s
.44109 .52323 m
.4427 .52449 L
s
.41035 .50376 m
.41357 .50571 L
s
.40548 .50052 m
.41035 .50376 L
s
.46212 .53682 m
.46439 .53825 L
s
.40155 .4978 m
.40548 .50052 L
s
.43722 .52054 m
.44109 .52323 L
s
.39855 .49558 m
.40155 .4978 L
s
.43365 .51821 m
.43722 .52054 L
s
.4291 .51535 m
.43365 .51821 L
s
.39914 .49571 m
.39855 .49558 L
s
.41804 .50796 m
.41446 .50562 L
s
.42128 .50992 m
.41804 .50796 L
s
.41446 .50562 m
.40693 .50054 L
s
.42192 .51007 m
.42128 .50992 L
s
.4001 .49623 m
.39914 .49571 L
s
.40333 .49819 m
.4001 .49623 L
s
.40693 .50054 m
.40333 .49819 L
s
.41895 .50787 m
.42192 .51007 L
s
.38569 .48681 m
.38531 .48641 L
s
.38797 .48825 m
.38569 .48681 L
s
.38759 .48784 m
.38797 .48825 L
s
.38531 .48641 m
.38759 .48784 L
s
.415 .50513 m
.41895 .50787 L
s
.41007 .50186 m
.415 .50513 L
s
.40682 .49989 m
.41007 .50186 L
s
.40587 .49778 m
.39236 .49043 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool0L`3oool010000000oooo0?ooo`3o
ool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0C0?ooo`030000o`3oool0oooo0780oooo1000001E0?ooo`030000003oool0
oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0503oool00`00
0?l0oooo0?ooo`1^0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo01@0oooo0P000?m[0?ooo`<000000P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo
00<000000?ooo`3oool0503oool30000ofH0oooo0`0000050?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo01D0oooo0`00
0?mR0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool05P3oool30000oed0oooo0`00000;
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?oo
o`030000003oool0oooo06X0oooo00<000000?ooo`3oool05P3oool40000oeP0oooo0`00000>0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00200oooo00@000000?ooo`3o
ool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo01L0oooo00<0003o0?oo
o`000?l0E03oool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?oo
o`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool05`3oool30000oe00oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?oo
o`030000003oool0oooo01P0oooo0P000?m<0?ooo`<00000603oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?oo
o`3oool0K`3oool00`000000oooo0?ooo`0I0?ooo`80003oA`3oool3000001/0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`0I0?ooo`<0003o@P3oool3000001h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo01X0oooo0P000?lm0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool06P3o
ool20000ocT0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`0K0?ooo`030000o`3oool0
oooo03<0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo0P00001f0?ooo`030000003oool0oooo01/0oooo0P000?l`0?ooo`<00000:`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000
oooo0?ooo`1f0?ooo`030000003oool0oooo01`0oooo0P000?l[0?ooo`<00000;P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0L0?ooo`80003o9`3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0703oool30000ob80oooo0`00
000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool07@3oool20000oah0oooo0`00000g
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`0M0?ooo`80003o6P3oool3000003X0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo01d0oooo0P000?lF0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0
7@3oool30000oa40oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0N0?ooo`80003o3@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo01l0oooo0P000?l80?ooo`<00000AP3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`00
0000oooo0?ooo`0O0?ooo`<0003o0`3oool3000004T0oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo01l0
oooo0P000?l3000004`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo0`0000030000odh0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?oo
o`240?ooo`030000003oool0oooo01P0oooo0`0000050?ooo`80003oC@3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool0503oool3000000X0oooo0P000?m;0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?oo
o`<000003P3oool20000odX0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?oo
o`009P3oool00`000000oooo0?ooo`270?ooo`030000003oool0oooo00`0oooo0`00000C0?ooo`80
003oB03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0203oool3000001L0oooo0`000?m60?ooo`030000
003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0RP3o
ool00`000000oooo0?ooo`040?ooo`<00000703oool20000odD0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo00<00000803oool30000od<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009@3oool00`000?l0oooo0?ooo`110?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`03
0000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0000o`0k0?ooo`<00000
0P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003o
ool0oooo08`0oooo00<000000?ooo`3oool09`3oool30000ocH0oooo100000060?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0Y0?ooo`80003o<P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
02/0oooo0P000?l]0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0;03oool20000obT0
oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`80003o903oool3000001H0oooo
00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02l0oooo0P000?lO0?ooo`@000006P3oool00`000000oooo0?oo
o`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool0<@3oool20000oaX0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<00000
0?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0b0?oo
o`80003o5P3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03@0oooo0P000?lA0?ooo`<0
00009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000
S`3oool00`000000oooo0?ooo`0e0?ooo`80003o3@3oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03L0oooo0P000?l70?ooo`@00000;P3oool00`000000oooo0?ooo`1@0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool4
0000o`80oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool0
02<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0i0?ooo`80003o0`00000f0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0h0?ooo`<000000P000?lh0?ooo`030000003oool0oooo04l0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0e0?ooo`<000001@3oool20000ocL0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000
00090?ooo`80003o=`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000000l0oooo0P000?lf
0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0[0?ooo`<000004`3oool30000oc@0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02P0oooo0`00000G0?ooo`<0003o=03oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000
703oool30000oc<0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0@0?ooo`008@3o
ool200000900oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01h0oooo0`00000V0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0K0?ooo`<00000:P3oool20000oc80oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool3000002l0oooo0P000?la0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000d0?ooo`80003o<03oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000h0?ooo`030000o`3oool0oooo02l0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000003d0oooo0P00
0?l`0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`000005
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000480oooo0`000?l]
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool00200oooo00<000000?oo
o`3oool0T03oool00`000000oooo0?ooo`080?ooo`<00000AP3oool30000obd0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00@0oooo1000001;0?ooo`80003o;@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0
oooo0`00001A0?ooo`80003o;03oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00h0
oooo000P0?ooo`800000T@3oool4000005H0oooo0P000?l[0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.59895 .6671 m
.60445 .67308 L
s
.62818 .68774 m
.60445 .67308 L
s
.5977 .66521 m
.59895 .6671 L
s
.59836 .66487 m
.5977 .66521 L
s
.59982 .66539 m
.59836 .66487 L
s
.60241 .66661 m
.59982 .66539 L
s
.62818 .68774 m
.62271 .68175 L
s
.60365 .66471 m
.58783 .655 L
s
.60808 .67009 m
.60241 .66661 L
s
.61228 .67306 m
.60808 .67009 L
s
.62271 .68175 m
.61921 .67846 L
s
.61535 .67533 m
.61228 .67306 L
s
.59684 .66053 m
.59944 .66175 L
s
.61921 .67846 m
.61535 .67533 L
s
.59944 .66175 m
.60011 .6614 L
s
.60011 .6614 m
.59965 .66034 L
s
.57991 .64478 m
.57603 .64163 L
s
.58411 .64774 m
.57991 .64478 L
s
.57603 .64163 m
.57328 .63917 L
s
.57328 .63917 m
.57083 .6365 L
s
.59965 .66034 m
.59724 .65771 L
s
.58638 .64912 m
.58411 .64774 L
s
.58898 .65032 m
.58638 .64912 L
s
.57083 .6365 m
.57031 .63541 L
s
.57031 .63541 m
.57093 .63499 L
s
.58963 .64994 m
.58898 .65032 L
s
.58343 .64261 m
.56754 .63293 L
s
.58915 .64886 m
.58963 .64994 L
s
.5867 .64619 m
.58915 .64886 L
s
.58392 .6437 m
.5867 .64619 L
s
.58 .64052 m
.58392 .6437 L
s
.57102 .62905 m
.55844 .62302 L
s
.57766 .63631 m
.55844 .62302 L
s
.56432 .62172 m
.55174 .61574 L
s
.57102 .62905 m
.55174 .61574 L
s
.54499 .60675 m
.54102 .60353 L
s
.54811 .60905 m
.54499 .60675 L
s
.54102 .60353 m
.53817 .60098 L
s
.55238 .61204 m
.54811 .60905 L
s
.53817 .60098 m
.53474 .59725 L
s
.5581 .61549 m
.55238 .61204 L
s
.53474 .59725 m
.53416 .59606 L
s
.5607 .61665 m
.5581 .61549 L
s
.53416 .59606 m
.5347 .59555 L
s
.56216 .61711 m
.5607 .61665 L
s
.5347 .59555 m
.53612 .59598 L
s
.54385 .60273 m
.53954 .59804 L
s
.56277 .61664 m
.56216 .61711 L
s
.53612 .59598 m
.53954 .59804 L
s
.54124 .5965 m
.52523 .5869 L
s
.56223 .61548 m
.56277 .61664 L
s
.55881 .61173 m
.56223 .61548 L
s
.53435 .59237 m
.53692 .59348 L
s
.55594 .60916 m
.55881 .61173 L
s
.54874 .60356 m
.55191 .60589 L
s
.55191 .60589 m
.55594 .60916 L
s
.53692 .59348 m
.53748 .59296 L
s
.53748 .59296 m
.53689 .59174 L
s
.51636 .57558 m
.51231 .57229 L
s
.52067 .57858 m
.51636 .57558 L
s
.51231 .57229 m
.5094 .56968 L
s
.5094 .56968 m
.50673 .56678 L
s
.53689 .59174 m
.53426 .58887 L
s
.52297 .57995 m
.52067 .57858 L
s
.52553 .58105 m
.52297 .57995 L
s
.50673 .56678 m
.50608 .56551 L
s
.50608 .56551 m
.50658 .56492 L
s
.52607 .58049 m
.52553 .58105 L
s
.51923 .57243 m
.50316 .56289 L
s
.51295 .56557 m
.48891 .55133 L
s
.52545 .57924 m
.52607 .58049 L
s
.52279 .57633 m
.52545 .57924 L
s
.51985 .5737 m
.52279 .57633 L
s
.49619 .55475 m
.50029 .55807 L
s
.49324 .5521 m
.49619 .55475 L
s
.51576 .57038 m
.51985 .5737 L
s
.49051 .54914 m
.49324 .5521 L
s
.48983 .54783 m
.49051 .54914 L
s
.49029 .54719 m
.48983 .54783 L
s
.50948 .56352 m
.50998 .56291 L
s
.49282 .54822 m
.49029 .54719 L
s
.50998 .56291 m
.50933 .56162 L
s
.50933 .56162 m
.50661 .55865 L
s
.49512 .54958 m
.49282 .54822 L
s
.4995 .55262 m
.49512 .54958 L
s
.50288 .55045 m
.47859 .53616 L
s
.50661 .55865 m
.50364 .55598 L
s
.50364 .55598 m
.4995 .55262 L
s
.49008 .54292 m
.49078 .54193 L
s
.47986 .53177 m
.46835 .52503 L
s
.49078 .54193 m
.49009 .54059 L
s
.49009 .54059 m
.4873 .53754 L
s
.47699 .52627 m
.46083 .51684 L
s
.48428 .53482 m
.47986 .53177 L
s
.4873 .53754 m
.48428 .53482 L
s
.45667 .51058 m
.45247 .50716 L
s
.46108 .51363 m
.45667 .51058 L
s
.45247 .50716 m
.4494 .50441 L
s
.4494 .50441 m
.44652 .50128 L
s
.4634 .51497 m
.46108 .51363 L
s
.46592 .51596 m
.4634 .51497 L
s
.44652 .50128 m
.44574 .49984 L
s
.44574 .49984 m
.44611 .49907 L
s
.46634 .51522 m
.46592 .51596 L
s
.48635 .53173 m
.48612 .53208 L
s
.48612 .53208 m
.484 .53037 L
s
.484 .53037 m
.48423 .53002 L
s
.48423 .53002 m
.48635 .53173 L
s
.46559 .51381 m
.46634 .51522 L
s
.46272 .51067 m
.46559 .51381 L
s
.43701 .49035 m
.44029 .49274 L
s
.43293 .48649 m
.43701 .49035 L
s
.45963 .50789 m
.46272 .51067 L
s
.42999 .48329 m
.43293 .48649 L
s
.45537 .50443 m
.45963 .50789 L
s
.42819 .48074 m
.42999 .48329 L
s
.44626 .49568 m
.44315 .49288 L
s
.44955 .49809 m
.44626 .49568 L
s
.45091 .49837 m
.44955 .49809 L
s
.44315 .49288 m
.43709 .48687 L
s
.42951 .48099 m
.42819 .48074 L
s
.44915 .49584 m
.45091 .49837 L
s
.43066 .48166 m
.42951 .48099 L
s
.43709 .48687 m
.43396 .48406 L
s
.43396 .48406 m
.43066 .48166 L
s
.44622 .49263 m
.44915 .49584 L
s
.42026 .47212 m
.41812 .47038 L
s
.42042 .4717 m
.42026 .47212 L
s
.41812 .47038 m
.41827 .46995 L
s
.4421 .48874 m
.44622 .49263 L
s
.41827 .46995 m
.42042 .4717 L
s
.43878 .48632 m
.4421 .48874 L
s
.44259 .48439 m
.42621 .47501 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`0V0?ooo`030000o`3o
ool0oooo06H0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`3oool0I@3oool0
0`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00;03oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool0H`3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo02L0oooo0P000?mS0?ooo`030000003oool0oooo00X0
oooo100000170?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0640oooo
00<000000?ooo`3oool09@3oool20000o`030?ooo`000?l0oooo0640oooo00<000000?ooo`3oool0
1`3oool3000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3o
ool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo0080003oH03oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo02@0oooo10000?l00`3oool0003o0?ooo`1N0?ooo`040000003oool0
oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo02@0oooo00<0003o0?ooo`000?l00P000?mO0?ooo`@00000E@3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
02@0oooo10000?mM0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo02D0oooo0`000?mI0?ooo`<000000P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0000006P0oooo
00<000000?ooo`3oool09P3oool20000oeD0oooo0`0000050?ooo`030000003oool0oooo05H0oooo
00<000000?ooo`3oool05`3oool002X0oooo0P00001Y0?ooo`030000003oool0oooo02H0oooo0`00
0?mA0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z
0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo0?ooo`1>
0?ooo`<000002`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?oo
o`8000001`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo02D0oooo00@0003o0?oo
o`3oool0003oB@3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool09@3oool20000o`030?ooo`000?l0oooo04@0oooo0`00000A0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo02H0oooo0P000?m20?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0V0?ooo`80003o?P3oool3
000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3oool09P3oool3
0000ocT0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool09@3oool00`00
0?l0oooo0000o`0f0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool09@3oool20000oc80
oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo
00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`0V0?ooo`80003o;@3oool3000002D0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool00`000000oooo0000
001d0?ooo`030000003oool0oooo02@0oooo0P000?l00`3oool0003o0000o`0X0?ooo`<00000:03o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool0
0`000000oooo0?ooo`0U0?ooo`80003o9P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0MP3oool00`00
0000oooo0?ooo`0V0?ooo`@0003o7`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0
oooo00<000000?ooo`3oool09P3oool00`000?l0oooo0000o`0L0?ooo`<00000<@3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240oooo
00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`0T0?ooo`030000o`3oool0003o01X0oooo
0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000
000P0?ooo`030000003oool0oooo07T0oooo00<000000?ooo`3oool0903oool40000oaD0oooo0`00
000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<00000
0?ooo`3oool0NP3oool00`000000oooo0?ooo`0U0?ooo`<0003o4@3oool3000003X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?oo
o`030000003oool0oooo02H0oooo0P000?l=0?ooo`<00000?@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3o
ool09@3oool010000?l0oooo0000o`000?l80?ooo`<00000@03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3o
ool0903oool20000o`80oooo00<0003o0?ooo`3oool00P3oool3000004<0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000
003oool0oooo0280oooo00<0003o0?ooo`000?l00P000?l20?ooo`<00000AP3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?oo
o`0R0?ooo`<0003o00<000000000o`000?l0B@3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool2
00000080003o0P3oool00`000?l0oooo0?ooo`160?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?oo
o`@00000103oool30000odT0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`0000080?ooo`04
0000o`3oool0003o0000odP0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?oo
o`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo0`00000<0?ooo`80
003o00<0oooo0000o`3oool0AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0403oool300000100oooo
0P000?m80?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<0
00000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<00000503oool30000odH0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`28
0?ooo`030000003oool0oooo00P0oooo0`00000H0?ooo`040000o`3oool0003o0000od@0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:
0?ooo`030000003oool0oooo00@0oooo0`00000L0?ooo`040000o`3oool0oooo0000od<0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2;
0?ooo`030000003oool0oooo00<00000803oool40000od80oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`8000009P3oool00`00
0?l0oooo0?ooo`100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0
oooo0P00002=0?ooo`030000003oool0oooo06L0oooo0P00001K0?ooo`030000003oool0oooo0180
oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09@3oool00`000?l0oooo
0?ooo`0l0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo
000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09P3oool30000ocL0oooo1000
00060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<00000
0?ooo`3oool0S03oool00`000000oooo0?ooo`0X0?ooo`80003o<`3oool3000000X0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo02P0oooo0`000?l_0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0:03oool010000?l0oooo0000o`000?l[0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0:@3oool30000obP0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0[0?ooo`<0003o
8P3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo00@0003o0?ooo`000?l0003o
7@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02d0oooo00@0003o0?ooo`3oool0003o
6@3oool300000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0P000?l00`3oool0003o0?oo
o`0D0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S
0?ooo`800000S`3oool00`000000oooo0?ooo`0`0?ooo`030000o`3oool0003o0140oooo0`00000Z
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0_0?ooo`030000o`3oool0003o0080003o303oool40000
02h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo0P000?l;0?ooo`<00000<`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0<P3oool30000o`H0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0c0?ooo`80003o0`3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00000n
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@0000000<0oooo0000o`000?l0?`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0
oooo00<000000?ooo`3oool0;P3oool3000000D0oooo0`000?lo0?ooo`030000003oool0oooo04`0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0[0?ooo`<000002@3oool00`000?l0oooo0000o`0n0?ooo`030000003oool0oooo04`0oooo
00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?oo
o`0X0?ooo`<000003@3oool20000ocl0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000140oooo0P000?lo
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?oo
o`030000003oool0oooo0240oooo1000000D0?ooo`040000o`3oool0003o0000och0oooo00<00000
0?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo01h0oooo0`00000I0?ooo`040000o`3oool0oooo0000och0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?oo
o`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<000007@3oool40000ocd0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0603oool3000002<0oooo00<0003o0?oo
o`3oool0?03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<0
00009@3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool0
4@3oool4000002T0oooo0P000?l00`3oool0003o0?ooo`0l0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo00h0oooo0`00000_0?ooo`80003o?P3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@
0?ooo`030000003oool0oooo00/0oooo0`00000c0?ooo`80003o?@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000003H0oooo0`000?lm0?ooo`030000003oool0oooo04D0oooo00<000000?oo
o`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@0
0000>@3oool00`000?l0oooo0000o`0n0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool3000003h0
oooo00@0003o0?ooo`000?l0003o?@3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
00h0oooo000P0?ooo`800000T@3oool400000480oooo00@0003o0?ooo`3oool0003o?@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000004H0
oooo0P000?l00`3oool0003o0?ooo`0k0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool0
AP3oool010000?l0oooo0000o`000?lk0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3o
ool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0
A`3oool20000o`030?ooo`000?l0oooo03X0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?oo
o`190?ooo`030000o`3oool0003o03/0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`1:
0?ooo`80003o?03oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00d0oooo000O0?oo
o`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0oooo04`0oooo00<0003o0?oo
o`3oool0>P3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`03
0000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000
503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0
3@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0
oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0
oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo
000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<0
00000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T
0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?oo
o`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`03
0000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000
=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0
303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03o
ool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0
oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`00
0000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000
oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo
0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo
0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<0
00000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`15
0?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?oo
o`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3o
ool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000
E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool0
2P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03o
ool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0
oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`00
0000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo
0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?oo
o`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?oo
o`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000
M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0
oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`00
0000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0
oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo
0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?oo
o`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<00000
0?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?oo
o`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?oo
o`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`03
0000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`000000
0P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo
0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?oo
o`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F
0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`07
0?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool0
0`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?oo
o`800000103oool200000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`00
8`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3o
ool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3o
ool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003o
ool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<0
00000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D
0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?oo
o`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?oo
o`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`03
0000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00
<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool0
0`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
03H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000
oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo
0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo
0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3o
ool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000
K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
0`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo
06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0
HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo
05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0
oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080
oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000
oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo
00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<00000
0?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?oo
o`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?oo
o`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?oo
o`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000
003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo
00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool0
0`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000
oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<0
00000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P000014
0?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?oo
o`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3o
ool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool0
0740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo
0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<0
00000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<00000
0?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?oo
o`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?oo
o`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3o
ool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`04
0000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?oo
o`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?oo
o`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`03
0000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3o
ool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3o
ool400000640oooo00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5
000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo
0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo
002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo
002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`03
0000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000
003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3o
ool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4
000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0
oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0
oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo
0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00
000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?oo
o`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<00000
0?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W
0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?oo
o`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3o
ool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?oo
o`00I03oool3000000030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000
003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3o
ool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool0
0:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?oo
o`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<0
0000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?oo
o`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`80
0000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.5645 .67362 m
.56776 .68009 L
s
.59292 .69751 m
.56776 .68009 L
s
.56429 .67165 m
.5645 .67362 L
s
.56574 .67144 m
.56429 .67165 L
s
.56766 .67216 m
.56574 .67144 L
s
.59292 .69751 m
.58973 .69105 L
s
.5708 .67371 m
.56766 .67216 L
s
.57683 .67786 m
.5708 .67371 L
s
.57477 .67212 m
.5579 .66052 L
s
.58973 .69105 m
.58715 .68743 L
s
.58092 .68129 m
.57683 .67786 L
s
.58715 .68743 m
.5838 .6839 L
s
.5838 .6839 m
.58092 .68129 L
s
.56751 .66713 m
.57067 .66868 L
s
.57067 .66868 m
.57215 .66846 L
s
.57215 .66846 m
.57242 .6674 L
s
.57242 .6674 m
.57101 .66455 L
s
.55481 .64968 m
.55143 .64611 L
s
.55892 .65312 m
.55481 .64968 L
s
.55143 .64611 m
.54925 .64336 L
s
.56134 .65478 m
.55892 .65312 L
s
.54925 .64336 m
.54779 .64046 L
s
.56451 .65632 m
.56134 .65478 L
s
.54779 .64046 m
.54803 .63935 L
s
.56599 .65607 m
.56451 .65632 L
s
.54803 .63935 m
.54948 .63906 L
s
.56289 .64821 m
.54584 .63659 L
s
.56625 .65498 m
.56599 .65607 L
s
.56482 .65208 m
.56625 .65498 L
s
.56263 .64931 m
.56482 .65208 L
s
.55922 .64571 m
.56263 .64931 L
s
.55559 .63351 m
.54042 .62582 L
s
.5595 .64138 m
.54042 .62582 L
s
.55164 .62556 m
.53643 .61791 L
s
.55559 .63351 m
.53643 .61791 L
s
.53405 .60837 m
.53058 .60469 L
s
.53702 .61103 m
.53405 .60837 L
s
.54122 .61454 m
.53702 .61103 L
s
.53058 .60469 m
.52833 .60184 L
s
.54741 .61871 m
.54122 .61454 L
s
.52833 .60184 m
.52628 .59777 L
s
.55064 .62021 m
.54741 .61871 L
s
.52628 .59777 m
.52649 .59655 L
s
.52649 .59655 m
.52793 .59617 L
s
.55263 .62089 m
.55064 .62021 L
s
.55413 .62055 m
.55263 .62089 L
s
.53616 .60441 m
.53361 .5993 L
s
.52793 .59617 m
.52989 .5968 L
s
.52989 .5968 m
.53361 .5993 L
s
.55438 .61937 m
.55413 .62055 L
s
.53801 .59814 m
.5206 .58648 L
s
.55237 .6153 m
.55438 .61937 L
s
.55011 .61242 m
.55237 .6153 L
s
.54659 .60869 m
.55011 .61242 L
s
.54358 .60599 m
.54659 .60869 L
s
.53052 .59312 m
.53375 .59459 L
s
.53375 .59459 m
.53522 .5942 L
s
.53522 .5942 m
.53544 .59296 L
s
.53544 .59296 m
.53389 .58983 L
s
.51698 .57437 m
.51343 .57061 L
s
.52125 .57792 m
.51698 .57437 L
s
.51343 .57061 m
.51112 .56767 L
s
.52375 .57958 m
.52125 .57792 L
s
.51112 .56767 m
.50952 .56449 L
s
.52699 .58104 m
.52375 .57958 L
s
.50952 .56449 m
.5097 .5632 L
s
.52846 .58061 m
.52699 .58104 L
s
.5097 .5632 m
.51113 .56273 L
s
.52498 .57191 m
.50738 .56024 L
s
.52867 .57934 m
.52846 .58061 L
s
.52126 .56441 m
.49486 .54696 L
s
.5271 .57616 m
.52867 .57934 L
s
.52478 .5732 m
.5271 .57616 L
s
.52119 .56939 m
.52478 .5732 L
s
.50377 .55142 m
.50736 .55523 L
s
.50143 .54843 m
.50377 .55142 L
s
.49979 .54518 m
.50143 .54843 L
s
.49995 .54383 m
.49979 .54518 L
s
.51746 .5619 m
.51892 .56142 L
s
.50138 .54331 m
.49995 .54383 L
s
.51892 .56142 m
.51912 .5601 L
s
.50462 .54472 m
.50138 .54331 L
s
.51912 .5601 m
.5175 .55685 L
s
.50716 .54639 m
.50462 .54472 L
s
.5175 .55685 m
.51515 .55384 L
s
.51152 .54999 m
.50716 .54639 L
s
.51515 .55384 m
.51152 .54999 L
s
.51943 .54852 m
.49262 .53095 L
s
.50532 .53927 m
.50751 .53847 L
s
.49922 .52705 m
.48646 .51873 L
s
.50751 .53847 m
.50769 .53709 L
s
.50769 .53709 m
.50603 .53375 L
s
.50603 .53375 m
.50363 .53068 L
s
.50363 .53068 m
.49922 .52705 L
s
.49989 .5214 m
.48193 .50973 L
s
.48119 .50312 m
.47747 .49917 L
s
.48561 .50676 m
.48119 .50312 L
s
.47747 .49917 m
.47504 .49605 L
s
.48819 .50842 m
.48561 .50676 L
s
.47504 .49605 m
.4733 .49259 L
s
.49149 .50979 m
.48819 .50842 L
s
.51027 .52814 m
.50952 .52843 L
s
.50952 .52843 m
.50766 .52645 L
s
.50766 .52645 m
.50841 .52617 L
s
.4733 .49259 m
.47342 .49111 L
s
.49294 .50917 m
.49149 .50979 L
s
.50841 .52617 m
.51027 .52814 L
s
.47342 .49111 m
.47483 .49046 L
s
.49309 .50772 m
.49294 .50917 L
s
.49138 .50426 m
.49309 .50772 L
s
.48893 .50112 m
.49138 .50426 L
s
.48518 .49712 m
.48893 .50112 L
s
.46815 .48064 m
.47132 .48347 L
s
.46508 .4763 m
.46815 .48064 L
s
.46331 .47276 m
.46508 .4763 L
s
.46281 .47005 m
.46331 .47276 L
s
.47851 .4873 m
.47604 .48412 L
s
.48169 .49014 m
.47851 .4873 L
s
.48372 .49064 m
.48169 .49014 L
s
.47604 .48412 m
.47179 .4774 L
s
.48328 .48796 m
.48372 .49064 L
s
.46481 .47052 m
.46281 .47005 L
s
.47179 .4774 m
.46931 .4742 L
s
.46611 .47135 m
.46481 .47052 L
s
.46931 .4742 m
.46611 .47135 L
s
.48152 .48443 m
.48328 .48796 L
s
.47845 .48004 m
.48152 .48443 L
s
.45802 .46052 m
.45612 .4585 L
s
.45872 .46015 m
.45802 .46052 L
s
.45612 .4585 m
.45681 .45812 L
s
.47524 .47718 m
.47845 .48004 L
s
.45681 .45812 m
.45872 .46015 L
s
.48369 .47604 m
.46524 .4643 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo05L0oooo00<00000
0?ooo`3oool08@3oool300000340oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`0h0?ooo`030000o`3oool0oooo05H0oooo00<000000?oo
o`3oool07P3oool3000003@0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3o
ool0FP3oool00`000000oooo0?ooo`0i0?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`0i0?ooo`80003oE@3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0=P3o
ool01@000?l0oooo0?ooo`3oool0003o05@0oooo00<000000?ooo`3oool0503oool3000003h0oooo
00<000000?ooo`3oool0603oool002/0oooo0P00001O0?ooo`030000003oool0oooo03H0oooo0P00
0?l20?ooo`030000o`3oool0oooo0540oooo00<000000?ooo`3oool04@3oool300000440oooo00<0
00000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0e
0?ooo`030000o`3oool0003o0080oooo0P000?mA0?ooo`030000003oool0oooo00h0oooo0`000014
0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?oo
o`3oool0=03oool00`000?l0oooo0?ooo`020000o`80oooo00<0003o0?ooo`3oool0CP3oool00`00
0000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1Q0?ooo`030000003oool0oooo03@0oooo00D0003o0?ooo`000?l0oooo0000o`1B0?oo
o`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`03
0000003oool0oooo0680oooo00<000000?ooo`3oool0=03oool40000oe80oooo00<000000?ooo`3o
ool0103oool3000004h0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0
H`3oool00`000000oooo0?ooo`0e0?ooo`030000o`3oool0003o0540oooo00@000000?ooo`3oool0
oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo
00<000000?ooo`3oool0=@3oool00`000?l0oooo0000o`1@0?ooo`@00000E@3oool00`000000oooo
0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0380oooo0P00
0?l00`3oool0003o0000o`1>0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool0
0`000000oooo0?ooo`1W0?ooo`030000003oool0oooo0340oooo00<0003o0?ooo`3oool0C@3oool3
00000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`00
0000oooo0000001X0?ooo`030000003oool0oooo0340oooo00D0003o0?ooo`3oool0oooo0000o`17
0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?oo
o`800000J@3oool00`000000oooo0?ooo`0b0?ooo`040000o`3oool0oooo0000od@0oooo0`000008
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?oo
o`3oool0J@3oool00`000000oooo0?ooo`0a0?ooo`050000o`3oool0oooo0?ooo`000?l0@03oool3
000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool20000
00L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0a0?ooo`050000o`3oool0oooo
0?ooo`000?l0?03oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<00000
0?ooo`3oool0<@3oool20000o`80oooo00<0003o0?ooo`3oool0=P3oool300000140oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0000o`02
0000ocD0oooo0`00000D0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0
oooo0300oooo00<0003o0?ooo`3oool0<`3oool3000001P0oooo00<000000?ooo`3oool0EP3oool0
0`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0
oooo06l0oooo00<000000?ooo`3oool0<03oool00`000?l0oooo0?ooo`0_0?ooo`<000006`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo0300oooo0P000?l/0?ooo`<000007P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740
oooo00<000000?ooo`3oool0;@3oool01@000?l0oooo0?ooo`3oool0003o02L0oooo1000000Q0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3o
ool0LP3oool00`000000oooo0?ooo`0]0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0Q0?ooo`<0
00009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000
003oool0000007@0oooo00<000000?ooo`3oool0;P3oool20000o`<0oooo00<0003o0?ooo`3oool0
6`3oool3000002P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03o
ool2000007H0oooo00<000000?ooo`3oool0;`3oool01@000?l0oooo0?ooo`3oool0003o01T0oooo
0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000
000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0;03oool00`000?l0oooo0?oo
o`020000oaP0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3o
ool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`030000003oool0
oooo02`0oooo0P000?l20?ooo`030000o`3oool0oooo0180oooo0`00000a0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo02d0oooo00<0003o0?ooo`000?l04@3oool30000
03@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200
oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0]0?ooo`80003o3P3oool3000003L0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo
0?ooo`1j0?ooo`030000003oool0oooo02d0oooo0P000?l:0?ooo`<00000>P3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo00<0
00000?ooo`3oool0:@3oool30000o`80oooo00<0003o0?ooo`3oool0103oool3000003d0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m
0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0?ooo`02
0000o`040?ooo`000000000000000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo02H0oooo0`000?l2
0?ooo`80003o0P0000000`000?l0oooo0?ooo`110?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0W0?oo
o`80003o0P0000000`000?l0oooo0?ooo`140?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo02D0oooo0P0000020000o`80
oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000W0?ooo`030000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000<0oooo
0P000?l20?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000
00060?ooo`050000o`3oool0003o0?ooo`000?l0A@3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool0603o
ool3000000/0oooo10000?m50?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D0?ooo`<000003P3oool0
0`000?l0oooo0000o`020000od@0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo0`00000A0?oo
o`040000o`3oool0oooo0?ooo`80003o@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool30000
01D0oooo00@0003o0?ooo`3oool0oooo0P000?m20?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?oo
o`<000006@3oool20000o`80oooo00<0003o0?ooo`3oool0@03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool3000001d0oooo00@0003o0?ooo`3oool0003o@P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3o
ool00`00000Q0?ooo`80003o00<0oooo0000o`3oool0@03oool00`000000oooo0?ooo`1H0?ooo`03
0000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000V0?ooo`80003o
@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3o
ool00`000000oooo0?ooo`1W0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool0
0`000000oooo0?ooo`2<0?ooo`030000003oool0oooo02<0oooo00<0003o0?ooo`3oool0?P3oool3
00000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo0P000?l20?ooo`030000o`3oool0oooo
03D0oooo100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0V0?ooo`80003o00<0oooo0000o`3o
ool0<P3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo0`000?la0?ooo`<00000
3P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool09@3oool20000o`80oooo00<0003o0?ooo`3oool0:`3o
ool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo00@0003o0?ooo`000?l0003o:`3o
ool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo00<0003o0?ooo`000?l09`3oool4
000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`000?l00P3oool00`00
0?l0oooo0?ooo`0N0?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo
0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo01X0oooo0`00000R0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0Y0?ooo`050000o`3oool0oooo0?ooo`000?l06@3oool3000002H0oooo00<000000?ooo`3o
ool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0
:P3oool20000o`80oooo00<0003o0?ooo`3oool04`3oool3000002X0oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02`0oooo00@0003o0?ooo`3oool0003o403oool4000002h0oooo00<000000?ooo`3oool0
D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo02X0oooo0P000?l20?ooo`80003o00<0oooo0000o`3oool02`3oool3000003<0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo02/0oooo10000?l00`3oool0003o0?ooo`090?ooo`<00000=P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool0;@3oool010000?l0oooo0000o`000?l70?ooo`<00000>P3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool0:`3oool20000o`030?ooo`000?l0oooo00D0oooo0`00000n0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0/0?ooo`D0003o100000120?ooo`030000003oool0oooo04d0
oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo
0?ooo`0^0?ooo`<0000000<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0:`3o
ool3000000030?ooo`000?l0003o04L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`000002
0?ooo`040000o`3oool0003o0?ooo`80003oAP3oool00`000000oooo0?ooo`1;0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<000001P3oool2
0000o`<0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@000002P3oool30000
odT0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01h0oooo0`00000>0?ooo`030000o`3oool0oooo0080
003oB03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01/0oooo0`00000B0?ooo`80003o
00<0oooo0000o`000?l0A`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo
000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0H0?ooo`<000005P3oool010000?l0oooo0?ooo`000?m80?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000J0?ooo`80003o00<0oooo0000o`3oool0
A`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3o
ool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000O0?ooo`80003oB@3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<000008@3oool0
0`000?l0oooo0?ooo`1;0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool0
01P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool30000
02D0oooo00<0003o0?ooo`3oool0BP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3000002T0
oooo00@0003o0?ooo`3oool0003oB@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000002d0
oooo0`000?m:0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo
00<000000?ooo`3oool0T03oool010000000oooo0?ooo`3oool300000380oooo0P000?m;0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000
<`3oool50000od/0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool200000900oooo0`00000g0?ooo`040000o`3oool0oooo0000od/0oooo00<000000?ooo`3oool0
@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3o
ool00`000000oooo0?ooo`0e0?ooo`050000o`3oool0oooo0?ooo`000?l0B`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo1000
00050?ooo`030000003oool0oooo03H0oooo00D0003o0?ooo`3oool0oooo0000o`1;0?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3o
ool3000000T0oooo00<000000?ooo`3oool0=`3oool20000o`80oooo0P000?m:0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool3
000000`0oooo00<000000?ooo`3oool0>@3oool010000?l0oooo0?ooo`000?m;0?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3
000000l0oooo00<000000?ooo`3oool0>P3oool20000o`030?ooo`000?l0oooo04X0oooo00<00000
0?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1l0?oo
o`<000004@3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0003o04X0oooo00<000000?oo
o`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@0
0000503oool00`000000oooo0?ooo`0n0?ooo`80003oB`3oool00`000000oooo0?ooo`0m0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07H0oooo0`00000H0?ooo`030000
003oool0oooo0400oooo00<0003o0?ooo`3oool0B@3oool00`000000oooo0?ooo`0l0?ooo`030000
003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003o
ool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool0
0`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool40000
0440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo
0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.52867 .676 m
.52959 .6827 L
s
.55528 .70302 m
.52959 .6827 L
s
.52949 .67407 m
.52867 .676 L
s
.53168 .67407 m
.52949 .67407 L
s
.55528 .70302 m
.55446 .69636 L
s
.534 .67504 m
.53168 .67407 L
s
.53756 .67697 m
.534 .67504 L
s
.54373 .68183 m
.53756 .67697 L
s
.55446 .69636 m
.55287 .69251 L
s
.54409 .67601 m
.5268 .66242 L
s
.54756 .68572 m
.54373 .68183 L
s
.55287 .69251 m
.55016 .68863 L
s
.55016 .68863 m
.54756 .68572 L
s
.53666 .67017 m
.54025 .67211 L
s
.54025 .67211 m
.54248 .67211 L
s
.54248 .67211 m
.54347 .67112 L
s
.54347 .67112 m
.54309 .66817 L
s
.52862 .65152 m
.52587 .64758 L
s
.53248 .65543 m
.52862 .65152 L
s
.53497 .65738 m
.53248 .65543 L
s
.52587 .64758 m
.52435 .64462 L
s
.53858 .65931 m
.53497 .65738 L
s
.52435 .64462 m
.52393 .64161 L
s
.54083 .65928 m
.53858 .65931 L
s
.52393 .64161 m
.5249 .64057 L
s
.54182 .65827 m
.54083 .65928 L
s
.5249 .64057 m
.52713 .6405 L
s
.54093 .65126 m
.52338 .63758 L
s
.54144 .65527 m
.54182 .65827 L
s
.53993 .65229 m
.54144 .65527 L
s
.53715 .64832 m
.53993 .65229 L
s
.53898 .63603 m
.52184 .62641 L
s
.54002 .64419 m
.52184 .62641 L
s
.53792 .62779 m
.52071 .61818 L
s
.53898 .63603 m
.52071 .61818 L
s
.5228 .60862 m
.51997 .60456 L
s
.52549 .61164 m
.5228 .60862 L
s
.52945 .61564 m
.52549 .61164 L
s
.51997 .60456 m
.51841 .60147 L
s
.53585 .62057 m
.52945 .61564 L
s
.51841 .60147 m
.51782 .59724 L
s
.53956 .62249 m
.53585 .62057 L
s
.51782 .59724 m
.51881 .5961 L
s
.542 .62343 m
.53956 .62249 L
s
.54432 .62333 m
.542 .62343 L
s
.51881 .5961 m
.52108 .59594 L
s
.52806 .60512 m
.52736 .59981 L
s
.54535 .62223 m
.54432 .62333 L
s
.52108 .59594 m
.5235 .59685 L
s
.5235 .59685 m
.52736 .59981 L
s
.54483 .61802 m
.54535 .62223 L
s
.53429 .59935 m
.51621 .5855 L
s
.54328 .61491 m
.54483 .61802 L
s
.54042 .6108 m
.54328 .61491 L
s
.53769 .60774 m
.54042 .6108 L
s
.52651 .5934 m
.53026 .5953 L
s
.53026 .5953 m
.53257 .59513 L
s
.53257 .59513 m
.5336 .59397 L
s
.5336 .59397 m
.53318 .59073 L
s
.51801 .57327 m
.51511 .5691 L
s
.52205 .57734 m
.51801 .57327 L
s
.52465 .57932 m
.52205 .57734 L
s
.51511 .5691 m
.51351 .56591 L
s
.52842 .58121 m
.52465 .57932 L
s
.51351 .56591 m
.51305 .5626 L
s
.53076 .58102 m
.52842 .58121 L
s
.51305 .5626 m
.51405 .56138 L
s
.53179 .57982 m
.53076 .58102 L
s
.51405 .56138 m
.51636 .56114 L
s
.5308 .57211 m
.51244 .55817 L
s
.53137 .57652 m
.53179 .57982 L
s
.5298 .56432 m
.50222 .54343 L
s
.52977 .57332 m
.53137 .57652 L
s
.52685 .56911 m
.52977 .57332 L
s
.51237 .5491 m
.5153 .55334 L
s
.51075 .54586 m
.51237 .5491 L
s
.51028 .54247 m
.51075 .54586 L
s
.52584 .56131 m
.52819 .56107 L
s
.51129 .5412 m
.51028 .54247 L
s
.52819 .56107 m
.52923 .55983 L
s
.51362 .54092 m
.51129 .5412 L
s
.52923 .55983 m
.5288 .55645 L
s
.51743 .54277 m
.51362 .54092 L
s
.5288 .55645 m
.52718 .55319 L
s
.52009 .54477 m
.51743 .54277 L
s
.52718 .55319 m
.52422 .54891 L
s
.52422 .54891 m
.52009 .54477 L
s
.53632 .54872 m
.50824 .52763 L
s
.52155 .53763 m
.52512 .53719 L
s
.52512 .53719 m
.52617 .53589 L
s
.51989 .52489 m
.50648 .51487 L
s
.52617 .53589 m
.52572 .53242 L
s
.52572 .53242 m
.52408 .52908 L
s
.52408 .52908 m
.51989 .52489 L
s
.52408 .51955 m
.50518 .50547 L
s
.50793 .49898 m
.5049 .49458 L
s
.51215 .50319 m
.50793 .49898 L
s
.51486 .5052 m
.51215 .50319 L
s
.5049 .49458 m
.50321 .49118 L
s
.53497 .52767 m
.53375 .52783 L
s
.53375 .52783 m
.53224 .52563 L
s
.53224 .52563 m
.53346 .52547 L
s
.51878 .50704 m
.51486 .5052 L
s
.50321 .49118 m
.50272 .48757 L
s
.53346 .52547 m
.53497 .52767 L
s
.5212 .50667 m
.51878 .50704 L
s
.50272 .48757 m
.50374 .48615 L
s
.52225 .50529 m
.5212 .50667 L
s
.50374 .48615 m
.50613 .48575 L
s
.52179 .50169 m
.52225 .50529 L
s
.52011 .49827 m
.52179 .50169 L
s
.51706 .49383 m
.52011 .49827 L
s
.50224 .47521 m
.50514 .47844 L
s
.50037 .47052 m
.50224 .47521 L
s
.49986 .46682 m
.50037 .47052 L
s
.5132 .48329 m
.5115 .47983 L
s
.51611 .48654 m
.5132 .48329 L
s
.51871 .48735 m
.51611 .48654 L
s
.50072 .46412 m
.49986 .46682 L
s
.5115 .47983 m
.50931 .47266 L
s
.51962 .48469 m
.51871 .48735 L
s
.5033 .4649 m
.50072 .46412 L
s
.50931 .47266 m
.5076 .46917 L
s
.51915 .481 m
.51962 .48469 L
s
.50468 .46591 m
.5033 .4649 L
s
.5076 .46917 m
.50468 .46591 L
s
.51729 .47628 m
.51915 .481 L
s
.51435 .47301 m
.51729 .47628 L
s
.49936 .45415 m
.4978 .45189 L
s
.50057 .45391 m
.49936 .45415 L
s
.4978 .45189 m
.49901 .45164 L
s
.49901 .45164 m
.50057 .45391 L
s
.52704 .47327 m
.50749 .45897 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0B@3oool30000odP0oooo00<000000?ooo`3oool09`3oool3000002/0oooo
00<000000?ooo`3oool06@3oool002d0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`14
0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0B`3oool00`000?l0oooo0?ooo`130?oo
o`030000003oool0oooo01h0oooo0`00000d0?ooo`030000003oool0oooo01T0oooo000/0?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0A`3oool20000o`80oooo00<0003o0?ooo`3o
ool0@`3oool00`000000oooo0?ooo`0J0?ooo`<00000=`3oool00`000000oooo0?ooo`0I0?ooo`00
;03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo04D0oooo00<0003o0?ooo`000?l0
0`3oool20000od<0oooo00<000000?ooo`3oool05`3oool3000003/0oooo00<000000?ooo`3oool0
603oool002`0oooo0P00001M0?ooo`030000003oool0oooo04@0oooo00@0003o0?ooo`3oool0003o
103oool00`000?l0oooo0?ooo`100?ooo`030000003oool0oooo01@0oooo0`00000n0?ooo`030000
003oool0oooo01P0oooo000[0?ooo`800000G`3oool00`000000oooo0?ooo`130?ooo`070000o`3o
ool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo03l0oooo00<000000?ooo`3o
ool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0
GP3oool00`000000oooo0?ooo`130?ooo`060000o`3oool0oooo0000o`3oool0003o0`3oool00`00
0?l0oooo0?ooo`0n0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0@P3oool01`000?l0
oooo0?ooo`3oool0003o0?ooo`000?l0@`3oool00`000000oooo0?ooo`0:0?ooo`@00000A`3oool0
0`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
0480oooo00H0003o0?ooo`3oool0003o0?ooo`000?m30?ooo`030000003oool0oooo00L0oooo0`00
001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo0680oooo00<00000
0?ooo`3oool0A03oool00`000?l0oooo0000o`130?ooo`030000003oool0oooo00@0oooo0`00001>
0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?oo
o`3oool0@03oool20000o`050?ooo`000?l0oooo0?ooo`000?l0@P3oool010000000oooo0?ooo`3o
ool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`0n0?ooo`030000o`3oool0oooo0080oooo0P000?m30?ooo`@00000E@3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
03d0oooo00<0003o0?ooo`3oool0A@3oool3000005P0oooo00<000000?ooo`3oool05`3oool002X0
oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?ooo`0l0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0?03oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo03`0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0i0?ooo`<000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?oo
o`0m0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=@3oool3000000P0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y
0?ooo`030000003oool0oooo03d0oooo00D0003o0?ooo`3oool0oooo0000o`0d0?ooo`<000002`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Q0?ooo`8000001`3oool0
0`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo03d0oooo0P000?l00`3oool0003o0?ooo`0`
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?oo
o`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0i
0?ooo`030000o`3oool0oooo0080oooo0`000?l]0?ooo`<000004@3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`0i0?ooo`80003o;`3oool3000001@0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`000005
0?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`0Y
0?ooo`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`0g
0?ooo`040000o`3oool0oooo0000obL0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<0
00000?ooo`3oool05P3oool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0=`3oool00`000?l0oooo0?ooo`020000ob80oooo0`00000N0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`0g0?ooo`80003o0P3oool00`000?l0oooo0?ooo`0K0?ooo`@000008@3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool0>03oool00`000?l0oooo0?ooo`0J0?ooo`<000009@3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo
00<000000?ooo`3oool0>03oool010000?l0oooo0?ooo`3oool20000oa<0oooo0`00000X0?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000
003oool0oooo0380oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o0100
oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo
1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0<P3oool20000o`<0oooo
00<0003o0?ooo`3oool03`3oool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<0
00000?ooo`3oool0<`3oool01@000?l0oooo0?ooo`3oool0003o00d0oooo0`00000a0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3o
ool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03<0oooo00@0003o0?ooo`3oool0003o
2P3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103o
ool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0c0?ooo`80003o203o
ool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool0
0`000000oooo0?ooo`1j0?ooo`030000003oool0oooo02h0oooo0P000?l40?ooo`030000o`3oool0
oooo0080oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0Z0?ooo`050000o`3oool0oooo
0000o`3oool00`000?l20?ooo`040000o`0000000000000003d0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0
oooo02X0oooo00<0003o0?ooo`000?l00`3oool010000?l000000000000000020000och0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo02X0oooo0`000?l3000000030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool200000080003o0`3oool00`00
0?l0oooo0?ooo`0o0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0
oooo0`0000210?ooo`030000003oool0oooo02D0oooo0`0000030?ooo`050000o`3oool0oooo0?oo
o`000?l0@@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo0840oooo00<000000?ooo`3oool08@3oool3000000D0oooo00<0003o0?ooo`00
0?l00`3oool00`000?l0oooo0?ooo`0n0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@00000
2@3oool60000od40oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3o
ool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000<0?ooo`060000o`3o
ool0oooo0000o`3oool0003o@P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool3000000l0oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0003o0440oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100
oooo0`00000C0?ooo`040000o`3oool0oooo0?ooo`80003o@@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3o
ool0303oool3000001H0oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0400oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?oo
o`030000003oool0oooo00P0oooo0`00000J0?ooo`050000o`3oool0oooo0?ooo`000?l0@@3oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0103oool3000001h0oooo0P000?l20?ooo`030000o`3oool0oooo
03h0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008P3oool010000?l0oooo0?ooo`000?m00?oo
o`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3o
ool0S03oool2000002H0oooo0`000?m00?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo0240oooo00<0003o0?ooo`3oool0
@`3oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03o
ool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo03l0oooo0`0000020?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool0
0`000000oooo0?ooo`0S0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=@3oool4
000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo02@0oooo0P000?l20?ooo`030000o`3oool0oooo
0380oooo0`00000:0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002@0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`80003o0P3oool30000oc40
oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0003o0080oooo
00<0003o0?ooo`3oool0;@3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo
0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0280oooo00<0
003o0?ooo`3oool00P000?l00`3oool0003o0?ooo`0Z0?ooo`<000005P3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<00000
0?ooo`3oool08P3oool01@000?l0oooo0?ooo`3oool0003o02T0oooo1000000J0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0S0?ooo`040000o`3oool0oooo0000obH0oooo0`00000N0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool04@3oool002@0oooo00<000000?ooo`3oool0S@3oool0
0`000000oooo0?ooo`0T0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool07P3oool3
00000280oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02D0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0J0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0140oooo000S0?ooo`800000S`3oool00`000000oooo0?ooo`0U0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool05P3oool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000
oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0B0?ooo`@00000;P3oool00`000000oooo
0?ooo`1@0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0903oool010000?l0oooo0?ooo`3oool20000o`<0oooo00<0003o0?ooo`3oool0
3P3oool3000003<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02D0oooo0P000?l30?ooo`80003o00<0
oooo0000o`3oool0303oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo02H0oooo0`000?l3
0?ooo`80003o2P3oool3000003X0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02@0oooo0P000?l00`3o
ool0003o0000o`020000o`X0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0U0?ooo`<0
003o00<0oooo0000o`3oool01P3oool400000480oooo00<000000?ooo`3oool0C@3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02H0oooo
00<0003o0?ooo`000?l00P000?l30?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool09`3o
ool20000o`030?ooo`000?l0000000800000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003o
ool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool09@3oool0
0`000?l0oooo0?ooo`03000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool09@3oool300000080oooo00<0003o0?oo
o`3oool0C@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`80
0000T03oool00`000000oooo0?ooo`0Q0?ooo`@0000000@0003o0?ooo`3oool0003o0P3oool00`00
0?l0oooo0?ooo`1=0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<00000103oool01@000?l0
oooo0?ooo`3oool0003o0580oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<0
0000203oool010000?l0oooo0?ooo`3oool20000oe00oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool0603oool3000000`0oooo00@0003o0?ooo`3oool0oooo0P000?m@
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00000?0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0C`3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0140oooo1000000C0?ooo`80003o0P3oool00`000?l0oooo0?ooo`1@0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00000I0?ooo`<0003o
D`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000H0?ooo`030000o`3o
ool0oooo05L0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00000L0?ooo`80003oF03oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo
0900oooo00<000000?ooo`3oool0103oool400000240oooo00@0003o0?ooo`3oool0003oE@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo
0900oooo00@000000?ooo`3oool0oooo0`00000V0?ooo`040000o`3oool0oooo0000oeD0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000Z
0?ooo`80003oE`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?oo
o`800000T03oool3000002T0oooo0`000?l30?ooo`030000o`3oool0oooo05@0oooo00<000000?oo
o`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<0
00000P3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo0080003oF@3oool00`000000
oooo0?ooo`110?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo
100000050?ooo`030000003oool0oooo02L0oooo00<0003o0?ooo`3oool00P3oool20000oeP0oooo
00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?oo
o`250?ooo`<000002@3oool00`000000oooo0?ooo`0W0?ooo`030000o`3oool0oooo00<0oooo00<0
003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo02P0oooo0P000?l4
0?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0Z0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0E`3oool00`000000oooo0?ooo`0n0?oo
o`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`03
0000003oool0oooo02`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1F0?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
N03oool4000001@0oooo00<000000?ooo`3oool0;@3oool20000o`80oooo00<0003o0?ooo`3oool0
E`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo02l0oooo00@0003o0?ooo`3oool0003o
F@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo0300oooo0`000?mJ0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L03oool3
000001h0oooo00<000000?ooo`3oool0<P3oool00`000?l0oooo0?ooo`1I0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0
oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo
0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?oo
o`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g
0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?oo
o`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`03
0000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000
003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003o
ool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool0
0`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0
oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool40000
0440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0
oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo
0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo
0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?oo
o`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<00000
0?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?oo
o`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`03
0000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003o
ool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool40000
0640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo
0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<0
00000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z
0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?oo
o`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?oo
o`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0
6P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000
003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003o
ool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool0
0`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0
oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool40000
0800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0
oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo
0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<0
00000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H
0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?oo
o`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?oo
o`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo
00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo
00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003o
ool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3o
ool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?
0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`07
0?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3o
ool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D00000
0P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool00000
0?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo
0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<0
00000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<0
00000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?oo
o`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?oo
o`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3o
ool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool0
03L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`03
0000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00
>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool0
0`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool0
03h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?oo
o`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`04
0000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000
003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3o
ool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000
003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03o
ool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`00
0000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0
oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo0000
00/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0
oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080
oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<0
00000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`01
0?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?oo
o`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`80
0000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0
oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0
oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0
oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003o
ool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool2
00000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0
oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo
0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00
000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000
?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03o
ool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0
oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0
oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo
001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y
0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?oo
o`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H
0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<00000
0?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?
0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?oo
o`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00
PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003o
ool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003o
ool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool0
0`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`00
0000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0
oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo
0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G
0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?oo
o`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00
T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool0
0`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`00
0000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000
oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo
0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<0
00000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<00000
0?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S
0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:
0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`0000000000
03T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0
oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00
YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103o
ool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000
000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[
0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo
T@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.49276 .67417 m
.49132 .68085 L
s
.51662 .70413 m
.49132 .68085 L
s
.49459 .67239 m
.49276 .67417 L
s
.51662 .70413 m
.51818 .69752 L
s
.49743 .67269 m
.49459 .67239 L
s
.50006 .67395 m
.49743 .67269 L
s
.50391 .67632 m
.50006 .67395 L
s
.51818 .69752 m
.51764 .69354 L
s
.50999 .68189 m
.50391 .67632 L
s
.51764 .69354 m
.51565 .6894 L
s
.51343 .6862 m
.50999 .68189 L
s
.51565 .6894 m
.51343 .6862 L
s
.51276 .67626 m
.49569 .66064 L
s
.50543 .66955 m
.50931 .67193 L
s
.50931 .67193 m
.5122 .67223 L
s
.5122 .67223 m
.51387 .6714 L
s
.51387 .6714 m
.51454 .66847 L
s
.50234 .65023 m
.50032 .646 L
s
.50581 .65458 m
.50234 .65023 L
s
.50827 .65682 m
.50581 .65458 L
s
.50032 .646 m
.49952 .64289 L
s
.51219 .6592 m
.50827 .65682 L
s
.49952 .64289 m
.50017 .6399 L
s
.51511 .65948 m
.51219 .6592 L
s
.50017 .6399 m
.50183 .63902 L
s
.5168 .65862 m
.51511 .65948 L
s
.50183 .63902 m
.50474 .63926 L
s
.51748 .65565 m
.5168 .65862 L
s
.5184 .65166 m
.50103 .63589 L
s
.5167 .65253 m
.51748 .65565 L
s
.51467 .64827 m
.5167 .65253 L
s
.52186 .63653 m
.50344 .62475 L
s
.52001 .64463 m
.50344 .62475 L
s
.52374 .62834 m
.50521 .61656 L
s
.52186 .63653 m
.50521 .61656 L
s
.51399 .61083 m
.51169 .60752 L
s
.51755 .61529 m
.51399 .61083 L
s
.51169 .60752 m
.50962 .60315 L
s
.52389 .621 m
.51755 .61529 L
s
.50962 .60315 m
.50881 .59991 L
s
.52794 .6234 m
.52389 .621 L
s
.50881 .59991 m
.50972 .5957 L
s
.53073 .62465 m
.52794 .6234 L
s
.53376 .62487 m
.53073 .62465 L
s
.50972 .5957 m
.51145 .59472 L
s
.51145 .59472 m
.51446 .59489 L
s
.53553 .62394 m
.53376 .62487 L
s
.51989 .60483 m
.52107 .59955 L
s
.53652 .61976 m
.53553 .62394 L
s
.51446 .59489 m
.51724 .59612 L
s
.51724 .59612 m
.52107 .59955 L
s
.53573 .61651 m
.53652 .61976 L
s
.53365 .6121 m
.53573 .61651 L
s
.53022 .60008 m
.51225 .584 L
s
.53132 .60875 m
.53365 .6121 L
s
.5225 .59317 m
.5266 .59556 L
s
.5266 .59556 m
.52966 .59572 L
s
.52966 .59572 m
.53144 .59474 L
s
.53144 .59474 m
.53218 .59151 L
s
.5194 .57232 m
.51729 .56783 L
s
.52304 .57687 m
.5194 .57232 L
s
.52563 .57917 m
.52304 .57687 L
s
.51729 .56783 m
.51647 .56449 L
s
.52976 .58156 m
.52563 .57917 L
s
.51647 .56449 m
.51718 .56119 L
s
.53286 .5817 m
.52976 .58156 L
s
.51718 .56119 m
.51895 .56014 L
s
.53466 .58068 m
.53286 .5817 L
s
.51895 .56014 m
.52204 .56025 L
s
.53541 .57741 m
.53466 .58068 L
s
.53642 .57302 m
.51813 .55678 L
s
.5346 .57405 m
.53541 .57741 L
s
.53249 .56953 m
.5346 .57405 L
s
.53819 .56528 m
.51068 .54091 L
s
.52161 .54792 m
.52374 .55248 L
s
.52078 .54452 m
.52161 .54792 L
s
.52151 .54115 m
.52078 .54452 L
s
.53424 .56178 m
.53738 .56189 L
s
.52332 .54005 m
.52151 .54115 L
s
.53738 .56189 m
.53921 .56083 L
s
.52644 .54012 m
.52332 .54005 L
s
.53921 .56083 m
.53998 .55747 L
s
.53066 .54249 m
.52644 .54012 L
s
.53998 .55747 m
.53917 .55406 L
s
.53331 .54482 m
.53066 .54249 L
s
.53917 .55406 m
.53703 .54946 L
s
.53703 .54946 m
.53331 .54482 L
s
.55272 .55103 m
.52471 .52637 L
s
.53801 .53807 m
.54279 .53817 L
s
.54279 .53817 m
.54466 .53705 L
s
.54086 .52542 m
.52745 .51366 L
s
.54466 .53705 m
.54545 .5336 L
s
.54545 .5336 m
.54463 .53011 L
s
.54463 .53011 m
.54086 .52542 L
s
.54838 .52083 m
.52947 .5043 L
s
.55925 .53034 m
.55761 .53031 L
s
.55761 .53031 m
.55652 .52796 L
s
.55652 .52796 m
.55816 .52798 L
s
.53558 .49838 m
.53339 .49364 L
s
.53939 .50311 m
.53558 .49838 L
s
.55816 .52798 m
.55925 .53034 L
s
.5421 .50548 m
.53939 .50311 L
s
.53339 .49364 m
.53255 .49007 L
s
.54644 .50786 m
.5421 .50548 L
s
.53255 .49007 m
.53333 .48647 L
s
.54971 .50786 m
.54644 .50786 L
s
.53333 .48647 m
.53521 .48525 L
s
.55162 .50668 m
.54971 .50786 L
s
.53521 .48525 m
.53846 .48522 L
s
.55244 .5031 m
.55162 .50668 L
s
.55161 .49952 m
.55244 .5031 L
s
.54941 .49473 m
.55161 .49952 L
s
.53757 .47436 m
.54005 .47795 L
s
.53699 .46951 m
.53757 .47436 L
s
.53779 .46583 m
.53699 .46951 L
s
.55105 .48749 m
.54857 .48389 L
s
.55409 .48867 m
.55105 .48749 L
s
.54857 .48389 m
.54774 .48026 L
s
.54774 .48026 m
.54772 .47295 L
s
.55631 .48622 m
.55409 .48867 L
s
.53997 .46333 m
.53779 .46583 L
s
.55714 .48256 m
.55631 .48622 L
s
.543 .46448 m
.53997 .46333 L
s
.54772 .47295 m
.54688 .4693 L
s
.54438 .46567 m
.543 .46448 L
s
.54688 .4693 m
.54438 .46567 L
s
.5566 .47769 m
.55714 .48256 L
s
.55409 .47406 m
.5566 .47769 L
s
.54212 .4534 m
.541 .45096 L
s
.54378 .45335 m
.54212 .4534 L
s
.541 .45096 m
.54266 .45091 L
s
.54266 .45091 m
.54378 .45335 L
s
.57036 .47623 m
.55075 .45935 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`1K0?ooo`030000o`3oool0oooo03L0
oooo00<000000?ooo`3oool0:P3oool3000002P0oooo00<000000?ooo`3oool06@3oool002d0oooo
00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`1J0?ooo`80003o>03oool00`000000oooo
0?ooo`0W0?ooo`<00000:`3oool00`000000oooo0?ooo`0I0?ooo`00;@3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0903oool3000002h0oooo00<0
00000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`1K
0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool08@3oool300000340oooo00<00000
0?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1K0?oo
o`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool07P3oool3000003@0oooo00<000000?oo
o`3oool06@3oool002`0oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`1E0?ooo`80
003o103oool00`000?l0oooo0?ooo`0c0?ooo`030000003oool0oooo01X0oooo0`00000g0?ooo`03
0000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05/0oooo00<000000?ooo`3oool0
D`3oool010000?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3o
ool05`3oool3000003/0oooo00<000000?ooo`3oool0603oool002`0oooo0P00001M0?ooo`030000
003oool0oooo0580oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`80003o<P3oool00`000000
oooo0?ooo`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo
00<000000?ooo`3oool0D@3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3o
ool0;`3oool00`000000oooo0?ooo`0A0?ooo`<00000@@3oool00`000000oooo0?ooo`0H0?ooo`00
;03oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo0500oooo00L0003o0?ooo`3oool0
oooo0000o`3oool0003o00D0oooo00<0003o0?ooo`3oool0;P3oool00`000000oooo0?ooo`0>0?oo
o`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1P0?ooo`03
0000003oool0oooo0500oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo02d0oooo00<000000?ooo`3oool02P3oool4000004L0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`1B0?ooo`04
0000o`3oool0oooo0000ocD0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?oo
o`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1A0?ooo`05
0000o`3oool0oooo0?ooo`000?l0=03oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`00
0000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo04/0
oooo0`000?l20?ooo`040000o`3oool0oooo0000ocD0oooo00@000000?ooo`3oool0oooo0`00001B
0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool0BP3oool00`000?l0oooo0?ooo`030?ooo`80003o=P3oool4000005D0oooo00<000000?oo
o`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`180?ooo`03
0000o`3oool0oooo03X0oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0B03oool00`000?l0oooo0?ooo`0f0?ooo`<00000
0P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003o
ool0000006P0oooo00<000000?ooo`3oool0A`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo02d0oooo0`0000050?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3o
ool002X0oooo0P00001Y0?ooo`030000003oool0oooo04P0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0Y0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003oool0
oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool0A`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo02H0oooo0`00000;0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0
oooo00<000000?ooo`3oool0@`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?oo
o`3oool08`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?oo
o`3oool0@`3oool010000?l0oooo0?ooo`3oool50000ob80oooo0`00000A0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3oool000001@3oool0
0`000000oooo0?ooo`1]0?ooo`030000003oool0oooo04<0oooo00<0003o0?ooo`3oool0903oool3
000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool01000
0000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0@`3oool2
0000ob40oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool0
0200oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo03l0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0K0?ooo`<000006`3oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`00
0000oooo0?ooo`1`0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`0G0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0?`3oool20000o`<0
oooo00<0003o0?ooo`3oool04P3oool400000240oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo0400oooo
00<0003o0?ooo`3oool04P3oool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo
0?ooo`0F0?ooo`00:03oool00`000000oooo0000001d0?ooo`030000003oool0oooo03X0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0>0?ooo`<00000:03oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`0j
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool20000o`L0oooo0`00000[
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?oo
o`030000003oool0oooo07H0oooo00<000000?ooo`3oool0>P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool3000002h0oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo0000000P0?ooo`03
0000003oool0oooo07L0oooo00<000000?ooo`3oool0>P3oool01@000?l0oooo0?ooo`3oool0003o
00H0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo03X0
oooo00@0003o0?ooo`3oool0003o0`3oool3000003@0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000
oooo0?ooo`0d0?ooo`030000o`3oool0oooo0080oooo0`000?l0103oool0000000000000000g0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`0^0?ooo`060000o`3oool0oooo0?ooo`000?l0oooo0`000?l2
0?ooo`03000000000?l0000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E
0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo02h0oooo00@0003o0?oo
o`3oool0003o0`3oool00`000000003o000000020?ooo`030000o`3oool0oooo03P0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?oo
o`030000003oool0oooo02h0oooo0`000?l3000000030?ooo`000?l0oooo00<0oooo00<0003o0?oo
o`3oool0=`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3oool2000000030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0f0?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O`3oool00`000000oooo
0?ooo`0Y0?ooo`<000000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0=@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000001`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo03X0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`000007
0?ooo`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0j0?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0P`3oool0
0`000000oooo0?ooo`0L0?ooo`@000002P3oool30000o`80oooo0P000?l00`3oool0003o0?ooo`0l
0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?oo
o`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000003@3oool010000?l0oooo0?ooo`000?l3
0?ooo`80003o?P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?oo
o`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool300000100oooo00@0003o0?oo
o`3oool0oooo0P000?l30?ooo`030000o`3oool0oooo03/0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo
0100oooo0`00000D0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0?P3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0
oooo00<000000?ooo`3oool0303oool3000001L0oooo00<0003o0?ooo`3oool00P3oool20000ocl0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000K0?ooo`030000o`3oool0oooo0080oooo
0P000?ln0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<000007`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo03`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?oo
o`0C0?ooo`009@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000008`3oool0
10000?l0oooo0?ooo`000?lo0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3o
ool002D0oooo00<000000?ooo`3oool0S03oool2000002L0oooo0`000?lo0?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?ooo`030000003oool0oooo
0200oooo00<0003o0?ooo`3oool0A03oool2000005/0oooo00<000000?ooo`3oool04P3oool002D0
oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0400
oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04P3oool002D0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`030000o`3oool0oooo03/0oooo
100000060?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<0
00000?ooo`3oool0S03oool00`000000oooo0?ooo`0S0?ooo`80003o0P3oool00`000?l0oooo0?oo
o`0c0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool40000o`80oooo0`000?lb
0?ooo`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool07`3oool010000?l0oooo0?ooo`000?l3
0?ooo`030000o`3oool0oooo02h0oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0O0?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0Z0?ooo`<000005P3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo
08d0oooo00<000000?ooo`3oool07`3oool01@000?l0oooo0?ooo`3oool0003o02`0oooo1000000J
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0O0?ooo`050000o`3oool0oooo0?ooo`000?l0:@3oool3
000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo0200oooo00<0003o0?ooo`3oool0103oool00`00
0?l0oooo0?ooo`0P0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool08@3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo01`0oooo0`00000V0?ooo`030000003oool0oooo0580
oooo00<000000?ooo`3oool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo0240oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0I0?ooo`<00000:P3oool00`000000oooo
0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool07@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0503oool4000002h0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01l0oooo0P000?l3
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool04@3oool3000003<0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01l0oooo00@0003o0?ooo`000?l0003o0P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00h0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0N0?oo
o`030000o`3oool0003o0080oooo0P000?l00`3oool0003o0000o`030000o`d0oooo0`00000j0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0O0?ooo`030000o`3oool0003o00<0oooo00<0003o0?ooo`3o
ool03@3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`00
8P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01l0oooo0P000?l00`3oool0003o
0?ooo`0=0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0803oool30000o`/0oooo0`00
00170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<00000
0?ooo`3oool0SP3oool00`000000oooo0?ooo`0M0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo
0000o`070?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo
000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool07@3oool20000o`<0oooo00<0
003o0?ooo`000?l00`3oool3000004h0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0703oool010000?l0oooo0000o`00
0?l20?ooo`030000o`3oool0oooo00<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0L0?ooo`050000o`3oool0
oooo0?ooo`000?l01000001F0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03`3o
ool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0
00000080000000@0003o0?ooo`3oool0003oE`3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo01/0oooo0`0000040?ooo`030000o`3oool0oooo05L0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0?0?ooo`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0
oooo08l0oooo00<000000?ooo`3oool0603oool300000080oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`1G0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool0
01X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01D0oooo0`0000060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0F03oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000000:0?ooo`050000o`3oool0oooo0?oo
o`000?l0F`3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<0
00003`3oool40000oe`0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool3000000D0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000
3@3oool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
3`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`080?ooo`<000004@3o
ool00`000?l0oooo0?ooo`1R0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@000005@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo05d0oooo00<000000?ooo`3oool0A03oool0
0`000000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo
0?ooo`<000006P3oool20000o`030?ooo`000?l0oooo0600oooo00<000000?ooo`3oool0@`3oool0
0`000000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000000I0?ooo`<0003o0P3oool30000
of80oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900
oooo0`00000L0?ooo`030000o`3oool0oooo0080003o0P3oool00`000?l0oooo0?ooo`1P0?ooo`03
0000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
S03oool300000080oooo00<000000?ooo`3oool06@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo06<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3o
ool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`0I0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool0H`3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000003oool0
oooo01X0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0PP3oool30000
00`0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
06@0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`0L0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0I03oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo01h0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1T0?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0N03oool4000001@0oooo00<0
00000?ooo`3oool07`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo06@0oooo00<0
00000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f
0?ooo`<00000603oool00`000000oooo0?ooo`0P0?ooo`050000o`3oool0oooo0?ooo`000?l0I`3o
ool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo07<0oooo0`00000K0?ooo`030000003oool0oooo0240oooo00@0003o0?ooo`3oool0003oJ03o
ool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0
oooo0700oooo0`00000N0?ooo`030000003oool0oooo0280oooo0P000?mZ0?ooo`030000003oool0
oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`00
0000oooo0?ooo`0S0?ooo`030000o`3oool0oooo06P0oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo
00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo
0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00
000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?oo
o`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B
0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?oo
o`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?oo
o`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`03
0000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`00
7@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03o
ool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0
oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo
03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0
oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo
0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00
001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`03
0000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`00
6`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000
003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3o
ool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003o
ool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0
oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`00
0000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0
oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo
00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<0
00000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?oo
o`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`03
0000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000
003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603o
ool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003o
ool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0
oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`00
0000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0
oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0
oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?oo
o`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<0
00000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<00000
0?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?oo
o`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<0
00000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003o
ool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?oo
o`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P000004
0?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?oo
o`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`80
0000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3o
ool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0
^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo
0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P00
00040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`20
0?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`05
0?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?oo
o`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?oo
o`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<0
0000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003o
ool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool200000003
0?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000
003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool0
0`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?oo
o`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool0
04P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00
B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool0
0`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool0
04l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`00
0000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0
oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo
0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000
oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?oo
o`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A
0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?oo
o`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000
oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0
oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000
003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003o
ool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo
0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440
oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<0
00000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`38
0?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?oo
o`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@0
00006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03o
ool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2
000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0
oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo
0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?oo
o`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M
0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a
0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?
0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?oo
o`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;
0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<00000
0?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?oo
o`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000
G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000
H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3o
ool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo
00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo
0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?oo
o`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3o
ool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000
T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3o
ool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool01000
0000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`00
0000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0
oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo
00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300
oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo
0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?oo
o`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00
002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;
0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S
0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?oo
o`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3o
ool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000
bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool0
1@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`00
00060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O
0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?oo
o`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.45806 .66818 m
.45428 .67458 L
s
.47831 .70081 m
.45428 .67458 L
s
.47831 .70081 m
.4822 .69449 L
s
.46083 .66667 m
.45806 .66818 L
s
.46422 .66733 m
.46083 .66667 L
s
.46707 .66892 m
.46422 .66733 L
s
.4822 .69449 m
.48272 .69051 L
s
.47108 .67176 m
.46707 .66892 L
s
.48272 .69051 m
.48152 .68617 L
s
.47686 .67805 m
.47108 .67176 L
s
.48152 .68617 m
.47977 .68274 L
s
.47977 .68274 m
.47686 .67805 L
s
.48193 .67286 m
.4657 .65523 L
s
.47496 .66529 m
.479 .66815 L
s
.479 .66815 m
.48245 .66881 L
s
.48245 .66881 m
.48474 .66822 L
s
.48474 .66822 m
.48644 .66542 L
s
.47992 .6506 m
.47698 .64585 L
s
.48226 .65313 m
.47992 .6506 L
s
.47698 .64585 m
.47576 .64142 L
s
.48634 .65599 m
.48226 .65313 L
s
.47576 .64142 m
.47572 .63826 L
s
.48982 .65665 m
.48634 .65599 L
s
.47572 .63826 m
.47741 .63539 L
s
.49214 .65603 m
.48982 .65665 L
s
.47741 .63539 m
.47971 .63475 L
s
.49387 .65319 m
.49214 .65603 L
s
.47971 .63475 m
.4832 .63537 L
s
.49617 .64939 m
.47967 .63156 L
s
.49384 .65002 m
.49387 .65319 L
s
.49263 .64556 m
.49384 .65002 L
s
.50493 .63497 m
.48595 .62092 L
s
.50024 .6427 m
.48595 .62092 L
s
.50966 .62718 m
.49057 .61309 L
s
.50493 .63497 m
.49057 .61309 L
s
.50602 .61352 m
.503 .60866 L
s
.51204 .61999 m
.50602 .61352 L
s
.503 .60866 m
.50119 .60508 L
s
.50119 .60508 m
.49996 .6005 L
s
.51625 .62288 m
.51204 .61999 L
s
.49996 .6005 m
.49994 .59721 L
s
.51927 .62449 m
.51625 .62288 L
s
.49994 .59721 m
.50231 .59319 L
s
.5229 .62511 m
.51927 .62449 L
s
.52533 .62444 m
.5229 .62511 L
s
.50231 .59319 m
.50471 .59247 L
s
.52777 .62047 m
.52533 .62444 L
s
.50471 .59247 m
.50833 .59305 L
s
.51199 .60356 m
.515 .59853 L
s
.50833 .59305 m
.51136 .59463 L
s
.52778 .61718 m
.52777 .62047 L
s
.51136 .59463 m
.515 .59853 L
s
.52657 .61257 m
.52778 .61718 L
s
.52474 .60896 m
.52657 .61257 L
s
.52598 .6003 m
.5089 .58204 L
s
.51865 .59246 m
.52292 .59536 L
s
.52292 .59536 m
.5266 .59595 L
s
.5266 .59595 m
.52906 .59522 L
s
.52906 .59522 m
.53092 .59216 L
s
.52417 .57653 m
.52109 .57156 L
s
.52663 .57915 m
.52417 .57653 L
s
.52109 .57156 m
.51986 .56686 L
s
.53095 .58206 m
.52663 .57915 L
s
.51986 .56686 m
.51986 .56347 L
s
.53467 .58263 m
.53095 .58206 L
s
.51986 .56347 m
.52171 .56033 L
s
.53716 .58188 m
.53467 .58263 L
s
.52171 .56033 m
.52419 .55955 L
s
.53905 .57877 m
.53716 .58188 L
s
.52419 .55955 m
.52791 .56008 L
s
.54158 .5746 m
.52419 .55613 L
s
.53907 .57537 m
.53905 .57877 L
s
.53785 .57064 m
.53907 .57537 L
s
.54604 .56726 m
.51985 .5395 L
s
.53106 .54792 m
.5323 .55269 L
s
.53107 .54447 m
.53106 .54792 L
s
.54228 .56328 m
.54606 .56383 L
s
.53296 .54126 m
.53107 .54447 L
s
.54606 .56383 m
.5486 .56304 L
s
.53548 .54044 m
.53296 .54126 L
s
.5486 .56304 m
.55053 .55986 L
s
.53927 .54095 m
.53548 .54044 L
s
.55053 .55986 m
.55056 .5564 L
s
.54368 .54387 m
.53927 .54095 L
s
.55056 .5564 m
.54933 .5516 L
s
.5462 .54653 m
.54368 .54387 L
s
.54933 .5516 m
.5462 .54653 L
s
.56789 .55533 m
.54125 .52722 L
s
.55391 .54058 m
.55968 .54135 L
s
.55968 .54135 m
.56227 .54052 L
s
.56227 .54052 m
.56426 .53725 L
s
.56113 .52859 m
.54837 .51516 L
s
.56426 .53725 m
.5643 .53372 L
s
.5643 .53372 m
.56113 .52859 L
s
.57159 .52517 m
.55361 .50628 L
s
.58191 .536 m
.57994 .53575 L
s
.57994 .53575 m
.57933 .53329 L
s
.57933 .53329 m
.5813 .53354 L
s
.5813 .53354 m
.58191 .536 L
s
.56598 .50654 m
.56277 .50136 L
s
.56856 .50925 m
.56598 .50654 L
s
.56277 .50136 m
.56153 .4964 L
s
.57311 .5122 m
.56856 .50925 L
s
.56153 .4964 m
.56157 .49279 L
s
.57706 .51267 m
.57311 .5122 L
s
.56157 .49279 m
.56358 .48938 L
s
.57972 .51178 m
.57706 .51267 L
s
.56358 .48938 m
.56623 .48846 L
s
.58177 .50841 m
.57972 .51178 L
s
.56623 .48846 m
.57018 .4889 L
s
.58184 .50478 m
.58177 .50841 L
s
.5806 .49979 m
.58184 .50478 L
s
.57233 .47815 m
.57426 .48202 L
s
.57307 .47332 m
.57233 .47815 L
s
.58473 .49295 m
.5828 .48907 L
s
.58804 .49454 m
.58473 .49295 L
s
.5828 .48907 m
.58286 .4854 L
s
.57512 .46983 m
.57307 .47332 L
s
.59144 .49247 m
.58804 .49454 L
s
.58286 .4854 m
.58501 .47825 L
s
.5785 .46771 m
.57512 .46983 L
s
.59354 .48902 m
.59144 .49247 L
s
.58501 .47825 m
.58508 .47456 L
s
.58182 .46928 m
.5785 .46771 L
s
.59432 .48417 m
.59354 .48902 L
s
.58508 .47456 m
.58314 .47065 L
s
.58314 .47065 m
.58182 .46928 L
s
.59238 .48026 m
.59432 .48417 L
s
.58405 .45833 m
.58342 .45577 L
s
.58607 .45852 m
.58405 .45833 L
s
.58342 .45577 m
.58545 .45596 L
s
.58545 .45596 m
.58607 .45852 L
s
.61134 .48475 m
.5927 .4654 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo06P0oooo0P00
0?lY0?ooo`030000003oool0oooo02@0oooo0`00000^0?ooo`030000003oool0oooo01T0oooo000/
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0J03oool00`000?l0oooo0?ooo`0W
0?ooo`030000003oool0oooo0240oooo0`00000a0?ooo`030000003oool0oooo01T0oooo000/0?oo
o`030000003oool0oooo05T0oooo00<000000?ooo`3oool0T@3oool00`000000oooo0?ooo`0N0?oo
o`<00000=03oool00`000000oooo0?ooo`0I0?ooo`00;03oool00`000000oooo0?ooo`1J0?ooo`03
0000003oool0oooo0940oooo00<000000?ooo`3oool06P3oool3000003L0oooo00<000000?ooo`3o
ool06@3oool002`0oooo00<000000?ooo`3oool0F`3oool00`000000oooo0?ooo`1S0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0H03o
ool20000o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`3oool0903oool00`000000oooo0?oo
o`0D0?ooo`<00000?P3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool2000005l0oooo00<00000
0?ooo`3oool0G`3oool010000?l0oooo0?ooo`000?l50?ooo`030000o`3oool0oooo02<0oooo00<0
00000?ooo`3oool04@3oool300000440oooo00<000000?ooo`3oool0603oool002`0oooo00<00000
0?ooo`3oool0GP3oool00`000000oooo0?ooo`1N0?ooo`050000o`3oool0oooo0?ooo`000?l01@3o
ool00`000?l0oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003o
ool0oooo01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0G03oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool08@3oool0
0`000000oooo0?ooo`0:0?ooo`@00000A`3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`00
0000oooo0?ooo`1Q0?ooo`030000003oool0oooo05/0oooo00<0003o0?ooo`3oool00P3oool01000
0?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo0200oooo00<000000?ooo`3oool01`3oool3
000004/0oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`00
0000oooo0?ooo`1K0?ooo`040000o`3oool0oooo0000o`<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo00@0oooo0`00001>0?ooo`030000003oool0
oooo01P0oooo000[0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0G@3oool01@00
0?l0oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool07P3oool010000000oooo0?ooo`3o
ool300000580oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I03oool0
0`000000oooo0?ooo`1F0?ooo`80003o103oool01@000?l0oooo0?ooo`3oool0003o02L0oooo1000
001E0?ooo`030000003oool0oooo01L0oooo000[0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool0E03oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0000obH0oooo0`00
001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06L0oooo00<00000
0?ooo`3oool0DP3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0003o02<0oooo0`000002
0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?oo
o`000000J03oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool07`3oool3000000D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?oo
o`00:P3oool2000006T0oooo00<000000?ooo`3oool0D@3oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo01l0oooo0`0000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1A0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0703oool3000000/0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3o
ool00`000000oooo0?ooo`1@0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0603o
ool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00803oool0
10000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool0B`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05@3o
ool300000140oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool0B`3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool04P3o
ool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool0B`3o
ool00`000?l0oooo0?ooo`020?ooo`@0003o4P3oool3000001P0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo01@0oooo0`00000K0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3o
ool00240oooo0P0000060?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool0AP3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo0`00000N0?ooo`030000003oool0
oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`00
0000oooo0?ooo`160?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool40000
0240oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000
oooo0?ooo`1b0?ooo`030000003oool0oooo04H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`070?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0AP3oool00`000?l0oooo
0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0`00000X0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo03l0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`<00000:`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f
0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`3o
ool3000002h0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool0
0`000000oooo0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0?`3oool0
0`000?l0oooo0?ooo`030?ooo`030000o`000000000000<0oooo0P000?l/0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`00
0000oooo0?ooo`1h0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`0000000P0000000`00
0?l0oooo0?ooo`030?ooo`80003o;03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000003oool0oooo03<0
oooo00<0003o0?ooo`3oool01`3oool2000000050000o`3oool0oooo0?ooo`000?l0<`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0
oooo00<000000?ooo`3oool0<`3oool010000?l0oooo0?ooo`3oool30000o`8000000P3oool50000
oc<0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000
oooo0?ooo`1l0?ooo`030000003oool0oooo03<0oooo00<0003o0?ooo`000?l00P0000000`3oool0
003o0000o`040?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo
00@000000000o`000000003o1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0380
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo
0?ooo`1n0?ooo`030000003oool0oooo02d0oooo0`0000020?ooo`80003o1@3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`00
00060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`0`0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`000021
0?ooo`030000003oool0oooo02D0oooo0`0000060?ooo`050000o`3oool0oooo0?ooo`000?l01@3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0240oooo0`00000:0?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000?l0oooo0?oo
o`0f0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo00<00000
0?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000002`3oool40000o`<0oooo00D0003o
0?ooo`3oool0oooo0000o`0i0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503o
ool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<000003`3oool0
1@000?l0oooo0?ooo`3oool0003o0080oooo10000?lj0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`0D
0?ooo`<000004P3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000oc`0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`26
0?ooo`030000003oool0oooo0100oooo0`00000E0?ooo`030000o`3oool0oooo00<0oooo00@0003o
0?ooo`3oool0003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V
0?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0303oool3000001P0oooo00<0003o
0?ooo`3oool00`3oool20000ocd0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000K0?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l0?03oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool3000001l0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0k0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0
R`3oool00`000000oooo0?ooo`03000002<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0k0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0S03oool200000200oooo00<0003o0?ooo`3oool0103oool40000och0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool0803oool00`000?l0oooo0?ooo`140?ooo`800000F`3oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0240oooo00<0003o0?oo
o`3oool0@03oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B0?oo
o`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0280oooo00<0003o0?ooo`3o
ool0>`3oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01`0oooo0`000?l30?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003o
ool0oooo01/0oooo00@0003o0?ooo`3oool0oooo0P000?l20?ooo`@0003o<`3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?oo
o`000?lb0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo0180oooo
000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool06`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0;03oool3000001H0oooo00<0
00000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=
0?ooo`030000003oool0oooo01/0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0]
0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`0^0?oo
o`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0703oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0280oooo0`00000R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0M0?ooo`030000
o`3oool0oooo00D0oooo00<0003o0?ooo`3oool07`3oool3000002H0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0603o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0703o
ool3000002X0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo01T0oooo0P000?l40?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool05`3oool4000002h0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo
01X0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
01@0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0G0?ooo`070000o`3oool0oooo0?oo
o`000?l0oooo0000o`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool04@3oool3
000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo01P0oooo0P000?l0103oool0003o0?ooo`3oool2
0000o`<0oooo10000?lA0?ooo`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0603oool01@00
0?l0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool04P3oool3000003h0oooo00<00000
0?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo01T0oooo00D0003o0?ooo`000?l0oooo0000o`0C0?ooo`@00000@P3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo
08h0oooo00<000000?ooo`3oool05@3oool01@000?l0oooo0?ooo`3oool0003o0080oooo0P000?l@
0?ooo`<00000A`3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0503oool30000o`<0oooo00D0003o0?oo
o`3oool0oooo0000o`0<0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0
oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04`3oool01@00
0?l0oooo0?ooo`3oool0003o00<0oooo00<0003o0?ooo`3oool02P3oool3000004h0oooo00<00000
0?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?oo
o`3oool04`3oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0000o`T0oooo0`00001B
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?oo
o`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?l4
0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?oo
o`030000003oool0oooo08l0oooo00<000000?ooo`3oool0503oool00`000?l0oooo0?ooo`030?oo
o`040000o`3oool0oooo0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01@0oooo00<0003o0?ooo`3oool00`3oool010000?l0000000000000001N0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool0
0`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool00`00001R
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00l0oooo00<0003o0?oo
o`3oool00`3oool300000080oooo00<0003o0?ooo`3oool0H@3oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`03
0000003oool0oooo0100oooo00<0003o0000000000000P0000020?ooo`<0003oI@3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo00l0oooo000H0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0>0?ooo`<0000000<0003o0?ooo`3oool0
K03oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`0000040?ooo`030000o`3o
ool0oooo06/0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`0000080?ooo`050000o`3oool0
oooo0?ooo`000?l0J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0103oool4000000D0oooo0`000?l4
0?ooo`040000o`3oool0oooo0000ofX0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<00000203o
ool01@000?l0oooo0?ooo`3oool0003o00@0oooo0P000?m/0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@000002`3oool00`000?l0oooo0?oo
o`020?ooo`80003o0`3oool00`000?l0oooo0?ooo`1[0?ooo`030000003oool0oooo0480oooo00<0
00000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<000003@3oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0oooo06h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`0<0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0KP3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08P0oooo100000050?ooo`03
0000003oool0oooo00d0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1_0?ooo`03
0000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0
Q@3oool3000000T0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo06l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`0?0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0L03oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo07l0oooo0`00000?0?ooo`030000003oool0
oooo0100oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1a0?ooo`030000003oool0
oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool30000
0140oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0700oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`0C0?ooo`050000o`3oool0oooo0?oo
o`000?l0L`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo000N0?ooo`03
0000003oool0oooo07H0oooo0`00000H0?ooo`030000003oool0oooo01@0oooo00<0003o0?ooo`00
0?l0M@3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool0
M@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003o
ool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3o
ool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`00
0000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0
oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<00000
0?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?oo
o`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?oo
o`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<0
0000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3o
ool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0
U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003o
ool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool0
0`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool0
01`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0
oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0
oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo
00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?oo
o`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<00000
0?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?oo
o`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<0
0000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0
W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003o
ool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3o
ool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool0
0`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool0
01/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`00
0000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0
oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00
000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<00000
0?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?oo
o`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<0
0000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0
YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003o
ool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool0
0`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool0
01T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0
oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo
0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<0
00000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@
0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`08
0?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo
1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0
[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo
00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000
TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
1`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<0
00000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R
0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?oo
o`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`80
00002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0
oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0
oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000
oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000oooo
0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<0
00000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<00000
0?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?oo
o`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3o
ool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003o
ool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<000000?oo
o`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`80
0000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool2
00000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`35
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@000000?oo
o`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3o
ool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000
J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
0`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
04T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3o
ool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000
HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
0P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0
oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool20000
00/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool0
0`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`00
0000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0
oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo
0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I
0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?oo
o`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool20000
0500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`00
0000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600
oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`000000
0P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3o
ool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool40000
00D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40
oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo
001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<00000
0?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`03
0000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000
003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3o
ool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5
000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool40000
0340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo
00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00
000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@00000
0?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@00
00120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?oo
o`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?oo
o`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y
0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`80
0000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool0
00009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`000000
9P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003o
ool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`00
0000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0
oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo
100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo1000
00240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`80
00006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003o
ool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003o
ool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0
oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo
03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0
oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo
0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000
000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000
002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<0
00000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool20000
00030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`80
00001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000
003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo
1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`00
00020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00
o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.42583 .65821 m
.41982 .66407 L
s
.44169 .69314 m
.41982 .66407 L
s
.44169 .69314 m
.44779 .68737 L
s
.42947 .65707 m
.42583 .65821 L
s
.43329 .65816 m
.42947 .65707 L
s
.44779 .68737 m
.44937 .68349 L
s
.43626 .6601 m
.43329 .65816 L
s
.44937 .68349 m
.44903 .67904 L
s
.44028 .66344 m
.43626 .6601 L
s
.44903 .67904 m
.4478 .67542 L
s
.44553 .6704 m
.44028 .66344 L
s
.4478 .67542 m
.44553 .6704 L
s
.45274 .66591 m
.43798 .64635 L
s
.44641 .65753 m
.45046 .66087 L
s
.45046 .66087 m
.45434 .66198 L
s
.45434 .66198 m
.45717 .66168 L
s
.45717 .66168 m
.45984 .65913 L
s
.4558 .64362 m
.4535 .63854 L
s
.45792 .64643 m
.4558 .64362 L
s
.46201 .64979 m
.45792 .64643 L
s
.4535 .63854 m
.45316 .63399 L
s
.46593 .65089 m
.46201 .64979 L
s
.45316 .63399 m
.45387 .63085 L
s
.45387 .63085 m
.45655 .62824 L
s
.46879 .65058 m
.46593 .65089 L
s
.4715 .64799 m
.46879 .65058 L
s
.45655 .62824 m
.45941 .6279 L
s
.45941 .6279 m
.46335 .62898 L
s
.47224 .64485 m
.4715 .64799 L
s
.47512 .64454 m
.46014 .62474 L
s
.47191 .64029 m
.47224 .64485 L
s
.4815 .63845 m
.47008 .61504 L
s
.48885 .63143 m
.47008 .61504 L
s
.48885 .63143 m
.47738 .60792 L
s
.49626 .62435 m
.47738 .60792 L
s
.49531 .61039 m
.49298 .60519 L
s
.50077 .61757 m
.49531 .61039 L
s
.49298 .60519 m
.49173 .60142 L
s
.50498 .62098 m
.50077 .61757 L
s
.49173 .60142 m
.49141 .59674 L
s
.50811 .62296 m
.50498 .62098 L
s
.49141 .59674 m
.49218 .59348 L
s
.51218 .62405 m
.50811 .62296 L
s
.49218 .59348 m
.49592 .58983 L
s
.51517 .6237 m
.51218 .62405 L
s
.51897 .62011 m
.51517 .6237 L
s
.49592 .58983 m
.49889 .58944 L
s
.50469 .60135 m
.50942 .5968 L
s
.49889 .58944 m
.50297 .59049 L
s
.51978 .61687 m
.51897 .62011 L
s
.50297 .59049 m
.50612 .59246 L
s
.51948 .61217 m
.51978 .61687 L
s
.50612 .59246 m
.50942 .5968 L
s
.51823 .60837 m
.51948 .61217 L
s
.52176 .6 m
.50629 .57971 L
s
.51512 .5913 m
.5194 .59473 L
s
.5194 .59473 m
.52353 .59579 L
s
.52353 .59579 m
.52656 .59541 L
s
.52656 .59541 m
.52946 .59264 L
s
.52539 .57634 m
.52302 .57103 L
s
.52762 .57925 m
.52539 .57634 L
s
.53193 .5827 m
.52762 .57925 L
s
.52302 .57103 m
.52272 .56623 L
s
.53611 .58375 m
.53193 .5827 L
s
.52272 .56623 m
.52354 .56289 L
s
.52354 .56289 m
.52645 .56005 L
s
.53919 .58335 m
.53611 .58375 L
s
.54212 .58054 m
.53919 .58335 L
s
.52645 .56005 m
.52951 .55961 L
s
.52951 .55961 m
.53371 .56065 L
s
.54297 .5772 m
.54212 .58054 L
s
.54606 .57679 m
.53034 .55625 L
s
.54269 .57238 m
.54297 .5772 L
s
.55299 .57017 m
.52932 .53928 L
s
.5403 .54911 m
.54058 .55397 L
s
.5496 .56575 m
.55385 .56679 L
s
.54114 .54571 m
.5403 .54911 L
s
.54411 .54282 m
.54114 .54571 L
s
.55385 .56679 m
.55697 .56637 L
s
.55697 .56637 m
.55997 .5635 L
s
.54723 .54236 m
.54411 .54282 L
s
.55149 .54338 m
.54723 .54236 L
s
.55997 .5635 m
.56084 .5601 L
s
.56084 .5601 m
.56057 .55522 L
s
.55589 .54685 m
.55149 .54338 L
s
.56057 .55522 m
.55817 .54981 L
s
.55817 .54981 m
.55589 .54685 L
s
.5811 .5614 m
.55709 .53016 L
s
.56851 .54502 m
.57499 .54656 L
s
.57499 .54656 m
.57818 .54611 L
s
.57818 .54611 m
.58126 .54317 L
s
.58126 .54317 m
.58216 .53971 L
s
.57973 .53424 m
.56823 .51929 L
s
.58216 .53971 m
.57973 .53424 L
s
.59261 .53233 m
.57641 .51131 L
s
.60189 .54436 m
.59968 .54384 L
s
.59968 .54384 m
.59957 .54135 L
s
.59957 .54135 m
.60177 .54187 L
s
.60177 .54187 m
.60189 .54436 L
s
.59061 .51329 m
.58816 .50776 L
s
.59293 .5163 m
.59061 .51329 L
s
.59747 .51982 m
.59293 .5163 L
s
.58816 .50776 m
.58792 .50272 L
s
.60189 .52083 m
.59747 .51982 L
s
.58792 .50272 m
.58884 .49918 L
s
.58884 .49918 m
.59197 .49613 L
s
.60517 .52034 m
.60189 .52083 L
s
.60833 .51731 m
.60517 .52034 L
s
.59197 .49613 m
.59523 .4956 L
s
.59523 .4956 m
.59968 .49658 L
s
.60928 .51377 m
.60833 .51731 L
s
.60905 .50871 m
.60928 .51377 L
s
.60473 .48635 m
.60602 .49042 L
s
.60674 .48172 m
.60473 .48635 L
s
.61543 .50259 m
.61414 .49852 L
s
.61886 .50461 m
.61543 .50259 L
s
.61414 .49852 m
.6151 .49494 L
s
.62325 .50306 m
.61886 .50461 L
s
.60993 .4786 m
.60674 .48172 L
s
.6151 .49494 m
.61928 .48825 L
s
.62648 .49997 m
.62325 .50306 L
s
.61432 .477 m
.60993 .4786 L
s
.61928 .48825 m
.62024 .48464 L
s
.62854 .49535 m
.62648 .49997 L
s
.61776 .47901 m
.61432 .477 L
s
.62024 .48464 m
.61895 .48054 L
s
.61895 .48054 m
.61776 .47901 L
s
.62725 .49125 m
.62854 .49535 L
s
.62294 .46861 m
.62283 .46602 L
s
.62521 .46909 m
.62294 .46861 L
s
.62283 .46602 m
.6251 .4665 L
s
.6251 .4665 m
.62521 .46909 L
s
.64788 .4983 m
.63117 .47677 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`1c0?ooo`80003o6`3oool00`000000oooo0?ooo`0G0?ooo`<00000
>`3oool00`000000oooo0?ooo`0H0?ooo`00;03oool2000005d0oooo00<000000?ooo`3oool0LP3o
ool20000oa/0oooo00<000000?ooo`3oool0503oool3000003h0oooo00<000000?ooo`3oool0603o
ool002/0oooo0P00001O0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool04@3oool3
00000440oooo00<000000?ooo`3oool0603oool002`0oooo00<000000?ooo`3oool0GP3oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0K03oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo01L0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`1Y0?ooo`80003o00<0oooo0000o`000?l0103oool00`000?l0oooo0?ooo`0F0?ooo`030000
003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo000[0?ooo`030000003o
ool0oooo0680oooo00<000000?ooo`3oool0I`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`040?ooo`<00000CP3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo06D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01D0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003oool0oooo01L0oooo000[
0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0I03oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0503oool4000005D0oooo00<00000
0?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`1T0?oo
o`050000o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0
oooo0140oooo0`00001H0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo
06L0oooo00<000000?ooo`3oool0I`3oool01@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o
0?ooo`3oool03P3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo05d0oooo0`000?l50?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?oo
o`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`80
0000J@3oool00`000000oooo0?ooo`1K0?ooo`80003o203oool01@000?l0oooo0?ooo`3oool0003o
00L0oooo00<0003o0?ooo`3oool01P3oool3000000P0oooo00<000000?ooo`3oool0EP3oool00`00
0000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003oool0oooo05X0
oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00d0oooo0`00000;0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool0F@3oool00`000?l0oooo0?ooo`070?ooo`@0
003o2`3oool3000000h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00
803oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3o
ool0F03oool00`000?l0oooo0?ooo`0C0?ooo`<000004@3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3o
ool0K@3oool00`000000oooo0?ooo`1G0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool0203oool3000001@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00
803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3o
ool0DP3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3o
ool01@3oool3000001P0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00
803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06l0oooo00<000000?ooo`3o
ool0DP3oool01@000?l0oooo0?ooo`3oool0003o00H0oooo00<0003o0?ooo`3oool00P3oool30000
01/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`008@3oool2000000H0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1A0?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo00000002000001h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo04`0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`D0003o
0P00000Q0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<0
00000?ooo`3oool0LP3oool00`000000oooo0?ooo`1<0?ooo`030000o`3oool0oooo0080oooo00@0
003o0?ooo`3oool0oooo0`00000U0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
5P3oool002P0oooo00<000000?ooo`000000M03oool00`000000oooo0?ooo`1<0?ooo`030000o`3o
ool0oooo0080oooo00<0003o000000000000:03oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1;0?ooo`030000o`3oool0
00000080000000<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo
04@0oooo00<0003o0?ooo`3oool00P3oool2000000030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool09`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`03
0000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`140?ooo`04
0000o`0000000000000000<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0V0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo0440oooo0`0000000`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo02/0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo
0?ooo`0f0?ooo`030000o`3oool0oooo00@0oooo0`0000030?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool0:P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo
000X0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0=P3oool00`000?l0oooo0?oo
o`03000000030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`80003o9@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W
0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0=@3oool00`000?l0000000000002
0?ooo`040000o`3oool0003o0000o`D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`80003o9@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W
0?ooo`030000003oool0oooo07d0oooo00<000000?ooo`3oool0<@3oool3000000050?ooo`000?l0
oooo0?ooo`000?l0103oool00`000?l0oooo0?ooo`030?ooo`@0003o;@3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<00000
0?ooo`3oool0;@3oool3000000D0oooo0P000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool0;@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?oo
o`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3000000T0oooo00<0003o0?oo
o`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02`0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3o
ool09@3oool3000000`0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo02`0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000<0?ooo`050000
o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02/0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000=0?ooo`@0003o0`3oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0:`3oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08@0oooo00<0
00000?ooo`3oool0603oool300000100oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool0<`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503o
ool3000001<0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool50000ocH0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0100oooo0`00000F0?ooo`030000o`3oool0oooo00<0oooo00D0
003o0?ooo`3oool0oooo0000o`0i0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000006@3o
ool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l0>03oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08P0oooo00<0
00000?ooo`3oool0203oool3000001`0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`0j0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000803oool00`000?l0oooo0?ooo`03
0?ooo`80003o>`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000L0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0j0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool200000200
oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o03`0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<000000?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`060?ooo`<0003o?03oool2000005/0oooo00<000000?ooo`3o
ool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0P0?ooo`030000
o`3oool0oooo0440oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0J0?ooo`<0003o0`3o
ool00`000?l0oooo0?ooo`0m0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0603oool2
0000o`<0oooo0P000?l20?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0=03oool3
000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool00`3oool01000
0?l0oooo0?ooo`3oool40000oc@0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0H0?oo
o`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3oool0003o=03oool300000180oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?oo
o`030000003oool0oooo01P0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo00<0003o0?oo
o`3oool0;P3oool3000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?oo
o`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01P0oooo00<0003o0?ooo`3o
ool0=@3oool4000001X0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool0
<@3oool3000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02D0oooo0`00000R0?ooo`030000003o
ool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0C0?ooo`80003o1@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0240oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool04@3oool0
02<0oooo0P00002?0?ooo`030000003oool0oooo0100oooo00@0003o0?ooo`3oool0oooo0P000?l5
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool07P3oool3000002X0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo0100oooo0P000?l20?ooo`040000o`3oool0003o0000o`@0oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0J0?ooo`@00000;P3oool00`000000oooo0?ooo`1@
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool04P3oool20000o`80oooo00@0003o0?ooo`3oool0003o0`3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo01P0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo00<00000
0?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0B0?oo
o`050000o`3oool0003o0?ooo`000?l00`3oool010000?l0oooo0?ooo`3oool20000o`80oooo00<0
003o0?ooo`3oool05P3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?oo
o`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00d0oooo00<0003o
0?ooo`3oool00`3oool01@000?l0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool00P3o
ool30000oaD0oooo0`00000j0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0<0?ooo`<0003o103oool0
0`000?l0oooo0?ooo`020000oad0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0;0?oo
o`030000o`3oool0oooo0080003o103oool00`000?l0oooo0?ooo`020000oaP0oooo100000120?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0SP3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3o
ool0oooo0000o`030?ooo`030000o`3oool0oooo01<0oooo0`0000170?ooo`030000003oool0oooo
04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0C0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100
oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo
0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l04P3oool3000004h0oooo00<000000?ooo`3o
ool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0oooo00<000000?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo0`00001B0?ooo`030000
003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240oooo0P00002@0?ooo`030000003o
ool0oooo00`0oooo00<0003o0?ooo`3oool00`3oool20000o`d0oooo1000001F0?ooo`030000003o
ool0oooo04X0oooo00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool0
0`000000oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool0
0`000?l0oooo0?ooo`090?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
00H0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o00P0oooo0`00001N
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?oo
o`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00L0oooo00<0003o
0?ooo`3oool01@3oool30000o`H0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool03`3oool001X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo00P0oooo00<0003o0?ooo`3oool02P3oool3000006H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool01P3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00
603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00H000000?ooo`3oool0
oooo0000o`3oool30000o`<0oooo00D0003o0?ooo`3oool0oooo0000o`03000006l0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?oo
o`3oool0T03oool010000000oooo0000o`000?l40?ooo`030000o`3oool0oooo0080oooo00@0003o
0000000000000000LP3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000P
0?ooo`030000003oool0oooo0900oooo00<000000000o`3oool01P3oool00`000?l0oooo00000002
000000030000o`3oool0oooo07<0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0003o00@0oooo1000001j0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3o
ool0T03oool010000000oooo0?ooo`000?l3000000@0oooo00<0003o0?ooo`3oool0N03oool00`00
0000oooo0?ooo`130?ooo`030000003oool0oooo00h0oooo000P0?ooo`800000T@3oool4000000L0
oooo00<0003o0?ooo`3oool0N@3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0
oooo000O0?ooo`800000T03oool3000000<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`1h0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool03P3oool001l0oooo00<0
00000?ooo`3oool0S03oool300000080oooo00<000000?ooo`3oool00P3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo07T0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0NP3oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?oo
o`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1k0?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3o
ool0PP3oool3000000`0oooo00<000000?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o
07h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`050?ooo`040000o`3oool0oooo0000
oh00oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1l0?ooo`<000004@3oool00`000000oooo0?ooo`070?ooo`030000o`3oool0003o0800
oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo0800oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3o
ool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0
oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@0
0000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0
U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3o
ool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0
oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@0
0000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool0
0`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool0
01X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?oo
o`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@0
0000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003o
ool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080
oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool20000
08l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@00
00020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`00
0000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800
oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0
oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?oo
o`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo
00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo
000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000
oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo
00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0015
0?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<
0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00
A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000
FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool0
0`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo
0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00
G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00
G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`000000
0`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?oo
o`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00
IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5
000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00
000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l
0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?oo
o`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3o
ool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool0
06T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0
oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`00
0000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000
oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool50000
04l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0
oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo
00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@00000
0?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<00000
0?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?oo
o`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool00000
7`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003o
ool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0
oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo
002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?oo
o`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?oo
o`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`03
0000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000
003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool00000
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003o
ool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool0
0`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`00
0000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo
02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool20000
00X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo00000000
0000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00
Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo
002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P000004
0?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0
000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool0
0:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.39733 .64455 m
.38926 .64962 L
s
.40812 .68133 m
.38926 .64962 L
s
.40812 .68133 m
.41625 .67636 L
s
.4017 .64388 m
.39733 .64455 L
s
.41625 .67636 m
.41885 .6727 L
s
.40583 .64546 m
.4017 .64388 L
s
.41885 .6727 m
.41938 .66823 L
s
.4088 .64776 m
.40583 .64546 L
s
.41938 .66823 m
.41874 .66447 L
s
.41268 .65159 m
.4088 .64776 L
s
.41874 .66447 m
.4172 .65919 L
s
.4172 .65919 m
.41268 .65159 L
s
.42632 .65564 m
.41362 .6343 L
s
.42087 .64649 m
.42477 .65034 L
s
.42477 .65034 m
.42895 .65193 L
s
.42895 .65193 m
.43222 .652 L
s
.43222 .652 m
.43577 .6498 L
s
.43441 .63387 m
.43286 .62853 L
s
.43623 .63693 m
.43441 .63387 L
s
.44016 .6408 m
.43623 .63693 L
s
.43286 .62853 m
.43341 .62397 L
s
.44438 .64239 m
.44016 .6408 L
s
.43341 .62397 m
.43487 .62094 L
s
.44768 .64245 m
.44438 .64239 L
s
.43487 .62094 m
.43845 .61869 L
s
.45128 .64023 m
.44768 .64245 L
s
.43845 .61869 m
.44175 .61872 L
s
.45276 .6372 m
.45128 .64023 L
s
.44175 .61872 m
.44598 .6203 L
s
.45333 .63263 m
.45276 .6372 L
s
.45608 .63726 m
.44323 .61568 L
s
.46454 .63203 m
.45648 .60735 L
s
.47428 .62602 m
.45648 .60735 L
s
.47428 .62602 m
.4662 .60123 L
s
.48408 .61997 m
.4662 .60123 L
s
.4859 .60602 m
.48434 .60057 L
s
.49056 .61383 m
.4859 .60602 L
s
.49459 .61776 m
.49056 .61383 L
s
.48434 .60057 m
.48371 .59667 L
s
.49769 .62012 m
.49459 .61776 L
s
.48371 .59667 m
.48431 .59199 L
s
.50205 .62172 m
.49769 .62012 L
s
.48431 .59199 m
.48585 .58887 L
s
.50547 .62176 m
.50205 .62172 L
s
.48585 .58887 m
.49082 .58575 L
s
.51047 .6187 m
.50547 .62176 L
s
.49082 .58575 m
.49424 .58576 L
s
.4983 .5983 m
.50455 .59441 L
s
.51204 .6156 m
.51047 .6187 L
s
.49424 .58576 m
.49861 .58733 L
s
.51268 .61092 m
.51204 .6156 L
s
.49861 .58733 m
.50173 .5897 L
s
.51206 .607 m
.51268 .61092 L
s
.50173 .5897 m
.50455 .59441 L
s
.51773 .59919 m
.50455 .57711 L
s
.51208 .58972 m
.51617 .59367 L
s
.51617 .59367 m
.52058 .59527 L
s
.52058 .59527 m
.52405 .59528 L
s
.52405 .59528 m
.52786 .59293 L
s
.52666 .5763 m
.52509 .57074 L
s
.52855 .57947 m
.52666 .5763 L
s
.53267 .58344 m
.52855 .57947 L
s
.52509 .57074 m
.52574 .56597 L
s
.53713 .58503 m
.53267 .58344 L
s
.52574 .56597 m
.52735 .56278 L
s
.54064 .58504 m
.53713 .58503 L
s
.52735 .56278 m
.53118 .56036 L
s
.5445 .58266 m
.54064 .58504 L
s
.53118 .56036 m
.5347 .56034 L
s
.54612 .57947 m
.5445 .58266 L
s
.5347 .56034 m
.53917 .56192 L
s
.5468 .57468 m
.54612 .57947 L
s
.54966 .57947 m
.53632 .55713 L
s
.55873 .57387 m
.53865 .54026 L
s
.54889 .55143 m
.54821 .55626 L
s
.55587 .56906 m
.56038 .57065 L
s
.55053 .54819 m
.54889 .55143 L
s
.56038 .57065 m
.56395 .57065 L
s
.55444 .54574 m
.55053 .54819 L
s
.56395 .57065 m
.56787 .56822 L
s
.55801 .5457 m
.55444 .54574 L
s
.56787 .56822 m
.56953 .56499 L
s
.56254 .54728 m
.55801 .5457 L
s
.56953 .56499 m
.57024 .56015 L
s
.56674 .55129 m
.56254 .54728 L
s
.57024 .56015 m
.56866 .55451 L
s
.56866 .55451 m
.56674 .55129 L
s
.59178 .56896 m
.57148 .53502 L
s
.58114 .55117 m
.58803 .55356 L
s
.58803 .55356 m
.59166 .55353 L
s
.59166 .55353 m
.59566 .55106 L
s
.59566 .55106 m
.59737 .54778 L
s
.59737 .54778 m
.59579 .54208 L
s
.59579 .54208 m
.58607 .52584 L
s
.61826 .55498 m
.61592 .55418 L
s
.61592 .55418 m
.6163 .55172 L
s
.61045 .54193 m
.59679 .5191 L
s
.6163 .55172 m
.61863 .55252 L
s
.61863 .55252 m
.61826 .55498 L
s
.6121 .52298 m
.61052 .51722 L
s
.61406 .52625 m
.6121 .52298 L
s
.61836 .53032 m
.61406 .52625 L
s
.61052 .51722 m
.61127 .51225 L
s
.62304 .53191 m
.61836 .53032 L
s
.61127 .51225 m
.61301 .5089 L
s
.62676 .53186 m
.62304 .53191 L
s
.61301 .5089 m
.6171 .50633 L
s
.63086 .52932 m
.62676 .53186 L
s
.6171 .50633 m
.62081 .50625 L
s
.63262 .52598 m
.63086 .52932 L
s
.62081 .50625 m
.62552 .50783 L
s
.6334 .52099 m
.63262 .52598 L
s
.63317 .49849 m
.63377 .50266 L
s
.64168 .51586 m
.64108 .5117 L
s
.64504 .5183 m
.64168 .51586 L
s
.63633 .49423 m
.63317 .49849 L
s
.64108 .5117 m
.64286 .50832 L
s
.6502 .51738 m
.64504 .5183 L
s
.64286 .50832 m
.64882 .50234 L
s
.64048 .49162 m
.63633 .49423 L
s
.65437 .5148 m
.6502 .51738 L
s
.64564 .49066 m
.64048 .49162 L
s
.65757 .51056 m
.65437 .5148 L
s
.64882 .50234 m
.65061 .49895 L
s
.64902 .4931 m
.64564 .49066 L
s
.65061 .49895 m
.65002 .49476 L
s
.65698 .50637 m
.65757 .51056 L
s
.65002 .49476 m
.64902 .4931 L
s
.65682 .48364 m
.65723 .48109 L
s
.65923 .48442 m
.65682 .48364 L
s
.65723 .48109 m
.65963 .48187 L
s
.65963 .48187 m
.65923 .48442 L
s
.6782 .51607 m
.66422 .49275 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`1k0?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool01`3oool3000004/0oooo
00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?oo
o`1j0?ooo`80003o3P3oool00`000000oooo0?ooo`040?ooo`<00000CP3oool00`000000oooo0?oo
o`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo07X0oooo00<0003o
0?ooo`3oool0303oool010000000oooo0?ooo`3oool300000580oooo00<000000?ooo`3oool05`3o
ool002/0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`280?ooo`@00000E@3oool0
0`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo
0740oooo0`000?lA0?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo06h0oooo0P000?l30?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01@3oool300000080oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0000001X0?ooo`030000003oool0oooo06`0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0oooo0?ooo`<0
00001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000
J@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool010000?l000000000000000080?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1[0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3000000030000o`3oool0oooo00P0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool2000000L0oooo00<0
00000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00`0000030?ooo`030000o`3oool0oooo00P0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0G0?ooo`00803oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo06/0oooo00<000000?ooo`3oool0H`3oool40000o`L0oooo00D0003o000000000000oooo
0000o`050?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0F0?ooo`00803oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool0H03oool20000o`P0oooo0P0000000`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool0
KP3oool00`000000oooo0?ooo`1O0?ooo`030000o`3oool0oooo00@0oooo0`0000000`3oool0003o
0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01`3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo000000D0oooo
00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1N0?ooo`040000o`3oool0oooo0?ooo`<0
0000103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool01`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`800000
1P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05d0oooo00@0003o000000000000
0000203oool40000o`T0oooo00<0003o0?ooo`3oool01P3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0
EP3oool00`000?l0oooo0?ooo`03000000030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool0
5`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003o
ool0oooo0780oooo00<000000?ooo`3oool0E@3oool00`000000003o000000030?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool05`3oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01H0oooo000X0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0D03oool0
1P000?l00000000000000000oooo0000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`0G0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00
001f0?ooo`030000003oool0oooo04d0oooo0`0000000`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0H0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool0B@3oool3000000<0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`020?ooo`D0003o6`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3oool00`00
0000oooo0?ooo`150?ooo`<000001`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo
0240oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000
oooo0000000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000000<0
oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0240
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo
00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<000001`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0803oool00`000000oooo
0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<0
00000?ooo`3oool0>@3oool00`000?l000000000000:0?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0O0?ooo`030000003oool0oooo05L0oooo00<0
00000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo0?ooo`0e
0?ooo`<0000000<0oooo0000o`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo02D0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`00
0000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000040?ooo`030000o`3oool0oooo
0080oooo10000?l50?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0903oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0
oooo00<000000?ooo`3oool0;@3oool3000000P0oooo00@0003o0?ooo`000?l0003o0`3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool09@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0
oooo00<000000?ooo`3oool0:@3oool3000000/0oooo00<0003o0?ooo`000?l01@3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool20000oah0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo
00<000000?ooo`3oool09@3oool3000000l0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo
0?ooo`030?ooo`@0003o203oool00`000?l0oooo0?ooo`0M0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`0Q0?ooo`<000003P3oool01@000?l0oooo0?ooo`3oool0003o00L0oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`0Y0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002H0oooo00<000000?ooo`3oool0P`3oool00`000000oooo0?ooo`0L0?ooo`@000003`3o
ool20000o`030?ooo`000?l0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo02T0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0D0?ooo`009P3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000B
0?ooo`030000o`3oool0oooo0080003o103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool0:03oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool30000
01@0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?oo
o`<000005`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02L0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00`0oooo0`00000J0?ooo`030000o`3oool0oooo00@0oooo00@0003o0?ooo`3o
ool0oooo1@000?lc0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0
oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<000007@3oool00`000?l0
oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l0=P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3o
ool0103oool3000001P0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`03
0000o`3oool0oooo03P0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo00<00000703oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0P000?li0?ooo`030000003oool0oooo05P0oooo
00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001l0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03T0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<00000
0?ooo`3oool07`3oool00`000?l0oooo0?ooo`050?ooo`D0003o>`3oool2000005/0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0H0?oo
o`@0003o0`3oool00`000?l0oooo0?ooo`120?ooo`<000000P3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3o
ool05P3oool20000o`@0oooo00D0003o0?ooo`3oool0oooo0000o`0o0?ooo`@000001P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool05@3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?oo
o`000?l01@3oool00`000?l0oooo0?ooo`0d0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?oo
o`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool05@3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`D0003o=03oool30000
00h0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool00`3oool20000o`@0
oooo00<0003o0?ooo`3oool0<`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00l0oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo02l0oooo
0`00000F0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<0
00000?ooo`3oool0S@3oool00`000000oooo0?ooo`0?0?ooo`80003o103oool00`000?l0oooo0?oo
o`0h0?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0403oool20000o`@0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0Z0?ooo`<000007P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool02`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0003o00@0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`0W0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool02`3oool20000o`<0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo02@0oooo0`00000V0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool04@3oool002<0oooo0P00002?0?ooo`030000003oool0oooo00`0oooo0P000?l20?ooo`040000
o`3oool0oooo0000o`@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0Q0?ooo`<0
0000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0003o0080oooo00@0003o0?ooo`3oool0003o103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo01d0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`050?ooo`@0003o
103oool01P000?l0oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo01/0oooo0`00000c0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool00`000?l0oooo0?ooo`020000
o`T0oooo10000?lK0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00@0003o0?ooo`3oool0oooo0P000?lT0?oo
o`<00000>P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0O0?ooo`<0
0000?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool07`3oool400000480oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o01h0oooo
0`0000170?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<0
00000?ooo`3oool0S@3oool00`000?l000000?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool07@3oool3000004X0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0103oool20000oa/0oooo0`00001>0?ooo`030000003oool0oooo04/0oooo00<00000
0?ooo`3oool0403oool00280oooo0`00002>0?ooo`030000o`3oool0oooo00D0oooo0P000?l30?oo
o`030000o`3oool0oooo01P0oooo0`00001B0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool0403oool00240oooo0P0000290?ooo`<0003o103oool00`000000003o0?ooo`070?ooo`<0
003o5`3oool4000005H0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0?0?ooo`00
8@3oool00`000000oooo0?ooo`260?ooo`80003o0`3oool01@000?l0oooo0?ooo`3oool000000080
003o7P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00
603oool2000000L0oooo00<000000?ooo`3oool0Q@3oool00`000?l0oooo0?ooo`040?ooo`060000
o`3oool0oooo0000003oool0003o103oool00`000?l0oooo0?ooo`0D0?ooo`<00000GP3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0QP3oool00`000?l0oooo0?ooo`040?ooo`80003o00<000000?oo
o`3oool010000?lD0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0QP3oool00`000?l0
oooo0?ooo`050?ooo`050000o`000000oooo0?ooo`000?l0503oool3000006H0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3o
ool0Q`3oool00`000?l0oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l03`3oool40000
06X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo08L0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0>0?ooo`<00000K`3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0
oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`290?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`290?ooo`030000o`3oool0oooo00@0oooo00<0
00000000o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0>0?ooo`00803oool00`000000oooo0?ooo`2:0?ooo`030000o`3oool0oooo00<0oooo00<00000
0000o`3oool0103oool4000007X0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0>
0?ooo`00803oool00`000000oooo0?ooo`2;0?ooo`030000o`3oool0oooo0080oooo00@000000000
o`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool0
0200oooo0P00002<0?ooo`030000o`3oool0oooo0080oooo100000230?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool03P3oool001l0oooo0P00002>0?ooo`030000o`3oool000000080
0000QP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08`0oooo0`0000020000o`030000003oool0oooo08D0oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000000P3o
ool010000?l0oooo0?ooo`0000280?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0
oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`00
0000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0O03oool300000140oooo00<000000?ooo`3oool0RP3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo
1000000D0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo
0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?oo
o`2<0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo0700oooo0`00000N0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool3000006h0oooo0`00000Q0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000
903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0
303oool001h0oooo00<000000?ooo`3oool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0
oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3oool0>03oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0GP3oool300000340oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo
1000000d0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?oo
o`2D0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool02`3oool001d0oooo00<00000
0?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e
0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo0580oooo0`00000n0?oo
o`030000003oool0oooo09H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`800000B@3oool3000004P0oooo00<000000?ooo`3oool0V03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0
oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`00
0000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0
oooo00<000000?ooo`3oool0?`3oool400000540oooo00<000000?ooo`3oool0V`3oool00`000000
oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo
0`00001E0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?oo
o`2L0?ooo`030000003oool0oooo02l0oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?oo
o`030000003oool0oooo09h0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo02X0oooo0`00001W0?ooo`030000003o
ool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`00
0000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0
oooo00<000000?ooo`3oool0803oool400000700oooo00<000000?ooo`3oool0Y03oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo
0`00001d0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?oo
o`2U0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool02@3oool001T0oooo00<00000
0?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?oo
o`030000003oool0oooo0:L0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?oo
o`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`03
0000003oool0oooo02H0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
3P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00/0oooo0`0000270?ooo`030000003o
ool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`3oool01P3oool30000
08d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
00000002000009@0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2
000009H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P
0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0/03oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a
0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000T0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00`0oooo00<000000?ooo`000000S`3oool0
0`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool0
00P0oooo0P0000040?ooo`800000403oool2000008l0oooo00<000000?ooo`3oool0/P3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0
oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0
oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool01P3oool001<0oooo1@0000020?ooo`8000002@3oool00`000000oooo0?oo
o`290?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool2000000030?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3o
ool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00H0oooo000=0?ooo`@00000103oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<0
00000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03o
ool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3o
ool001@0oooo0P0000040?ooo`800000403oool00`000000oooo0?ooo`210?ooo`030000003oool0
oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`00
0000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<000000?ooo`3oool0^`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0
oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0
oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01@3oool003<0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?oo
o`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j
0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`05
0?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`03
0000003oool0oooo0<00oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00
>03oool2000000030?ooo`000000oooo07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?ooo`800000M03oool00`000000oooo0?oo
o`320?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c
0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`04
0?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3oool200000700oooo00<000000?ooo`3o
ool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000
003oool0oooo0?ooo`000000J`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0103oool00440oooo00@000000?ooo`3oool00000J`3oool00`000000
oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo
0P00001/0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`38
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool00`3oool004L0oooo00<000000?oo
o`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool004T0oooo0P0000000`3oool00000
0?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool004h0oooo00<000000?oo
o`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool00P3oool004l0oooo0P00001N0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool0
0000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool00P3oool004<0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0000001J0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00
AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool003d0oooo100000030?ooo`8000003`3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0=80oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`010?ooo`00A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool0
0`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool0
04@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo001I0?ooo`040000003oool0oooo0000
0580oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0040oooo001J0?ooo`800000D`3oool00`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo
00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0
e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool00600oooo0P0000000`3oool000000?oo
o`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool00680oooo0P00001;
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`0000000P3oool006<0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`03
0000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=40oooo100000090?ooo`00J@3oool2
000004@0oooo00<000000?ooo`3oool0c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`00
0000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000
000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S
0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`03
0000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000
003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3o
ool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0oooo00<000000?ooo`000000=03oool0
0`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`00
0000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@000000?ooo`3oool000003P3oool00`00
0000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo1@0000120?ooo`00J03oool010000000
oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0
oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo
0900oooo1000001;0?ooo`00J03oool010000000oooo0?ooo`00000B0?ooo`030000003oool00000
02d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo001Y0?ooo`800000503oool2000002d0
oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo00210?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool0PP3oool5000005P0oooo00220?ooo`800000:P3oool00`000000oooo0?oo
o`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?oo
o`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e
0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000003oool0oooo0740oooo1000001Z0?oo
o`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00
R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000
LP3oool008/0oooo00@000000?ooo`3oool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000
M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0oooo100000200?ooo`00S`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo100000240?ooo`00T03oool2000001`0
oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B0?ooo`030000003oool0000001T0oooo
00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?ooo`8000006@3oool00`000000oooo0?oo
o`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`15
0?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000003oool0oooo0440oooo1000002J0?oo
o`00V03oool010000000oooo0?ooo`00000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?oo
o`00V@3oool00`000000oooo0000000B0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00
S03oool2000000`0oooo0P00000A0?ooo`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3o
ool2000002@0oooo00@000000?ooo`3oool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000
003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool0
0`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000oooo0000000;0?ooo`030000003oool0
oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo0000000S0?ooo`030000003oool0oooo
0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000
oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo00<000000?ooo`3oool07P3oool50000
0;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo01X0oooo100000320?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo
00<000000?ooo`3oool05P3oool400000<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?oo
o`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`030000003oool0oooo00d0oooo1000003?
0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool01000
0000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0
oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool50000
0080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?oo
o`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:T0
oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.37891 .66574 m
.38881 .66178 L
s
.37891 .66574 m
.36386 .63167 L
s
.37373 .62762 m
.36386 .63167 L
s
.38881 .66178 m
.39236 .65845 L
s
.3787 .62751 m
.37373 .62762 L
s
.39236 .65845 m
.39376 .65406 L
s
.38298 .62961 m
.3787 .62751 L
s
.39376 .65406 m
.39375 .65023 L
s
.39375 .65023 m
.39302 .64476 L
s
.38584 .63229 m
.38298 .62961 L
s
.38942 .63661 m
.38584 .63229 L
s
.39302 .64476 m
.38942 .63661 L
s
.40373 .64237 m
.39364 .61947 L
s
.39941 .63255 m
.403 .63688 L
s
.403 .63688 m
.40731 .639 L
s
.40731 .639 m
.4109 .63948 L
s
.4109 .63948 m
.41522 .63774 L
s
.41809 .62497 m
.41664 .62169 L
s
.4217 .62932 m
.41809 .62497 L
s
.41664 .62169 m
.41591 .61616 L
s
.42604 .63144 m
.4217 .62932 L
s
.41591 .61616 m
.41735 .61169 L
s
.42967 .63192 m
.42604 .63144 L
s
.41735 .61169 m
.41952 .60886 L
s
.43402 .63016 m
.42967 .63192 L
s
.41952 .60886 m
.42387 .60708 L
s
.43621 .62734 m
.43402 .63016 L
s
.42387 .60708 m
.4275 .60754 L
s
.43767 .62286 m
.43621 .62734 L
s
.4275 .60754 m
.43186 .60965 L
s
.43984 .62781 m
.42968 .6047 L
s
.45007 .62369 m
.44575 .59812 L
s
.46183 .61896 m
.44575 .59812 L
s
.46183 .61896 m
.45751 .59329 L
s
.47365 .61419 m
.45751 .59329 L
s
.48183 .60893 m
.47817 .60059 L
s
.48552 .61334 m
.48183 .60893 L
s
.47817 .60059 m
.47746 .59497 L
s
.48847 .61608 m
.48552 .61334 L
s
.49292 .61822 m
.48847 .61608 L
s
.47746 .59497 m
.47749 .59102 L
s
.47749 .59102 m
.479 .58646 L
s
.49664 .6187 m
.49292 .61822 L
s
.50264 .6163 m
.49664 .6187 L
s
.479 .58646 m
.48125 .58357 L
s
.48125 .58357 m
.48723 .58112 L
s
.50491 .61343 m
.50264 .6163 L
s
.4931 .59453 m
.50061 .59148 L
s
.50645 .60887 m
.50491 .61343 L
s
.48723 .58112 m
.49096 .58157 L
s
.49096 .58157 m
.49543 .5837 L
s
.50649 .60491 m
.50645 .60887 L
s
.49543 .5837 m
.4984 .58645 L
s
.4984 .58645 m
.50061 .59148 L
s
.51407 .59791 m
.50376 .57435 L
s
.50965 .58781 m
.51337 .59225 L
s
.51337 .59225 m
.51787 .59439 L
s
.51787 .59439 m
.52164 .59485 L
s
.52164 .59485 m
.5262 .59302 L
s
.52939 .5798 m
.52791 .57642 L
s
.53313 .58426 m
.52939 .5798 L
s
.52791 .57642 m
.52722 .57072 L
s
.53767 .58641 m
.53313 .58426 L
s
.52722 .57072 m
.52879 .56609 L
s
.54147 .58687 m
.53767 .58641 L
s
.52879 .56609 m
.53111 .56314 L
s
.54607 .58501 m
.54147 .58687 L
s
.53111 .56314 m
.5357 .56126 L
s
.5484 .58208 m
.54607 .58501 L
s
.5357 .56126 m
.53951 .5617 L
s
.55 .57744 m
.5484 .58208 L
s
.53951 .5617 m
.54406 .56384 L
s
.55222 .58253 m
.54184 .55874 L
s
.56303 .57818 m
.54742 .54239 L
s
.5608 .57307 m
.56539 .57523 L
s
.55646 .55476 m
.55486 .55944 L
s
.56539 .57523 m
.56923 .57568 L
s
.55882 .55179 m
.55646 .55476 L
s
.56923 .57568 m
.5739 .5738 L
s
.56347 .54988 m
.55882 .55179 L
s
.5739 .5738 m
.57627 .57084 L
s
.56733 .55032 m
.56347 .54988 L
s
.57627 .57084 m
.5779 .56616 L
s
.57193 .55247 m
.56733 .55032 L
s
.5779 .56616 m
.57722 .56039 L
s
.57573 .55697 m
.57193 .55247 L
s
.57722 .56039 m
.57573 .55697 L
s
.59946 .57762 m
.58377 .54156 L
s
.59124 .55874 m
.5982 .56199 L
s
.5982 .56199 m
.6021 .56244 L
s
.6021 .56244 m
.60684 .56053 L
s
.60684 .56053 m
.60926 .55753 L
s
.60926 .55753 m
.60859 .55172 L
s
.60859 .55172 m
.60109 .53447 L
s
.63031 .56732 m
.62797 .56623 L
s
.62797 .56623 m
.62881 .56386 L
s
.63116 .56495 m
.63031 .56732 L
s
.62881 .56386 m
.63116 .56495 L
s
.62431 .55349 m
.61379 .52926 L
s
.63098 .53857 m
.62948 .5351 L
s
.63484 .54313 m
.63098 .53857 L
s
.62948 .5351 m
.62882 .52924 L
s
.63956 .5453 m
.63484 .54313 L
s
.62882 .52924 m
.63052 .52446 L
s
.64353 .54574 m
.63956 .5453 L
s
.63052 .52446 m
.63297 .5214 L
s
.64836 .5438 m
.64353 .54574 L
s
.63297 .5214 m
.6378 .51943 L
s
.65083 .54075 m
.64836 .5438 L
s
.6378 .51943 m
.64177 .51985 L
s
.65256 .53597 m
.65083 .54075 L
s
.64177 .51985 m
.64651 .52202 L
s
.66228 .53203 m
.66239 .52788 L
s
.66542 .53487 m
.66228 .53203 L
s
.67106 .53465 m
.66542 .53487 L
s
.65633 .51389 m
.65623 .51805 L
s
.66239 .52788 m
.66489 .52481 L
s
.66045 .51015 m
.65633 .51389 L
s
.66489 .52481 m
.67228 .51975 L
s
.67596 .53268 m
.67106 .53465 L
s
.66534 .50814 m
.66045 .51015 L
s
.6801 .52895 m
.67596 .53268 L
s
.671 .50789 m
.66534 .50814 L
s
.67228 .51975 m
.67479 .51667 L
s
.68022 .52478 m
.6801 .52895 L
s
.67479 .51667 m
.67491 .51249 L
s
.67415 .51073 m
.671 .50789 L
s
.67491 .51249 m
.67415 .51073 L
s
.70097 .53706 m
.69033 .51242 L
s
.68411 .50252 m
.685 .50009 L
s
.68652 .50361 m
.68411 .50252 L
s
.68741 .50118 m
.68652 .50361 L
s
.685 .50009 m
.68741 .50118 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000D0oooo0P000?l40?ooo`030000003oool0oooo05H0oooo00<00000
0?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0oooo06X0oooo00<000000?oo
o`3oool0LP3oool3000000T0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`1F0?oo
o`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo000000H0oooo00<000000?oo
o`3oool0J`3oool00`000000oooo0?ooo`1^0?ooo`<000001P3oool00`000?l0oooo0?ooo`080?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06X0oooo0`0000050?oo
o`D0003o2P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<000001`3oool00`000?l0oooo0?ooo`030?ooo`80003o103oool00`000?l0oooo0?ooo`020?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200oooo00@000000?ooo`3o
ool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo0680oooo0`00000:0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo0700oooo00<000000?ooo`3oool0GP3oool3000000d0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000000F03oool00`00
0000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo05T0
oooo100000090?ooo`80003o2`3oool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?oo
o`000000F03oool00`000000oooo0?ooo`0F0?ooo`00:@3oool00`000000oooo0?ooo`1b0?ooo`03
0000003oool0oooo05D0oooo0`00000;0?ooo`80003o0P3oool20000o`L0oooo0P000?l80?ooo`04
0000o`3oool0oooo000005P0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`00
0000M03oool00`000000oooo0?ooo`1A0?ooo`<000003@3oool00`000?l0oooo0?ooo`0:0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`00001I0?oo
o`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool00`000000oooo0?ooo`1=0?ooo`<0
00002P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0000005T0oooo00<000000?ooo`3o
ool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0
B@3oool3000000d0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`030000
o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000001I0?ooo`030000
003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`150?ooo`<000002`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool02@3oool00`000?l0oooo0?ooo`030000o`P0oooo00<0
003o0000003oool0F03oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000000Q
0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000000h0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool20000o`/0oooo00<0003o0000003oool0F03oool00`000000oooo0?ooo`0E
0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?oo
o`<000004P3oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l01`3oool0
0`000?l0oooo0?ooo`0@0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<0000000<0003o0?oo
o`3oool02`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0100oooo00<000000?oo
o`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`009`3oool00`000000oooo0?ooo`1l0?ooo`03
0000003oool0oooo03D0oooo0`0000030?ooo`030000o`3oool0oooo00/0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo0P000?l30?ooo`03
0000o`3oool0oooo0140oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`00
9`3oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0340oooo0`0000070?ooo`030000
o`3oool0oooo00/0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo0`000?lD0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<000002P3o
ool00`000?l0oooo0?ooo`020?ooo`80003o1`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool06`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01@0oooo000W0?ooo`030000003oool0oooo07l0oooo00<000000?ooo`3oool0:@3oool3
000000h0oooo00@0003o0?ooo`000?l0003o0P3oool20000o`D0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3
00000140oooo0P000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool0
0`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0F03oool0
0`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo
0240oooo0`00000@0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0803oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0
oooo00<000000?ooo`3oool0703oool400000140oooo00<0003o0?ooo`000?l0103oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo0`000?l30?ooo`030000o`3oool0oooo0280
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo
0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000C0?ooo`80003o00@0oooo0000o`000?l0
003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`00
0?l00P000?l80?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo
0`00000E0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool02P3oool20000oa/0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0100oooo0`00000G0?ooo`030000o`3oool0oooo00D0oooo00D0
003o0?ooo`3oool0oooo0000o`060?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
2P3oool00`000?l0oooo0?ooo`0I0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000006P3o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo02H0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo00P0oooo0`00000E0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01P3oool0
1@000?l0oooo0?ooo`3oool0003o00@0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`0V0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<00000
0?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`<00000603oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool40000o`T0oooo00<0003o
0?ooo`3oool09@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?oo
o`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000L0?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0000o`030?ooo`030000o`3oool0oooo
00X0oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000G0?ooo`<0003o1@3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`000?l0>03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000S@3oool00`000000oooo
0?ooo`0D0?ooo`80003o0`3oool20000o`@0oooo00<0003o0?ooo`3oool01P3oool01@000?l0oooo
0?ooo`3oool0003o03X0oooo0P00001K0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool04`3oool00`000?l0oooo0?ooo`050?ooo`050000
o`3oool0oooo0?ooo`000?l02@3oool30000ocP0oooo0`0000020?ooo`030000003oool0oooo05P0
oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0C0?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo0P000?lo0?ooo`@0
00001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`050?ooo`030000
o`3oool0oooo00D0oooo0P000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
=@3oool3000000X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`00903o
ool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00/0oooo0P000?l60?ooo`030000o`3o
ool0oooo00<0oooo0P000?l60?ooo`@0003o=@3oool3000000h0oooo00<000000?ooo`3oool0EP3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo00L0oooo00@0003o0?ooo`3oool0oooo0P000?l60?ooo`030000o`3oool0oooo00/0oooo00<0
003o0?ooo`3oool0<`3oool300000180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?oo
o`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo00L0oooo0P000?l3
0?ooo`80003o1@3oool00`000?l0oooo0?ooo`0n0?ooo`<000005P3oool00`000000oooo0?ooo`1D
0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?oo
o`3oool01`3oool20000o`<0oooo00<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`0i0?oo
o`@000006P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo08d0oooo00D000000?ooo`3oool0oooo0000o`060?ooo`80003o0P3oool01000
0?l0oooo0?ooo`000?l40?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool0;03oool3
000001h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`00
0000oooo0?ooo`2=0?ooo`H0003o1@3oool01@000?l0oooo0000o`3oool0003o0080oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo02T0oooo0`00000R
0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00P000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`0W0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo
0140oooo000S0?ooo`800000SP3oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo00<0
oooo00H0003o0?ooo`3oool0003o0?ooo`000?l30?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool0103oool00`000?l0oooo0?ooo`0T0?ooo`<00000:P3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<0003o0000
003oool0103oool00`000?l0oooo0?ooo`020?ooo`040000o`3oool0oooo0?ooo`80003o2@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0240oooo1000000^0?ooo`030000003oool0
oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0Q@3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00`3oool01@00
0?l0oooo0?ooo`3oool0003o00X0oooo10000?lQ0?ooo`<00000<`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08D0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool0;P3oool3000003H0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?oo
o`008`3oool00`000000oooo0?ooo`260?ooo`030000o`3oool0oooo00@0oooo00<000000000o`3o
ool0103oool20000o`@0oooo00<0003o0?ooo`3oool0:`3oool3000003X0oooo00<000000?ooo`3o
ool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`1n0?ooo`<0003o
1P3oool00`000?l0oooo0?ooo`040?ooo`03000000000?l0oooo00@0oooo00<0003o0?ooo`000?l0
;P3oool3000003h0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`0@0?ooo`008P3o
ool00`000000oooo0?ooo`1l0?ooo`80003o0`3oool20000o`@0oooo00<0003o0?ooo`3oool0103o
ool00`000000oooo0000o`040?ooo`030000o`3oool0oooo02X0oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0NP3oool2
0000o`L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0
oooo00@0003o:P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`1j0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000003oool0oooo02/0oooo0`00001:0?oo
o`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3o
ool0N`3oool00`000?l0oooo0?ooo`060?ooo`040000o`3oool0oooo0?ooo`@0003o0P3oool00`00
0?l0oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo
0100oooo000R0?ooo`<00000N`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool00P000?l00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000OP3oool00`000?l0oooo
0?ooo`060?ooo`050000o`3oool0oooo0?ooo`000?l0103oool00`000000oooo0?ooo`0Q0?ooo`@0
0000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000
003oool0oooo07d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`030000
003oool0oooo01h0oooo0`00001K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
3`3oool001P0oooo0P0000070?ooo`030000003oool0oooo07h0oooo00<0003o0?ooo`3oool01@3o
ool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo01/0oooo0`00001N0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3o
ool00`000000oooo0?ooo`1n0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3o
ool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0O`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0oooo00<000000?ooo`3oool05@3oool3
000006H0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0?0?ooo`00603oool20000
00L0oooo00<000000?ooo`3oool0O`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo
00H0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0800
oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000003oool0oooo00h0
oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo
0`0000050?ooo`030000003oool0oooo0840oooo00@0003o0?ooo`3oool0oooo0P000?l90?ooo`03
0000003oool0oooo00/0oooo0`00001b0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03`3oool00200oooo00<000000?ooo`3oool0PP3oool30000o`/0oooo00<000000?ooo`3oool0
203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803o
ool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool0
10000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<00000
0?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`03
0000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`00
7`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3o
ool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003o
ool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`00
0000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140
oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0
oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?oo
o`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<0
00000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<00000
0?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?oo
o`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`03
0000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`00
7P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3o
ool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003o
ool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0
oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`00
0000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo
03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340
oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0
oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?oo
o`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<0
00000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<00000
0?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?oo
o`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?oo
o`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@0
0000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3o
ool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0
U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3o
ool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003o
ool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0
oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`00
0000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo
0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540
oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0
oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo
00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?oo
o`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<00000
0?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?oo
o`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@0
0000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3o
ool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0
W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003o
ool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03o
ool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool0
0`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool0
01X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo
02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700
oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0
oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?oo
o`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<0
00000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<00000
0?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?oo
o`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@0
0000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0
Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003o
ool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool0
0`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool0
01P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080
oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3o
ool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3o
ool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool0
0`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:
0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool20000
08l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo
0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@00
00020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`00
0000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?oo
o`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo
0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800
oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0
oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo
0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<0
00000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?oo
o`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?oo
o`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3o
ool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo
00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo
000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?oo
o`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000
oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo
00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<0
00000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0015
0?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3o
ool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<0
00000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<
0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`03
0000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00
A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000
FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool0
0`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo
0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00
G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00
G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`000000
0`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<0
00000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<00000
0?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?oo
o`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00
IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5
000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0
oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00
000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l
0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?oo
o`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0
ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3o
ool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool0
06T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0
oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`00
0000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`00
0000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000
oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool50000
04l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0
oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo
00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@00000
0?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<00000
0?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?oo
o`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool0
7@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool00000
7`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003o
ool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0
oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo
002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?oo
o`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?oo
o`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`03
0000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000
003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool00000
3@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003o
ool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool0
0`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`00
0000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo
02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool20000
00X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo00000000
0000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00
Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo
002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P000004
0?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0
000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool0
0:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3o
oonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.35529 .64684 m
.36664 .6441 L
s
.35529 .64684 m
.34478 .61079 L
s
.36664 .6441 m
.37102 .64121 L
s
.35613 .60799 m
.34478 .61079 L
s
.37102 .64121 m
.37328 .63699 L
s
.37328 .63699 m
.37391 .63315 L
s
.36151 .60851 m
.35613 .60799 L
s
.37391 .63315 m
.37404 .62759 L
s
.37404 .62759 m
.37153 .61898 L
s
.36577 .61116 m
.36151 .60851 L
s
.3684 .61421 m
.36577 .61116 L
s
.37153 .61898 m
.3684 .61421 L
s
.38597 .62654 m
.37896 .60236 L
s
.3861 .62097 m
.39038 .62362 L
s
.38297 .61619 m
.3861 .62097 L
s
.39038 .62362 m
.39415 .62455 L
s
.39415 .62455 m
.39908 .62336 L
s
.40745 .61577 m
.4043 .61097 L
s
.41174 .61843 m
.40745 .61577 L
s
.4043 .61097 m
.4033 .60751 L
s
.4033 .60751 m
.40344 .6019 L
s
.41554 .61936 m
.41174 .61843 L
s
.40344 .6019 m
.40574 .59762 L
s
.42049 .61816 m
.41554 .61936 L
s
.40574 .59762 m
.40854 .59507 L
s
.4233 .61562 m
.42049 .61816 L
s
.40854 .59507 m
.41349 .59385 L
s
.42561 .61134 m
.4233 .61562 L
s
.42711 .61655 m
.42011 .59222 L
s
.41349 .59385 m
.4173 .59477 L
s
.4173 .59477 m
.42161 .59744 L
s
.43872 .61374 m
.43838 .58771 L
s
.45204 .6105 m
.45172 .58442 L
s
.45204 .6105 m
.43838 .58771 L
s
.46541 .60726 m
.45172 .58442 L
s
.47815 .60791 m
.47498 .60306 L
s
.48083 .611 m
.47815 .60791 L
s
.47498 .60306 m
.47248 .59431 L
s
.48519 .61368 m
.48083 .611 L
s
.48906 .61462 m
.48519 .61368 L
s
.47248 .59431 m
.47266 .58864 L
s
.4958 .613 m
.48906 .61462 L
s
.47266 .58864 m
.47335 .58472 L
s
.47335 .58472 m
.47571 .58038 L
s
.49868 .61043 m
.4958 .613 L
s
.47571 .58038 m
.47858 .5778 L
s
.50107 .60611 m
.49868 .61043 L
s
.47858 .5778 m
.48533 .57613 L
s
.48932 .59019 m
.49778 .58813 L
s
.50176 .60219 m
.50107 .60611 L
s
.48533 .57613 m
.48921 .57706 L
s
.48921 .57706 m
.49359 .57974 L
s
.49628 .58285 m
.49778 .58813 L
s
.49359 .57974 m
.49628 .58285 L
s
.51094 .5962 m
.50395 .57154 L
s
.51114 .59051 m
.51553 .59321 L
s
.50795 .58564 m
.51114 .59051 L
s
.51553 .59321 m
.51943 .59414 L
s
.51943 .59414 m
.52454 .5929 L
s
.53329 .58512 m
.53009 .58023 L
s
.53771 .58782 m
.53329 .58512 L
s
.53009 .58023 m
.52909 .57669 L
s
.52909 .57669 m
.5293 .57097 L
s
.54163 .58875 m
.53771 .58782 L
s
.5293 .57097 m
.53173 .56658 L
s
.54677 .58751 m
.54163 .58875 L
s
.53173 .56658 m
.53465 .56397 L
s
.54971 .5849 m
.54677 .58751 L
s
.53465 .56397 m
.53979 .5627 L
s
.55215 .58052 m
.54971 .5849 L
s
.55364 .58584 m
.54666 .561 L
s
.53979 .5627 m
.54373 .56363 L
s
.54373 .56363 m
.54816 .56633 L
s
.56569 .58291 m
.55523 .54557 L
s
.5642 .57759 m
.56865 .5803 L
s
.56865 .5803 m
.5726 .58124 L
s
.56267 .55896 m
.56022 .56337 L
s
.5726 .58124 m
.57779 .57998 L
s
.56563 .55633 m
.56267 .55896 L
s
.57779 .57998 m
.58075 .57736 L
s
.57082 .55505 m
.56563 .55633 L
s
.58075 .57736 m
.58323 .57295 L
s
.57478 .55598 m
.57082 .55505 L
s
.58323 .57295 m
.58347 .56718 L
s
.57925 .55869 m
.57478 .55598 L
s
.58347 .56718 m
.58247 .56362 L
s
.58247 .56362 m
.57925 .55869 L
s
.60384 .58698 m
.5934 .54948 L
s
.59838 .56735 m
.6051 .57144 L
s
.6051 .57144 m
.60909 .57238 L
s
.60909 .57238 m
.61433 .57111 L
s
.61433 .57111 m
.61734 .56847 L
s
.61734 .56847 m
.6176 .56267 L
s
.6176 .56267 m
.61262 .54474 L
s
.6376 .58076 m
.63534 .5794 L
s
.63534 .5794 m
.6366 .57718 L
s
.63886 .57855 m
.6376 .58076 L
s
.6366 .57718 m
.63886 .57855 L
s
.63363 .56642 m
.62667 .54127 L
s
.64624 .5576 m
.64299 .55263 L
s
.65077 .56034 m
.64624 .5576 L
s
.64299 .55263 m
.642 .54904 L
s
.642 .54904 m
.64227 .5432 L
s
.6548 .56128 m
.65077 .56034 L
s
.64227 .5432 m
.64481 .53872 L
s
.66012 .55999 m
.6548 .56128 L
s
.64481 .53872 m
.64785 .53605 L
s
.66317 .55733 m
.66012 .55999 L
s
.64785 .53605 m
.65317 .53474 L
s
.66573 .55286 m
.66317 .55733 L
s
.65317 .53474 m
.65721 .53567 L
s
.65721 .53567 m
.66176 .53841 L
s
.6764 .55026 m
.6772 .5462 L
s
.67918 .55344 m
.6764 .55026 L
s
.68503 .55394 m
.67918 .55344 L
s
.6772 .5462 m
.68027 .54352 L
s
.67323 .53172 m
.67244 .53578 L
s
.69039 .55264 m
.68503 .55394 L
s
.68027 .54352 m
.68871 .53953 L
s
.67808 .52859 m
.67323 .53172 L
s
.69526 .54953 m
.69039 .55264 L
s
.68345 .52727 m
.67808 .52859 L
s
.69606 .54547 m
.69526 .54953 L
s
.68871 .53953 m
.69179 .53684 L
s
.68931 .52776 m
.68345 .52727 L
s
.69179 .53684 m
.69259 .53277 L
s
.69259 .53277 m
.6921 .53095 L
s
.6921 .53095 m
.68931 .52776 L
s
.71537 .56012 m
.70845 .5347 L
s
.70367 .52422 m
.70498 .52196 L
s
.70597 .5256 m
.70367 .52422 L
s
.70727 .52334 m
.70597 .5256 L
s
.70498 .52196 m
.70727 .52334 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000000o`000?l0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`03000000000?l0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000R0?ooo`D0003o103oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo04T0
oooo0`00000S0?ooo`80003o1@3oool01@000?l0oooo0?ooo`3oool0000005T0oooo00<000000?oo
o`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1g0?ooo`03
0000003oool0oooo04D0oooo0`00000V0?ooo`030000o`3oool0oooo00@0oooo00D0003o0?ooo`3o
ool0oooo0000001I0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool000000240
oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`110?ooo`<000007`3oool50000o`D0
oooo00<0003o0?ooo`3oool0103oool01`000?l0oooo0?ooo`3oool000000?ooo`000?l0E`3oool0
0`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0N@3oool00`00
0000oooo0?ooo`0m0?ooo`<000008@3oool00`000?l0oooo0?ooo`030?ooo`80003o2@3oool00`00
0?l0oooo0?ooo`020?ooo`030000003oool0003o05L0oooo00<000000?ooo`3oool05@3oool002P0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0i0?ooo`<000007P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00d0oooo0P000?l50?ooo`040000003oool0oooo0000
oeH0oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000
oooo0?ooo`0e0?ooo`<000006`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080
oooo00<0003o0?ooo`3oool0303oool00`000?l0oooo0?ooo`050?ooo`040000003oool0oooo0000
oeL0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0O@3oool00`000000
oooo0?ooo`0a0?ooo`<000002@3oool00`000?l0oooo0?ooo`0B0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`80003o1@3oool010000?l0
oooo0?ooo`0000020?ooo`030000o`3oool0oooo05D0oooo00<000000?ooo`3oool0503oool002L0
oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0]0?ooo`<00000303oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool01@000?l0
oooo0?ooo`3oool0003o00`0oooo00<0003o0?ooo`3oool0103oool010000?l0oooo0?ooo`000003
0?ooo`030000o`3oool0oooo05@0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?oo
o`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<00000403oool00`000?l0oooo0?ooo`0:0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool2
0000o`<0oooo00D000000?ooo`3oool0oooo0000o`1F0?ooo`030000003oool0oooo01@0oooo000V
0?ooo`<00000P@3oool00`000000oooo0?ooo`0U0?ooo`<000004`3oool00`000?l0oooo0?ooo`02
0?ooo`80003o1`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0`000?l5
0?ooo`050000003oool0oooo0?ooo`000?l0EP3oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo0240oooo0`00000F0?ooo`030000o`3oool0
oooo0080003o0P3oool20000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0<
0?ooo`030000003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000E0?oo
o`030000o`3oool0oooo0080oooo0P000?l50?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo1@000?l@0?oo
o`050000003oool0oooo0?ooo`000?l0E@3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`00
0000oooo0?ooo`240?ooo`030000003oool0oooo01P0oooo0`00000D0?ooo`H0003o103oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0
oooo0`00000F0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo01P0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`260?ooo`030000003oool0oooo0100oooo
0`00000H0?ooo`030000o`3oool0oooo00D0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`03
0000o`3oool0oooo00<0oooo0P000?l50?ooo`030000o`3oool0oooo01h0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`030000
003oool0oooo00`0oooo0`00000B0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0`3oool010000?l0oooo0000o`000?l20?ooo`030000o`3oool0oooo01l0oooo00<000000?ooo`3o
ool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000
003oool0oooo00P0oooo0`00000E0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020000ob80oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00
000@0?ooo`<0003o1@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool02P3oool00`000?l0oooo0?ooo`0G0?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`03
00000140oooo0P000?l30?ooo`80003o103oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool20000o`<0oooo00<0003o0?ooo`3oool01P3oool0
0`000?l0oooo0?ooo`0:0?ooo`80003o603oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P00000C0?ooo`030000o`3oool0oooo
00D0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00P3oool40000o`T0oooo00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0F
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002D0oooo0P00002=0?oo
o`030000003oool0oooo00T0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`060?oo
o`050000o`3oool0oooo0?ooo`000?l02@3oool00`000?l0oooo0?ooo`030?ooo`80003o4P3oool0
0`000?l0oooo0?ooo`0R0?ooo`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool20000
o`H0oooo00<0003o0?ooo`3oool01@3oool20000o`<0oooo00<0003o0?ooo`3oool0203oool01`00
0?l0oooo0?ooo`3oool0003o0?ooo`000?l04P3oool00`000?l0oooo0?ooo`0O0?ooo`<000000P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0
oooo08`0oooo00<000000?ooo`3oool0103oool20000o`<0oooo0P000?l60?ooo`030000o`3oool0
oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo00P0oooo0`000?lc0?ooo`@000001P3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000003oool0oooo
08`0oooo00<0003o0?ooo`3oool0103oool20000o`<0oooo00<0003o0?ooo`000?l01@3oool00`00
0?l0oooo0?ooo`0;0?ooo`<0003o0P3oool00`000?l0oooo0?ooo`0f0?ooo`<000002P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08T0
oooo1@000?l60?ooo`030000o`3oool0003o0080oooo00<0003o0?ooo`000?l01@3oool00`000?l0
oooo0?ooo`0;0?ooo`030000o`3oool0oooo0080003o=P3oool3000000h0oooo00<000000?ooo`3o
ool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`280?ooo`030000
o`3oool0oooo0080oooo0P000?l50?ooo`030000o`3oool0003o0080oooo00@0003o0?ooo`3oool0
003o103oool00`000?l0oooo0?ooo`130?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08L0oooo00<0003o0?ooo`3oool0
0`3oool00`000000003o0?ooo`040?ooo`060000o`3oool0oooo0000o`3oool0003o0P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo03l0oooo0`00000F0?ooo`030000003oool0oooo
05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0OP3oool00`000?l0
oooo0?ooo`060?ooo`030000o`3oool0oooo00<0oooo00<000000000o`3oool0103oool01P000?l0
oooo0?ooo`000?l0oooo0000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`07
0?ooo`030000o`3oool0oooo0340oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<00000
0?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0OP3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo00<0oooo00<000000?ooo`000?l0103oool010000?l0oooo0?ooo`3oool2
0000o`<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0
oooo02h0oooo0`00000N0?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool04@3oool0
02@0oooo00<000000?ooo`3oool0M03oool50000o`H0oooo00<0003o0?ooo`3oool01@3oool00`00
0?l0oooo0?ooo`030?ooo`030000003oool0003o00@0oooo00@0003o0?ooo`3oool0oooo0P000?l4
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0/
0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo0780oooo0`000?l50?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`040000003oool0003o0000o`<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool0:@3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000007<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool010000000oooo0000o`000?l3
0?ooo`030000o`3oool0oooo00h0oooo1P000?lY0?ooo`<00000:P3oool00`000000oooo0?ooo`1A
0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo07<0oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00H0oooo00H0003o0?oo
o`3oool0oooo0000003oool20000ocl0oooo1000000^0?ooo`030000003oool0oooo0500oooo00<0
00000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0L`3oool00`000?l0oooo0?ooo`06
0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool50000och0oooo0`00000c
0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0L`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo0P000?l:0?oo
o`030000003oool0oooo03/0oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0M03oool00`000?l0oooo0?ooo`060?ooo`03
0000o`3oool0oooo0080oooo1P000?l50?ooo`030000003oool0oooo03P0oooo0`00000j0?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
M@3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
203oool00`000000oooo0?ooo`0e0?ooo`<00000?P3oool00`000000oooo0?ooo`1>0?ooo`030000
003oool0oooo0100oooo000R0?ooo`030000003oool0oooo07D0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`0=0?ooo`030000003oool0oooo0340oooo100000120?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0M@3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool0;P3oool3
000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`1f0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03@3oool00`00
0000oooo0?ooo`0[0?ooo`<00000BP3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
0100oooo000R0?ooo`030000003oool0oooo07H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0
oooo0?ooo`0=0?ooo`030000003oool0oooo02P0oooo0`00001>0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool0403oool00280oooo0`00001f0?ooo`030000o`3oool0oooo00@0oooo
00<0003o0?ooo`3oool03P3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000N@3oool00`000?l0oooo0?oo
o`030000oa40oooo00<000000?ooo`3oool08@3oool4000005H0oooo00<000000?ooo`3oool0BP3o
ool00`000000oooo0?ooo`0?0?ooo`008@3oool00`000000oooo0?ooo`1h0?ooo`<0003o503oool0
0`000000oooo0?ooo`0N0?ooo`<00000F`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01/0oooo0`00001N0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool03`3oool001L0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo
01P0oooo0`00001R0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0
oooo0`00001V0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo
0P0000070?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<00000
0?ooo`3oool0T03oool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0203oool3000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`03
0000003oool0oooo04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool010000000oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000
oooo0?ooo`0>0?ooo`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`000002
0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?oo
o`030000003oool0oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0Q@3oool3000000T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000
003oool0oooo08P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool3
00000140oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo
08/0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000
oooo0?ooo`1f0?ooo`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q
0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<
0?ooo`007P3oool00`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?oo
o`030000003oool0oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0IP3oool3000002P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`03
0000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000
003oool0oooo0940oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo03L0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool3
00000340oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo
09<0oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1G0?ooo`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo
00<000000?ooo`3oool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo
000L0?ooo`030000003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>
0?ooo`@00000@@3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?oo
o`3oool0U`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`80
0000B@3oool3000004P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`03
0000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000
003oool0oooo09T0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool4
00000540oooo00<000000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0i0?ooo`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo
00<000000?ooo`3oool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_
0?ooo`@00000H@3oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`03
0000003oool0oooo02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3o
ool0;03oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000
JP3oool00`000000oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0
2@3oool001X0oooo0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool4
00000700oooo00<000000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0J0?ooo`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo
00<000000?ooo`3oool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A
0?ooo`@00000P03oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000
RP3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
203oool001P0oooo00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo0080oooo1000002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`80
0000U`3oool00`000000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool01`3oool000L0oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0
[P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003o
ool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0:0?ooo`800000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403o
ool2000008l0oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00L0oooo000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`00
0000oooo0?ooo`2d0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0
oooo1@0000020?ooo`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`00
5@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool200000003
0?ooo`000000oooo08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000
403oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003o
ool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool2
00000800oooo00<000000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00D0oooo000`0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`00
0000oooo0?ooo`2m0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?oo
o`1g0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?oo
o`040?ooo`00=`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo
07<0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00@0oooo000j0?ooo`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?oo
o`1`0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`040?ooo`00?P3oool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool0
0`000000oooo0?ooo`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool0
0440oooo00@000000?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0
oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0
oooo00150?ooo`800000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?oo
o`390?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<00000
0?ooo`3oool0I@3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool00`3oool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0
oooo00<000000?ooo`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo001<0?ooo`800000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?oo
o`3>0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N
0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
0?ooo`00A03oool2000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?oo
o`3oool000002`3oool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?oo
o`800000FP3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool00P3oool003d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00
A03oool00`000000oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003o
ool0oooo05@0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0040oooo001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool0
0`000000oooo0?ooo`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool0
05/0oooo0P00001B0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo00000003
0?ooo`00G@3oool200000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`000003
0?ooo`00G`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?oo
o`0000000`3oool00600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0
oooo00<000000?ooo`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo
00<000000?ooo`0000000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`3J0?ooo`8000000P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`000002
0?ooo`00IP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool0e@3oool4000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0
c03oool5000000d0oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3o
ool006`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool0
06d0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0
oooo0P00000o0?ooo`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo
0000000l0?ooo`030000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<0
00000?ooo`3oool0/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<00000
0?ooo`3oool0[@3oool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?oo
o`3oool0ZP3oool400000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@0
0000=@3oool007L0oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000
>@3oool006T0oooo0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3o
ool006P0oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003o
ool0oooo09P0oooo1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3o
ool00`000000oooo0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3o
ool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool0
10000000oooo0?ooo`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3o
ool5000004l0oooo001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4
000005@0oooo00210?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool50000
05P0oooo00220?ooo`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo
00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo
00<000000?ooo`0000009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00
000V0?ooo`030000003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S
0?ooo`030000003oool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3o
ool000007`3oool00`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`03
0000003oool0oooo05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo05/0oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo05L0oooo100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5
000008P0oooo002B0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool40000
08d0oooo002C0?ooo`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00
000F0?ooo`030000003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00
000B0?ooo`030000003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B
0?ooo`030000003oool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?oo
o`030000003oool0oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3o
ool000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?oo
o`00IP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`03
0000003oool0oooo02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`800000
4@3oool00`000000oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3o
ool00`000000oooo0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003o
ool0oooo02<0oooo1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3o
ool2000000X0oooo00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo
000000000000>@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo10000032
0?ooo`00Y03oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool40000
0<H0oooo002V0?ooo`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo
0P0000040?ooo`030000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?oo
o`3oool0000000X0oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000
f03oool00:/0oooo0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.33842 .62526 m
.35081 .62392 L
s
.33842 .62526 m
.33305 .58774 L
s
.35081 .62392 m
.35587 .62157 L
s
.35587 .62157 m
.35891 .61762 L
s
.35891 .61762 m
.36018 .61385 L
s
.36018 .61385 m
.3612 .60829 L
s
.34547 .58638 m
.33305 .58774 L
s
.3612 .60829 m
.35993 .59935 L
s
.35993 .59935 m
.35739 .59417 L
s
.35105 .58758 m
.34547 .58638 L
s
.37389 .60874 m
.37036 .58364 L
s
.35739 .59417 m
.35511 .59078 L
s
.35511 .59078 m
.35105 .58758 L
s
.37491 .60317 m
.37897 .60637 L
s
.37238 .59799 m
.37491 .60317 L
s
.37897 .60637 m
.38279 .60777 L
s
.38279 .60777 m
.38813 .60719 L
s
.39808 .60065 m
.39555 .59546 L
s
.40215 .60385 m
.39808 .60065 L
s
.40597 .60526 m
.40215 .60385 L
s
.41133 .60468 m
.40597 .60526 L
s
.39555 .59546 m
.39505 .59187 L
s
.39505 .59187 m
.39608 .58628 L
s
.41466 .6025 m
.41133 .60468 L
s
.41774 .59852 m
.41466 .6025 L
s
.39608 .58628 m
.39916 .5823 L
s
.41848 .6039 m
.41502 .57872 L
s
.39916 .5823 m
.40249 .5801 L
s
.40249 .5801 m
.40785 .57951 L
s
.43102 .60255 m
.43475 .57655 L
s
.40785 .57951 m
.41168 .58092 L
s
.41168 .58092 m
.41576 .58413 L
s
.44537 .60099 m
.44913 .57497 L
s
.44537 .60099 m
.43475 .57655 L
s
.45974 .59943 m
.44913 .57497 L
s
.47511 .60508 m
.47283 .60167 L
s
.4792 .6083 m
.47511 .60508 L
s
.48304 .60971 m
.4792 .6083 L
s
.47283 .60167 m
.4703 .59646 L
s
.49026 .60893 m
.48304 .60971 L
s
.4703 .59646 m
.46909 .58744 L
s
.49363 .60674 m
.49026 .60893 L
s
.46909 .58744 m
.47017 .58183 L
s
.49676 .60275 m
.49363 .60674 L
s
.47017 .58183 m
.47148 .57802 L
s
.49809 .59894 m
.49676 .60275 L
s
.47148 .57802 m
.47461 .574 L
s
.48714 .58547 m
.49617 .58449 L
s
.47461 .574 m
.47798 .5718 L
s
.47798 .5718 m
.48521 .571 L
s
.49546 .57906 m
.49617 .58449 L
s
.50847 .59416 m
.50512 .56881 L
s
.48521 .571 m
.48907 .57242 L
s
.49317 .57564 m
.49546 .57906 L
s
.48907 .57242 m
.49317 .57564 L
s
.50956 .58853 m
.51366 .59176 L
s
.50704 .5833 m
.50956 .58853 L
s
.51366 .59176 m
.51752 .59317 L
s
.51752 .59317 m
.52296 .59259 L
s
.53315 .58597 m
.53062 .58073 L
s
.53725 .5892 m
.53315 .58597 L
s
.54112 .59062 m
.53725 .5892 L
s
.54658 .59003 m
.54112 .59062 L
s
.53062 .58073 m
.53015 .5771 L
s
.53015 .5771 m
.53126 .57146 L
s
.54998 .58782 m
.54658 .59003 L
s
.55316 .5838 m
.54998 .58782 L
s
.53126 .57146 m
.53442 .56743 L
s
.55386 .58924 m
.55058 .56381 L
s
.53442 .56743 m
.53783 .56521 L
s
.53783 .56521 m
.54329 .56461 L
s
.56662 .58786 m
.56172 .54965 L
s
.54329 .56461 m
.54717 .56603 L
s
.56592 .58241 m
.57003 .58564 L
s
.57003 .58564 m
.57392 .58706 L
s
.54717 .56603 m
.55129 .56927 L
s
.57392 .58706 m
.5794 .58647 L
s
.5794 .58647 m
.58282 .58426 L
s
.58282 .58426 m
.58602 .58022 L
s
.56725 .56382 m
.56406 .56787 L
s
.60479 .59662 m
.59998 .55837 L
s
.58602 .58022 m
.58716 .57457 L
s
.57067 .5616 m
.56725 .56382 L
s
.57616 .561 m
.57067 .5616 L
s
.58716 .57457 m
.5867 .57092 L
s
.5867 .57092 m
.58417 .56566 L
s
.58005 .56242 m
.57616 .561 L
s
.58417 .56566 m
.58005 .56242 L
s
.60227 .57661 m
.60846 .58148 L
s
.60846 .58148 m
.61236 .5829 L
s
.61236 .5829 m
.61786 .5823 L
s
.61786 .5823 m
.62131 .58008 L
s
.62131 .58008 m
.62247 .57441 L
s
.63989 .59469 m
.63783 .59307 L
s
.63783 .59307 m
.63944 .59105 L
s
.64151 .59268 m
.63989 .59469 L
s
.63944 .59105 m
.64151 .59268 L
s
.62247 .57441 m
.6202 .55615 L
s
.63809 .58011 m
.63493 .55453 L
s
.65216 .57303 m
.64965 .56775 L
s
.6563 .57629 m
.65216 .57303 L
s
.66022 .57772 m
.6563 .57629 L
s
.66576 .57712 m
.66022 .57772 L
s
.64965 .56775 m
.6492 .56409 L
s
.6492 .56409 m
.65037 .5584 L
s
.66923 .57489 m
.66576 .57712 L
s
.67249 .57083 m
.66923 .57489 L
s
.65037 .5584 m
.65362 .55433 L
s
.65362 .55433 m
.65709 .55209 L
s
.65709 .55209 m
.66264 .55148 L
s
.68589 .57308 m
.6836 .56962 L
s
.69167 .57431 m
.68589 .57308 L
s
.6836 .56962 m
.68501 .56575 L
s
.66264 .55148 m
.66657 .55291 L
s
.69724 .57371 m
.69167 .57431 L
s
.66657 .55291 m
.67071 .55617 L
s
.68501 .56575 m
.6885 .56351 L
s
.70259 .57127 m
.69724 .57371 L
s
.6885 .56351 m
.69756 .56067 L
s
.68325 .55107 m
.68183 .55495 L
s
.70401 .5674 m
.70259 .57127 L
s
.72105 .58412 m
.71802 .55843 L
s
.68859 .54863 m
.68325 .55107 L
s
.69756 .56067 m
.70106 .55842 L
s
.69417 .54801 m
.68859 .54863 L
s
.70106 .55842 m
.70248 .55455 L
s
.69996 .54924 m
.69417 .54801 L
s
.70248 .55455 m
.70226 .55271 L
s
.70226 .55271 m
.69996 .54924 L
s
.71485 .5476 m
.71649 .54556 L
s
.71693 .54924 m
.71485 .5476 L
s
.71858 .54719 m
.71693 .54924 L
s
.71649 .54556 m
.71858 .54719 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000?@3oool010000?l0oooo0?ooo`0000030?ooo`<0
003oE03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1n0?ooo`030000
003oool0oooo02d0oooo0`00000>0?ooo`030000o`3oool0oooo02d0oooo0P000?l0103oool0003o
0000o`0000040?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0503oool002L0oooo
00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`0Y0?ooo`<000004@3oool00`000?l0oooo
0?ooo`0Q0?ooo`@0003o1P3oool20000o`D0oooo00<000000?ooo`3oool0F03oool00`000000oooo
0?ooo`0D0?ooo`009P3oool300000840oooo00<000000?ooo`3oool09@3oool3000001@0oooo00<0
003o0?ooo`3oool06@3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000003oool0oooo05P0oooo00<0
00000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`0Q
0?ooo`<000005`3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo00@0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`80003o1P3oool00`000?l0oooo0?ooo`08
0?ooo`030000o`000000oooo00@0oooo00<0003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo1000000K0?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?oo
o`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0>0?oo
o`80003o0P3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0580oooo00<000000?oo
o`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`0H0?ooo`<0
00006P3oool00`000?l0oooo0?ooo`020?ooo`D0003o00<0oooo0000o`3oool01P3oool00`000?l0
oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`0<0?ooo`80003o103oool00`000000oooo0?ooo`020?ooo`030000o`3oool0oooo0580
oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`0D0?ooo`<00000603oool60000o`@0oooo00<0003o0?ooo`3oool0103oool20000o`D0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool02P3oool20000o`H0oooo00<000000?ooo`3oool00P3oool00`000?l0oooo
0?ooo`1C0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool0403oool3000000l0oooo00<0003o0?ooo`3oool0203oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool01@000?l0oooo0?oo
o`3oool0003o00`0oooo00<0003o0?ooo`3oool0103oool00`000?l000000?ooo`030?ooo`030000
o`3oool0oooo05<0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0Q`3o
ool00`000000oooo0?ooo`0<0?ooo`<00000203oool40000o`H0oooo00<0003o0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3o
ool01@000?l0oooo0?ooo`3oool0003o00P0oooo00D0003o0?ooo`3oool0oooo0000o`060?ooo`03
0000o`000000oooo00<0oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`00
9P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`00000:0?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`070?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool00`3oool20000o`D0oooo1P000?l00`3oool00000
0?ooo`040?ooo`030000o`3oool0oooo0580oooo00<000000?ooo`3oool04`3oool002D0oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`040?ooo`03000000000?l0000000<0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`040?ooo`80003o0`3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00<0oooo0P000?l20?ooo`030000o`3oool0oooo00`0oooo00<0
00000?ooo`3oool00`3oool00`000?l0oooo0?ooo`1B0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`030000003oool0oooo08H0oooo0`000?l20?ooo`030000o`3oool0oooo00<0000000<0oooo
0000o`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00H0oooo00@0003o
0?ooo`3oool0003o2@3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`80003o1@3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00D0oooo0P000?l?0?ooo`030000003oool0oooo00<0oooo00<0
003o0?ooo`3oool0DP3oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`25
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`02000000@0oooo0P000?l30?ooo`80003o
1P3oool00`000?l0oooo0?ooo`070?ooo`040000o`3oool0oooo0000o`T0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool01@3oool00`000?l0oooo0000o`040000oal0oooo00<000000?ooo`3oool00`3oool00`000?l0
oooo0?ooo`1B0?ooo`030000003oool0oooo01<0oooo000U0?ooo`800000N`3oool00`000?l0oooo
0?ooo`070?ooo`030000o`3oool0oooo00<0oooo0P000?l00`000000oooo0?ooo`030?ooo`80003o
0`3oool20000o`H0oooo00<0003o0?ooo`3oool00`3oool50000o`<0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0
0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0280oooo0P0000050?ooo`030000
o`3oool0oooo05<0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0K03o
ool80000o`H0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`00
0000oooo00@0oooo00<0003o0?ooo`000?l00P3oool00`000?l0oooo0000o`050?ooo`030000o`3o
ool0oooo00/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`80003o103o
ool60000o`P0oooo00<0003o0?ooo`3oool07`3oool300000080oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0
oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo00D0oooo00<0003o0000003oool00`3oool01P000?l0oooo0?ooo`000?l0oooo0000o`80oooo
00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0;0?ooo`80003o2@3oool50000o`030?oo
o`000?l0oooo0140oooo00<0003o0?ooo`3oool06`3oool4000000H0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`1/0?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0003o00@0003o
7@3oool00`000?l0oooo0?ooo`0:0?ooo`80003o303oool3000000X0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1]0?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20000o`<0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo0240oooo
00<0003o0?ooo`3oool02`3oool00`000?l0oooo0?ooo`070?ooo`<000003P3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06h0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00D0oooo00<0
003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o00X0oooo00<0003o0?ooo`3oool0
903oool00`000?l0oooo0?ooo`0B0?ooo`<000004P3oool00`000000oooo0?ooo`1E0?ooo`030000
003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06h0oooo00<0003o0?ooo`3oool01P3o
ool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0103o
ool20000o`@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0g0?ooo`<000005P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0
oooo06h0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`80003o203oool2
0000o`<0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool0<`3oool4000001X0oooo00<000000?ooo`3oool0D`3oool0
0`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`1^0?ooo`030000o`3oool0oooo
00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0000o`090?ooo`<0003o0P3oool00`00
0000oooo0?ooo`0B0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0<@3oool30000
01h0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000
oooo0?ooo`1^0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`040000o`X0oooo00<000000?ooo`3oool04`3oool60000oc40oooo0`00000R0?ooo`03
0000003oool0oooo05<0oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0
K`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo01<0oooo00<000000?ooo`3oool0
A`3oool3000002H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A0?ooo`008`3o
ool200000700oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0C0?ooo`030000003o
ool0oooo04@0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0L03oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo01<0oooo00<000000?ooo`3oool0@03oool4000002h0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`1`0?ooo`030000o`3oool0oooo
00@0oooo00<0003o0?ooo`3oool04`3oool00`000000oooo0?ooo`0n0?ooo`<00000<`3oool00`00
0000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo0700
oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`030000003oool0oooo03/0
oooo0`00000f0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3oool002<0oooo
00<000000?ooo`3oool0L03oool70000oaH0oooo00<000000?ooo`3oool0>03oool3000003X0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<0
00000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a
0?ooo`@00000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?oo
o`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3o
ool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000
CP3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3o
ool00`000000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo
08l0oooo00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0
oooo000G0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000
oooo0?ooo`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0
oooo000J0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo
0?ooo`0E0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo
000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000
001Z0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`03
0000003oool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool03P3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000
NP3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003o
ool0oooo0900oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?oo
o`120?ooo`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?oo
o`<000000P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?oo
o`3oool03P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3o
ool0QP3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000
003oool0oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0
@03oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303o
ool00`000000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3o
ool001l0oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool0
0`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo
07`0oooo0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`00
0000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000
oooo0?ooo`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo
00<000000?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo
0?ooo`0l0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00
000K0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?oo
o`0=0?ooo`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?oo
o`<000008@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3o
ool0S`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000
003oool0oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0
>@3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3o
ool00`000000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303o
ool001d0oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool0
0`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo
05h0oooo0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000
oooo0?ooo`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo
00<000000?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo
0?ooo`0f0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00
000k0?ooo`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?oo
o`0;0?ooo`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F
0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?oo
o`3oool0CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?oo
o`030000003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`03
0000003oool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00
703oool2000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0
<P3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3o
ool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool0
0`000000oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo
03l0oooo1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`00
0000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000
oooo0?ooo`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo
00<000000?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo
0?ooo`0_0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00
001K0?ooo`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`0:0?ooo`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N
0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?oo
o`3oool0;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`03
0000003oool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`00
6P3oool00`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000
003oool0oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3o
ool3000006X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
0200oooo1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000
oooo0?ooo`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo
00<000000?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo
0?ooo`0X0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00
001j0?ooo`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`090?ooo`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?oo
o`3oool04@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?oo
o`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`03
0000003oool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`00
6@3oool00`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203o
ool3000008X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003o
ool0oooo00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`00
0000oooo0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`03
0000003oool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00
603oool2000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000
003oool0oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003o
ool0oooo0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool2
00000100oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0;<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0
oooo00<000000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0
oooo000C0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo
0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
R03oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
1P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo
0P0000000`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0
^@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103o
ool200000100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003o
ool0oooo01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool0
0`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool0
02h0oooo0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo
0;`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0
oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0
oooo000c0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?oo
o`2n0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<00000
0?ooo`3oool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool0
00000?ooo`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?oo
o`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<00000
0?ooo`3oool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool00000
06/0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00@0oooo00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000
oooo0?ooo`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo
0P00001[0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`030?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?oo
o`030000003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000
oooo0?ooo`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo
0P00001S0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`020?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<00000
0?ooo`3oool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?oo
o`800000GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool00P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?oo
o`3oool0d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`04
0000003oool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3o
ool02P3oool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0
E`3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
0@3oool004@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool0
0`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0
oooo0=D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool20000
05<0oooo00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0040oooo001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?oo
o`0000000`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3o
ool000000`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`03
0000003oool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo
0?ooo`3I0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?oo
o`3I0?ooo`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?oo
o`<000000P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`03
0000003oool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003o
ool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool4
00000180oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool50000
01H0oooo001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0
oooo001^0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<0
00000?ooo`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l
0?ooo`030000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0
YP3oool4000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3o
ool5000003T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4
000003h0oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool0
0`000000oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool2
00000340oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo
00000140oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool0
06P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0
oooo08/0oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo
08L0oooo1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880
oooo1@00001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo
00240?ooo`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo
00250?ooo`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo0026
0?ooo`8000009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000
003oool0oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<00000
7`3oool00`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool0
0`000000oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo
0580oooo1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0
oooo1000002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo
002E0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F
0?ooo`8000005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?oo
o`3oool000004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?oo
o`0000004P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`80
00004@3oool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000
003oool0oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@0
0000[03oool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`800000
3P3oool00`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3o
ool200000140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03o
ool006H0oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool0
0`000000oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool3
00000180oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool30000
00030?ooo`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?oo
o`@00000`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0
oooo100000360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo
002W0?ooo`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D00000
0?ooo`3oool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3o
ool400000=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool0
0:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?oo
o`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool20000
0=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.71812 .60795 m
.71895 .58249 L
s
.63722 .60848 m
.63543 .60664 L
s
.63911 .6067 m
.63722 .60848 L
s
.63732 .60485 m
.63911 .6067 L
s
.63543 .60664 m
.63732 .60485 L
s
.69648 .59488 m
.69096 .59479 L
s
.70205 .59315 m
.69648 .59488 L
s
.60232 .60611 m
.60326 .56784 L
s
.69096 .59479 m
.6855 .59288 L
s
.704 .58954 m
.70205 .59315 L
s
.6855 .59288 m
.68377 .58921 L
s
.66521 .59438 m
.65969 .59429 L
s
.66895 .59262 m
.66521 .59438 L
s
.65969 .59429 m
.65607 .59241 L
s
.67273 .58904 m
.66895 .59262 L
s
.68377 .58921 m
.68572 .5856 L
s
.65607 .59241 m
.65249 .58871 L
s
.63761 .59394 m
.6383 .56841 L
s
.68572 .5856 m
.68946 .58384 L
s
.61736 .59361 m
.62109 .59185 L
s
.61184 .59353 m
.61736 .59361 L
s
.65249 .58871 m
.6508 .58322 L
s
.68946 .58384 m
.69871 .58216 L
s
.6082 .59165 m
.61184 .59353 L
s
.69871 .58216 m
.70245 .5804 L
s
.62109 .59185 m
.62308 .58642 L
s
.70245 .5804 m
.7044 .57679 L
s
.60281 .58609 m
.6082 .59165 L
s
.57868 .593 m
.58241 .59123 L
s
.57315 .59291 m
.57868 .593 L
s
.48625 .60427 m
.47887 .60416 L
s
.48997 .60251 m
.48625 .60427 L
s
.7044 .57679 m
.70446 .57496 L
s
.6508 .58322 m
.6509 .57957 L
s
.56951 .59103 m
.57315 .59291 L
s
.62308 .58642 m
.62355 .56817 L
s
.58241 .59123 m
.58618 .58765 L
s
.47887 .60416 m
.47521 .60228 L
s
.49372 .59893 m
.48997 .60251 L
s
.56578 .59279 m
.56663 .55444 L
s
.72114 .57158 m
.71924 .57338 L
s
.71924 .57338 m
.71746 .57152 L
s
.70446 .57496 m
.70274 .57128 L
s
.5659 .58732 m
.56951 .59103 L
s
.71936 .56973 m
.72114 .57158 L
s
.55288 .59258 m
.55342 .56704 L
s
.47521 .60228 m
.47158 .59858 L
s
.71746 .57152 m
.71936 .56973 L
s
.6509 .57957 m
.6529 .57413 L
s
.58618 .58765 m
.58815 .58221 L
s
.5455 .59247 m
.53997 .59238 L
s
.54923 .5907 m
.5455 .59247 L
s
.49563 .59531 m
.49372 .59893 L
s
.68616 .57101 m
.68421 .57463 L
s
.53997 .59238 m
.53632 .5905 L
s
.55299 .58712 m
.54923 .5907 L
s
.70274 .57128 m
.69727 .56937 L
s
.66958 .57075 m
.67316 .57446 L
s
.53632 .5905 m
.5327 .58679 L
s
.47158 .59858 m
.46979 .5949 L
s
.51599 .59199 m
.52153 .59208 L
s
.69174 .56928 m
.68616 .57101 L
s
.69727 .56937 m
.69174 .56928 L
s
.51234 .59011 m
.51599 .59199 L
s
.6529 .57413 m
.65668 .57054 L
s
.58815 .58221 m
.58824 .57856 L
s
.50677 .59185 m
.50723 .56629 L
s
.66595 .56886 m
.66958 .57075 L
s
.50871 .58641 m
.51234 .59011 L
s
.46979 .5949 m
.46803 .5894 L
s
.5327 .58679 m
.53097 .58129 L
s
.65668 .57054 m
.66042 .56877 L
s
.66042 .56877 m
.66595 .56886 L
s
.58824 .57856 m
.58652 .57305 L
s
.50697 .5809 m
.50871 .58641 L
s
.45692 .59105 m
.4499 .56536 L
s
.46803 .5894 m
.46817 .58028 L
s
.53097 .58129 m
.53104 .57764 L
s
.58652 .57305 m
.58292 .56934 L
s
.44214 .59081 m
.4499 .56536 L
s
.44214 .59081 m
.43509 .56512 L
s
.34219 .60199 m
.34775 .60025 L
s
.32924 .60178 m
.34219 .60199 L
s
.53104 .57764 m
.53299 .57219 L
s
.42736 .59058 m
.43509 .56512 L
s
.34775 .60025 m
.35148 .59667 L
s
.57 .56913 m
.56622 .57273 L
s
.32924 .60178 m
.32948 .5634 L
s
.48665 .58058 m
.49588 .58072 L
s
.49598 .57525 m
.49588 .58072 L
s
.58292 .56934 m
.57927 .56745 L
s
.41442 .59037 m
.41473 .56478 L
s
.54969 .5688 m
.5533 .57252 L
s
.40703 .59025 m
.40148 .59016 L
s
.41075 .58849 m
.40703 .59025 L
s
.35148 .59667 m
.35336 .59305 L
s
.57373 .56736 m
.57 .56913 L
s
.40148 .59016 m
.3978 .58828 L
s
.57927 .56745 m
.57373 .56736 L
s
.41449 .5849 m
.41075 .58849 L
s
.53299 .57219 m
.53676 .56859 L
s
.46817 .58028 m
.47011 .57483 L
s
.3978 .58828 m
.39414 .58457 L
s
.37744 .58978 m
.38299 .58987 L
s
.54603 .56692 m
.54969 .5688 L
s
.4942 .57156 m
.49598 .57525 L
s
.35336 .59305 m
.35525 .5876 L
s
.37376 .5879 m
.37744 .58978 L
s
.53676 .56859 m
.54049 .56683 L
s
.36819 .58963 m
.36841 .56403 L
s
.54049 .56683 m
.54603 .56692 L
s
.37009 .58418 m
.37376 .5879 L
s
.39414 .58457 m
.39235 .57906 L
s
.47011 .57483 m
.47201 .5712 L
s
.49056 .56784 m
.4942 .57156 L
s
.35525 .5876 m
.35532 .57846 L
s
.36829 .57867 m
.37009 .58418 L
s
.47201 .5712 m
.47577 .5676 L
s
.48689 .56596 m
.49056 .56784 L
s
.39235 .57906 m
.39239 .5754 L
s
.47577 .5676 m
.4795 .56584 L
s
.4795 .56584 m
.48689 .56596 L
s
.39239 .5754 m
.3943 .56995 L
s
.35532 .57846 m
.35351 .57295 L
s
.411 .56656 m
.41466 .57027 L
s
.3943 .56995 m
.39804 .56635 L
s
.40732 .56466 m
.411 .56656 L
s
.35351 .57295 m
.35169 .56926 L
s
.39804 .56635 m
.40176 .56457 L
s
.40176 .56457 m
.40732 .56466 L
s
.35169 .56926 m
.34801 .56553 L
s
.34801 .56553 m
.34246 .56361 L
s
.34246 .56361 m
.32948 .5634 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`0m0?ooo`<00000=`3oool00`000000oooo0?ooo`1G
0?ooo`030000003oool0oooo01D0oooo000X0?ooo`030000003oool0oooo07X0oooo00<000000?oo
o`3oool0>@3oool3000003X0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?oo
o`009`3oool00`000000oooo0?ooo`1l0?ooo`030000003oool0oooo03D0oooo0`00000m0?ooo`03
0000003oool0oooo05P0oooo00<000000?ooo`3oool0503oool002L0oooo00<000000?ooo`3oool0
O@3oool00`000000oooo0?ooo`0a0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0;@3o
ool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1o0?ooo`030000003oool0oooo02T0oooo0`0000160?ooo`030000003oool0
oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`0000210?ooo`030000003oool0oooo
02D0oooo0`00000F0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`00
0000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`210?ooo`030000003oool0oooo0240
oooo0`00000I0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`230?ooo`030000003oool0oooo01`0oooo
1000000L0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`H0003o203oool00`000?l0oooo0?oo
o`090?ooo`030000003oool0oooo01P0oooo0`00000P0?ooo`030000o`3oool0oooo0340oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`1Z
0?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo00P0oooo1`000?l7
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool3000000<0oooo0`000?l7
0?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0a
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0JP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool01`3oool01P000?l0oooo0?ooo`3oool000000?ooo`80003o1`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0000000800000103oool20000o`<0oooo0P000?l50?ooo`030000o`3o
ool0oooo00P0oooo00<0003o0?ooo`000?l010000?l40?ooo`L0003o1`3oool00`000?l0oooo0?oo
o`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool30000o`T0oooo0`00
0?l20?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0JP3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0003o00H0oooo00<0003o
0?ooo`000?l00`3oool20000o`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool01@3oool0
0`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3oool2
0000o`@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`040000o`3oool0
oooo0?ooo`80003o1@3oool20000o`<0oooo0P000?l010000000oooo0?ooo`3oool30000oe@0oooo
00<000000?ooo`3oool04`3oool002H0oooo00<000000?ooo`3oool0JP3oool00`000?l0oooo0?oo
o`060?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`040?ooo`03000000000?l0oooo00D0oooo00<0003o0?ooo`000?l00`0000000`000?l0oooo0000
o`050?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`070?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo0P000?l60?ooo`050000o`3oool0oooo0?ooo`000?l0
1P3oool00`000?l000000?ooo`030?ooo`030000o`3oool0oooo05<0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0003o000000000?l00`3oool00`000?l0oooo0000o`050?ooo`030000o`3o
ool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000o`080?ooo`030000o`3oool0oooo00D0oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool04@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo
000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool010000?l000000?oo
o`3oool2000000070000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool0203oool01@000?l0oooo0?ooo`3oool0003o00P0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`000000oooo05T0oooo00<00000
0?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?oo
o`040000o`3oool0000000000080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo
00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`D0003o0`3oool00`000?l0oooo
0?ooo`060?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo
0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool03@3oool40000o`030000
003oool0oooo0080oooo00<0003o0?ooo`3oool0D`3oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000006`0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`020?ooo`80003o203o
ool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0000000<0oooo00L0003o0?ooo`3oool0oooo
0000o`3oool0003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0<0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0:0?ooo`<0
003o0`3oool2000000@0oooo00<0003o0?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
9@3oool00`000000oooo0?ooo`1[0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0000o`080?ooo`030000o`3oool0oooo0080oooo0P000?l01@3oool00000
0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool00P3oool01@000?l0oooo0?ooo`3oool0003o
00h0oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`040000o`3oool0oooo
0?ooo`<000000P3oool01@000000oooo0?ooo`3oool0003o05H0oooo00<000000?ooo`3oool04P3o
ool002D0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0
oooo0080oooo00<0003o0?ooo`3oool010000?l50?ooo`H0003o00D0oooo0000003oool0oooo0000
o`050?ooo`030000o`3oool0oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000
o`3oool0003o00L0oooo0P000?l40?ooo`80003o103oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00@0oooo00<0003o0?ooo`000?l0103oool00`000?l0oooo0?ooo`040?ooo`030000
o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool4000000<0
oooo00@0003o0?ooo`3oool000000P3oool00`000?l0oooo0?ooo`1D0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo06/0oooo00<0003o0?ooo`3oool01P3oool00`000?l0
oooo0?ooo`0E0?ooo`030000003oool0oooo00/0oooo00D0003o0?ooo`3oool0oooo0000o`0>0?oo
o`030000o`3oool0oooo00<0003o1P3oool40000o`030?ooo`000?l0oooo00<0oooo1`000?l60?oo
o`030000o`3oool0oooo00D0003o1P3oool00`000?l0oooo0?ooo`030?ooo`80003o0`3oool20000
o`060?ooo`00000000000000003oool0003o1@3oool010000?l0oooo0?ooo`0000020?ooo`030000
o`3oool0oooo05@0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0K03o
ool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo01H0oooo00<000000?ooo`3oool0403o
ool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo02@0oooo00<0003o0?ooo`3oool02`3o
ool00`000?l0oooo0?ooo`050?ooo`<0003o0`0000050?ooo`D0003o103oool00`000000oooo0000
o`1F0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo06`0oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0F0?ooo`030000003oool0oooo0140oooo00<0003o
0?ooo`3oool01@3oool00`000?l0oooo0?ooo`0U0?ooo`030000o`3oool0oooo01<0oooo0`00000B
0?ooo`03000000000?l0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?oo
o`3oool0K03oool00`000?l0oooo0?ooo`030?ooo`80003o6@3oool00`000000oooo0?ooo`0A0?oo
o`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool09P3oool00`000?l0oooo0?ooo`0@0?oo
o`<000005P3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0180oooo000T0?ooo`03
0000003oool0oooo06`0oooo1P000?lK0?ooo`030000003oool0oooo0180oooo1`000?lX0?ooo`03
0000o`3oool0oooo00`0oooo1000000I0?ooo`030000o`000000oooo05@0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`110?ooo`030000
o`3oool0oooo00T0oooo0`00000M0?ooo`030000o`000000oooo05D0oooo00<000000?ooo`3oool0
4@3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`1:0?ooo`<000000P3o
ool00`000?l0oooo0?ooo`0K0?ooo`030000o`3oool0000005D0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`170?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`140?ooo`<00000:P3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0@03oool4000002h0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo03h0oooo0`00000c0?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0k0?ooo`<00000=P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>03oool3000003X0oooo00<00000
0?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03D0oooo0`00000n0?ooo`030000003oool0oooo04h0oooo00<000000?oo
o`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?ooo`@0
0000@P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000
003oool0oooo08h0oooo00<000000?ooo`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo02/0oooo0`00001:0?ooo`030000003oool0oooo04`0oooo00<000000?ooo`3oool0403o
ool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool0
0`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`00
0000oooo0?ooo`0U0?ooo`<00000DP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo
0100oooo000Q0?ooo`800000T03oool00`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo
00<000000?ooo`3oool07P3oool3000005/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0K0?ooo`<00000GP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0H0?ooo`<00000HP3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E
0?ooo`<00000IP3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?oo
o`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?oo
o`030000003oool0oooo04H0oooo00<000000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool02`3oool300000780oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo00P0oooo0`00001f0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool03P3o
ool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo
0900oooo00@000000?ooo`3oool0oooo0`00001o0?ooo`030000003oool0oooo04<0oooo00<00000
0?ooo`3oool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?oo
o`030000003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<00000
0P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
3P3oool001l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0
oooo08D0oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`00
0000oooo0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0
oooo00<000000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo
0`00000A0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo
0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?oo
o`2;0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<00000
0?ooo`3oool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l
0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?oo
o`007P3oool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<00000
8@3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0
303oool001h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0
oooo06H0oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool0
0`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`00
0000oooo0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0
oooo00<000000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000
oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo
0`00000a0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo
0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?oo
o`2C0?ooo`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<00000
0?ooo`3oool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f
0?ooo`030000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?oo
o`030000003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`03
0000003oool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
CP3oool400000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000
003oool0oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003o
ool0oooo09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2
000004T0oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool0
0`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`00
0000oooo0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0
oooo00<000000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000
oooo0?ooo`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo
1000001A0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo
0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?oo
o`2K0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<00000
0?ooo`3oool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?oo
o`030000003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?oo
o`006`3oool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0
;`3oool400000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003o
ool0oooo09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0
oooo02`0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool30000
06X0oooo00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00T0oooo000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo
1000001`0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?oo
o`2T0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<00000
0?ooo`3oool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?oo
o`030000003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?oo
o`006@3oool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0
4@3oool400000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003o
ool0oooo0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool0
0`000000oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool30000
08X0oooo00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
00P0oooo000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo
0?ooo`020?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003o
ool0oooo0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2
000009L0oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0
oooo00L0oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo
0:h0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?oo
o`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`00
0000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100
oooo0P00002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<0
00000?ooo`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C
0?ooo`D000000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool0
0`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool0
01D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P000000
0`3oool000000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool0
00000080oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool20000
0100oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000
oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo
0P0000200?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`050?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<0
00000?ooo`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c
0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3o
ool0M`3oool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3o
ool0103oool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?oo
o`1c0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`040?ooo`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3o
ool0L03oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3o
ool0103oool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo
00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo
00110?ooo`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[
0?ooo`030000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`03
0?ooo`00A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3o
ool0b@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000
003oool0oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?oo
o`3;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S
0?ooo`030000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`02
0?ooo`00C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000
GP3oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
0P3oool004@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0
d03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003o
ool0oooo000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3o
ool2000005X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool0
04@0oooo00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo
00<000000?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo
001K0?ooo`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`000000
0`3oool005d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool00000
0`3oool005l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003o
ool0000000<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I
0?ooo`030000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?oo
o`030000003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0fP3oool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<00000
0P3oool006H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003o
ool0oooo0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool0
0`000000oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo
0<`0oooo1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180
oooo001/0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo
001]0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^
0?ooo`800000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?oo
o`000000?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`03
0000003oool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003o
ool0oooo0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4
000003D0oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool50000
03T0oooo001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0
oooo001X0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000
oooo0?ooo`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340
oooo00<000000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo
00@000000?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0
oooo1@00001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo
1000001D0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00
001H0?ooo`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?oo
o`040000003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?oo
o`030000003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`80
00009P3oool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0
oooo000001l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool0
0`000000oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000
oooo0?ooo`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo
1@0000280?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000
002=0?ooo`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`80
00005P3oool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool0
00004P3oool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`000000
4P3oool00`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3o
ool00`000000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0
oooo000000d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03o
ool006H0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool0
0`000000oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool20000
0140oooo00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0
oooo00<000000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000
oooo0?ooo`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180
oooo0P00000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?oo
o`000000000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000
`P3oool00:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo1000
00360?ooo`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?oo
o`800000103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3o
ool0oooo0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool40000
0=P0oooo002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo
0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.70707 .63058 m
.71156 .6058 L
s
.71523 .59541 m
.71317 .59694 L
s
.71381 .59339 m
.71523 .59541 L
s
.71317 .59694 m
.71175 .59491 L
s
.69397 .61421 m
.68842 .61524 L
s
.69635 .61091 m
.69397 .61421 L
s
.71175 .59491 m
.71381 .59339 L
s
.68842 .61524 m
.68319 .6145 L
s
.69621 .60179 m
.6986 .59849 L
s
.6924 .60307 m
.69621 .60179 L
s
.68319 .6145 m
.67826 .61198 L
s
.6986 .59849 m
.69892 .59671 L
s
.69892 .59671 m
.69781 .59291 L
s
.68335 .6036 m
.6924 .60307 L
s
.69781 .59291 m
.6929 .59038 L
s
.67826 .61198 m
.67715 .60818 L
s
.67954 .60488 m
.68335 .6036 L
s
.67715 .60818 m
.67954 .60488 L
s
.6929 .59038 m
.68766 .58962 L
s
.68766 .58962 m
.68209 .59065 L
s
.68209 .59065 m
.6797 .59396 L
s
.66665 .60669 m
.66251 .60975 L
s
.66251 .60975 m
.65869 .61103 L
s
.65869 .61103 m
.65343 .61028 L
s
.65343 .61028 m
.65024 .60801 L
s
.66633 .58838 m
.6692 .59245 L
s
.65024 .60801 m
.64735 .60394 L
s
.66314 .58609 m
.66633 .58838 L
s
.63189 .62001 m
.62982 .62154 L
s
.63045 .61798 m
.63189 .62001 L
s
.64735 .60394 m
.64654 .59835 L
s
.62982 .62154 m
.62837 .61952 L
s
.65787 .58533 m
.66314 .58609 L
s
.62837 .61952 m
.63045 .61798 L
s
.64654 .59835 m
.64718 .59478 L
s
.65403 .58661 m
.65787 .58533 L
s
.64718 .59478 m
.64988 .58968 L
s
.64988 .58968 m
.65403 .58661 L
s
.63233 .60729 m
.63675 .58229 L
s
.61677 .60326 m
.61948 .59815 L
s
.61293 .60454 m
.61677 .60326 L
s
.61948 .59815 m
.62262 .58026 L
s
.60762 .60379 m
.61293 .60454 L
s
.59659 .61505 m
.60315 .57746 L
s
.6044 .6015 m
.60762 .60379 L
s
.60002 .59538 m
.6044 .6015 L
s
.58374 .5949 m
.58645 .58977 L
s
.57956 .59798 m
.58374 .5949 L
s
.5757 .59927 m
.57956 .59798 L
s
.58645 .58977 m
.58707 .58618 L
s
.57036 .59851 m
.5757 .59927 L
s
.58707 .58618 m
.58623 .58054 L
s
.56711 .59621 m
.57036 .59851 L
s
.58623 .58054 m
.58329 .57644 L
s
.56416 .59211 m
.56711 .59621 L
s
.56323 .5975 m
.56974 .55972 L
s
.58329 .57644 m
.58004 .57413 L
s
.58004 .57413 m
.5747 .57336 L
s
.5747 .57336 m
.57082 .57465 L
s
.55074 .59573 m
.55506 .57053 L
s
.57082 .57465 m
.56664 .57773 L
s
.55167 .59034 m
.54748 .59343 L
s
.54748 .59343 m
.54359 .59472 L
s
.54359 .59472 m
.53823 .59396 L
s
.53823 .59396 m
.53495 .59165 L
s
.55117 .57182 m
.55413 .57594 L
s
.53495 .59165 m
.53198 .58754 L
s
.5479 .5695 m
.55117 .57182 L
s
.53198 .58754 m
.53111 .58188 L
s
.54253 .56873 m
.5479 .5695 L
s
.53111 .58188 m
.53172 .57827 L
s
.51491 .59065 m
.5203 .59141 L
s
.53864 .57002 m
.54253 .56873 L
s
.53172 .57827 m
.53444 .57311 L
s
.53444 .57311 m
.53864 .57002 L
s
.51162 .58834 m
.51491 .59065 L
s
.50863 .58422 m
.51162 .58834 L
s
.50592 .58938 m
.51018 .56407 L
s
.50774 .57854 m
.50863 .58422 L
s
.49209 .59481 m
.48788 .59791 L
s
.4945 .59146 m
.49209 .59481 L
s
.48788 .59791 m
.48397 .59921 L
s
.48397 .59921 m
.47674 .59819 L
s
.47674 .59819 m
.47343 .59588 L
s
.4879 .57571 m
.49693 .577 L
s
.49784 .57157 m
.49693 .577 L
s
.49664 .56769 m
.49784 .57157 L
s
.47343 .59588 m
.47041 .59175 L
s
.49364 .56355 m
.49664 .56769 L
s
.47041 .59175 m
.46921 .58788 L
s
.49032 .56122 m
.49364 .56355 L
s
.46921 .58788 m
.4683 .58219 L
s
.48309 .56017 m
.49032 .56122 L
s
.4683 .58219 m
.4698 .57313 L
s
.47916 .56147 m
.48309 .56017 L
s
.4698 .57313 m
.47252 .56795 L
s
.47494 .56458 m
.47916 .56147 L
s
.47252 .56795 m
.47494 .56458 L
s
.45712 .58246 m
.45405 .55599 L
s
.44258 .5804 m
.45405 .55599 L
s
.44258 .5804 m
.43947 .5539 L
s
.428 .57833 m
.43947 .5539 L
s
.41522 .57652 m
.41938 .551 L
s
.41611 .57106 m
.41186 .57418 L
s
.41186 .57418 m
.40791 .57548 L
s
.40791 .57548 m
.40241 .57471 L
s
.40241 .57471 m
.39904 .57236 L
s
.41542 .5523 m
.41849 .55648 L
s
.39904 .57236 m
.39596 .5682 L
s
.41205 .54995 m
.41542 .5523 L
s
.39596 .5682 m
.39501 .56246 L
s
.40655 .54916 m
.41205 .54995 L
s
.39501 .56246 m
.3956 .5588 L
s
.37855 .57132 m
.38406 .57211 L
s
.40259 .55046 m
.40655 .54916 L
s
.3956 .5588 m
.39832 .55359 L
s
.39832 .55359 m
.40259 .55046 L
s
.37516 .56898 m
.37855 .57132 L
s
.37207 .5648 m
.37516 .56898 L
s
.36935 .57002 m
.37344 .54439 L
s
.3711 .55905 m
.37207 .5648 L
s
.35158 .57499 m
.35401 .57159 L
s
.3473 .57812 m
.35158 .57499 L
s
.35401 .57159 m
.35673 .56636 L
s
.34147 .57917 m
.3473 .57812 L
s
.35673 .56636 m
.35818 .5572 L
s
.32851 .57735 m
.34147 .57917 L
s
.35818 .5572 m
.35721 .55144 L
s
.35721 .55144 m
.35595 .54751 L
s
.32851 .57735 m
.33458 .5388 L
s
.35595 .54751 m
.35283 .5433 L
s
.35283 .5433 m
.34757 .54067 L
s
.34757 .54067 m
.33458 .5388 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1R0?oo
o`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`80
00001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo05h0oooo0`00000N0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1I0?ooo`@000008@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0E@3o
ool3000002D0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0F0?ooo`00:03oool0
0`000000oooo0000001d0?ooo`030000003oool0oooo0540oooo0`00000X0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001f0?ooo`030000003oool0oooo
04d0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0
oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool0B@3oool3000002h0
oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`001@3oool00`000000oooo
0000000P0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0A@3oool300000340oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool00`000000oooo0000
000Q0?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0@@3oool3000003@0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00103oool400000200oooo00<00000
0?ooo`3oool0JP3oool20000o`d0oooo00<000000?ooo`3oool0?@3oool3000003L0oooo00<00000
0?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool00`000000oooo0?ooo`1Z0?oo
o`030000o`3oool0003o0080003o2`3oool00`000000oooo0?ooo`0i0?ooo`<00000>P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo06/0
oooo00<0003o0?ooo`3oool00P3oool20000o`L0oooo00@0003o0?ooo`3oool00000=`3oool30000
03d0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000
oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00D0oooo0P000?l50?ooo`050000o`3oool0oooo0?oo
o`000000<`3oool300000400oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?oo
o`009`3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3o
ool00`3oool00`000?l0oooo0?ooo`020?ooo`030000003oool0oooo00<0oooo10000?lV0?ooo`<0
0000@`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000
003oool0oooo06X0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000o`040?ooo`<0003o803oool3000004H0
oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009P3oool3000006/0oooo
00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo
00<000000?ooo`000?l01P3oool20000o`L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0>0?ooo`<00000B@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo06T0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?oo
o`040?ooo`80003o103oool00`000?l0oooo0?ooo`0;0?ooo`<00000C03oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo06X0oooo00<0003o
0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00H0oooo00<0003o
0000003oool01P3oool00`000?l0oooo0?ooo`040?ooo`80003o0`3oool20000o`T0oooo1@000?lL
0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D
0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3oool0000000H0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0000o`030?ooo`80003o1P3oool2000000030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo
0300oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000
oooo0?ooo`1Z0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool20000o`L0
oooo00@0003o0?ooo`3oool00000103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o
0080oooo00<0003o0?ooo`000?l00`3oool3000000030?ooo`000?l0oooo00D0oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`0C0?ooo`030000o`3oool0oooo0300oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`1Z0?ooo`03
0000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000o`060?ooo`05
0000o`3oool0oooo0?ooo`0000000`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3oool0oooo
0000o`80oooo00<0003o0?ooo`000?l00`0000030?ooo`030000o`3oool0oooo00H0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`090?ooo`<0003o1`3oool00`000?l0oooo0?ooo`0`
0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<000000?oo
o`3oool0J@3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0oooo00<0003o0?oo
o`3oool00`000?l40?ooo`050000o`3oool0oooo0?ooo`0000000P3oool00`000?l0oooo0?ooo`03
0?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`02000000030000o`3oool0oooo0080oooo
00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00P0oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0003o00<0oooo00<0003o0?ooo`3oool0<@3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo06T0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0?0?ooo`80003o0P3oool30000o`@0
oooo00D0003o0?ooo`3oool0oooo000000020000o`<0oooo00<0003o0?ooo`3oool00P3oool00`00
0?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01P3oool20000
o`@0oooo00<0003o0?ooo`000?l00`3oool00`000?l0oooo0000o`030000obh0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`000000oooo0?ooo`1Z0?ooo`<0
003o1P3oool00`000?l0oooo0?ooo`0A0?ooo`80003o00<0oooo000000000?l0103oool01@000?l0
0000000000000000oooo0080003o0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
00@0oooo10000?l30?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool01@3oool20000
o`<0oooo0P000?l40?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool08`3oool00`00
0000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo06d0
oooo1P000?lH0?ooo`060000003oool0oooo000000000?l00000103oool00`000?l0oooo0?ooo`02
0?ooo`050000o`3oool0oooo0?ooo`000?l03P3oool00`000?l0oooo0?ooo`060?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool08`3oool00`000000oooo0?ooo`1H0?ooo`030000003o
ool0oooo01<0oooo000U0?ooo`030000003oool0oooo08`0oooo0P0000070?ooo`030000o`3oool0
oooo0080oooo00D0003o0?ooo`3oool0oooo0000o`0>0?ooo`030000o`3oool0oooo00H0oooo00<0
003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00<0
003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0
003o0?ooo`3oool05`3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U
0?ooo`800000S@3oool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00`0oooo0P000?l7
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool03P3oool2000005/0oooo00<00000
0?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0@0?oo
o`030000o`3oool0oooo00/0oooo0P000?l70?ooo`030000o`3oool0oooo00D0oooo00<0003o0?oo
o`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo0080oooo00<0003o0?oo
o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00@0oooo00@0003o0?oo
o`000?l0003o2`3oool300000080oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0B
0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0100oooo00<0003o0?oo
o`3oool02`3oool010000?l0oooo0000o`000?l50?ooo`030000o`3oool0oooo00@0oooo0P000?l3
0?ooo`030000o`3oool0oooo00H0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`04
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool20000o`@0oooo00<0003o
0?ooo`3oool00`3oool00`000?l0000000000002000000H0oooo00<000000?ooo`3oool0E`3oool0
0`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo
0100oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`060?ooo`80003o103oool00`00
0?l0oooo0?ooo`020?ooo`80003o103oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo
00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`050000o`3oool0oooo
0?ooo`000?l01`3oool00`000?l0oooo0?ooo`03000000@0oooo0P000?l40?ooo`03000000000?l0
oooo05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0A0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool03P3oool40000
o`030?ooo`000?l0oooo00<0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo0P000?l60?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?oo
o`<0000000<0oooo0000o`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`030000o`000000003o
05L0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0B0?ooo`80003o0`3oool00`000?l0oooo0?ooo`0I0?ooo`040000o`3oool0003o0000
o`80oooo0P000?l50?ooo`80003o1P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo
0080oooo00<0003o0?ooo`3oool00P3oool3000000/0oooo0P000?l40?ooo`030000o`000000oooo
05H0oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000
oooo0?ooo`0D0?ooo`<0003o803oool20000o`L0oooo00<0003o0?ooo`000?l0103oool00`000?l0
oooo0?ooo`030?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`0000000P00000>0?ooo`03
0000o`3oool0oooo00D0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00
903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0400oooo00@0003o0?ooo`3oool0
003o0`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@00000303oool60000o`P0
oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo
0?ooo`2=0?ooo`030000003oool0oooo0400oooo00@0003o0?ooo`3oool0oooo0`000?l60?ooo`<0
00000P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo0080oooo0P000?l:0?ooo`05
0000o`3oool0oooo0?ooo`000000EP3oool00`000000oooo0?ooo`0A0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo03l0oooo00<0003o0?ooo`3oool0203oool300000003
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool00P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
?`3oool00`000?l0oooo0?ooo`050?ooo`<000002P3oool50000o`D0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<000000?ooo`3oool0
DP3oool00`000000oooo0?ooo`0A0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0?`3o
ool00`000?l0oooo0?ooo`020?ooo`<00000603oool20000o`<0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`040?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`100?ooo`@000007@3oool3
0000o`H0oooo00<0003o0?ooo`3oool01@3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool30000
00/0oooo0`000?lK0?ooo`030000o`3oool0oooo00L0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo03/0
oooo0`00000?0?ooo`030000o`3oool0oooo01X0oooo00<0003o0?ooo`3oool01`3oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>03oool3000002l0oooo00<0003o0?ooo`3oool0203oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0=@3oool300000380oooo00<0003o0?ooo`3oool02@3oool00`000000oooo0?oo
o`1>0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0<@3oool4000003D0oooo00<0003o0?ooo`3oool02P3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<000000?oo
o`3oool0;P3oool3000004L0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?oo
o`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`00001:0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0
SP3oool00`000000oooo0?ooo`0X0?ooo`<00000CP3oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0oooo0100oooo000R0?ooo`<00000SP3oool00`000000oooo0?ooo`0U0?ooo`<00000DP3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool0
0`000000oooo0?ooo`0Q0?ooo`@00000EP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
05/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0K0?ooo`<00000GP3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0
oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000HP3oool00`000000
oooo0?ooo`180?ooo`030000003oool0oooo00l0oooo000J0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0E0?ooo`<00000IP3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?oo
o`2?0?ooo`030000003oool0oooo0140oooo1000001Z0?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool03`3oool001P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2?
0?ooo`030000003oool0oooo00h0oooo0`00001_0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool03`3oool001P0oooo0`0000050?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool02`3oool300000780oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0?0?oo
o`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00P0oooo0`00001f0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0
T03oool00`000000oooo0?ooo`040?ooo`@00000NP3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3oool0oooo
0`00001o0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool03P3oool00200oooo0P00
002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00h0oooo000O
0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?ooo`250?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3o
ool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0oooo0`0000090?ooo`030000
003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?ooo`007`3o
ool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`030000003o
ool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O`3oool3
000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000
oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool3000001P0oooo
00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00d0oooo
000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0oooo00<0
00000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1`
0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<00000
0?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?ooo`2>0?oo
o`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3o
ool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j0?ooo`03
0000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?ooo`030000
003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?ooo`007@3o
ool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`030000003o
ool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0H@3oool3
000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0
oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003oool0oooo
0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000
oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo03H0
oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool3000003P0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo00/0oooo
000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0oooo00<0
00000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1B
0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<000000?oo
o`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L0?ooo`03
0000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3o
ool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?ooo`030000
003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`030000003o
ool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0@P3oool3
000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003oool0oooo
09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000
oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0oooo0300
oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool3000005P0oooo
00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo00X0oooo
000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0c
0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo00<00000
0?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<000000?oo
o`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K0?ooo`03
0000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?ooo`<00000
I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
2@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3oool0XP3o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`8000009@3oool3
000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0
oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003oool0oooo
0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool3000007L0oooo
00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00T0oooo
000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo0?ooo`0E
0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<000000?oo
o`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`03
0000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?ooo`<00000
Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3oool0ZP3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0
oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03oool00`00
0000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203oool001P0
oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?ooo`3oool0
[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D000000P3o
ool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`030000003o
ool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`002@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980oooo00<0
00000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0oooo0009
0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000003oool0
oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3oool00`00
0000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool2000000T0oooo
00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?ooo`030000
003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?ooo`003@3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00X0oooo
0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3oool0P@3o
ool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3o
ool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003oool0oooo
0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool010000000
oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo07X0oooo
00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00D0oooo
000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<000000?oo
o`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<000000?oo
o`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0oooo0<40
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool2000007@0oooo
00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00@0oooo
000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`33
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00001`0?oo
o`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`040?oo
o`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0oooo0000
06/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo0<L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0oooo00<0
00000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0oooo0017
0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<000000?oo
o`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00190?ooo`80
000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo0</0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680oooo00<0
00000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080oooo001>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?ooo`3?0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;0?ooo`04
0000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<000000?oo
o`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<000000?ooo`3o
ool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?ooo`@00000
0`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3oool03`3o
ool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0
oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3oool01000
0000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool00`000000
oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@0?ooo`03
0000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?ooo`800000
00<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo
001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080oooo001S
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo001T0?oo
o`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo100000050?ooo`00
I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?ooo`@00000
2@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00JP3oool2
000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003oool0oooo
0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`000000oooo
0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000oooo0?oo
o`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo1000000X
0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00000/0?oo
o`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a0?ooo`00
M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`030000003o
ool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`8000003@3oool2
000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003oool0oooo
000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000@P3oool0
06P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0U03oool4
000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0;P3oool0
0`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool000004P3oool0
0`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3oool20000
01@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool2000002X0oooo
00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo000002H0oooo
00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0oooo00<0
00000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo0?ooo`1a
0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1]0?oo
o`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3o
ool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?ooo`D00000
N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@00000P03o
ool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000Q03oool0
0900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool00`000000
oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool2000001T0oooo
00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo0?ooo`11
0?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo0?ooo`0l
0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0h0?oo
o`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d0?ooo`D0
0000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?ooo`3oool0
9@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?ooo`@00000
/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`0000002`3o
ool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`0000008`3oool0
0`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000^@3oool0
06D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000003oool0
oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P0000000`3oool0
00000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool2000000D0oooo
00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000oooo0?oo
o`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D00000d`3o
ool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<000000P3oool4
00000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3o
ool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo00<00000
0?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0
oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.68867 .65115 m
.6965 .62743 L
s
.70144 .6177 m
.69931 .61895 L
s
.70043 .61556 m
.70144 .6177 L
s
.69931 .61895 m
.6983 .61681 L
s
.6983 .61681 m
.70043 .61556 L
s
.68167 .63066 m
.67897 .63362 L
s
.67897 .63362 m
.67366 .63398 L
s
.68559 .61876 m
.68615 .61706 L
s
.68289 .62172 m
.68559 .61876 L
s
.68615 .61706 m
.68569 .61321 L
s
.67917 .62252 m
.68289 .62172 L
s
.67366 .63398 m
.66891 .63265 L
s
.68569 .61321 m
.68151 .61015 L
s
.67069 .62198 m
.67917 .62252 L
s
.66891 .63265 m
.66472 .62961 L
s
.68151 .61015 m
.67676 .6088 L
s
.66696 .62279 m
.67069 .62198 L
s
.66472 .62961 m
.66425 .62575 L
s
.67676 .6088 m
.67145 .60915 L
s
.66425 .62575 m
.66696 .62279 L
s
.67145 .60915 m
.66874 .61211 L
s
.65471 .62306 m
.6504 .62558 L
s
.6504 .62558 m
.64664 .62639 L
s
.65713 .60506 m
.65919 .60939 L
s
.64664 .62639 m
.64185 .62504 L
s
.6545 .60244 m
.65713 .60506 L
s
.64185 .62504 m
.63921 .62243 L
s
.64971 .60107 m
.6545 .60244 L
s
.63921 .62243 m
.63713 .6181 L
s
.64594 .60187 m
.64971 .60107 L
s
.63713 .6181 m
.63721 .61251 L
s
.64162 .60439 m
.64594 .60187 L
s
.63721 .61251 m
.63833 .60908 L
s
.63833 .60908 m
.64162 .60439 L
s
.62027 .63209 m
.6181 .63335 L
s
.61923 .62992 m
.62027 .63209 L
s
.6181 .63335 m
.61705 .63119 L
s
.61705 .63119 m
.61923 .62992 L
s
.62259 .61963 m
.63045 .59557 L
s
.61192 .60912 m
.61754 .59189 L
s
.60862 .61382 m
.61192 .60912 L
s
.60482 .61464 m
.60862 .61382 L
s
.59996 .61327 m
.60482 .61464 L
s
.59727 .61063 m
.59996 .61327 L
s
.59408 .60408 m
.59727 .61063 L
s
.5879 .62306 m
.5997 .58679 L
s
.58216 .59693 m
.58328 .59347 L
s
.57883 .60166 m
.58216 .59693 L
s
.57444 .60421 m
.57883 .60166 L
s
.58328 .59347 m
.58333 .5878 L
s
.5706 .60502 m
.57444 .60421 L
s
.58333 .5878 m
.58119 .5834 L
s
.56568 .60363 m
.5706 .60502 L
s
.58119 .5834 m
.57847 .58073 L
s
.56295 .60098 m
.56568 .60363 L
s
.57847 .58073 m
.57355 .57933 L
s
.56079 .59658 m
.56295 .60098 L
s
.57355 .57933 m
.5697 .58013 L
s
.5591 .60179 m
.57092 .56526 L
s
.5697 .58013 m
.56529 .58267 L
s
.54756 .59854 m
.55544 .57415 L
s
.54924 .59332 m
.54481 .59587 L
s
.54481 .59587 m
.54094 .59668 L
s
.55157 .57495 m
.55375 .57938 L
s
.54094 .59668 m
.53597 .59529 L
s
.54882 .57226 m
.55157 .57495 L
s
.53597 .59529 m
.53321 .59261 L
s
.54385 .57084 m
.54882 .57226 L
s
.53321 .59261 m
.53101 .58818 L
s
.53997 .57164 m
.54385 .57084 L
s
.53101 .58818 m
.53104 .58247 L
s
.53552 .5742 m
.53997 .57164 L
s
.53104 .58247 m
.53217 .57897 L
s
.53217 .57897 m
.53552 .5742 L
s
.51432 .5892 m
.51933 .59061 L
s
.51154 .58651 m
.51432 .5892 L
s
.50932 .58206 m
.51154 .58651 L
s
.50934 .57633 m
.50932 .58206 L
s
.50596 .58685 m
.51385 .56228 L
s
.49476 .58753 m
.49195 .59058 L
s
.49195 .59058 m
.48746 .59315 L
s
.48746 .59315 m
.48352 .59396 L
s
.49085 .57109 m
.49927 .57348 L
s
.50096 .5682 m
.49927 .57348 L
s
.50041 .5642 m
.50096 .5682 L
s
.48352 .59396 m
.47677 .59208 L
s
.49817 .55972 m
.50041 .5642 L
s
.49536 .557 m
.49817 .55972 L
s
.47677 .59208 m
.47395 .58938 L
s
.48861 .55507 m
.49536 .557 L
s
.47395 .58938 m
.47169 .58491 L
s
.47169 .58491 m
.47112 .58091 L
s
.48466 .55587 m
.48861 .55507 L
s
.47112 .58091 m
.47112 .57514 L
s
.48015 .55844 m
.48466 .55587 L
s
.47112 .57514 m
.47394 .56631 L
s
.47733 .56149 m
.48015 .55844 L
s
.47394 .56631 m
.47733 .56149 L
s
.46036 .57404 m
.46145 .54731 L
s
.44672 .5702 m
.46145 .54731 L
s
.44672 .5702 m
.44778 .54341 L
s
.43301 .56635 m
.44778 .54341 L
s
.42096 .56297 m
.42887 .53801 L
s
.42266 .55762 m
.41808 .56022 L
s
.41808 .56022 m
.41406 .56103 L
s
.42486 .53881 m
.42718 .54336 L
s
.41406 .56103 m
.40887 .55957 L
s
.42197 .53604 m
.42486 .53881 L
s
.40887 .55957 m
.40597 .55681 L
s
.41678 .53456 m
.42197 .53604 L
s
.40597 .55681 m
.40363 .55226 L
s
.41275 .53536 m
.41678 .53456 L
s
.40363 .55226 m
.40359 .5464 L
s
.40815 .53795 m
.41275 .53536 L
s
.40359 .5464 m
.40472 .54282 L
s
.40472 .54282 m
.40815 .53795 L
s
.38628 .55322 m
.39151 .55469 L
s
.38335 .55045 m
.38628 .55322 L
s
.38099 .54587 m
.38335 .55045 L
s
.38093 .53999 m
.38099 .54587 L
s
.37754 .55076 m
.38546 .52561 L
s
.36584 .54552 m
.36867 .53652 L
s
.36239 .55042 m
.36584 .54552 L
s
.3595 .55352 m
.36239 .55042 L
s
.35485 .55614 m
.3595 .55352 L
s
.36867 .53652 m
.36861 .53062 L
s
.349 .55646 m
.35485 .55614 L
s
.36861 .53062 m
.36798 .52652 L
s
.36798 .52652 m
.36559 .52191 L
s
.33663 .55301 m
.349 .55646 L
s
.36559 .52191 m
.36088 .51859 L
s
.36088 .51859 m
.34851 .51506 L
s
.33663 .55301 m
.34851 .51506 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo0840oooo0`0000020?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo
0?ooo`1m0?ooo`<000001@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo
000Z0?ooo`800000J@3oool00`000000oooo0?ooo`1j0?ooo`<00000203oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<00000
0?ooo`3oool0MP3oool3000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G
0?ooo`008@3oool2000000L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1b0?oo
o`<000003P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`04
0000003oool0oooo000000H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1^0?oo
o`<000004@3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1Z0?oo
o`<00000503oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1V0?oo
o`<00000603oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`04
0000003oool0oooo000000D0oooo00<000000?ooo`3oool0KP3oool20000of@0oooo0`00000K0?oo
o`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00240oooo0P0000060?ooo`03
0000003oool0oooo06h0oooo00<0003o0?ooo`000?l00P000?mN0?ooo`<000007P3oool00`000000
oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo06d0oooo
00L0003o0?ooo`3oool0oooo0000003oool0003o05T0oooo1000000Q0?ooo`030000003oool0oooo
05H0oooo00<000000?ooo`3oool05P3oool002T0oooo00<000000?ooo`3oool0K@3oool00`000?l0
oooo0?ooo`020?ooo`030000003oool0003o05D0oooo0`00000U0?ooo`030000003oool0oooo05H0
oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000KP3oool00`000?l0oooo
0?ooo`030?ooo`030000003oool0003o00H0oooo00<0003o0?ooo`3oool0B03oool3000002P0oooo
00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00:03oool2000006h0oooo00<0
003o0?ooo`3oool01@3oool00`000000003o0?ooo`050?ooo`030000o`3oool0oooo04D0oooo0`00
000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo1000000P
0?ooo`030000003oool0oooo06d0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`03
0?ooo`030000o`3oool0oooo04<0oooo0`00000^0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool05@3oool000D0oooo00<000000?ooo`000000803oool00`000000oooo0?ooo`1/0?oo
o`030000o`3oool0oooo00L0oooo00<0003o0000003oool00`3oool00`000?l0oooo0?ooo`090?oo
o`030000o`3oool0oooo03@0oooo0`00000a0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo00<000000?ooo`0000008@3oool00`000000oooo0?ooo`1/0?ooo`03
0000o`3oool0oooo00L0oooo00<0003o0?ooo`0000000`3oool00`000?l0oooo0?ooo`080?ooo`04
0000o`3oool0003o0000oc40oooo0`00000d0?ooo`030000003oool0oooo05L0oooo00<000000?oo
o`3oool05@3oool000@0oooo1000000P0?ooo`030000003oool0oooo06`0oooo00<0003o0?ooo`3o
ool01`3oool01P000?l0oooo0?ooo`000000oooo0000o`T0oooo0P000?l40?ooo`030000o`3oool0
003o02/0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
02P0oooo00<000000?ooo`3oool0J`3oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo
0080oooo00<000000000o`3oool01`3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0003o
02P0oooo0`00000j0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002L0
oooo00<000000?ooo`3oool0K03oool00`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00D0
oooo00<0003o0?ooo`3oool0703oool3000003d0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1/0?ooo`030000o`3oool0oooo00L0oooo
00<0003o0?ooo`3oool00P3oool20000o`030000003oool0oooo00@0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`040?ooo`80003o103oool00`000?l0oooo0?ooo`0D0?ooo`<00000
@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003o
ool0oooo06/0oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`030?ooo`040000o`3o
ool0003o000000D0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0003o00<0oooo0P000?lC0?ooo`<00000@`3oool00`000000oooo0?ooo`1H0?ooo`030000
003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo06/0oooo0P000?l70?ooo`030000o`3o
ool0oooo00L0oooo00<0003o0000003oool00`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`000?l00`3oool20000oa00oooo0`0000160?ooo`030000003o
ool0oooo05P0oooo00<000000?ooo`3oool0503oool002H0oooo0`00001^0?ooo`80003o1@3oool0
0`000?l0oooo0?ooo`080?ooo`80003o0`3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo00<0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo0000o`080?ooo`<0003o0P3o
ool3000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`1_0?ooo`D0003o3@3oool01@000000oooo0?ooo`3oool0003o00D0oooo0P00
0?l40?ooo`040000o`3oool0oooo0000o`80oooo00@0003o0?ooo`3oool0003o1P3oool20000o`80
oooo00<000000000o`000?l0C03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0
oooo000V0?ooo`030000003oool0oooo08<0oooo00@000000?ooo`3oool0oooo1P000?l40?ooo`05
0000o`3oool0oooo0?ooo`000?l00P3oool010000?l0oooo0?ooo`000?l50?ooo`030000o`000000
0000008000000`3oool00`000?l0oooo0?ooo`1:0?ooo`030000003oool0oooo05L0oooo00<00000
0?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`050?oo
o`030000o`3oool0oooo0080oooo00L0003o0?ooo`3oool0oooo0000o`3oool0003o00<0oooo00L0
003o0?ooo`3oool0oooo000000000?l0000000L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`150?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo
00<000000?ooo`3oool0Q@3oool00`000000oooo0?ooo`080?ooo`030000o`3oool0oooo0080oooo
0P000?l40?ooo`060000o`00000000000000003oool0003o203oool00`000?l0oooo0?ooo`020?oo
o`030000o`3oool0oooo01<0oooo00<0003o0?ooo`3oool0;`3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3o
ool0303oool20000o`80oooo0P0000000`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo0000o`0E0?ooo`030000o`3oool0oooo02l0oooo00<000000?oo
o`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo00/0oooo00@0003o00000000000000000P3oool01@000?l0oooo0?ooo`3oool0
003o00H0oooo0P000?l00`3oool0003o0?ooo`020?ooo`030000o`3oool0oooo00P0oooo0`000?l8
0?ooo`030000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C
0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo00P0oooo0`0000050?oo
o`050000o`3oool0oooo0?ooo`000?l0203oool20000o`<0oooo00<0003o0?ooo`3oool01`3oool0
10000?l0oooo0?ooo`3oool20000o`030?ooo`000?l0oooo00<0oooo00<0003o0?ooo`3oool0<03o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0
oooo08X0oooo00<000000?ooo`3oool0103oool3000000`0oooo00<0003o0?ooo`3oool02`3oool0
0`000?l0oooo0?ooo`060?ooo`030000o`3oool0oooo00@0oooo0P000?l40?ooo`030000o`3oool0
oooo0300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool00`00
0000oooo0?ooo`2;0?ooo`030000003oool0oooo00<000003`3oool00`000?l0oooo0?ooo`0;0?oo
o`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?oo
o`@0003o<03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`03
0000003oool0oooo08`0oooo0P00000B0?ooo`030000o`3oool0oooo00X0oooo0P000?l70?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool010000?l0oooo0?ooo`3oool20000
obh0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0
oooo00<000000?ooo`3oool04@3oool00`000?l0oooo0?ooo`0:0?ooo`80003o1`3oool00`000?l0
oooo0?ooo`050?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0Z0?oo
o`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo0140oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0003o00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0P0?ooo`<0
00000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0180oooo000U0?ooo`030000
003oool0oooo08`0oooo00<000000?ooo`3oool04P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo00H0oooo0`000?l30?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
0P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0
703oool4000000H0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0B0?ooo`009@3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo01<0oooo00D0003o0?ooo`3oool0oooo
0000o`0@0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0C0?ooo`<0
00002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0503oool30000oa80oooo00<0003o0?ooo`3oool0
0P000?l40?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool02`3oool3000000h0oooo
00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo02X0oooo0P000?l00`3oool0003o0?ooo`030?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`040?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0203oool300000180oooo00<000000?ooo`3oool0E@3o
ool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`030000003oool0
oooo0340oooo00<0003o0?ooo`000?l01@3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`050?ooo`040000o`000000
0000000001H0oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool0
0`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0340oooo00@0003o0?ooo`3oool0003o0P3o
ool20000o`D0oooo0P000?l60?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool00P3o
ool400000080003o603oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo000T
0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0=@3oool20000o`L0oooo0P000?l5
0?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`0000000P0000020000o`@0oooo00<0003o
0?ooo`3oool05@3oool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0?P3oool20000o`D0oooo00<0003o0?oo
o`3oool00P3oool300000080oooo00<0003o0?ooo`3oool01@3oool010000?l0oooo0?ooo`3oool3
0000oa40oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo03h0oooo00<0003o0?ooo`000?l00`3oool00`00
0?l0oooo0?ooo`03000000030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0203oool01000
0?l0oooo0?ooo`3oool20000oa00oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0A
0?ooo`008`3oool2000008l0oooo00<000000?ooo`3oool0?@3oool010000?l0oooo0?ooo`3oool3
0000o`<000000`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00h0oooo0P000?l?
0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0SP3oool00`000000oooo0?ooo`0m0?ooo`030000o`3oool0oooo00@000001@3oool00`00
0?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0100oooo00@0003o0?ooo`3oool0oooo0P000?l;
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`0m0?ooo`040000o`0000000000000000T0oooo00<0003o
0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0@0?ooo`030000o`3oool0oooo0080oooo00<0003o
0?ooo`3oool02P3oool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool300000180oooo00<0003o0?oo
o`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`L0003o4P3oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3o
ool0>03oool3000001H0oooo00<0003o0?ooo`3oool00P000?l40?ooo`030000o`3oool0oooo01P0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo
0?ooo`2>0?ooo`030000003oool0oooo03D0oooo0`00000J0?ooo`80003o1P3oool00`000?l0oooo
0?ooo`090?ooo`030000o`3oool0oooo00d0oooo00<000000?ooo`3oool0CP3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo1000
000D0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo00h0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00000G
0?ooo`80003o4@3oool01@000?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0403o
ool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0
oooo08h0oooo00<000000?ooo`3oool0:`3oool3000002h0oooo0`000?l60?ooo`030000o`3oool0
oooo0100oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`00
0000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00000j0?ooo`030000o`3oool0oooo
0140oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`0@0?ooo`008P3oool3000008h0
oooo00<000000?ooo`3oool09@3oool3000003`0oooo00<0003o0?ooo`3oool04`3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0oooo0100oooo000Q0?ooo`800000T03oool00`000000oooo
0?ooo`0Q0?ooo`@00000?`3oool00`000?l0oooo0?ooo`0D0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?oo
o`0N0?ooo`<00000@`3oool00`000?l0oooo0?ooo`0E0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0oooo00<00000
0?ooo`3oool06`3oool3000004D0oooo00<0003o0?ooo`3oool05P3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo00l0oooo000G0?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`3oool0S`3oool00`000000oooo0?ooo`0H0?ooo`<00000B03oool00`000?l0oooo0?ooo`0G
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool03`3oool001X0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo01D0oooo0`00001V0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool04@3oool4000006X0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000006l0oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`0?0?ooo`00603oool3000000D0oooo00<000000?ooo`3oool0T03o
ool00`000000oooo0?ooo`0;0?ooo`<00000LP3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00l0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0203oool3
000007H0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0>0?ooo`00803oool00`00
0000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0oooo1000001j0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool03P3oool00200oooo00<000000?ooo`3oool0T03oool010000000
oooo0?ooo`3oool3000007l0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0>0?oo
o`00803oool200000940oooo100000230?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool03P3oool001l0oooo0P00002@0?ooo`<00000QP3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08`0oooo0`0000020?ooo`030000003o
ool0oooo08D0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0>0?ooo`007`3oool0
0`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`260?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool03P3oool001l0oooo00<000000?ooo`3oool0Q@3oool30000
00T0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00d0oooo000O0?ooo`030000003oool0oooo0880oooo0`00000<0?ooo`030000003oool0oooo08P0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0=0?ooo`007`3oool00`000000oooo
0?ooo`1o0?ooo`<000003`3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo03h0oooo
00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0O03oool300000140oooo00<0
00000?ooo`3oool0RP3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo00d0oooo000O
0?ooo`030000003oool0oooo07P0oooo1000000D0?ooo`030000003oool0oooo08/0oooo00<00000
0?ooo`3oool0?@3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo0?ooo`1f0?oo
o`<00000603oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo03`0oooo00<000000?oo
o`3oool03@3oool001h0oooo00<000000?ooo`3oool0L`3oool3000001/0oooo00<000000?ooo`3o
ool0S@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo00d0oooo000N0?ooo`030000
003oool0oooo0700oooo0`00000N0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0
>`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool3000006h0oooo0`00000Q0?ooo`030000003o
ool0oooo08h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0<0?ooo`007P3oool0
0`000000oooo0?ooo`1Y0?ooo`@00000903oool00`000000oooo0?ooo`2?0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0303oool001h0oooo00<000000?ooo`3oool0IP3oool30000
02P0oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
00`0oooo000M0?ooo`030000003oool0oooo06@0oooo0`00000[0?ooo`030000003oool0oooo0940
oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo
0?ooo`1Q0?ooo`<00000;P3oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo03L0oooo
00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0GP3oool300000340oooo00<0
00000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo00`0oooo000M
0?ooo`030000003oool0oooo05X0oooo1000000d0?ooo`030000003oool0oooo09<0oooo00<00000
0?ooo`3oool0=P3oool00`000000oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1G0?oo
o`<00000>03oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool02`3oool001d0oooo00<000000?ooo`3oool0E03oool3000003/0oooo00<000000?ooo`3o
ool0U@3oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo00/0oooo000L0?ooo`030000
003oool0oooo0580oooo0`00000n0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
=03oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`1>0?ooo`@00000@@3o
ool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool02`3o
ool001`0oooo00<000000?ooo`3oool0B`3oool3000004D0oooo00<000000?ooo`3oool0U`3oool0
0`000000oooo0?ooo`0c0?ooo`030000003oool0oooo00/0oooo000L0?ooo`800000B@3oool30000
04P0oooo00<000000?ooo`3oool0V03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
00/0oooo000L0?ooo`030000003oool0oooo04D0oooo0`00001;0?ooo`030000003oool0oooo09T0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`120?ooo`<00000CP3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo0340oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0?`3oool400000540oooo00<0
00000?ooo`3oool0V`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo03`0oooo0`00001E0?ooo`030000003oool0oooo09/0oooo00<00000
0?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0i0?oo
o`<00000F03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool02P3oool001/0oooo00<000000?ooo`3oool0=P3oool3000005/0oooo00<000000?ooo`3o
ool0W@3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000
003oool0oooo03<0oooo0`00001N0?ooo`030000003oool0oooo09h0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`@00000H@3o
ool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02P3o
ool001/0oooo00<000000?ooo`3oool0;03oool3000006D0oooo00<000000?ooo`3oool0W`3oool0
0`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo
02X0oooo0`00001W0?ooo`030000003oool0oooo0:40oooo00<000000?ooo`3oool0;03oool00`00
0000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0W0?ooo`<00000JP3oool00`000000
oooo0?ooo`2R0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool02@3oool001X0oooo
0P00000U0?ooo`<00000K@3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo02X0oooo
00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool0803oool400000700oooo00<0
00000?ooo`3oool0Y03oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00T0oooo000J
0?ooo`030000003oool0oooo01d0oooo0`00001d0?ooo`030000003oool0oooo0:@0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0J0?oo
o`<00000M`3oool00`000000oooo0?ooo`2U0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool02@3oool001T0oooo00<000000?ooo`3oool0603oool3000007X0oooo00<000000?ooo`3o
ool0YP3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo000I0?ooo`030000
003oool0oooo01D0oooo0`00001m0?ooo`030000003oool0oooo0:L0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0A0?ooo`@00000P03o
ool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0203o
ool001T0oooo00<000000?ooo`3oool03P3oool3000008@0oooo00<000000?ooo`3oool0Z03oool0
0`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I0?ooo`030000003oool0oooo
00/0oooo0`0000270?ooo`030000003oool0oooo0:T0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`080?ooo`<00000RP3oool00`000000
oooo0?ooo`2Z0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0203oool001P0oooo
00<000000?ooo`3oool01P3oool3000008d0oooo00<000000?ooo`3oool0Z`3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000003oool0oooo0080oooo1000
002@0?ooo`030000003oool0oooo0:`0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`080?ooo`00603oool00`000000oooo00000002000009@0oooo00<000000?ooo`3oool0[@3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo000H0?ooo`800000U`3oool00`00
0000oooo0?ooo`2]0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool01`3oool000L0
oooo1@0000020?ooo`8000002@3oool2000009H0oooo00<000000?ooo`3oool0[P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo09<0oooo00<000000?ooo`3o
ool0[`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo00090?ooo`050000
003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0980
oooo00<000000?ooo`3oool0/03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`80
0000TP3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool01`3oool000T0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`000000S`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool000P0oooo0P0000040?ooo`800000403oool2000008l0oooo
00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo
000R0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00H0oooo000S0?ooo`800000S03oool00`000000oooo0?ooo`2d
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool01P3oool001<0oooo1@0000020?oo
o`8000002@3oool00`000000oooo0?ooo`290?ooo`030000003oool0oooo0;D0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool00000
0080oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`280?ooo`030000003oool0oooo
0;D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0203oool2000000030?ooo`000000oooo
08@0oooo00<000000?ooo`3oool0]`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
00H0oooo000=0?ooo`@00000103oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02P3oool2000008D0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo00H0oooo000E0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`0;0?ooo`800000Q03oool00`000000oooo0?ooo`2i0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool01P3oool001@0oooo0P0000040?ooo`800000403oool00`000000
oooo0?ooo`210?ooo`030000003oool0oooo0;X0oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`050?ooo`00;@3oool00`000000oooo0?ooo`200?ooo`030000003oool0oooo0;X0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`050?ooo`00;P3oool200000800oooo00<0
00000?ooo`3oool0^`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00D0oooo000`
0?ooo`040000003oool0oooo000007`0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00D0oooo000a0?ooo`<00000O03oool00`000000oooo0?ooo`2m
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool003<0oooo00<000000?oo
o`3oool0NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool003@0oooo0P00001j0?ooo`030000003oool0oooo0;h0oooo00<000000?ooo`3o
ool0503oool00`000000oooo0?ooo`050?ooo`00=P3oool00`000000oooo0?ooo`1g0?ooo`030000
003oool0oooo0;l0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`040?ooo`00=`3o
ool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`040?ooo`00>03oool2000000030?ooo`000000oooo07<0oooo00<00000
0?ooo`3oool0`@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo000j0?oo
o`800000M03oool00`000000oooo0?ooo`320?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool0103oool003/0oooo0P00001c0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`040?ooo`00?@3oool00`000000oooo0?ooo`1`0?ooo`030000
003oool0oooo0<<0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`040?ooo`00?P3o
ool200000700oooo00<000000?ooo`3oool0a03oool00`000000oooo0?ooo`0?0?ooo`030000003o
ool0oooo00@0oooo00100?ooo`050000003oool0oooo0?ooo`000000J`3oool00`000000oooo0?oo
o`350?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool00440oooo00@00000
0?ooo`3oool00000J`3oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool00`3oool00480oooo0P00001/0?ooo`030000003oool0oooo0<L0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00@`3oool2000006/0oooo00<000000?oo
o`3oool0a`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00150?ooo`80
0000J@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool00`3oool004L0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`390?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool004P0oooo00<000000?ooo`3oool0I@3o
ool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3o
ool004T0oooo0P0000000`3oool000000?ooo`1R0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`00B`3oool2000006<0oooo00<000000?oo
o`3oool0b`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo001<0?ooo`80
0000HP3oool00`000000oooo0?ooo`3<0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool004h0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool00P3oool004l0oooo0P00001N0?ooo`030000003o
ool0oooo0<l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`00A03oool2
000000/0oooo00@000000?ooo`3oool00000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool00P3oool004<0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0000001J0?ooo`030000003oool0oooo0=00oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`00AP3oool00`000000oooo0?ooo`0:0?ooo`800000FP3oool0
0`000000oooo0?ooo`3A0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool0
03d0oooo100000030?ooo`8000003`3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo
0=80oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`010?ooo`00A03oool00`000000
oooo0?ooo`0?0?ooo`800000E`3oool00`000000oooo0?ooo`3C0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool00@3oool004@0oooo0`00000A0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0040oooo
001I0?ooo`040000003oool0oooo00000580oooo00<000000?ooo`3oool0e@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0040oooo001J0?ooo`800000D`3oool00`000000oooo0?oo
o`3E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00@3oool005/0oooo0P00001B
0?ooo`030000003oool0oooo0=H0oooo00D000000?ooo`3oool0oooo000000030?ooo`00G@3oool2
00000500oooo00<000000?ooo`3oool0e`3oool010000000oooo0?ooo`0000030?ooo`00G`3oool0
0`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`0000000`3oool0
0600oooo0P0000000`3oool000000?ooo`1:0?ooo`030000003oool0oooo0=T0oooo00<000000?oo
o`0000000P3oool00680oooo0P00001;0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`00
00000P3oool006<0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`3J0?ooo`800000
0P3oool006@0oooo0P0000190?ooo`030000003oool0oooo0=T0oooo0`0000020?ooo`00IP3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0e@3oool4
000000D0oooo001W0?ooo`8000000P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=40oooo100000090?ooo`00J@3oool2000004@0oooo00<000000?ooo`3oool0c03oool5000000d0
oooo001Z0?ooo`800000@`3oool00`000000oooo0?ooo`380?ooo`@000004P3oool006`0oooo00<0
00000?ooo`3oool0@03oool00`000000oooo0?ooo`330?ooo`D000005P3oool006d0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`2o0?ooo`@000006`3oool006h0oooo0P00000o0?oo
o`030000003oool0oooo0;/0oooo1000000O0?ooo`00L03oool00`000000oooo0000000l0?ooo`03
0000003oool0oooo0;H0oooo1@00000S0?ooo`00L@3oool2000003`0oooo00<000000?ooo`3oool0
/P3oool4000002P0oooo001c0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3oool0[@3o
ool5000002`0oooo001d0?ooo`030000003oool0oooo03L0oooo00<000000?ooo`3oool0ZP3oool4
00000340oooo001e0?ooo`800000=`3oool00`000000oooo0?ooo`2V0?ooo`@00000=@3oool007L0
oooo00<000000?ooo`000000=03oool00`000000oooo0?ooo`2Q0?ooo`D00000>@3oool006T0oooo
0P00000=0?ooo`800000=03oool00`000000oooo0?ooo`2M0?ooo`@00000?P3oool006P0oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09P0oooo
1@0000120?ooo`00J03oool010000000oooo0?ooo`00000?0?ooo`800000<@3oool00`000000oooo
0?ooo`2D0?ooo`@00000A`3oool006P0oooo00@000000?ooo`3oool000004@3oool00`000000oooo
0?ooo`0^0?ooo`030000003oool0oooo0900oooo1000001;0?ooo`00J03oool010000000oooo0?oo
o`00000B0?ooo`030000003oool0000002d0oooo00<000000?ooo`3oool0R`3oool5000004l0oooo
001Y0?ooo`800000503oool2000002d0oooo00<000000?ooo`3oool0Q`3oool4000005@0oooo0021
0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0PP3oool5000005P0oooo00220?oo
o`800000:P3oool00`000000oooo0?ooo`1n0?ooo`@00000G@3oool008@0oooo00@000000?ooo`3o
ool000009P3oool00`000000oooo0?ooo`1j0?ooo`@00000H@3oool008D0oooo00<000000?ooo`00
00009P3oool00`000000oooo0?ooo`1e0?ooo`D00000I@3oool008H0oooo0P00000V0?ooo`030000
003oool0oooo0740oooo1000001Z0?ooo`00R03oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo06d0oooo1000001^0?ooo`00R@3oool2000000<0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`1X0?ooo`D00000LP3oool008/0oooo00@000000?ooo`3oool000007`3oool0
0`000000oooo0?ooo`1T0?ooo`@00000M`3oool008`0oooo0`00000O0?ooo`030000003oool0oooo
05l0oooo1@00001k0?ooo`00SP3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo05/0
oooo100000200?ooo`00S`3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo05L0oooo
100000240?ooo`00T03oool2000001`0oooo00<000000?ooo`3oool0DP3oool5000008P0oooo002B
0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0CP3oool4000008d0oooo002C0?oo
o`8000006@3oool00`000000oooo0?ooo`190?ooo`D00000T@3oool009D0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`150?ooo`@00000UP3oool009H0oooo0P00000F0?ooo`030000
003oool0oooo0440oooo1000002J0?ooo`00V03oool010000000oooo0?ooo`00000B0?ooo`030000
003oool0oooo03`0oooo1@00002N0?ooo`00V@3oool00`000000oooo0000000B0?ooo`030000003o
ool0oooo03P0oooo1000002S0?ooo`00S03oool2000000`0oooo0P00000A0?ooo`030000003oool0
oooo03@0oooo1@00002W0?ooo`00I@3oool2000002@0oooo00@000000?ooo`3oool000003@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0300oooo1000002/0?ooo`00IP3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo0P00000>0?ooo`030000003oool0oooo
02`0oooo1000002`0?ooo`00I`3oool00`000000oooo0?ooo`0R0?ooo`8000004@3oool00`000000
oooo0000000;0?ooo`030000003oool0oooo02L0oooo1@00002d0?ooo`00IP3oool00`000000oooo
0000000S0?ooo`030000003oool0oooo0140oooo0P00000;0?ooo`030000003oool0oooo02<0oooo
1000002i0?ooo`00I@3oool010000000oooo0?ooo`00000S0?ooo`<000004P3oool2000000X0oooo
00<000000?ooo`3oool07P3oool500000;d0oooo001T0?ooo`<0000000<0oooo000000000000>@3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01X0oooo100000320?ooo`00Y03oool2
000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool05P3oool400000<H0oooo002V0?oo
o`8000001@3oool00`000000oooo0?ooo`0A0?ooo`D00000bP3oool00:L0oooo0P0000040?ooo`03
0000003oool0oooo00d0oooo1000003?0?ooo`00Z@3oool01@000000oooo0?ooo`3oool0000000X0
oooo1@00003C0?ooo`00ZP3oool010000000oooo0?ooo`0000060?ooo`@00000f03oool00:/0oooo
0`0000020?ooo`@00000g03oool00:d0oooo0`00003P0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?ooo`00o`3ooonA0?oo
o`00o`3ooonA0?ooo`00Z03oool500000080oooo0P00003O0?ooo`00ZP3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:T0oooo0P0000040?ooo`800000g`3oool00001\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.66393 .66892 m
.67468 .64657 L
s
.68063 .63761 m
.67852 .63859 L
s
.68005 .6354 m
.68063 .63761 L
s
.67852 .63859 m
.67794 .63637 L
s
.67794 .63637 m
.68005 .6354 L
s
.66078 .64805 m
.65788 .65064 L
s
.66617 .63684 m
.66694 .63524 L
s
.66327 .63942 m
.66617 .63684 L
s
.66694 .63524 m
.66712 .63141 L
s
.65788 .65064 m
.65303 .6504 L
s
.65978 .63979 m
.66327 .63942 L
s
.66712 .63141 m
.66382 .62794 L
s
.6522 .63829 m
.65978 .63979 L
s
.65303 .6504 m
.64893 .64855 L
s
.66382 .62794 m
.65974 .62606 L
s
.64893 .64855 m
.64561 .64509 L
s
.65974 .62606 m
.65488 .62579 L
s
.6487 .63866 m
.6522 .63829 L
s
.64561 .64509 m
.64578 .64125 L
s
.64578 .64125 m
.6487 .63866 L
s
.65488 .62579 m
.65196 .62838 L
s
.63755 .63752 m
.63325 .6395 L
s
.64254 .62013 m
.64374 .62462 L
s
.63325 .6395 m
.62971 .63986 L
s
.64057 .61725 m
.64254 .62013 L
s
.62971 .63986 m
.62557 .63799 L
s
.63643 .61535 m
.64057 .61725 L
s
.62557 .63799 m
.62357 .63512 L
s
.63289 .6157 m
.63643 .61535 L
s
.62357 .63512 m
.62235 .63063 L
s
.62857 .61767 m
.63289 .6157 L
s
.62235 .63063 m
.6233 .62514 L
s
.62485 .6219 m
.62857 .61767 L
s
.6233 .62514 m
.62485 .6219 L
s
.60483 .64245 m
.60265 .64344 L
s
.60421 .6402 m
.60483 .64245 L
s
.60265 .64344 m
.60203 .64119 L
s
.60203 .64119 m
.60421 .6402 L
s
.60888 .63046 m
.61979 .60771 L
s
.6008 .61887 m
.60862 .60257 L
s
.59705 .62313 m
.6008 .61887 L
s
.59345 .62349 m
.59705 .62313 L
s
.58922 .62157 m
.59345 .62349 L
s
.58718 .61866 m
.58922 .62157 L
s
.58528 .61183 m
.58718 .61866 L
s
.57666 .62983 m
.59313 .59546 L
s
.57549 .60339 m
.57706 .6001 L
s
.5717 .60767 m
.57549 .60339 L
s
.57706 .6001 m
.578 .59452 L
s
.56727 .60966 m
.5717 .60767 L
s
.578 .59452 m
.57672 .58993 L
s
.56362 .61001 m
.56727 .60966 L
s
.57672 .58993 m
.57465 .58697 L
s
.55932 .60807 m
.56362 .61001 L
s
.57465 .58697 m
.57036 .585 L
s
.55724 .60512 m
.55932 .60807 L
s
.57036 .585 m
.56671 .58533 L
s
.55594 .60052 m
.55724 .60512 L
s
.56671 .58533 m
.56226 .58732 L
s
.55357 .60547 m
.57016 .5708 L
s
.54346 .6009 m
.55455 .57773 L
s
.54583 .59594 m
.54135 .59794 L
s
.55086 .57806 m
.55217 .5827 L
s
.54135 .59794 m
.53766 .59828 L
s
.54876 .57507 m
.55086 .57806 L
s
.53766 .59828 m
.53329 .59631 L
s
.54441 .57307 m
.54876 .57507 L
s
.53329 .59631 m
.53117 .59333 L
s
.5407 .5734 m
.54441 .57307 L
s
.53117 .59333 m
.52984 .58869 L
s
.5362 .57539 m
.5407 .5734 L
s
.52984 .58869 m
.53077 .58304 L
s
.53236 .57971 m
.5362 .57539 L
s
.53077 .58304 m
.53236 .57971 L
s
.51426 .58771 m
.51867 .58971 L
s
.51211 .58471 m
.51426 .58771 L
s
.51076 .58004 m
.51211 .58471 L
s
.51168 .57435 m
.51076 .58004 L
s
.50689 .58438 m
.51807 .56097 L
s
.4964 .58372 m
.49332 .5864 L
s
.49538 .56693 m
.50281 .57031 L
s
.50521 .56528 m
.50281 .57031 L
s
.50533 .56125 m
.50521 .56528 L
s
.49332 .5864 m
.48874 .58842 L
s
.50396 .55654 m
.50533 .56125 L
s
.48874 .58842 m
.48496 .58876 L
s
.50179 .55349 m
.50396 .55654 L
s
.48496 .58876 m
.47898 .58608 L
s
.49584 .55076 m
.50179 .55349 L
s
.47898 .58608 m
.47678 .58306 L
s
.49205 .55107 m
.49584 .55076 L
s
.47678 .58306 m
.47539 .57835 L
s
.48745 .55307 m
.49205 .55107 L
s
.47539 .57835 m
.47549 .5743 L
s
.48434 .55576 m
.48745 .55307 L
s
.47549 .5743 m
.4764 .56856 L
s
.48043 .56013 m
.48434 .55576 L
s
.4764 .56856 m
.48043 .56013 L
s
.46656 .56617 m
.47182 .53972 L
s
.45444 .56069 m
.47182 .53972 L
s
.45444 .56069 m
.45969 .53415 L
s
.44224 .55518 m
.45969 .53415 L
s
.4315 .55033 m
.44289 .52643 L
s
.43394 .54521 m
.42924 .54723 L
s
.439 .52673 m
.44045 .53155 L
s
.42924 .54723 m
.42534 .54755 L
s
.43674 .5236 m
.439 .52673 L
s
.42534 .54755 m
.4207 .54545 L
s
.43211 .52148 m
.43674 .5236 L
s
.4207 .54545 m
.41842 .54234 L
s
.42821 .52177 m
.43211 .52148 L
s
.41842 .54234 m
.41695 .53751 L
s
.42348 .52379 m
.42821 .52177 L
s
.41695 .53751 m
.41785 .53166 L
s
.41948 .52822 m
.42348 .52379 L
s
.41785 .53166 m
.41948 .52822 L
s
.40048 .53632 m
.40517 .53844 L
s
.39817 .53318 m
.40048 .53632 L
s
.39667 .52831 m
.39817 .53318 L
s
.39756 .52243 m
.39667 .52831 L
s
.39264 .53278 m
.40413 .50862 L
s
.38244 .52607 m
.38655 .51742 L
s
.37839 .53055 m
.38244 .52607 L
s
.38655 .51742 m
.38744 .5115 L
s
.37516 .5333 m
.37839 .53055 L
s
.38744 .5115 m
.38751 .50732 L
s
.37035 .53534 m
.37516 .5333 L
s
.38751 .50732 m
.38599 .5024 L
s
.36476 .53493 m
.37035 .53534 L
s
.38599 .5024 m
.38207 .49849 L
s
.35359 .52993 m
.36476 .53493 L
s
.38207 .49849 m
.37094 .49337 L
s
.35359 .52993 m
.37094 .49337 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0S@3oool00`00
0000oooo0?ooo`0>0?ooo`<00000A03oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000
oooo0?ooo`1P0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool02P3oool4000004L0
oooo00<000000?ooo`3oool0603oool002/0oooo00<000000?ooo`3oool0H@3oool00`000000oooo
0?ooo`2;0?ooo`030000003oool0oooo00L0oooo0`00001;0?ooo`030000003oool0oooo01P0oooo
000[0?ooo`030000003oool0oooo0680oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`040?ooo`<00000CP3oool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S
0?ooo`030000003oool0oooo08T0oooo00@000000?ooo`3oool0oooo0`00001B0?ooo`030000003o
ool0oooo01L0oooo000[0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0R03oool4
000005D0oooo00<000000?ooo`3oool05`3oool002/0oooo00<000000?ooo`3oool0I@3oool00`00
0000oooo0?ooo`250?ooo`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000
oooo0?ooo`1W0?ooo`030000003oool0oooo00/0oooo00<0003o0?ooo`3oool0L`3oool300000080
oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo
0000001X0?ooo`030000003oool0oooo00X0oooo0`000?m`0?ooo`<000001@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3oool00`000000oooo0?oo
o`090?ooo`040000o`3oool0oooo0?ooo`80003oJ`3oool3000000P0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1Y0?ooo`030000003o
ool0oooo00P0oooo00<0003o0?ooo`3oool00`3oool20000ofH0oooo0`00000;0?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool05`3oool00240oooo0P0000070?ooo`030000003oool0
oooo06X0oooo00<000000?ooo`3oool01P3oool00`000?l0oooo0?ooo`050?ooo`030000o`3oool0
oooo0640oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05`3oool0
0200oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0
oooo00D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1N0?ooo`<000004@3oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`030?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1D0?ooo`<00000503oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`020?ooo`030000o`3oool0
oooo00H0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1B0?ooo`<00000603oool0
0`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo
000000D0oooo00<000000?ooo`3oool0K`3oool01@000000oooo0?ooo`3oool0003o00P0oooo00<0
003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`1?0?ooo`<000006`3oool00`000000oooo0?oo
o`1F0?ooo`030000003oool0oooo01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`
0?ooo`030000003oool0003o00T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1=
0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?oo
o`030000003oool0oooo0740oooo00<000000000o`3oool01`3oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo04T0oooo1000000Q0?ooo`030000003oool0oooo05H0oooo00<000000?oo
o`3oool05P3oool002T0oooo00<000000?ooo`3oool0L@3oool00`000?l000000?ooo`070?ooo`03
0000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01`3oool60000ocX0oooo0`00000U0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool002P0oooo00<000000?ooo`000000
LP3oool00`000?l0oooo000000060?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
1P3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0003o03D0oooo0`00000X0?ooo`030000
003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0oooo0P00001b0?ooo`050000o`3o
ool0oooo0?ooo`000000103oool00`000?l0oooo0?ooo`030?ooo`80003o1`3oool00`000?l0oooo
0?ooo`050?ooo`80003o<P3oool3000002/0oooo00<000000?ooo`3oool0E`3oool00`000000oooo
0?ooo`0E0?ooo`00103oool400000200oooo00<000000?ooo`3oool0L@3oool00`000?l0oooo0?oo
o`020?ooo`050000003oool0oooo0?ooo`000?l01@3oool20000o`L0oooo00<0003o0?ooo`3oool0
1@3oool00`000?l0oooo0?ooo`0^0?ooo`<00000;P3oool00`000000oooo0?ooo`1G0?ooo`030000
003oool0oooo01D0oooo00050?ooo`030000003oool000000200oooo00<000000?ooo`3oool0LP3o
ool20000o`<0oooo00<000000?ooo`000?l01@3oool00`000?l0oooo0000o`070?ooo`030000o`3o
ool0oooo00D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0T0?ooo`<00000<@3o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`030000003oool0
00000240oooo00<000000?ooo`3oool0M03oool50000o`T0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00@0oooo0P000?lS0?ooo`<00000=03oool0
0`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00040?ooo`@00000803oool00`00
0000oooo0?ooo`1i0?ooo`030000003oool0oooo00L0oooo0P000?l30?ooo`030000o`3oool0oooo
00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0000o`040?ooo`030000o`3oool0oooo
01T0oooo0`00000g0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool002P0
oooo00<000000?ooo`3oool0NP3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo00<0
oooo00<0003o0?ooo`3oool0103oool20000o`@0oooo0P000?lH0?ooo`<00000>P3oool00`000000
oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000W0?ooo`030000003oool0oooo07`0oooo
00<000000?ooo`3oool02`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00<0oooo
00<0003o0?ooo`000?l00`3oool00`000?l0oooo0000o`0E0?ooo`<00000?@3oool00`000000oooo
0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`030000003oool0oooo07d0oooo00<0
00000?ooo`3oool02`3oool50000o`D0oooo00@0003o0?ooo`3oool0003o0P3oool00`000?l0oooo
0000o`0C0?ooo`<00000@03oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000W0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool03P3oool00`000?l0oooo0?oo
o`020?ooo`070000o`3oool0oooo0?ooo`000?l0oooo0000o`020?ooo`030000o`3oool0oooo00L0
oooo00<0003o0?ooo`3oool0103oool3000004<0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0180oooo
00L0003o0?ooo`3oool0oooo0000o`3oool0003o0080oooo00<0003o0?ooo`3oool0103oool30000
o`040?ooo`000?l0oooo0?ooo`<00000AP3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0
oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0@0?ooo`070000o`3oool0oooo
0?ooo`000?l0oooo0000o`030?ooo`030000o`3oool0oooo0080oooo0P000?l40?ooo`0300000000
0?l0000004T0oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool0
0`000000oooo0?ooo`210?ooo`030000003oool0oooo01<0oooo0P000?l40?ooo`050000o`3oool0
oooo0?ooo`000?l00`3oool300000080oooo00<0003o0?ooo`3oool0A`3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`030000003oool0oooo08<0oooo00<00000
0?ooo`3oool04P3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo0080oooo00@0003o
00000000000000001@3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo04<0oooo00<0
00000?ooo`3oool0E`3oool00`000000oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`24
0?ooo`030000003oool0oooo01H0oooo00D0003o0?ooo`00000000000000o`090?ooo`030000o`3o
ool0oooo0080oooo00<0003o0?ooo`3oool0@`3oool00`000000oooo0?ooo`1G0?ooo`030000003o
ool0oooo01@0oooo000V0?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3oool0503oool0
0`000000003o000000020?ooo`030000o`3oool0oooo00L0oooo00D0003o0?ooo`3oool0oooo0000
o`160?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool04`3oool002H0oooo00<00000
0?ooo`3oool0QP3oool00`000000oooo0?ooo`0@0?ooo`<00000103oool00`000?l0oooo0?ooo`05
0?ooo`030000o`3oool0003o00@0oooo00<0003o0?ooo`3oool0A03oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo01<0oooo000V0?ooo`030000003oool0oooo08L0oooo00<000000?oo
o`3oool0303oool3000000L0oooo00<0003o0?ooo`3oool01P3oool20000o`<0oooo00<0003o0?oo
o`3oool04P3oool00`000?l0oooo0?ooo`0`0?ooo`030000003oool0oooo05P0oooo00<000000?oo
o`3oool04`3oool002H0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`080?ooo`<0
00002P3oool00`000?l0oooo0?ooo`0;0?ooo`030000o`3oool0oooo00L0oooo0`000?l80?ooo`03
0000o`3oool0oooo0300oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo00@0oooo0`00000=0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01`3oool01@000?l0oooo0?ooo`3oool0003o00H0
oooo00<0003o0?ooo`3oool0<@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0
oooo000U0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool00`00000@0?ooo`030000
o`3oool0oooo00X0oooo00<0003o0?ooo`3oool01@3oool20000o`D0oooo00<0003o0?ooo`000?l0
0`3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002D0oooo00<000000?ooo`3oool0S03oool2000001<0oooo00<0003o0?ooo`3oool02@3o
ool20000o`L0oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?ooo`3oool0003o03@0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3oool2000008d0oooo00<0
00000?ooo`3oool04`3oool00`000?l0oooo0?ooo`040?ooo`070000o`3oool0oooo0?ooo`000?l0
oooo0000o`060?ooo`030000o`3oool0oooo00D0oooo00@0003o0?ooo`3oool0oooo10000?l`0?oo
o`800000F`3oool00`000000oooo0?ooo`0B0?ooo`009@3oool00`000000oooo0?ooo`2<0?ooo`03
0000003oool0oooo01<0oooo0P000?l40?ooo`030000o`3oool0oooo00D0oooo00<0003o0?ooo`3o
ool00P3oool00`000?l0oooo0?ooo`050?ooo`040000o`3oool0oooo0?ooo`80003o0`3oool00`00
0?l0oooo0?ooo`0Z0?ooo`<000000P3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool05@3oool40000o`T0
oooo00D0003o0?ooo`3oool0oooo0000o`070?ooo`050000o`3oool0oooo0?ooo`000?l01@3oool0
0`000?l0oooo0?ooo`0U0?ooo`@000001P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0
oooo0180oooo000U0?ooo`030000003oool0oooo08`0oooo00<000000?ooo`3oool09`3oool00`00
0?l0oooo0?ooo`030?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`0R
0?ooo`<000002P3oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo0180oooo000T0?oo
o`030000003oool0oooo08d0oooo00<000000?ooo`3oool0:03oool010000?l0oooo0?ooo`3oool2
0000o`<0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0
oooo01T0oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool04P3oool0
02@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0Y0?ooo`@0003o0`3oool00`00
0?l0oooo0?ooo`050?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool05P3oool30000
0180oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000
oooo0?ooo`2=0?ooo`030000003oool0oooo02`0oooo00D0003o0?ooo`3oool0oooo0000o`070?oo
o`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0503oool3000001H0oooo00<000000?oo
o`3oool0E03oool00`000000oooo0?ooo`0B0?ooo`00903oool00`000000oooo0?ooo`2=0?ooo`03
0000003oool0oooo02l0oooo0P000?l60?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3o
ool0103oool00`000?l0oooo0?ooo`090?ooo`@000006P3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo0180oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
;`3oool00`000?l0oooo0000o`040?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0
103oool00`000?l0oooo0?ooo`070?ooo`<000007P3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0140oooo000T0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0<@3o
ool00`000?l0oooo0?ooo`030000o`D0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?oo
o`020?ooo`030000o`3oool00000008000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003o
ool0oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0<P3oool2
0000o`L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`020?ooo`<000009P3oool0
0`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?ooo`800000S`3oool00`00
0000oooo0?ooo`0k0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`0000000P0000000`00
0?l0oooo0?ooo`0W0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool04@3oool002<0
oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0j0?ooo`030000o`3oool0003o00<0
oooo100000020?ooo`030000o`3oool0oooo0080oooo1P000?lQ0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0k0?ooo`030000o`3oool0003o00<0000000<0oooo0000o`3oool00`3oool01@000?l0oooo
0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool0803oool00`000000oooo0?ooo`1?0?ooo`03
0000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo00<000000?ooo`3oool0
>P3oool01@000?l00000000000000000003o0080oooo00<0003o0?ooo`3oool00P3oool00`000?l0
oooo0?ooo`020?ooo`030000o`3oool0oooo00<0oooo00<0003o0?ooo`3oool0803oool00`000000
oooo0?ooo`1?0?ooo`030000003oool0oooo0140oooo000S0?ooo`030000003oool0oooo08d0oooo
00<000000?ooo`3oool0>03oool3000000@0oooo0`000?l40?ooo`050000o`3oool0oooo0?ooo`00
0?l01`3oool01@000?l0oooo0?ooo`3oool0003o01h0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03D0
oooo0`0000000`3oool0003o0?ooo`0:0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3o
ool0203oool00`000?l0oooo0000o`020000oa`0oooo00<000000?ooo`3oool0CP3oool00`000000
oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0340oooo
100000040?ooo`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo
0?ooo`0=0?ooo`030000o`3oool0oooo01X0oooo00<000000?ooo`3oool0C@3oool00`000000oooo
0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`00
000I0?ooo`030000o`3oool0oooo00h0oooo00<0003o0?ooo`3oool06P3oool00`000000oooo0?oo
o`1<0?ooo`030000003oool0oooo0100oooo000R0?ooo`030000003oool0oooo08h0oooo00<00000
0?ooo`3oool0:`3oool3000001`0oooo00<0003o0?ooo`3oool03P3oool01@000?l0oooo0?ooo`3o
ool0003o01P0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02P0oooo0`00000P0?ooo`030000o`3oool0
oooo0080oooo00@0003o0?ooo`3oool0oooo0`000?l30?ooo`030000o`3oool0oooo0080oooo0P00
0?lH0?ooo`030000003oool0oooo04/0oooo00<000000?ooo`3oool0403oool00280oooo0`00002>
0?ooo`030000003oool0oooo02D0oooo0`00000J0?ooo`80003o203oool40000o`<0oooo00@0003o
0?ooo`3oool0oooo0`000?lP0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403o
ool00240oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000N0?ooo`030000o`3oool0
oooo00d0oooo00<0003o0?ooo`3oool09@3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo00l0oooo000Q0?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool07P3oool30000
0380oooo00<0003o0?ooo`3oool01`3oool00`000?l0oooo0?ooo`0L0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool03`3oool001P0oooo0P0000070?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool06`3oool3000003H0oooo00D0003o0?ooo`3oool0oooo0000o`040?oo
o`030000o`3oool0oooo01`0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0?0?oo
o`005`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo08l0oooo00<000000?oo
o`3oool0603oool3000003X0oooo0`000?l40?ooo`030000o`3oool0oooo01h0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool3000004@0oooo00<0003o0?ooo`3o
ool07`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00l0oooo000H0?ooo`800000
1`3oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0140oooo100000160?ooo`030000
o`3oool0oooo0240oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0?0?ooo`00603o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool03P3o
ool3000004X0oooo00<0003o0?ooo`3oool08P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo00l0oooo000H0?ooo`<000001@3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo00/0oooo0`00001<0?ooo`030000o`3oool0oooo02<0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`0?0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo
00P0oooo0`00001?0?ooo`030000o`3oool0oooo02@0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00@0
oooo1000001A0?ooo`030000o`3oool0oooo02H0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0>0?ooo`00803oool00`000000oooo0?ooo`2@0?ooo`040000003oool0oooo0?ooo`<0
0000E@3oool00`000?l0oooo0?ooo`0W0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3o
ool03P3oool00200oooo0P00002A0?ooo`@00000P`3oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00h0oooo000O0?ooo`800000T03oool3000008H0oooo00<000000?ooo`3oool0@P3o
ool00`000000oooo0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool0
0`000000oooo0?ooo`250?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool03P3oool0
01l0oooo00<000000?ooo`3oool0R03oool4000000D0oooo00<000000?ooo`3oool0QP3oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo00h0oooo000O0?ooo`030000003oool0oooo08D0
oooo0`0000090?ooo`030000003oool0oooo08L0oooo00<000000?ooo`3oool0@03oool00`000000
oooo0?ooo`0=0?ooo`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo
0?ooo`280?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<0
00000?ooo`3oool0O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?oo
o`0n0?ooo`030000003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A
0?ooo`030000003oool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=
0?ooo`007`3oool00`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?oo
o`030000003oool0oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3o
ool0MP3oool3000001P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`03
0000003oool0oooo00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000
003oool0oooo08d0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3o
ool00`000000oooo0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003o
ool0oooo03/0oooo00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool0
01h0oooo00<000000?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0
oooo0`00000X0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0<0?ooo`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo
0?ooo`2A0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<0
00000?ooo`3oool0H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a
0?ooo`030000003oool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<
0?ooo`007@3oool00`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?oo
o`030000003oool0oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3o
ool0E`3oool3000003P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`03
0000003oool0oooo00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000
003oool0oooo09D0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703o
ool00`000000oooo0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003o
ool0oooo03@0oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool4
00000440oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0
oooo00/0oooo000L0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo
09L0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0
oooo0`0000180?ooo`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000
oooo0?ooo`0;0?ooo`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo
0?ooo`2I0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<0
00000?ooo`3oool0@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?oo
o`0a0?ooo`030000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A
0?ooo`030000003oool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:
0?ooo`006`3oool00`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3o
ool0>@3oool3000005P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`03
0000003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000
003oool0oooo09d0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3o
ool00`000000oooo0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool4
00000640oooo00<000000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0
oooo00X0oooo000K0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo
09l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000
oooo0?ooo`0Z0?ooo`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo
00<000000?ooo`3oool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo
000J0?ooo`8000009@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?oo
o`0Z0?ooo`030000003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`
0?ooo`030000003oool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`09
0?ooo`006P3oool00`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3o
ool06P3oool3000007L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000
003oool0oooo0:H0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3o
ool00`000000oooo0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool4
00000800oooo00<000000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0
oooo00P0oooo000I0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo
0:P0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000
oooo0?ooo`0;0?ooo`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0
oooo00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo
00<000000?ooo`3oool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo
000H0?ooo`030000003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`02
0?ooo`@00000T03oool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<00000
0?ooo`3oool0203oool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo
0:d0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0
oooo00<000000?ooo`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0
oooo00070?ooo`D000000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000
003oool0oooo0:l0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3o
ool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2B0?ooo`030000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0
2P3oool200000980oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo00L0oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00
002?0?ooo`030000003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`070?ooo`008P3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?oo
o`3oool0]03oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D0
00000P3oool2000000T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000
oooo0?ooo`2e0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool0
00000?ooo`240?ooo`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000
oooo0?ooo`060?ooo`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`03
0000003oool0oooo00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo
00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?oo
o`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P000020
0?ooo`030000003oool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`05
0?ooo`00<03oool010000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?oo
o`3oool0_@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`03
0000003oool0oooo07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3o
ool00`000000oooo0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103o
ool003L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?oo
o`030000003oool0oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?oo
o`00>P3oool2000007@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03o
ool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103o
ool003h0oooo0P00001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<00000
0?ooo`3oool0a@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?oo
o`040000003oool0oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`03
0000003oool0oooo0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00
A@3oool2000006T0oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00<0oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0
oooo06D0oooo00<000000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00<0oooo00190?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`03
0000003oool0oooo0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00
C03oool200000680oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0080oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool0
0`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool0
04@0oooo0P00000;0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo
000000/0oooo00<000000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool20000
05X0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
0080oooo000m0?ooo`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`3B0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo
00<000000?ooo`3oool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?oo
o`1D0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`010?ooo`00F@3oool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<00000
0?ooo`3oool0e@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?oo
o`800000DP3oool00`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool0
05d0oooo0P00001@0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool0
05l0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool00000
00<0oooo001P0?ooo`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`03
0000003oool000000080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000
003oool000000080oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3o
ool200000080oooo001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool0
06H0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
0=D0oooo100000050?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`3A0?ooo`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo
1@00000=0?ooo`00JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`80
0000?`3oool00`000000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000
?03oool00`000000oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003o
ool0oooo0;80oooo1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0
oooo0:d0oooo1@00000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo
0:X0oooo1000000a0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0
oooo001g0?ooo`030000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo
001Y0?ooo`8000003@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X
0?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?oo
o`2H0?ooo`D00000@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<0
00000?ooo`3oool0U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@00000
0?ooo`3oool000004P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00
001?0?ooo`00J@3oool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D
0?ooo`00P@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?oo
o`00PP3oool2000002X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000
003oool0oooo000002H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000
003oool0000002H0oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3o
ool00`000000oooo0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo0000
01l0oooo00<000000?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000
oooo0?ooo`1O0?ooo`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`1K0?ooo`@00000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?oo
o`1G0?ooo`@00000Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@000028
0?ooo`00TP3oool00`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?oo
o`00T`3oool2000001T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3o
ool00`000000oooo0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3o
ool00`000000oooo0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool0
0`000000oooo0?ooo`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`00
0000oooo0?ooo`0d0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo0000
00d0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000
oooo0?ooo`0/0?ooo`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo
00<000000?ooo`0000002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<0
00000?ooo`0000008`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?oo
o`0S0?ooo`@00000^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00
000:0?ooo`030000003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000
000003T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool0
0:@0oooo0P0000000`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?oo
o`00YP3oool2000000D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000
103oool00`000000oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo
0000000:0?ooo`D00000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo
002[0?ooo`<000000P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`030000003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.0855 
%%ImageSize: 400 434.198 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0567234 1.16608 1.1601e-016 1.16608 [
[.07825 .23514 -17.8259 -9 ]
[.07825 .23514 .17408 0 ]
[.21247 .17844 -11.3335 -9 ]
[.21247 .17844 .66648 0 ]
[.3545 .11847 -5.39155 -9 ]
[.3545 .11847 .60845 0 ]
[.50502 .05496 -5.11634 -9 ]
[.50502 .05496 .88366 0 ]
[.66483 -0.01242 -9.68227 -9 ]
[.66483 -0.01242 2.31773 0 ]
[.30907 .06148 -8.98592 -12.75 ]
[.30907 .06148 1.01408 0 ]
[-0.00228 .81813 -10.4262 0 ]
[-0.00228 .81813 7.57376 9 ]
[.11551 .90072 -6.72109 0 ]
[.11551 .90072 5.27891 9 ]
[.22056 .97437 -3.26269 0 ]
[.22056 .97437 2.73731 9 ]
[.31482 1.04044 -3.17834 0 ]
[.31482 1.04044 2.82166 9 ]
[.39987 1.10006 -6.20973 0 ]
[.39987 1.10006 5.79027 9 ]
[.2142 1.04697 -5.43782 0 ]
[.2142 1.04697 4.56218 12.75 ]
[.07502 .2512 -18 -2.6079 ]
[.07502 .2512 0 6.3921 ]
[.0557 .37211 -12 -2.71522 ]
[.0557 .37211 0 6.28478 ]
[.03462 .5041 -6 -2.83339 ]
[.03462 .5041 0 6.16661 ]
[.01151 .64877 -6 -2.96413 ]
[.01151 .64877 0 6.03587 ]
[-0.01393 .80804 -12 -3.10957 ]
[-0.01393 .80804 0 5.89043 ]
[-0.03373 .52941 -10 -4.01397 ]
[-0.03373 .52941 0 8.73603 ]
[ 0 0 0 0 ]
[ 1 1.0855 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
.08846 .24555 m
.09517 .24273 L
s
[(-10)] .07502 .2512 1 -0.42047 Mshowa
.06925 .36674 m
.07603 .36405 L
s
[(-5)] .0557 .37211 1 -0.39662 Mshowa
.04829 .49904 m
.05512 .49651 L
s
[(0)] .03462 .5041 1 -0.37036 Mshowa
.0253 .64406 m
.0322 .64171 L
s
[(5)] .01151 .64877 1 -0.3413 Mshowa
0 .80374 m
.00696 .80159 L
s
[(10)] -0.01393 .80804 1 -0.30899 Mshowa
.125 Mabswid
.08475 .26897 m
.08878 .26729 L
s
.08097 .29278 m
.08502 .29112 L
s
.07713 .31701 m
.08118 .31536 L
s
.07323 .34166 m
.07728 .34003 L
s
.06521 .39226 m
.06928 .39067 L
s
.06109 .41824 m
.06517 .41666 L
s
.0569 .44469 m
.06099 .44313 L
s
.05263 .47162 m
.05672 .47008 L
s
.04386 .52697 m
.04797 .52547 L
s
.03935 .55542 m
.04347 .55395 L
s
.03476 .58441 m
.03888 .58296 L
s
.03008 .61396 m
.03421 .61252 L
s
.02044 .67476 m
.02459 .67337 L
s
.01548 .70606 m
.01963 .70469 L
s
.01042 .73797 m
.01458 .73663 L
s
.00526 .77053 m
.00943 .76921 L
s
gsave
-0.03373 .52941 -71 -8.01397 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
1.000 setlinewidth
grestore
.25 Mabswid
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
.41799 .58158 m
.08846 .24555 L
s
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.41799 .58158 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.40037 1.0855 L
s
.40037 1.0855 m
.41799 .58158 L
s
0 0 m
1 0 L
1 1.0855 L
0 1.0855 L
closepath
clip
newpath
0 0 1 r
1 Mabswid
.65387 .65445 m
.65185 .65517 L
s
.65373 .65222 m
.65387 .65445 L
s
.65171 .65294 m
.65373 .65222 L
s
.65185 .65517 m
.65171 .65294 L
s
.63399 .68329 m
.64715 .66257 L
s
.64225 .6506 m
.64305 .64686 L
s
.6413 .65208 m
.64225 .6506 L
s
.63833 .65429 m
.6413 .65208 L
s
.6347 .66247 m
.63172 .66469 L
s
.64305 .64686 m
.64073 .64309 L
s
.6352 .65426 m
.63833 .65429 L
s
.63172 .66469 m
.62749 .66392 L
s
.62878 .65194 m
.6352 .65426 L
s
.64073 .64309 m
.63745 .64079 L
s
.62749 .66392 m
.62419 .66165 L
s
.63745 .64079 m
.63322 .63998 L
s
.62419 .66165 m
.62184 .65788 L
s
.62563 .65191 m
.62878 .65194 L
s
.63322 .63998 m
.63023 .64219 L
s
.62263 .65413 m
.62563 .65191 L
s
.62184 .65788 m
.62263 .65413 L
s
.62331 .63303 m
.62361 .63757 L
s
.616 .64954 m
.61187 .651 L
s
.62205 .62998 m
.62331 .63303 L
s
.61187 .651 m
.60869 .65097 L
s
.61872 .62764 m
.62205 .62998 L
s
.60869 .65097 m
.60534 .64866 L
s
.61554 .62758 m
.61872 .62764 L
s
.60534 .64866 m
.60406 .64562 L
s
.61139 .62903 m
.61554 .62758 L
s
.60406 .64562 m
.60373 .64106 L
s
.6074 .63276 m
.61139 .62903 L
s
.60373 .64106 m
.60549 .63577 L
s
.60549 .63577 m
.6074 .63276 L
s
.59184 .63937 m
.60531 .61823 L
s
.58624 .65072 m
.58414 .65145 L
s
.58607 .64843 m
.58624 .65072 L
s
.58397 .64917 m
.58607 .64843 L
s
.58414 .65145 m
.58397 .64917 L
s
.58662 .62704 m
.59628 .61189 L
s
.58259 .63081 m
.58662 .62704 L
s
.57934 .63075 m
.58259 .63081 L
s
.5759 .62838 m
.57934 .63075 L
s
.57458 .62528 m
.5759 .62838 L
s
.57404 .61833 m
.57458 .62528 L
s
.56335 .6351 m
.58375 .6031 L
s
.56871 .60582 m
.57048 .60042 L
s
.56676 .60888 m
.56871 .60582 L
s
.56267 .61266 m
.56676 .60888 L
s
.57048 .60042 m
.57011 .59574 L
s
.55839 .61412 m
.56267 .61266 L
s
.57011 .59574 m
.56877 .59259 L
s
.55508 .61404 m
.55839 .61412 L
s
.56877 .59259 m
.56529 .59014 L
s
.55157 .61163 m
.55508 .61404 L
s
.56529 .59014 m
.56198 .59004 L
s
.55021 .60848 m
.55157 .61163 L
s
.56198 .59004 m
.55768 .59148 L
s
.54983 .60378 m
.55021 .60848 L
s
.54688 .6084 m
.5675 .57612 L
s
.53863 .60271 m
.55243 .58111 L
s
.54909 .581 m
.54947 .58574 L
s
.54159 .59808 m
.53725 .59954 L
s
.54771 .57781 m
.54909 .581 L
s
.53725 .59954 m
.53389 .59945 L
s
.54417 .57532 m
.54771 .57781 L
s
.53389 .59945 m
.53032 .59699 L
s
.54081 .5752 m
.54417 .57532 L
s
.53032 .59699 m
.52892 .59379 L
s
.53645 .57664 m
.54081 .5752 L
s
.52892 .59379 m
.52852 .58904 L
s
.53228 .58046 m
.53645 .57664 L
s
.52852 .58904 m
.5303 .58356 L
s
.5303 .58356 m
.53228 .58046 L
s
.51473 .58625 m
.51834 .58874 L
s
.51331 .58302 m
.51473 .58625 L
s
.51289 .57823 m
.51331 .58302 L
s
.51467 .57271 m
.51289 .57823 L
s
.50868 .58208 m
.52266 .56022 L
s
.5104 .56296 m
.50739 .56766 L
s
.51119 .55898 m
.5104 .56296 L
s
.50129 .56342 m
.50739 .56766 L
s
.51076 .55414 m
.51119 .55898 L
s
.49937 .58019 m
.49614 .58248 L
s
.49614 .58248 m
.49168 .58394 L
s
.50933 .55087 m
.51076 .55414 L
s
.49168 .58394 m
.48822 .58384 L
s
.50445 .54744 m
.50933 .55087 L
s
.48822 .58384 m
.48328 .58047 L
s
.50099 .54729 m
.50445 .54744 L
s
.48328 .58047 m
.48182 .57721 L
s
.49651 .54872 m
.50099 .54729 L
s
.48182 .57721 m
.48136 .57236 L
s
.49326 .55101 m
.49651 .54872 L
s
.489 .55488 m
.49326 .55101 L
s
.48136 .57236 m
.48215 .56836 L
s
.48215 .56836 m
.48394 .56277 L
s
.48394 .56277 m
.489 .55488 L
s
.47547 .55921 m
.48471 .53358 L
s
.46546 .55231 m
.48471 .53358 L
s
.46546 .55231 m
.47472 .52657 L
s
.45536 .54536 m
.47472 .52657 L
s
.44646 .53923 m
.46084 .51683 L
s
.45728 .51665 m
.45776 .52163 L
s
.44954 .53443 m
.44493 .53587 L
s
.45576 .51327 m
.45728 .51665 L
s
.44493 .53587 m
.44134 .53571 L
s
.45193 .51058 m
.45576 .51327 L
s
.44134 .53571 m
.43749 .53305 L
s
.44834 .51039 m
.45193 .51058 L
s
.43749 .53305 m
.43595 .52967 L
s
.44371 .51181 m
.44834 .51039 L
s
.43595 .52967 m
.43544 .52468 L
s
.43933 .51574 m
.44371 .51181 L
s
.43544 .52468 m
.43726 .51896 L
s
.43726 .51896 m
.43933 .51574 L
s
.42067 .52146 m
.42457 .52415 L
s
.4191 .51805 m
.42067 .52146 L
s
.41857 .51301 m
.4191 .51805 L
s
.42039 .50724 m
.41857 .51301 L
s
.41414 .51697 m
.42873 .49429 L
s
.41121 .50087 m
.41304 .49508 L
s
.40598 .509 m
.41121 .50087 L
s
.40152 .51297 m
.40598 .509 L
s
.41304 .49508 m
.41382 .49091 L
s
.41382 .49091 m
.41328 .48581 L
s
.3981 .51532 m
.40152 .51297 L
s
.39335 .51676 m
.3981 .51532 L
s
.41328 .48581 m
.41037 .48141 L
s
.3883 .51567 m
.39335 .51676 L
s
.41037 .48141 m
.40109 .4749 L
s
.37894 .50928 m
.3883 .51567 L
s
.37894 .50928 m
.40109 .4749 L
s
0 g
.25 Mabswid
.67245 0 m
.92713 .41497 L
s
.92713 .41497 m
1 .94814 L
s
1 .94814 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.08846 .24555 m
0 .80374 L
s
0 .80374 m
.70644 .58546 L
s
.70644 .58546 m
.67245 0 L
s
.67245 0 m
.08846 .24555 L
s
.08846 .24555 m
.67245 0 L
s
.08846 .24555 m
.09356 .25076 L
s
[(-10)] .07825 .23514 .98066 1 Mshowa
.22216 .18933 m
.227 .19478 L
s
[(-5)] .21247 .17844 .88892 1 Mshowa
.36358 .12987 m
.36813 .13557 L
s
[(0)] .3545 .11847 .79718 1 Mshowa
.51343 .06687 m
.51763 .07282 L
s
[(5)] .50502 .05496 .70545 1 Mshowa
.67245 0 m
.67627 .00621 L
s
[(10)] .66483 -0.01242 .61371 1 Mshowa
.125 Mabswid
.11461 .23456 m
.11764 .23771 L
s
.14105 .22344 m
.14405 .22662 L
s
.16779 .2122 m
.17076 .21541 L
s
.19482 .20083 m
.19776 .20407 L
s
.2498 .17771 m
.25268 .18101 L
s
.27776 .16595 m
.2806 .16928 L
s
.30604 .15406 m
.30885 .15742 L
s
.33465 .14204 m
.33741 .14542 L
s
.39286 .11756 m
.39554 .12101 L
s
.42247 .10511 m
.42512 .10859 L
s
.45243 .09251 m
.45504 .09602 L
s
.48275 .07977 m
.48531 .08331 L
s
.54447 .05381 m
.54695 .05742 L
s
.57589 .0406 m
.57832 .04424 L
s
.60769 .02723 m
.61007 .0309 L
s
.63987 .0137 m
.64221 .0174 L
s
gsave
.30907 .06148 -69.9859 -16.75 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
1.000 setlinewidth
grestore
.25 Mabswid
0 .80374 m
.40037 1.0855 L
s
0 .80374 m
.00114 .79654 L
s
[(-10)] -0.00228 .81813 .15847 -1 Mshowa
.11725 .88625 m
.11812 .87902 L
s
[(-5)] .11551 .90072 .12018 -1 Mshowa
.22183 .95985 m
.22246 .95259 L
s
[(0)] .22056 .97437 .08756 -1 Mshowa
.31568 1.02589 m
.31611 1.01862 L
s
[(5)] .31482 1.04044 .05945 -1 Mshowa
.40037 1.0855 m
.40063 1.07821 L
s
[(10)] .39987 1.10006 .03495 -1 Mshowa
.125 Mabswid
.02457 .82103 m
.02522 .81671 L
s
.04857 .83792 m
.04918 .83359 L
s
.072 .85441 m
.07258 .85007 L
s
.09489 .87051 m
.09544 .86618 L
s
.13911 .90164 m
.13961 .89729 L
s
.16049 .91668 m
.16095 .91233 L
s
.18139 .93139 m
.18182 .92703 L
s
.20183 .94577 m
.20224 .94142 L
s
.2414 .97362 m
.24176 .96926 L
s
.26056 .9871 m
.26089 .98274 L
s
.27932 1.0003 m
.27963 .99594 L
s
.29769 1.01323 m
.29797 1.00887 L
s
.33331 1.0383 m
.33354 1.03393 L
s
.35058 1.05045 m
.35079 1.04609 L
s
.36751 1.06237 m
.3677 1.058 L
s
.3841 1.07404 m
.38428 1.06968 L
s
gsave
.2142 1.04697 -66.4378 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.75 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{400, 434.188},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006@0001/R000`400?l00000o`00003oo`3ooonA
0?ooo`00o`3oool80?ooo`D000000P3oool200000800oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`X0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo07d0oooo003o0?ooo`T0oooo0P0000040?ooo`80
0000P03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0oooo4`3oool2000007`0oooo003o0?oo
oa40oooo0P0000000`3oool000000000001k0?ooo`00o`3oool?0?ooo`8000000`3oool2000007/0
oooo003o0?ooo``0oooo0`0000050?ooo`030000003oool0000007X0oooo003o0?ooo`X0oooo0P00
00080?ooo`030000003oool0000007X0oooo003o0?ooo`L0oooo0`00000:0?ooo`040000003oool0
oooo000007T0oooo003o0?ooo`D0oooo0P0000000`3oool000000?ooo`0:0?ooo`050000003oool0
oooo0?ooo`000000N03oool00?l0oooo0`3oool2000000l0oooo00D000000?ooo`3oool0oooo0000
001h0?ooo`00o`3oool300000140oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1e
0?ooo`00o@3oool2000001@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1d0?oo
o`00nP3oool3000001L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1d0?ooo`00
n03oool4000001P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1c0?ooo`00d@3o
ool2000002<0oooo0P00000L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0L`3o
ool00=00oooo00@000000?ooo`3oool00000803oool2000001h0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`1b0?ooo`00d`3oool00`000000oooo0?ooo`0K0?ooo`<00000803oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0740oooo00240?ooo`80000000<0oooo0000
00000000B03oool2000001`0oooo0P00000S0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0L@3oool008D0oooo00<000000?ooo`000000B@3oool00`000000oooo0?ooo`0H0?ooo`<0
000000<0oooo0000003oool08P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0700
oooo00260?ooo`030000003oool0oooo04P0oooo0`00000F0?ooo`800000:03oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo0700oooo00240?ooo`80000000<0oooo000000000000G`3o
ool2000002X0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1_0?ooo`00i@3oool3
000002`0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h`3oool20000
02l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1^0?ooo`00h@3oool200000003
0?ooo`000000oooo02h0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00
gP3oool3000003<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1]0?ooo`00g03o
ool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1/0?ooo`00f@3oool3
000003P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e`3oool20000
03/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1[0?ooo`00e@3oool200000003
0?ooo`000000oooo03X0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1Z0?ooo`00
dP3oool3000000@0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo06T0oooo003@0?ooo`800000@`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo06T0oooo003>0?ooo`800000A@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo06P0oooo003;0?ooo`<00000A`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
06P0oooo00390?ooo`8000000P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool0I`3oool00<H0oooo0`00001<0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0IP3oool00<@0oooo0P00001?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0IP3oool00<40oooo0`00001A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0I@3oool00;l0oooo0`00001C0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool0I@3oool009T0oooo0P00000R0?ooo`8000000`3oool00`000000oooo0?ooo`1@0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0I03oool009P0oooo00@000000?ooo`3oool0
00007`3oool2000005P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S0?ooo`00
V03oool010000000oooo0?ooo`00000L0?ooo`<00000FP3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo06<0oooo002H0?ooo`040000003oool0oooo000001T0oooo0`00001M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool0HP3oool009P0oooo00@000000?ooo`3oool0
0000603oool3000005h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1Q0?ooo`00
V@3oool2000001H0oooo0`00001Q0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
H@3oool00:l0oooo0P00001T0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03o
ool00:`0oooo0`00001V0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0H03oool0
0:X0oooo0P00001Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0G`3oool00:P0
oooo0P0000000`3oool000000?ooo`1X0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0GP3oool00:D0oooo0`00001^0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
GP3oool00:<0oooo0P00001a0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0G@3o
ool009l0oooo00@000000?ooo`0000000000L`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo05d0oooo002N0?ooo`<00000M@3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo05`0oooo002L0?ooo`8000000P3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
01T0oooo00<000000?ooo`3oool0F`3oool009T0oooo0`0000050?ooo`030000003oool0oooo0780
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1K0?ooo`00U`3oool2000007d0oooo
00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00U@3oool2000007l0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`1J0?ooo`00TP3oool3000000030?ooo`000000
oooo07h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1I0?ooo`00T03oool20000
08@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00SP3oool2000008H0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1H0?ooo`00RP3oool4000008P0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1G0?ooo`00R@3oool2000008/0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1F0?ooo`00I03oool200000240oooo0P000002
0?ooo`030000003oool0oooo08P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`1F
0?ooo`00H`3oool010000000oooo0?ooo`00000M0?ooo`<00000S`3oool00`000000oooo0?ooo`0O
0?ooo`030000003oool0oooo05D0oooo001V0?ooo`030000003oool0oooo01T0oooo0P00002B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool0E@3oool005d0oooo100000030?ooo`80
00006@3oool3000009@0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1D0?ooo`00
I03oool00`000000oooo0?ooo`0F0?ooo`80000000<0oooo0000003oool0U03oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo05<0oooo001T0?ooo`<00000503oool2000009X0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1C0?ooo`00N03oool3000009`0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M@3oool3000009l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`1B0?ooo`00M03oool200000:40oooo00<000000?ooo`3o
ool08P3oool00`000000oooo0?ooo`1A0?ooo`00L@3oool300000080oooo00<000000?ooo`3oool0
WP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001_0?ooo`800000YP3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0500oooo001/0?ooo`<00000Z03oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04l0oooo001Z0?ooo`800000Z`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001X0?ooo`80000000<0oooo0000003o
ool0ZP3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo04h0oooo001U0?ooo`<00000
103oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
C@3oool006<0oooo0P00002b0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0C@3o
ool00600oooo0`00002d0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0C03oool0
05h0oooo1000002e0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005`0
oooo0P00002i0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0B`3oool005T0oooo
0`00002k0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool005H0oooo0`00
002n0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0BP3oool002X0oooo1@000002
0?ooo`8000008P3oool300000;l0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`19
0?ooo`00;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0703oool3
00000<80oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`180?ooo`00;03oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool06P3oool200000<H0oooo00<00000
0?ooo`3oool0:P3oool00`000000oooo0?ooo`180?ooo`00903oool4000000@0oooo00D000000?oo
o`3oool0oooo000000020?ooo`030000003oool0oooo01H0oooo00@000000?ooo`0000000000b03o
ool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo04L0oooo000/0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0E0?ooo`<00000bP3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo04L0oooo000[0?ooo`800000103oool2000001H0oooo0P000002
0?ooo`030000003oool0oooo0<P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`16
0?ooo`00A`3oool200000<l0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`150?oo
o`00@P3oool00`000000oooo0000000200000=40oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`150?ooo`00@P3oool200000=@0oooo00<000000?ooo`3oool0;P3oool00`000000oooo
0?ooo`140?ooo`00?`3oool300000080oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0_0?ooo`030000003oool0oooo04<0oooo000m0?ooo`800000f@3oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo04<0oooo000k0?ooo`800000f`3oool00`000000oooo0?ooo`0`0?oo
o`030000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0`0?ooo`03
0000003oool0oooo0480oooo000i0?ooo`800000g@3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0440oooo000Y0?ooo`D000000P3oool2000000L0oooo00<000000?ooo`000000g03o
ool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0400oooo000[0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo00000=/0oooo
00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`100?ooo`00:`3oool01@000000oooo0?oo
o`3oool000000080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0=P0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0o0?ooo`008`3o
ool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3G0?ooo`030000003oool0oooo03<0oooo
00<000000?ooo`3oool0?`3oool002/0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3F0?ooo`030000
003oool0oooo03@0oooo00<000000?ooo`3oool0?P3oool002X0oooo0P0000040?ooo`8000001P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0=@3o
ool00`000000oooo0?ooo`0m0?ooo`00=`3oool3000000L0oooo00<000000?ooo`3oool0e@3oool0
0`000000oooo0?ooo`0d0?ooo`030000003oool0oooo03d0oooo000h0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0e0?ooo`030000003oool0oooo
03`0oooo000g0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0d`3oool00`000000
oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo000g0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool0dP3oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo03/0oooo
000g0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0d@3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo03X0oooo000g0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0d03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo03X0oooo000g0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0h0?oo
o`030000003oool0oooo03T0oooo000g0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool0cP3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo03P0oooo000f0?ooo`030000
003oool0oooo0100oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo03P0oooo000f0?ooo`8000004P3oool00`000000oooo0?ooo`3<0?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0=`3oool003H0oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`3;0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0=`3oool0
03H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`3:0?ooo`030000003oool0oooo
03/0oooo00<000000?ooo`3oool0=P3oool003H0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`390?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0=@3oool003H0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`380?ooo`030000003oool0oooo03`0oooo
00<000000?ooo`3oool0=@3oool003H0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`370?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0=03oool003D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`360?ooo`030000003oool0oooo03d0oooo00<00000
0?ooo`3oool0=03oool003D0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`350?oo
o`030000003oool0oooo03h0oooo00<000000?ooo`3oool0<`3oool003D0oooo00<000000?ooo`3o
ool06P3oool00`000000oooo0?ooo`340?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0<P3oool003@0oooo0`00000L0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0b0?ooo`00=@3oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0a0?ooo`00=@3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0`0?ooo`00=03oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0<40oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0`0?ooo`00=03oool00`000000
oooo0?ooo`0P0?ooo`030000003oool0oooo0<00oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0;l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0_0?ooo`00=03oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo0;l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?oo
o`0^0?ooo`00=03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo0;h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?ooo`00=03oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo0;d0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0]0?oo
o`00<`3oool3000002D0oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo02`0oooo000c0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0
^`3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo02`0oooo000c0?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool0^P3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo02/0oooo000c0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0^@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo02X0oooo000c0?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
02X0oooo000c0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0]`3oool00`000000
oooo0?ooo`170?ooo`030000003oool0oooo02T0oooo000b0?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool0]P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo02P0oooo
000b0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0]@3oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo02P0oooo000b0?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool0]03oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo02L0oooo000b0?oo
o`030000003oool0000002l0oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo02L0oooo000b0?ooo`800000<@3oool00`000000oooo0?ooo`2c0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool09P3oool00380oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`2b0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
9@3oool002P0oooo0P0000080?ooo`030000003oool0oooo0380oooo00<000000?ooo`3oool0/@3o
ool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo02D0oooo000W0?ooo`040000003oool0
oooo000000H0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`3oool0903oool002X0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0e0?ooo`030000003oool0oooo0:l0oooo00<000000?ooo`3oool0B`3oool0
0`000000oooo0?ooo`0T0?ooo`008@3oool4000000<0oooo0P0000070?ooo`030000003oool0oooo
03H0oooo00<000000?ooo`3oool0[P3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo
02<0oooo000X0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2]0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool08P3oool002P0oooo
0`0000060?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0[03oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo0280oooo000a0?ooo`030000003oool0oooo03T0oooo00<0
00000?ooo`3oool0Z`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0240oooo000`
0?ooo`<00000>`3oool00`000000oooo0?ooo`2Z0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool08@3oool00300oooo00<000000?ooo`3oool0?03oool00`000000oooo0?ooo`2Y0?oo
o`030000003oool0oooo04l0oooo00<000000?ooo`3oool0803oool00300oooo00<000000?ooo`3o
ool0?@3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3o
ool07`3oool00300oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`2W0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool07`3oool00300oooo00<000000?ooo`3oool0?`3o
ool00`000000oooo0?ooo`2V0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool07P3o
ool00300oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`2U0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool07@3oool002l0oooo00<000000?ooo`3oool0@P3oool00`00
0000oooo0?ooo`2T0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool07@3oool002l0
oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`2S0?ooo`030000003oool0oooo05<0
oooo00<000000?ooo`3oool0703oool002l0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`2R0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0703oool002l0oooo0P00
00160?ooo`030000003oool0oooo0:80oooo00<000000?ooo`3oool0DP3oool2000001d0oooo000^
0?ooo`800000B03oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo04l0oooo0`000000
0`3oool000000?ooo`0L0?ooo`00;`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
0:00oooo00<000000?ooo`3oool0C03oool3000000@0oooo00<000000?ooo`3oool06`3oool002l0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`2O0?ooo`030000003oool0oooo04T0
oooo0`0000070?ooo`030000003oool0oooo01/0oooo000^0?ooo`030000003oool0oooo04X0oooo
00<000000?ooo`3oool0WP3oool00`000000oooo0?ooo`160?ooo`<000002`3oool00`000000oooo
0?ooo`0J0?ooo`00;P3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo09d0oooo00<0
00000?ooo`3oool0@`3oool3000000h0oooo00<000000?ooo`3oool06P3oool002h0oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`2L0?ooo`030000003oool0oooo0400oooo0`00000A
0?ooo`030000003oool0oooo01X0oooo000^0?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0V`3oool00`000000oooo0?ooo`0m0?ooo`<00000503oool00`000000oooo0?ooo`0J0?oo
o`00;P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3o
ool0>@3oool4000001L0oooo00<000000?ooo`3oool06P3oool002h0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo03H0oooo0`00000K0?ooo`030000
003oool0oooo01X0oooo000]0?ooo`800000DP3oool00`000000oooo0?ooo`2H0?ooo`030000003o
ool0oooo03<0oooo0`00000N0?ooo`030000003oool0oooo01X0oooo000]0?ooo`030000003oool0
oooo0580oooo00<000000?ooo`3oool0U`3oool00`000000oooo0?ooo`0`0?ooo`<000008@3oool0
0`000000oooo0?ooo`0J0?ooo`00;@3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
09H0oooo00<000000?ooo`3oool0;@3oool3000002D0oooo00<000000?ooo`3oool06@3oool002d0
oooo00<000000?ooo`3oool0E03oool00`000000oooo0?ooo`2E0?ooo`030000003oool0oooo02X0
oooo0`00000X0?ooo`030000003oool0oooo01T0oooo000]0?ooo`030000003oool0oooo05D0oooo
00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0W0?ooo`<00000:`3oool00`000000oooo
0?ooo`0I0?ooo`00;@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo09<0oooo00<0
00000?ooo`3oool0903oool3000002h0oooo00<000000?ooo`3oool06@3oool002`0oooo00<00000
0?ooo`3oool0F03oool00`000000oooo0?ooo`2B0?ooo`030000003oool0oooo0240oooo0`00000a
0?ooo`030000003oool0oooo01T0oooo000/0?ooo`030000003oool0oooo05T0oooo00<000000?oo
o`3oool0T@3oool00`000000oooo0?ooo`0N0?ooo`<00000=03oool00`000000oooo0?ooo`0I0?oo
o`00;03oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo0940oooo00<000000?ooo`3o
ool06P3oool3000003L0oooo00<000000?ooo`3oool06@3oool002`0oooo00<000000?ooo`3oool0
F`3oool00`000000oooo0?ooo`2@0?ooo`030000003oool0oooo01L0oooo0`00000k0?ooo`030000
003oool0oooo01P0oooo000/0?ooo`800000G@3oool00`000000oooo0?ooo`2?0?ooo`030000003o
ool0oooo01@0oooo0`00000n0?ooo`030000003oool0oooo01P0oooo000[0?ooo`800000G`3oool0
0`000000oooo0?ooo`2>0?ooo`030000003oool0oooo0140oooo0`0000110?ooo`030000003oool0
oooo01P0oooo000/0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool07@3oool00`00
0?l0oooo0?ooo`1]0?ooo`030000003oool0oooo00h0oooo0`0000140?ooo`030000003oool0oooo
01P0oooo000[0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool06`3oool00`000?l0
oooo0000o`1^0?ooo`030000003oool0oooo00X0oooo100000170?ooo`030000003oool0oooo01P0
oooo000[0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool06P3oool00`000?l0oooo
0?ooo`020000of`0oooo00<000000?ooo`3oool01`3oool3000004/0oooo00<000000?ooo`3oool0
603oool002/0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0H0?ooo`030000o`3o
ool0oooo00<0oooo00<0003o0?ooo`3oool0J@3oool00`000000oooo0?ooo`040?ooo`<00000CP3o
ool00`000000oooo0?ooo`0H0?ooo`00:`3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0
oooo01L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`1X0?ooo`040000003oool0
oooo0?ooo`<00000DP3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1T
0?ooo`030000003oool0oooo01D0oooo00<0003o0?ooo`3oool01@3oool00`000?l0oooo0?ooo`1X
0?ooo`@00000E@3oool00`000000oooo0?ooo`0G0?ooo`00:`3oool00`000000oooo0?ooo`1U0?oo
o`030000003oool0oooo01<0oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`1V0?oo
o`<00000F03oool00`000000oooo0?ooo`0G0?ooo`00:P3oool00`000000oooo0?ooo`1W0?ooo`03
0000003oool0oooo0180oooo00<0003o0?ooo`3oool01P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo05d0oooo0`0000020?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool05`3oool002X0oooo00<000000?ooo`000000J03oool00`000000oooo0?ooo`0@0?ooo`030000
o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1K0?ooo`<00000
1@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000Z0?ooo`800000J@3o
ool00`000000oooo0?ooo`0?0?ooo`030000o`3oool0oooo00L0oooo00<0003o0?ooo`3oool00`3o
ool00`000?l0oooo0?ooo`1H0?ooo`<00000203oool00`000000oooo0?ooo`1F0?ooo`030000003o
ool0oooo01L0oooo000Z0?ooo`030000003oool0oooo06T0oooo00<000000?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`070?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool0EP3oool3
000000/0oooo00<000000?ooo`3oool0EP3oool00`000000oooo0?ooo`0G0?ooo`008@3oool20000
00L0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0<0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1D0?ooo`<000003P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo01L0oooo000P0?ooo`040000003oool0oooo0000
00H0oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0;0?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`1A0?ooo`<000004@3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01H0oooo000P0?ooo`040000003oool0oooo0000
00D0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`090?ooo`030000o`3oool0oooo
00L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`080?ooo`80003oA@3oool30000
01@0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0F0?ooo`00803oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo06h0oooo00<000000?ooo`3oool02@3oool20000
o`H0oooo00<0003o0?ooo`3oool00P3oool20000o`P0oooo0P000?l20?ooo`030000o`3oool0oooo
03l0oooo0`00000H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool05P3oool00200
oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo
00X0oooo0P000?l20?ooo`80003o1@3oool20000o`L0oooo00<0003o0?ooo`3oool00`3oool00`00
0?l0oooo0?ooo`0k0?ooo`<000006`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo
01H0oooo000Q0?ooo`8000001P3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00/0
oooo0P000?l60?ooo`030000o`3oool0003o00H0oooo00<0003o0?ooo`3oool0103oool00`000?l0
oooo0000o`0h0?ooo`<000007P3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0
oooo000Y0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool0503oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo00@0oooo0P000?le0?ooo`@000008@3oool00`000000oooo
0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000Y0?ooo`030000003oool0oooo0780oooo00<0
00000?ooo`3oool0503oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo00D0oooo0P00
0?lb0?ooo`<000009@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo01H0oooo000X
0?ooo`030000003oool0000007@0oooo00<000000?ooo`3oool0503oool01@000?l0oooo0?ooo`3o
ool0003o00L0oooo00<0003o0?ooo`3oool0103oool00`000?l0oooo0?ooo`0W0?ooo`<00000:03o
ool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo000X0?ooo`800000MP3oool0
0`000000oooo0?ooo`0G0?ooo`030000o`3oool0oooo00@0oooo00<0003o0?ooo`3oool0103oool2
0000obH0oooo0`00000[0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool0
00@0oooo1000000P0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool05P3oool00`00
0?l0oooo0?ooo`030?ooo`030000o`3oool0oooo00@0oooo0P000?lT0?ooo`<00000;P3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo01D0oooo00050?ooo`030000003oool000000200
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`0F0?ooo`050000o`3oool0oooo0?oo
o`000?l01P3oool00`000?l0oooo0000o`040?ooo`030000o`3oool0oooo01X0oooo0`00000a0?oo
o`030000003oool0oooo05L0oooo00<000000?ooo`3oool05@3oool000@0oooo00<000000?ooo`00
00008@3oool00`000000oooo0?ooo`1h0?ooo`030000003oool0oooo01H0oooo10000?l50?ooo`03
0000o`3oool0003o00@0oooo0P000?lI0?ooo`<00000=03oool00`000000oooo0?ooo`1G0?ooo`03
0000003oool0oooo01D0oooo00040?ooo`@00000803oool00`000000oooo0?ooo`1i0?ooo`030000
003oool0oooo01L0oooo00<0003o0?ooo`3oool00`3oool010000?l0oooo0?ooo`000?l30?ooo`80
003o5`3oool3000003L0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0E0?ooo`00
:03oool00`000000oooo0?ooo`1j0?ooo`030000003oool0oooo01/0oooo00D0003o0?ooo`3oool0
oooo0000o`020?ooo`030000o`3oool0003o01@0oooo0`00000j0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool05@3oool002L0oooo00<000000?ooo`3oool0O03oool00`000000oooo
0?ooo`0I0?ooo`060000o`3oool0oooo0?ooo`000?l0oooo0P000?l00`3oool0003o0?ooo`0A0?oo
o`<00000?@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo000W0?ooo`03
0000003oool0oooo07d0oooo00<000000?ooo`3oool0703oool20000o`<0oooo00<0003o0?ooo`3o
ool01@3oool20000o`H0oooo0`0000100?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0503oool002L0oooo00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0J0?ooo`80003o
103oool00`000?l0oooo0?ooo`030?ooo`80003o0P3oool00`000?l0oooo0?ooo`03000004<0oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?oo
o`1o0?ooo`030000003oool0oooo01T0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?oo
o`030?ooo`030000o`3oool0oooo0080oooo00<000000000o`000000AP3oool00`000000oooo0?oo
o`1H0?ooo`030000003oool0oooo01@0oooo000V0?ooo`<00000P@3oool00`000000oooo0?ooo`0M
0?ooo`040000o`3oool0oooo0?ooo`80003o0P3oool3000000030?ooo`000?l0oooo04H0oooo00<0
00000?ooo`3oool0F03oool00`000000oooo0?ooo`0D0?ooo`009`3oool00`000000oooo0?ooo`21
0?ooo`030000003oool0oooo01/0oooo00H0003o0?ooo`3oool0oooo0000o`3oool3000000@0oooo
00<0003o0?ooo`3oool0A@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01@0oooo
000V0?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool06P3oool01P000?l0oooo0000
00000000003o000000L0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`110?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool0503oool002H0oooo00<000000?ooo`3oool0
Q03oool00`000000oooo0?ooo`0H0?ooo`<0000000<0oooo0000o`3oool01@3oool010000?l0oooo
0?ooo`000?l30?ooo`030000o`3oool0oooo0480oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0D0?ooo`009P3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo01@0oooo
0`0000040?ooo`030000o`3oool0oooo00D0oooo0P000?l40?ooo`030000o`3oool0oooo0480oooo
00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?oo
o`260?ooo`030000003oool0oooo0100oooo0`0000070?ooo`030000o`3oool0oooo00H0oooo00D0
003o0?ooo`3oool0oooo0000o`150?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4`3oool002H0oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`0<0?ooo`<000002@3o
ool00`000?l0oooo0?ooo`0:0?ooo`030000o`3oool0oooo04@0oooo00<000000?ooo`3oool0F03o
ool00`000000oooo0?ooo`0C0?ooo`009P3oool00`000000oooo0?ooo`280?ooo`030000003oool0
oooo00P0oooo0`00000<0?ooo`030000o`3oool0oooo00X0oooo00<0003o0?ooo`3oool0A03oool0
0`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01<0oooo000U0?ooo`030000003oool0oooo
08X0oooo00<000000?ooo`3oool0103oool300000100oooo00<0003o0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`060?ooo`@0003o1`3oool00`000?l0oooo0?ooo`0a0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool04`3oool002D0oooo00<000000?ooo`3oool0R`3oool00`000000
oooo0?ooo`03000001<0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`020?ooo`03
0000o`3oool0oooo00D0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`030?ooo`03
0000o`3oool0oooo0380oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`00
9@3oool00`000000oooo0?ooo`2<0?ooo`8000005P3oool00`000?l0oooo0?ooo`020?ooo`030000
o`3oool0oooo0080oooo0P000?l60?ooo`030000o`3oool0oooo00@0oooo0P000?l30?ooo`030000
o`3oool0oooo0380oooo00<000000?ooo`3oool0F03oool00`000000oooo0?ooo`0C0?ooo`009@3o
ool2000008d0oooo00<000000?ooo`3oool05P3oool40000o`H0oooo00<0003o0?ooo`3oool0103o
ool00`000?l0oooo0?ooo`040?ooo`050000o`3oool0oooo0?ooo`000?l0=03oool2000005/0oooo
00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?oo
o`0Q0?ooo`030000o`3oool0oooo0080oooo00<0003o0?ooo`3oool01@3oool01@000?l0oooo0?oo
o`3oool0003o0340oooo0`0000020?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3oool0
4P3oool002D0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0R0?ooo`050000o`3o
ool0oooo0?ooo`000?l01P3oool010000?l0oooo0?ooo`3oool40000ob/0oooo100000060?ooo`03
0000003oool0oooo05L0oooo00<000000?ooo`3oool04P3oool002D0oooo00<000000?ooo`3oool0
S03oool00`000000oooo0?ooo`0V0?ooo`030000o`3oool0oooo00<0oooo00@0003o0?ooo`3oool0
oooo0P000?l30?ooo`030000o`3oool0oooo02D0oooo0`00000:0?ooo`030000003oool0oooo05L0
oooo00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0V0?ooo`030000o`3oool0oooo00<0oooo00D0003o0?ooo`3oool0oooo0000o`040?ooo`03
0000o`3oool0oooo0280oooo0`00000>0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3o
ool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0W0?ooo`050000
o`3oool0oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`030?ooo`030000o`3oool0oooo01l0
oooo0`00000B0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool04P3oool002@0oooo
00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0X0?ooo`@0003o0`3oool00`000?l0oooo
0?ooo`040?ooo`030000o`3oool0oooo01/0oooo0`00000F0?ooo`030000003oool0oooo05@0oooo
00<000000?ooo`3oool04P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?oo
o`0Z0?ooo`050000o`3oool0oooo0?ooo`000?l01P3oool00`000?l0oooo0?ooo`030?ooo`030000
o`3oool0oooo0180oooo1000000J0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0
4P3oool002@0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0^0?ooo`030000o`3o
ool0oooo00@0oooo00<0003o0?ooo`3oool00P3oool00`000?l0oooo0?ooo`0@0?ooo`<000007P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo0140oooo000T0?ooo`030000003oool0
oooo08d0oooo00<000000?ooo`3oool0;@3oool20000o`D0oooo00<0003o0?ooo`3oool00`3oool0
0`000?l0oooo0?ooo`0=0?ooo`<000008P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0
oooo0140oooo000S0?ooo`030000003oool0oooo08h0oooo00<000000?ooo`3oool0;`3oool01@00
0?l0oooo0?ooo`3oool0003o00D0oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`05
0?ooo`<000009P3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0140oooo000S0?oo
o`800000S`3oool00`000000oooo0?ooo`0`0?ooo`@0003o103oool00`000?l0oooo0?ooo`030?oo
o`030000o`3oool0oooo00<0oooo0`00000Z0?ooo`030000003oool0oooo0540oooo00<000000?oo
o`3oool04@3oool002<0oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0h0?ooo`03
0000o`3oool0oooo00<0oooo00<0003o0?ooo`0000000`00000^0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool04@3oool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo
0?ooo`0h0?ooo`030000o`3oool0oooo00<0oooo0`0000030?ooo`030000o`3oool0oooo02d0oooo
00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0A0?ooo`008`3oool00`000000oooo0?oo
o`2=0?ooo`030000003oool0oooo03L0oooo0P000?l20?ooo`<0000000<0003o0?ooo`3oool00P3o
ool00`000?l0oooo0?ooo`0^0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool04@3o
ool002<0oooo00<000000?ooo`3oool0S@3oool00`000000oooo0?ooo`0g0?ooo`040000o`000000
000000000080oooo00<0003o0?ooo`3oool00`3oool00`000?l0oooo0?ooo`0_0?ooo`030000003o
ool0oooo04l0oooo00<000000?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool0
0`000000oooo0?ooo`0e0?ooo`<0000000<0oooo0000o`3oool00P3oool00`000?l0oooo0?ooo`02
0?ooo`030000o`3oool0oooo0080oooo0`000?l/0?ooo`030000003oool0oooo04h0oooo00<00000
0?ooo`3oool0403oool00280oooo00<000000?ooo`3oool0SP3oool00`000000oooo0?ooo`0a0?oo
o`@0000000<0003o0?ooo`3oool00P3oool30000o`@0oooo00<0003o0?ooo`3oool00P3oool01@00
0?l0oooo0?ooo`3oool0003o02`0oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`0@
0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo02h0oooo0`0000040?oo
o`030000o`3oool0oooo00T0oooo00<0003o0?ooo`3oool00P000?l40?ooo`030000o`3oool0oooo
02/0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000
oooo0?ooo`2>0?ooo`030000003oool0oooo02/0oooo0`0000060?ooo`030000o`3oool0oooo00T0
oooo00D0003o0?ooo`3oool0oooo0000o`050?ooo`030000o`3oool0oooo02/0oooo00<000000?oo
o`3oool0C03oool00`000000oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`2>0?ooo`03
0000003oool0oooo02P0oooo0`00000E0?ooo`040000o`3oool0oooo0000o`H0oooo00<0003o0?oo
o`3oool0;03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0oooo0100oooo000R0?ooo`<0
0000SP3oool00`000000oooo0?ooo`0U0?ooo`<000005`3oool01@000?l0oooo0?ooo`3oool0003o
00X0oooo0`000?lY0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0403oool00240
oooo0P00002@0?ooo`030000003oool0oooo0240oooo1000000N0?ooo`030000o`3oool0oooo00L0
oooo00D0003o0?ooo`3oool0oooo0000o`0Y0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool03`3oool00240oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0N0?ooo`<0
00008P3oool00`000?l0oooo0?ooo`0<0?ooo`030000o`3oool0oooo02L0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`0?0?ooo`00603oool2000000L0oooo00<000000?ooo`3oool0
S`3oool00`000000oooo0?ooo`0K0?ooo`<000007P3oool00`000?l0oooo0?ooo`050?ooo`050000
o`3oool0oooo0?ooo`000?l0203oool00`000?l0oooo0?ooo`0X0?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool03`3oool001L0oooo00@000000?ooo`3oool000001P3oool00`000000
oooo0?ooo`2?0?ooo`030000003oool0oooo01P0oooo0`00000Q0?ooo`030000o`3oool0oooo00H0
oooo0`000?l30?ooo`<0003o0`3oool00`000?l0oooo0?ooo`020?ooo`030000o`3oool0oooo02@0
oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0?0?ooo`006P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo08l0oooo00<000000?ooo`3oool05@3oool300000380oooo
00@0003o0?ooo`3oool0oooo0`000?l40?ooo`80003o9`3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00l0oooo000H0?ooo`8000001`3oool00`000000oooo0?ooo`2?0?ooo`030000
003oool0oooo0140oooo1000000e0?ooo`030000o`3oool0oooo0380oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`0?0?ooo`00603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo08l0oooo00<000000?ooo`3oool03P3oool3000003T0oooo00<0003o0?ooo`3oool0<`3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00l0oooo000H0?ooo`<000001@3oool0
0`000000oooo0?ooo`2@0?ooo`030000003oool0oooo00/0oooo0`00000m0?ooo`050000o`3oool0
oooo0?ooo`000?l00`3oool00`000?l0oooo0?ooo`0Z0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool03`3oool00200oooo00<000000?ooo`3oool0T03oool00`000000oooo0?ooo`08
0?ooo`<00000@@3oool30000o`<0oooo00<0003o0?ooo`3oool0;03oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?oo
o`3oool0103oool4000004X0oooo00<0003o0?ooo`3oool0;@3oool00`000000oooo0?ooo`140?oo
o`030000003oool0oooo00h0oooo000P0?ooo`030000003oool0oooo0900oooo00@000000?ooo`3o
ool0oooo0`00001=0?ooo`030000o`3oool0oooo02l0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0>0?ooo`00803oool200000940oooo1000001?0?ooo`030000o`3oool0oooo0340
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0>0?ooo`007`3oool200000900oooo
0`00001B0?ooo`030000o`3oool0oooo0340oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0>0?ooo`007`3oool00`000000oooo0?ooo`2<0?ooo`<000000P3oool00`000000oooo0?oo
o`1?0?ooo`030000o`3oool0oooo03<0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0>0?ooo`007`3oool00`000000oooo0?ooo`280?ooo`@000001@3oool00`000000oooo0?ooo`1?
0?ooo`030000o`3oool0oooo03@0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0>
0?ooo`007`3oool00`000000oooo0?ooo`250?ooo`<000002@3oool00`000000oooo0?ooo`1>0?oo
o`030000o`3oool0oooo03H0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0=0?oo
o`007`3oool00`000000oooo0?ooo`220?ooo`<00000303oool00`000000oooo0?ooo`280?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool03@3oool001l0oooo00<000000?ooo`3oool0
O`3oool3000000l0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`0n0?ooo`030000
003oool0oooo00d0oooo000O0?ooo`030000003oool0oooo07`0oooo0`00000A0?ooo`030000003o
ool0oooo08X0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0=0?ooo`007`3oool0
0`000000oooo0?ooo`1h0?ooo`@00000503oool00`000000oooo0?ooo`2;0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`3oool03@3oool001h0oooo00<000000?ooo`3oool0MP3oool30000
01P0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
00d0oooo000N0?ooo`030000003oool0oooo07<0oooo0`00000K0?ooo`030000003oool0oooo08d0
oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0=0?ooo`007P3oool00`000000oooo
0?ooo`1`0?ooo`<000007P3oool00`000000oooo0?ooo`2>0?ooo`030000003oool0oooo03/0oooo
00<000000?ooo`3oool0303oool001d0oooo0`00001^0?ooo`<000008@3oool00`000000oooo0?oo
o`2>0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0303oool001h0oooo00<00000
0?ooo`3oool0J@3oool4000002@0oooo00<000000?ooo`3oool0S`3oool00`000000oooo0?ooo`0j
0?ooo`030000003oool0oooo00`0oooo000N0?ooo`030000003oool0oooo06H0oooo0`00000X0?oo
o`030000003oool0oooo0900oooo00<000000?ooo`3oool0>@3oool00`000000oooo0?ooo`0<0?oo
o`007@3oool00`000000oooo0?ooo`1T0?ooo`<00000:`3oool00`000000oooo0?ooo`2A0?ooo`03
0000003oool0oooo03P0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0
H@3oool3000002h0oooo00<000000?ooo`3oool0TP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo00`0oooo000M0?ooo`030000003oool0oooo05h0oooo0`00000a0?ooo`030000003o
ool0oooo0980oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`0<0?ooo`007@3oool0
0`000000oooo0?ooo`1J0?ooo`@00000=03oool00`000000oooo0?ooo`2C0?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0303oool001d0oooo00<000000?ooo`3oool0E`3oool30000
03P0oooo00<000000?ooo`3oool0U03oool00`000000oooo0?ooo`0f0?ooo`030000003oool0oooo
00/0oooo000M0?ooo`030000003oool0oooo05@0oooo0`00000k0?ooo`030000003oool0oooo09D0
oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`0;0?ooo`00703oool00`000000oooo
0?ooo`1B0?ooo`<00000?P3oool00`000000oooo0?ooo`2F0?ooo`030000003oool0oooo03@0oooo
00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0CP3oool400000440oooo00<0
00000?ooo`3oool0UP3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo00/0oooo000L
0?ooo`030000003oool0oooo04/0oooo0`0000150?ooo`030000003oool0oooo09L0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0;0?ooo`00703oool2000004T0oooo0`0000180?oo
o`030000003oool0oooo09P0oooo00<000000?ooo`3oool0<P3oool00`000000oooo0?ooo`0;0?oo
o`00703oool00`000000oooo0?ooo`150?ooo`<00000B`3oool00`000000oooo0?ooo`2I0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool02`3oool001`0oooo00<000000?ooo`3oool0
@P3oool3000004h0oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo00X0oooo000K0?ooo`030000003oool0oooo03l0oooo1000001A0?ooo`030000003o
ool0oooo09/0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0:0?ooo`006`3oool0
0`000000oooo0?ooo`0l0?ooo`<00000E@3oool00`000000oooo0?ooo`2K0?ooo`030000003oool0
oooo0300oooo00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0>@3oool30000
05P0oooo00<000000?ooo`3oool0W03oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo
00X0oooo000K0?ooo`030000003oool0oooo03H0oooo0`00001K0?ooo`030000003oool0oooo09d0
oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0:0?ooo`006`3oool00`000000oooo
0?ooo`0c0?ooo`<00000GP3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool02P3oool001/0oooo00<000000?ooo`3oool0;`3oool400000640oooo00<0
00000?ooo`3oool0W`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00X0oooo000K
0?ooo`030000003oool0oooo02`0oooo0`00001U0?ooo`030000003oool0oooo09l0oooo00<00000
0?ooo`3oool0;@3oool00`000000oooo0?ooo`090?ooo`006P3oool00`000000oooo0?ooo`0Z0?oo
o`<00000I`3oool00`000000oooo0?ooo`2Q0?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool02@3oool001X0oooo00<000000?ooo`3oool09`3oool3000006X0oooo00<000000?ooo`3o
ool0XP3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00T0oooo000J0?ooo`800000
9@3oool3000006d0oooo00<000000?ooo`3oool0X`3oool00`000000oooo0?ooo`0Z0?ooo`030000
003oool0oooo00T0oooo000J0?ooo`030000003oool0oooo0200oooo1000001`0?ooo`030000003o
ool0oooo0:@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`090?ooo`006P3oool0
0`000000oooo0?ooo`0M0?ooo`<00000M03oool00`000000oooo0?ooo`2T0?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool02@3oool001X0oooo00<000000?ooo`3oool06P3oool30000
07L0oooo00<000000?ooo`3oool0Y@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo
00T0oooo000I0?ooo`030000003oool0oooo01P0oooo0`00001j0?ooo`030000003oool0oooo0:H0
oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`006@3oool00`000000oooo
0?ooo`0E0?ooo`<00000O@3oool00`000000oooo0?ooo`2W0?ooo`030000003oool0oooo02L0oooo
00<000000?ooo`3oool0203oool001T0oooo00<000000?ooo`3oool04@3oool400000800oooo00<0
00000?ooo`3oool0Z03oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00P0oooo000I
0?ooo`030000003oool0oooo00h0oooo0`0000240?ooo`030000003oool0oooo0:P0oooo00<00000
0?ooo`3oool09P3oool00`000000oooo0?ooo`080?ooo`006@3oool00`000000oooo0?ooo`0;0?oo
o`<00000Q`3oool00`000000oooo0?ooo`2Y0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool0203oool001T0oooo00<000000?ooo`3oool0203oool3000008X0oooo00<000000?ooo`3o
ool0ZP3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00P0oooo000H0?ooo`030000
003oool0oooo00H0oooo0`00002=0?ooo`030000003oool0oooo0:/0oooo00<000000?ooo`3oool0
8`3oool00`000000oooo0?ooo`080?ooo`00603oool00`000000oooo0?ooo`020?ooo`@00000T03o
ool00`000000oooo0?ooo`2/0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0203o
ool001P0oooo00<000000?ooo`0000000P00002D0?ooo`030000003oool0oooo0:d0oooo00<00000
0?ooo`3oool08P3oool00`000000oooo0?ooo`070?ooo`00603oool2000009L0oooo00<000000?oo
o`3oool0[@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00L0oooo00070?ooo`D0
00000P3oool2000000T0oooo0P00002F0?ooo`030000003oool0oooo0:h0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo0?ooo`3oool000000080
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2C0?ooo`030000003oool0oooo0:l0
oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?ooo`002@3oool01@000000oooo
0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2B0?ooo`03
0000003oool0oooo0;00oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`070?ooo`00
2@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02P3oool200000980
oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo00L0
oooo00090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0000008l0oooo00<000000?ooo`3oool0/@3oool00`000000oooo0?ooo`0N0?ooo`03
0000003oool0oooo00L0oooo00080?ooo`800000103oool200000100oooo0P00002?0?ooo`030000
003oool0oooo0;80oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`070?ooo`008P3o
ool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0;<0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`060?ooo`008`3oool2000008`0oooo00<000000?ooo`3oool0]03oool0
0`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00H0oooo000C0?ooo`D000000P3oool20000
00T0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3oool0oooo000000020?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool0R03oool00`000000oooo0?ooo`2e0?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool01P3oool001D0oooo00D000000?ooo`3o
ool0oooo000000020?ooo`030000003oool0oooo00P0oooo0P0000000`3oool000000?ooo`240?oo
o`030000003oool0oooo0;L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`060?oo
o`003@3oool4000000@0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo
00X0oooo0P0000250?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`060?ooo`005@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool02`3oool2000008@0oooo00<000000?ooo`3oool0^@3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo00H0oooo000D0?ooo`800000103oool200000100oooo00<000000?ooo`3o
ool0P@3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01@3oool002d0oooo00<000000?ooo`3oool0P03oool00`000000oooo0?ooo`2j0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01@3oool002h0oooo0P0000200?ooo`030000003o
ool0oooo0;/0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`050?ooo`00<03oool0
10000000oooo0?ooo`00001l0?ooo`030000003oool0oooo0;`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`050?ooo`00<@3oool3000007`0oooo00<000000?ooo`3oool0_@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00D0oooo000c0?ooo`030000003oool0oooo
07X0oooo00<000000?ooo`3oool0_P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
00D0oooo000d0?ooo`800000NP3oool00`000000oooo0?ooo`2n0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01@3oool003H0oooo00<000000?ooo`3oool0M`3oool00`000000oooo
0?ooo`2o0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0103oool003L0oooo00<0
00000?ooo`3oool0MP3oool00`000000oooo0?ooo`300?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool0103oool003P0oooo0P0000000`3oool000000?ooo`1c0?ooo`030000003oool0
oooo0<40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`00>P3oool20000
07@0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
00@0oooo000k0?ooo`800000L`3oool00`000000oooo0?ooo`330?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool0103oool003d0oooo00<000000?ooo`3oool0L03oool00`000000oooo
0?ooo`330?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0103oool003h0oooo0P00
001`0?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`040?ooo`00@03oool01@000000oooo0?ooo`3oool0000006/0oooo00<000000?ooo`3oool0a@3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00@0oooo00110?ooo`040000003oool0
oooo000006/0oooo00<000000?ooo`3oool0aP3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00<0oooo00120?ooo`800000K03oool00`000000oooo0?ooo`370?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool00`3oool004<0oooo0P00001[0?ooo`030000003oool0oooo
0<L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`030?ooo`00A@3oool2000006T0
oooo00<000000?ooo`3oool0b03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00<0
oooo00170?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool0b@3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00180?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0bP3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo0019
0?ooo`80000000<0oooo0000003oool0HP3oool00`000000oooo0?ooo`3;0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool00`3oool004/0oooo0P00001S0?ooo`030000003oool0oooo
0</0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`00C03oool200000680
oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0080
oooo001>0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0cP3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo0080oooo001?0?ooo`800000GP3oool00`000000oooo0?oo
o`3?0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool004@0oooo0P00000;
0?ooo`040000003oool0oooo000005X0oooo00<000000?ooo`3oool0d03oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo0080oooo00130?ooo`040000003oool0oooo000000/0oooo00<0
00000?ooo`000000FP3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool00P3oool004H0oooo00<000000?ooo`3oool02P3oool2000005X0oooo00<00000
0?ooo`3oool0d@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo000m0?oo
o`@000000`3oool2000000l0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`3B0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00@3oool004@0oooo00<000000?ooo`3o
ool03`3oool2000005L0oooo00<000000?ooo`3oool0d`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0040oooo00140?ooo`<000004@3oool00`000000oooo0?ooo`1D0?ooo`030000
003oool0oooo0=@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`010?ooo`00F@3o
ool010000000oooo0?ooo`00001B0?ooo`030000003oool0oooo0=D0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`010?ooo`00FP3oool2000005<0oooo00<000000?ooo`3oool0e@3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0040oooo001K0?ooo`800000DP3oool0
0`000000oooo0?ooo`3F0?ooo`050000003oool0oooo0?ooo`0000000`3oool005d0oooo0P00001@
0?ooo`030000003oool0oooo0=L0oooo00@000000?ooo`3oool000000`3oool005l0oooo00<00000
0?ooo`3oool0C@3oool00`000000oooo0?ooo`3H0?ooo`030000003oool0000000<0oooo001P0?oo
o`80000000<0oooo0000003oool0BP3oool00`000000oooo0?ooo`3I0?ooo`030000003oool00000
0080oooo001R0?ooo`800000B`3oool00`000000oooo0?ooo`3I0?ooo`030000003oool000000080
oooo001S0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0fP3oool200000080oooo
001T0?ooo`800000B@3oool00`000000oooo0?ooo`3I0?ooo`<000000P3oool006H0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo0=D0oooo10000005
0?ooo`00I`3oool200000080oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`3A0?oo
o`@000002@3oool006T0oooo0P0000140?ooo`030000003oool0oooo0<`0oooo1@00000=0?ooo`00
JP3oool2000004<0oooo00<000000?ooo`3oool0b03oool400000180oooo001/0?ooo`030000003o
ool0oooo0400oooo00<000000?ooo`3oool0``3oool5000001H0oooo001]0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool0_`3oool4000001/0oooo001^0?ooo`800000?`3oool00`00
0000oooo0?ooo`2k0?ooo`@000007`3oool00700oooo00<000000?ooo`000000?03oool00`000000
oooo0?ooo`2f0?ooo`D000008`3oool00740oooo0P00000l0?ooo`030000003oool0oooo0;80oooo
1000000X0?ooo`00L`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0:d0oooo1@00
000/0?ooo`00M03oool00`000000oooo0?ooo`0g0?ooo`030000003oool0oooo0:X0oooo1000000a
0?ooo`00M@3oool2000003L0oooo00<000000?ooo`3oool0YP3oool4000003D0oooo001g0?ooo`03
0000003oool0000003@0oooo00<000000?ooo`3oool0X@3oool5000003T0oooo001Y0?ooo`800000
3@3oool2000003@0oooo00<000000?ooo`3oool0W@3oool4000003h0oooo001X0?ooo`040000003o
ool0oooo000000h0oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`2H0?ooo`D00000
@P3oool006P0oooo00@000000?ooo`3oool000003`3oool200000340oooo00<000000?ooo`3oool0
U03oool4000004L0oooo001X0?ooo`040000003oool0oooo00000140oooo00<000000?ooo`3oool0
;P3oool00`000000oooo0?ooo`2@0?ooo`@00000B`3oool006P0oooo00@000000?ooo`3oool00000
4P3oool00`000000oooo0000000]0?ooo`030000003oool0oooo08/0oooo1@00001?0?ooo`00J@3o
ool2000001@0oooo0P00000]0?ooo`030000003oool0oooo08L0oooo1000001D0?ooo`00P@3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0880oooo1@00001H0?ooo`00PP3oool20000
02X0oooo00<000000?ooo`3oool0OP3oool4000005d0oooo00240?ooo`040000003oool0oooo0000
02H0oooo00<000000?ooo`3oool0NP3oool400000640oooo00250?ooo`030000003oool0000002H0
oooo00<000000?ooo`3oool0M@3oool5000006D0oooo00260?ooo`8000009P3oool00`000000oooo
0?ooo`1a0?ooo`@00000JP3oool008P0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`1]0?ooo`@00000KP3oool008T0oooo0P0000030?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool0J03oool500000780oooo002;0?ooo`040000003oool0oooo000001l0oooo00<00000
0?ooo`3oool0I03oool4000007L0oooo002<0?ooo`<000007`3oool00`000000oooo0?ooo`1O0?oo
o`D00000N`3oool008h0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1K0?ooo`@0
0000P03oool008l0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`1G0?ooo`@00000
Q03oool00900oooo0P00000L0?ooo`030000003oool0oooo0580oooo1@0000280?ooo`00TP3oool0
0`000000oooo0000000I0?ooo`030000003oool0oooo04h0oooo1000002=0?ooo`00T`3oool20000
01T0oooo00<000000?ooo`3oool0B@3oool500000940oooo002E0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool0A@3oool4000009H0oooo002F0?ooo`8000005P3oool00`000000oooo
0?ooo`110?ooo`@00000VP3oool009P0oooo00@000000?ooo`3oool000004P3oool00`000000oooo
0?ooo`0l0?ooo`D00000WP3oool009T0oooo00<000000?ooo`0000004P3oool00`000000oooo0?oo
o`0h0?ooo`@00000X`3oool008`0oooo0P00000<0?ooo`8000004@3oool00`000000oooo0?ooo`0d
0?ooo`D00000Y`3oool006D0oooo0P00000T0?ooo`040000003oool0oooo000000d0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0`0?ooo`@00000[03oool006H0oooo00<000000?oo
o`3oool09@3oool00`000000oooo0?ooo`0<0?ooo`8000003P3oool00`000000oooo0?ooo`0/0?oo
o`@00000/03oool006L0oooo00<000000?ooo`3oool08P3oool200000140oooo00<000000?ooo`00
00002`3oool00`000000oooo0?ooo`0W0?ooo`D00000]03oool006H0oooo00<000000?ooo`000000
8`3oool00`000000oooo0?ooo`0A0?ooo`8000002`3oool00`000000oooo0?ooo`0S0?ooo`@00000
^@3oool006D0oooo00@000000?ooo`3oool000008`3oool300000180oooo0P00000:0?ooo`030000
003oool0oooo01h0oooo1@00002m0?ooo`00I03oool3000000030?ooo`000000000003T0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`@00000`P3oool00:@0oooo0P000000
0`3oool000000?ooo`040?ooo`030000003oool0oooo01H0oooo100000360?ooo`00YP3oool20000
00D0oooo00<000000?ooo`3oool04@3oool500000<X0oooo002W0?ooo`800000103oool00`000000
oooo0?ooo`0=0?ooo`@00000c`3oool00:T0oooo00D000000?ooo`3oool0oooo0000000:0?ooo`D0
0000d`3oool00:X0oooo00@000000?ooo`3oool000001P3oool400000=P0oooo002[0?ooo`<00000
0P3oool400000=`0oooo002]0?ooo`<00000h03oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0ooooT@3oool00?l0
ooooT@3oool00:P0oooo1@0000020?ooo`800000g`3oool00:X0oooo00D000000?ooo`3oool0oooo
000000020?ooo`030000003oool0oooo0=`0oooo002Z0?ooo`050000003oool0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`3L0?ooo`00ZP3oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool0g03oool00:X0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000
003oool0oooo0=`0oooo002Y0?ooo`800000103oool200000=l0oooo0000\
\>"],
  ImageRangeCache->{{{0, 399}, {433.188, 0}} -> {-0.0069442, -0.0313366, \
0.00229786, 0.00229786}}]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Moving the Text Plane Around a Sphere", "Subsection"],

Cell[CellGroupData[{

Cell["Rotating about the North pole", "Subsubsection"],

Cell["\<\
The following routine produces one frame for rotating the text about the \
north pole of a sphere.\
\>", "Text"],

Cell[BoxData[
    \(\(\(sframe[\[Phi]_, \[Theta]_]\)[\[Psi]_] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{SurfaceColor[
              LightSkyBlue], 
            EdgeForm[\(ColorMix[LightSkyBlue, Black]\)[
                0.5]], \[IndentingNewLine]ParametricDraw3D[{Cos[t] Sin[f], 
                Sin[t] Sin[f], Cos[f]}, {f, 0, \[Pi]}, {t, 0, 2  \[Pi]}, 
              PlotPoints \[Rule] {15, 
                  30}], \[IndentingNewLine]AbsoluteThickness[2], 
            AlizarinCrimson, \[IndentingNewLine]Text3D["\<Euclid!\>", {Cos[\
\[Theta]] Sin[\[Phi]], Sin[\[Theta]] Sin[\[Phi]], Cos[\[Phi]]}, {2, 2}/
                10, {\[Phi], \[Theta], \[Psi]}, 
              Font3D \[Rule] FuturaFont3D]}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
            0.1], \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                  1}, {\(-1\), 1}} 1.5, \[IndentingNewLine]ImageSize \[Rule] 
            400];\)\)], "Input"],

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(sframe[0, 0]\)[\[Psi]], {\[Psi], 0, 2  \[Pi] - del, 
        del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotating along the Equator", "Subsubsection"],

Cell["\<\
The following routine produces one frame for rotating the text around the \
equator of a sphere.\
\>", "Text"],

Cell[BoxData[
    \(\(\(sframe[\[Phi]_, \[Psi]_]\)[\[Theta]_] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{SurfaceColor[
              LightSkyBlue], 
            EdgeForm[\(ColorMix[LightSkyBlue, Black]\)[
                0.5]], \[IndentingNewLine]ParametricDraw3D[{Cos[t] Sin[f], 
                Sin[t] Sin[f], Cos[f]}, {f, 0, \[Pi]}, {t, 0, 2  \[Pi]}, 
              PlotPoints \[Rule] {15, 
                  30}], \[IndentingNewLine]AbsoluteThickness[2], 
            Red, \[IndentingNewLine]Text3D["\<Thales!\>", {Cos[\[Theta]] 
                  Sin[\[Phi]], Sin[\[Theta]] Sin[\[Phi]], 
                Cos[\[Phi]]}, {1, 1}/4, {\[Phi], \[Theta], \[Psi]}, 
              Font3D \[Rule] FuturaFont3D]}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
            0.1], \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                  1}, {\(-1\), 1}} 1.5, \[IndentingNewLine]ImageSize \[Rule] 
            400];\)\)], "Input"],

Cell["\<\
In the following we first align the text along the y-axis, then rotate it to \
the equator, and then rotate along the equator. Notice that true 3D text is \
hidden when behind surfaces.\
\>", "Text"],

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(sframe[\[Pi]/2, \[Pi]/
            2]\)[\[Theta]], {\[Theta], \(-2\) \[Pi] + del, 0, 
        del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotating along a Meridian", "Subsubsection"],

Cell["\<\
The following routine produces one frame for rotating the text along a \
meridian of a sphere.\
\>", "Text"],

Cell[BoxData[
    \(\(\(sframe[\[Theta]_, \[Psi]_]\)[\[Phi]_] \
:= \[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{SurfaceColor[
              LightSkyBlue], 
            EdgeForm[\(ColorMix[LightSkyBlue, Black]\)[
                0.5]], \[IndentingNewLine]ParametricDraw3D[{Cos[t] Sin[f], 
                Sin[t] Sin[f], Cos[f]}, {f, 0, \[Pi]}, {t, 0, 2  \[Pi]}, 
              PlotPoints \[Rule] {15, 
                  30}], \[IndentingNewLine]AbsoluteThickness[2], 
            ForestGreen, \[IndentingNewLine]Text3D["\<Hippias!\>", {Cos[\
\[Theta]] Sin[\[Phi]], Sin[\[Theta]] Sin[\[Phi]], Cos[\[Phi]]}, {1, 1}/
                4, {\[Phi], \[Theta], \[Psi]}, 
              Font3D \[Rule] FuturaFont3D]}, \[IndentingNewLine]Axes \[Rule] 
            True, \[IndentingNewLine]AxesLabel \[Rule] {x, y, 
              z}, \[IndentingNewLine]NeutralLighting[0.3, 0.5, 
            0.1], \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 1}, {\(-1\), 
                  1}, {\(-1\), 1}} 1.5, \[IndentingNewLine]ImageSize \[Rule] 
            400];\)\)], "Input"],

Cell[TextData[{
  "In the following we first rotate the text to lie along the y-axis and then \
rotate along the ",
  Cell[BoxData[
      \(0  \[Degree]\)]],
  " meridian."
}], "Text"],

Cell[BoxData[{
    \(\(del = 2  \[Pi]/30;\)\), "\[IndentingNewLine]", 
    \(Animate[\(sframe[0, \[Pi]/2]\)[\[Phi]], {\[Phi], 0, 2  \[Pi] - del, 
        del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Placing Text On a  Curved Surface", "Section"],

Cell["\<\
In some cases, in order to obtain a better fit of the characters to a \
surface, it may be desirable to use the FineGrainLines routine before \
performing the mappings of the characters. This was not necessary in the \
following examples.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Text on a Cylinder", "Subsection"],

Cell["\<\
The following generates one frame of an animation drawing text on the inside \
and outside surfaces of a cylinder. The text is slightly displaced from the \
surface to prevent intersections between the lines of the text and the \
polygons of the cylinder.\
\>", "Text"],

Cell[BoxData[
    \(\(frame[\[Theta]_] := \[IndentingNewLine]Module[{textstring1, 
            textstring2}, \[IndentingNewLine]textstring1 = 
            Text3D["\<Archimedes!        Euclid!        Apollonius!       \
Eudoxus!\>", \ {0, 0, 0}, \ {0.1, \ 1}, \ {0, 0, 0}, 
              Font3D \[Rule] TimesFont3D]; \[IndentingNewLine]textstring2 = 
            Text3D[StringJoin[Table["\<DrawGraphics!   \>", {4}]], {0, 0, 
                0}, \ {0.1, \ 0.7}, \ {\[Pi], 0, 0}, 
              Font3D \[Rule] 
                TimesFont3D]; \[IndentingNewLine]Draw3DItems[\
\[IndentingNewLine]{FaceForm[SurfaceColor[DeepNaplesYellow], 
                SurfaceColor[Gray]], 
              EdgeForm[\(ColorMix[Gray, Black]\)[
                  0.1]], \[IndentingNewLine]ParametricDraw3D[{5 
                     Cos[\[Theta]1], 5  Sin[\[Theta]1], z}, {\[Theta]1, 0, 
                  2  \[Pi]}, {z, \(-1\), 1}, 
                PlotPoints \[Rule] {41, 
                    5}], \[IndentingNewLine]AbsoluteThickness[
                1], \[IndentingNewLine]textstring1 /. 
                DrawingTransform3D[5.03  Cos[#1 - \[Theta]] &, 
                  5.03  Sin[#1 - \[Theta]] &, #2 &], \
\[IndentingNewLine]RoyalBlue, 
              textstring2 /. 
                DrawingTransform3D[4.97  Cos[#1 - \[Theta]] &, 
                  4.97  Sin[#1 - \[Theta]] &, #2 &]}, \
\[IndentingNewLine]NeutralLighting[0.3, 0.5, 0.1, 
              40  \[Degree]], \[IndentingNewLine]Boxed \[Rule] 
              False, \[IndentingNewLine]PlotRange \[Rule] {{\(-5.2\), 
                  5.2}, {\(-5.2\), 5.2}, {\(-1.2\), 
                  1.2}}, \[IndentingNewLine]Background \[Rule] 
              PowderBlue, \[IndentingNewLine]ViewPoint -> {1.718, \ \
\(-2.747\), \ 0.975}, \[IndentingNewLine]ImageSize \[Rule] 
              500]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(del = 2  \[Pi]/50;\)\), "\[IndentingNewLine]", 
    \(Animate[
      frame[\[Theta]], {\[Theta], 0, 2  \[Pi] - del, 
        del}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51887 .3341 m
.51553 .33088 L
s
.51553 .33088 m
.51219 .33086 L
s
.52055 .33411 m
.51553 .33088 L
s
.51219 .33086 m
.50717 .33401 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50384 .33075 m
.49716 .33062 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.548 .33055 m
.56393 .33016 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51146 .33856 m
.52305 .33862 L
s
.5363 .34079 m
.53961 .33849 L
s
.53961 .33849 m
.54291 .33844 L
s
.53465 .34081 m
.53961 .33849 L
s
.49328 .33824 m
.50484 .33848 L
s
.54291 .33844 m
.54788 .3406 L
s
.53134 .34535 m
.53465 .34081 L
s
.533 .34533 m
.5363 .34079 L
s
.54788 .3406 m
.5512 .34503 L
s
.47516 .33763 m
.48668 .33805 L
s
.52969 .35213 m
.53134 .34535 L
s
.53135 .35212 m
.533 .34533 L
s
.56272 .33792 m
.56439 .34237 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56602 .34005 m
.5693 .33767 L
s
.43947 .31975 m
.45078 .32055 L
s
.56439 .34237 m
.56602 .34005 L
s
.52969 .35213 m
.52969 .35665 L
s
.53135 .35212 m
.53135 .35664 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56276 .34695 m
.56439 .34237 L
s
.5693 .33767 m
.57586 .33738 L
s
.56272 .33792 m
.56276 .34695 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57586 .33738 m
.57915 .33948 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49981 .36325 m
.49988 .33839 L
s
.49816 .36321 m
.49823 .33836 L
s
.4815 .3855 m
.48174 .33789 L
s
.47984 .38544 m
.48009 .33783 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51807 .37026 m
.51808 .33861 L
s
.5164 .37025 m
.51643 .3386 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52969 .35665 m
.53136 .36343 L
s
.53135 .35664 m
.53302 .36342 L
s
.57915 .33948 m
.58081 .34166 L
s
.58081 .34166 m
.58086 .34844 L
s
.45552 .33664 m
.4604 .33918 L
s
.4604 .33918 m
.46364 .34387 L
s
.54959 .35863 m
.55126 .36086 L
s
.54794 .36093 m
.54959 .35863 L
s
.45552 .33664 m
.45877 .33908 L
s
.45877 .33908 m
.462 .34378 L
s
.45227 .33644 m
.45552 .33664 L
s
.53136 .36343 m
.53469 .36794 L
s
.53302 .36342 m
.53635 .36792 L
s
.46364 .34387 m
.46522 .35074 L
s
.54794 .36093 m
.54961 .36316 L
s
.462 .34378 m
.46359 .35065 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.449 .33849 m
.45227 .33644 L
s
.55126 .36086 m
.55126 .36312 L
s
.57922 .34852 m
.58084 .34618 L
s
.59382 .33639 m
.59547 .33855 L
s
.59222 .33875 m
.59382 .33639 L
s
.49814 .36775 m
.49981 .36325 L
s
.49648 .36771 m
.49816 .36321 L
s
.59222 .33875 m
.59386 .34091 L
s
.57595 .35094 m
.57922 .34852 L
s
.56775 .35581 m
.57595 .35094 L
s
.56447 .3582 m
.56775 .35581 L
s
.54796 .36773 m
.55126 .36312 L
s
.57923 .35078 m
.58086 .34844 L
s
.56283 .36052 m
.56447 .3582 L
s
.53469 .36794 m
.53967 .37015 L
s
.53635 .36792 m
.53967 .37015 L
s
.57597 .3532 m
.57923 .35078 L
s
.59386 .34091 m
.59547 .33855 L
s
.56777 .35808 m
.57597 .3532 L
s
.56448 .36047 m
.56777 .35808 L
s
.56283 .36052 m
.56285 .36506 L
s
.46519 .35527 m
.46522 .35074 L
s
.44571 .3428 m
.449 .33849 L
s
.51142 .37021 m
.51807 .37026 L
s
.56284 .36279 m
.56448 .36047 L
s
.46355 .35519 m
.46359 .35065 L
s
.49316 .36991 m
.49814 .36775 L
s
.54465 .37007 m
.54796 .36773 L
s
.49316 .36991 m
.49648 .36771 L
s
.53967 .37015 m
.54465 .37007 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48161 .36276 m
.48489 .3674 L
s
.56285 .36506 m
.56452 .36727 L
s
.4635 .36199 m
.46519 .35527 L
s
.48985 .36982 m
.49316 .36991 L
s
.46186 .36191 m
.46355 .35519 L
s
.48489 .3674 m
.48985 .36982 L
s
.56452 .36727 m
.56783 .36942 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45137 .35908 m
.45171 .35722 L
s
.45322 .35805 m
.45335 .35735 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44547 .36778 m
.44592 .32022 L
s
.44385 .36767 m
.44431 .32011 L
s
.43447 .33518 m
.43608 .3353 L
s
.43123 .33718 m
.43447 .33518 L
s
.43284 .33731 m
.43447 .33518 L
s
.5164 .38161 m
.51806 .3839 L
s
.51473 .38388 m
.5164 .38161 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59257 .37963 m
.59396 .35224 L
s
.59396 .35224 m
.59584 .37944 L
s
.56783 .36942 m
.57442 .36916 L
s
.58094 .35977 m
.581 .36885 L
s
.57933 .36439 m
.58094 .35977 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46019 .36637 m
.4635 .36199 L
s
.5777 .36674 m
.57933 .36439 L
s
.57933 .36439 m
.581 .36885 L
s
.45855 .36628 m
.46186 .36191 L
s
.51639 .38617 m
.51806 .3839 L
s
.57442 .36916 m
.5777 .36674 L
s
.51473 .38388 m
.51639 .38617 L
s
.43118 .34171 m
.43284 .33731 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42957 .34158 m
.43123 .33718 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45526 .36837 m
.46019 .36637 L
s
.45526 .36837 m
.45855 .36628 L
s
.431 .35761 m
.43118 .34171 L
s
.42642 .33677 m
.42957 .34158 L
s
.42325 .33422 m
.42642 .33677 L
s
.41847 .33378 m
.42325 .33422 L
s
.42934 .36204 m
.42957 .34158 L
s
.45199 .36818 m
.45526 .36837 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47488 .38526 m
.4815 .3855 L
s
.59408 .36586 m
.5942 .37954 L
s
.44554 .36095 m
.44875 .36571 L
s
.44875 .36571 m
.45199 .36818 L
s
.41526 .33574 m
.41847 .33378 L
s
.41368 .33559 m
.41847 .33378 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43898 .36733 m
.44547 .36778 L
s
.41362 .34013 m
.41526 .33574 L
s
.41203 .33997 m
.41368 .33559 L
s
.42934 .36204 m
.431 .35761 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41824 .35196 m
.42781 .35508 L
s
.42781 .35508 m
.42939 .35748 L
s
.59257 .37963 m
.59424 .38411 L
s
.41356 .34467 m
.41362 .34013 L
s
.59424 .38411 m
.59584 .37944 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41197 .34452 m
.41203 .33997 L
s
.4277 .36419 m
.42934 .36204 L
s
.41356 .34467 m
.41508 .34938 L
s
.41508 .34938 m
.41824 .35196 L
s
.4135 .34923 m
.41824 .35196 L
s
.41197 .34452 m
.4135 .34923 L
s
.42446 .3662 m
.4277 .36419 L
s
.41806 .36564 m
.42446 .3662 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40707 .35434 m
.40737 .35366 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41337 .35835 m
.41496 .3585 L
s
.41493 .36078 m
.41496 .3585 L
s
.41334 .36063 m
.41337 .35835 L
s
.4149 .36306 m
.41806 .36564 L
s
.41334 .36063 m
.4149 .36306 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38099 .32948 m
.39177 .33087 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3866 .36231 m
.38713 .33029 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38505 .36212 m
.38559 .33009 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39757 .35899 m
.39917 .35688 L
s
.39917 .35688 m
.4007 .35934 L
s
.40067 .36163 m
.4007 .35934 L
s
0 0 0 r
.36355 .31922 m
.36436 .31935 L
s
.255 .412 .882 r
.39906 .36375 m
.40067 .36163 L
s
.39757 .35899 m
.3991 .36146 L
s
.39437 .36322 m
.39906 .36375 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38683 .34855 m
.38826 .35561 L
s
.39129 .36057 m
.39437 .36322 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38826 .35561 m
.39129 .36057 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37152 .34652 m
.37186 .3282 L
s
.37 .3463 m
.37034 .32798 L
s
.38043 .36153 m
.3866 .36231 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36729 .32981 m
.37022 .33484 L
s
.36284 .32683 m
.36729 .32981 L
s
.36548 .34564 m
.37608 .34715 L
s
.35986 .32636 m
.36284 .32683 L
s
.68469 .3265 m
.68565 .37486 L
s
.35684 .32817 m
.35986 .32636 L
s
.35537 .32793 m
.35986 .32636 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3538 .33227 m
.35684 .32817 L
s
.35232 .33203 m
.35537 .32793 L
s
.37096 .37645 m
.37122 .36261 L
s
.36957 .36932 m
.37122 .36261 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68617 .32626 m
.68715 .37464 L
s
.68021 .3272 m
.69502 .32478 L
s
.35223 .33662 m
.3538 .33227 L
s
.69502 .32478 m
.69799 .32656 L
s
.69502 .32478 m
.69945 .32631 L
s
.35076 .33638 m
.35232 .33203 L
s
.36645 .37351 m
.36957 .36932 L
s
.36957 .36932 m
.37096 .37645 L
s
.35061 .34329 m
.35223 .33662 L
s
.69799 .32656 m
.701 .33065 L
s
.34914 .34304 m
.35076 .33638 L
s
.69945 .32631 m
.70245 .33039 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36189 .37518 m
.36645 .37351 L
s
.35037 .35483 m
.35061 .34329 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.701 .33065 m
.70255 .33499 L
s
.3489 .35458 m
.34914 .34304 L
s
.70245 .33039 m
.704 .33473 L
s
.35889 .37474 m
.36189 .37518 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68114 .37552 m
.69605 .37326 L
s
.70255 .33499 m
.70415 .34166 L
s
.35037 .35483 m
.35169 .36201 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35595 .37197 m
.35889 .37474 L
s
.35446 .37174 m
.35889 .37474 L
s
.704 .33473 m
.7056 .3414 L
s
.3489 .35458 m
.35022 .36177 L
s
.35169 .36201 m
.35308 .36687 L
s
.35308 .36687 m
.35595 .37197 L
s
.7109 .32186 m
.72076 .31986 L
s
.35022 .36177 m
.3516 .36664 L
s
.3516 .36664 m
.35446 .37174 L
s
.33368 .3217 m
.33866 .35514 L
s
.32725 .35301 m
.33368 .3217 L
s
.70415 .34166 m
.70441 .35323 L
s
.7056 .3414 m
.70586 .35297 L
s
.32866 .35328 m
.33352 .32862 L
s
.71515 .32101 m
.71592 .35343 L
s
.33435 .35436 m
.343 .35591 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69605 .37326 m
.69894 .37046 L
s
.69605 .37326 m
.70041 .37022 L
s
.71656 .32073 m
.71734 .35316 L
s
.70312 .36043 m
.70441 .35323 L
s
.70457 .36018 m
.70586 .35297 L
s
.69894 .37046 m
.70176 .36533 L
s
.70176 .36533 m
.70312 .36043 L
s
.70041 .37022 m
.70322 .36508 L
s
.70322 .36508 m
.70457 .36018 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32245 .31939 m
.32725 .35301 L
s
.717 .33923 m
.71858 .34591 L
s
.71166 .35424 m
.71734 .35316 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31611 .35074 m
.32245 .31939 L
s
.31748 .35103 m
.32227 .32634 L
s
.71858 .34591 m
.7215 .35 L
s
.7215 .35 m
.72435 .35176 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.312 .34985 m
.32164 .35189 L
s
.30879 .31632 m
.31014 .31664 L
s
.72435 .35176 m
.7285 .3509 L
s
.30606 .318 m
.30879 .31632 L
s
.30739 .31832 m
.30879 .31632 L
s
.727 .34653 m
.72844 .34857 L
s
.727 .34653 m
.72832 .34391 L
s
.72832 .34391 m
.72976 .34594 L
s
.30593 .32265 m
.30739 .31832 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72976 .34594 m
.72982 .34827 L
s
.7285 .3509 m
.72982 .34827 L
s
.3046 .32233 m
.30606 .318 L
s
.73991 .31786 m
.74382 .31456 L
s
.7387 .32283 m
.73991 .31786 L
s
.7387 .32283 m
.73882 .32749 L
s
.3055 .33898 m
.30593 .32265 L
s
.74124 .31754 m
.74382 .31456 L
s
.74003 .32251 m
.74124 .31754 L
s
.74003 .32251 m
.74016 .32717 L
s
.30208 .31703 m
.3046 .32233 L
s
.30403 .34334 m
.3046 .32233 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73882 .32749 m
.74028 .33183 L
s
.74382 .31456 m
.74775 .31356 L
s
.74016 .32717 m
.74161 .33152 L
s
.29951 .31404 m
.30208 .31703 L
s
.74028 .33183 m
.74433 .33321 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29561 .31303 m
.29951 .31404 L
s
.74161 .33152 m
.74433 .33321 L
s
.30403 .34334 m
.3055 .33898 L
s
.74775 .31356 m
.75041 .31521 L
s
.30289 .33601 m
.30416 .33866 L
s
.74053 .34118 m
.7406 .34352 L
s
.74053 .34118 m
.74187 .34086 L
s
.29508 .33172 m
.30289 .33601 L
s
.7406 .34352 m
.74199 .34555 L
s
.74187 .34086 m
.74193 .3432 L
s
.29296 .31468 m
.29561 .31303 L
s
.29168 .31433 m
.29561 .31303 L
s
.30264 .34537 m
.30403 .34334 L
s
.74433 .33321 m
.75223 .33359 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75041 .31521 m
.75311 .3192 L
s
.74199 .34555 m
.74471 .34726 L
s
.29993 .34708 m
.30264 .34537 L
s
0 0 0 r
.76474 .30121 m
.76477 .3012 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29155 .31901 m
.29296 .31468 L
s
.29027 .31866 m
.29168 .31433 L
s
.74471 .34726 m
.74996 .34598 L
s
.75426 .31418 m
.75674 .31115 L
s
.75311 .3192 m
.75426 .31418 L
s
.75311 .3192 m
.75371 .3403 L
s
.29469 .3458 m
.29993 .34708 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29256 .32871 m
.29508 .33172 L
s
.29128 .32837 m
.29508 .33172 L
s
.29141 .32369 m
.29155 .31901 L
s
.75554 .31384 m
.75674 .31115 L
s
.75439 .31886 m
.75554 .31384 L
s
.75439 .31886 m
.75486 .33527 L
s
.75674 .31115 m
.758 .3108 L
s
.29013 .32335 m
.29027 .31866 L
s
.29141 .32369 m
.29256 .32871 L
s
.75223 .33359 m
.75358 .3356 L
s
.29013 .32335 m
.29128 .32837 L
s
.74996 .34598 m
.75249 .34298 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76594 .33023 m
.76693 .33098 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29217 .34279 m
.29469 .3458 L
s
.29101 .33776 m
.2923 .33809 L
s
.29223 .34044 m
.2923 .33809 L
s
.75249 .34298 m
.75371 .3403 L
s
.75371 .3403 m
.75486 .33527 L
s
.29095 .34011 m
.29101 .33776 L
s
.29095 .34011 m
.29217 .34279 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76522 .34195 m
.76914 .30754 L
s
.26607 .30428 m
.27436 .30695 L
s
.76646 .34161 m
.76935 .31459 L
s
.27967 .33467 m
.28084 .33738 L
s
.28077 .33974 m
.28084 .33738 L
s
.27837 .33668 m
.27967 .33467 L
s
.27946 .34176 m
.28077 .33974 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27837 .33668 m
.27953 .33939 L
s
.27577 .3407 m
.27946 .34176 L
s
.26974 .33891 m
.27077 .30582 L
s
.26855 .33854 m
.26959 .30544 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76148 .34299 m
.77014 .34055 L
s
.76914 .30754 m
.77497 .33911 L
s
.27342 .33762 m
.27577 .3407 L
s
.77865 .3045 m
.78434 .33615 L
s
.77497 .33911 m
.77865 .3045 L
s
.27116 .33216 m
.27342 .33762 L
s
.27019 .32469 m
.27116 .33216 L
s
.77616 .33875 m
.77888 .31158 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26502 .33743 m
.26974 .33891 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25688 .30348 m
.25897 .30902 L
s
.25897 .30902 m
.25995 .31415 L
s
.25995 .31415 m
.26085 .32166 L
s
.78087 .33727 m
.78776 .335 L
s
.26047 .33355 m
.26085 .32166 L
s
.25364 .29989 m
.25688 .30348 L
s
.25577 .30307 m
.25784 .30862 L
s
.25784 .30862 m
.25881 .31376 L
s
.25881 .31376 m
.25971 .32127 L
s
.25933 .33317 m
.25971 .32127 L
s
.25364 .29989 m
.25577 .30307 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2591 .34032 m
.26047 .33355 L
s
.243 .29569 m
.25364 .29989 L
s
.25796 .33994 m
.25933 .33317 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25781 .34472 m
.2591 .34032 L
s
.79355 .30642 m
.79555 .30084 L
s
.79262 .31159 m
.79355 .30642 L
s
.79176 .31913 m
.79262 .31159 L
s
.25667 .34434 m
.25796 .33994 L
s
.79176 .31913 m
.79215 .33106 L
s
.79371 .31118 m
.79464 .30601 L
s
.79286 .31873 m
.79371 .31118 L
s
.79464 .30601 m
.79663 .30043 L
s
.79555 .30084 m
.79867 .29721 L
s
.25539 .34875 m
.25781 .34472 L
s
.79286 .31873 m
.79325 .33067 L
s
.79663 .30043 m
.79867 .29721 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25427 .34837 m
.25667 .34434 L
s
.79215 .33106 m
.79349 .33785 L
s
.79325 .33067 m
.79459 .33746 L
s
.25197 .35001 m
.25539 .34875 L
s
.25197 .35001 m
.25427 .34837 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79867 .29721 m
.80076 .29636 L
s
.79349 .33785 m
.79475 .34225 L
s
.80076 .29636 m
.80394 .29746 L
s
.79459 .33746 m
.79584 .34186 L
s
.79475 .34225 m
.79709 .34628 L
s
.79584 .34186 m
.79816 .34588 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24126 .34609 m
.25197 .35001 L
s
.2444 .34728 m
.24612 .29697 L
s
.24546 .34768 m
.24718 .29739 L
s
.80394 .29746 m
.80614 .30138 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79709 .34628 m
.80038 .34751 L
s
.79816 .34588 m
.80038 .34751 L
s
.80689 .29377 m
.80757 .31294 L
s
.8035 .31463 m
.81055 .31166 L
s
.80589 .29421 m
.80656 .31337 L
s
.80038 .34751 m
.8025 .34671 L
s
.81278 .29112 m
.81932 .28794 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8025 .34671 m
.80553 .34309 L
s
.80553 .34309 m
.8074 .33745 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80816 .32979 m
.80867 .34429 L
s
.8074 .33745 m
.80816 .32979 L
s
.8074 .33745 m
.80867 .34429 L
s
.81562 .28977 m
.81685 .32355 L
s
.81656 .28931 m
.81779 .32312 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81399 .32484 m
.81779 .32312 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81726 .3086 m
.81845 .31541 L
s
.81845 .31541 m
.82047 .31938 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82047 .31938 m
.82237 .32092 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82237 .32092 m
.82504 .31959 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82752 .3059 m
.82756 .3069 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82398 .31517 m
.82495 .31715 L
s
.82398 .31517 m
.82476 .31228 L
s
.82476 .31228 m
.82573 .31426 L
s
.82504 .31959 m
.82582 .3167 L
s
.82573 .31426 m
.82582 .3167 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83078 .28911 m
.8314 .28377 L
s
.8314 .28377 m
.83368 .27989 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83078 .28911 m
.83096 .29398 L
s
.83096 .29398 m
.83196 .29838 L
s
.83159 .28863 m
.8322 .28329 L
s
.83159 .28863 m
.83177 .2935 L
s
.21233 .28526 m
.21322 .28331 L
s
.21252 .28039 m
.21322 .28331 L
s
.8322 .28329 m
.83368 .27989 L
s
.21164 .28234 m
.21252 .28039 L
s
.83177 .2935 m
.83276 .29791 L
s
.21164 .28234 m
.21233 .28526 L
s
.83368 .27989 m
.83598 .27842 L
s
.83196 .29838 m
.83443 .2994 L
s
.83276 .29791 m
.83443 .2994 L
s
.83233 .30815 m
.83243 .3106 L
s
.83233 .30815 m
.83313 .30768 L
s
.21153 .32732 m
.21186 .29745 L
s
.20994 .3264 m
.21186 .29745 L
s
.83243 .3106 m
.83332 .31258 L
s
.83313 .30768 m
.83323 .31013 L
s
.83598 .27842 m
.83757 .27987 L
s
.83443 .2994 m
.83907 .29898 L
s
.83332 .31258 m
.835 .3141 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21073 .32686 m
.2113 .31213 L
s
.83757 .27987 m
.83922 .28377 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.835 .3141 m
.83807 .31222 L
s
.21054 .33179 m
.21153 .32732 L
s
.20566 .2784 m
.20629 .28134 L
s
.206 .28869 m
.20629 .28134 L
s
.20994 .3264 m
.21054 .33179 L
s
.83922 .28377 m
.83975 .27838 L
s
.83922 .28377 m
.84009 .30587 L
s
.20435 .27495 m
.20566 .2784 L
s
.83975 .27838 m
.84106 .27493 L
s
.20528 .2882 m
.20609 .28624 L
s
.20518 .29065 m
.206 .28869 L
s
.83994 .28328 m
.84046 .27788 L
s
.83994 .28328 m
.84062 .30047 L
s
.84046 .27788 m
.84106 .27493 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84244 .25628 m
.84692 .25263 L
s
.20163 .27293 m
.20435 .27495 L
s
.83907 .29898 m
.8399 .30095 L
s
.84106 .27493 m
.84176 .27443 L
s
.20377 .28967 m
.20528 .2882 L
s
.83807 .31222 m
.83946 .30881 L
s
.20367 .29213 m
.20518 .29065 L
s
.2046 .30541 m
.20552 .30097 L
s
.20513 .31082 m
.20552 .30097 L
s
.83946 .30881 m
.84009 .30587 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84009 .30587 m
.84062 .30047 L
s
.20018 .29212 m
.20377 .28967 L
s
.84441 .25472 m
.84648 .30645 L
s
.20008 .29459 m
.20367 .29213 L
s
.2046 .30541 m
.20513 .31082 L
s
.20379 .30739 m
.2046 .30541 L
s
.84505 .2542 m
.84712 .30596 L
s
.20022 .27437 m
.20163 .27293 L
s
.20229 .3089 m
.20379 .30739 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19947 .27632 m
.20022 .27437 L
s
.19959 .30696 m
.20229 .3089 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19904 .27089 m
.19947 .27632 L
s
.19864 .28074 m
.19947 .27632 L
s
.19864 .28074 m
.19904 .27089 L
s
.84603 .27877 m
.8471 .27282 L
s
.19878 .2936 m
.20018 .29212 L
s
.19868 .29607 m
.20008 .29459 L
s
.84449 .30791 m
.84712 .30596 L
s
.8471 .27282 m
.84822 .26932 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85048 .28711 m
.85067 .29158 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19805 .29557 m
.19878 .2936 L
s
.84822 .26932 m
.84941 .26828 L
s
.19839 .3035 m
.19959 .30696 L
s
.19795 .29805 m
.19868 .29607 L
s
.84683 .29853 m
.84829 .3025 L
s
.19785 .30053 m
.19805 .29557 L
s
.19785 .30053 m
.19839 .3035 L
s
.84941 .26828 m
.85067 .26971 L
s
.84941 .26828 m
.85123 .26919 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84829 .3025 m
.84962 .30399 L
s
.85067 .26971 m
.85199 .27362 L
s
.19362 .26869 m
.19454 .27468 L
s
.85123 .26919 m
.85253 .2731 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85179 .3194 m
.85198 .32391 L
s
.5 Mabswid
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84962 .30399 m
.85082 .303 L
s
.19211 .26463 m
.19362 .26869 L
s
.85199 .27362 m
.85284 .28055 L
s
.85082 .303 m
.85188 .29951 L
s
.85082 .303 m
.85245 .299 L
s
.19373 .29454 m
.19383 .29206 L
s
.19337 .28906 m
.19383 .29206 L
s
.85253 .2731 m
.85338 .28004 L
s
.1924 .29852 m
.19373 .29454 L
s
.19271 .29104 m
.19337 .28906 L
s
.19108 .26357 m
.19211 .26463 L
s
.85284 .28055 m
.85304 .28553 L
s
.85188 .29951 m
.8528 .29351 L
s
.19271 .29104 m
.19317 .29404 L
s
.8528 .29351 m
.85304 .28553 L
s
.85338 .28004 m
.85358 .28502 L
s
.85245 .299 m
.85335 .293 L
s
.18999 .26499 m
.19108 .26357 L
s
.1895 .26446 m
.19108 .26357 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85335 .293 m
.85358 .28502 L
s
0 0 0 r
.1831 .24895 m
.18459 .25075 L
s
.255 .412 .882 r
.19121 .30001 m
.1924 .29852 L
s
.18882 .26891 m
.18999 .26499 L
s
.18964 .29849 m
.19121 .30001 L
s
.8558 .26195 m
.85892 .25817 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18836 .26838 m
.1895 .26446 L
s
.18805 .27587 m
.18882 .26891 L
s
.18875 .29496 m
.18964 .29849 L
s
.18826 .29445 m
.18964 .29849 L
s
.85719 .26034 m
.85938 .31304 L
s
.18759 .27534 m
.18836 .26838 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85764 .2598 m
.85983 .31254 L
s
0 0 0 r
.86224 .25203 m
.86314 .24782 L
s
.86234 .25424 m
.86246 .25249 L
s
.255 .412 .882 r
.18799 .28891 m
.18875 .29496 L
s
.18784 .28088 m
.18805 .27587 L
s
0 0 0 r
.86246 .25249 m
.86314 .24782 L
s
.255 .412 .882 r
.18784 .28088 m
.18799 .28891 L
s
.18753 .2884 m
.18826 .29445 L
s
.18738 .28035 m
.18759 .27534 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18231 .30067 m
.18317 .28022 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18231 .30067 m
.18248 .30086 L
s
.255 .412 .882 r
.18738 .28035 m
.18753 .2884 L
s
0 0 0 r
.18231 .28937 m
.18312 .28013 L
s
.86314 .24782 m
.86393 .2467 L
s
.255 .412 .882 r
.18383 .25437 m
.18649 .25819 L
s
.85878 .28734 m
.85986 .29133 L
s
.85797 .31455 m
.85983 .31254 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86402 .29419 m
.86427 .29549 L
s
.255 .412 .882 r
.18381 .29178 m
.18529 .25656 L
s
.18343 .29126 m
.18491 .25601 L
s
.86049 .25599 m
.86287 .25214 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85986 .29133 m
.8612 .29228 L
s
.86157 .25435 m
.86274 .28207 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8612 .29228 m
.86197 .29124 L
s
.86191 .2538 m
.86308 .28154 L
s
.18234 .28968 m
.18381 .29178 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86197 .29124 m
.8626 .28766 L
s
.86197 .29124 m
.86295 .28713 L
s
0 0 0 r
.86695 .29225 m
.86704 .2918 L
s
.255 .412 .882 r
.18062 .24826 m
.18252 .25216 L
s
.18269 .309 m
.18318 .30697 L
s
.1829 .30392 m
.18318 .30697 L
s
.8626 .28766 m
.86274 .28207 L
s
.18242 .30594 m
.1829 .30392 L
s
.86295 .28713 m
.86308 .28154 L
s
0 0 0 r
.86704 .2918 m
.86706 .29129 L
s
.255 .412 .882 r
.18242 .30594 m
.18269 .309 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18047 .27835 m
.18165 .25049 L
s
.18019 .27781 m
.18138 .24994 L
s
.86402 .24992 m
.86565 .246 L
s
0 0 0 r
.17596 .24011 m
.17666 .23849 L
s
.255 .412 .882 r
.86478 .24824 m
.86629 .28382 L
s
0 0 0 r
.8692 .23907 m
.86948 .2359 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17998 .2829 m
.18047 .27835 L
s
.86501 .24768 m
.86653 .28329 L
s
0 0 0 r
.86925 .24024 m
.86948 .2359 L
s
.255 .412 .882 r
.17971 .28236 m
.18019 .27781 L
s
0 0 0 r
.86983 .20468 m
.86893 .20887 L
s
.255 .412 .882 r
.1791 .28384 m
.17998 .2829 L
s
0 0 0 r
.17525 .24621 m
.17596 .24011 L
s
.255 .412 .882 r
.86553 .28543 m
.86653 .28329 L
s
0 0 0 r
.86948 .2359 m
.86986 .23474 L
s
.255 .412 .882 r
.1791 .28384 m
.17971 .28236 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17861 .24206 m
.17975 .24602 L
s
0 0 0 r
.86986 .23474 m
.87035 .23721 L
s
.17436 .2885 m
.1745 .2888 L
s
.255 .412 .882 r
.17864 .28277 m
.1791 .28384 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8667 .29969 m
.86684 .29661 L
s
.8667 .29969 m
.86706 .30173 L
s
0 0 0 r
.87035 .23721 m
.87095 .24333 L
s
.87121 .28564 m
.87169 .28685 L
s
.255 .412 .882 r
.17814 .27859 m
.17864 .28277 L
s
0 0 0 r
.1745 .2686 m
.17455 .2728 L
s
.17418 .2759 m
.17455 .2728 L
s
.255 .412 .882 r
.86684 .29661 m
.86718 .29864 L
s
0 0 0 r
.17407 .28376 m
.17436 .2885 L
s
.17415 .2717 m
.1745 .2686 L
s
.87116 .28451 m
.87169 .28685 L
s
.255 .412 .882 r
.86706 .30173 m
.86718 .29864 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1769 .29807 m
.1792 .24433 L
s
.17674 .29754 m
.17904 .24376 L
s
0 0 0 r
.17399 .27535 m
.17407 .28376 L
s
.17399 .27535 m
.17415 .2717 L
s
.17478 .23186 m
.17417 .22778 L
s
.255 .412 .882 r
.86683 .25082 m
.86689 .24459 L
s
.86683 .25082 m
.86701 .25903 L
s
.178 .27239 m
.17814 .27859 L
s
.86701 .25903 m
.86723 .26414 L
s
.86697 .25026 m
.86701 .24402 L
s
.86697 .25026 m
.86716 .25848 L
s
.86723 .26414 m
.86771 .27127 L
s
0 0 0 r
.87206 .28577 m
.87169 .28685 L
s
.255 .412 .882 r
.86716 .25848 m
.86738 .26359 L
s
.86738 .26359 m
.86785 .27073 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86701 .24402 m
.86711 .24033 L
s
.86689 .24459 m
.86711 .24033 L
s
0 0 0 r
.86938 .20708 m
.8727 .28359 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87224 .28101 m
.87206 .28577 L
s
.255 .412 .882 r
.86771 .27127 m
.8682 .27531 L
s
.86711 .24033 m
.86728 .23919 L
s
.86785 .27073 m
.86832 .27477 L
s
0 0 0 r
.87222 .27257 m
.87224 .28101 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87134 .22541 m
.8711 .22892 L
s
.255 .412 .882 r
.17631 .29595 m
.1769 .29807 L
s
0 0 0 r
.87412 .28922 m
.8747 .30144 L
s
.87316 .2814 m
.8727 .28359 L
s
.87366 .27833 m
.87421 .29023 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86832 .27477 m
.86865 .27625 L
s
.8682 .27531 m
.86865 .27625 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86951 .20648 m
.87283 .28304 L
s
.255 .412 .882 r
.86728 .23919 m
.86756 .24004 L
s
.17766 .24576 m
.17779 .23949 L
s
.17739 .25403 m
.17766 .24576 L
s
.86756 .24004 m
.86784 .24404 L
s
.17717 .25917 m
.17739 .25403 L
s
.86865 .27625 m
.86889 .27462 L
s
.17761 .2452 m
.17777 .23892 L
s
.17733 .25347 m
.17761 .2452 L
s
.17677 .26634 m
.17717 .25917 L
s
.17779 .23949 m
.17786 .23521 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17101 .30679 m
.17437 .22953 L
s
.1711 .30732 m
.17446 .23011 L
s
.255 .412 .882 r
.17711 .25861 m
.17733 .25347 L
s
0 0 0 r
.17262 .26982 m
.17215 .27608 L
s
.17405 .22543 m
.17425 .2213 L
s
.255 .412 .882 r
.17673 .26579 m
.17711 .25861 L
s
.17777 .23892 m
.17786 .23521 L
s
.17647 .27041 m
.17677 .26634 L
s
0 0 0 r
.17144 .30891 m
.17101 .30679 L
s
.255 .412 .882 r
.17786 .23521 m
.17788 .23406 L
s
.17868 .2155 m
.17916 .21138 L
s
.17644 .26986 m
.17673 .26579 L
s
0 0 0 r
.87202 .24284 m
.87228 .24801 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86855 .26319 m
.8687 .26522 L
s
.86848 .26006 m
.86855 .26319 L
s
.86889 .27094 m
.86889 .27462 L
s
0 0 0 r
.87127 .22717 m
.87366 .27833 L
s
.255 .412 .882 r
.86848 .26006 m
.86862 .26208 L
s
0 0 0 r
.17215 .27608 m
.17185 .27812 L
s
.17231 .26423 m
.17407 .22366 L
s
.255 .412 .882 r
.86873 .26466 m
.86889 .27094 L
s
.17788 .23406 m
.17783 .23549 L
s
0 0 0 r
.17233 .26366 m
.1741 .22307 L
s
.255 .412 .882 r
.86862 .26208 m
.86873 .26466 L
s
.1763 .27135 m
.17647 .27041 L
s
.1763 .27135 m
.17644 .26986 L
s
0 0 0 r
.87066 .21833 m
.87119 .22187 L
s
.255 .412 .882 r
.17783 .23549 m
.17771 .2395 L
s
0 0 0 r
.17185 .27812 m
.1718 .27702 L
s
.255 .412 .882 r
.8674 .23231 m
.86756 .2369 L
s
.8674 .23231 m
.86784 .24264 L
s
.17632 .27025 m
.1763 .27135 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87122 .22775 m
.87412 .28922 L
s
.1718 .27702 m
.17197 .2722 L
s
.1718 .27702 m
.17198 .27165 L
s
.255 .412 .882 r
.86756 .2369 m
.86784 .24264 L
s
.86738 .23374 m
.86756 .2369 L
s
.8671 .23 m
.86738 .23374 L
s
0 0 0 r
.17197 .2722 m
.17231 .26423 L
s
.255 .412 .882 r
.17649 .26655 m
.17632 .27025 L
s
0 0 0 r
.87088 .21951 m
.8747 .30144 L
s
.17198 .27165 m
.17233 .26366 L
s
.255 .412 .882 r
.86662 .22769 m
.8671 .23 L
s
0 0 0 r
.17461 .21894 m
.17566 .21479 L
s
.255 .412 .882 r
.86834 .25503 m
.86851 .25818 L
s
.86851 .25818 m
.86873 .26337 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17656 .26749 m
.17889 .21315 L
s
.17649 .26804 m
.17882 .21373 L
s
.5 Mabswid
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17649 .26655 m
.17682 .26024 L
s
.86845 .25762 m
.86862 .26078 L
s
.86808 .25131 m
.86834 .25503 L
s
.86873 .26337 m
.86879 .26542 L
s
.86819 .2539 m
.86845 .25762 L
s
.86729 .24328 m
.86808 .25131 L
s
.86875 .26692 m
.86879 .26542 L
s
.8674 .24588 m
.86819 .2539 L
s
.17876 .22771 m
.17862 .22829 L
s
.17683 .26583 m
.17649 .26804 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17879 .22973 m
.17876 .22771 L
s
.86643 .22913 m
.86662 .22769 L
s
.86832 .26471 m
.86875 .26692 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86638 .23116 m
.86643 .22913 L
s
.86688 .23954 m
.86729 .24328 L
s
.86699 .24214 m
.8674 .24588 L
s
.17794 .2526 m
.17825 .2455 L
s
.86671 .23897 m
.86638 .23116 L
s
.86688 .23954 m
.8666 .23636 L
s
.86699 .24214 m
.86671 .23897 L
s
0 0 0 r
.17235 .27092 m
.17288 .2687 L
s
.255 .412 .882 r
.86793 .26098 m
.86832 .26471 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86766 .25781 m
.86793 .26098 L
s
.86727 .25202 m
.86766 .25781 L
s
.86766 .25781 m
.86772 .26249 L
s
0 0 0 r
.1765 .21242 m
.17841 .20826 L
s
.255 .412 .882 r
.86727 .25202 m
.86772 .26249 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17794 .25292 m
.17794 .2526 L
s
.17806 .25319 m
.1784 .24525 L
s
0 0 0 r
.17288 .2687 m
.17514 .21657 L
s
.17273 .26925 m
.17499 .21716 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17498 .26312 m
.17725 .21064 L
s
.17161 .29233 m
.17192 .28802 L
s
.17159 .29555 m
.17161 .29233 L
s
.17192 .28802 m
.1719 .29124 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17526 .26256 m
.17752 .21004 L
s
.1719 .29124 m
.17159 .29555 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17423 .26479 m
.17526 .26256 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17574 .25125 m
.176 .25767 L
s
.17974 .20589 m
.18252 .20175 L
s
.17909 .2456 m
.18087 .20411 L
s
.176 .25767 m
.17679 .25978 L
s
.17949 .24504 m
.18126 .20352 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17679 .25978 m
.17748 .25866 L
s
.17748 .25866 m
.17838 .25375 L
s
.17748 .25866 m
.17877 .25319 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17838 .25375 m
.17909 .2456 L
s
.17949 .24504 m
.18 .25151 L
s
.17877 .25319 m
.17949 .24504 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18639 .24757 m
.18704 .23181 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18436 .19939 m
.18802 .19527 L
s
.255 .412 .882 r
.18534 .2453 m
.18625 .24012 L
s
0 0 0 r
.18 .25151 m
.18116 .25366 L
s
.255 .412 .882 r
.18625 .24012 m
.18703 .23182 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18116 .25366 m
.18211 .25255 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1841 .23941 m
.18586 .19762 L
s
.255 .412 .882 r
.18739 .23448 m
.18752 .23141 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18462 .23885 m
.18638 .19703 L
s
.18211 .25255 m
.18326 .24761 L
s
.18211 .25255 m
.18378 .24706 L
s
.18326 .24761 m
.1841 .23941 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18378 .24706 m
.18462 .23885 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19051 .20377 m
.19209 .19499 L
s
.18942 .21579 m
.19051 .20377 L
s
.19209 .19499 m
.19423 .18944 L
s
.1891 .22344 m
.18942 .21579 L
s
.19114 .20319 m
.19274 .19441 L
s
.19003 .21522 m
.19114 .20319 L
s
.19274 .19441 m
.19423 .18944 L
s
.18972 .22288 m
.19003 .21522 L
s
.1891 .22344 m
.18924 .23439 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19423 .18944 m
.19561 .18828 L
s
.18972 .22288 m
.18987 .23383 L
s
.18972 .22288 m
.19802 .21617 L
s
.19561 .18828 m
.19762 .19038 L
s
.18924 .23439 m
.19019 .24098 L
s
.18987 .23383 m
.19084 .24043 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19762 .19038 m
.1988 .19692 L
s
.19019 .24098 m
.19202 .2432 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19084 .24043 m
.19202 .2432 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19202 .2432 m
.19412 .24157 L
s
.19679 .22832 m
.19726 .21673 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19771 .2239 m
.19802 .21617 L
s
.19412 .24157 m
.19573 .23661 L
s
.19573 .23661 m
.19679 .22832 L
s
.19664 .23219 m
.19771 .2239 L
s
.19573 .23661 m
.19664 .23219 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20525 .19242 m
.20729 .18358 L
s
.20394 .20457 m
.20525 .19242 L
s
.20729 .18358 m
.21012 .17804 L
s
.20611 .19186 m
.20817 .18302 L
s
.20364 .21232 m
.20394 .20457 L
s
.20817 .18302 m
.21012 .17804 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20479 .20402 m
.20611 .19186 L
s
.20448 .21177 m
.20479 .20402 L
s
.20364 .21232 m
.20402 .22343 L
s
.21012 .17804 m
.21196 .17693 L
s
.20448 .21177 m
.20488 .22289 L
s
.21196 .17693 m
.21369 .17969 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20402 .22343 m
.20545 .23016 L
s
.20488 .22289 m
.20633 .22962 L
s
.21369 .17969 m
.21533 .18635 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21578 .17471 m
.21978 .17252 L
s
.21261 .25695 m
.21578 .17471 L
s
.20545 .23016 m
.20798 .23248 L
s
.2136 .25644 m
.21676 .17416 L
s
.20633 .22962 m
.20798 .23248 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20798 .23248 m
.20983 .23143 L
s
.20983 .23143 m
.21188 .22646 L
s
.21188 .22646 m
.21413 .21758 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2246 .18151 m
.22707 .17264 L
s
.22308 .19378 m
.2246 .18151 L
s
.22707 .17264 m
.23057 .16714 L
s
.22568 .18098 m
.22818 .17211 L
s
.22416 .19326 m
.22568 .18098 L
s
.22279 .20162 m
.22308 .19378 L
s
.2097 .25846 m
.2136 .25644 L
s
.22818 .17211 m
.23057 .16714 L
s
.22387 .2011 m
.22416 .19326 L
s
.23057 .16714 m
.23287 .16608 L
s
.22279 .20162 m
.22342 .2129 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22387 .2011 m
.22451 .21239 L
s
.23287 .16608 m
.23625 .16844 L
s
.22342 .2129 m
.22532 .21977 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22451 .21239 m
.22644 .21927 L
s
.255 .412 .882 r
.23314 .20454 m
.23367 .20312 L
s
.23367 .20312 m
.2365 .20083 L
s
0 0 0 r
.23625 .16844 m
.23837 .17526 L
s
.22532 .21977 m
.22855 .22223 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22387 .2011 m
.23767 .19499 L
s
.22644 .21927 m
.22855 .22223 L
s
.255 .412 .882 r
.80726 .20664 m
.808 .20001 L
s
0 0 0 r
.22855 .22223 m
.23203 .22074 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80818 .20024 m
.80818 .20033 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23603 .20736 m
.23645 .19549 L
s
.23738 .2029 m
.23767 .19499 L
s
.24754 .15991 m
.24857 .16729 L
s
.247 .17569 m
.24754 .15991 L
s
.23203 .22074 m
.23454 .21579 L
s
.23454 .21579 m
.23603 .20736 L
s
.23589 .21133 m
.23738 .2029 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23454 .21579 m
.23589 .21133 L
s
.247 .17569 m
.24857 .16729 L
s
.24857 .16729 m
.25001 .16285 L
s
.25001 .16285 m
.25278 .15791 L
s
.25278 .15791 m
.25819 .15595 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25819 .15595 m
.26083 .15894 L
s
.24617 .19948 m
.24761 .19502 L
s
.2459 .20745 m
.24617 .19948 L
s
.24761 .19502 m
.25038 .19009 L
s
.24604 .20346 m
.24747 .199 L
s
.24747 .199 m
.25024 .19406 L
s
.25038 .19009 m
.2574 .17975 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2459 .20745 m
.24706 .21096 L
s
.25024 .19406 m
.25727 .18373 L
s
.26083 .15894 m
.2621 .16243 L
s
.24706 .21096 m
.24956 .21401 L
s
.26171 .17436 m
.2621 .16243 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2574 .17975 m
.2603 .17483 L
s
.25727 .18373 m
.26017 .17881 L
s
.2603 .17483 m
.26184 .17038 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24956 .21401 m
.25496 .21216 L
s
.26017 .17881 m
.26171 .17436 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27231 .15518 m
.27392 .15075 L
s
.27231 .15518 m
.27367 .15871 L
s
.27392 .15075 m
.27529 .15427 L
s
.25496 .21216 m
.25785 .20724 L
s
.25938 .20277 m
.26105 .19431 L
s
.26053 .21034 m
.26105 .19431 L
s
.25785 .20724 m
.25938 .20277 L
s
.27367 .15871 m
.27529 .15427 L
s
.25938 .20277 m
.26053 .21034 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75288 .1454 m
.75459 .14983 L
s
.75139 .14898 m
.75288 .1454 L
s
.75311 .15341 m
.75459 .14983 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27303 .2266 m
.27304 .17868 L
s
.27004 .22745 m
.27304 .17868 L
s
.27153 .22702 m
.27229 .20278 L
s
.75139 .14898 m
.75311 .15341 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27004 .22745 m
.27127 .23514 L
s
.73469 .14087 m
.74143 .14247 L
s
.27127 .23514 m
.27303 .2266 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73137 .1441 m
.73501 .15294 L
s
.72781 .1393 m
.73137 .1441 L
s
.72432 .13854 m
.72781 .1393 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7544 .19773 m
.7551 .22211 L
s
.73469 .14087 m
.73697 .22614 L
s
.73639 .14126 m
.73868 .2265 L
s
.75348 .22172 m
.75369 .17349 L
s
.75369 .17349 m
.75671 .2225 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72089 .14182 m
.72432 .13854 L
s
.71911 .14146 m
.72432 .13854 L
s
.75534 .23027 m
.75671 .2225 L
s
.71753 .14917 m
.72089 .14182 L
s
.71573 .14881 m
.71911 .14146 L
s
.75348 .22172 m
.75534 .23027 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71967 .17222 m
.71982 .17289 L
s
0 0 0 r
.73265 .19269 m
.73588 .1853 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71982 .17289 m
.71987 .17492 L
s
.72158 .17385 m
.72162 .17521 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71422 .16062 m
.71573 .14881 L
s
.71603 .16097 m
.71753 .14917 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69143 .13226 m
.70452 .13458 L
s
.72928 .19604 m
.73265 .19269 L
s
.71603 .16097 m
.71623 .1691 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71422 .16062 m
.71442 .16875 L
s
.71623 .1691 m
.71832 .18167 L
s
.72576 .19532 m
.72928 .19604 L
s
.71442 .16875 m
.71652 .18132 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72211 .19053 m
.72576 .19532 L
s
.72032 .19018 m
.72576 .19532 L
s
.71832 .18167 m
.72211 .19053 L
s
.73177 .22507 m
.73868 .2265 L
s
.71652 .18132 m
.72032 .19018 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69708 .13324 m
.69834 .19033 L
s
.69895 .13357 m
.70022 .19064 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67015 .12897 m
.68378 .13102 L
s
.5 Mabswid
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69264 .18942 m
.70022 .19064 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67603 .12983 m
.6777 .21608 L
s
.67798 .13012 m
.67967 .21635 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65426 .13093 m
.65842 .1396 L
s
.64811 .12612 m
.65426 .13093 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64402 .12565 m
.64811 .12612 L
s
.63998 .12928 m
.64402 .12565 L
s
.63792 .12906 m
.64402 .12565 L
s
.63597 .13703 m
.63998 .12928 L
s
.69879 .21092 m
.70077 .21536 L
s
.69698 .21475 m
.69879 .21092 L
s
.69897 .21919 m
.70077 .21536 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6339 .13682 m
.63792 .12906 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69698 .21475 m
.69897 .21919 L
s
.61489 .1228 m
.62331 .12354 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63407 .14913 m
.63597 .13703 L
s
.63199 .14893 m
.6339 .13682 L
s
.65683 .16395 m
.65892 .16831 L
s
.65487 .16782 m
.65683 .16395 L
s
.65892 .16831 m
.65899 .17243 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65487 .16782 m
.65696 .17218 L
s
.6107 .12656 m
.61503 .1351 L
s
.60428 .12197 m
.6107 .12656 L
s
.60001 .12167 m
.60428 .12197 L
s
.63407 .14913 m
.63419 .15736 L
s
.59577 .12548 m
.60001 .12167 L
s
.59362 .12535 m
.60001 .12167 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65507 .18019 m
.65899 .17243 L
s
.61489 .1228 m
.61556 .18051 L
s
.617 .12298 m
.61769 .18068 L
s
.63199 .14893 m
.6321 .15716 L
s
.65106 .18386 m
.65507 .18019 L
s
.63419 .15736 m
.63644 .16994 L
s
.6321 .15716 m
.63436 .16974 L
s
.67176 .21531 m
.67967 .21635 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59154 .13343 m
.59362 .12535 L
s
.59369 .13356 m
.59577 .12548 L
s
.57196 .12009 m
.57211 .14479 L
s
.53695 .11912 m
.57196 .12009 L
s
.6449 .1832 m
.65106 .18386 L
s
.56978 .12 m
.57211 .14479 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63644 .16994 m
.64071 .17863 L
s
.63436 .16974 m
.63864 .17842 L
s
.64071 .17863 m
.6449 .1832 L
s
.63864 .17842 m
.6449 .1832 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48783 .16408 m
.48949 .15748 L
s
.48775 .16418 m
.48783 .16408 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55901 .14845 m
.55916 .18167 L
s
.60916 .18003 m
.61769 .18068 L
s
.59369 .13356 m
.5941 .17905 L
s
.59154 .13343 m
.59193 .17892 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58542 .17857 m
.5941 .17905 L
s
.54586 .1647 m
.55908 .16502 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54573 .11926 m
.54599 .20646 L
s
.54354 .11922 m
.54377 .20642 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57235 .18213 m
.5725 .20722 L
s
.5703 .20713 m
.57235 .18213 L
s
.5371 .20633 m
.5725 .20722 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ005@3o
YQ09000001d0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd4
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01@0ojHA8`2][Jd2000000<0[Jf]2P0000040:f][@l0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
00D0ojHA3`2][Jd70?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU40080?nU
40800000103oYA080:f][@@00000102][Jd200000080[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0
/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0F0?nV4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3o
YA00203oYA02000000X0ojD@0`0000030?nU4080000000<0ojD@0:f][@000000100000080:f][@h0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0
k9H>0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA00203oYA02000000X0ojD@
0P0000060?nU40040000002][Jd00000000000/0oj<@00<0[Jf]0000000000000P0000050:f][@@0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0
k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA00203oYA02000000T0ojD@
00<000000?nU400000001P3oYA0010000000[Jf]00000000000:0?nS40<000000`3oXa02000000<0
oj<@1@2][Jd3000001L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80
[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01T0ojH@
0P0000000`3oYQ00[Jf]0?nU40080?nU408000002@3oYA02000000P0ojD@0`0000090?nS40800000
1`3oXa000`000000oj<@0?nS40040?nS40040:f][@3lX100o:0@0:f][@@0000000<0[Jf]0?bP403l
X100403lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40
oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400I0?nV4080000000<0ojH@0:f][@3oYA00203oYA02000000T0ojD@0P0000080?nU40<00000
2@3oXa02000000L0oj<@00<000000?nS403oXa00103oXa00102][Jd0o:0@0?bP403lX102000000<0
o:0@0P2][Jd4000000`0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P03
0:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd70?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400I0?nV40800000
00<0ojH@0:f][@3oYA002@3oYA000`000000ojD@0?nU40070?nU40800000203oYA000`2][Jd00000
000000080?nS408000002@3oXa000`000000oj<@0?nS40030?nS40040:f][@3lX100o:0@0?bP4080
0000203lX105000000P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01T0ojH@
0P0000000`3oYQ00[Jf]0?nU40090?nU40030000003oYA00ojD@00L0ojD@0P0000080?nU40030:f]
[@000000000000P0oj<@0P0000090?nS40030000003oXa00oj<@00<0oj<@00@0[Jf]0?bP403lX100
o:0@0P0000080?bP408000000`3lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f]
[@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00T0ojD@00<000000?nU403oYA00
1`3oYA02000000P0ojD@00<0[Jf]000000000000203oXa02000000X0oj<@00<000000?nS403oXa00
0P3oXa00102][Jd0o:0@0?bP403lX102000000P0o:0@0P0000090?bP4080[Jf]0`00000D0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V
0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1440:f][AL0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01T0ojH@
0P0000000`3oYQ00[Jf]0?nU40090?nU40030000003oYA00ojD@00L0ojD@0P0000080?nU40030:f]
[@000000000000P0oj<@0P00000:0?nS40030000003oXa00oj<@0080oj<@00@0[Jf]0?bP403lX100
o:0@0P0000080?bP408000002@3lX103000000030?JL3`2][Jd000000080[Jf]0P00000?0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V
0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT
4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU40090?nU40030000003oYA00ojD@00L0ojD@
0P0000080?nU40030:f][@000000000000L0oj<@0P00000@0?nS40040:f][@3lX100o:0@0?bP4080
0000203lX102000000P0o:0@00@000000?bP40000000[Jf]0P3fW0l00`000000mY`?0?JL3`040000
00d0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H10?oo
o`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0
[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA002@3oYA000`000000
ojD@0?nU40070?nU40800000203oYA000`2][Jd00000000000070?nS40800000403oXa00102][Jd0
o:0@0?bP403lX102000000P0o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l00P3fW0l01000
0000mY`?0000000000020?JL3`@0[Jf]00<0mY`?0000003fW0l01P3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f]
[@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@01<0ojD@0P0000080?nU
40030:f][@000000000000L0oj<@0P00000@0?nS40040:f][@3lX100o:0@0?bP40800000203lX102
000000L0o:0@00D000000?bP40000000o:0@0:f][@030?JL3`040000003fW0l00000000000H0mY`?
0P0000020:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]
D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA000P3o
YA000`000000ojD@0?nU400>0?nU40800000203oYA000`2][Jd00000000000070?nS408000004@3o
Xa000`2][Jd0o:0@0?bP4002000000P0o:0@0P0000070?bP408000000P3lX1000`2][Jd0mY`?0?JL
3`020?JL3`<000001P3fW0l010000000mY`?0000003fW0l40:f][@030?JL3`2][Jd0k9H>0140k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0:f][@1@0;3PiP40oooo001U0;3PiP030:f][@3C
Q`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd000000:f][@030:f][A40oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@0080ojD@00<000000?nU403oYA003P3o
YA02000000P0ojD@00<0[Jf]0000000000001`3oXa0200000140oj<@00<0[Jf]0?bP403lX1000P00
00080?bP408000001`3lX10200000080o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l3000000H0mY`?00<0
00000?JL3`0000001@3fW0l30:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue
2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100
3P3lX1020:f][@030000003oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV
402][Jd0ojD@0080ojD@00<000000?nU403oYA003P3oYA02000000P0ojD@00@0[Jf]0?nS40000000
00001P3oXa0200000140oj<@00<0[Jf]0?bP403lX1000P0000080?bP408000001`3lX10200000080
o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000L0mY`?00<000000?JL3`3fW0l01@3fW0l00`2][Jd0
k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]
04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@
00`0o:0@0P2][Jd0103lX100[Jf]00000000000D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P000000
0`3oYQ00[Jf]0?nU40020?nU40030000003oYA00ojD@00h0ojD@0P0000080?nU40040:f][@3oXa00
0000000000H0oj<@0P00000A0?nS40030:f][@3lX100o:0@00800000203lX102000000L0o:0@0P00
00020?bP40030:f][@3fW0l0mY`?00<0mY`?0P00000?0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2]
[Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3o
ool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100
o:0@00P0o:0@0P0000020:f][@<0o:0@00<0[Jf]0000003oY140503oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4S0:f][@8000001@2][Jd0
10000000[Jf]0:f][@2][Jd=0?nU40800000203oYA00102][Jd0oj<@0000000000060?nS40800000
4@3oXa000`2][Jd0o:0@0?bP4002000000P0o:0@0P0000070?bP408000000P3lX1000`2][Jd0mY`?
0?JL3`030?JL3`8000003`3fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`
h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001P3l
X102000000030:f][@3lX100000000@0o:0@00<0[Jf]0000003oY1404`3oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0
[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@0080ojD@00@000000?nU403oYA00ojD@
3@2][Jd2000000030:f][@3oYA00ojD@00D0ojD@00@0[Jf]0?nS4000000000001P3oXa0200000140
oj<@00<0[Jf]0?bP403lX1000P0000080?bP408000001`3lX10200000080o:0@00<0[Jf]0?JL3`3f
W0l00`3fW0l2000000l0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V
00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00<0o:0@
00@000000:f][@000000[Jf]0`3lX1000`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@`0[Jf]5`3oYQ400`2][Jd0
ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA000P3oYA000`000000ojD@0?nU400>0?nU4080
000000<0ojD@0:f][@2][Jd01`2][Jd2000000030:f][@3oXa00oj<@00<0oj<@0P00000A0?nS4003
0:f][@3lX100o:0@00800000203lX102000000L0o:0@0P0000020?bP40030:f][@3fW0l0mY`?00<0
mY`?0P00000?0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f]
[@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1020:f][@03
0000003lX100000000D0o:0@00D000000?bP403lX100o:0@0:f][@0E0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ490:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA000P3oYA000`000000ojD@0?nU400>0?nU
40800000203oYA001@2][Jd0oj<@000000000000oj<@00D0[Jf]0P0000030:f][@h0oj<@00<0[Jf]
0?bP403lX1000P0000090?bP40030000003lX100o:0@00D0o:0@0P0000020?bP40030:f][@3fW0l0
mY`?00<0mY`?0P00000?0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0<
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2]
[Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP402][Jd0[Jf]0P3lX102
000000H0o:0@00D000000?bP403lX100o:0@0:f][@0E0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400I0?nV40P00000403oYA02000000P0ojD@00@0[Jf]0?nS4000000000001`3oXa0200000080oj<@
1`2][Jd00`000000[Jf]0:f][@040?nS40030:f][@3lX100o:0@008000002@3lX102000000H0o:0@
0P0000020?bP40030:f][@3fW0l0mY`?00<0mY`?0P00000?0?JL3`030:f][@3/UPh0k9H>00l0k9H>
0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203C
Q`h00`2][Jd0kiP@0>nH40090>nH408000000P2][Jd40?bP408000001P3lX1001@000000o:0@0?bP
403lX100[Jf]01D0oj@A00<0[Jf]0?nV4@3oYQ405P3oYQ470:f][AL0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA000P3oYA000`000000ojD@
0?nU400>0?nU40800000203oYA00102][Jd0oj<@0000000000070?nS40800000203oXa0200000080
oj<@1`2][Jd2000000T0o:0@0P0000060?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`80
00003`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V100203_V102000000030:f]
[@000000000000@0o:0@0P0000050?bP40030000003lX100o:0@0080o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@H0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@0080ojD@
00<000000?nU403oYA003P3oYA02000000P0ojD@00@0[Jf]0?nS4000000000001`3oXa02000000P0
oj<@00<000000?nS400000001@3oXa000`2][Jd0o:0@0?bP4002000000D0[Jf]103lX102000000H0
o:0@0P0000020?bP40030:f][@3fW0l0mY`?00<0mY`?0P00000?0?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2]
[Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@
00H0[Jf]0000003_V100kiP@0:f][@0000040?bP408000001@3lX1000`000000o:0@0?bP40020?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@P0ojHA00<0[Jf]0?nV
4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3o
YQ00[Jf]0?nU40020?nU40030000003oYA00ojD@00h0ojD@0P0000080?nU40040:f][@3oXa000000
000000L0oj<@0P0000080?nS40030000003oXa00000000D0oj<@00<0[Jf]0?bP403lX1000P000005
0?bP40@0[Jf]0P0000000`2][Jd0o:0@0?bP40030?bP408000000P3lX1000`2][Jd0mY`?0?JL3`03
0?JL3`8000003`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd7
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102]
[Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@00<000000:f][@2][Jd00P000002
0>nH40030:f][@3lX100000000<0o:0@00<000000?bP403lX100103lX1000`000000o:0@0?bP4002
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P000000
0`3oYQ00[Jf]0?nU40020?nU40030000003oYA00ojD@00h0ojD@0P0000080?nU40040:f][@3oXa00
0000000000L0oj<@0P0000090?nS408000001@3oXa000`2][Jd0o:0@0?bP4002000000T0o:0@0P00
00000`3lX100[Jf]0:f][@030:f][@8000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`8000001`3f
W0l00`000000mY`?0?JL3`050?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0103K
RPd00`2][Jd0fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]
A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@0080kiP@
0P000000102][Jd0kiP@0>nH400000030>nH40030:f][@3lX100000000<0o:0@00<000000?bP403l
X100103lX1000`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ401P2][JdB0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA000P3oYA000`000000ojD@0?nU400>0?nU4080
0000203oYA00102][Jd0oj<@0000000000080?nS40800000203oXa000`000000oj<@0?nS40040?nS
40030:f][@3lX100o:0@008000002@3lX102000000H0o:0@0P0000040:f][@@0mY`?0P0000070?JL
3`030000003fW0l0mY`?00D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@050=^:
3@80[Jf]103KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H1
0?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00L0[Jf]0>nH403_V10000000>nH
40000000[Jf]0080kiP@0P0000030>nH40030:f][@3lX100o:0@00<0o:0@00<000000?bP403lX100
0`3lX102000000@0o:0@00<0[Jf]0?nT4@3oY1404P3oY1440:f][AP0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]
0?nU40020?nU40030000003oYA00ojD@00h0ojD@0P0000080?nU40040:f][@3oXa000000000000P0
oj<@0P0000080?nS40030000003oXa00oj<@00@0oj<@00<0[Jf]0?bP403lX1000P0000090?bP4080
00001`3lX102000000030?bP402][Jd0mY`?00@0[Jf]0P0000070?JL3`030000003fW0l0mY`?00D0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0P3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00P0dhL>00H0[Jf]0>nH4000000000000:f][@0000030>nH40030000003_
V100kiP@0080kiP@00<0[Jf]0?bP403lX1002@3lX102000000@0o:0@00<0[Jf]0000003oY1403P3o
Y1440:f][@030?nT4@2][Jd0ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU40020?nU40030000003o
YA00ojD@00/0ojD@1@0000080?nU40040:f][@3oXa000000000000T0oj<@0P0000060?nS40030000
003oXa00oj<@00D0oj<@00<0[Jf]0?bP403lX1000P0000090?bP408000001`3lX102000000030?bP
402][Jd0mY`?00@0mY`?0P0000020:f][@D0mY`?00<000000?JL3`3fW0l01@3fW0l00`2][Jd0k9H>
0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00T0fhX=0`2][Jd90;Ue2`030:f][@28EPL0R5H70080R5H7
00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3C
Q`h0dhL>00H0dhL>00H0[Jf]0000002][Jd000000>nH400000030>nH40030000003_V100kiP@0080
kiP@00<0[Jf]0?bP403lX100203lX102000000D0o:0@00<0[Jf]0000003oY1402P3oY1440:f][@D0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@0080ojD@00<000000?nU403o
YA005P3oYA06000000X0oj<@0P0000050?nS40030000003oXa00oj<@00D0oj<@00<0[Jf]0?bP403l
X1000P0000090?bP408000001`3lX102000000030?bP402][Jd0mY`?00@0mY`?0P0000020?JL3`@0
[Jf]00<0mY`?0000003fW0l01P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P80000000@0kiP@0000003_
V10000000`3_V1000`000000kiP@0>nH40020>nH40030:f][@3lX100o:0@00L0o:0@00<000000?bP
400000001@3lX1000`2][Jd000000?nT4@070?nT4@<0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400I0?nV
4080000000<0ojH@0:f][@3oYA002@3oYA000`000000ojD@0?nU400A0?nU40030:f][@3oXa00oj<@
00d0oj<@0P0000020?nS40030000003oXa00oj<@00H0oj<@00<0[Jf]0?bP403lX1000P0000090?bP
408000001`3lX102000000030?bP402][Jd0mY`?00@0mY`?0P0000060?JL3`040:f][@000000[Jf]
0:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/0
0`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@080=>73P030:f][@00000000000080kiP@0P0000030>nH40050000003_V100
kiP@0>nH402][Jd02P3lX102000000H0o:0@00<0[Jf]0000003oY1400`3oY1440:f][@`0oj@A00<0
[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00T0ojD@00<000000?nU403oYA004@3o
YA000`2][Jd0oj<@0?nS400?0?nS408000002@3oXa000`2][Jd0o:0@0?bP4002000000T0o:0@0P00
00080?bP4080000000<0[Jf]0?JL3`3fW0l00`3fW0l3000000H0mY`?00<000000?JL3`3fW0l0102]
[Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]
1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00<0dhL>0000000000000P3_V102000000<0kiP@
00D000000>nH403_V100kiP@0:f][@090?bP408000001`3lX1000`2][Jd000000:f][@030:f][A00
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00T0ojD@00<000000?nU403o
YA004@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@008000002@3lX102000000P0
o:0@0P0000000`2][Jd0mY`?0?JL3`030?JL3`<000001P3fW0l2000000D0mY`?0`2][JdA0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H7
0080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00<0dhL>00<000000=>73P2][Jd00P3CQ`h2000000@0kiP@00<000000>nH403_V1000P0000030>nH
40030:f][@3lX100o:0@00L0o:0@0P0000060?bP4080[Jf]00<000000?nT4@3oY1404P3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA002@3oYA000`000000ojD@0?nU400A0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1000P0000060?bP4080000000<0o:0@0000
000000002@3lX102000000@0mY`?00@000000?JL3`00000000001P3fW0l2000000H0mY`?00<0[Jf]
0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/0
0`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h2000000<0dhL>0P0000040>nH40030000003_V100
kiP@008000000`3_V1000`2][Jd0o:0@0?bP40060?bP40800000103lX1030:f][@030?bP402][Jd0
000001@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00T0ojD@00<00000
0?nU403oYA004@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00800000203lX103
000000T0o:0@0P0000040?JL3`040000003fW0l00000000000H0mY`?0P0000060?JL3`030:f][@3/
UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2i
M@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd00P3CQ`h00`000000[Jf]000000030=>73P800000103_V1000`000000kiP@
0>nH4002000000<0kiP@00<0[Jf]0?bP403lX1001@3lX1000`000000o:0@000000020?bP4080[Jf]
103lX1000`2][Jd000000?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]
0?nU40090?nU40030000003oYA00ojD@0140ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP4002000001D0o:0@00<000000?JL3`3fW0l00P3fW0l010000000mY`?0000000000060?JL3`80
00001P3fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80[Jf]@P2`h>H10?ooo`00
F@2`h>H0202][Jd0Uf0;09MP2`2GH0/0[Jf]0000002][Jd000000P3CQ`h00`000000dhL>0=>73P02
000000@0kiP@00<000000>nH403_V1000P0000030>nH40030:f][@3lX100000000@0o:0@00<00000
0?bP400000000`2][Jd00`3lX10000000?bP40030?bP40030:f][@000000oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA8`2][Jd2
000000T0[Jf]0P3oYA02000001<0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP4002
000001H0o:0@00@000000?JL3`3fW0l000000P3fW0l2000000H0mY`?0P0000060?JL3`030:f][@3/
UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2i
M@/20:f][@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP080:f][@2GH0/0Uf0;09MP2`000000[Jf]
0=>73P0000020=>73P030000003CQ`h0dhL>008000000`3_V10010000000kiP@0>nH403_V1020000
00<0kiP@0`0000040?bP4080000000<0[Jf]0?bP403lX1000P3lX1000`000000o:0@0?bP40020?bP
40030:f][@000000oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3o
YQ00[Jf]0?nU40060?nU4080[Jf]0P00000<0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP4002000001H0o:0@00<0[Jf]0000000000000`3fW0l2000000H0mY`?0P0000060?JL
3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0
/>3V00<0[Jf]09MP2`2GH0/00P0000000`3CQ`h000000=>73P050=>73P030000002][Jd0kiP@0080
kiP@00@000000>nH403_V100kiP@0P0000001P3_V10000000000002][Jd0o:0@00000080o:0@0P2]
[Jd00`000000o:0@0?bP40030?bP40800000103lX1000`2][Jd000000?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ006@3o
YQ02000000030?nV402][Jd0ojD@00P0ojD@0P00000<0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP
4002000001H0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000H0mY`?0P0000060?JL3`030:f][@3/
UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2]
[Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00L0[Jf]09MP2`000000[Jf]0000
003CQ`h0000000H0dhL>00<000000>nH403_V1000P3_V10010000000kiP@0>nH403_V10300000080
kiP@00<0[Jf]0?bP400000000P2][Jd20?bP40030000003lX100o:0@00<0o:0@0P0000040?bP4003
0:f][@000000oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0
[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00
[Jf]0?nU40080?nU408000004`3oYA000`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0
o:0@0?bP4002000001H0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000H0mY`?0P0000060?JL3`03
0:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`03
0:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00L0[Jf]000000000000[Jf]0000003CQ`h00000
00H0dhL>00<000000>nH403_V1000P3_V10010000000kiP@0>nH403_V102000000<0kiP@0P2][Jd0
0`000000o:0@0?bP40020?bP40030000003lX100o:0@00<0o:0@0P0000040?bP40800000503oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00P0ojD@0P00000C
0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@008000005P3lX100
0`2][Jd0mY`?0?JL3`030?JL3`8000001P3fW0l2000000H0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00`28
EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP070:f][@000000[Jf]09MP2`000000dhL>
000000060=>73P030000003_V100kiP@0080kiP@00@000000>nH403_V100kiP@0P0000001P3_V100
[Jf]0:f][@2][Jd0o:0@000000@0o:0@00<000000?bP403lX1000P3lX103000000@0o:0@0P00000D
0?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdH0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00P0ojD@0P00000C0?nU40030:f][@3oXa00
oj<@01H0oj<@1`2][Jd2000001H0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000H0mY`?0P000006
0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2i
M@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2][Jd000000;3PiP100;3PiP40oooo
001I0;3PiP070:f][@000000[Jf]09MP2`000000dhL>000000060=>73P030000003_V100kiP@0080
kiP@00@000000>nH403_V100kiP@0P0000001P2][Jd0kiP@0>nH402][Jd0o:0@000000@0o:0@00<0
00000?bP403lX1000P3lX103000000<0o:0@00<0[Jf]000000000000503oY1400`2][Jd0ojHA0?nV
4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ005@3oYQ0C000001<0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
4002000000H0[Jf]403lX1000`2][Jd0mY`?0?JL3`030?JL3`8000001P3fW0l2000000L0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`080:f][@28EPL0R5H708QF1`2][Jd0R5H70:f][@0000110;3PiP40oooo001I0;3PiP80
00000P2GH0/3000000D0dhL>0P0000040>nH40040000003_V100kiP@0:f][@8000000`3_V1000`2]
[Jd0o:0@000000040?bP40030000003lX100o:0@0080o:0@00<000000?bP400000000`3lX1000`2]
[Jd000000000000D0?nT4@030:f][@3oYQ40ojHA00L0ojHA1`2][Jd90?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP4002000000H0o:0@1P2][Jd:0?bP
40030:f][@3fW0l0mY`?00<0mY`?0P0000060?JL3`8000001`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00P0[Jf]08QF
1`28EPL0R5H70:f][@28EPL0[Jf]00000440/>3V0@3oool005P0/>3V00<000000:f][@0000000P2G
H0/3000000D0dhL>0P0000040>nH40040000002][Jd0[Jf]0>nH408000000`3_V1000`2][Jd00000
000000040?bP40050000003lX100o:0@0?bP400000000P3lX1001@000000o:0@0?bP403lX100[Jf]
00800000503oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@008000002@3lX1000`000000o:0@0?bP4007
0:f][@<0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000H0mY`?0`0000060?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0
0`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?`2`h>H10?ooo`00F02`h>H00`00
0000[Jf]0000000209MP2`<000001@3CQ`h2000000<0kiP@00<0[Jf]0000003_V1000P3_V1020000
00<0kiP@00<0[Jf]0000003lX100103lX1000`000000o:0@0?bP4002000000H0o:0@00<0[Jf]0000
000000004`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@00800000203lX102000000T0o:0@1P2][Jd30?JL3`8000001P3fW0l30000
00H0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f]
[@2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@000000/>3V0400/>3V0@3oool005P0
/>3V00<000000:f][@0000000P2GH0/3000000D0dhL>0P0000001@3_V100[Jf]0:f][@3_V1000000
00<0kiP@0P0000030>nH40030:f][@000000o:0@00D0o:0@0P0000080?bP40030:f][@0000000000
00l0oj@A102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa02000000030?bP40000000000000P0o:0@00<000000?bP400000002`3lX1000`2]
[Jd0mY`?0?JL3`030:f][@8000001P3fW0l3000000H0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@000000/>3V
0400/>3V0@3oool005L0/>3V0P000000102][Jd0000009MP2`2GH0/300000080dhL>0P000000103C
Q`h000000000002][Jd30>nH40030000003_V100kiP@0080kiP@0P0000020>nH40030:f][@000000
o:0@00l0o:0@00<0[Jf]0000000000002`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP400000000P000008
0?bP40800000303lX1000`2][Jd0mY`?0?JL3`030?JL3`800000102][Jd20?JL3`<000001P3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][Jd80;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0000002`h>H0@02`h>H10?ooo`00E`2`h>H2000000050:f][@000000Uf0;
0000002][Jd00P0000020=>73P80000000<0dhL>0:f][@000000103_V1000`000000kiP@0>nH4002
0>nH408000000P3_V1000`000000o:0@0?bP400?0?bP40030:f][@000000000000L0oj@A102][Jd9
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@00/0o:0@00<000000?bP403lX1002P3lX1000`2][Jd0mY`?0?JL3`03
0?JL3`800000103fW0l20:f][@<000001P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@00
000000000400/>3V0@3oool005L0/>3V0P0000001@2][Jd0000009MP2`000000[Jf]00H0000000<0
[Jf]0=>73P000000103_V1000`000000kiP@0>nH40030>nH40040000003_V100kiP@00000140o:0@
00<0[Jf]0000000000000`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`030?JL3`8000001P3fW0l3000000@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H70080
R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H2000000050:f][@000000Uf0;0000002]
[Jd00P0000020=>73P8000000P3CQ`h010000000kiP@0>nH403_V102000000H0kiP@0P0000000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@000000000000<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?00<0mY`?0P0000060?JL3`<00000103fW0l40:f][A40k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF
1`28EPL00P28EPL00`2][Jd00000000000100;3PiP40oooo001G0;3PiP<000000P2GH0/01P000000
[Jf]000000000000dhL>0:f][@8000000P3CQ`h010000000kiP@0>nH403_V102000000P0kiP@00<0
[Jf]0?bP403lX1003P3lX1020:f][@800000503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?0080000000<0mY`?0000000000001P3fW0l00`000000mY`?000000060?JL3`030:f][@3/
UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0
[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`030:f][@00000000000400/>3V0@3oool005L0/>3V0`00
000209MP2`060000002][Jd000000000002][Jd0dhL>0P0000020=>73P8000000P3_V102000000P0
kiP@00<0[Jf]0?bP403lX100303lX1020:f][@040?bP402][Jd00000000001@0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`020?JL3`<000001`3fW0l00`000000mY`?0?JL3`050?JL
3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/0102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3P
iP40oooo001G0;3PiP<000000P2GH0/010000000[Jf]0000000000020=>73P040000003CQ`h0dhL>
0=>73P80000000@0kiP@0000003_V1000000203_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3l
X1000`2][Jd000000000000D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0303f
W0l00`000000mY`?0?JL3`050?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H70P2][Jd00`000000/>3V0;3P
iP0n0;3PiP40oooo001G0;3PiP<000000P2GH0/010000000@FWQ0000000000020=>73P040000003C
Q`h0dhL>0=>73P80000000@0kiP@0000003_V1000000203_V1000`2][Jd0o:0@0?bP40070?bP4080
[Jf]1P3lX1000`2][Jd000000?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0303fW0l00`000000mY`?0?JL3`050?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80
[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H300000080Uf0;00@000000:f][@000000
00000P3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]008000000P3_V1000`000000kiP@0>nH40060>nH
40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@000000oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL
3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/20:f][@<0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001G0;3PiP<0
00000P2GH0/010000000@FWQ0000000000020=>73P040000003CQ`h0dhL>0:f][@D0kiP@00<00000
0>nH403_V1001P3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0000003oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3o
YQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:
3@0=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd308QF1`80[Jf]00<000000;3PiP2`h>H0?P2`
h>H10?ooo`00E`2`h>H00`000000[Jf]0000000209MP2`040000002][Jd0000000000080dhL>00@0
00000=>73P3CQ`h0[Jf]103_V1000`000000kiP@0>nH40070>nH40040:f][@3lX100[Jf]0:f][@h0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0
ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0
R5H70:f][@0208QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H02`000000[Jf]
0000002GH0/0[Jf]0000002][Jd0dhL>0000003CQ`h0000000<0dhL>00<0[Jf]0>nH403_V1000P3_
V1000`000000kiP@0>nH40060>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3K
RPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]
00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H02`000000[Jf]0000002][Jd0Uf0;0000002]
[Jd0dhL>0000003CQ`h0000000<0dhL>00<0[Jf]0>nH403_V1000P3_V1000`000000kiP@0>nH4004
0>nH4080[Jf]00<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V2P2][JdH0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0
[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0R5H708QF1`2][Jd0R5H70080[Jf]0P00000o0;3PiP40oooo
001F0;3PiP80000000<0[Jf]0000002][Jd00P000000102][Jd0dhL>0=>73P0000040=>73P030:f]
[@3_V100kiP@0080kiP@00<000000>nH403_V1000P3_V1020:f][@<0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]
4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
0`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL30:f][@80
0000?`2`h>H10?ooo`00EP2`h>H2000000030:f][@000000Uf0;0080000000<0[Jf]0=>73P3CQ`h0
1@3CQ`h00`2][Jd0kiP@0>nH40020>nH40030000003_V100kiP@0080[Jf]1@3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V
1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H708QF1`<0
[Jf]0P00000o0;3PiP40oooo001F0;3PiP80000000<0[Jf]0000002GH0/00P0000000`2][Jd0dhL>
0=>73P050=>73P030:f][@3_V100kiP@0080kiP@00<000000:f][@2][Jd01`3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0/>3V
1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0R5H70080R5H7
0P2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000000`2][Jd0000000000002000000030:f][@3C
Q`h0dhL>00D0dhL>00H0[Jf]0>nH403_V100kiP@0:f][@0000090>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP
40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:
3@80[Jf]00<0fhX=0:f][@2iM@/0202iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H1
0?ooo`00EP2`h>H6000000030:f][@3CQ`h0dhL>00H0dhL>00H0[Jf]0>nH402][Jd0[Jf]0>nH4000
00090>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2]
[JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@T0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V1P0000000`2][Jd0dhL>0=>7
3P060=>73P80[Jf]0`3_V1000`000000kiP@0>nH40070>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd0303KRPd30:f][@L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V
0@3oool005H0/>3V1000000209MP2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd40>nH40030000003_
V100kiP@00L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`
h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2i
M@/0^GD;0:f][@H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V
0`00000309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH40030>nH40030000
003_V100kiP@00H0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]
h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f]
[@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?oo
o`00EP2`h>H3000000<0Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]
00<0kiP@00<000000>nH403_V1001`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A
00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;0080^GD;0P2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o
0;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0
dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H4
0:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`040:f][@2iM@/0
^GD;0:f][@<0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000001P2][Jd0Uf0;09MP2`2G
H0/0[Jf]0=>73P80[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@
0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;
0`2][Jd308QF1`040:f][@11JN400000000003l0/>3V0@3oool005H0/>3V0P000000102][Jd0Uf0;
09MP2`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080
[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H00000
03l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/00`2][Jd0dhL>0=>73P060=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0
[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]0`28EPL00`2][Jd0/>3V0000000o0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;
0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[
W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd0/>3V0000000o0;3PiP40oooo
001F0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102]
[Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H700<0[Jf]0;3PiP000000?`2`
h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f]
[@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H7
00<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H010000000[Jf]09MP2`2][Jd209MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f]
[@28EPL0R5H70:f][@28EPL0[Jf]0P00000o0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;0:f]
[@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;
00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V00<000000:f]
[@2][Jd00`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`00
0000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f]
[@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@800000?P2`h>H10?ooo`00EP2`h>H00`00
0000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd4
0:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0
a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0
102][Jd0];2a0:f][@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28
EPL20:f][@800000?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0
dhL>00L0dhL>00H0[Jf]0>nH402][Jd0[Jf]0:BNS`11JN440:BNS`030:f][@2aZid0/J^M00@0/J^M
0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a0;B`/@11JN420:f]
[@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool0
05H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]00<0@FWQ0:BN
S`2TWXl01@2TWXl00`2][Jd0/J^M0;6[W@060;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd7
0;ji^004045Yh@2n^KP0_[Vh0:f][@80];2a00<0@FWQ0;B`/@2d/;400P2][Jd:0;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]0P00000n0;3PiP40oooo001E0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;
0:f][@080=>73P040:f][@2TWXl0@FWQ045Yh@L0Y9j?00<0[Jf]0;6[W@2aZid0202aZid20:f][@03
0;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0
[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00`0`kfk0`2][Jd70;ji^080@FWQ0`2n^KP0102][Jd0];2a0;B`/@11JN430;B`
/@03045Yh@2][Jd0[Jf]00P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool0
05D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd3045Yh@P0Y9j?00<0[Jf]
0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji
^0060;ji^0<0@FWQ0`2n^KP0102][Jd0];2a0;B`/@11JN430;B`/@04045Yh@2d/;40];2a0:f][@L0
^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool005D0/>3V0P0000001@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00D0dhL>0P2][Jd00`11JN40Y9j?045Yh@080:BNS`030:f][@2aZid0/J^M
00`0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m
^`030:f][@2n^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN440;ji^0030:f][@2d/;40
@FWQ00<0];2a0P11JN40102d/;40@FWQ0:f][@2][Jd50;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]
0P00000n0;3PiP40oooo001E0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P030:f]
[@11JN40RXEe0080@FWQ2@2TWXl00`2][Jd0/J^M0;6[W@080;6[W@80@FWQ0P2aZid00`2][Jd0^K:V
0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/0102][Jd0_[Vh
0;ji^02n^KP2045Yh@<0_[Vh0P11JN440;ji^0030:f][@2d/;40@FWQ00<0];2a0P11JN400`2d/;40
@FWQ045Yh@030:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool005D0
/>3V00<000000;3PiP2][Jd00`2GH0/01P2][Jd0dhL>0=>73P3CQ`h0[Jf]045Yh@80RXEe00<0@FWQ
0:f][@2][Jd0102TWXl01@11JN40Y9j?0:BNS`2TWXl0[Jf]00`0/J^M0P11JN400`2][Jd0^K:V0;Vb
YP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0
[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@11JN40@FWQ00<0@FWQ0`2n^KP2045Yh@@0_[Vh00@0
[Jf]0;B`/@11JN40@FWQ0P2d/;42045Yh@070:f][@11JN40@FWQ0:f][@11JN40Wi^P0:f][@020;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]00<0/>3V0000002`h>H0?@2`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`040:f][@3CQ`h0[Jf]0:f][@80@FWQ0P2:QGD01011JN40Y9j?0:BNS`2]
[Jd30:BNS`05045Yh@2TWXl0Y9j?0:BNS`2][Jd0302aZid01011JN40/J^M045Yh@11JN4:0;VbYP@0
[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]3P33_K/00`11JN40
_[Vh0;ji^003045Yh@<0_[Vh0P11JN440;ji^0030:f][@2d/;40@FWQ00D0@FWQ00D0];2a045Yh@11
JN40[Jf]045Yh@0209nKX0<0[Jf]1028EPL00`2][Jd0/>3V0000000n0;3PiP40oooo001E0;3PiP03
0000002][Jd0Uf0;00<0Uf0;0P2][Jd608Z5M@04045Yh@2TWXl0Y9j?045Yh@80[Jf]00<0Y9j?045Y
h@2TWXl00P2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@03045Yh@2aZid0[Jf]0080@FWQ3@2i/ZH30:f]
[A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f]
[@030<K0_02][Jd0`kfk00d0`kfk0P11JN430;ji^080@FWQ0`2n^KP2045Yh@@0_[Vh00@0[Jf]0;B`
/@2d/;40];2a0P2][Jd2045Yh@050;B`/@11JN40@FWQ0:f][@11JN400`2OVj000`11JN40[Jf]08QF
1`0308QF1`030:f][@2`h>H0000003h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00`2GH0/0
0`2][Jd0RXEe08Z5M@0508Z5M@04045Yh@2TWXl0Y9j?045Yh@80Y9j?00<0[Jf]045Yh@2TWXl00P2T
WXl00`2][Jd0/J^M0;6[W@0:0;6[W@04045Yh@2aZid0[Jf]0;VbYP80@FWQ3@2i/ZH00`2][Jd0_[N/
0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/0
3033_K/00`11JN40[Jf]0;ji^0020;ji^080@FWQ0`2n^KP2045Yh@@0_[Vh00@0[Jf]0;B`/@2d/;40
[Jf]0P2d/;400`11JN40];2a0;B`/@04045Yh@<0Wi^P00<0@FWQ09nKX02][Jd00`28EPL00`2][Jd0
/>3V0;3PiP0n0;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]045Yh@2:QGD0
1P2:QGD01011JN40Y9j?0:BNS`11JN430:BNS`05045Yh@2][Jd0Y9j?0:BNS`2][Jd0302aZid01011
JN40/J^M0:f][@2i/ZH2045Yh@@0^K:V0`11JN460;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd9
0;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A
0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk00@0`kfk00<0@FWQ
0<>m^`33_K/01033_K/2045Yh@030<>m^`2][Jd0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11
JN440;ji^0030000002][Jd0[Jf]00<0];2a00<0@FWQ0;B`/@2d/;400P11JN400`2][Jd0Wi^P09nK
X00209nKX003045Yh@2OVj00[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00E@2`h>H0
0`000000[Jf]09MP2`0209MP2`030:f][@11JN40RXEe00H0RXEe00@0@FWQ0:BNS`2TWXl0@FWQ0`2T
WXl00`11JN40Y9j?0:f][@020:f][@`0/J^M00<0@FWQ0;6[W@2][Jd00P2i/ZH2045Yh@@0^K:V1011
JN440;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0
[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36
`;`00`2][Jd0`kfk045Yh@040<>m^`03045Yh@33_K/0`kfk00@0`kfk0P11JN400`33_K/0[Jf]0;ji
^0020;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P2][Jd00`2d/;40@FWQ
045Yh@020;B`/@06045Yh@2d/;40@FWQ045Yh@2d/;40[Jf]102OVj001011JN40Wi^P09nKX02][Jd2
08QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00@000000:f][@2GH0/0Uf0;0P2][Jd0
0`11JN40RXEe08Z5M@0508Z5M@040:f][@11JN40@FWQ045Yh@<0Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?
0P2][Jd;0;6[W@03045Yh@2aZid0[Jf]0080^K:V0P11JN440;VbYP80@FWQ1P2i/ZH00`2][Jd0_[N/
0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00l0al6l102][JdA0<K0_0030:f][@33_K/0@FWQ00@0`kfk00<0@FWQ0<>m^`33_K/0
1033_K/01011JN40`kfk0<>m^`2][Jd30;ji^003045Yh@2n^KP0_[Vh0080_[Vh00L0@FWQ0;ji^02]
[Jd0[Jf]0;ji^02][Jd0];2a0080@FWQ0P2d/;400`11JN40];2a0;B`/@020;B`/@030:f][@2OVj00
Wi^P0080Wi^P00<0@FWQ09nKX02OVj000P2][Jd00`28EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3P
iP040:f][@2GH0/0[Jf]06=PD`80[Jf]1P2:QGD01@2][Jd0Y9j?0:BNS`2TWXl0@FWQ0080Y9j?0P11
JN430:BNS`040:f][@2aZid0[Jf]0:f][@T0/J^M00<0@FWQ0;6[W@2][Jd00P2i/ZH2045Yh@@0^K:V
0P11JN460;VbYP030:f][@2n]j`0_[N/00l0_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`03036`;`01`11JN40a/2l
0<K0_036`;`0[Jf]0<>m^`11JN401033_K/2045Yh@D0`kfk00@0@FWQ0<>m^`33_K/0[Jf]0`2n^KP0
0`11JN40_[Vh045Yh@020;ji^003045Yh@2][Jd0_[Vh0080_[Vh00<0[Jf]0;B`/@11JN400P2d/;40
0`11JN40];2a0;B`/@030;B`/@030:f][@2OVj00Wi^P0080Wi^P00D0@FWQ09nKX02OVj00[Jf]071^
N@020:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]
0:BNS`2TWXl0102TWXl00`11JN40Y9j?0:BNS`020:BNS`040:f][@2aZid0/J^M0;6[W@<0[Jf]1P2a
Zid00`11JN40/J^M0:f][@030;VbYP80@FWQ0`2i/ZH2045Yh@H0^K:V00<0[Jf]0;jg[02n]j`00P2n
]j`3045Yh@/0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`01`36`;`01@11JN40a/2l0<K0
_036`;`0@FWQ00@0a/2l00@0[Jf]0<>m^`11JN40@FWQ0`33_K/2045Yh@D0`kfk00@0@FWQ0<>m^`33
_K/0[Jf]0`2n^KP2045Yh@<0[Jf]0P11JN420;ji^004045Yh@2][Jd0];2a0;B`/@80@FWQ1P2d/;40
0`2][Jd0Wi^P09nKX00209nKX005045Yh@2OVj00[Jf]0:f][@1`KWT00P2][Je00;3PiP40oooo001F
0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00<0[Jf]0:BNS`2TWXl0102TWXl00`11JN40Y9j?0:BNS`02
0:BNS`030:f][@2aZid0/J^M00@0/J^M0P2][Jd40;6[W@03045Yh@2aZid0[Jf]00<0^K:V0P11JN43
0;VbYP80@FWQ1P2i/ZH00`2][Jd0_[N/0;jg[002045Yh@80_[N/00<0@FWQ0;jg[02n]j`02@2n]j`0
0`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0_0050<K0_080@FWQ00D0a/2l045Yh@11JN40a/2l045Y
h@040<K0_0040:f][@33_K/0@FWQ045Yh@80`kfk0`11JN440<>m^`80@FWQ0P33_K/0102][Jd0_[Vh
045Yh@11JN420:f][@<0_[Vh0P11JN40102n^KP0@FWQ045Yh@2][Jd:0;B`/@090:f][@2OVj00Wi^P
09nKX011JN40Wi^P0:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1S
H5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0Y9j?0:BNS`040:BNS`03045Yh@2T
WXl0Y9j?0080Y9j?00<0[Jf]0;6[W@2aZid01P2aZid30:f][@040;6[W@11JN40/J^M0:f][@<0^K:V
0P11JN430;VbYP80@FWQ1@2i/ZH01@2][Jd0_[N/0;jg[02n]j`0@FWQ00@0_[N/00<0@FWQ0;jg[011
JN400P11JN460;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100
b<6k1P2][JdA0<O1_0030:f][@36`;`0a/2l00<0a/2l0P11JN440<K0_0<0@FWQ1036`;`0102][Jd0
@FWQ045Yh@11JN420<>m^`<0@FWQ1033_K/2045Yh@80`kfk00@0[Jf]0;ji^02][Jd0[Jf]1@2n^KP2
045Yh@80_[Vh00<0@FWQ0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2OVj00
Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]
08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`040:BNS`03045Yh@2TWXl0Y9j?0080Y9j?00<0
[Jf]0;6[W@2aZid02@2aZid0102][Jd0@FWQ0;6[W@2][Jd30;VbYP80@FWQ0`2i/ZH2045Yh@D0^K:V
00D0[Jf]0;jg[02n]j`0_[N/045Yh@050;jg[0<0@FWQ1`2n]j`00`11JN40`KZ`0<6j/00?0<6j/0P0
[Jf]4033_K<00`2][Jd0aKje0<Fn]@0=0<Fn]@@0@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00`0al6l0`11JN420<O1_003
0:f][@36`;`0a/2l00<0a/2l0P11JN450<K0_080@FWQ1036`;`0102][Jd0@FWQ045Yh@11JN420<>m
^`03045Yh@33_K/0@FWQ00@0`kfk0P11JN401033_K/0[Jf]0:f][@2][Jd70;ji^006045Yh@2n^KP0
@FWQ0;ji^011JN40[Jf]2P2d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT0
0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe
0:f][@0208Z5M@030:f][@2TWXl0Y9j?00@0Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl00`2][Jd0/J^M
0;6[W@0:0;6[W@04045Yh@2][Jd0[Jf]0:f][@80^K:V0P11JN430;VbYP80@FWQ1@2i/ZH01@2][Jd0
_[N/0;jg[02n]j`0@FWQ00D0_[N/0P11JN480;jg[003045Yh@31^[00`KZ`0080`KZ`00<0@FWQ0<6j
/031^[003031^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0?0<Fn
]@D0@FWQ00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]
0<O1_037`K`02@37`K`4045Yh@@0al6l00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_004
0<K0_080@FWQ1036`;`0102][Jd0@FWQ045Yh@11JN420<>m^`04045Yh@33_K/0`kfk045Yh@<0`kfk
0P11JN400`2][Jd0`kfk0:f][@080;ji^006045Yh@2n^KP0@FWQ045Yh@2n^KP0[Jf]2P2d/;400`2]
[Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd01P2TWXl00`11JN40
Y9j?0:BNS`020:BNS`030:f][@2aZid0/J^M00T0/J^M00D0@FWQ0;6[W@2aZid0[Jf]0;VbYP020:f]
[@80@FWQ0`2i/ZH00`11JN40^K:V0;VbYP040;VbYP050:f][@2n]j`0_[N/0;jg[011JN401P2n]j`0
0`11JN40_[N/0;jg[0050;jg[080@FWQ1031^[000`11JN40`KZ`0<6j/00<0<6j/0030:f][@33_K<0
`kfc00h0`kfc2`2][Jd<0<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/0
0`2][Jd0al6l0<O1_00;0<O1_080@FWQ1037`K`00`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0
a/2l00@0a/2l0P11JN440<K0_0040:f][@11JN40@FWQ045Yh@80`kfk00@0@FWQ0<>m^`33_K/0@FWQ
0`2][Jd2045Yh@80`kfk00<0[Jf]0;ji^02n^KP01P2n^KP00`11JN40_[Vh0;ji^0020;ji^0030:f]
[@2d/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd60:BNS`03045Yh@2T
WXl0Y9j?0080Y9j?00<0[Jf]0;6[W@2aZid02@2aZid01011JN40/J^M0;6[W@2][Jd30;VbYP80@FWQ
0P2][Jd00`2i/ZH0@FWQ045Yh@050;VbYP050:f][@2n]j`0_[N/0;jg[011JN401P2n]j`00`11JN40
_[N/0;jg[0050;jg[080@FWQ1031^[000`11JN40`KZ`0<6j/00<0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0
[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`L0@FWQ1`37`K`2045Yh@@0al6l00<0[Jf]0<K0_036
`;`00`36`;`00`11JN40a/2l0<K0_0040<K0_080@FWQ1036`;`02P2][Jd0@FWQ045Yh@33_K/0@FWQ
0<>m^`11JN40`kfk0:f][@11JN430<>m^`80@FWQ0P33_K/00`2][Jd0_[Vh0;ji^0040;ji^080@FWQ
1@2n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0
L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0
102:QGD00`2][Jd0Y9j?0:BNS`040:BNS`03045Yh@2TWXl0Y9j?0080Y9j?00<0[Jf]0;6[W@2aZid0
2@2aZid01011JN40/J^M0;6[W@2][Jd30;VbYP80@FWQ0P2i/ZH0102][Jd0@FWQ045Yh@2][Jd40;Vb
YP040:f][@2n]j`0_[N/0;jg[080@FWQ1@2n]j`00`11JN40_[N/0;jg[0050;jg[080@FWQ0`31^[00
0`11JN40`KZ`045Yh@090<6j/0D0@FWQ0P33_K<2045YhA40`kfc00<0[Jf]0<Fn]@35_[D03`35_[D2
045Yh@l0[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA
0<S1^`030:f][@38`K/0b<6k0100b<6k1011JN440<O1_0<0@FWQ1P37`K`2045Yh@@0al6l00<0[Jf]
0<K0_036`;`00`36`;`2045Yh@D0a/2l0P11JN440<K0_00:0:f][@11JN40@FWQ0<>m^`11JN40[Jf]
045Yh@2][Jd0`kfk045Yh@<0`kfk0P11JN420<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`
/@2d/;401P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3P
iP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@@0Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl0
0`2][Jd0/J^M0;6[W@090;6[W@04045Yh@2aZid0/J^M0:f][@<0^K:V0P11JN430;VbYP80@FWQ00H0
^K:V0:f][@2][Jd0[Jf]0;VbYP2][Jd30;jg[080@FWQ1@2n]j`00`11JN40_[N/0;jg[0050;jg[0<0
@FWQ0P31^[03045Yh@P0`KZ`0P11JN430<6j/0030:f][@11JN40@FWQ0080@FWQ1033_K<4045Yh@T0
`kfc00<0[Jf]0<Fn]@35_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ1@37`K`2045Yh@H0
al6l0P11JN440<O1_0030:f][@36`;`0a/2l00<0a/2l0P11JN450<K0_080@FWQ1036`;`01`000000
@FWQ0:f][@2][Jd0@FWQ0<>m^`11JN400P33_K/01011JN40`kfk0<>m^`33_K/2045Yh@80`kfk00D0
[Jf]0;ji^02n^KP0_[Vh045Yh@090;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d/;40
[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1S
H5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]0P2TWXl00`11JN40Y9j?0:BNS`020:BN
S`030:f][@2aZid0/J^M00T0/J^M00@0@FWQ0;6[W@2aZid0[Jf]0`2i/ZH2045Yh@<0^K:V0P11JN44
0;VbYP<0[Jf]0`2n]j`2045Yh@@0_[N/00<0@FWQ0;jg[02n]j`0102n]j`2045Yh@040<6j/011JN40
`KZ`0<6j/0<0@FWQ1`31^[02045Yh@@0`KZ`00<0[Jf]0<>m/`11JN400P11JN460<>m/`@0@FWQ1`33
_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k0180b<6k0P11JN460<O1_080@FWQ1@37`K`2045Yh@@0al6l00<0[Jf]0<K0_036`;`01036
`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ0P36`;`30:f][@03045Yh@33_K/0`kfk00<0@FWQ0`33
_K/00`11JN40`kfk0<>m^`02045Yh@80`kfk00D0[Jf]0;ji^02n^KP0_[Vh045Yh@090;ji^0030:f]
[@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0
L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2T
WXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f][@2aZid0/J^M00T0/J^M00@0@FWQ0;6[W@2a
Zid0[Jf]0`2i/ZH2045Yh@<0^K:V0P11JN450;VbYP030:f][@2n]j`0[Jf]00<0[Jf]00@0_[N/045Y
h@11JN40_[N/0P11JN460;jg[080@FWQ00@0`KZ`045Yh@31^[00`KZ`0`11JN470<6j/080@FWQ1031
^[000`2][Jd0`kfc0<>m/`02045Yh@H0`kfc0P11JN490<>m/`030:f][@35_[D0aKje0080aKje1011
JN490<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k0P11
JN460<O1_080@FWQ1@37`K`2045Yh@@0al6l00<0[Jf]0<K0_036`;`01@36`;`7045Yh@80[Jf]0P36
`;`2045Yh@80`kfk0P11JN440<>m^`03045Yh@33_K/0`kfk0080@FWQ0P33_K/01@2][Jd0_[Vh0;ji
^02n^KP0@FWQ00T0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5
M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M00T0/J^M00@0@FWQ0;6[
W@2aZid0[Jf]0`2i/ZH2045Yh@<0^K:V00<0@FWQ0;VbYP11JN400P2i/ZH00`11JN40^K:V0:f][@05
0;jg[0<0[Jf]0`11JN460;jg[080@FWQ00L0`KZ`045Yh@31^[00`KZ`045Yh@31^[00@FWQ00L0`KZ`
00<0@FWQ0<6j/031^[000`31^[000`2][Jd0`kfc0<>m/`02045Yh@H0`kfc0P11JN490<>m/`030:f]
[@35_[D0aKje0080@FWQ0`35_[D00`11JN40aKje0<Fn]@020<Fn]@80@FWQ0`35_[D2045Yh@<0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ1`37`K`2045Yh@@0al6l
0P11JN440<O1_0030:f][@36`;`0a/2l00D0a/2l102][Jd00`36`;`0@FWQ045Yh@040<K0_080@FWQ
0`33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ0P33_K/2045Yh@030<>m^`2][Jd0_[Vh0080_[Vh
00<0@FWQ0;ji^02n^KP01`2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@03
0:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M00T0/J^M00<0@FWQ0;6[W@2]
[Jd0102i/ZH02011JN40^K:V0;VbYP11JN40^K:V045Yh@2i/ZH0@FWQ0P2i/ZH2045Yh@040:f][@2n
]j`0_[N/0;jg[080@FWQ102n]j`2045Yh@80[Jf]102n]j`2045Yh@030<6j/011JN40`KZ`0080@FWQ
00<0`KZ`045Yh@31^[001P31^[000`11JN40`KZ`0<6j/0030<6j/0030:f][@33_K<0`kfc0080@FWQ
1P33_K<2045Yh@T0`kfc00@0[Jf]0<Fn]@11JN40@FWQ1@35_[D00`11JN40aKje0<Fn]@02045Yh@@0
aKje0P11JN420<Fn]@<0@FWQ2@36_kL6045Yh@<0a[ng1011JN400`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37`KX01@11JN480<O1^P03045Yh@2][Jd0b<6k01D0
b<6k00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@L0al6l0P11JN440<O1_080@FWQ1037`K`00`2][Jd0
a/2l0<K0_0050:f][@D0a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@<0`kfk00<0@FWQ0<>m^`33
_K/00P11JN440<>m^`80@FWQ00<0`kfk0:f][@2n^KP00P2n^KP2045Yh@P0_[Vh0`2][Jd80;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C
0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd;0;6[W@03045Yh@2aZid0[Jf]00@0^K:V
00@0@FWQ0;VbYP2i/ZH0^K:V0P11JN40102i/ZH0@FWQ0;VbYP2i/ZH2045Yh@040:f][@2n]j`0_[N/
0;jg[080@FWQ102n]j`2045Yh@80_[N/0`2][Jd2045Yh@040:f][@31^[00@FWQ0<6j/080@FWQ0P31
^[000`11JN40`KZ`0<6j/0030<6j/080@FWQ1@31^[000`2][Jd0`kfc0<>m/`02045Yh@H0`kfc0P11
JN490<>m/`040:f][@35_[D0@FWQ045Yh@H0aKje0`11JN450<Fn]@80@FWQ00D0aKje045Yh@35_[D0
[Jf]0<Jo]`02045Yh@T0a[ng0P11JN470<Jo]`@0@FWQ0`37`KP6045Yh@L0al6h1011JN400`37`KP0
[Jf]0<O1^P050<O1^P03045Yh@37`KX0@FWQ00D0al6j00<0@FWQ0<O1^P37`KX01037`KX00`11JN40
al6j045Yh@0F0<S1^`030:f][@38`K/0b<6k0180b<6k0P11JN480<O1_003045Yh@37`K`0al6l0080
al6l0P11JN420<O1_0D0[Jf]2P36`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ0`33_K/00`11JN40
`kfk0<>m^`060<>m^`80@FWQ00<0`kfk0:f][@2n^KP00P2n^KP2045Yh@L0_[Vh0P2][Jd:0;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@X0/J^M00<0@FWQ0;6[W@2][Jd00`2i/ZH2045Yh@L0^K:V
0`11JN400`2i/ZH0[Jf]0;jg[0020;jg[080@FWQ102n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ
0P2][Jd01011JN40[Jf]045Yh@11JN420<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11JN450<6j/003
0:f][@33_K<0`kfc0080@FWQ1P33_K<2045Yh@T0`kfc00@0[Jf]0<Fn]@11JN40@FWQ1`35_[D2045Y
h@D0aKje0`11JN420<Fn]@030:f][@36_kL0a[ng0080@FWQ2036_kL2045Yh@L0a[ng0P11JN400`2]
[Jd0al6h0<O1^0040<O1^080@FWQ1`37`KP3045Yh@<0al6h0P11JN460<O1^P80@FWQ1`37`KX00`11
JN40al6j0<O1^P040<O1^P03045Yh@2][Jd0b<6k01D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/2045Y
h@P0al6l00D0@FWQ0<O1_037`K`0al6l0:f][@02045Yh@80[Jf]0P37`K`00`2][Jd0a/2l0<K0_004
0<K0_003045Yh@36`;`0a/2l00<0a/2l00<0@FWQ0<K0_036`;`00`36`;`3045Yh@`0`kfk00<0@FWQ
0<>m^`2][Jd00P2n^KP00`11JN40_[Vh045Yh@050;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;40
0`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BN
S`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@L0/J^M00<0@FWQ0;6[W@2][Jd00`2i/ZH00`11
JN40^K:V0;VbYP0:0;VbYP030:f][@2n]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11
JN40_[N/0;jg[0040;jg[080@FWQ00@0[Jf]0<6j/011JN40`KZ`0P11JN420:f][@03045Yh@2][Jd0
[Jf]00<0`KZ`0P11JN450<6j/0030:f][@33_K<0`kfc0080@FWQ1P33_K<2045Yh@T0`kfc00@0[Jf]
0<Fn]@11JN40@FWQ1`35_[D2045Yh@D0aKje0P11JN430<Fn]@040:f][@36_kL0a[ng0<Jo]`80@FWQ
1`36_kL2045Yh@L0a[ng0P11JN400`2][Jd0al6h0<O1^0040<O1^080@FWQ1P37`KP2045Yh@H0al6h
00<0@FWQ0<O1^P37`KX01037`KX2045Yh@L0al6j00<0@FWQ0<O1^P37`KX01@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k0P11JN470<O1_0030:f][@11JN40[Jf]0080[Jf]
00@0al6l045Yh@11JN40@FWQ0`37`K`00`2][Jd0@FWQ0<K0_0040<K0_003045Yh@36`;`0a/2l00<0
a/2l00@0@FWQ0<K0_036`;`0a/2l0`11JN4>0<>m^`03045Yh@33_K/0[Jf]0080_[Vh00<0@FWQ0;ji
^011JN400`2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nK
X080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@<0/J^M0`11JN40102aZid0[Jf]0;VbYP2i/ZH2045Y
h@`0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`01@11JN40_[N/0;jg[02n]j`0@FWQ00H0_[N/0P11JN40
0`2][Jd0`KZ`0<6j/003045Yh@80`KZ`00<0@FWQ0<6j/031^[000`2][Jd2045Yh@80[Jf]0`31^[00
0`2][Jd0@FWQ045Yh@02045Yh@H0`kfc0P11JN490<>m/`040:f][@35_[D0@FWQ045Yh@L0aKje0P11
JN450<Fn]@80@FWQ0`35_[D0102][Jd0a[ng0<Jo]`36_kL2045Yh@L0a[ng0P11JN470<Jo]`80@FWQ
00<0[Jf]0<O1^037`KP01037`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6j
0<O1^P030<O1^P03045Yh@37`KX0al6j00H0al6j00<0@FWQ0<O1^P37`KX01@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k0P11JN420<O1_0D0[Jf]00<0al6l045Yh@37`K`0
0`37`K`3045Yh@<0al6l0P11JN450<K0_004045Yh@36`;`0a/2l0<K0_080@FWQ1P36`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`04045Yh@2][Jd0_[Vh045Yh@<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a
00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP03
0:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0
[Jf]0P2aZid3045Yh@80^K:V00<0@FWQ0;VbYP2i/ZH02`2i/ZH00`2][Jd0_[N/0;jg[0040;jg[0<0
@FWQ1P2n]j`2045Yh@040;jg[02][Jd0`KZ`0<6j/080@FWQ0`31^[000`11JN40`KZ`0<6j/0030<6j
/080@FWQ0P31^[070:f][@<0@FWQ1033_K<2045Yh@T0`kfc00@0[Jf]0<Fn]@11JN40@FWQ1`35_[D2
045Yh@D0aKje0P11JN430<Fn]@040:f][@36_kL0a[ng0<Jo]`80@FWQ1`36_kL2045Yh@L0a[ng0P11
JN400`2][Jd0al6h0<O1^0040<O1^080@FWQ1P37`KP00`11JN40al6h0<O1^0060<O1^0030:f][@37
`KX0al6j00<0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@L0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0@0<S1^`80[Jf]0P11JN420:f][@H0al6l00<0@FWQ0<O1_037`K`00P37
`K`3045Yh@<0al6l0P11JN460<K0_0<0@FWQ2@36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0@FWQ00<0
_[Vh0:f][@2][Jd0202n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0
[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid30:f][@030;6[W@2][Jd0@FWQ0080@FWQ3@2i/ZH0
0`2][Jd0_[N/0;jg[00;0;jg[0@0@FWQ00@0_[N/0:f][@31^[00`KZ`0P11JN430<6j/003045Yh@31
^[00`KZ`00<0`KZ`0P11JN450<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]0P11JN490<>m/`030:f]
[@35_[D0aKje0080@FWQ1P35_[D2045Yh@D0aKje0P11JN430<Fn]@030:f][@36_kL0a[ng0080a[ng
0P11JN460<Jo]`80@FWQ1`36_kL2045Yh@030:f][@37`KP0al6h00@0al6h0P11JN450<O1^080@FWQ
2037`KP00`2][Jd0al6j0<O1^P0;0<O1^P03045Yh@37`KX0al6j00H0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0P38`K/2045Yh@P0al6l00<0@FWQ0<O1_037`K`0
0P37`K`2045Yh@060<O1_011JN40al6l0<O1_02][Jd0@FWQ4P36`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX002
09nKX0030:f][@2`h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2]
[Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/
00d0_[N/1011JN420<6j/080@FWQ1031^[000`11JN40`KZ`0<6j/0020<6j/080@FWQ1@31^[000`2]
[Jd0`kfc0<>m/`080<>m/`80@FWQ1P2][Jd30<>m/`040:f][@35_[D0aKje0<Fn]@<0@FWQ1035_[D2
045Yh@D0aKje0P11JN430<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN460<Jo]`80@FWQ1`36_kL2
045Yh@030:f][@37`KP0al6h00@0al6h0P11JN450<O1^080@FWQ2037`KP00`2][Jd0al6j0<O1^P0:
0<O1^P80@FWQ1`37`KX00`11JN40[Jf]0<S1^`0E0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2@38
`K/2045Yh@P0al6l00<0@FWQ0<O1_037`K`00P37`K`2045Yh@80al6l1011JN4B0<K0_0030:f][@33
_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2]
[Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[000P11JN420<6j/0<0@FWQ1031^[02045Yh@D0`KZ`00<0[Jf]0<>m/`33_K<02033_K<2
045Yh@H0`kfc2@2][Jd00`35_[D0@FWQ045Yh@020<Fn]@80@FWQ1@35_[D2045Yh@<0aKje00<0[Jf]
0<Jo]`36_kL00P36_kL2045Yh@H0a[ng0P11JN470<Jo]`80@FWQ00<0[Jf]0<O1^037`KP01037`KP2
045Yh@D0al6h0P11JN480<O1^0030:f][@37`KX0al6j00P0al6j0`11JN480<O1^P03045Yh@2][Jd0
b<6k0100b<6k2@2][JdA0<S1^`80@FWQ2037`K`00`11JN40al6l0<O1_004045Yh@@0al6l00<0[Jf]
0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP0
0`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5
M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001P31^[03045Yh@80`KZ`0P11JN450<6j
/0030:f][@33_K<0`kfc00P0`kfc0P11JN490<>m/`030:f][@35_[D0aKje00<0aKje0`2][Jd4045Y
h@D0[Jf]0P11JN430<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN460<Jo]`80@FWQ1`36_kL2045Y
h@030:f][@37`KP0al6h00@0al6h0P11JN450<O1^080@FWQ2037`KP00`2][Jd0al6j0<O1^P060<O1
^P@0@FWQ2@37`KX00`11JN40[Jf]0<S1^`040<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1
^`80@FWQ2037`K`00`11JN40al6l0<O1_0090<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`
/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0
^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0
`KZ`0P11JN450<6j/0030:f][@33_K<0`kfc00P0`kfc0`11JN440<>m/`05045Yh@33_K<0`kfc0<>m
/`2][Jd00P35_[D00`11JN40aKje0<Fn]@050<Fn]@80@FWQ1@35_[D2045Yh@P0[Jf]0P11JN450:f]
[@030<Jo]`11JN40@FWQ00L0a[ng0P11JN400`2][Jd0al6h0<O1^0040<O1^080@FWQ1@37`KP2045Y
h@P0al6h00<0[Jf]0<O1^P37`KX01037`KX4045Yh@030<O1^P2][Jd0[Jf]00P0[Jf]00<0@FWQ0:f]
[@2][Jd0102][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k0P11JN470<O1_080@FWQ2`37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh
00`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP03
0:f][@2TWXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0
[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00;0<6j/080@FWQ1@31^[000`2][Jd0
`kfc0<>m/`080<>m/`<0@FWQ0`33_K<00`11JN40`kfc045Yh@020<>m/`030:f][@35_[D0aKje0080
@FWQ1P35_[D00`11JN40aKje0<Fn]@040<Fn]@80@FWQ0P35_[D00`000000[Jf]0<Jo]`020<Jo]`80
@FWQ1P36_kL00`2][Jd0@FWQ045Yh@070:f][@80@FWQ1`2][Jd2045Yh@D0[Jf]0P11JN480:f][@03
045Yh@2][Jd0[Jf]00<0[Jf]0`11JN430:f][@<0al6j00<0@FWQ0<O1^P37`KX01037`KX00`11JN40
[Jf]0<S1^`0E0<S1^`030:f][@38`K/0b<6k0180b<6k0P11JN470<O1_080@FWQ2`37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^003
0:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M
0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`00/0`KZ`
0P11JN450<6j/0030:f][@33_K<0`kfc00D0`kfc1@11JN400`33_K<0@FWQ0<>m/`020<>m/`80@FWQ
0P33_K<00`2][Jd0aKje0<Fn]@02045Yh@H0aKje00<0@FWQ0<Fn]@35_[D01035_[D2045Yh@<0aKje
00@0[Jf]0<Jo]`36_kL0a[ng0P11JN470<Jo]`80@FWQ1`36_kL2045Yh@030:f][@37`KP0al6h00@0
al6h0P11JN460<O1^003045Yh@37`KP0al6h00D0al6h00<0@FWQ0:f][@11JN401037`KX00`11JN40
al6j0<O1^P050<O1^P80@FWQ1P37`KX00`11JN40[Jf]0<S1^`0E0<S1^`030:f][@38`K/0b<6k0180
b<6k0P11JN470<O1_080@FWQ2`37`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00
I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00;0<6j/080@FWQ1@31^[001@2][Jd0`kfc
0<>m/`33_K<0@FWQ00X0`kfc1011JN430<>m/`050:f][@35_[D0aKje0<Fn]@11JN401@35_[D00`11
JN40aKje0<Fn]@050<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`02045Yh@P0a[ng0P11JN470<Jo
]`80@FWQ00<0[Jf]0<O1^037`KP01037`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP01P37`KP2045Y
h@@0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@H0al6j00<0@FWQ0:f][@38`K/05@38`K/00`2]
[Jd0b<6k0<S1^`0B0<S1^`80@FWQ1P37`K`2045Yh@`0al6l00<0[Jf]0<K0_036`;`02@36`;`50:f]
[@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a
00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031
^[003031^[02045Yh@@0`KZ`00D0[Jf]0<>m/`33_K<0`kfc045Yh@0A0<>m/`030:f][@35_[D0aKje
0080aKje1@11JN480<Fn]@<0@FWQ0P35_[D0102][Jd0a[ng045Yh@11JN490<Jo]`80@FWQ1P36_kL2
045Yh@030<Jo]`2][Jd0al6h00D0al6h0P11JN460<O1^080@FWQ1`37`KP00`11JN40al6j0<O1^P03
0<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN450<O1^P80@FWQ00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ1P37`K`2045Yh@`0al6l00<0[Jf]0<K0_036`;`01@36`;`4
0:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40
];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00
`KZ`00`0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc0080@FWQ4@33_K<00`2][Jd0aKje0<Fn]@0=
0<Fn]@@0@FWQ00<0aKje045Yh@11JN400`11JN4:0<Jo]`@0@FWQ1036_kL2045Yh@030<Jo]`2][Jd0
al6h00D0al6h0P11JN470<O1^080@FWQ1@37`KP00`11JN40[Jf]0<O1^P050<O1^P03045Yh@37`KX0
al6j00@0al6j0P11JN450<O1^P80@FWQ00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B
0<S1^`80@FWQ1@37`K`2045Yh@d0al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[
0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd0
0`2n]j`0[Jf]0<6j/00>0<6j/003045Yh@31^[00`KZ`0080`KZ`00<0[Jf]0<>m/`33_K<00P11JN4A
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02P36_kL2045Yh@80a[ng1@11JN42
0<Jo]`030:f][@37`KP0al6h0080al6h1011JN490<O1^0D0@FWQ00<0al6h0:f][@37`KX01P37`KX6
045Yh@030<O1^P11JN40al6j00@0al6j0P11JN400`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k0180b<6k0P11JN450<O1_080@FWQ2`37`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]3@31^[001P11JN40`KZ`0<6j/031^[00
[Jf]0<>m/`<0@FWQ4@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00X0a[ng0P11
JN490<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX04P37`KX2045Yh@030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@@0al6l0P11JN470<O1_0D0[Jf]0P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n
^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@L0`KZ`00@0@FWQ0<6j/031^[00[Jf]
0P11JN400`33_K<0@FWQ0<>m/`0@0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
2P36_kL2045Yh@T0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0B0<O1^P80@FWQ
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ00<0al6l045Yh@11JN40
0P11JN420<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]00@0
`KZ`045Yh@11JN40@FWQ0`33_K<00`11JN40`kfc0<>m/`0?0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL02P36_kL2045Yh@T0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0B0<O1^P80@FWQ00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`D0@FWQ
00<0al6l0:f][@2][Jd00`2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2]
[JdB0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02P36_kL2045Yh@T0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0B0<O1^P80@FWQ00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd3
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng00X0a[ng0P11JN490<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX04P37
`KX3045YhAH0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2]
[JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0:0<Jo]`80@FWQ2@36_kL00`2][Jd0al6h0<O1^004
0<O1^003045Yh@37`KP0al6h00h0al6h00<0[Jf]0<O1^P37`KX04P37`KX2045Yh@030:f][@38`K/0
b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H3
0:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc0100`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng00X0a[ng0P11JN490<Jo]`030:f][@37`KP0
al6h00<0al6h00<0@FWQ0<O1^011JN403`37`KP00`2][Jd0al6j0<O1^P0C0<O1^P03045Yh@2][Jd0
b<6k0100b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL01`36_kL5045Yh@T0a[ng00<0[Jf]0<O1
^037`KP01037`KP00`11JN40al6h0<O1^00>0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880
/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0
al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]
1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V
0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2]
[Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H1
0?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0
/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]
0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool0
0:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB
0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0
[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`
h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52029 .33411 m
.51695 .33089 L
s
.51695 .33089 m
.51361 .33087 L
s
.52197 .33411 m
.51695 .33089 L
s
.51361 .33087 m
.51026 .33404 L
s
.54202 .33074 m
.53534 .33083 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50692 .33079 m
.50025 .33068 L
s
.55036 .33057 m
.54537 .33389 L
s
.55369 .33048 m
.55036 .33057 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47664 .32194 m
.48814 .32235 L
s
0 0 0 r
.57537 .34166 m
.57542 .349 L
s
.59501 .32854 m
.60163 .32815 L
s
.57542 .349 m
.57603 .34122 L
s
.255 .412 .882 r
.51287 .33858 m
.52446 .33862 L
s
0 0 0 r
.45052 .32861 m
.45458 .32885 L
s
.255 .412 .882 r
.53108 .33859 m
.54266 .33844 L
s
.54927 .33831 m
.56082 .33798 L
s
.49302 .33823 m
.49632 .34057 L
s
.48972 .33814 m
.49302 .33823 L
s
.49302 .33823 m
.49797 .34061 L
s
0 0 0 r
.52364 .36632 m
.52488 .35916 L
s
.52532 .36632 m
.52656 .35915 L
s
.255 .412 .882 r
.49797 .34061 m
.50127 .34518 L
s
.48642 .3403 m
.48972 .33814 L
s
.49632 .34057 m
.49961 .34515 L
s
.50127 .34518 m
.50291 .35199 L
s
.4831 .3447 m
.48642 .3403 L
s
.49961 .34515 m
.50125 .35196 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47162 .33748 m
.47327 .33755 L
s
.46833 .33958 m
.47162 .33748 L
s
.46997 .33966 m
.47162 .33748 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57235 .3398 m
.57725 .33732 L
s
.56909 .34445 m
.57235 .3398 L
s
.50289 .35651 m
.50291 .35199 L
s
.57399 .33972 m
.57725 .33732 L
s
.57725 .33732 m
.58053 .33715 L
s
.50124 .35648 m
.50125 .35196 L
s
.57073 .34438 m
.57399 .33972 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48298 .36961 m
.48321 .32219 L
s
.48132 .36956 m
.48156 .32213 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4683 .3441 m
.46997 .33966 L
s
.58053 .33715 m
.58545 .33915 L
s
.46666 .34402 m
.46833 .33958 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51947 .38618 m
.51949 .33861 L
s
.5178 .38617 m
.51783 .33861 L
s
.53605 .33854 m
.53609 .36339 L
s
.5377 .33852 m
.53775 .36337 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55423 .33818 m
.55435 .36985 L
s
.55588 .33814 m
.55601 .36981 L
s
.56748 .3513 m
.56909 .34445 L
s
.56913 .35123 m
.57073 .34438 L
s
.50122 .36327 m
.50289 .35651 L
s
.49956 .36324 m
.50124 .35648 L
s
.46017 .3369 m
.46342 .33934 L
s
.45528 .33662 m
.46017 .3369 L
s
.46342 .33934 m
.46666 .34402 L
s
.46819 .35995 m
.4683 .3441 L
s
.58545 .33915 m
.58875 .34349 L
s
.46652 .36441 m
.46666 .34402 L
s
.56748 .3513 m
.5675 .35582 L
s
.452 .33868 m
.45528 .33662 L
s
.45037 .33858 m
.45528 .33662 L
s
.51948 .36346 m
.5228 .368 L
s
.56913 .35123 m
.56915 .35576 L
s
.53443 .36794 m
.53609 .36339 L
s
.53609 .36792 m
.53775 .36337 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49789 .36774 m
.50122 .36327 L
s
.49623 .36771 m
.49956 .36324 L
s
.5675 .35582 m
.56919 .36256 L
s
.45033 .3431 m
.452 .33868 L
s
.5228 .368 m
.52779 .37026 L
s
.56915 .35576 m
.57084 .36249 L
s
.53111 .37024 m
.53443 .36794 L
s
.53111 .37024 m
.53609 .36792 L
s
.44871 .343 m
.45037 .33858 L
s
.52779 .37026 m
.53111 .37024 L
s
.60007 .33598 m
.60173 .34039 L
s
.60007 .33598 m
.60016 .34503 L
s
.49291 .3699 m
.49789 .36774 L
s
.49291 .3699 m
.49623 .36771 L
s
.48301 .3628 m
.48629 .36745 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45029 .34763 m
.45033 .3431 L
s
.54938 .36997 m
.55601 .36981 L
s
0 0 0 r
.58548 .36469 m
.59539 .36413 L
s
.255 .412 .882 r
.44867 .34753 m
.44871 .343 L
s
.4896 .36981 m
.49291 .3699 L
s
.56919 .36256 m
.57251 .36696 L
s
.48629 .36745 m
.4896 .36981 L
s
.57084 .36249 m
.57416 .3669 L
s
.60173 .34039 m
.60333 .33801 L
s
.60333 .33801 m
.60654 .33551 L
s
.45513 .35473 m
.46493 .35752 L
s
.46493 .35752 m
.46655 .35987 L
s
.60016 .34503 m
.60173 .34039 L
s
.46652 .36441 m
.46819 .35995 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45021 .3571 m
.45103 .35927 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45029 .34763 m
.45188 .35226 L
s
.47637 .36938 m
.48298 .36961 L
s
.44867 .34753 m
.45025 .35216 L
s
.45188 .35226 m
.45513 .35473 L
s
.45025 .35216 m
.45513 .35473 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57416 .3669 m
.57747 .36902 L
s
.5856 .35953 m
.58722 .35717 L
s
.58722 .35717 m
.58888 .35935 L
s
.57251 .36696 m
.57747 .36902 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59697 .35673 m
.59698 .35705 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60654 .33551 m
.61298 .33501 L
s
.5856 .35953 m
.58726 .36171 L
s
.46486 .3666 m
.46652 .36441 L
s
.61298 .33501 m
.61621 .33701 L
s
0 0 0 r
.40838 .32829 m
.4085 .32822 L
s
.255 .412 .882 r
.58888 .35935 m
.58889 .36162 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46156 .36871 m
.46486 .3666 L
s
.51281 .38614 m
.51947 .38618 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57747 .36902 m
.58239 .36879 L
s
.55439 .38122 m
.55606 .38346 L
s
.55274 .38354 m
.55439 .38122 L
s
.58566 .36634 m
.58889 .36162 L
s
.41664 .33361 m
.4278 .33463 L
s
.61621 .33701 m
.61784 .33914 L
s
.55274 .38354 m
.55441 .38578 L
s
.58239 .36879 m
.58566 .36634 L
s
.55441 .38578 m
.55606 .38346 L
s
.45501 .36836 m
.46156 .36871 L
s
.45017 .36124 m
.4518 .36134 L
s
.45178 .36362 m
.4518 .36134 L
s
.45015 .36352 m
.45017 .36124 L
s
.61784 .33914 m
.61792 .34595 L
s
.42262 .36605 m
.42301 .3342 L
s
.60189 .35626 m
.60511 .35376 L
s
.60028 .35864 m
.60189 .35626 L
s
.60511 .35376 m
.61313 .34861 L
s
.60028 .35864 m
.60033 .36319 L
s
.45015 .36352 m
.45176 .36589 L
s
.42101 .36591 m
.42141 .33406 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40523 .32603 m
.40525 .32471 L
s
.5 Mabswid
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45176 .36589 m
.45501 .36836 L
s
.60191 .35854 m
.60513 .35604 L
s
.60031 .36092 m
.60191 .35854 L
s
.60513 .35604 m
.61316 .35088 L
s
.61313 .34861 m
.61632 .34608 L
s
.61632 .34608 m
.6179 .34368 L
s
.60033 .36319 m
.60198 .36536 L
s
.61316 .35088 m
.61635 .34835 L
s
.61635 .34835 m
.61792 .34595 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60198 .36536 m
.60524 .36741 L
s
.63054 .33343 m
.63215 .33554 L
s
.62898 .33585 m
.63054 .33343 L
s
.62898 .33585 m
.6306 .33797 L
s
.43393 .3624 m
.43557 .36024 L
s
.43557 .36024 m
.43716 .36264 L
s
.43714 .36492 m
.43716 .36264 L
s
.6306 .33797 m
.63215 .33554 L
s
.43549 .36708 m
.43714 .36492 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43393 .3624 m
.43552 .3648 L
s
.42278 .35237 m
.4243 .35934 L
s
.43065 .36671 m
.43549 .36708 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59724 .38631 m
.59725 .38663 L
s
.5 Mabswid
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61806 .35731 m
.61816 .36643 L
s
.6165 .362 m
.61806 .35731 L
s
.60524 .36741 m
.61172 .36694 L
s
.61172 .36694 m
.61492 .36441 L
s
.61492 .36441 m
.6165 .362 L
s
.6165 .362 m
.61816 .36643 L
s
.4243 .35934 m
.42746 .36417 L
s
.42746 .36417 m
.43065 .36671 L
s
.63075 .34934 m
.63271 .3766 L
s
.62952 .3769 m
.63075 .34934 L
s
.40241 .3344 m
.40548 .33929 L
s
.39775 .33159 m
.40241 .3344 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4048 .35557 m
.40483 .35334 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4006 .35017 m
.41164 .35133 L
s
.40532 .35068 m
.40558 .33247 L
s
.40689 .35084 m
.40715 .33264 L
s
.39464 .33122 m
.39775 .33159 L
s
.41622 .36547 m
.42262 .36605 L
s
.39149 .33312 m
.39464 .33122 L
s
.38995 .33293 m
.39464 .33122 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63093 .36302 m
.63111 .37675 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38833 .3373 m
.39149 .33312 L
s
.38678 .3371 m
.38995 .33293 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62952 .3769 m
.63117 .38134 L
s
.3867 .34167 m
.38833 .3373 L
s
.40499 .37356 m
.40667 .36684 L
s
.63117 .38134 m
.63271 .3766 L
s
.38516 .34147 m
.38678 .3371 L
s
.38505 .34833 m
.3867 .34167 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40647 .3806 m
.40667 .36684 L
s
.38351 .34813 m
.38516 .34147 L
s
.40176 .37782 m
.40499 .37356 L
s
.40499 .37356 m
.40647 .3806 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38485 .35979 m
.38505 .34833 L
s
0 0 0 r
.36326 .32245 m
.36181 .31895 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39701 .37962 m
.40176 .37782 L
s
.38331 .3596 m
.38351 .34813 L
s
.39388 .37928 m
.39701 .37962 L
s
.38485 .35979 m
.38628 .36687 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3671 .32749 m
.37255 .36048 L
s
.38331 .3596 m
.38474 .36668 L
s
.39079 .37662 m
.39388 .37928 L
s
.38924 .37644 m
.39388 .37928 L
s
.38628 .36687 m
.38776 .37166 L
s
.38776 .37166 m
.39079 .37662 L
s
.38474 .36668 m
.38621 .37147 L
s
.38621 .37147 m
.38924 .37644 L
s
.368 .35985 m
.37713 .3611 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36147 .34782 m
.3615 .34947 L
s
.36203 .37798 m
.36209 .38155 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36048 .35874 m
.3671 .32749 L
s
.36198 .35897 m
.36697 .33436 L
s
.35519 .3256 m
.36048 .35874 L
s
.34862 .35686 m
.35519 .3256 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35009 .3571 m
.35505 .33248 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36061 .37962 m
.36064 .37775 L
s
.5 Mabswid
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34061 .32303 m
.34205 .32329 L
s
.33769 .32479 m
.34061 .32303 L
s
.33912 .32506 m
.34061 .32303 L
s
.34424 .35612 m
.35452 .35782 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33758 .3294 m
.33912 .32506 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33615 .32912 m
.33769 .32479 L
s
.33721 .34557 m
.33758 .3294 L
s
.33341 .32396 m
.33615 .32912 L
s
.33567 .34994 m
.33615 .32912 L
s
.33063 .32109 m
.33341 .32396 L
s
.32641 .32023 m
.33063 .32109 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33567 .34994 m
.33721 .34557 L
s
.71775 .32048 m
.71893 .36925 L
s
.3344 .34272 m
.33578 .3453 L
s
.32357 .32196 m
.32641 .32023 L
s
.32218 .32166 m
.32641 .32023 L
s
.71915 .32019 m
.72034 .36898 L
s
.32597 .33874 m
.3344 .34272 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33419 .35199 m
.33567 .34994 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71353 .32134 m
.72747 .31841 L
s
.5 Mabswid
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32206 .32629 m
.32357 .32196 L
s
.33128 .35378 m
.33419 .35199 L
s
.32068 .32599 m
.32218 .32166 L
s
.32195 .33092 m
.32206 .32629 L
s
.32323 .33585 m
.32597 .33874 L
s
.32563 .35269 m
.33128 .35378 L
s
.32056 .33063 m
.32068 .32599 L
s
.72747 .31841 m
.73027 .32011 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32195 .33092 m
.32323 .33585 L
s
.32183 .33556 m
.32597 .33874 L
s
.32056 .33063 m
.32183 .33556 L
s
.32288 .3498 m
.32563 .35269 L
s
.3216 .34486 m
.323 .34514 L
s
.32294 .34747 m
.323 .34514 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73027 .32011 m
.73311 .32414 L
s
.72747 .31841 m
.73163 .31981 L
s
.73163 .31981 m
.73446 .32383 L
s
.32155 .34719 m
.3216 .34486 L
s
.32155 .34719 m
.32288 .3498 L
s
.73311 .32414 m
.73458 .32848 L
s
.73446 .32383 m
.73593 .32817 L
s
.73458 .32848 m
.73612 .33515 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29412 .31263 m
.30326 .31498 L
s
.7423 .31494 m
.75143 .31259 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71467 .37005 m
.7287 .36731 L
s
.73612 .33515 m
.73642 .34683 L
s
.73593 .32817 m
.73746 .33484 L
s
.73746 .33484 m
.73777 .34652 L
s
.30926 .34219 m
.31055 .34483 L
s
.31049 .34717 m
.31055 .34483 L
s
.30785 .34422 m
.30926 .34219 L
s
.30908 .3492 m
.31049 .34717 L
s
.7287 .36731 m
.7314 .36439 L
s
.7287 .36731 m
.73277 .3641 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30785 .34422 m
.30914 .34686 L
s
.73525 .35414 m
.73642 .34683 L
s
.29841 .34672 m
.29931 .31399 L
s
.74624 .31394 m
.74715 .34667 L
s
.7314 .36439 m
.73401 .35913 L
s
.30504 .34829 m
.30908 .3492 L
s
.73401 .35913 m
.73525 .35414 L
s
.73661 .35384 m
.73777 .34652 L
s
.2971 .3464 m
.29801 .31365 L
s
.74755 .31361 m
.74846 .34635 L
s
.73277 .3641 m
.73537 .35883 L
s
.73537 .35883 m
.73661 .35384 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30244 .34532 m
.30504 .34829 L
s
.29992 .34 m
.30244 .34532 L
s
.2988 .33266 m
.29992 .34 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74318 .34762 m
.74846 .34635 L
s
.74807 .33229 m
.74957 .33899 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29319 .34542 m
.29841 .34672 L
s
.74957 .33899 m
.75229 .34303 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75229 .34303 m
.75494 .34472 L
s
.28391 .31217 m
.28628 .31757 L
s
.28628 .31757 m
.2874 .3226 L
s
.2874 .3226 m
.28847 .32999 L
s
.28813 .34174 m
.28847 .32999 L
s
.28026 .30875 m
.28391 .31217 L
s
.28266 .31181 m
.28502 .31722 L
s
.28502 .31722 m
.28614 .32226 L
s
.28614 .32226 m
.2872 .32964 L
s
.28686 .34141 m
.2872 .32964 L
s
.28026 .30875 m
.28266 .31181 L
s
.75494 .34472 m
.75876 .34372 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75736 .33935 m
.7587 .34136 L
s
.75736 .33935 m
.75856 .33665 L
s
.26823 .305 m
.28026 .30875 L
s
.75856 .33665 m
.75989 .33867 L
s
.28665 .34848 m
.28813 .34174 L
s
.28538 .34814 m
.28686 .34141 L
s
.75989 .33867 m
.75996 .34102 L
s
.75876 .34372 m
.75996 .34102 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28525 .35287 m
.28665 .34848 L
s
.76902 .30994 m
.77257 .30647 L
s
.76795 .31501 m
.76902 .30994 L
s
.76795 .31501 m
.76809 .31972 L
s
.28398 .35253 m
.28538 .34814 L
s
.77023 .30957 m
.77257 .30647 L
s
.76917 .31464 m
.77023 .30957 L
s
.76917 .31464 m
.76931 .31935 L
s
.76809 .31972 m
.76945 .32406 L
s
.76931 .31935 m
.77067 .3237 L
s
.77257 .30647 m
.77613 .30533 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27144 .3562 m
.27298 .30652 L
s
.28134 .35659 m
.28398 .35253 L
s
.28259 .35693 m
.28525 .35287 L
s
.27024 .35585 m
.27178 .30614 L
s
.27878 .35828 m
.28259 .35693 L
s
.27878 .35828 m
.28134 .35659 L
s
.76974 .33351 m
.76981 .33587 L
s
.77613 .30533 m
.77855 .30692 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76981 .33587 m
.7711 .33788 L
s
.76974 .33351 m
.77095 .33315 L
s
.77067 .3237 m
.77315 .32533 L
s
.76945 .32406 m
.77315 .32533 L
s
.77095 .33315 m
.77103 .33551 L
s
.77315 .32533 m
.78032 .32546 L
s
.7711 .33788 m
.77359 .33953 L
s
.26667 .35478 m
.27878 .35828 L
s
.77855 .30692 m
.78103 .31087 L
s
.77359 .33953 m
.77835 .33807 L
s
.78203 .30575 m
.78424 .3026 L
s
.78103 .31087 m
.78203 .30575 L
s
.78103 .31087 m
.78171 .3322 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78318 .30536 m
.78424 .3026 L
s
.78218 .31048 m
.78318 .30536 L
s
.78218 .31048 m
.78271 .32707 L
s
.78424 .3026 m
.78538 .3022 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78032 .32546 m
.78156 .32745 L
s
.77835 .33807 m
.78062 .33495 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78062 .33495 m
.78171 .3322 L
s
.78171 .3322 m
.78271 .32707 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79206 .33351 m
.79531 .29853 L
s
.78872 .33468 m
.79644 .33193 L
s
.79317 .33312 m
.79555 .30567 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79531 .29853 m
.80071 .33033 L
s
.80071 .33033 m
.8037 .29514 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80176 .32992 m
.80395 .30231 L
s
.8037 .29514 m
.80893 .32703 L
s
.80589 .32828 m
.8119 .32576 L
s
.23233 .29587 m
.23338 .29391 L
s
.2325 .29107 m
.23338 .29391 L
s
.23146 .29302 m
.2325 .29107 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23146 .29302 m
.23233 .29587 L
s
.23182 .33733 m
.23189 .30789 L
s
.22989 .33649 m
.23189 .30789 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81592 .30187 m
.81668 .2966 L
s
.81523 .30955 m
.81592 .30187 L
s
.81668 .2966 m
.81835 .29088 L
s
.81523 .30955 m
.81567 .32163 L
s
.81685 .30142 m
.81761 .29615 L
s
.81618 .30911 m
.81685 .30142 L
s
.23085 .33691 m
.23137 .32238 L
s
.81761 .29615 m
.81927 .29042 L
s
.81835 .29088 m
.82099 .28709 L
s
.81618 .30911 m
.81662 .3212 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81927 .29042 m
.82099 .28709 L
s
.81567 .32163 m
.81688 .32847 L
s
.23068 .34176 m
.23182 .33733 L
s
.82099 .28709 m
.82276 .28616 L
s
.81662 .3212 m
.81782 .32804 L
s
.22407 .28938 m
.22488 .29225 L
s
.22461 .2995 m
.22488 .29225 L
s
.22239 .28603 m
.22407 .28938 L
s
.22989 .33649 m
.23068 .34176 L
s
.22372 .29904 m
.2247 .29708 L
s
.81688 .32847 m
.818 .33289 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22363 .30146 m
.22461 .2995 L
s
.82276 .28616 m
.82546 .28717 L
s
.21894 .28415 m
.22239 .28603 L
s
.81782 .32804 m
.81893 .33246 L
s
.22185 .30055 m
.22372 .29904 L
s
.22176 .30297 m
.22363 .30146 L
s
.818 .33289 m
.82004 .3369 L
s
.22309 .31601 m
.22417 .3116 L
s
.22381 .32131 m
.22417 .3116 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81893 .33246 m
.82096 .33647 L
s
.21736 .3031 m
.22185 .30055 L
s
.21727 .30554 m
.22176 .30297 L
s
.22309 .31601 m
.22381 .32131 L
s
.22211 .31799 m
.22309 .31601 L
s
.82004 .3369 m
.82287 .33805 L
s
.21716 .28563 m
.21894 .28415 L
s
.82096 .33647 m
.82287 .33805 L
s
.22025 .31953 m
.22211 .31799 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8274 .30618 m
.82743 .30699 L
s
.82823 .30432 m
.82831 .30643 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82707 .28381 m
.8278 .30323 L
s
.82546 .28717 m
.82734 .29108 L
s
.82791 .28333 m
.82864 .30276 L
s
.21624 .28758 m
.21716 .28563 L
s
.82287 .33805 m
.82466 .33718 L
s
.21681 .31773 m
.22025 .31953 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21561 .28225 m
.21624 .28758 L
s
.21524 .29196 m
.21624 .28758 L
s
.21524 .29196 m
.21561 .28225 L
s
.2156 .30461 m
.21736 .3031 L
s
.2155 .30705 m
.21727 .30554 L
s
.82466 .33718 m
.82719 .33342 L
s
0 0 0 r
.82891 .34644 m
.82967 .34251 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82523 .30461 m
.83112 .30136 L
s
.21468 .30658 m
.2156 .30461 L
s
.21523 .31437 m
.21681 .31773 L
s
.21459 .30902 m
.2155 .30705 L
s
.83278 .28045 m
.8381 .27701 L
s
.82719 .33342 m
.82872 .32763 L
s
.82929 .31984 m
.82984 .33454 L
s
.82872 .32763 m
.82929 .31984 L
s
.21449 .31147 m
.21468 .30658 L
s
.82872 .32763 m
.82984 .33454 L
s
.21449 .31147 m
.21523 .31437 L
s
.83511 .27898 m
.83643 .31323 L
s
.83587 .27849 m
.8372 .31276 L
s
.20847 .28031 m
.20979 .28617 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20637 .27638 m
.20847 .28031 L
s
.83409 .31464 m
.8372 .31276 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83662 .29804 m
.83767 .30492 L
s
.20904 .30574 m
.20913 .30329 L
s
.20846 .30036 m
.20913 .30329 L
s
.20733 .30971 m
.20904 .30574 L
s
.20762 .30234 m
.20846 .30036 L
s
.20494 .27538 m
.20637 .27638 L
s
.20762 .30234 m
.20827 .30527 L
s
.83767 .30492 m
.83934 .30888 L
s
.20345 .27682 m
.20494 .27538 L
s
.20277 .27632 m
.20494 .27538 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20575 .31122 m
.20733 .30971 L
s
.2019 .28073 m
.20345 .27682 L
s
.83934 .30888 m
.84089 .31039 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20359 .30979 m
.20575 .31122 L
s
.20123 .28023 m
.20277 .27632 L
s
.84089 .31039 m
.84301 .30895 L
s
.20094 .28761 m
.2019 .28073 L
s
.84212 .3045 m
.84292 .30648 L
s
.84212 .3045 m
.84272 .30155 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20228 .30635 m
.20359 .30979 L
s
.2016 .30587 m
.20359 .30979 L
s
.20028 .28711 m
.20123 .28023 L
s
.84272 .30155 m
.84351 .30353 L
s
.20074 .29254 m
.20094 .28761 L
s
.20111 .30044 m
.20228 .30635 L
s
.84301 .30895 m
.84361 .306 L
s
.84351 .30353 m
.84361 .306 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20074 .29254 m
.20111 .30044 L
s
.20008 .29205 m
.20028 .28711 L
s
.20044 .29995 m
.2016 .30587 L
s
.20008 .29205 m
.20044 .29995 L
s
.19419 .26665 m
.19832 .27029 L
s
.8472 .27783 m
.84762 .27238 L
s
.8472 .27783 m
.8474 .28276 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84762 .27238 m
.84932 .26836 L
s
.8474 .28276 m
.84822 .2872 L
s
.84782 .27732 m
.84823 .27187 L
s
.84782 .27732 m
.84802 .28226 L
s
.84823 .27187 m
.84932 .26836 L
s
.84802 .28226 m
.84883 .2867 L
s
.19509 .30344 m
.1965 .26874 L
s
.84932 .26836 m
.85104 .2668 L
s
.84822 .2872 m
.85012 .28816 L
s
.1945 .30294 m
.19591 .26822 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84883 .2867 m
.85012 .28816 L
s
.84862 .29711 m
.84872 .29959 L
s
.84862 .29711 m
.84923 .29661 L
s
.84872 .29959 m
.84943 .30158 L
s
.84923 .29661 m
.84933 .2991 L
s
.85104 .2668 m
.85225 .26822 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84943 .30158 m
.85073 .30307 L
s
.85012 .28816 m
.8536 .28759 L
s
.19277 .30144 m
.19509 .30344 L
s
.85225 .26822 m
.85352 .27214 L
s
.85073 .30307 m
.85302 .30107 L
s
.1886 .26081 m
.19203 .26455 L
s
.19379 .32041 m
.19449 .3184 L
s
.19399 .31541 m
.19449 .3184 L
s
.85352 .27214 m
.85384 .26664 L
s
.85352 .27214 m
.85444 .29456 L
s
.85384 .26664 m
.85475 .2631 L
s
.19331 .31742 m
.19399 .31541 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85404 .27161 m
.85435 .26611 L
s
.85404 .27161 m
.85476 .28905 L
s
.19331 .31742 m
.19379 .32041 L
s
.85435 .26611 m
.85475 .2631 L
s
.8536 .28759 m
.85424 .28957 L
s
.85475 .2631 m
.85524 .26256 L
s
.85548 .2441 m
.85853 .24024 L
s
.85302 .30107 m
.85401 .29757 L
s
.18937 .29039 m
.19051 .26295 L
s
.18888 .28987 m
.19001 .26242 L
s
.85401 .29757 m
.85444 .29456 L
s
.85444 .29456 m
.85476 .28905 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86212 .24909 m
.86348 .24734 L
s
.18331 .25298 m
.18456 .25138 L
s
.255 .412 .882 r
.85684 .24245 m
.85903 .29496 L
s
.85728 .2419 m
.85947 .29444 L
s
.18867 .29488 m
.18937 .29039 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18819 .29437 m
.18888 .28987 L
s
.18714 .29585 m
.18867 .29488 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18714 .29585 m
.18819 .29437 L
s
.18413 .25483 m
.18684 .25865 L
s
.85832 .26684 m
.85896 .26076 L
s
.85765 .2965 m
.85947 .29444 L
s
0 0 0 r
.18224 .3006 m
.18248 .30086 L
s
.255 .412 .882 r
.85896 .26076 m
.85966 .25717 L
s
.18624 .29482 m
.18714 .29585 L
s
.85966 .25717 m
.86043 .25608 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1834 .30994 m
.18562 .25702 L
s
.85915 .28689 m
.86022 .29088 L
s
0 0 0 r
.18195 .28517 m
.18167 .28105 L
s
.255 .412 .882 r
.18506 .29074 m
.18624 .29482 L
s
.86043 .25608 m
.86127 .25749 L
s
.86043 .25608 m
.86162 .25694 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18301 .30943 m
.18523 .25648 L
s
.86022 .29088 m
.86114 .29236 L
s
.18446 .28465 m
.18506 .29074 L
s
.86127 .25749 m
.86218 .26143 L
s
.86162 .25694 m
.86251 .26088 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86347 .27796 m
.86349 .27852 L
s
.86485 .31083 m
.86543 .32449 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86114 .29236 m
.86191 .29132 L
s
.86218 .26143 m
.86283 .26845 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86191 .29132 m
.86254 .28774 L
s
.86191 .29132 m
.8629 .28721 L
s
.86251 .26088 m
.86315 .2679 L
s
.18189 .30789 m
.1834 .30994 L
s
.86254 .28774 m
.86303 .28162 L
s
.86283 .26845 m
.86304 .2735 L
s
.86303 .28162 m
.86304 .2735 L
s
.8629 .28721 m
.86336 .28109 L
s
.86315 .2679 m
.86337 .27296 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86336 .28109 m
.86337 .27296 L
s
.18123 .25238 m
.18157 .25854 L
s
.18154 .26667 m
.18157 .25854 L
s
.18132 .27173 m
.18154 .26667 L
s
.18097 .25182 m
.18128 .25799 L
s
.18124 .26613 m
.18128 .25799 L
s
.18071 .2788 m
.18132 .27173 L
s
.18058 .24818 m
.18123 .25238 L
s
.18103 .27119 m
.18124 .26613 L
s
.86425 .24945 m
.86581 .24552 L
s
0 0 0 r
.17551 .23467 m
.17669 .23789 L
s
.255 .412 .882 r
.18042 .27827 m
.18103 .27119 L
s
.18058 .24818 m
.18097 .25182 L
s
.17993 .28282 m
.18071 .2788 L
s
.18013 .24706 m
.18058 .24818 L
s
.17949 .22475 m
.18067 .22878 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17967 .28228 m
.18042 .27827 L
s
.86498 .24777 m
.86726 .30129 L
s
0 0 0 r
.17457 .27691 m
.17629 .23698 L
s
.86936 .24294 m
.86941 .24018 L
s
.255 .412 .882 r
.8652 .24721 m
.86748 .30076 L
s
0 0 0 r
.17436 .27637 m
.17608 .23641 L
s
.255 .412 .882 r
.17961 .24847 m
.18013 .24706 L
s
0 0 0 r
.86941 .24018 m
.86983 .23483 L
s
.86952 .24659 m
.86961 .2396 L
s
.255 .412 .882 r
.17907 .28376 m
.17993 .28282 L
s
0 0 0 r
.86961 .2396 m
.86983 .23483 L
s
.255 .412 .882 r
.17907 .28376 m
.17967 .28228 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17782 .28053 m
.1801 .22706 L
s
.5 Mabswid
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17765 .27999 m
.17993 .22648 L
s
.17902 .25243 m
.17961 .24847 L
s
0 0 0 r
.86983 .23483 m
.87016 .23367 L
s
.255 .412 .882 r
.17861 .28269 m
.17907 .28376 L
s
0 0 0 r
.87104 .28177 m
.87129 .28382 L
s
.17448 .28476 m
.1746 .28648 L
s
.17426 .28422 m
.17456 .28721 L
s
.255 .412 .882 r
.86639 .27517 m
.86703 .2792 L
s
.86651 .30285 m
.86748 .30076 L
s
0 0 0 r
.87016 .23367 m
.87062 .23614 L
s
.87016 .23367 m
.87075 .23557 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87088 .27809 m
.8715 .28328 L
s
.17448 .28476 m
.17457 .27691 L
s
.255 .412 .882 r
.1783 .27905 m
.17861 .28269 L
s
0 0 0 r
.17426 .28422 m
.17436 .27637 L
s
.17489 .23235 m
.17421 .22827 L
s
.255 .412 .882 r
.86703 .2792 m
.8677 .28014 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87118 .24227 m
.87062 .23614 L
s
.255 .412 .882 r
.17815 .27285 m
.1783 .27905 L
s
0 0 0 r
.87129 .28382 m
.87204 .28585 L
s
.8713 .2417 m
.87075 .23557 L
s
.8715 .28328 m
.87204 .28585 L
s
.255 .412 .882 r
.17719 .27837 m
.17782 .28053 L
s
.17837 .24084 m
.17848 .24141 L
s
0 0 0 r
.87177 .25266 m
.87118 .24227 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86688 .24156 m
.86809 .26971 L
s
.86648 .24326 m
.86726 .23928 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8677 .28014 m
.86802 .27905 L
s
.86699 .24099 m
.8682 .26916 L
s
.17807 .24225 m
.17837 .24084 L
s
.17816 .24282 m
.17837 .24084 L
s
0 0 0 r
.87204 .28585 m
.87238 .28476 L
s
.87187 .25209 m
.8713 .2417 L
s
.255 .412 .882 r
.17785 .24737 m
.17816 .24282 L
s
.86802 .27905 m
.86818 .2754 L
s
.86802 .27905 m
.86831 .27485 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17221 .28134 m
.17444 .23003 L
s
.17231 .28189 m
.17454 .23061 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87238 .28476 m
.87252 .28 L
s
.87238 .28476 m
.87265 .27945 L
s
.87209 .25998 m
.87177 .25266 L
s
.255 .412 .882 r
.17777 .24681 m
.17807 .24225 L
s
.86809 .26971 m
.86818 .2754 L
s
.17708 .26534 m
.17785 .24737 L
s
0 0 0 r
.87219 .25942 m
.87187 .25209 L
s
.87252 .28 m
.87245 .27155 L
s
.87245 .27155 m
.87209 .25998 L
s
.255 .412 .882 r
.8682 .26916 m
.86831 .27485 L
s
.17787 .24055 m
.17777 .24681 L
s
.17678 .26994 m
.17777 .24681 L
s
0 0 0 r
.17267 .28353 m
.17221 .28134 L
s
.87257 .27099 m
.87219 .25942 L
s
.87265 .27945 m
.87257 .27099 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1779 .23684 m
.17787 .24055 L
s
.17678 .26994 m
.17708 .26534 L
s
.86745 .23297 m
.86748 .23699 L
s
.17786 .23512 m
.1779 .23684 L
s
0 0 0 r
.17406 .22593 m
.1742 .2218 L
s
.255 .412 .882 r
.177 .26479 m
.17705 .26166 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17705 .26166 m
.17697 .25573 L
s
.1766 .27197 m
.17678 .26994 L
s
.17639 .27346 m
.1766 .27197 L
s
0 0 0 r
.87182 .2365 m
.8715 .22799 L
s
.87228 .2481 m
.87182 .2365 L
s
.255 .412 .882 r
.17777 .23655 m
.17786 .23512 L
s
.1778 .23597 m
.17786 .23512 L
s
0 0 0 r
.17181 .27583 m
.17405 .22416 L
s
.17146 .3046 m
.17151 .30036 L
s
.17119 .30777 m
.17146 .3046 L
s
.8715 .22799 m
.87125 .22255 L
s
.8726 .25546 m
.87228 .2481 L
s
.17151 .30036 m
.17125 .30353 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86753 .23527 m
.86909 .27141 L
s
0 0 0 r
.87182 .23591 m
.87148 .2274 L
s
.8723 .24752 m
.87182 .23591 L
s
.255 .412 .882 r
.86753 .2347 m
.86908 .27086 L
s
0 0 0 r
.17183 .27528 m
.17407 .22357 L
s
.87148 .2274 m
.87125 .22255 L
s
.87262 .25489 m
.8723 .24752 L
s
.86914 .19083 m
.86995 .19509 L
s
.8731 .26597 m
.8726 .25546 L
s
.17125 .30353 m
.17119 .30777 L
s
.255 .412 .882 r
.1763 .27126 m
.17639 .27346 L
s
.17758 .24113 m
.17777 .23655 L
s
.86903 .27306 m
.86908 .27086 L
s
0 0 0 r
.87311 .26541 m
.87262 .25489 L
s
.87125 .22255 m
.87114 .22137 L
s
.255 .412 .882 r
.17697 .25573 m
.1771 .25203 L
s
.17697 .25573 m
.17713 .25146 L
s
.17761 .24056 m
.1778 .23597 L
s
.17735 .24629 m
.17758 .24113 L
s
0 0 0 r
.87342 .27227 m
.8731 .26597 L
s
.86967 .19327 m
.87305 .27099 L
s
.87114 .22137 m
.87115 .22388 L
s
.255 .412 .882 r
.1771 .25203 m
.17735 .24629 L
s
.17739 .24573 m
.17761 .24056 L
s
0 0 0 r
.87341 .27171 m
.87311 .26541 L
s
.86956 .19266 m
.87294 .27043 L
s
.17182 .27749 m
.17183 .27528 L
s
.255 .412 .882 r
.17644 .26757 m
.1763 .27126 L
s
.17713 .25146 m
.17739 .24573 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17666 .26238 m
.17669 .26182 L
s
.17655 .26497 m
.17666 .26238 L
s
.86964 .28439 m
.86975 .28754 L
s
.86975 .28754 m
.86987 .2896 L
s
.17644 .26757 m
.17657 .26442 L
s
0 0 0 r
.87115 .22388 m
.87127 .23009 L
s
.255 .412 .882 r
.17657 .26442 m
.17669 .26182 L
s
0 0 0 r
.8735 .27432 m
.87342 .27227 L
s
.255 .412 .882 r
.86964 .28439 m
.86975 .28646 L
s
0 0 0 r
.17231 .26414 m
.17206 .27045 L
s
.17452 .21944 m
.1755 .21529 L
s
.255 .412 .882 r
.86975 .28646 m
.86987 .2896 L
s
0 0 0 r
.8735 .27432 m
.87341 .27171 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86701 .23153 m
.86745 .23786 L
s
.86745 .23786 m
.86787 .2462 L
s
.86787 .2462 m
.86809 .25139 L
s
.86689 .23095 m
.86735 .23728 L
s
.86735 .23728 m
.86778 .24563 L
s
.8665 .2272 m
.86701 .23153 L
s
.86809 .25139 m
.86834 .25863 L
s
0 0 0 r
.17206 .27045 m
.17208 .2725 L
s
.1731 .25851 m
.17487 .21766 L
s
.255 .412 .882 r
.86778 .24563 m
.868 .25083 L
s
0 0 0 r
.8734 .27321 m
.8735 .27432 L
s
.255 .412 .882 r
.8665 .2272 m
.86689 .23095 L
s
.868 .25083 m
.86824 .25807 L
s
0 0 0 r
.17324 .25795 m
.17501 .21707 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86834 .25863 m
.86835 .26273 L
s
0 0 0 r
.87308 .26837 m
.8734 .27321 L
s
.255 .412 .882 r
.86618 .22605 m
.8665 .2272 L
s
.86823 .26218 m
.86824 .25807 L
s
0 0 0 r
.17208 .2725 m
.17226 .27139 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87256 .25979 m
.87308 .26837 L
s
.86868 .21189 m
.86993 .21545 L
s
.255 .412 .882 r
.17718 .25997 m
.17742 .25681 L
s
.17707 .26258 m
.17718 .25997 L
s
.86807 .26369 m
.86835 .26273 L
s
.17708 .26464 m
.17707 .26258 L
s
.17742 .25681 m
.17744 .25886 L
s
0 0 0 r
.17226 .27139 m
.17265 .26654 L
s
.17226 .27139 m
.17278 .26598 L
s
.255 .412 .882 r
.86807 .26369 m
.86823 .26218 L
s
.17744 .25886 m
.17719 .26203 L
s
0 0 0 r
.87253 .26876 m
.87305 .27099 L
s
.17265 .26654 m
.1731 .25851 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17324 .25795 m
.17323 .26431 L
s
.17278 .26598 m
.17324 .25795 L
s
.17631 .21292 m
.17815 .20877 L
s
.255 .412 .882 r
.86757 .26202 m
.86807 .26369 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17525 .2523 m
.17703 .21114 L
s
.17323 .26431 m
.17362 .26638 L
s
.255 .412 .882 r
.86673 .25042 m
.86641 .24724 L
s
0 0 0 r
.17551 .25173 m
.17729 .21055 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86734 .22964 m
.86744 .22985 L
s
.17362 .26638 m
.17404 .26527 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86495 .20478 m
.86702 .20833 L
s
.17404 .26527 m
.17467 .26038 L
s
.17404 .26527 m
.17492 .25982 L
s
.17467 .26038 m
.17525 .2523 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86744 .22985 m
.86988 .23485 L
s
.17492 .25982 m
.17551 .25173 L
s
.86569 .20596 m
.86771 .23592 L
s
.17932 .21705 m
.18038 .20837 L
s
.17848 .22891 m
.17932 .21705 L
s
.18038 .20837 m
.18173 .20284 L
s
.17815 .23645 m
.17848 .22891 L
s
.17968 .21647 m
.18076 .20778 L
s
.17883 .22833 m
.17968 .21647 L
s
.18076 .20778 m
.18173 .20284 L
s
.17851 .23587 m
.17883 .22833 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86771 .23592 m
.87131 .28914 L
s
.86956 .21427 m
.87131 .28914 L
s
.86936 .21367 m
.87082 .27776 L
s
.17802 .24721 m
.17815 .23645 L
s
.18173 .20284 m
.18259 .20166 L
s
.17839 .24664 m
.17851 .23587 L
s
.17851 .23587 m
.18364 .22902 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18666 .21384 m
.18697 .21407 L
s
0 0 0 r
.17802 .24721 m
.17844 .25366 L
s
.18259 .20166 m
.1838 .20366 L
s
.17839 .24664 m
.17883 .25311 L
s
.255 .412 .882 r
.18661 .21515 m
.18721 .21879 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17844 .25366 m
.17948 .25579 L
s
.1838 .20366 m
.18445 .21005 L
s
.17883 .25311 m
.17948 .25579 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17948 .25579 m
.18078 .25413 L
s
.255 .412 .882 r
.85552 .20814 m
.85614 .21136 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18267 .24101 m
.18315 .22959 L
s
.18078 .25413 m
.18187 .2492 L
s
.18332 .23664 m
.18364 .22902 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18791 .23506 m
.18808 .23095 L
s
.18746 .23456 m
.18759 .23135 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18187 .2492 m
.18267 .24101 L
s
.18187 .2492 m
.18251 .24482 L
s
.18251 .24482 m
.18332 .23664 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85633 .22746 m
.85647 .22989 L
s
.85631 .2274 m
.85637 .22981 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18879 .20541 m
.1903 .19664 L
s
.18772 .21742 m
.18879 .20541 L
s
.1903 .19664 m
.19235 .1911 L
s
.255 .412 .882 r
.85785 .26421 m
.85794 .26269 L
s
0 0 0 r
.18741 .22505 m
.18772 .21742 L
s
.18938 .20483 m
.19092 .19606 L
s
.18831 .21685 m
.18938 .20483 L
s
.19092 .19606 m
.19235 .1911 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18799 .22449 m
.18831 .21685 L
s
.18741 .22505 m
.18751 .23597 L
s
.255 .412 .882 r
.85754 .26175 m
.85785 .26421 L
s
0 0 0 r
.19235 .1911 m
.19366 .18993 L
s
.18799 .22449 m
.18811 .23542 L
s
.19366 .18993 m
.19487 .19259 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18751 .23597 m
.18839 .24255 L
s
.18811 .23542 m
.18901 .242 L
s
.19487 .19259 m
.19596 .1991 L
s
.18839 .24255 m
.19013 .24475 L
s
.19643 .18762 m
.19938 .18532 L
s
.19311 .26869 m
.19643 .18762 L
s
.18901 .242 m
.19013 .24475 L
s
.19384 .26817 m
.19715 .18704 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19013 .24475 m
.19145 .24366 L
s
.19145 .24366 m
.19297 .2387 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19297 .2387 m
.1947 .22988 L
s
.255 .412 .882 r
.20427 .23231 m
.20431 .23229 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20287 .19401 m
.20484 .18518 L
s
.20159 .20615 m
.20287 .19401 L
s
.19101 .27027 m
.19384 .26817 L
s
.20484 .18518 m
.20757 .17964 L
s
.2037 .19345 m
.20569 .18462 L
s
.20241 .20559 m
.2037 .19345 L
s
.20128 .21388 m
.20159 .20615 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20569 .18462 m
.20757 .17964 L
s
.2021 .21333 m
.20241 .20559 L
s
.20128 .21388 m
.20163 .22497 L
s
.20757 .17964 m
.20935 .17852 L
s
.2021 .21333 m
.20246 .22443 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2119 .20736 m
.21279 .20683 L
s
.2021 .21333 m
.2119 .20736 L
s
.20935 .17852 m
.21195 .18071 L
s
.20163 .22497 m
.20299 .23167 L
s
.20246 .22443 m
.20384 .23114 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21195 .18071 m
.21354 .18736 L
s
.20299 .23167 m
.20543 .23398 L
s
.20384 .23114 m
.20543 .23398 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20543 .23398 m
.20812 .2324 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21138 .21908 m
.21183 .20736 L
s
.21248 .21464 m
.21279 .20683 L
s
.20812 .2324 m
.21013 .22743 L
s
.22097 .17189 m
.22171 .17913 L
s
.22038 .18747 m
.22097 .17189 L
s
.21013 .22743 m
.21138 .21908 L
s
.21122 .22299 m
.21248 .21464 L
s
.21013 .22743 m
.21122 .22299 L
s
.22038 .18747 m
.22171 .17913 L
s
.22171 .17913 m
.22291 .1747 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22291 .1747 m
.2252 .16973 L
s
.2252 .16973 m
.22961 .16759 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21948 .21096 m
.22068 .20651 L
s
.21919 .21882 m
.21948 .21096 L
s
.22068 .20651 m
.22295 .20154 L
s
.22961 .16759 m
.23174 .17044 L
s
.21934 .21489 m
.22053 .21044 L
s
.22053 .21044 m
.2228 .20547 L
s
.22295 .20154 m
.22875 .19109 L
s
.21919 .21882 m
.22009 .22224 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2228 .20547 m
.2286 .19502 L
s
.23174 .17044 m
.23276 .17384 L
s
.22009 .22224 m
.22207 .22517 L
s
.23233 .18561 m
.23276 .17384 L
s
.22875 .19109 m
.23117 .18613 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2286 .19502 m
.23103 .19006 L
s
.22207 .22517 m
.22646 .22315 L
s
.23117 .18613 m
.23247 .18169 L
s
.23103 .19006 m
.23233 .18561 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22646 .22315 m
.22887 .21819 L
s
.24129 .1663 m
.24267 .16186 L
s
.24129 .1663 m
.24239 .16973 L
s
.23016 .21373 m
.23161 .20532 L
s
.23103 .22116 m
.23161 .20532 L
s
.24267 .16186 m
.24378 .16528 L
s
.22887 .21819 m
.23016 .21373 L
s
.23016 .21373 m
.23103 .22116 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80594 .19742 m
.80602 .19957 L
s
.80722 .23352 m
.80724 .23401 L
s
.80716 .19895 m
.80719 .19999 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24239 .16973 m
.24378 .16528 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24127 .23676 m
.24169 .18946 L
s
.23876 .2377 m
.24169 .18946 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24001 .23723 m
.24086 .21328 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23876 .2377 m
.23973 .24525 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23973 .24525 m
.24127 .23676 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71391 .13639 m
.71581 .14078 L
s
.7122 .14007 m
.71391 .13639 L
s
.71411 .14447 m
.71581 .14078 L
s
.7122 .14007 m
.71411 .14447 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71854 .17125 m
.71923 .17481 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6936 .13263 m
.7011 .13395 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6899 .13605 m
.69387 .14481 L
s
.686 .13137 m
.6899 .13605 L
s
.68215 .13076 m
.686 .13137 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71459 .16474 m
.71759 .21415 L
s
.71396 .21349 m
.71459 .16474 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67836 .13423 m
.68215 .13076 L
s
.67641 .13394 m
.68215 .13076 L
s
.71519 .1892 m
.71578 .21382 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67461 .14179 m
.67836 .13423 L
s
.67265 .14151 m
.67641 .13394 L
s
.67288 .15377 m
.67461 .14179 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67091 .15349 m
.67265 .14151 L
s
.69093 .18505 m
.69457 .17745 L
s
.64638 .12592 m
.66052 .12766 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71396 .21349 m
.71598 .22206 L
s
.71598 .22206 m
.71759 .21415 L
s
.6936 .13263 m
.69546 .21864 L
s
.69549 .13296 m
.69736 .21894 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67288 .15377 m
.67303 .16195 L
s
.68718 .18858 m
.69093 .18505 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67091 .15349 m
.67106 .16168 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67303 .16195 m
.67524 .17454 L
s
.67106 .16168 m
.67327 .17427 L
s
.6833 .188 m
.68718 .18858 L
s
.62363 .12357 m
.63817 .12501 L
s
.67524 .17454 m
.67932 .18332 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67932 .18332 m
.6833 .188 L
s
.67736 .18305 m
.6833 .188 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67327 .17427 m
.67736 .18305 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6897 .21777 m
.69736 .21894 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6668 .20143 m
.6673 .20124 L
s
.6668 .20143 m
.66721 .20117 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66285 .20093 m
.6668 .20143 L
s
0 0 0 r
.60678 .12625 m
.61112 .13478 L
s
.60034 .12169 m
.60678 .12625 L
s
.59605 .1214 m
.60034 .12169 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65247 .12664 m
.65342 .18413 L
s
.65449 .12689 m
.65545 .18436 L
s
.5918 .12523 m
.59605 .1214 L
s
.58964 .1251 m
.59605 .1214 L
s
.64728 .18345 m
.65545 .18436 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58539 .13308 m
.58964 .1251 L
s
.58755 .1332 m
.5918 .12523 L
s
.56576 .11984 m
.57446 .12021 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48677 .1196 m
.52189 .11903 L
s
.58549 .14544 m
.58755 .1332 L
s
.55483 .11948 m
.56141 .12379 L
s
.55045 .11937 m
.55483 .11948 L
s
.58332 .14532 m
.58539 .13308 L
s
.54608 .12338 m
.55045 .11937 L
s
.54388 .12334 m
.55045 .11937 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56141 .12379 m
.56582 .13218 L
s
.51969 .11904 m
.52189 .14376 L
s
.52189 .14376 m
.52189 .11903 L
s
.5439 .13157 m
.54608 .12338 L
s
.5417 .13153 m
.54388 .12334 L
s
.60926 .15934 m
.61144 .16363 L
s
.60717 .16332 m
.60926 .15934 L
s
.58549 .14544 m
.58555 .1537 L
s
.65376 .20486 m
.65587 .20925 L
s
.61144 .16363 m
.61149 .16777 L
s
.58332 .14532 m
.58338 .15358 L
s
.60717 .16332 m
.60935 .16761 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65389 .21319 m
.65587 .20925 L
s
.65178 .2088 m
.65376 .20486 L
s
.62989 .12416 m
.63106 .21092 L
s
.63197 .12437 m
.63316 .21111 L
s
.6073 .17575 m
.61149 .16777 L
s
.65178 .2088 m
.65389 .21319 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5439 .13157 m
.54403 .17715 L
s
.5417 .13153 m
.54181 .17711 L
s
.255 .412 .882 r
.55039 .16512 m
.5513 .16392 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60306 .17961 m
.6073 .17575 L
s
.58338 .15358 m
.58565 .16612 L
s
.58555 .1537 m
.58782 .16624 L
s
.56794 .11993 m
.56827 .17781 L
s
.56576 .11984 m
.56607 .17773 L
s
.50859 .18121 m
.50865 .14798 L
s
.58782 .16624 m
.59223 .17478 L
s
.58565 .16612 m
.59006 .17466 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59659 .1792 m
.60306 .17961 L
s
.59223 .17478 m
.59659 .1792 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59006 .17466 m
.59659 .1792 L
s
.62473 .21038 m
.63316 .21111 L
s
.49537 .16479 m
.50862 .16456 L
s
.55947 .17751 m
.56827 .17781 L
s
.53517 .17703 m
.54403 .17715 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49301 .20659 m
.49333 .11941 L
s
.49523 .20654 m
.49553 .11935 L
s
.51966 .20625 m
.52188 .18113 L
s
.52188 .20625 m
.52188 .18113 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48637 .20676 m
.507 .20646 L
s
.507 .20646 m
.52188 .20625 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P00
00040?nV40T000003@3oYQ000`000000ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2]
[Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4@H0[Jf]2P000007
0:f][@8000002`2][Jd2000000030:f][@000000000000D0[Jf]1@0000030:f][@L0ojD@00<00000
0?nU403oYA001@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f]
[@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f][@L0ojHA00<0[Jf]0?nV403oYQ000P00000;0?nV
408000002P3oYQ02000000040?nV402][Jd0ojD@0?nU408000000`3oYA02000000H0ojD@1@2][Jd2
000000030:f][@000000000000X0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV
4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV4002000000/0ojH@0P00000:0?nV4080000000<0ojH@0:f]
[@3oYA000`3oYA02000000030?nU40000000000000X0ojD@0P0000040?nU408000000`3oYA000`2]
[Jd0oj<@0?nS40020?nS40030:f][@000000000000H000003P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0
/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@0080
00002`3oYQ02000000X0ojH@0P0000000`3oYQ00[Jf]0?nU40040?nU40040000003oYA0000000000
00T0ojD@0P0000070?nU40040000003oYA00ojD@0:f][@P0oj<@0P0000030?nS40<0[Jf]1@000002
0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV
4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV4002000000/0ojH@0P0000090?nV408000000P3oYQ000`2]
[Jd0ojD@0?nU40040?nU40<000002@3oYA02000000L0ojD@00@000000?nU403oYA00[Jf]203oXa02
000000T0oj<@1@0000060:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@
008000002`3oYQ02000000T0ojH@0P0000020?nV40030:f][@3oYA00ojD@00@0ojD@0`0000080?nU
408000002@3oYA000`000000ojD@0:f][@080?nS408000002@3oXa02000000H0oj<@00<0[Jf]0?bP
403lX100102][Jd300000140o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0@0?nV4@D0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0
ojHA00<0[Jf]0?nV403oYQ000P00000<0?nV40030000003oYQ00ojH@00L0ojH@0P0000020?nV4003
0:f][@3oYA00ojD@00D0ojD@0P0000080?nU408000002@3oYA000`000000ojD@0:f][@080?nS4080
00002@3oXa02000000H0oj<@00<0[Jf]0?bP403lX1000P3lX10200000080o:0@00<0[Jf]0000002]
[Jd00P00000=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0
fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]1`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P00000<0?nV40030000
003oYQ00ojH@00L0ojH@0P0000020?nV40030:f][@3oYA00ojD@00D0ojD@0P0000080?nU40800000
2P3oYA000`000000[Jf]0?nS40070?nS408000002@3oXa02000000H0oj<@00@0[Jf]0?bP403lX100
o:0@0P0000040?bP40030000003lX100000000@000000P2][Jd80?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00
K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA00D0ojHA1P2][Jd<0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV4002000000`0ojH@00<000000?nV403oYQ001`3oYQ0200000080ojH@
00<0[Jf]0?nU403oYA001@3oYA02000000L0ojD@00<000000?nU400000002`3oYA000`2][Jd0oj<@
0?nS40060?nS408000002@3oXa02000000H0oj<@00<0[Jf]0?bP403lX1000P0000060?bP40<00000
1@3lX1030:f][@030000002][Jd0[Jf]0080o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_
V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0
[Jf]0?nV403oYQ000P00000<0?nV40030000003oYQ00ojH@00L0ojH@0P0000020?nV40030:f][@3o
YA00ojD@00D0ojD@0P0000070?nU40800000303oYA000`2][Jd0oj<@0?nS40060?nS408000002@3o
Xa02000000H0oj<@00<0[Jf]0?bP403lX1000P0000060?bP40<00000203lX1000`000000o:0@0?bP
40040:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@060=^:3@80[Jf]E`2`
h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@@0[Jf]5`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ000P00000<0?nV40030000003oYQ00ojH@00L0ojH@0P0000020?nV40030:f][@3oYA00
ojD@00D0ojD@0P0000070?nU40800000303oYA000`2][Jd0oj<@0?nS40060?nS408000002@3oXa02
000000H0oj<@00@0[Jf]0?bP400000000000203lX102000000P0o:0@0P0000030?bP40030:f][@3f
W0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2]
[JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV4002000000`0ojH@00<000000?nV403oYQ001`3oYQ02
00000080ojH@00<0[Jf]0?nU403oYA001@3oYA02000000H0ojD@00<000000?nU40000000303oYA00
0`2][Jd0oj<@0?nS40060?nS408000002@3oXa02000000H0oj<@00@0[Jf]0?bP400000000000203l
X102000000P0o:0@0P0000030?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2][Jd;
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ000P00000<0?nV40030000003oYQ00ojH@00L0ojH@0P0000020?nV40030:f][@3oYA00
ojD@00D0ojD@0P0000060?nU40030000003oYA00000000`0ojD@00<0[Jf]0?nS403oXa001P3oXa02
000000T0oj<@0P0000060?nS40040:f][@3lX1000000000000P0o:0@0P0000090?bP40050000003l
X100o:0@0?bP402][Jd02@3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@008000005P3oYQ0200000080ojH@00<0[Jf]0?nU403oYA001@3oYA02000000H0ojD@00<0
00000?nU40000000303oYA000`2][Jd0oj<@0?nS40060?nS408000002@3oXa02000000H0oj<@00@0
[Jf]0000003lX1000000203lX102000000d0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`
h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV4002000000D0ojH@00<000000?nV403oYQ003P3oYQ0200000080ojH@00<0
[Jf]0?nU403oYA001@3oYA02000000H0ojD@00<000000?nU40000000303oYA000`2][Jd0oj<@0?nS
40060?nS408000002@3oXa02000000L0oj<@0P0000090?bP408000003@3lX1000`2][Jd0mY`?0?JL
3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV4002000000D0ojH@00<00000
0?nV403oYQ003P3oYQ0200000080ojH@00<0[Jf]0?nU403oYA001@3oYA02000000L0ojD@0P00000<
0?nU40030:f][@3oXa00oj<@00H0oj<@0P0000090?nS408000001`3oXa02000000T0o:0@0P00000=
0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]
0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3l
X100o:0@00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@008000001@3oYQ000`000000ojH@0?nV
400>0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40050?nU408000001`3oYA02000000`0ojD@00<0
[Jf]0?nS403oXa001P3oXa02000000T0oj<@0P0000070?nS408000002@3lX102000000d0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>
0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@008000001@3oYQ000`000000ojH@0?nV400>0?nV408000000P3oYQ000`2][Jd0ojD@
0?nU40050?nU408000001`3oYA02000000`0ojD@00<0[Jf]0?nS403oXa001P3oXa02000000T0oj<@
0P0000070?nS408000002@3lX102000000d0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;
0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@X0[Jf]0P00
00050:f][@030000002][Jd0[Jf]00h0[Jf]0P00000:0:f][@8000001`3oYA02000000`0ojD@00<0
[Jf]0?nS403oXa001P3oXa02000000T0oj<@0P0000070?nS408000002@3lX102000000d0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H0
0`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX102
0:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40
ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ000P000005
0?nV40030000003oYQ00ojH@00h0ojH@0P0000020?nV40030:f][@3oYA00ojD@00D0ojD@0P000007
0:f][@8000001@2][Jd50?nU40030000003oYA00[Jf]00P0oj<@0P0000090?nS408000001`3oXa02
000000T0o:0@0P00000=0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh3
0:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0
/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@`0[Jf]5`3oYQ400`2][Jd0ojH@0?nV40020000
00D0ojH@00<000000?nV403oYQ003P3oYQ0200000080ojH@00<0[Jf]0?nU403oYA001@3oYA020000
00L0ojD@0P0000050?nU40@0[Jf]0P0000060:f][@@0oj<@0P0000090?nS408000001`3oXa020000
00T0o:0@0P00000=0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f]
[@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V
04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH4005
0:f][@3lX100o:0@0?bP400000000P2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@008000001@3oYQ000`000000ojH@0?nV400>0?nV408000000P3oYQ000`2]
[Jd0ojD@0?nU40050?nU40800000203oYA02000000P0ojD@00@000000?nU40000000[Jf]103oXa04
0:f][@800000102][Jd50?nS408000001`3oXa02000000T0o:0@0P00000=0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>
00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@02000000d0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd=0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ002000000@0?nV408000000P3oYQ000`2]
[Jd0ojD@0?nU40050?nU40800000203oYA02000000P0ojD@00@000000?nU40000000[Jf]203oXa02
000000@0oj<@1@2][Jd2000000<0[Jf]103oXa02000000T0o:0@0P0000090?bP40050000003lX100
o:0@0?bP402][Jd05P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V100203_V100
0`000000kiP@0>nH40020:f][@030?bP40000000000000d0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]5`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@008000001@3oYQ000`000000ojH@0?nV400>0?nV408000000P3oYQ000`2][Jd0ojD@0?nU4005
0?nU40800000203oYA02000000T0ojD@0P0000000`2][Jd0oj<@0?nS40060?nS408000002@3oXa02
000000<0oj<@102][Jd200000080[Jf]1`3lX102000000T0o:0@00D000000?bP403lX100o:0@0:f]
[@0F0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2]
[Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40070>nH408000000`2][Jd2
0?bP408000003@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1P2][Jd2
0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV4002
000000D0ojH@00<000000?nV403oYQ003P3oYQ0200000080ojH@00<0[Jf]0?nU403oYA001@3oYA02
000000P0ojD@0P00000:0?nU40030000002][Jd0oj<@00L0oj<@0P0000090?nS408000001`3oXa02
00000080o:0@1P2][Jd00`3lX1000000000000090?bP40050000003lX100o:0@0?bP402][Jd05P3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h0
0`2][Jd0kiP@0>nH40060>nH40060000002][Jd0[Jf]0000003_V100[Jf]0`3lX1000`000000o:0@
0?bP400;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@P0ojHA
00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00800000
1@3oYQ000`000000ojH@0?nV400>0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40050?nU40800000
2@3oYA02000000P0ojD@00<000000?nU402][Jd0203oXa02000000T0oj<@0P0000070?nS40030:f]
[@000000000000L0o:0@00<0[Jf]000000000000102][Jd50?bP40050000003lX100@FWQ0?bP402]
[Jd05P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd70=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;
09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@0P0000001P2][Jd0kiP@0>nH40000000kiP@
0:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060?nV4@D0[Jf]3@3oYQ40
0`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ000P000005
0?nV40030000003oYQ00ojH@00h0ojH@0P0000020?nV40030:f][@3oYA00ojD@00D0ojD@0P000009
0?nU40800000203oYA000`000000ojD@0:f][@080?nS408000002@3oXa02000000L0oj<@00<0[Jf]
000000000000203lX102000000@0o:0@1@2][Jd01@000000o:0@0?bP403lX100[Jf]01H0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2G
H0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V102000000@0kiP@00<000000:f][@3lX100
403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0[Jf]4P3oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ000P0000050?nV40030000
003oYQ00ojH@00h0ojH@0P0000020?nV40030:f][@3oYA00ojD@00D0ojD@0P00000:0?nU40800000
1P3oYA0010000000ojD@0?nU402][Jd80?nS408000002@3oXa02000000L0oj<@00<0[Jf]00000000
0000203lX102000000T0o:0@00<000000:f][@2][Jd00`2][JdE0?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0
R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>7
3P030:f][@3_V100kiP@0080kiP@0P2][Jd00`000000kiP@0>nH40030>nH40030000002][Jd0o:0@
0100o:0@00<0[Jf]0?nT4@3oY1404P3oY1440:f][AP0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@008000001@3oYQ000`000000ojH@0?nV400;0?nV
40D000000P3oYQ000`2][Jd0ojD@0?nU40020?nU4080000000<0ojD@0000000000002`3oYA020000
00D0ojD@00@000000?nU403oYA00[Jf]203oXa02000000T0oj<@0P0000070?nS40030:f][@000000
000000T0o:0@0P0000080?bP40060000003lX100o:0@0?bP402][Jd0mY`?102][JdA0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@80fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@080=>73P80000000<0kiP@0:f][@2][Jd00P3_V1000`000000kiP@0>nH40030>nH4003
0000002][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1403P3oY1440:f][@030?nT4@2][Jd0ojHA01T0
ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0080
00001@3oYQ000`000000ojH@0?nV400B0?nV40030:f][@3oYA00ojD@00@0ojD@0`00000=0?nU40D0
00000`3oYA000`2][Jd0oj<@0?nS40060?nS408000002@3oXa02000000L0oj<@00@0[Jf]0?bP4000
000000001`3lX103000000P0o:0@00D000000?bP403lX100o:0@0:f][@050?JL3`@0[Jf]3@3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00T0fhX=0`2][Jd90;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP
2`030:f][@3CQ`h0dhL>00H0dhL>00@000000:f][@00000000000`3_V1000`000000kiP@0>nH4003
0>nH40030000002][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1402P3oY1440:f][@D0oj@A00<0[Jf]
0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ000P0000050?nV40030000003oYQ00ojH@00@0ojH@00<000000?nV403oYQ002`3oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00H0oj<@0P0000090?nS408000001`3oXa00
102][Jd0o:0@0000000000070?bP40<00000203lX1001@000000o:0@0?bP403lX100[Jf]00T0mY`?
102][Jd90?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`
h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P0000020>nH40050000003_V100kiP@0>nH4000
00001@3_V1000`000000[Jf]0?bP400@0?bP40030:f][@3oY140oj@A00L0oj@A0`2][Jd90?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@00800000303oYQ000`000000ojH@0?nV400;0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa001P3oXa02000000H0oj<@0P0000000`3oXa000000000000070?nS4003
0:f][@3lX100o:0@008000001@3lX10010000000o:0@0000000000080?bP40050000003lX100o:0@
0?bP402][Jd03@3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool0
05T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P030000003CQ`h0dhL>008000000P3_V100
1@000000kiP@0>nH403_V100000000@0kiP@0P00000B0?bP40030:f][@3oY140oj@A00<0oj@A102]
[Jd<0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@00800000303oYQ000`000000ojH@0?nV400;0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001P3oXa02000000P0oj<@0`0000070?nS40040:f][@3l
X100o:0@0?bP40800000103lX10010000000o:0@0000000000080?bP40050000003lX100o:0@0?bP
402][Jd04@3fW0l40:f][@030?JL3`2][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102]
[Jd0^GD;0:f][@2][Jd60;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00@000000=>73P2][Jd0[Jf]0P00
00020>nH40050000003_V100kiP@0>nH40000000103_V10200000180o:0@00<0[Jf]0?nT4@2][Jd0
0`2][Jd@0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00800000303oYQ000`000000ojH@0?nV400;0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001P3oXa0200000180oj<@00<0[Jf]0?bP403lX100
0P3lX1001@000000o:0@0?bP403lX10000000080o:0@0P0000080?bP40050000003lX100o:0@0?bP
402][Jd05@3fW0l30:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0
[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01P000000[Jf]0=>73P3CQ`h000000:f][@X0kiP@
0P0000001@2][Jd0o:0@0?bP403lX100000000d0o:0@0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0080
0000303oYQ000`000000ojH@0?nV400;0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa001P3oXa0200000180oj<@00<0[Jf]0?bP403lX1000`3lX103000000<0o:0@0P0000080?bP4005
0000003lX100o:0@0?bP402][Jd05P3fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF
1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>7
3P<000000P3CQ`h2000000030:f][@3_V100kiP@00P0kiP@0P0000001@2][Jd0o:0@0?bP403lX100
000000X0o:0@0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00800000303oYQ00
0`000000ojH@0?nV400;0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001P3oXa02
00000180oj<@00<0[Jf]0?bP403lX1002@3lX102000000P0o:0@0P0000020?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][@030000002`
h>H0/>3V03l0/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P<000000P3C
Q`h2000000030:f][@3_V100kiP@00L0kiP@0P0000000`3_V100[Jf]0?bP40020?bP40030000003l
X100o:0@00H0o:0@0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ000P00
000<0?nV40030000003oYQ00ojH@00/0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
40060?nS408000004P3oXa000`2][Jd0o:0@0?bP40090?bP40800000203lX10200000080o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80[Jf]00<0
00000;3PiP2`h>H0?`2`h>H10?ooo`00F@2`h>H0202][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P000000
[Jf]0P0000020=>73P80000000<0[Jf]0>nH403_V1001`3_V102000000030>nH402][Jd0o:0@0080
o:0@00<000000?bP403lX1000`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4:0:f][@80
00002`2][Jd2000001D0[Jf]5`3oYA000`2][Jd0oj<@0?nS40060?nS408000004P3oXa000`2][Jd0
o:0@0?bP40090?bP40800000203lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0
^GD;0P2][Jd408QF1`80[Jf]00<000000;3PiP2`h>H0?`2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;
09MP2`2GH0/20:f][@040000003CQ`h0dhL>00000080dhL>0P0000000`2][Jd0kiP@0>nH40060>nH
408000000P3_V1001@2][Jd0o:0@0?bP403lX10000000080o:0@0`2][Jd90?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@008000002`3oYQ02000000d0ojH@00<0[Jf]
0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa001P3oXa0200000180oj<@00<0[Jf]
0?bP403lX1002@3lX102000000P0o:0@0P0000030?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh02P3/UPh20:f][@<0k9H>00<0@FWQ0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0000002`h>H0@02`h>H10?ooo`00F@2`h>H01`2]
[Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P0000000P3CQ`h01P000000dhL>0=>73P000000dhL>0:f][@P0
kiP@0P0000020>nH40050:f][@3lX100o:0@0?bP400000000P2][Jd<0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5`3oYQ400`2]
[Jd0ojH@0?nV4002000000/0ojH@0P00000=0?nV40030:f][@3oYA00ojD@01D0ojD@302][Jd40?nS
408000004P3oXa000`2][Jd0o:0@0?bP40090?bP40800000203lX102000000<0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>045Yh@3KRPd03@3KRPd00`2]
[Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd000000;3PiP100;3PiP40oooo001I0;3PiP03
0:f][@2GH0/000000080[Jf]00H000000=>73P3CQ`h0dhL>0000003CQ`h2000000030:f][@3_V100
kiP@00H0kiP@0P0000030>nH40050:f][@3lX100[Jf]0:f][@0000003P3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV4002000000/0ojH@0P00000=0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa040:f][@800000102][Jd<0?nS4003045Yh@3o
Xa00[Jf]00/0o:0@0P0000080?bP408000000`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/
UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`030:f][@00
0000/>3V0400/>3V0@3oool005T0/>3V00H0[Jf]09MP2`00000000000:f][@0000030=>73P050000
003CQ`h000000000002][Jd0203_V102000000<0kiP@0P2][Jd20?bP40030000003lX100o:0@00`0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080
ojHA2P2][Jd>0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ000P00000;0?nV4080
00003@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00H0oj<@0P0000040?nS40X0
[Jf]103oXa000`2][Jd0o:0@0?bP40090?bP40800000203lX102000000<0o:0@00<0[Jf]0?JL3`3f
W0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0308QF1`030:f][@000000/>3V0400/>3V0@3oool005T0
/>3V00H0[Jf]00000000000000000:f][@0000030=>73P050000003CQ`h000000000002][Jd01`3_
V10200000080kiP@00<0[Jf]0000002][Jd00`3lX1000`000000o:0@0?bP400<0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ480:f][AP0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV4002000000/0ojH@0P00000=0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa001P3oXa02000000X0oj<@00@000000?nS403oXa00oj<@202][Jd80?bP40800000
203lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f]
[@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`080:f][@28EPL0R5H70:f]
[@28EPL000000:f][@0000110;3PiP40oooo001I0;3PiP060:f][@000000[Jf]0000002][Jd00000
0`3CQ`h01@000000dhL>000000000000[Jf]00<0kiP@00@000000>nH403_V100kiP@0P0000020:f]
[@030>nH40000000[Jf]00<0o:0@00<000000?bP403lX1002`3lX1000`2][Jd0oj@A0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ406`3oYQ4C000000d0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40060?nS
408000002@3oXa02000000L0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd00`3lX100000000000008
0?bP408000000`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0202][Jd0R5H708QF1`28
EPL0[Jf]0000002][Jd00000@@2`h>H10?ooo`00F@2`h>H20000000409MP2`000000[Jf]00000080
dhL>0P0000001@3CQ`h000000000002][Jd0kiP@00<000000P3_V102000000060:f][@3_V100kiP@
0>nH40000000[Jf]0`3lX1000`000000o:0@0?bP400;0?bP40030:f][@3oY140oj@A01@0oj@A00<0
[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
40060?nS408000002@3oXa000`000000oj<@000000060?nS40030:f][@3lX100o:0@00P0o:0@00<0
[Jf]0000000000000`2][Jd50?bP408000000`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2i
M@/01@2][Jd0R5H708QF1`28EPL0[Jf]00<00000@@2`h>H10?ooo`00F02`h>H01`000000[Jf]0000
002GH0/000000:f][@0000000P3CQ`h2000000030=>73P0000000000008000000P3_V1000`000000
kiP@0:f][@02000000@0kiP@00<000000:f][@3lX1000P3lX1000`000000o:0@0?bP400;0?bP4003
0:f][@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa000`3oXa05000000T0oj<@0P0000070?nS40030:f][@3lX100o:0@
00T0o:0@0P0000030?bP40D0[Jf]0P0000030?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`030:f][@28EPL0R5H70080R5H700<000000:f][@000000@@2`h>H10?ooo`00F02`h>H300000080
Uf0;00@0[Jf]0000003CQ`h0dhL>0P000000103CQ`h000000000002][Jd20>nH4080000000<0[Jf]
0>nH400000001@3_V10010000000[Jf]0?bP403lX102000000d0o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400B0?nS40030000003o
Xa00oj<@00D0oj<@00<0[Jf]0?bP403lX1002@3lX102000000P0o:0@0P0000060:f][A@0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/01`2i
M@/00`2][Jd0R5H708QF1`0208QF1`040000002][Jd0000000000400/>3V0@3oool005L0/>3V1000
000209MP2`040:f][@000000dhL>0=>73P80000000H0dhL>000000000000[Jf]0>nH402][Jd20000
0080kiP@00<000000>nH403_V1000`3_V10010000000[Jf]0?bP403lX102000000d0o:0@00<0[Jf]
0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00T0o:0@0P0000080?bP408000000`3lX100
0`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@80[Jf]2@2iM@/01P2][Jd0R5H708QF1`28EPL000000:f][@800000@02`h>H10?ooo`00E`2`
h>H400000080Uf0;00@0[Jf]0000003CQ`h0dhL>0P0000000`3CQ`h00000000000020:f][@030>nH
4000000000000080kiP@00<000000>nH403_V1000P3_V102000000030:f][@3lX100o:0@00800000
3@3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40060?bP40800000
00<0o:0@000000000000203lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l50:f][@/0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]202iM@/01P2][Jd0R5H7
08QF1`28EPL000000:f][@800000@02`h>H10?ooo`00E`2`h>H400000080Uf0;00@0[Jf]0000003C
Q`h0dhL>0P000000103CQ`h000000000002][Jd20>nH40050000003_V100kiP@0>nH40000000103_
V102000000030:f][@3lX100o:0@008000003@3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP40080?bP40<000002@3lX1001@000000o:0@0?bP403lX100[Jf]00/0mY`?
1@2][Jd60?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;
0:f][@2][Jd60;Ue2`060:f][@28EPL0R5H708QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3P
iP@000000P2GH0/200000080dhL>0P000000103CQ`h000000000002][Jd20>nH40050000003_V100
kiP@0>nH400000000`3_V10010000000kiP@0000002][Jd20?bP408000003@3lX1000`2][Jd0oj@A
0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400D0?bP40050000003lX100o:0@0?bP402]
[Jd0403fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@05
0:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/01P2][Jd0R5H708QF1`28EPL000000:f][@800000@02`
h>H10?ooo`00E`2`h>H3000000<0Uf0;0P0000020=>73P80000000@0[Jf]000000000000[Jf]0P3_
V1000`000000kiP@0>nH40020>nH40040000003_V100kiP@00000080kiP@00<0[Jf]0?bP403lX100
0P00000=0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400D0?bP40050000
003lX100o:0@0?bP402][Jd0503fW0l40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL300000400
/>3V0@3oool005L0/>3V0`00000309MP2`8000000P3CQ`h2000000040=>73P00000000000:f][@80
kiP@00<000000>nH403_V1000`3_V102000000<0kiP@00<0[Jf]0?bP403lX1000P00000<0?bP40<0
[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2]
[Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0
^GD;0;Ue2`2iM@/0[Jf]00@0R5H70`0000100;3PiP40oooo001G0;3PiP<000000`2GH0/200000005
0=>73P2][Jd000000000003CQ`h00P000000102][Jd0kiP@0>nH4000000:0>nH40030:f][@3lX100
o:0@008000002P3lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H70`000010
0;3PiP40oooo001G0;3PiP<0000000<0Uf0;0000000000000P0000000`2][Jd0dhL>000000030=>7
3P8000000P3_V1000`000000kiP@0>nH40080>nH40030:f][@3lX100o:0@008000001`3lX1030:f]
[@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL300000400/>3V0@3oool005L0/>3V0`0000000`2GH0/0
00000000000200000080dhL>00@000000=>73P3CQ`h0dhL>0P0000000`3_V10000000>nH400:0>nH
40030:f][@3lX100o:0@008000001@3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H7
0080R5H70`0000100;3PiP40oooo001G0;3PiP030000002][Jd000000080000000<0Uf0;00000000
00000P3CQ`h010000000dhL>0=>73P3CQ`h2000000030>nH40000000kiP@00X0kiP@00<0[Jf]0?bP
403lX1000P0000020?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0:0>bF3P80[Jf]0`3/UPh00`11JN40[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;
00L0^GD;0P2][Jd308QF1`<00000@02`h>H10?ooo`00E`2`h>H01P000000[Jf]0000002GH0/00000
0:f][@80000000<0dhL>0000000000000`3CQ`h00`2][Jd000000000000<0>nH40030:f][@3lX100
o:0@008000000P2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`80[Jf]0`28EPL300000400/>3V0@3oool005H0/>3V0P0000001@2][Jd0000009MP2`000000
[Jf]0080000000<0dhL>0000000000000`3CQ`h00`2][Jd0kiP@0>nH400<0>nH40030:f][@3lX100
[Jf]008000003@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]
0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`030:f][@28EPL0[Jf]0080R5H70`0000100;3PiP40oooo001F0;3PiP80000000D0[Jf]0000
002GH0/0000009MP2`02000000030=>73P000000000000<0dhL>00<0[Jf]0>nH403_V1002`3_V103
0:f][@030?bP40000000000000d0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H
0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2]
[Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P28EPL300000400/>3V0@3o
ool005H0/>3V0P0000001P2][Jd000000:f][@000000Uf0;0:f][@80000000<0dhL>0000003CQ`h0
0P3CQ`h00`2][Jd0kiP@0>nH40090>nH4080[Jf]00D0kiP@0:f][@3lX100o:0@0000000>0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P04
0:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`050:f][@28EPL0R5H7
0:f][@28EPL00`0000100;3PiP40oooo001F0;3PiP80000000H0[Jf]0000002][Jd0000009MP2`2]
[Jd2000000030=>73P000000dhL>0080dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@00@0
[Jf]0?bP403lX10000003P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA
202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0R5H7
08QF1`28EPL0[Jf]00<00000@02`h>H10?ooo`00EP2`h>H20000000:0:f][@000000Uf0;0000002G
H0/0[Jf]0=>73P000000dhL>000000<0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@00@0
[Jf]0?bP403lX10000003P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA
1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0R5H7
08QF1`28EPL0[Jf]00<00000@02`h>H10?ooo`00EP2`h>H2000000060:f][@000000Uf0;0000002G
H0/0[Jf]0`3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00D0kiP@0P2][Jd70>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H5
0:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`28EPL00P28EPL3
00000400/>3V0@3oool005H0/>3V0P0000001P2][Jd0000009MP2`000000Uf0;0:f][@80dhL>0P00
00030=>73P040:f][@3_V100kiP@0>nH4080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0
mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@03
0=^:3@2][Jd0^GD;00P0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@0200000400/>3V0@3oool005H0
/>3V0P0000001@2][Jd0000009MP2`000000[Jf]00<0dhL>0P0000030=>73P040:f][@3_V100[Jf]
0:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H5
0:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/0
1@2][Jd0R5H708QF1`28EPL0[Jf]00800000@02`h>H10?ooo`00EP2`h>H2000000050:f][@000000
000009MP2`2][Jd00`3CQ`h2000000<0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd0303KRPd30:f][@L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@03000003l0/>3V
0@3oool005H0/>3V0P0000001@2][Jd000000000002GH0/0[Jf]00<0dhL>0P0000020=>73P80[Jf]
3P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]
303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0
[Jf]1P2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H200000005
0:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h200000080[Jf]00<0dhL>0:f][@3_V100303_V1000`2]
[Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@05
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00`00000o0;3PiP40oooo001F0;3PiP80000000D0[Jf]
09MP2`2GH0/0Uf0;0:f][@030=>73P8000000`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00D0
[Jf]08QF1`28EPL0R5H70:f][@03000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00<0dhL>0P0000030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
3`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
102iM@/0102][Jd0^GD;0;Ue2`2][Jd308QF1`040:f][@0000000000000003l0/>3V0@3oool005H0
/>3V0P0000001P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]0P0000030=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0R5H700@0[Jf]0000000000000000?`2`
h>H10?ooo`00EP2`h>H2000000040:f][@2GH0/0Uf0;09MP2`80[Jf]0P3CQ`h2000000<0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2]
[Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H708QF1`0208QF1`<00000?`2`h>H10?ooo`00EP2`h>H2000000@0Uf0;00@0
[Jf]0=>73P3CQ`h0dhL>0P0000030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
1`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL3000003l0/>3V0@3oool005H0/>3V00<0
00000:f][@2GH0/00P2GH0/20:f][@<0dhL>0P0000030=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33
_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28
EPL3000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@80dhL>0P000004
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]
0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0
_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
[Jf]0080R5H70`00000o0;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;09MP2`2][Jd0Uf0;0:f]
[@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i
/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0
[Jf]08QF1`2][Jd00P28EPL3000003l0/>3V0@3oool005H0/>3V00@000000:f][@2GH0/0[Jf]0P2G
H0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00X0kiP@0`2][Jd80;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][MP0/>3V102][Jd80<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/01@2][Jd0R5H708QF1`2][Jd0R5H700<00000?`2`h>H10?ooo`00EP2`h>H010000000[Jf]09MP
2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00
EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
1P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]
b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]
1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`
h>H0?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0
a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0
_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0
00000;3PiP0o0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@05045Yh@2TWXl0@FWQ0:BNS`2][Jd0102aZid20:f]
[@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@11JN40[Jf]0:f][@<0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@000000/>3V03l0/>3V0@3oool0
05L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P060:f][@3_V100[Jf]0:f][@11JN40Y9j?
0P11JN400`2TWXl0@FWQ045Yh@060;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@L0
_[Vh00<0@FWQ0:f][@11JN400P2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00H0[Jf]08QF1`28
EPL0R5H70:f][@0000100;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h2
0:f][@80Y9j?00@0@FWQ0:BNS`11JN40@FWQ0P2TWXl00`11JN40/J^M0;6[W@060;6[W@80[Jf]0`2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31
^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33
_K/0102][Jd0_[Vh0:f][@2][Jd80;ji^004045Yh@2n^KP0@FWQ045Yh@<0];2a00<0@FWQ0:f][@2]
[Jd02P2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000400/>3V0@3oool005L0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@080=>73P030:f][@2TWXl0Y9j?00@0Y9j?00H0@FWQ0:BNS`2TWXl0Y9j?0:f]
[@11JN490;6[W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@T0_[Vh00<0@FWQ0;ji^02n^KP0
0P11JN430;B`/@03045Yh@2d/;40];2a0080[Jf]202iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]0000
0400/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00<0@FWQ0:BN
S`2TWXl0102TWXl01P11JN40Y9j?0:BNS`2TWXl0[Jf]045Yh@<0/J^M00<0@FWQ0;6[W@2aZid01@2a
Zid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33
_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0080;ji^080@FWQ
0P2n^KP00`2][Jd0@FWQ0;B`/@020;B`/@03045Yh@2d/;40];2a0080];2a00<0[Jf]0;Ue2`2iM@/0
1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@050=>73P<0[Jf]00<0@FWQ0:BNS`2TWXl01`2TWXl00`2][Jd0/J^M045Yh@020;6[W@80
@FWQ202aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0
`kfk00<0[Jf]0;ji^02n^KP01`2n^KP00`11JN40_[Vh0;ji^0020;ji^005045Yh@2d/;40];2a0;B`
/@11JN401@2d/;420:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01@2][Jd0@FWQ08Z5M@2][Jd0@FWQ00T0Y9j?00<0
[Jf]0;6[W@11JN400`2aZid00`11JN40/J^M0;6[W@060;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2]
[Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`040:f][@2n^KP0_[Vh045Yh@H0_[Vh
00<0@FWQ0;ji^02n^KP00P2n^KP2045Yh@80];2a00<0@FWQ0;B`/@2d/;400P2d/;450:f][@<0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00`3CQ`h01`2][Jd0RXEe045Yh@2:QGD0[Jf]045Yh@2][Jd0202TWXl00`2][Jd0/J^M045Yh@0<
0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA
0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00@0[Jf]0;ji^02n^KP0@FWQ1P2n
^KP00`11JN40_[Vh0;ji^0020;ji^080@FWQ0P2d/;42045Yh@80];2a00L0[Jf]0;B`/@2d/;40@FWQ
09nKX011JN40[Jf]0080^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP06
0:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd208Z5M@06045Yh@2:QGD0[Jf]045Yh@2TWXl0[Jf]
1`2TWXl00`2][Jd0@FWQ045Yh@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]
0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd=0<>m^`05045Yh@2][Jd0_[Vh0;ji^011
JN401@2n^KP2045Yh@@0_[Vh0P11JN420;B`/@80@FWQ0P2][Jd30;B`/@04045Yh@2OVj00@FWQ09nK
X0<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;00<0
Uf0;0P2][Jd308Z5M@80@FWQ00<0RXEe0:f][@11JN400P2TWXl00`2][Jd0@FWQ0:BNS`040:BNS`80
@FWQ3@2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0
[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02033_K/00`11JN40
`kfk0<>m^`020<>m^`04045Yh@2][Jd0_[Vh0;ji^080@FWQ102n^KP2045Yh@@0_[Vh0`11JN400`2d
/;40@FWQ045Yh@020;B`/@06045Yh@2d/;40];2a045Yh@2OVj00@FWQ0`2OVj000`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00`2GH0/0
0`2][Jd0RXEe08Z5M@0308Z5M@04045Yh@2:QGD0[Jf]045Yh@80Y9j?0P11JN420:f][@030:BNS`11
JN40@FWQ0080@FWQ3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37
`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`060<>m^`03045Yh@33
_K/0`kfk00<0`kfk00@0@FWQ0:f][@2n^KP0_[Vh0P11JN440;ji^080@FWQ102n^KP2045Yh@050;B`
/@2][Jd0@FWQ045Yh@2d/;400P11JN420;B`/@030:f][@11JN40Wi^P00@0Wi^P00D0[Jf]08QF1`28
EPL0R5H70:f][@100;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]045Yh@2:
QGD01P2:QGD00`2][Jd0@FWQ045Yh@020:BNS`03045Yh@2TWXl0Y9j?00<0@FWQ00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP80@FWQ1P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0
[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`020<>m^`03
045Yh@33_K/0`kfk0080@FWQ1@33_K/2045Yh@040:f][@2n^KP0@FWQ045Yh@@0_[Vh00<0@FWQ0;ji
^02n^KP00P2n^KP01@11JN4000000:f][@2][Jd0];2a0080@FWQ00<0];2a045Yh@11JN400P2d/;40
0`2][Jd0Wi^P09nKX00409nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00E@2`h>H0
0`000000[Jf]09MP2`0209MP2`030:f][@11JN40RXEe00H0RXEe00D0[Jf]045Yh@11JN40Y9j?045Y
h@030:BNS`04045Yh@2][Jd0[Jf]0:f][@D0/J^M00<0@FWQ0;6[W@2aZid01P2aZid00`2][Jd0^K:V
0;VbYP070;VbYP@0@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`
0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l
0:f][@030:f][@d0a/2l00H0[Jf]0<>m^`33_K/0`kfk045Yh@33_K/4045Yh@D0`kfk0P11JN40102]
[Jd0_[Vh045Yh@11JN440;ji^003045Yh@2n^KP0_[Vh0080_[Vh0P2][Jd30;B`/@80@FWQ0P2d/;40
1011JN40];2a0;B`/@2][Jd709nKX0040:f][@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V00<0
[Jf]09MP2`2GH0/00P2][Jd00`11JN40RXEe08Z5M@0508Z5M@050:f][@2TWXl0@FWQ0:BNS`11JN40
0`2TWXl00`11JN40Y9j?0:BNS`020:f][@@0/J^M00<0@FWQ0;6[W@2aZid01P2aZid00`2][Jd0^K:V
0;VbYP070;VbYP80@FWQ0P2i/ZH2045Yh@030;VbYP2][Jd0_[N/00`0_[N/102][Jd00`2n]j`0[Jf]
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40a/2l
00@0[Jf]0<>m^`11JN40@FWQ0`33_K/2045Yh@D0`kfk0`11JN40102][Jd0_[Vh045Yh@11JN440;ji
^003045Yh@2n^KP0_[Vh0080[Jf]00<0_[Vh0:f][@2d/;400P2d/;43045Yh@050;B`/@11JN40];2a
0;B`/@2][Jd01`2OVj020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP
2`2][Jd0Hf1C0P2][Jd608Z5M@040:f][@2TWXl0Y9j?0:BNS`80@FWQ0`2TWXl01`11JN40Y9j?0:BN
S`2][Jd0/J^M045Yh@2][Jd00P2aZid00`11JN40/J^M0;6[W@060;6[W@030:f][@2i/ZH0^K:V00L0
^K:V0P11JN440;VbYP03045Yh@2][Jd0_[N/0100_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`0102][Jd0
`kfk045Yh@11JN440<>m^`03045Yh@33_K/0`kfk00<0`kfk0`11JN40102][Jd0_[Vh045Yh@11JN44
0;ji^003045Yh@2][Jd0[Jf]00<0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P11JN400`2d/;40@FWQ0;B`
/@020;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`
h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`060:BNS`04045Yh@2T
WXl0Y9j?0:f][@80@FWQ00@0/J^M0:f][@2][Jd0@FWQ202aZid00`2][Jd0^K:V0;VbYP070;VbYP80
@FWQ102i/ZH2045Yh@@0_[N/0`11JN4;0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00L0
a/2l0`11JN460<K0_0030:f][@11JN40@FWQ00D0`kfk00<0@FWQ0<>m^`33_K/00`33_K/3045Yh@06
0:f][@11JN40@FWQ0;ji^011JN40_[Vh0P2][Jd00`11JN40_[Vh0;ji^0030;ji^0040:f][@2d/;40
];2a0;B`/@80@FWQ1@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00<0L6ii0:f][@2][Jd0@02`
h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd408Z5M@03045Yh@2][Jd0Y9j?00L0Y9j?00@0@FWQ
0:BNS`2TWXl0[Jf]0P11JN430;6[W@03045Yh@2][Jd0[Jf]00H0/J^M00<0[Jf]0;VbYP2i/ZH01`2i
/ZH2045Yh@D0^K:V00<0@FWQ0;jg[02n]j`00`2n]j`4045Yh@T0_[N/00<0[Jf]0<6j/031^[001@31
^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0
[Jf]0<K0_036`;`01@36`;`3045Yh@P0a/2l00<0[Jf]045Yh@11JN401@33_K/00`11JN40`kfk0<>m
^`030<>m^`80@FWQ00L0`kfk045Yh@11JN40@FWQ0;ji^011JN40[Jf]0080_[Vh00<0@FWQ0;ji^02n
^KP00`2n^KP00`2][Jd0];2a0;B`/@02045Yh@H0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0
Wi^P0:f][@02071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f]
[@2:QGD0[Jf]0080RXEe0P11JN400`2][Jd0Y9j?0:BNS`070:BNS`03045Yh@2TWXl0[Jf]0080@FWQ
0`2aZid00`11JN40/J^M0;6[W@030:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH01`2i/ZH2045Yh@@0^K:V
00<0[Jf]045Yh@11JN40102n]j`2045Yh@/0_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`01`36`;`00`11JN40a/2l
0<K0_0060<K0_0030:f][@11JN40@FWQ00D0`kfk00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@030<>m
^`11JN40@FWQ0080[Jf]00@0@FWQ0;ji^02n^KP0_[Vh0P11JN440;ji^0030:f][@2d/;40];2a00P0
];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe0:f][@2:QGD00P11JN400`2]
[Jd0Y9j?0:BNS`080:BNS`80@FWQ00<0/J^M045Yh@2aZid00P2aZid00`11JN40/J^M0;6[W@030;6[
W@80[Jf]00<0/J^M0:f][@2i/ZH0202i/ZH2045Yh@@0^K:V00<0[Jf]045Yh@11JN40102n]j`2045Y
h@/0_[N/00<0[Jf]045Yh@11JN403`31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l
00d0al6l1`11JN470<K0_003045Yh@36`;`0a/2l00H0a/2l00<0[Jf]045Yh@11JN401@33_K/00`11
JN40`kfk0<>m^`030<>m^`03045Yh@33_K/0[Jf]0080@FWQ0P2n^KP01011JN40_[Vh0;ji^02n^KP2
045Yh@@0_[Vh00<0[Jf]045Yh@2d/;40202d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00P0[Jf]08Z5
M@2:QGD0RXEe0:f][@2:QGD0@FWQ0:f][@/0Y9j?00<0[Jf]0;6[W@11JN400`2aZid00`11JN40/J^M
0;6[W@050;6[W@<0[Jf]202i/ZH2045Yh@@0^K:V00<0[Jf]0;jg[011JN40102n]j`2045Yh@X0_[N/
0`11JN400`31^[00@FWQ045Yh@0?0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02036_kL5045Yh@P0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0
b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00X0al6l1011JN430<O1_0040:f][@36`;`0@FWQ045Y
h@H0a/2l00<0@FWQ0<K0_036`;`01P36`;`00`2][Jd0@FWQ045Yh@050<>m^`80@FWQ0`33_K/0102]
[Jd0@FWQ0:f][@33_K/2045Yh@80_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN440;ji^0030:f][@11
JN40];2a00P0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0
[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2045Yh@P0/J^M00<0[Jf]0;VbYP2][Jd00P2][Jd5
0;VbYP80@FWQ102i/ZH00`2][Jd0_[N/045Yh@040;jg[080@FWQ2P2n]j`00`11JN40[Jf]0<6j/003
0<6j/005045Yh@31^[00`KZ`0<6j/011JN402P31^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0[Jf]4@35
_[D00`2][Jd0a[ng0<Jo]`0;0<Jo]`@0@FWQ1P36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`03037
`K`2045Yh@<0al6l00<0[Jf]0<K0_036`;`00P11JN450<K0_003045Yh@36`;`0a/2l00H0a/2l00@0
[Jf]0<>m^`11JN40@FWQ1033_K/2045Yh@<0[Jf]00@0`kfk045Yh@33_K/0`kfk0P11JN430;ji^003
045Yh@2n^KP0_[Vh0080@FWQ102n^KP00`2][Jd0@FWQ0;B`/@080;B`/@80[Jf]1P2OVj000`2][Jd0
L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe
08Z5M@0308Z5M@80[Jf]2`2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80@FWQ202aZid00`2][Jd0^K:V
0;VbYP020;VbYP<0[Jf]0P2i/ZH2045Yh@@0^K:V00<0[Jf]0;jg[011JN40102n]j`2045Yh@X0_[N/
00<0@FWQ0:f][@31^[000`31^[001011JN40`KZ`045Yh@11JN470<6j/005045Yh@31^[00`KZ`0<6j
/02][Jd05033_K<00`000000[Jf]0<Fn]@040<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0;0<Jo
]`80@FWQ2036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00<0<O1
_080@FWQ0`37`K`00`2][Jd0a/2l0<K0_002045Yh@D0a/2l00<0@FWQ0<K0_036`;`01P36`;`00`2]
[Jd0`kfk0<>m^`07045Yh@<0`kfk0P11JN420<>m^`030:f][@11JN40_[Vh0080_[Vh0P11JN400`2n
^KP0@FWQ045Yh@040;ji^0030:f][@11JN40];2a00P0];2a00<0[Jf]09nKX02OVj001@2OVj001@2]
[Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2]
[Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2045Y
h@P0/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH20:f][@80@FWQ102i/ZH0102][Jd0_[N/045Yh@11JN43
0;jg[080@FWQ2P2n]j`00`11JN40`KZ`0<6j/0040<6j/080@FWQ2031^[001`11JN40`KZ`0<6j/031
^[00[Jf]0<>m/`11JN404`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]0P36_kL2045Yh@P0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00`0al6l0P11JN430<O1_0050:f][@36`;`0a/2l0<K0_011
JN401@36`;`00`11JN40a/2l0<K0_0060<K0_0030:f][@33_K/0`kfk0080`kfk0`2][Jd2045Yh@<0
`kfk0P11JN420<>m^`030:f][@11JN40_[Vh00<0@FWQ0`2n^KP00`11JN40_[Vh0;ji^0020;ji^003
0:f][@11JN40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0/J^M
0080/J^M0P11JN480;6[W@030:f][@2i/ZH0^K:V00L0^K:V0P11JN430:f][@030;VbYP2][Jd0_[N/
0080@FWQ0`2n]j`2045Yh@X0_[N/00<0@FWQ0<6j/031^[001031^[02045Yh@P0`KZ`00L0@FWQ0<6j
/031^[00`KZ`0:f][@33_K<0@FWQ01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`090<Jo]`80[Jf]0P11JN4/0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00`0al6l0P11JN430<O1_0050:f][@36`;`0a/2l0<K0_011JN40
1@36`;`00`11JN40a/2l0<K0_0060<K0_0030:f][@33_K/0[Jf]0080[Jf]0`33_K/00`11JN40`kfk
0<>m^`020<>m^`80@FWQ0P33_K/00`2][Jd0@FWQ0;ji^0060;ji^003045Yh@2n^KP0_[Vh0080_[Vh
00<0[Jf]045Yh@2d/;401@2d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^
N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BN
S`2TWXl00P2][Jd70:BNS`030:f][@2aZid0/J^M0080/J^M0P11JN480;6[W@030:f][@2i/ZH0^K:V
00L0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH30:f][@80@FWQ0`2n]j`2045Yh@X0_[N/00<0@FWQ0<6j
/031^[001031^[02045Yh@L0`KZ`00<0@FWQ0<6j/011JN400P31^[000`2][Jd0`kfc045Yh@0<0<>m
/`<0@FWQ1033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00/0a[ng0P11JN480<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03037`K`2045Yh@<0al6l00D0[Jf]0<K0
_036`;`0a/2l045Yh@050<K0_080@FWQ1@36`;`40:f][@H0`kfk00<0@FWQ0<>m^`33_K/00P33_K/2
045Yh@030<>m^`11JN40[Jf]00P0_[Vh0P11JN430;ji^080@FWQ102d/;420:f][@<0];2a00<0[Jf]
09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]
06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0
[Jf]0;6[W@2aZid00P2aZid2045Yh@P0/J^M00<0[Jf]0;VbYP2i/ZH01`2i/ZH00`11JN40^K:V0;Vb
YP030;VbYP040:f][@2n]j`0@FWQ045Yh@80[Jf]00<0_[N/045Yh@11JN402P2n]j`00`11JN40`KZ`
0<6j/0040<6j/080@FWQ1`31^[03045Yh@80`KZ`00@0[Jf]045Yh@11JN40@FWQ2@33_K<3045Yh@80
`kfc00<0@FWQ0<>m/`33_K<00P11JN440<Fn]@@0@FWQ3P35_[D00`2][Jd0a[ng0<Jo]`0;0<Jo]`80
@FWQ2036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/03P38`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`03037`K`2045Yh@<0al6l00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l0<K0_0020<K0_080
@FWQ1@2][Jd20<K0_0040:f][@33_K/0@FWQ045Yh@@0`kfk00<0@FWQ0<>m^`33_K/00P33_K/3045Y
h@030<>m^`2][Jd0_[Vh00L0_[Vh0P11JN430;ji^080@FWQ0P2d/;420:f][@D0];2a00<0[Jf]09nK
X02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C
0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2
045Yh@P0/J^M00<0[Jf]0;VbYP2i/ZH01`2i/ZH00`11JN40^K:V0;VbYP030;VbYP040:f][@2n]j`0
@FWQ045Yh@80_[N/00@0[Jf]045Yh@11JN40[Jf]2@2n]j`2045Yh@D0`KZ`0P11JN470<6j/0<0@FWQ
0P31^[00102][Jd0@FWQ045Yh@11JN480<>m/`80@FWQ1@33_K<01011JN40`kfc045Yh@11JN460<Fn
]@@0@FWQ3035_[D00`2][Jd0a[ng0<Jo]`0;0<Jo]`80@FWQ2036_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`11JN400P38`K/4045Yh@L0b<6k00<0@FWQ0<S1
^`11JN401038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00`0al6l0P11JN430<O1
_0030:f][@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`00P2][Jd2045Yh@L0a/2l00@0[Jf]0<>m
^`11JN40@FWQ1033_K/01011JN40`kfk0<>m^`33_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP01P2n
^KP2045Yh@80_[Vh00D0@FWQ0:f][@11JN40];2a0:f][@070;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f]
[@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M0080/J^M0P11JN470;6[W@030:f]
[@2i/ZH0^K:V00P0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH0102][Jd0_[N/045Yh@11JN430;jg[080
@FWQ00<0_[N/0:f][@2][Jd00P2][Jd50;jg[0030:f][@11JN40`KZ`00@0`KZ`0P11JN470<6j/003
045Yh@31^[00@FWQ0080`KZ`00@0[Jf]045Yh@11JN40@FWQ2033_K<00`11JN40`kfc0<>m/`050<>m
/`<0@FWQ1P35_[D2045Yh@h0aKje1011JN450<Jo]`80@FWQ0`36_kL2045Yh@80a[ng0`11JN430<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]045Yh@11JN401011JN470<O1^P@0@FWQ1P37`KX00`2]
[Jd0b<6k045Yh@02045Yh@@0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00<0<O1_080@FWQ0`37`K`00`2][Jd0a/2l0<K0_0020:f]
[@03045Yh@2][Jd0[Jf]0080a/2l0P11JN440<K0_004045Yh@36`;`0a/2l0:f][@80`kfk00<0@FWQ
0<>m^`33_K/00P11JN490<>m^`030:f][@2n^KP0_[Vh00L0_[Vh1011JN430:f][@P0];2a00<0[Jf]
09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]
00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@@0/J^M00<0@FWQ0;6[W@2aZid01P2aZid00`2]
[Jd0^K:V0;VbYP080;VbYP03045Yh@2i/ZH0^K:V00<0^K:V00@0[Jf]0;jg[011JN40@FWQ0`2n]j`2
045Yh@D0_[N/102][Jd00`2n]j`0[Jf]0<6j/002045Yh@<0`KZ`0P11JN470<6j/003045Yh@31^[00
@FWQ0080`KZ`00@0[Jf]045Yh@33_K<0@FWQ1`33_K<2045Yh@P0`kfc0P11JN460<Fn]@80@FWQ3035
_[D3045Yh@<0a[ng0P11JN400`36_kL0@FWQ045Yh@050<Jo]`@0@FWQ0P36_kL2045Yh@80a[ng00<0
[Jf]0<O1^037`KP00P37`KP7045Yh@80al6h1`11JN420<O1^0030:f][@37`KX0al6j0080@FWQ1`37
`KX2045Yh@@0al6j0P11JN440<O1^P040:f][@38`K/0@FWQ045Yh@L0b<6k00<0@FWQ0<S1^`38`K/0
2@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00`0al6l0P11JN400`37`K`0[Jf]
0:f][@030:f][@80a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@<0a/2l0P11JN420<K0_0040:f]
[@33_K/0`kfk0<>m^`80@FWQ2`33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0
Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f]
[@2TWXl0Y9j?00T0Y9j?0P2][Jd30;6[W@03045Yh@2aZid0/J^M00H0/J^M00<0[Jf]0;VbYP2i/ZH0
202i/ZH00`11JN40^K:V0;VbYP030;VbYP040:f][@2n]j`0@FWQ045Yh@<0_[N/0`11JN430;jg[003
045Yh@2n]j`0_[N/0080_[N/1@2][Jd2045Yh@030<6j/011JN40@FWQ00H0`KZ`0P11JN402031^[00
@FWQ0<6j/031^[00[Jf]045Yh@33_K<0@FWQ1`33_K<2045Yh@P0`kfc0P11JN460<Fn]@80@FWQ2`35
_[D2045Yh@030<Fn]@2][Jd0a[ng00<0a[ng0`11JN460<Jo]`<0@FWQ1036_kL2045Yh@030<Jo]`2]
[Jd0al6h00H0al6h0P11JN470<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P02045Yh@H0al6j0P11
JN460<O1^P03045Yh@37`KX0al6j0080al6j00@0[Jf]0<S1^`11JN40@FWQ1`38`K/00`11JN40b<6k
0<S1^`090<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`20:f][@80@FWQ
00@0[Jf]0<O1_037`K`0[Jf]1036`;`00`11JN40a/2l0<K0_0020<K0_0<0@FWQ0`36`;`01011JN40
a/2l0<K0_02][Jd@0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`
/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]2@2aZid00`2][Jd0^K:V0;VbYP080;VbYP03
045Yh@2i/ZH0^K:V00<0^K:V00@0[Jf]0;jg[011JN40@FWQ0`2n]j`3045Yh@80_[N/0P11JN450;jg
[0040:f][@31^[00`KZ`0<6j/080[Jf]0`11JN420:f][@@0`KZ`0P11JN420<6j/006045Yh@31^[00
@FWQ045Yh@33_K<0@FWQ1`33_K<2045Yh@P0`kfc0P11JN460<Fn]@80@FWQ2`35_[D2045Yh@030<Fn
]@2][Jd0a[ng00@0a[ng0P11JN460<Jo]`80@FWQ1P36_kL2045Yh@030:f][@37`KP0al6h00D0al6h
0P11JN470<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P02045Yh@H0al6j00<0@FWQ0<O1^P37`KX0
1P37`KX01`11JN40al6j0<O1^P37`KX0[Jf]0<S1^`11JN402038`K/00`11JN40b<6k0<S1^`090<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@80al6l0P11JN430<O1
_0030:f][@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@050<K0_011JN40a/2l
0<K0_011JN400P36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd3
0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool0
05X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M
0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00P0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`2]
[Jd0@FWQ045Yh@020;jg[0@0@FWQ00H0_[N/045Yh@2n]j`0@FWQ0;jg[011JN440;jg[080@FWQ1@31
^[02045Yh@80`KZ`102][Jd01P11JN40[Jf]0:f][@31^[00@FWQ0<6j/080@FWQ0P33_K<00`11JN40
`kfc0<>m/`030<>m/`80@FWQ2@33_K<2045Yh@H0aKje0P11JN4;0<Fn]@80@FWQ00<0aKje0:f][@36
_kL01036_kL2045Yh@H0a[ng0P11JN470<Jo]`80@FWQ1`37`KP2045Yh@L0al6h0P11JN450<O1^004
0:f][@37`KX0@FWQ045Yh@D0al6j0P11JN4<0<O1^P030:f][@38`K/0@FWQ00L0b<6k0P11JN4;0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd70<O1_003045Yh@37`K`0@FWQ
0080al6l00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ0P36`;`2045Y
h@<0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2]
[Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?oo
o`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2a
Zid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0202i/ZH00`11JN40^K:V0;VbYP030;VbYP03
0:f][@11JN40@FWQ00@0_[N/0P11JN420;jg[004045Yh@2n]j`0@FWQ045Yh@@0_[N/0P11JN450<6j
/003045Yh@31^[00`KZ`00D0`KZ`00L0@FWQ0<6j/031^[00[Jf]045Yh@2][Jd0@FWQ00<0[Jf]00<0
@FWQ0<>m/`33_K<00`33_K<2045Yh@T0`kfc0P11JN460<Fn]@80@FWQ2`35_[D2045Yh@030<Fn]@2]
[Jd0a[ng00@0a[ng0P11JN460<Jo]`80@FWQ1`36_kL2045Yh@L0al6h0P11JN470<O1^080@FWQ1@37
`KP0102][Jd0al6j045Yh@11JN450<O1^P03045Yh@37`KX0al6j00/0al6j00<0[Jf]0<S1^`38`K/0
1P38`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][@d0al6l0P11JN420<O1_0030:f]
[@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`00`11JN490<K0_0030:f][@33_K/0`kfk00d0`kfk
00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02O
Vj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH0
2@2i/ZH00`11JN40^K:V0;VbYP030;VbYP030:f][@11JN40@FWQ00T0_[N/0P11JN450;jg[0030:f]
[@11JN40`KZ`00@0`KZ`00<0@FWQ0<6j/031^[001@31^[001`11JN40`KZ`0<6j/031^[00@FWQ0000
0011JN400`33_K<00`11JN40[Jf]0:f][@030:f][@80@FWQ1`33_K<4045Yh@H0aKje00<0@FWQ0<Fn
]@35_[D02P35_[D2045Yh@030<Fn]@2][Jd0a[ng00@0a[ng0P11JN460<Jo]`80@FWQ2036_kL00`11
JN40al6h0<O1^0050<O1^080@FWQ1`37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40@FWQ1@37`KX0
0`11JN40al6j0<O1^P0;0<O1^P030:f][@38`K/0b<6k00D0b<6k0P11JN470<S1^`03045Yh@38`K/0
b<6k00<0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`03@37`K`2
045Yh@80al6l00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l0<K0_00<0<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2O
Vj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@02
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@T0^K:V00<0@FWQ
0;VbYP2i/ZH00`2i/ZH2045YhA40_[N/00<0[Jf]045Yh@31^[000`31^[000`11JN40`KZ`0<6j/006
0<6j/007045Yh@31^[00`KZ`0<6j/011JN40`KZ`045Yh@030<>m/`03045Yh@33_K<0`kfc00<0`kfc
0P11JN470:f][@80`kfc1011JN440<Fn]@80@FWQ3035_[D2045Yh@030:f][@36_kL0a[ng00<0a[ng
0P11JN460<Jo]`80@FWQ2036_kL00`11JN40al6h0<O1^0050<O1^080@FWQ1`37`KP2045Yh@D0al6h
00@0[Jf]0<O1^P11JN40@FWQ1@37`KX00`11JN40al6j0<O1^P0;0<O1^P030:f][@38`K/0b<6k00<0
b<6k0`11JN480<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1
^`030:f][@37`K`0al6l00d0al6l0P11JN420<O1_0040:f][@36`;`0a/2l0<K0_080@FWQ3P36`;`0
0`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00
Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2]
[Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]1@2i/ZH00`11JN40^K:V0;VbYP030;Vb
YP80@FWQ4@2n]j`00`2][Jd0`KZ`045Yh@03045Yh@P0`KZ`00<0@FWQ0<6j/031^[000P31^[000`11
JN40`KZ`045Yh@030<>m/`03045Yh@33_K<0`kfc00<0`kfc0P11JN470<>m/`T0[Jf]00<0aKje045Y
h@11JN403@35_[D2045Yh@D0a[ng0P11JN460<Jo]`80@FWQ2036_kL00`11JN40al6h0<O1^0050<O1
^080@FWQ1`37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40@FWQ1@37`KX00`11JN40al6j0<O1^P0;
0<O1^P040:f][@38`K/0b<6k0<S1^`@0@FWQ2@38`K/00`11JN40[Jf]0:f][@070:f][A80b<6k00<0
[Jf]0<O1_037`K`03@37`K`2045Yh@80al6l00@0[Jf]0<K0_036`;`0a/2l0P11JN4>0<K0_0030:f]
[@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a
00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2a
Zid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@<0@FWQ102i/ZH2045YhA80_[N/00<0
[Jf]0<6j/031^[002031^[04045Yh@D0`KZ`00<0@FWQ0:f][@33_K<00`33_K<00`11JN40`kfc0<>m
/`020<>m/`80@FWQ2@33_K<00`000000[Jf]0<Fn]@040<Fn]@030:f][@11JN40@FWQ00T0[Jf]1@35
_[D0102][Jd0@FWQ045Yh@11JN420<Jo]`80@FWQ1P36_kL2045Yh@P0a[ng00<0@FWQ0<O1^037`KP0
1@37`KP2045Yh@L0al6h0P11JN450<O1^0040:f][@37`KX0@FWQ045Yh@D0al6j00<0@FWQ0<O1^P37
`KX02`37`KX00`2][Jd0b<6k0<S1^`03045Yh@/0[Jf]00<0@FWQ0<S1^`38`K/00`38`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00d0al6l0P11JN430<O1_0030:f][@36`;`0a/2l0080
@FWQ3P36`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^003
0:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M
0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd6045YhA80_[N/00<0[Jf]0<6j/031^[00
2`31^[04045Yh@80`KZ`00<0@FWQ0:f][@33_K<00`33_K<00`11JN40`kfc0<>m/`020<>m/`80@FWQ
2P33_K<00`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ2@35_[D90:f][@@0@FWQ102][Jd20<Jo]`80@FWQ
2036_kL00`11JN40al6h0<O1^0050<O1^080@FWQ1`37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40
@FWQ1@37`KX00`11JN40al6j0<O1^P060:f][@03045Yh@2][Jd0[Jf]00@0[Jf]0P11JN420:f][@D0
b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`03@37`K`2045Yh@<0al6l00@0[Jf]0<K0_011JN40@FWQ3`36`;`00`2]
[Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a
00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`03
0:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140
_[N/00<0[Jf]0<6j/031^[004@31^[000`11JN40[Jf]0<>m/`04045Yh@@0`kfc0P11JN4:0<>m/`03
0:f][@35_[D0aKje00@0aKje0P11JN450<Fn]@03045Yh@35_[D0aKje00D0aKje00<000000:f][@36
_kL01036_kL2045Yh@@0a[ng0P2][Jd2045Yh@P0[Jf]00<0@FWQ0:f][@2][Jd01@2][Jd2045Yh@L0
[Jf]0P11JN470:f][@80@FWQ1@2][Jd2045Yh@030:f][@37`KX0al6j00@0al6j0P11JN430<O1^P04
0:f][@38`K/0@FWQ045Yh@H0b<6k0P11JN450<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00=0<O1_080@FWQ0`37`K`0102][Jd0a/2l045Yh@11JN4?
0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40
];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<00P33_K<3045Yh@80`kfc0P11JN4:0<>m/`030:f][@35_[D0aKje00@0aKje00<0@FWQ0<Fn
]@11JN400`35_[D2045Yh@H0aKje0P11JN400`2][Jd0a[ng0<Jo]`030<Jo]`03045Yh@36_kL0a[ng
00D0a[ng0P11JN470<Jo]`80@FWQ1`37`KP2045Yh@L0al6h0P11JN450<O1^0040:f][@37`KX0@FWQ
045Yh@D0al6j0P11JN470<O1^P80@FWQ0`37`KX00`2][Jd0b<6k045Yh@070<S1^`80@FWQ1@38`K/0
0`11JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03@37`K`2
045Yh@<0al6l00<0[Jf]045Yh@11JN403P36`;`40:f][@h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0
0`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0/>3V0@3oool006D0/>3V0P2][Jd60:BN
S`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0:f][@030:f]
[@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`070<>m/`80@FWQ2P33_K<00`2]
[Jd0aKje0<Fn]@040<Fn]@04045Yh@35_[D0aKje045Yh@80aKje00<0@FWQ0<Fn]@11JN401@35_[D2
045Yh@030:f][@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL2045Yh@L0a[ng0P11JN47
0<O1^080@FWQ1`37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40@FWQ1@37`KX00`11JN40al6j045Y
h@060<O1^P03045Yh@37`KX0al6j0080al6j00<0[Jf]0<S1^`11JN401P38`K/3045Yh@@0b<6k0P11
JN450<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03@37`K`2045Yh@<0al6l00<0
[Jf]045Yh@11JN402@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`4
0:f][@T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`03045Yh@33_K<0
`kfc00P0`kfc00@0[Jf]0<Fn]@35_[D0aKje1011JN420<Fn]@04045Yh@35_[D0aKje0<Fn]@80@FWQ
1P35_[D00`11JN40[Jf]0<Jo]`040<Jo]`03045Yh@36_kL0a[ng00D0a[ng0P11JN460<Jo]`80@FWQ
00<0[Jf]0<O1^037`KP01@37`KP2045Yh@H0al6h0P11JN460<O1^0040:f][@37`KX0@FWQ045Yh@H0
al6j0P11JN460<O1^P03045Yh@37`KX0al6j0080al6j00@0[Jf]0<S1^`38`K/0@FWQ1038`K/01011
JN40b<6k0<S1^`11JN440<S1^`<0@FWQ1038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l00d0al6l0P11JN430<O1_080@FWQ1P36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0
0`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H2
0:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<0
0`11JN40`kfc0<>m/`080<>m/`03045Yh@35_[D0aKje00P0aKje1011JN480<Fn]@<0@FWQ0`36_kL0
0`11JN40a[ng0<Jo]`050<Jo]`<0@FWQ1036_kL2045Yh@030<Jo]`2][Jd0al6h00H0al6h1011JN44
0<O1^080@FWQ1P37`KP0102][Jd0al6j045Yh@11JN470<O1^P80@FWQ1037`KX00`11JN40al6j0<O1
^P030<O1^P040:f][@38`K/0b<6k0<S1^`D0@FWQ1`38`K/3045Yh@@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00=0<O1_0H0@FWQ0P36`;`50:f][@/0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][E80/>3V0@3oool006/0/>3V
0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg
[02][Jd0`KZ`01<0`KZ`00<0[Jf]0<>m/`33_K<02033_K<00`11JN40`kfc0<>m/`080<>m/`03045Y
h@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL00`11JN450<Jo]`D0@FWQ00<0a[ng045Yh@11JN40
0P11JN430<Jo]`030:f][@37`KP0al6h00D0al6h0P11JN420<O1^0@0@FWQ2037`KP4045Yh@T0al6j
1011JN460<O1^P030:f][@38`K/0b<6k00d0b<6k0`11JN440<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`02`37`K`4045Yh@030<O1_02][Jd0[Jf]00<0[Jf]4036`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33
_K<0`kfc00P0`kfc0P11JN480<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00D0al6h0P11JN4>0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03@38
`K/3045Yh@@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00;0<O1_0D0[Jf]0P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n
^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]0<>m/`33_K<02@33
_K<2045Yh@L0`kfc0P11JN4F0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37
`KP2045Yh@h0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0=0<S1^`<0@FWQ1038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`
h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc00X0`kfc00<0@FWQ
0<>m/`33_K<01033_K<2045Yh@030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^0050<O1^080@FWQ3P37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k00d0b<6k0`11JN440<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^005
0;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][Jd:0<>m/`03045Yh@33_K<0`kfc
0080`kfc00@0@FWQ0<>m/`11JN40[Jf]5P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h00D0al6h0P11JN4>0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03@38`K/3
045Yh@@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3P
iP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004@31^[000`000000[Jf]0<>m/`020<>m/`L0[Jf]1033_K<4045Yh@80`kfc00<0@FWQ0:f]
[@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00D0al6h0P11JN4>0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03@38`K/2045Yh@D0b<6k00<0[Jf]0<S1
^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80
[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@80`kfc00<0@FWQ0:f][@35_[D05@35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00D0al6h0P11JN4>0<O1^0030:f][@37`KX0@FWQ01@0
al6j00<0[Jf]0<S1^`38`K/03P38`K/00`11JN40b<6k0<S1^`030<S1^`040:f][@38`K/0b<6k0<S1
^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00D0al6h0P11JN4>0<O1^0040:f][@11JN40al6j045Y
hA<0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n0;3PiP@0
[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h0080al6h1@11JN4>0<O1^0030:f][@37`KX0@FWQ01@0al6j00<000000<S1^`38
`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V
0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h
:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3o
ool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec
0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?oo
o`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V
102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0
/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3P
iP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]
X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H1
0?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52338 .33411 m
.52004 .3309 L
s
.52004 .3309 m
.5167 .33089 L
s
.52506 .33411 m
.52004 .3309 L
s
.5167 .33089 m
.51335 .33407 L
s
.5167 .33089 m
.51168 .33406 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5451 .33068 m
.53842 .3308 L
s
.49832 .33064 m
.48832 .33039 L
s
.55177 .33053 m
.54845 .33382 L
s
.55511 .33044 m
.55177 .33053 L
s
.255 .412 .882 r
.51429 .32285 m
.52585 .32288 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56504 .34857 m
.56519 .34942 L
s
.255 .412 .882 r
.5242 .34087 m
.52752 .33861 L
s
.52752 .33861 m
.53083 .33859 L
s
.53083 .33859 m
.53414 .34081 L
s
.53083 .33859 m
.5358 .3408 L
s
.5093 .33854 m
.51096 .33856 L
s
.50599 .34075 m
.5093 .33854 L
s
.50764 .34077 m
.5093 .33854 L
s
.52089 .34538 m
.5242 .34087 L
s
0 0 0 r
.58007 .33911 m
.58051 .33823 L
s
.255 .412 .882 r
.53414 .34081 m
.53746 .34529 L
s
.5358 .3408 m
.53912 .34526 L
s
.49773 .33835 m
.50103 .34067 L
s
.49277 .33823 m
.49773 .33835 L
s
.50598 .34526 m
.50764 .34077 L
s
.50433 .34523 m
.50599 .34075 L
s
.55067 .33828 m
.56222 .33794 L
s
.50103 .34067 m
.50433 .34523 L
s
.48946 .34039 m
.49277 .33823 L
s
.48781 .34034 m
.49277 .33823 L
s
0 0 0 r
.45356 .3288 m
.45457 .32953 L
s
.59283 .32999 m
.59486 .33183 L
s
.59317 .32977 m
.5965 .33172 L
s
.45356 .3288 m
.45457 .32986 L
s
.45356 .3288 m
.45027 .32859 L
s
.52674 .36632 m
.52798 .35915 L
s
.52842 .36631 m
.52966 .35915 L
s
.50875 .3592 m
.50996 .36626 L
s
.50708 .3592 m
.50828 .36624 L
s
.255 .412 .882 r
.53746 .34529 m
.53913 .35204 L
s
.48779 .34485 m
.48946 .34039 L
s
.53912 .34526 m
.54079 .35201 L
s
.48615 .3448 m
.48781 .34034 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48778 .34937 m
.48779 .34485 L
s
.48612 .34932 m
.48615 .3448 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5688 .33769 m
.58028 .33717 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53913 .35204 m
.53914 .35656 L
s
.54079 .35201 m
.5408 .35653 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48778 .34937 m
.48941 .35394 L
s
.4534 .33651 m
.46482 .33715 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52089 .37027 m
.5209 .32288 L
s
.51922 .37026 m
.51924 .32288 L
s
.50595 .36108 m
.50598 .34526 L
s
.50428 .36559 m
.50433 .34523 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57536 .3374 m
.57553 .36229 L
s
0 0 0 r
.57862 .36904 m
.57866 .37476 L
s
.58027 .36793 m
.58032 .37468 L
s
.255 .412 .882 r
.57372 .33748 m
.57388 .36236 L
s
.48612 .34932 m
.48776 .35389 L
s
.53749 .36337 m
.53914 .35656 L
s
.53915 .36335 m
.5408 .35653 L
s
.45967 .36861 m
.45992 .33689 L
s
.48941 .35394 m
.49271 .35629 L
s
.58681 .33681 m
.5982 .33611 L
s
.45804 .36853 m
.45829 .3368 L
s
.48776 .35389 m
.49271 .35629 L
s
.49271 .35629 m
.50264 .35877 L
s
.50264 .35877 m
.50429 .36106 L
s
0 0 0 r
.61298 .345 m
.613 .34668 L
s
.255 .412 .882 r
.50428 .36559 m
.50595 .36108 L
s
0 0 0 r
.613 .34668 m
.61313 .34489 L
s
.255 .412 .882 r
.52089 .36346 m
.52421 .368 L
s
.53418 .36794 m
.53749 .36337 L
s
.53584 .36793 m
.53915 .36335 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50261 .36783 m
.50428 .36559 L
s
.52421 .368 m
.52754 .37026 L
s
.53086 .37024 m
.53418 .36794 L
s
.53086 .37024 m
.53584 .36793 L
s
.48772 .36295 m
.48937 .363 L
s
.48936 .36527 m
.48937 .363 L
s
.55738 .36296 m
.56071 .3674 L
s
.48771 .36522 m
.48772 .36295 L
s
.49929 .37004 m
.50261 .36783 L
s
.51424 .37024 m
.52089 .37027 L
s
.52754 .37026 m
.53086 .37024 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48771 .36522 m
.48935 .36754 L
s
.49266 .36989 m
.49929 .37004 L
s
.48935 .36754 m
.49266 .36989 L
s
.56071 .3674 m
.56568 .3695 L
s
.4712 .36462 m
.47286 .36242 L
s
.47286 .36242 m
.4745 .36476 L
s
.57226 .36698 m
.57388 .36236 L
s
.45978 .35499 m
.46137 .36188 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44186 .35388 m
.44204 .33575 L
s
.44349 .35399 m
.44366 .33587 L
s
.47448 .36703 m
.4745 .36476 L
s
.57391 .36691 m
.57553 .36229 L
s
.43879 .33777 m
.44198 .34254 L
s
.43398 .33514 m
.43879 .33777 L
s
.4712 .36462 m
.47284 .36696 L
s
.56568 .3695 m
.56898 .36938 L
s
.47282 .36924 m
.47448 .36703 L
s
.56898 .36938 m
.57226 .36698 L
s
.43077 .33488 m
.43398 .33514 L
s
.56898 .36938 m
.57391 .36691 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59333 .33643 m
.59361 .36817 L
s
.5917 .33653 m
.59197 .36827 L
s
.55727 .3381 m
.55748 .3857 L
s
.55563 .33815 m
.55582 .38574 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59673 .35692 m
.59673 .35708 L
s
.59836 .35572 m
.59837 .35694 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60636 .34232 m
.60954 .33755 L
s
.60954 .33755 m
.61434 .3349 L
s
.60481 .34924 m
.60636 .34232 L
s
.61115 .33742 m
.61434 .3349 L
s
.60798 .3422 m
.61115 .33742 L
s
.46788 .36902 m
.47282 .36924 L
s
.46137 .36188 m
.46461 .36659 L
s
.61434 .3349 m
.61755 .33463 L
s
.42753 .33687 m
.43077 .33488 L
s
.42593 .33673 m
.43077 .33488 L
s
.60643 .34912 m
.60798 .3422 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46461 .36659 m
.46788 .36902 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43701 .35353 m
.44836 .35431 L
s
.61755 .33463 m
.62237 .33647 L
s
.60481 .34924 m
.60486 .35378 L
s
.42428 .34113 m
.42753 .33687 L
s
.60643 .34912 m
.60648 .35367 L
s
.55084 .38587 m
.55748 .3857 L
s
.45313 .36825 m
.45967 .36861 L
s
.42268 .34098 m
.42593 .33673 L
s
.58706 .36854 m
.59361 .36817 L
s
.60486 .35378 m
.60655 .36049 L
s
.60648 .35367 m
.60817 .36037 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62237 .33647 m
.62562 .34072 L
s
.42262 .34552 m
.42428 .34113 L
s
.42103 .34538 m
.42268 .34098 L
s
.60655 .36049 m
.60983 .3648 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60817 .36037 m
.61145 .36468 L
s
.42094 .3522 m
.42262 .34552 L
s
.41935 .35206 m
.42103 .34538 L
s
.44164 .37665 m
.44333 .36991 L
s
.59207 .37966 m
.59372 .38185 L
s
.59045 .38204 m
.59207 .37966 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4432 .38361 m
.44333 .36991 L
s
.59045 .38204 m
.59211 .38423 L
s
.63662 .33281 m
.63826 .33719 L
s
.63662 .33281 m
.63675 .3419 L
s
.59211 .38423 m
.59372 .38185 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61145 .36468 m
.6147 .36671 L
s
.60983 .3648 m
.6147 .36671 L
s
.4208 .3636 m
.42094 .3522 L
s
.43834 .381 m
.44164 .37665 L
s
.44164 .37665 m
.4432 .38361 L
s
.4192 .36346 m
.41935 .35206 L
s
.62419 .35451 m
.62582 .35664 L
s
.62262 .35693 m
.62419 .35451 L
s
.62262 .35693 m
.62425 .35906 L
s
.63826 .33719 m
.6398 .33475 L
s
.6398 .33475 m
.64291 .33213 L
s
.6147 .36671 m
.61953 .36632 L
s
.63675 .3419 m
.63826 .33719 L
s
.64291 .33213 m
.64916 .33141 L
s
.62582 .35664 m
.62585 .35892 L
s
.61953 .36632 m
.62271 .36377 L
s
.62271 .36377 m
.62585 .35892 L
s
.43346 .38293 m
.43834 .381 L
s
.4208 .3636 m
.42232 .37059 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4022 .3321 m
.40804 .36469 L
s
.39546 .36335 m
.4022 .3321 L
s
.39702 .36352 m
.4021 .33892 L
s
.4192 .36346 m
.42071 .37046 L
s
.43022 .38269 m
.43346 .38293 L
s
.42232 .37059 m
.42386 .3753 L
s
.42071 .37046 m
.42226 .37517 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64916 .33141 m
.65231 .33332 L
s
.42386 .3753 m
.42703 .38015 L
s
.63849 .35313 m
.64161 .35052 L
s
.63694 .35557 m
.63849 .35313 L
s
.42703 .38015 m
.43022 .38269 L
s
.42542 .38002 m
.43022 .38269 L
s
.63694 .35557 m
.63701 .36014 L
s
.65231 .33332 m
.65389 .3354 L
s
.42226 .37517 m
.42542 .38002 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64161 .35052 m
.64937 .34508 L
s
.63852 .35541 m
.64164 .3528 L
s
.63697 .35786 m
.63852 .35541 L
s
.4033 .3642 m
.4128 .36515 L
s
.38975 .33062 m
.39546 .36335 L
s
.38304 .36186 m
.38975 .33062 L
s
.64164 .3528 m
.64941 .34736 L
s
.63701 .36014 m
.63862 .36227 L
s
.65389 .3354 m
.654 .34225 L
s
.64937 .34508 m
.65245 .34243 L
s
.63862 .36227 m
.64181 .36423 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65245 .34243 m
.65397 .33996 L
s
.64941 .34736 m
.65249 .34472 L
s
.38458 .36206 m
.38964 .33746 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65249 .34472 m
.654 .34225 L
s
.64181 .36423 m
.64809 .36355 L
s
.66464 .33174 m
.66613 .32925 L
s
.66464 .33174 m
.66621 .33381 L
s
.66613 .32925 m
.66769 .33132 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65271 .35844 m
.65419 .35367 L
s
.64809 .36355 m
.65118 .36091 L
s
.66621 .33381 m
.66769 .33132 L
s
.37443 .32857 m
.37594 .32879 L
s
.65118 .36091 m
.65271 .35844 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65271 .35844 m
.65434 .36284 L
s
.65419 .35367 m
.65434 .36284 L
s
.37135 .33042 m
.37443 .32857 L
s
.37287 .33064 m
.37443 .32857 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37127 .33499 m
.37287 .33064 L
s
.37842 .36127 m
.38922 .36262 L
s
.36976 .33477 m
.37135 .33042 L
s
.66641 .34525 m
.66843 .37262 L
s
.66536 .37302 m
.66641 .34525 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37097 .35104 m
.37127 .33499 L
s
.36683 .32975 m
.36976 .33477 L
s
.36937 .35543 m
.36976 .33477 L
s
.36388 .327 m
.36683 .32975 L
s
.35941 .32629 m
.36388 .327 L
s
.66665 .35901 m
.6669 .37282 L
s
.35639 .3281 m
.35941 .32629 L
s
.35492 .32785 m
.35941 .32629 L
s
.36937 .35543 m
.37097 .35104 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36799 .34831 m
.36945 .35083 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35904 .34465 m
.36799 .34831 L
s
.66536 .37302 m
.66698 .37743 L
s
.36781 .35751 m
.36937 .35543 L
s
.35482 .33244 m
.35639 .3281 L
s
.66698 .37743 m
.66843 .37262 L
s
.35335 .3322 m
.35492 .32785 L
s
.36475 .35938 m
.36781 .35751 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35473 .33704 m
.35482 .33244 L
s
.35611 .34188 m
.35904 .34465 L
s
.35463 .34164 m
.35904 .34465 L
s
.35325 .3368 m
.35335 .3322 L
s
.35473 .33704 m
.35611 .34188 L
s
.35876 .35848 m
.36475 .35938 L
s
.35325 .3368 m
.35463 .34164 L
s
.35444 .35086 m
.35592 .35109 L
s
.35588 .3534 m
.35592 .35109 L
s
.35583 .35571 m
.35876 .35848 L
s
.35439 .35316 m
.35444 .35086 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35439 .35316 m
.35583 .35571 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3248 .31989 m
.33467 .32189 L
s
.34127 .34863 m
.34266 .3512 L
s
.34261 .35351 m
.34266 .3512 L
s
.33977 .35068 m
.34127 .34863 L
s
.32965 .35347 m
.33042 .32105 L
s
.34111 .35558 m
.34261 .35351 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32823 .3532 m
.32901 .32076 L
s
.33977 .35068 m
.34116 .35326 L
s
.33678 .3548 m
.34111 .35558 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33397 .35195 m
.33678 .3548 L
s
.32998 .33954 m
.33123 .34677 L
s
.33123 .34677 m
.33397 .35195 L
s
.32401 .35236 m
.32965 .35347 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31373 .3198 m
.31634 .32505 L
s
.31634 .32505 m
.31759 .32999 L
s
.31759 .32999 m
.3188 .33726 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30973 .31654 m
.31373 .3198 L
s
.31237 .31949 m
.31497 .32475 L
s
.31497 .32475 m
.31622 .32969 L
s
.3185 .3489 m
.3188 .33726 L
s
.31622 .32969 m
.31742 .33696 L
s
.30973 .31654 m
.31237 .31949 L
s
.31712 .34861 m
.31742 .33696 L
s
.29651 .31326 m
.30973 .31654 L
s
.31695 .35561 m
.3185 .3489 L
s
.31557 .35532 m
.31712 .34861 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31545 .35999 m
.31695 .35561 L
s
.31408 .3597 m
.31557 .35532 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3004 .36375 m
.30174 .3146 L
s
.31259 .3641 m
.31545 .35999 L
s
.74473 .31433 m
.75762 .31091 L
s
.29908 .36344 m
.30042 .31427 L
s
.31122 .36381 m
.31408 .3597 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30844 .36556 m
.31259 .3641 L
s
.30844 .36556 m
.31122 .36381 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29513 .3625 m
.30844 .36556 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74995 .31298 m
.75133 .36224 L
s
.74865 .31332 m
.75002 .36256 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75762 .31091 m
.7602 .31254 L
s
.75762 .31091 m
.76145 .31218 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74608 .3635 m
.75905 .3603 L
s
.7602 .31254 m
.76284 .31651 L
s
.76145 .31218 m
.76408 .31615 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76284 .31651 m
.76422 .32085 L
s
.76408 .31615 m
.76545 .32049 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76422 .32085 m
.76566 .32755 L
s
.76545 .32049 m
.76689 .3272 L
s
.76566 .32755 m
.76602 .33935 L
s
.77118 .3069 m
.77947 .30423 L
s
.76689 .3272 m
.76725 .339 L
s
.75905 .3603 m
.76151 .35727 L
s
.75905 .3603 m
.76277 .35694 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76151 .35727 m
.76388 .35186 L
s
.76499 .34679 m
.76602 .33935 L
s
.76388 .35186 m
.76499 .34679 L
s
.76277 .35694 m
.76513 .35152 L
s
.76623 .34644 m
.76725 .339 L
s
.76513 .35152 m
.76623 .34644 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77595 .30539 m
.77699 .33849 L
s
.77477 .30577 m
.7758 .33886 L
s
.7722 .33994 m
.77699 .33849 L
s
.77654 .32427 m
.77795 .33101 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77795 .33101 m
.78044 .33501 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78044 .33501 m
.78284 .33664 L
s
.25602 .30557 m
.25721 .3036 L
s
.25618 .30082 m
.25721 .3036 L
s
.25499 .30279 m
.25618 .30082 L
s
.78284 .33664 m
.78628 .3355 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25499 .30279 m
.25602 .30557 L
s
.78499 .33112 m
.7862 .33312 L
s
.78499 .33112 m
.78605 .32836 L
s
.78605 .32836 m
.78726 .33035 L
s
.78726 .33035 m
.78734 .33274 L
s
.78628 .3355 m
.78734 .33274 L
s
.25563 .31744 m
.25581 .34647 L
s
.25357 .34571 m
.25563 .31744 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79431 .30614 m
.79523 .30097 L
s
.79431 .30614 m
.79447 .3109 L
s
.79523 .30097 m
.79835 .29734 L
s
.25469 .34609 m
.25516 .33174 L
s
.79447 .3109 m
.79571 .31526 L
s
.79539 .30573 m
.7963 .30056 L
s
.79539 .30573 m
.79555 .31049 L
s
.7963 .30056 m
.79835 .29734 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79555 .31049 m
.79678 .31485 L
s
.25453 .35088 m
.25581 .34647 L
s
.24636 .29948 m
.24733 .30228 L
s
.24709 .30943 m
.24733 .30228 L
s
.24434 .29625 m
.24636 .29948 L
s
.24603 .30902 m
.24717 .30705 L
s
.25357 .34571 m
.25453 .35088 L
s
.24595 .3114 m
.24709 .30943 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79571 .31526 m
.799 .31642 L
s
.79678 .31485 m
.799 .31642 L
s
.79835 .29734 m
.80149 .29606 L
s
.79603 .32481 m
.79611 .32721 L
s
.79603 .32481 m
.79711 .32441 L
s
.24024 .29453 m
.24434 .29625 L
s
.79611 .32721 m
.79727 .3292 L
s
.80149 .29606 m
.80363 .29759 L
s
.24385 .31057 m
.24603 .30902 L
s
.79711 .32441 m
.79719 .32681 L
s
.24377 .31296 m
.24595 .3114 L
s
.79727 .3292 m
.79949 .33079 L
s
.24546 .32576 m
.24668 .32138 L
s
.24636 .33097 m
.24668 .32138 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80363 .29759 m
.80583 .30151 L
s
.23856 .31326 m
.24385 .31057 L
s
.23847 .31566 m
.24377 .31296 L
s
.24546 .32576 m
.24636 .33097 L
s
.24432 .32776 m
.24546 .32576 L
s
.23814 .29605 m
.24024 .29453 L
s
.24215 .32934 m
.24432 .32776 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80171 .34808 m
.80172 .35015 L
s
.5 Mabswid
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79949 .33079 m
.80368 .32917 L
s
.799 .31642 m
.80532 .31632 L
s
.80583 .30151 m
.80667 .2963 L
s
.80583 .30151 m
.80659 .32311 L
s
.80667 .2963 m
.80858 .29303 L
s
.23706 .298 m
.23814 .29605 L
s
.80684 .30108 m
.80767 .29586 L
s
.80684 .30108 m
.80743 .31788 L
s
.80767 .29586 m
.80858 .29303 L
s
.80858 .29303 m
.80957 .29259 L
s
.23805 .32769 m
.24215 .32934 L
s
.80532 .31632 m
.80642 .3183 L
s
.23624 .29278 m
.23706 .298 L
s
.2359 .30236 m
.23706 .298 L
s
.2359 .30236 m
.23624 .29278 L
s
.80368 .32917 m
.80566 .32593 L
s
.23647 .31481 m
.23856 .31326 L
s
.23638 .31721 m
.23847 .31566 L
s
.80566 .32593 m
.80659 .32311 L
s
.80659 .32311 m
.80743 .31788 L
s
.23539 .31679 m
.23647 .31481 L
s
.23613 .32444 m
.23805 .32769 L
s
.2353 .31919 m
.23638 .31721 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23522 .32161 m
.23539 .31679 L
s
.23522 .32161 m
.23613 .32444 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22757 .29114 m
.22925 .29686 L
s
0 0 0 r
.22231 .27875 m
.22247 .28166 L
s
.255 .412 .882 r
.81272 .3254 m
.81936 .32238 L
s
.81813 .28854 m
.823 .32061 L
s
.81561 .32412 m
.81813 .28854 L
s
.22492 .28736 m
.22757 .29114 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2214 .27828 m
.22141 .27839 L
s
.5 Mabswid
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81656 .32368 m
.81839 .29577 L
s
.22855 .31617 m
.22864 .31375 L
s
.22779 .31089 m
.22864 .31375 L
s
.22314 .28643 m
.22492 .28736 L
s
.22651 .32014 m
.22855 .31617 L
s
.22677 .31287 m
.22779 .31089 L
s
.22677 .31287 m
.22761 .31573 L
s
.22129 .28791 m
.22314 .28643 L
s
.22043 .28744 m
.22314 .28643 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22458 .32169 m
.22651 .32014 L
s
.21939 .29182 m
.22129 .28791 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.823 .32061 m
.82524 .28482 L
s
.22188 .32036 m
.22458 .32169 L
s
.21853 .29135 m
.22043 .28744 L
s
.82389 .32017 m
.82551 .29209 L
s
.21826 .29863 m
.21939 .29182 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82893 .30275 m
.82905 .30596 L
s
.8281 .3046 m
.82818 .30652 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21742 .29817 m
.21853 .29135 L
s
.22021 .31703 m
.22188 .32036 L
s
.21934 .31658 m
.22188 .32036 L
s
.21808 .30349 m
.21826 .29863 L
s
.21866 .31125 m
.22021 .31703 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21808 .30349 m
.21866 .31125 L
s
.21723 .30303 m
.21742 .29817 L
s
.2178 .3108 m
.21934 .31658 L
s
.21723 .30303 m
.2178 .3108 L
s
.2092 .27828 m
.21467 .28169 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82737 .31837 m
.83237 .31563 L
s
.82524 .28482 m
.8299 .31701 L
s
.21096 .31444 m
.21228 .28024 L
s
.21018 .31397 m
.2115 .27975 L
s
.83546 .29125 m
.83603 .28588 L
s
.83497 .29907 m
.83546 .29125 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83603 .28588 m
.83734 .28002 L
s
.83497 .29907 m
.83545 .31132 L
s
.83622 .29077 m
.83679 .2854 L
s
.83575 .29859 m
.83622 .29077 L
s
.83679 .2854 m
.83808 .27953 L
s
.83734 .28002 m
.83944 .27609 L
s
.83575 .29859 m
.83622 .31085 L
s
.20787 .31257 m
.21096 .31444 L
s
.83808 .27953 m
.83944 .27609 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83545 .31132 m
.83651 .31822 L
s
.20142 .27278 m
.20626 .2763 L
s
.83622 .31085 m
.83727 .31776 L
s
.83944 .27609 m
.84085 .27509 L
s
0 0 0 r
.19906 .26438 m
.20005 .26692 L
s
.255 .412 .882 r
.20952 .33119 m
.2104 .32918 L
s
.20971 .32627 m
.2104 .32918 L
s
.20883 .32827 m
.20971 .32627 L
s
.83651 .31822 m
.83746 .32268 L
s
0 0 0 r
.19906 .26438 m
.20001 .26782 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20883 .32827 m
.20952 .33119 L
s
.84085 .27509 m
.84301 .27603 L
s
.83727 .31776 m
.83822 .32222 L
s
.20307 .30183 m
.20414 .2748 L
s
.83746 .32268 m
.83916 .32669 L
s
.20237 .30134 m
.20345 .2743 L
s
.83822 .32222 m
.83991 .32622 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84301 .27603 m
.84454 .27993 L
s
.83916 .32669 m
.84146 .32777 L
s
.83991 .32622 m
.84146 .32777 L
s
.84425 .27256 m
.84503 .29225 L
s
.20218 .30628 m
.20307 .30183 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84301 .29374 m
.8476 .29026 L
s
.5 Mabswid
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8449 .27205 m
.84569 .29176 L
s
.20149 .3058 m
.20237 .30134 L
s
.84146 .32777 m
.84289 .32683 L
s
.20005 .3073 m
.20218 .30628 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20005 .3073 m
.20149 .3058 L
s
.19467 .2671 m
.19885 .27073 L
s
.84289 .32683 m
.84487 .32293 L
s
.19873 .30632 m
.20005 .3073 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84487 .32293 m
.84602 .31701 L
s
.84864 .26896 m
.85261 .2653 L
s
.84638 .30908 m
.84698 .32399 L
s
.84602 .31701 m
.84638 .30908 L
s
.19693 .30236 m
.19873 .30632 L
s
.84602 .31701 m
.84698 .32399 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1943 .32082 m
.19641 .26866 L
s
.1949 .32131 m
.197 .26918 L
s
.1959 .2964 m
.19693 .30236 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85096 .26688 m
.85238 .30165 L
s
.85039 .2674 m
.85181 .30215 L
s
.85004 .30365 m
.85238 .30165 L
s
.85177 .28671 m
.85263 .29367 L
s
.19254 .31936 m
.1949 .32131 L
s
.85263 .29367 m
.85393 .29764 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18984 .26483 m
.19062 .27086 L
s
.19062 .27086 m
.19082 .27886 L
s
.19062 .28384 m
.19082 .27886 L
s
.85393 .29764 m
.85509 .29913 L
s
.18936 .26429 m
.19012 .27034 L
s
.19012 .27034 m
.19031 .27834 L
s
.1898 .29082 m
.19062 .28384 L
s
.18853 .26073 m
.18984 .26483 L
s
.19011 .28333 m
.19031 .27834 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1893 .29031 m
.19011 .28333 L
s
.18853 .26073 m
.18936 .26429 L
s
.85509 .29913 m
.85661 .2976 L
s
.1886 .2948 m
.1898 .29082 L
s
.18763 .25965 m
.18853 .26073 L
s
.18517 .23778 m
.18793 .24167 L
s
.85591 .2931 m
.85651 .2951 L
s
.85591 .2931 m
.8563 .29009 L
s
.18812 .29429 m
.1893 .29031 L
s
.8563 .29009 m
.85689 .29208 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18667 .26107 m
.18763 .25965 L
s
.85661 .2976 m
.857 .29458 L
s
.85689 .29208 m
.857 .29458 L
s
.18707 .29577 m
.1886 .2948 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18173 .28868 m
.18217 .27824 L
s
.18334 .25054 m
.18339 .24934 L
s
.18217 .28921 m
.1826 .27909 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18448 .29267 m
.18669 .24001 L
s
.18707 .29577 m
.18812 .29429 L
s
.18409 .29214 m
.18629 .23945 L
s
.18564 .265 m
.18667 .26107 L
s
0 0 0 r
.86305 .25925 m
.86308 .27052 L
s
.86305 .25925 m
.86357 .251 L
s
.255 .412 .882 r
.8591 .26584 m
.85931 .2603 L
s
.8591 .26584 m
.85931 .27086 L
s
.85931 .2603 m
.86038 .25616 L
s
.18617 .29474 m
.18707 .29577 L
s
0 0 0 r
.18232 .29692 m
.18258 .29848 L
s
.18187 .2964 m
.18255 .29925 L
s
.255 .412 .882 r
.85931 .27086 m
.85993 .27534 L
s
.85951 .26531 m
.85971 .25976 L
s
.85951 .26531 m
.85972 .27032 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86374 .27549 m
.86381 .27715 L
s
.255 .412 .882 r
.85971 .25976 m
.86038 .25616 L
s
0 0 0 r
.86343 .27825 m
.86427 .28793 L
s
.18217 .28921 m
.18232 .29692 L
s
.255 .412 .882 r
.85972 .27032 m
.86034 .27481 L
s
0 0 0 r
.86381 .27715 m
.86468 .2874 L
s
.255 .412 .882 r
.18541 .29119 m
.18617 .29474 L
s
0 0 0 r
.18187 .2964 m
.18173 .28868 L
s
.255 .412 .882 r
.85993 .27534 m
.86122 .27626 L
s
.86038 .25616 m
.86146 .25452 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86034 .27481 m
.86122 .27626 L
s
.1848 .2851 m
.18541 .29119 L
s
.86035 .2854 m
.86046 .28792 L
s
.86035 .2854 m
.86076 .28488 L
s
.86046 .28792 m
.86097 .28992 L
s
.86076 .28488 m
.86086 .2874 L
s
.86146 .25452 m
.86225 .25593 L
s
.18295 .29057 m
.18448 .29267 L
s
.86097 .28992 m
.86185 .2914 L
s
.18339 .25365 m
.18373 .2542 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86122 .27626 m
.86343 .27557 L
s
.18263 .25506 m
.18339 .25365 L
s
.18295 .25561 m
.18339 .25365 L
s
0 0 0 r
.86654 .29585 m
.86671 .29611 L
s
.255 .412 .882 r
.86225 .25593 m
.8631 .25987 L
s
0 0 0 r
.86656 .2957 m
.86671 .29611 L
s
.255 .412 .882 r
.86185 .2914 m
.8633 .2893 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18242 .2601 m
.18295 .25561 L
s
.18211 .25955 m
.18263 .25506 L
s
.18167 .27779 m
.18242 .2601 L
s
.8631 .25987 m
.86319 .25428 L
s
.8631 .25987 m
.86406 .28264 L
s
.86319 .25428 m
.86367 .25064 L
s
.18174 .2534 m
.18211 .25955 L
s
.18115 .28233 m
.18211 .25955 L
s
.86341 .25932 m
.86349 .25372 L
s
.86341 .25932 m
.86416 .27703 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86349 .25372 m
.86367 .25064 L
s
.86343 .27557 m
.86385 .27757 L
s
.8633 .2893 m
.86385 .2857 L
s
.18129 .24977 m
.18174 .2534 L
s
.86367 .25064 m
.86394 .25009 L
s
.86371 .23131 m
.86521 .2273 L
s
.18115 .28233 m
.18167 .27779 L
s
0 0 0 r
.17566 .23516 m
.17669 .23786 L
s
.255 .412 .882 r
.86385 .2857 m
.86406 .28264 L
s
.18055 .24809 m
.18129 .24977 L
s
.18117 .27419 m
.18136 .27726 L
s
.86406 .28264 m
.86416 .27703 L
s
.17968 .26839 m
.18117 .27419 L
s
.18074 .28434 m
.18115 .28233 L
s
0 0 0 r
.8691 .2368 m
.86998 .23434 L
s
.255 .412 .882 r
.18006 .28582 m
.18074 .28434 L
s
0 0 0 r
.17429 .28833 m
.17648 .23747 L
s
.255 .412 .882 r
.17999 .24951 m
.18055 .24809 L
s
.17978 .24895 m
.18055 .24809 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17903 .28368 m
.18006 .28582 L
s
.17956 .25402 m
.17999 .24951 L
s
.17934 .26475 m
.17968 .26839 L
s
.17913 .2642 m
.17968 .26839 L
s
.17936 .25347 m
.17978 .24895 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86571 .25434 m
.86589 .24814 L
s
.17935 .25911 m
.17956 .25402 L
s
.86597 .28452 m
.8669 .28237 L
s
.86589 .24814 m
.86614 .24448 L
s
.17934 .26475 m
.17935 .25911 L
s
.17914 .25855 m
.17936 .25347 L
s
0 0 0 r
.17406 .28779 m
.1745 .28877 L
s
.255 .412 .882 r
.17869 .28005 m
.17903 .28368 L
s
.17913 .2642 m
.17914 .25855 L
s
.86614 .24448 m
.86646 .24335 L
s
.17869 .2744 m
.1789 .27494 L
s
.1788 .27749 m
.1789 .27494 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86463 .22903 m
.8669 .28237 L
s
.86441 .2296 m
.86668 .28291 L
s
.86658 .27471 m
.8672 .27874 L
s
.17858 .27695 m
.17869 .28005 L
s
0 0 0 r
.17381 .28305 m
.17454 .27683 L
s
.255 .412 .882 r
.17858 .27695 m
.17869 .2744 L
s
0 0 0 r
.17501 .23285 m
.17427 .22877 L
s
.255 .412 .882 r
.86646 .24335 m
.86685 .24476 L
s
.86646 .24335 m
.86697 .2442 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17406 .28779 m
.17626 .23689 L
s
.87121 .22793 m
.87057 .23202 L
s
.255 .412 .882 r
.8672 .27874 m
.86767 .28022 L
s
0 0 0 r
.17381 .28305 m
.1731 .28508 L
s
.255 .412 .882 r
.86767 .28022 m
.86799 .27914 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86697 .2442 m
.86741 .24818 L
s
.86685 .24476 m
.8673 .24874 L
s
0 0 0 r
.86942 .23607 m
.87273 .31274 L
s
.86922 .23665 m
.87253 .31326 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8673 .24874 m
.86774 .25586 L
s
0 0 0 r
.87253 .31326 m
.8733 .31116 L
s
.255 .412 .882 r
.86799 .27914 m
.86816 .27548 L
s
.86799 .27914 m
.86829 .27493 L
s
0 0 0 r
.1731 .28508 m
.17279 .28399 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17278 .27076 m
.17452 .23052 L
s
.17288 .27131 m
.17463 .2311 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .24818 m
.86783 .2553 L
s
.86816 .27548 m
.86818 .26925 L
s
.86774 .25586 m
.86796 .26099 L
s
.17725 .26948 m
.17726 .2726 L
s
.17715 .27517 m
.17726 .2726 L
s
0 0 0 r
.17279 .28399 m
.17268 .27922 L
s
.17279 .28399 m
.17257 .27867 L
s
.255 .412 .882 r
.17692 .2772 m
.17715 .27517 L
s
.17703 .2715 m
.17725 .26948 L
s
.86796 .26099 m
.86818 .26925 L
s
.86829 .2687 m
.86829 .27493 L
s
.86783 .2553 m
.86805 .26043 L
s
.17786 .23446 m
.17803 .23847 L
s
.17703 .27462 m
.17703 .2715 L
s
0 0 0 r
.17268 .27922 m
.17288 .27131 L
s
.255 .412 .882 r
.17663 .27556 m
.17692 .2772 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86805 .26043 m
.86829 .2687 L
s
0 0 0 r
.17278 .27076 m
.17227 .27702 L
s
.17257 .27867 m
.17278 .27076 L
s
.17408 .22642 m
.17415 .2223 L
s
.255 .412 .882 r
.17634 .27283 m
.17789 .23675 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .23249 m
.86751 .23651 L
s
.17659 .27189 m
.17663 .27556 L
s
.17632 .27228 m
.17787 .23618 L
s
0 0 0 r
.17227 .27702 m
.17191 .27906 L
s
.17228 .26518 m
.17405 .22466 L
s
.255 .412 .882 r
.17671 .26562 m
.17659 .27189 L
s
0 0 0 r
.17229 .26462 m
.17406 .22407 L
s
.255 .412 .882 r
.17671 .26562 m
.17701 .25733 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.871 .22969 m
.87435 .30694 L
s
.87091 .23027 m
.87426 .30747 L
s
.255 .412 .882 r
.86753 .23479 m
.86987 .28914 L
s
0 0 0 r
.87182 .23542 m
.8723 .24704 L
s
.87146 .2269 m
.87182 .23542 L
s
.255 .412 .882 r
.86752 .23421 m
.86985 .28861 L
s
0 0 0 r
.87115 .22146 m
.87146 .2269 L
s
.8723 .24704 m
.87262 .25441 L
s
.87457 .30534 m
.87426 .30747 L
s
.8718 .23484 m
.8723 .24647 L
s
.87142 .22632 m
.8718 .23484 L
s
.17191 .27906 m
.17184 .27796 L
s
.255 .412 .882 r
.17631 .27063 m
.17634 .27283 L
s
0 0 0 r
.87115 .22146 m
.87142 .22632 L
s
.8723 .24647 m
.87262 .25384 L
s
.87262 .25441 m
.8731 .26494 L
s
.87262 .25384 m
.87309 .26438 L
s
.871 .22028 m
.87115 .22146 L
s
.17184 .27796 m
.17196 .27314 L
s
.17184 .27796 m
.17196 .27259 L
s
.17196 .27314 m
.17228 .26518 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86874 .26261 m
.8689 .26669 L
s
0 0 0 r
.8731 .26494 m
.87339 .27124 L
s
.255 .412 .882 r
.86984 .29075 m
.86985 .28861 L
s
0 0 0 r
.87097 .22279 m
.871 .22028 L
s
.87085 .2222 m
.871 .22028 L
s
.17196 .27259 m
.17229 .26462 L
s
.255 .412 .882 r
.17725 .25172 m
.17814 .231 L
s
0 0 0 r
.87309 .26438 m
.87335 .27068 L
s
.255 .412 .882 r
.17765 .24946 m
.17706 .2534 L
s
.17733 .25115 m
.17822 .23043 L
s
.86621 .22613 m
.86713 .23018 L
s
.86885 .26764 m
.8689 .26669 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17831 .23186 m
.17789 .23819 L
s
0 0 0 r
.87105 .22901 m
.87097 .22279 L
s
.87339 .27124 m
.87341 .27329 L
s
.17405 .23043 m
.1746 .22186 L
s
.17347 .24211 m
.17405 .23043 L
s
.87092 .22842 m
.87085 .2222 L
s
.255 .412 .882 r
.17831 .23186 m
.1788 .22754 L
s
0 0 0 r
.87335 .27068 m
.87341 .27329 L
s
.1746 .22186 m
.17519 .21639 L
s
.17315 .24953 m
.17347 .24211 L
s
.17416 .22984 m
.17473 .22127 L
s
.17357 .24154 m
.17416 .22984 L
s
.255 .412 .882 r
.8668 .22845 m
.86802 .25704 L
s
0 0 0 r
.17473 .22127 m
.17519 .21639 L
s
.17325 .24896 m
.17357 .24154 L
s
.17276 .26012 m
.17315 .24953 L
s
.255 .412 .882 r
.86667 .22787 m
.86789 .25648 L
s
.86869 .26653 m
.86885 .26764 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8714 .23956 m
.87105 .22901 L
s
.17287 .25955 m
.17325 .24896 L
s
.87341 .27329 m
.87326 .27218 L
s
.17519 .21639 m
.17553 .2152 L
s
.255 .412 .882 r
.17579 .28561 m
.17647 .26993 L
s
.17621 .27721 m
.17647 .26993 L
s
0 0 0 r
.87125 .23898 m
.87092 .22842 L
s
.255 .412 .882 r
.86837 .26282 m
.86869 .26653 L
s
.86825 .26226 m
.86869 .26653 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17267 .26646 m
.17276 .26012 L
s
.87326 .27218 m
.8729 .26734 L
s
.87326 .27218 m
.87279 .26678 L
s
.17553 .2152 m
.17596 .21714 L
s
.87172 .247 m
.8714 .23956 L
s
.255 .412 .882 r
.17621 .27721 m
.17619 .28136 L
s
.17579 .28561 m
.17621 .27721 L
s
.86802 .25704 m
.86837 .26282 L
s
0 0 0 r
.1728 .2659 m
.17287 .25955 L
s
.87158 .24643 m
.87125 .23898 L
s
.87234 .25875 m
.87172 .247 L
s
.8729 .26734 m
.87234 .25875 L
s
.255 .412 .882 r
.86789 .25648 m
.86825 .26226 L
s
0 0 0 r
.87158 .24643 m
.87221 .25818 L
s
.87279 .26678 m
.87221 .25818 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17293 .26853 m
.17267 .26646 L
s
.17596 .21714 m
.17609 .22341 L
s
.17293 .26853 m
.1728 .2659 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17619 .28136 m
.17645 .28236 L
s
0 0 0 r
.17325 .24896 m
.17528 .24209 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17345 .26685 m
.17293 .26853 L
s
.255 .412 .882 r
.17645 .28236 m
.17676 .28128 L
s
0 0 0 r
.86837 .21452 m
.8692 .22316 L
s
.8692 .22316 m
.86992 .23494 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86895 .22257 m
.86968 .23436 L
s
.86992 .23494 m
.87024 .24242 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8681 .21393 m
.86895 .22257 L
s
.86737 .20902 m
.86837 .21452 L
s
.255 .412 .882 r
.17676 .28128 m
.17699 .2794 L
s
.17676 .28128 m
.17706 .27929 L
s
0 0 0 r
.17456 .25391 m
.17505 .24266 L
s
.86737 .20902 m
.8681 .21393 L
s
.86271 .17688 m
.8653 .18115 L
s
.86968 .23436 m
.87001 .24184 L
s
.87024 .24242 m
.87049 .2531 L
s
.17402 .26198 m
.17345 .26685 L
s
.17496 .24959 m
.17528 .24209 L
s
.87001 .24184 m
.87025 .25253 L
s
.86675 .20783 m
.86737 .20902 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17456 .25391 m
.17402 .26198 L
s
.1744 .25766 m
.17402 .26198 L
s
.1744 .25766 m
.17496 .24959 L
s
.87031 .2595 m
.87049 .2531 L
s
.86625 .21039 m
.86675 .20783 L
s
.87004 .25894 m
.87025 .25253 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86389 .17871 m
.86727 .2577 L
s
.86426 .17932 m
.86764 .25825 L
s
.17834 .21872 m
.17934 .21005 L
s
.17753 .23056 m
.17834 .21872 L
s
.86586 .21671 m
.86625 .21039 L
s
.86963 .2616 m
.87031 .2595 L
s
.17934 .21005 m
.1806 .20453 L
s
.17721 .23808 m
.17753 .23056 L
s
.17867 .21813 m
.17969 .20946 L
s
.17785 .22998 m
.17867 .21813 L
s
.86963 .2616 m
.87004 .25894 L
s
.17969 .20946 m
.1806 .20453 L
s
.17753 .2375 m
.17785 .22998 L
s
.17704 .24882 m
.17721 .23808 L
s
.1806 .20453 m
.18139 .20334 L
s
.17738 .24825 m
.17753 .2375 L
s
.86902 .26048 m
.86963 .2616 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17704 .24882 m
.1774 .25526 L
s
.18139 .20334 m
.18206 .20592 L
s
.17738 .24825 m
.17775 .2547 L
s
.86819 .25558 m
.86902 .26048 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86017 .19837 m
.86298 .20191 L
s
.18206 .20592 m
.18262 .21229 L
s
.86716 .24688 m
.86819 .25558 L
s
.1774 .25526 m
.17833 .25738 L
s
.1831 .20098 m
.185 .19862 L
s
.17971 .28084 m
.1831 .20098 L
s
.17775 .2547 m
.17833 .25738 L
s
.86199 .27686 m
.86209 .20073 L
s
.18017 .2803 m
.18356 .20039 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86609 .25603 m
.86764 .25825 L
s
.255 .412 .882 r
.18638 .22061 m
.18715 .21134 L
s
0 0 0 r
.8615 .2653 m
.86163 .20014 L
s
.17833 .25738 m
.17913 .25626 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17913 .25626 m
.18013 .25134 L
s
.18013 .25134 m
.18133 .24261 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18736 .23155 m
.18739 .23448 L
s
.18691 .23192 m
.18692 .23396 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1784 .28245 m
.18017 .2803 L
s
.18716 .20706 m
.18861 .1983 L
s
.18613 .21904 m
.18716 .20706 L
s
.18861 .1983 m
.19055 .19275 L
s
.18581 .22666 m
.18613 .21904 L
s
.18772 .20648 m
.18919 .19772 L
s
.18668 .21847 m
.18772 .20648 L
s
.18919 .19772 m
.19055 .19275 L
s
.18636 .2261 m
.18668 .21847 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85674 .21652 m
.86163 .22166 L
s
.85331 .19134 m
.85695 .19484 L
s
.18581 .22666 m
.18588 .23756 L
s
.19055 .19275 m
.1918 .19159 L
s
.18636 .2261 m
.18644 .237 L
s
.18636 .2261 m
.19387 .21934 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1918 .19159 m
.19361 .19366 L
s
.18588 .23756 m
.18669 .24412 L
s
.18644 .237 m
.18728 .24357 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85457 .19251 m
.86199 .27686 L
s
.18669 .24412 m
.18833 .24631 L
s
.19361 .19366 m
.19466 .20016 L
s
.18728 .24357 m
.18833 .24631 L
s
.18833 .24631 m
.19022 .24467 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1927 .23145 m
.19318 .2199 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19355 .22704 m
.19387 .21934 L
s
.19022 .24467 m
.19171 .23972 L
s
.19171 .23972 m
.1927 .23145 L
s
.19255 .23531 m
.19355 .22704 L
s
.19171 .23972 m
.19255 .23531 L
s
.20027 .18466 m
.20074 .19177 L
s
.19965 .20003 m
.20027 .18466 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19965 .20003 m
.20074 .19177 L
s
.20074 .19177 m
.20169 .18736 L
s
.20169 .18736 m
.20346 .18238 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20346 .18238 m
.20683 .18012 L
s
.19871 .22319 m
.19965 .21877 L
s
.1984 .23094 m
.19871 .22319 L
s
.19965 .21877 m
.20141 .2138 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19855 .22706 m
.19949 .22264 L
s
.19949 .22264 m
.20125 .21767 L
s
.20683 .18012 m
.20844 .18285 L
s
.1984 .23094 m
.19902 .23428 L
s
.255 .412 .882 r
.20545 .22624 m
.20637 .22299 L
s
.20534 .22896 m
.20545 .22624 L
s
0 0 0 r
.19902 .23428 m
.20047 .23709 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20125 .21767 m
.20576 .20718 L
s
.20141 .2138 m
.20592 .2033 L
s
.20844 .18285 m
.20918 .18616 L
s
.20592 .2033 m
.20783 .19833 L
s
.20873 .19778 m
.20918 .18616 L
s
.20047 .23709 m
.20382 .23496 L
s
.20576 .20718 m
.20768 .20221 L
s
.20783 .19833 m
.20888 .1939 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20768 .20221 m
.20873 .19778 L
s
.20382 .23496 m
.20571 .22999 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20676 .22556 m
.20796 .21722 L
s
.20735 .23284 m
.20796 .21722 L
s
.20571 .22999 m
.20676 .22556 L
s
.20676 .22556 m
.20735 .23284 L
s
.21593 .17842 m
.21706 .17399 L
s
.21593 .17842 m
.21676 .18176 L
s
.21706 .17399 m
.21791 .17733 L
s
.21676 .18176 m
.21791 .17733 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21521 .24788 m
.21602 .20124 L
s
.21321 .24889 m
.21602 .20124 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21421 .24838 m
.21511 .22474 L
s
.21321 .24889 m
.2139 .25629 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2139 .25629 m
.21521 .24788 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23513 .20323 m
.2352 .2013 L
s
.5 Mabswid
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76849 .22112 m
.76869 .22118 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76764 .22011 m
.76849 .22112 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67075 .12906 m
.67279 .13341 L
s
.66885 .13285 m
.67075 .12906 L
s
.6709 .1372 m
.67279 .13341 L
s
.66885 .13285 m
.6709 .1372 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36851 .1709 m
.3703 .16807 L
s
.37218 .17066 m
.3703 .16807 L
s
0 0 0 r
.64872 .1262 m
.65682 .12718 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37019 .1738 m
.37218 .17066 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66744 .16623 m
.66774 .16461 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64471 .12981 m
.64892 .13845 L
s
.64054 .12527 m
.64471 .12981 L
s
.63642 .12483 m
.64054 .12527 L
s
.63234 .12849 m
.63642 .12483 L
s
.63026 .12828 m
.63642 .12483 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62829 .13627 m
.63234 .12849 L
s
.6262 .13608 m
.63026 .12828 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67174 .18228 m
.67221 .20708 L
s
.59852 .12157 m
.61342 .12268 L
s
.62636 .1484 m
.62829 .13627 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62426 .14821 m
.6262 .13608 L
s
.43742 .12225 m
.47184 .12016 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67128 .15763 m
.67419 .20734 L
s
.5 Mabswid
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67022 .20682 m
.67128 .15763 L
s
.64547 .17912 m
.64944 .17131 L
s
.62636 .1484 m
.62646 .15663 L
s
.62426 .14821 m
.62436 .15645 L
s
.67236 .21538 m
.67419 .20734 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46967 .12026 m
.47168 .14486 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57479 .12022 m
.58993 .12102 L
s
.67022 .20682 m
.67236 .21538 L
s
.47168 .14486 m
.47184 .12016 L
s
.62646 .15663 m
.62872 .16921 L
s
.62436 .15645 m
.62663 .16902 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43083 .16338 m
.43086 .16068 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6414 .18283 m
.64547 .17912 L
s
.55078 .11938 m
.55737 .12366 L
s
.5464 .11928 m
.55078 .11938 L
s
.54202 .1233 m
.5464 .11928 L
s
.53982 .12327 m
.5464 .11928 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49585 .12345 m
.50025 .11925 L
s
.50025 .11925 m
.50464 .11917 L
s
.49365 .12351 m
.50025 .11925 L
s
.50464 .11917 m
.51122 .1232 L
s
.55737 .12366 m
.56178 .13203 L
s
.51563 .11905 m
.52442 .11903 L
s
.62872 .16921 m
.63302 .17787 L
s
.49143 .1318 m
.49365 .12351 L
s
.63725 .18242 m
.6414 .18283 L
s
.49362 .13174 m
.49585 .12345 L
s
.62663 .16902 m
.63093 .17768 L
s
.53764 .13147 m
.54202 .1233 L
s
.53544 .13144 m
.53982 .12327 L
s
.51122 .1232 m
.51561 .1314 L
s
.63302 .17787 m
.63725 .18242 L
s
.63093 .17768 m
.63725 .18242 L
s
.53546 .14383 m
.53764 .13147 L
s
.53325 .1438 m
.53544 .13144 L
s
.45834 .18281 m
.45861 .14963 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64872 .1262 m
.6501 .21278 L
s
.65076 .12644 m
.65216 .213 L
s
.255 .412 .882 r
.5255 .15778 m
.52742 .15737 L
s
0 0 0 r
.64391 .21214 m
.65216 .213 L
s
.255 .412 .882 r
.56249 .16714 m
.56344 .16589 L
s
0 0 0 r
.44551 .16696 m
.45848 .16619 L
s
.53546 .14383 m
.53547 .1521 L
s
.53325 .1438 m
.53326 .15208 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51557 .17698 m
.51563 .11905 L
s
.51779 .17697 m
.51783 .11904 L
s
.49125 .17736 m
.49143 .1318 L
s
.49346 .17731 m
.49362 .13174 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60493 .12202 m
.60553 .17978 L
s
.60706 .12218 m
.60767 .17993 L
s
.59908 .17935 m
.60767 .17993 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44295 .20875 m
.44381 .12178 L
s
.44511 .20862 m
.44595 .12163 L
s
.55971 .15675 m
.56193 .16096 L
s
.55753 .16083 m
.55971 .15675 L
s
.53547 .1521 m
.5377 .16457 L
s
.53326 .15208 m
.53549 .16455 L
s
.56193 .16096 m
.56195 .16511 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55753 .16083 m
.55975 .16504 L
s
.55759 .17329 m
.56195 .16511 L
s
.5377 .16457 m
.54214 .17295 L
s
.53549 .16455 m
.53993 .17292 L
s
.5532 .17734 m
.55759 .17329 L
s
.60575 .20061 m
.60794 .20493 L
s
.60364 .20465 m
.60575 .20061 L
s
.46908 .20737 m
.47144 .1822 L
s
.47128 .20728 m
.47144 .1822 L
s
.48464 .17755 m
.49346 .17731 L
s
.54214 .17295 m
.54657 .17719 L
s
.53993 .17292 m
.54657 .17719 L
s
.60583 .20897 m
.60794 .20493 L
s
.54657 .17719 m
.5532 .17734 L
s
.60364 .20465 m
.60583 .20897 L
s
.50893 .17704 m
.51779 .17697 L
s
.43648 .20918 m
.47128 .20728 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5813 .12054 m
.58194 .20762 L
s
.58346 .12065 m
.58413 .20773 L
s
.57537 .20733 m
.58413 .20773 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000`3o
YQ03000000D0ojH@1@00000:0?nV40<000007P3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ49000000`0[Jf]00@00000
0:f][@2][Jd0[Jf]0P0000030:f][@8000002`2][Jd2000000<0[Jf]00<000000:f][@2][Jd0202]
[Jd9000000X0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd6
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA0080ojHA2@0000070:f][@8000001`3oYQ40102][Jd0ojH@0?nV403o
YQ02000000D0ojH@0P0000000`3oYQ0000000000000:0?nV408000000`3oYQ00102][Jd0ojD@0000
0000000;0?nU40030000002][Jd0000000H0[Jf]200000040:f][AL0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][JeX0;3PiP40oooo
001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ405P3oYQ4<0:f][@8000002`3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ000P00
00070?nV40040000003oYQ000000000000T0ojH@00<000000?nV400000000`3oYQ001@2][Jd0ojD@
0?nU403oYA00000000X0ojD@00<000000?nU400000002@3oYA0200000080ojD@00<0[Jf]0?nS403o
Xa000P3oXa070:f][@<000003@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]
103oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002`3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ00
0P0000080?nV40<000002@3oYQ02000000@0ojH@00D0[Jf]0?nU403oYA00ojD@0000000:0?nU4003
0000003oYA00000000T0ojD@0P0000020?nU40030:f][@3oXa00oj<@00L0oj<@0P0000020?nS4004
0:f][@000000[Jf]0:f][@D0000000<0[Jf]0?nS403oXa000P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3oool007L0
/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002`3oYQ42000000L0
ojHA00@0[Jf]0?nV4000000000002@3oYQ03000000P0ojH@00<000000?nV40000000103oYQ000`2]
[Jd0ojD@0?nU40020?nU40030000003oYA00ojD@00L0ojD@00<000000?nU400000002@3oYA020000
0080ojD@00<0[Jf]0?nS403oXa001P3oXa02000000@0oj<@00<000000?nS403oXa000P0000040?nS
40D0[Jf]00<000000:f][@3lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01D0ojHA1`2][JdH0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000;0?nV4@80
00001`3oYQ40102][Jd0ojH@00000000000:0?nV40800000203oYQ02000000D0ojH@00<0[Jf]0?nU
403oYA000P3oYA000`000000ojD@0?nU40070?nU40030000003oYA00000000T0ojD@0P0000020?nU
40030:f][@3oXa00oj<@00D0oj<@0P0000060?nS40040000003oXa000000000000P0oj<@0P000000
0`3lX100[Jf]0:f][@040:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@
0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0@0?nV4@D0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
00D0ojHA0P00000;0?nV4@8000001`3oYQ40102][Jd0ojH@00000000000:0?nV40800000203oYQ02
000000D0ojH@00<0[Jf]0?nU403oYA000`3oYA000`000000ojD@0?nU40060?nU40030000003oYA00
000000T0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000060?nS40040000003oXa00
0000000000P0oj<@00<000000?bP400000001P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H2
0:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40
ojHA00/0ojHA1@2][Jd70?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42
000000`0ojHA00<000000?nV4@3oYQ401@3oYQ40102][Jd0ojH@00000000000:0?nV40800000203o
YQ02000000D0ojH@00<0[Jf]0?nU403oYA00303oYA000`000000ojD@000000090?nU408000000P3o
YA000`2][Jd0oj<@0?nS40040?nS40800000203oXa03000000P0oj<@0P00000<0?bP40D0[Jf]203l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3K
RPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@050?nV4@H0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000<0?nV4@030000003oYQ40ojHA00D0ojHA00@0[Jf]
0?nV4000000000002P3oYQ02000000P0ojH@0P0000050?nV40030:f][@3oYA00ojD@00`0ojD@00<0
00000?nU400000002@3oYA0200000080ojD@00<0[Jf]0?nS403oXa00103oXa02000000P0oj<@0`00
00080?nS40030:f][@000000o:0@0100o:0@1P2][Jd20?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H0
0`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140
0`2][Jd0ojHA0?nV4@050:f][A80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@05
0?nV4@800000303oYQ400`000000ojHA0?nV4@050?nV4@040:f][@3oYQ000000000000X0ojH@0P00
00070?nV408000001P3oYQ000`2][Jd0ojD@0?nU400<0?nU40030000003oYA00000000T0ojD@0P00
00020?nU40030:f][@3oXa00oj<@00@0oj<@0P0000090?nS40800000203oXa000`2][Jd0o:0@0?bP
400F0?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2]
[JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01<0oj@A102][JdG0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42
000000`0ojHA00<000000?nV4@3oYQ401@3oYQ40102][Jd0ojH@00000000000:0?nV408000001`3o
YQ02000000H0ojH@00<0[Jf]0?nU403oYA00303oYA000`000000ojD@000000090?nU408000000P3o
YA000`2][Jd0oj<@0?nS40040?nS408000002@3oXa02000000P0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0:f][@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I
0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000<0?nV4@030000003oYQ40ojHA00D0ojHA00@0[Jf]
0?nV4000000000002P3oYQ02000000L0ojH@0P0000060?nV40030:f][@3oYA00ojD@00`0ojD@00<0
00000?nU400000002@3oYA0200000080ojD@00<0[Jf]0?nS403oXa000`3oXa02000000X0oj<@0P00
00080?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][@d0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H2
0:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42
000000`0ojHA00<000000?nV4@3oYQ401@3oYQ40102][Jd0ojH@00000000000:0?nV408000001`3o
YQ02000000H0ojH@00<0[Jf]0?nU403oYA00303oYA000`000000ojD@000000090?nU408000000P3o
YA000`2][Jd0oj<@0?nS40030?nS408000002P3oXa02000000P0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000D
0?nV4@040:f][@3oYQ000000000000X0ojH@0P0000070?nV408000001P3oYQ000`2][Jd0ojD@0?nU
400<0?nU40030000003oYA00000000T0ojD@0P0000020?nU40030:f][@3oXa00oj<@00<0oj<@0P00
000:0?nS40800000203oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?102]
[Jd50?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3o
ool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY144
0:f][@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40
ojHA00H0ojHA0P00000D0?nV4@040:f][@3oYQ000000000000X0ojH@0P0000070?nV408000001P3o
YQ000`2][Jd0ojD@0?nU400<0?nU40030000003oYA00000000T0ojD@0P0000020?nU40030:f][@3o
Xa00oj<@00<0oj<@0P00000:0?nS408000002@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@0<
0?nV4@040:f][@3oYQ000000000000X0ojH@0P0000070?nV408000001P3oYQ000`2][Jd0ojD@0?nU
400<0?nU40030000003oYA00000000T0ojD@0P0000020?nU40030:f][@3oXa00oj<@00<0oj<@0P00
000:0?nS408000002@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2]
[JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`
h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00h0o:0@0`2][JdE0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@060?nV4@800000
1@3oYQ400`000000ojHA0?nV4@0<0?nV4@040:f][@3oYQ000000000000X0ojH@0P0000070?nV4080
00001P3oYQ000`2][Jd0ojD@0?nU400<0?nU40030000003oYA00000000X0ojD@0P0000000`3oYA00
[Jf]0?nS40040?nS408000002P3oXa02000000T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@05
0:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]
00d0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P0000050?nV
4@030000003oYQ40ojHA00`0ojHA00@0[Jf]0?nV4000000000002P3oYQ02000000L0ojH@0P000006
0?nV40030:f][@3oYA00ojD@00`0ojD@00<000000?nU400000002P3oYA02000000030?nU402][Jd0
oj<@00@0oj<@0P00000:0?nS408000002@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT
4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ401P3oYQ42000000D0ojHA00<000000?nV4@3oYQ401@3oYQ490:f][@8000002P2][Jd20000
00L0[Jf]0P00000;0:f][@030000002][Jd0[Jf]00L0ojD@00<000000?nU400000002P3oYA020000
00030?nU402][Jd0oj<@00@0oj<@0P00000:0?nS408000002@3oXa000`2][Jd0o:0@0?bP400G0?bP
40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640
/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0
o:0@0P2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00D0ojHA00<0[Jf]0000000000001@2][Jd00`000000
[Jf]0:f][@050:f][@L0ojHA00@0[Jf]0?nV4000000000002P3oYQ02000000L0ojH@0P0000060?nV
40040:f][@3oYA00ojD@0?nU408000000P3oYA070:f][@030000002][Jd0000000H0[Jf]103oYA02
000000030?nU402][Jd0oj<@00@0oj<@0P00000:0?nS408000002@3oXa000`000000o:0@0?bP400G
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool0
0600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2]
[Jd0ojHA0?nV4@0E0?nV4@`0[Jf]00<0ojHA0000000000001@3oYQ400`000000ojHA0?nV4@0<0?nV
4@040:f][@3oYQ000000000000X0ojH@0P0000080?nV408000001@3oYQ001`2][Jd0ojD@0?nU403o
YA0000000?nU40000000203oYA000`000000ojD@000000060?nU40@0[Jf]0P0000060:f][@030?nS
40000000000000X0oj<@0P0000090?nS40030000003lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>7
3P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]
103oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@0<0?nV4@040:f]
[@3oYQ000000000000X0ojH@0P0000080?nV408000001@3oYQ001`2][Jd0ojD@0?nU403oYA000000
0?nU40000000203oYA000`000000ojD@0000000:0?nU4080000000<0ojD@0:f][@3oXa000`3oXa00
0`2][Jd00000000000070:f][@<0oj<@0P0000090?nS40030000003lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>7
3P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd=
0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P0000050?nV4@030000003oYQ40ojHA00`0ojHA00@0[Jf]
0?nV4000000000002P3oYQ02000000P0ojH@0P0000050?nV40030:f][@3oYA00ojD@0080ojD@0P00
00090?nU408000002P3oYA02000000030?nU402][Jd0oj<@00D0oj<@0P0000060?nS40<0[Jf]0P00
00050:f][@@0oj<@00<000000?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00l0k9H>0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M
0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]403lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01H0ojHA1`2][JdG0?nV4@030:f][@3oYQ40ojHA00H0ojHA2000000>
0?nV4@040:f][@3oYQ000000000000X0ojH@0P0000080?nV408000001@3oYQ000`2][Jd0ojD@0?nU
40020?nU40030000003oYA00ojD@00P0ojD@0P00000:0?nU4080000000<0ojD@0:f][@3oXa001@3o
Xa02000000T0oj<@0P0000050?nS40@0[Jf]00@000000:f][@2][Jd0[Jf]5P3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;
0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4@3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1P2][Jd20?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000000D0ojHA00<000000?nV4@3oYQ40303o
YQ40102][Jd0ojH@00000000000:0?nV408000002@3oYQ02000000@0ojH@00<0[Jf]0?nU403oYA00
0P3oYA000`000000ojD@0?nU40080?nU408000002P3oYA02000000030?nU402][Jd0oj<@00D0oj<@
0P0000090?nS408000002@3oXa0010000000o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]2@3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@P0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@0<0?nV4@040:f]
[@3oYQ000000000000X0ojH@0P0000090?nV40800000103oYQ001@2][Jd0ojD@0?nU403oYA000000
00/0ojD@0P00000:0?nU4080000000<0ojD@0:f][@3oXa001@3oXa02000000T0oj<@0`0000080?nS
40030000003lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2]
[Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@0<0?nV4@040:f][@3oYQ000000
000000X0ojH@0P00000:0?nV408000000`3oYQ001@2][Jd0ojD@0?nU403oYA00000000/0ojD@0P00
000:0?nU4080000000<0ojD@0:f][@3oXa001P3oXa02000000L0oj<@00@000000?nS400000000000
203oXa02000000l0o:0@1P2][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh00`2][Jd0fhX=0=^:3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0
dhL>00<0[Jf]0>nH403_V1000P3_V1000`000000kiP@0:f][@060>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060:f][A80ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@0<0?nV4@04
0:f][@3oYQ000000000000X0ojH@0P00000;0?nV408000000P3oYQ00102][Jd0ojD@00000000000<
0?nU408000002P3oYA02000000030?nU402][Jd0oj<@00H0oj<@0P0000070?nS40040000003oXa00
0000000000P0oj<@0P00000E0?bP40D0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3K
RPd0fhX=00D0fhX=0P2][Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H7
0:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@
0>nH40020>nH408000001`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0180oj@A
102][JdH0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000000D0ojHA
00<000000?nV4@3oYQ402P3oYQ46000000H0ojH@1P00000=0?nV40@000003P3oYA02000000X0ojD@
0P0000000`3oYA00[Jf]0?nS40070?nS408000001@3oXa000`000000oj<@0?nS4002000000P0oj<@
0P00000H0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=00L0fhX=0P2][Jd20=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0
R5H7000000140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0
kiP@0>nH40020:f][@8000001`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00h0
oj@A102][Jd00`3oY140[Jf]0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3o
YQ401P3oYQ42000000D0ojHA00<000000?nV4@3oYQ40303oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@00d0ojD@0P0000060?nU40<0000000D0ojD@000000000000ojD@0:f][@080?nS
408000001@3oXa000`000000oj<@0?nS4002000000P0oj<@0P00000H0?bP40030:f][@3fW0l0mY`?
00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd30:f]
[@T0^GD;00H0[Jf]08QF1`28EPL0R5H70000002][Je30;3PiP40oooo001I0;3PiP030:f][@2GH0/0
Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`000000[Jf]0:f][@020>nH40030000003_V100
kiP@00H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@@0[Jf]1@3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42
000000D0ojHA00<000000?nV4@3oYQ40303oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@00d0ojD@0P0000090?nU40<0000000<0ojD@0:f][@3oXa00203oXa02000000<0oj<@00@00000
0?nS403oXa00oj<@0P0000080?nS40800000603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/0102][Jd0R5H708QF1`28EPL2000004<0/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@070=>73P80000000<0[Jf]0000003_V1000P3_V1000`000000kiP@0>nH40060>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV4@3oYQ40
603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P0000050?nV4@030000
003oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ401@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@00d0ojD@0P00000=0?nU40030:f][@3oXa00oj<@00T0oj<@0`0000040?nS40800000
203oXa02000001P0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/01P2][Jd0R5H708QF1`28EPL000000:f]
[D<0/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P8000000P2][Jd00`00
0000kiP@0>nH40090>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f]
[@`0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
00H0ojHA0P00000<0?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400=0?nU408000003@3oYA000`2][Jd0oj<@0?nS400@0?nS40800000203oXa020000
01P0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL3`2][Jd0k9H>0140k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd0102][Jd0^GD;0:f][@2][Jd60;Ue2`060:f][@28EPL0R5H708QF1`000000[Jf]
@`2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P0000000`3CQ`h0[Jf]
0000000;0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd@0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@060?nV4@800000
303oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
3@3oYA02000000d0ojD@00<0[Jf]0?nS403oXa00403oXa02000000P0oj<@0P00000H0?bP40030:f]
[@3fW0l0mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0
^GD;0:f][@050;Ue2`060:f][@28EPL0R5H708QF1`000000[Jf]@`2`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00H0[Jf]000000000000dhL>0:f][@00000;0>nH40030:f]
[@3lX100o:0@00l0o:0@0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@060?nV4@800000303oYQ400`000000ojHA0?nV4@050?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003@3oYA02000000d0ojD@00<0[Jf]0?nS403oXa00
403oXa02000000P0oj<@0P00000H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd0
0P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0^GD;
0;Ue2`020;Ue2`050:f][@28EPL0R5H708QF1`0000000P2][Je20;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h01@000000dhL>0:f][@3CQ`h000000080dhL>00<0[Jf]0000
003_V1002P3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]00<0o:0@0:f][@3oY140503oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ420000
00`0ojHA00<000000?nV4@3oYQ401@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00d0ojD@0P00000=0?nU40030:f][@3oXa00oj<@0100oj<@0P0000080?nS40800000603lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`000000[Jf]00<0R5H700<00000
0:f][@2][Jd0@P2`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80000000@0
[Jf]0=>73P3CQ`h000000P3CQ`h00`2][Jd000000>nH400:0>nH40030:f][@3lX100o:0@00X0o:0@
0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000<0?nV4@030000003oYQ40ojHA00D0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU408000003@3oYA000`2][Jd0oj<@
0?nS400@0?nS40800000203oXa02000001P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;
0P2][Jd2000000<0R5H700<000000:f][@2][Jd0@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00<000000`3CQ`h01@000000dhL>0=>73P2][Jd0000000/0kiP@00<0[Jf]0?bP403l
X1001`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000000/0ojHA0P00000^0:f][@P0
ojD@0P00000=0?nU40030:f][@3oXa00oj<@0100oj<@0P0000080?nS408000006@3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`000000[Jf]0000000208QF1`030000002][Jd0[Jf]0480
/>3V0@3oool005T0/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@000000dhL>000000<0dhL>00D00000
0=>73P3CQ`h0[Jf]0000000;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd90?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA00D0ojHA00<0[Jf]0000000000002`2][Jd2000000L0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU40050?nU40P0[Jf]0P0000060:f][@L0ojD@00<0[Jf]0?nS403oXa00403o
Xa02000000P0oj<@0`00000H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/
UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030000002]
[Jd0R5H70080R5H700<0000008QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;09MP2`00
0000[Jf]00000080dhL>00@000000=>73P3CQ`h000000P3CQ`h00`2][Jd000000>nH400:0>nH4003
0:f][@3lX100o:0@0080o:0@0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]00<0ojHA0000000000002`3oYQ42000000L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU408000001P3oYA0<0:f][@h0
oj<@0P0000080?nS40<00000603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0
k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/0^GD;00D0^GD;00D000000:f][@2]
[Jd0000008QF1`02000000030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`00
00000P2][Jd010000000dhL>0=>73P0000020=>73P040000003CQ`h0[Jf]000000@0kiP@00<00000
0>nH403_V1001@3_V1000`2][Jd0@FWQ0:f][@020:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@030:f][@3oYQ40
ojHA00H0ojHA0P00000;0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@00d0ojD@0P00000:0?nU40040000003oYA00ojD@0:f][@@0oj<@2P2][Jd40?nS40800000203o
Xa03000001P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]3@3K
RPd00`2][Jd0^GD;0;Ue2`050;Ue2`080000002][Jd0[Jf]08QF1`000000R5H70000002][Je20;3P
iP40oooo001I0;3PiP040:f][@00000000000:f][@8000001`3CQ`h00`2][Jd000000>nH40030>nH
40030000003_V100kiP@00D0kiP@0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@060?nV
4@8000002`3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU
408000002@3oYA0200000080ojD@00<0[Jf]0?nS403oXa00303oXa040:f][@800000102][Jd40?nS
40<00000603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:
3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`040000002][Jd0R5H70:f][@<0000000<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H0102][Jd000000000002GH0/2000000L0dhL>0P00
00040>nH40030000003_V100kiP@00<0kiP@0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ40503oYQ480:f][AP0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000000/0ojHA0P00
00070?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003@3oYA02000000T0ojD@00D0
00000?nU40000000ojD@0:f][@0B0?nS40800000103oXa040:f][@<0000000<0[Jf]0?bP403lX100
5@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0
fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00L0000008QF1`28EPL0000008QF1`000000
[Jf]0480/>3V0@3oool005T0/>3V00@0[Jf]000000000000Uf0;0P0000070=>73P800000103_V100
10000000kiP@0>nH403_V1020:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@0D0?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ401P3oYQ42000000@0ojHA2@0000070?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA002P3oYA05000000T0ojD@0P0000020?nU40030:f][@3oXa00oj<@0100oj<@0P00
00080?nS40<0000000<0o:0@0:f][@2][Jd01@2][Jd@0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`0700000028EPL0R5H70000002][Jd000000:f][@120;3PiP40oooo001I0;3PiP<00000
00<0Uf0;0000000000001P3CQ`h2000000D0kiP@00@000000>nH402][Jd0[Jf]103_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X00000403oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01T0ojD@00@000000?nU403oYA00[Jf]4P3oXa020000
00P0oj<@00<000000?bP40000000203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0^GD;
00H0^GD;00D0000008QF1`28EPL000000:f][@0200000480/>3V0@3oool005T0/>3V0`0000000`2G
H0/00000000000060=>73P8000001@3_V1000`000000[Jf]0>nH40050>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400@0?nS40800000203oXa02000000l0o:0@1`2][Jd3
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@07
0=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`0500000028EPL0R5H700000028EPL00P00
00120;3PiP40oooo001I0;3PiP<0000000<0Uf0;0000003CQ`h01@3CQ`h2000000050:f][@3_V100
kiP@0>nH402][Jd00P0000070>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400=0?nS40D00000203o
Xa000`2][Jd000000?bP400E0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`070;Ue2`0500000028EPL0R5H700000028EPL0
0P0000120;3PiP40oooo001G0;3PiP070000002][Jd0000009MP2`000000Uf0;000000060=>73P80
000000D0[Jf]0>nH402][Jd0[Jf]0>nH4002000000L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0000003lX100603lX1000`2][Jd0mY`?0?JL3`040:f]
[A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/01@00
0000[Jf]08QF1`000000R5H70080000000<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00E`2`h>H30000
000409MP2`000000Uf0;000000H0dhL>00D000000=>73P2][Jd0[Jf]000000020>nH408000001`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l50:f][@/0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]1`2iM@/20000000308QF1`000000R5H70080000000<0
[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;000000<0dhL>00@0
00000=>73P3CQ`h000000P2][Jd0103_V10000000>nH403_V102000000L0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0303KRPd0102][Jd0^GD;0:f][@2][Jd50;Ue2`050000002][Jd0000000000028EPL00P000000
0`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP<0000000@0Uf0;0000002GH0/000000P3CQ`h2
000000050=>73P000000[Jf]0=>73P2][Jd00P0000020>nH408000001`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l03P3fW0l40:f][@030?JL3`11JN40[Jf]0180k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0^GD;00L000000:f][@28EPL0000008QF1`000000[Jf]
00800000@02`h>H10?ooo`00E`2`h>H30000000509MP2`000000Uf0;0000003CQ`h00P0000020=>7
3P040000003CQ`h0dhL>0:f][@8000000P3_V102000000L0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B
0?JL3`@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;00/0[Jf]
0;Ue2`2iM@/0^GD;0000002][Jd0R5H700000028EPL000000:f][@0200000400/>3V0@3oool005L0
/>3V0`0000000`2GH0/0000009MP2`02000000050=>73P000000[Jf]0:f][@0000000P3CQ`h00`2]
[Jd000000>nH40020>nH40030000003_V100kiP@00H0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f]
[AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]
0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00X0[Jf]0;Ue
2`2iM@/0^GD;00000028EPL0000008QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3PiP<00000
00@0Uf0;0000002GH0/000000P3CQ`h010000000dhL>0=>73P0000020=>73P030:f][@000000kiP@
0080kiP@00<000000>nH403_V1001P3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f]
[@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue
2`80[Jf]00L0^GD;00000028EPL0000008QF1`000000[Jf]00800000@02`h>H10?ooo`00E`2`h>H3
0000000709MP2`000000Uf0;0000003CQ`h0[Jf]000000020=>73P050000003CQ`h0dhL>0:f][@00
00000`3_V1000`000000kiP@0>nH40060>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01P2iM@/01`2][Jd0000008QF1`000000R5H70000002][Jd00P0000100;3PiP40oooo001G0;3P
iP<0000000L0Uf0;0000002GH0/000000:f][@3CQ`h000000080dhL>00D000000=>73P3CQ`h0[Jf]
000000030>nH40030000003_V100kiP@00H0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@
00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`0600000028EPL0000008QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3PiP<0
000000@0Uf0;0000002GH0/000000P3CQ`h010000000dhL>0=>73P0000020=>73P8000000`3_V100
0`000000kiP@0>nH40060>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P000000[Jf]00000028EPL000000:f][@800000
@02`h>H10?ooo`00E`2`h>H200000080Uf0;00<000000:f][@0000000P3CQ`h01`000000dhL>0=>7
3P000000dhL>0:f][@000000103_V1000`000000kiP@0>nH40060>nH40040:f][@3lX100o:0@0?bP
40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01P00
0000[Jf]00000028EPL000000:f][@800000@02`h>H10?ooo`00EP2`h>H300000080Uf0;00<00000
0:f][@0000000P3CQ`h010000000dhL>0=>73P3CQ`h2000000@0kiP@0P0000080>nH40040:f][@3l
X100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/01P000000R5H700000028EPL000000:f][@800000@02`h>H10?ooo`00EP2`h>H300000080
Uf0;00<0000009MP2`0000000P3CQ`h00`000000dhL>0=>73P020=>73P030:f][@3_V100kiP@0080
kiP@0P0000070>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f]
[@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/010000000R5H700000028EPL400000400/>3V0@3oool0
05H0/>3V0`0000001@2GH0/0000009MP2`2GH0/000000080dhL>00<000000=>73P3CQ`h00P3CQ`h0
0`2][Jd0kiP@0>nH40020>nH408000001@3_V1020:f][@030>nH402][Jd0o:0@0100o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf1
0;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]
0=^:3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00D0000008QF1`000000[Jf]
08QF1`0300000400/>3V0@3oool005H0/>3V0`0000001`2GH0/0000009MP2`2GH0/000000=>73P00
00001@3CQ`h00`2][Jd0kiP@0>nH40020>nH408000000`3_V1020:f][@<0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0
[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@000000R5H700000028EPL0[Jf]
00<00000@02`h>H10?ooo`00EP2`h>H3000000070:f][@000000Uf0;09MP2`000000dhL>00000005
0=>73P030:f][@3_V100kiP@0080kiP@0P0000000`3_V100[Jf]0:f][@050>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H5
0:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00D0000008QF1`000000R5H70:f]
[@0300000400/>3V0@3oool005H0/>3V0`0000001P2][Jd0000009MP2`2GH0/0[Jf]000000H0dhL>
00<0[Jf]0>nH403_V1000P3_V102000000030:f][@3_V100kiP@00D0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]
203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
1`3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd000000000000208QF1`<00000
@02`h>H10?ooo`00EP2`h>H30000000509MP2`000000Uf0;09MP2`2][Jd01`3CQ`h01@2][Jd0kiP@
0>nH403_V100[Jf]00800000203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0
oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@030=^:3@2][Jd0^GD;
00P0^GD;0P00000208QF1`<00000@02`h>H10?ooo`00EP2`h>H30000000409MP2`000000Uf0;0:f]
[@P0dhL>00D0[Jf]0>nH402][Jd0[Jf]0>nH4002000000P0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/200000080R5H70`0000100;3PiP40oooo001F0;3P
iPD0000000<0Uf0;0:f][@3CQ`h01`3CQ`h20:f][@<0kiP@0P0000080>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@L0^GD;0P00000208QF1`<00000@02`h>H10?oo
o`00EP2`h>H50000000309MP2`2][Jd0dhL>00H0dhL>0P2][Jd50>nH40030000003_V100kiP@00H0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f]
[@H0^GD;0P00000208QF1`<00000@02`h>H10?ooo`00EP2`h>H2000000050:f][@000000000009MP
2`2][Jd01@3CQ`h20:f][@030=>73P2][Jd0kiP@00@0kiP@00<000000>nH403_V1001@3_V1000`2]
[Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@05
0;Ue2`80000000<0R5H70000000000000P0000100;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP
2`000000Uf0;0:f][@040=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP
400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Jd30;Ue2`8000000P28
EPL300000400/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;0000002GH0/0[Jf]00<0dhL>00<0
[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102]
[Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0
[Jf]0;Ue2`2iM@/00P00000208QF1`040:f][@0000000000000003l0/>3V0@3oool005H0/>3V0P00
00001P2][Jd0Uf0;0000002GH0/0[Jf]0=>73P80[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00D0^GD;0P2][Jd200000080R5H700@0[Jf]045Yh@0000000000?`2`h>H10?oo
o`00EP2`h>H01P000000[Jf]0:f][@2GH0/0000009MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0
[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`8000000`28
EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;09MP2`000000Uf0;
0:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V
0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@000000R5H70080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`
h>H01@000000[Jf]09MP2`2GH0/000000080[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`h>H30:f][@l0`kfk
0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd00000
08QF1`0208QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00D000000:f][@2GH0/0Uf0;
000000020:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]
102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk
00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;
00<0[Jf]0000002][Jd00P28EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3PiP070000002]
[Jd0Uf0;09MP2`000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402]
[Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0
[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0000002][Jd00P28EPL00`2][Jd000000000000o0;3PiP40
oooo001F0;3PiP070000002][Jd0Uf0;0:f][@000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@
00X0kiP@0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f]
[@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0000008QF1`2][Jd0R5H70:f][@800000?`2`
h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2][Jd0000009MP2`2][Jd0203CQ`h00`2][Jd0kiP@
0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/
102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh
0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]00000028EPL0R5H70P2][Jd2000003l0
/>3V0@3oool005H0/>3V00L000000:f][@2][Jd0Uf0;0000002GH0/0[Jf]00P0dhL>00<0[Jf]0>nH
403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg
[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji
^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o
0;3PiP40oooo001F0;3PiP070000002][Jd0[Jf]09MP2`000000Uf0;0:f][@080=>73P030:f][@3_
V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`0
3`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]
1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V
0;3PiP0m0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;00000080Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0
[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?oo
o`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00L0dhL>00@0[Jf]0>nH402]
[Jd0[Jf]0P11JN440:BNS`030:f][@2aZid0/J^M00@0/J^M0P2][Jd50;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f]
[@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh
0;ji^080[Jf]202n^KP01011JN40];2a0;B`/@2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@80Y9j?0P11JN430:BNS`<0@FWQ1`2aZid20:f][@<0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`
1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk
00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`11JN40];2a0;B`/@020;B`/@03045Yh@2][Jd0[Jf]00X0
^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0@FWQ0:BNS`020:BNS`80@FWQ0P2TWXl01011
JN40Y9j?0:f][@11JN490;6[W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@P0_[Vh00D0@FWQ
0;ji^02n^KP0_[Vh045Yh@040;B`/@03045Yh@2d/;40];2a0080[Jf]202iM@/0102][Jd0R5H708QF
1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@060=>73P80[Jf]00<0Y9j?045Yh@2TWXl00P2TWXl2045Yh@80Y9j?00D0@FWQ0:BNS`2][Jd0
/J^M045Yh@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh
00P0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh045Yh@040;B`/@03045Yh@2d/;40];2a0080];2a00<0[Jf]
0;Ue2`2iM@/01@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3o
ool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P050:f][@11JN40[Jf]0:BNS`11JN40
0`2TWXl2045Yh@80Y9j?00D0@FWQ0:f][@2aZid0/J^M045Yh@040;6[W@03045Yh@2aZid0/J^M00@0
/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`03
0:f][@2n^KP0_[Vh00<0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh045Yh@030;ji^003045Yh@2][Jd0];2a
0080];2a00@0@FWQ0;B`/@2d/;40];2a0P11JN420:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2]
[Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103C
Q`h01P2][Jd0@FWQ08Z5M@2][Jd0Y9j?045Yh@<0Y9j?0P11JN40102TWXl0@FWQ045Yh@2][Jd30;6[
W@04045Yh@2aZid0/J^M0;6[W@<0@FWQ102aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<9
0:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh045Yh@020;ji^003045Yh@2n^KP0
_[Vh0080_[Vh0P11JN420;ji^080@FWQ0`2d/;400`11JN40];2a0;B`/@020;B`/@D0[Jf]0`2iM@/0
102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@030=>73P040:f][@2:QGD0@FWQ045Yh@80[Jf]00@0@FWQ0:BNS`2TWXl0
Y9j?0P11JN40102TWXl0@FWQ045Yh@2][Jd30;6[W@05045Yh@2aZid0/J^M0;6[W@11JN400P2aZid2
045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<
0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/01P2][Jd0@FWQ0;ji^011
JN40_[Vh045Yh@@0_[Vh0P11JN420;ji^080@FWQ0`2d/;401@11JN40];2a0;B`/@2d/;40[Jf]0080
];2a00@0[Jf]045Yh@11JN40[Jf]0P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0
/>3V03d0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@80RXEe0P11
JN40102][Jd0Y9j?045Yh@2][Jd20:BNS`03045Yh@2TWXl0Y9j?0080@FWQ00<0[Jf]0;6[W@2aZid0
1@2aZid00`11JN40/J^M0;6[W@020;6[W@03045Yh@2aZid0[Jf]00/0^K:V102][Jd00`2i/ZH0[Jf]
0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd>0<>m^`03045Yh@2n^KP0_[Vh00<0@FWQ
102n^KP2045Yh@80_[Vh0P11JN430;B`/@04045Yh@2d/;40[Jf]0:f][@<0];2a00@0[Jf]045Yh@2O
Vj00@FWQ0`2][Jd408QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2G
H0/00P2GH0/20:f][@@0RXEe0P11JN40102][Jd0Y9j?045Yh@2TWXl20:f][@03045Yh@2TWXl0Y9j?
0080@FWQ00<0[Jf]0;6[W@2aZid01@2aZid00`11JN40/J^M0;6[W@020;6[W@03045Yh@2aZid0[Jf]
0080^K:V00<0@FWQ0;VbYP2i/ZH02P2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f]
[@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0_02][Jd0`kfk00d0`kfk00<0@FWQ0:f]
[@2n^KP00P2n^KP2045Yh@@0_[Vh0P11JN420;ji^080@FWQ0`2d/;400`11JN40[Jf]0;B`/@040;B`
/@030:f][@11JN40Wi^P00<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000;3PiP0n0;3P
iP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD2045Yh@03
0:f][@11JN40@FWQ00<0Y9j?00<0@FWQ0:f][@2TWXl00P11JN400`2][Jd0/J^M0;6[W@050;6[W@03
045Yh@2aZid0/J^M0080/J^M00@0@FWQ0;6[W@2][Jd0^K:V0P11JN4=0;VbYP030:f][@2n]j`0[Jf]
00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`040<>m
^`03045Yh@33_K/0`kfk00@0`kfk0P11JN40102][Jd0_[Vh0;ji^02n^KP2045Yh@@0_[Vh0P11JN40
102n^KP0@FWQ045Yh@11JN420;B`/@030:f][@11JN40];2a00D0];2a00<0@FWQ09nKX02OVj00102O
Vj001P2][Jd0R5H708QF1`28EPL0[Jf]000003l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0
Uf0;0P2][Jd508Z5M@80@FWQ00<0[Jf]045Yh@11JN400`2TWXl00`11JN40Y9j?0:f][@02045Yh@03
0:f][@2aZid0/J^M00X0/J^M00<0@FWQ0;6[W@2][Jd00P2i/ZH00`11JN40^K:V0;VbYP0;0;VbYP03
0:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33
_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd90<K0_003
0:f][@33_K/0`kfk0080`kfk0P11JN470<>m^`80@FWQ00@0`kfk0:f][@2n^KP0_[Vh0P11JN440;ji
^080@FWQ00@0_[Vh045Yh@2n^KP0@FWQ0P2][Jd00`2d/;40@FWQ0;B`/@050;B`/@030:f][@2OVj00
Wi^P00@0Wi^P00H0[Jf]08QF1`28EPL0R5H70:f][@00000o0;3PiP40oooo001F0;3PiP040:f][@2G
H0/0Uf0;09MP2`80[Jf]1@2:QGD00`11JN40RXEe045Yh@02045Yh@<0Y9j?00<0@FWQ0:BNS`2TWXl0
0P11JN400`2][Jd0/J^M0;6[W@0:0;6[W@03045Yh@2aZid0[Jf]0100^K:V00<0[Jf]0;jg[02n]j`0
1`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@33_K/0`kfk00<0@FWQ
2033_K/2045Yh@040<>m^`2][Jd0_[Vh0;ji^080@FWQ0`2n^KP2045Yh@050;ji^011JN40@FWQ0:f]
[@11JN400`2d/;400`11JN40];2a0;B`/@040;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]08QF
1`28EPL0[Jf]0000000o0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1@2:QGD00`11
JN40RXEe0:f][@050:BNS`05045Yh@2TWXl0Y9j?0:BNS`11JN400P2][Jd;0;6[W@03045Yh@2aZid0
[Jf]0100^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]4@36`;`00`2][Jd0`kfk0<>m^`02
0<>m^`03045Yh@33_K/0`kfk00L0`kfk00<0@FWQ0<>m^`2][Jd00P2n^KP2045Yh@<0_[Vh0P11JN40
1@2n^KP0@FWQ045Yh@2n^KP0@FWQ00<0];2a00<0@FWQ0;B`/@2d/;400P2d/;400`11JN40];2a0:f]
[@0709nKX080[Jf]00<0R5H70:f][@000000?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1S
H5<20:f][@D0RXEe00<0@FWQ0:f][@2TWXl01@2TWXl01`11JN40Y9j?0:BNS`2TWXl0@FWQ0:f][@2a
Zid00P2][Jd00`11JN40/J^M0;6[W@040;6[W@<0@FWQ00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0
_[N/0;jg[00?0;jg[0@0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0
aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00X0
al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l00/0a/2l1011JN400`36`;`0[Jf]0<>m^`030<>m^`03
045Yh@33_K/0`kfk00L0`kfk00<0@FWQ0<>m^`2][Jd00P2n^KP2045Yh@<0_[Vh0P11JN401P2][Jd0
@FWQ045Yh@2n^KP0[Jf]045Yh@80];2a00<0@FWQ0;B`/@2d/;400P2d/;400`11JN40];2a0:f][@07
09nKX0050:f][@1`KWT0[Jf]0:f][@000000?`2`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]
08Z5M@2:QGD00`2:QGD00`11JN40[Jf]0:BNS`040:BNS`80@FWQ0`2TWXl01011JN40[Jf]0;6[W@2a
Zid2045Yh@80[Jf]0P2aZid4045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0030;jg[0<0@FWQ2P2n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0_0080<K0_0<0@FWQ0P36
`;`2045Yh@030<K0_02][Jd0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/01`33_K/00`11JN40`kfk0:f]
[@030;ji^004045Yh@2n^KP0[Jf]0:f][@80@FWQ00H0_[Vh045Yh@11JN40_[Vh0:f][@11JN420;B`
/@03045Yh@2d/;40];2a0080];2a00<0@FWQ0;B`/@2][Jd01P2OVj020:f][@04071^N@2][Jd0[Jf]
000003l0/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]102:QGD00`11JN40[Jf]0:BNS`050:BN
S`04045Yh@2TWXl0Y9j?0:BNS`80@FWQ0P2aZid2045Yh@80/J^M00@0[Jf]045Yh@11JN40@FWQ102a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00D0_[N/0`11JN480;jg[0030:f][@31
^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2]
[Jd<0<O1_0030:f][@36`;`0a/2l00H0a/2l0`11JN450<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P33
_K/00`11JN40`kfk0<>m^`070<>m^`80@FWQ00H0[Jf]0;ji^02n^KP0_[Vh045Yh@2][Jd20;ji^080
@FWQ00D0_[Vh045Yh@11JN40_[Vh0:f][@02045Yh@80];2a00L0@FWQ0;B`/@2d/;40];2a045Yh@2d
/;40[Jf]00D0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0308Z5M@03045Yh@2][Jd0Y9j?00T0Y9j?0P11JN42
0;6[W@04045Yh@2aZid0/J^M0;6[W@80@FWQ0`2][Jd30;6[W@030:f][@2i/ZH0@FWQ00d0^K:V00<0
[Jf]0;jg[02n]j`01P2n]j`00`11JN40_[N/0;jg[002045Yh@H0_[N/00<0[Jf]0<6j/031^[002P31
^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`02036
`;`00`11JN40a/2l0<K0_0040<K0_003045Yh@2][Jd0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/02033
_K/6045Yh@<0_[Vh0P11JN420;ji^004045Yh@2n^KP0[Jf]045Yh@<0];2a00@0@FWQ0;B`/@2d/;40
];2a0P11JN400`2][Jd0Wi^P09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0[Jf]08Z5M@02045Y
h@030:f][@2TWXl0Y9j?00T0Y9j?00@0@FWQ0;6[W@2aZid0@FWQ0`2aZid00`11JN40/J^M0;6[W@02
0;6[W@80[Jf]00@0/J^M0:f][@2i/ZH0@FWQ3@2i/ZH00`2][Jd0_[N/0;jg[0060;jg[003045Yh@2n
]j`0_[N/0080_[N/0P11JN440;jg[0040:f][@11JN40@FWQ045Yh@h0`KZ`202][Jd@0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]
0`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00P0a/2l00<0@FWQ0<K0_036`;`0
1036`;`2045Yh@@0`kfk00<0@FWQ0<>m^`33_K/02033_K/30:f][@80_[Vh00@0@FWQ0;ji^02n^KP0
_[Vh0P11JN420;ji^003045Yh@2n^KP0@FWQ00@0];2a00@0@FWQ0;B`/@2d/;40];2a0P11JN400`2]
[Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00P0[Jf]08Z5M@2:QGD0RXEe0:f][@2:QGD0@FWQ0:f][@/0Y9j?00<0
[Jf]045Yh@11JN40102aZid00`11JN40/J^M0;6[W@030;6[W@05045Yh@2][Jd0[Jf]0:f][@11JN40
3@2i/ZH00`2][Jd0_[N/0;jg[0060;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11JN430;jg[0030:f]
[@31^[00`KZ`00@0@FWQ3@31^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`03
0:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`02036`;`00`11JN40a/2l0<K0_0050<K0_003
045Yh@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`33_K/01@33_K/30:f][@030<>m^`2][Jd0_[Vh0080
_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN420;ji^003045Yh@2n^KP0[Jf]00@0];2a00@0@FWQ0;B`
/@2d/;40];2a0P11JN400`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H1
0?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5
M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@040;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN40102a
Zid0[Jf]0;VbYP11JN420:f][@/0^K:V00<0[Jf]0;jg[02n]j`01P2n]j`00`11JN40_[N/0;jg[004
0;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd00P31^[02045Yh@l0`KZ`00<0[Jf]0<>m/`33_K<03P33
_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0030<O1^0L0@FWQ2P37
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37
`K`0al6l0140al6l00<0[Jf]0<K0_036`;`02036`;`00`11JN40a/2l0<K0_0050<K0_003045Yh@33
_K/0`kfk0080`kfk0P11JN430<>m^`<0[Jf]1033_K/01@2][Jd0_[Vh0;ji^02n^KP0@FWQ00<0_[Vh
0`11JN430;ji^0030:f][@2d/;40];2a0080];2a00@0@FWQ0;B`/@2d/;40];2a0P11JN420:f][@H0
Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C
00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@H0Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl00`2][Jd0/J^M
0;6[W@050;6[W@04045Yh@2aZid0/J^M0;6[W@80@FWQ00@0/J^M0:f][@2i/ZH0@FWQ0P2i/ZH30:f]
[@P0^K:V00<0[Jf]0;jg[02n]j`01P2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ0P2n]j`00`2]
[Jd0`KZ`0<6j/002045Yh@d0`KZ`00<0@FWQ0<6j/02][Jd05@33_K<00`2][Jd0aKje0<Fn]@030<Fn
]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00H0al6h00<0@FWQ0<O1
^037`KP02`37`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0080<K0
_003045Yh@36`;`0a/2l00D0a/2l0P11JN430<>m^`80@FWQ00<0`kfk0:f][@2][Jd01@33_K/2045Y
h@040:f][@2n^KP0_[Vh045Yh@<0_[Vh0P11JN450;ji^0030:f][@2d/;40];2a0080];2a0P11JN40
1@2d/;40@FWQ0;B`/@2d/;40[Jf]00L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo
001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BN
S`030:BNS`80@FWQ102TWXl00`2][Jd0/J^M0;6[W@060;6[W@03045Yh@2aZid0/J^M0080@FWQ00@0
/J^M0:f][@2i/ZH0@FWQ1@2i/ZH40:f][@@0^K:V00<0[Jf]0;jg[02n]j`01P2n]j`00`11JN40_[N/
0;jg[0040;jg[080@FWQ00<0_[N/0:f][@31^[000P31^[02045Yh@/0`KZ`0P11JN400`31^[00@FWQ
045Yh@0E0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00H0al6h
00<0@FWQ0<O1^037`KP02`37`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`02036`;`00`11JN40a/2l
0<K0_0050<K0_080@FWQ0`33_K/2045Yh@030:f][@33_K/0`kfk00D0`kfk0P11JN400`2][Jd0_[Vh
045Yh@0;0;ji^0030:f][@2d/;40];2a00<0];2a0`11JN430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0
L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@<0
Y9j?0P11JN440:BNS`030:f][@2aZid0/J^M00L0/J^M0P11JN401P2aZid0@FWQ0;6[W@2][Jd0^K:V
045Yh@T0^K:V0`2][Jd00`2i/ZH0[Jf]0;jg[0070;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0@FWQ
0;jg[02][Jd00`31^[02045Yh@X0`KZ`00<0@FWQ0<6j/011JN400P31^[000`2][Jd0@FWQ045Yh@02
0<>m/`80@FWQ3`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng5@2][Jd0
0`11JN40[Jf]0:f][@0H0:f][@T0al6j00<000000<O1^P2][Jd05P38`K/00`2][Jd0b<6k0<S1^`09
0<S1^`03045Yh@38`K/0b<6k00L0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_008
0<K0_003045Yh@36`;`0a/2l00D0a/2l0P11JN430:f][@80@FWQ0`33_K/2045Yh@@0`kfk00@0@FWQ
0:f][@2n^KP0@FWQ2`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f][@L0Wi^P
00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2]
[Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@030:BNS`11JN40Y9j?00@0Y9j?00<0[Jf]0;6[W@2a
Zid02P2aZid00`11JN40/J^M0:f][@02045Yh@`0^K:V0`2][Jd70;jg[003045Yh@2n]j`0_[N/00D0
_[N/00<0@FWQ0;jg[02][Jd00`31^[02045Yh@X0`KZ`0P11JN430<6j/0040:f][@33_K<0@FWQ0<>m
/`80@FWQ1`33_K<00`11JN40`kfc0<>m/`030<>m/`04045Yh@33_K<0`kfc0:f][AH0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0060<O1^003045Yh@37`KP0al6h00/0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`@0@FWQ1`38`K/2045Yh@T0b<6k00<0[Jf]
0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0080<K0_003045Yh@36`;`0a/2l00<0a/2l0P2][Jd2
045Yh@<0`kfk0P11JN430<>m^`80@FWQ1@33_K/2045Yh@`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;42
0:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3o
ool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2T
WXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0@FWQ045Yh@0=0;VbYP030:f][@2n
]j`0[Jf]00<0[Jf]0`2n]j`00`11JN40_[N/0;jg[0050;jg[003045Yh@2n]j`0[Jf]00<0`KZ`0P11
JN4:0<6j/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`02045Yh@P0`kfc00<0@FWQ0<>m/`33_K<00`33
_K<01011JN40`kfc0<>m/`2][JdF0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
1P37`KP00`11JN40al6h0<O1^00;0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
4@38`K/01011JN40b<6k045Yh@2][Jd30<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`070<S1^`03
0:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`02036`;`00`11JN40[Jf]0:f][@030:f][@80
a/2l0P11JN430<>m^`<0@FWQ0P33_K/2045Yh@D0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0
];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je0
0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl2
0:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0@FWQ045Yh@0=0;VbYP030:f][@2n]j`0
_[N/00<0_[N/0`2][Jd00`11JN40_[N/0;jg[0050;jg[080@FWQ00@0[Jf]0<6j/031^[00`KZ`0P11
JN4:0<6j/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`02045Yh@P0`kfc00<0@FWQ0<>m/`33_K<00`33
_K<01011JN40`kfc0<>m/`2][Jd:0<Fn]@@0@FWQ0P35_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^0060<O1^003045Yh@37`KP0al6h00/0al6h00<0[Jf]0<O1^P37`KX0
5037`KX3045Yh@L0b<6k0`11JN480<S1^`04045Yh@38`K/0@FWQ0:f][@D0b<6k00<0@FWQ0<S1^`38
`K/03@38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00D0a/2l0`2][Jd00`11JN40
a/2l0<K0_0050<K0_080@FWQ0`33_K/2045Yh@040<>m^`11JN40`kfk045Yh@H0`kfk00<0[Jf]0;ji
^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]
071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0
Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M00/0/J^M00@0[Jf]0;VbYP11JN40@FWQ3@2i
/ZH00`2][Jd0_[N/0;jg[0060;jg[003045Yh@2][Jd0[Jf]0080[Jf]0`2n]j`2045Yh@050:f][@31
^[00`KZ`0<6j/011JN402`31^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN470<>m/`<0@FWQ
0`33_K<01@11JN40`kfc045Yh@33_K<0[Jf]00P0aKje0`11JN430<Fn]@@0@FWQ1035_[D6045Yh@d0
a[ng1011JN400`36_kL0[Jf]0<O1^0070<O1^003045Yh@37`KP0al6h00/0al6h00<0[Jf]045Yh@11
JN401@11JN420<O1^PL0@FWQ0P37`KX4045Yh@030<O1^P2][Jd0b<6k00D0b<6k0P11JN430<S1^`80
@FWQ1P38`K/2045Yh@030<S1^`2][Jd0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/03@38`K/00`2][Jd0
al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00D0[Jf]0`36`;`00`11JN40a/2l0<K0_0050<K0_080
@FWQ0`33_K/2045Yh@80`kfk00<0@FWQ0<>m^`33_K/01@33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0
[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V
00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]3@2aZid0102][Jd0^K:V
045Yh@11JN4=0;VbYP030:f][@2n]j`0_[N/00D0_[N/0P11JN440;jg[0<0[Jf]0P11JN401@2][Jd0
`KZ`0<6j/031^[00@FWQ00/0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc0080@FWQ1`33_K<3045Y
h@<0`kfc0`11JN400`33_K<0[Jf]0<Fn]@060<Fn]@80@FWQ1P35_[D3045Yh@@0aKje00@0[Jf]0<Jo
]`11JN40@FWQ3@36_kL2045Yh@@0a[ng00<0@FWQ0:f][@37`KP00P37`KP00`11JN40al6h0<O1^002
0<O1^004045Yh@37`KP0al6h0<O1^0<0@FWQ1`37`KP0102][Jd0al6j0<O1^P37`KX2045Yh@L0al6j
0P11JN470<O1^P03045Yh@37`KX0[Jf]00D0b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`11JN40b<6k
0<S1^`030<S1^`04045Yh@38`K/0b<6k0:f][@D0b<6k00<0@FWQ0<S1^`38`K/03@38`K/00`2][Jd0
al6l0<O1_00?0<O1_0D0[Jf]2036`;`2045Yh@H0a/2l0P11JN400`33_K/0@FWQ045Yh@02045Yh@X0
`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0
L6ii0:f][@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]
302aZid0102][Jd0^K:V045Yh@11JN4=0;VbYP030:f][@2n]j`0_[N/00D0_[N/0P11JN470;jg[080
@FWQ102][Jd00`11JN40`KZ`0<6j/00:0<6j/005045Yh@31^[00`KZ`0<6j/02][Jd00P33_K<2045Y
h@L0`kfc0`11JN430<>m/`<0@FWQ00<0`kfc0:f][@35_[D01P35_[D00`11JN40aKje0<Fn]@060<Fn
]@80@FWQ1035_[D0102][Jd0a[ng045Yh@11JN4=0<Jo]`80@FWQ1@36_kL01011JN40al6h045Yh@11
JN450<O1^004045Yh@37`KP0@FWQ045Yh@80al6h0`11JN450<O1^0040:f][@37`KX0al6j0<O1^P80
@FWQ1`37`KX2045Yh@L0al6j00<0@FWQ0<O1^P2][Jd01038`K/2045Yh@P0b<6k00<0@FWQ0<S1^`38
`K/00P38`K/01011JN40b<6k0<S1^`2][Jd40<S1^`80@FWQ3`38`K/00`2][Jd0al6l0<O1_00:0<O1
_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_0080<K0_080@FWQ1P36`;`2045Yh@l0`kfk00<0[Jf]0;ji
^02n^KP0202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f]
[D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2]
[Jd00P2][Jd90;6[W@040:f][@2i/ZH0@FWQ045Yh@d0^K:V00<0[Jf]0;jg[02n]j`01@2n]j`2045Y
h@L0_[N/0P11JN401@2][Jd0`KZ`0<6j/031^[00@FWQ00H0[Jf]1`31^[001011JN40`KZ`0<6j/02]
[Jd20<>m/`80@FWQ1`33_K<00`11JN40`kfc045Yh@030<>m/`<0@FWQ00<0`kfc0:f][@35_[D01@35
_[D00`11JN40aKje0<Fn]@070<Fn]@80@FWQ1035_[D0102][Jd0a[ng045Yh@11JN4<0<Jo]`80@FWQ
1P36_kL3045Yh@H0al6h0P11JN460<O1^003045Yh@37`KP0al6h00<0al6h00@0[Jf]0<O1^P37`KX0
al6j0P11JN470<O1^P80@FWQ1`37`KX00`11JN40al6j0:f][@040<S1^`80@FWQ4038`K/00`2][Jd0
b<6k0<S1^`020<S1^`03045Yh@38`K/0b<6k00h0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0
al6l00<0[Jf]0<K0_036`;`02036`;`2045Yh@H0a/2l0P11JN4?0<>m^`030:f][@2n^KP0_[Vh00H0
_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80
/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M0080/J^M0P2][Jd70;6[W@040:f][@2i/ZH0@FWQ045Yh@d0^K:V00<0[Jf]0;jg[02n
]j`01@2n]j`2045Yh@L0_[N/0P11JN40102][Jd0`KZ`0<6j/031^[02045Yh@D0`KZ`1`2][Jd01031
^[00@FWQ045Yh@2][Jd20<>m/`80@FWQ1`33_K<00`11JN40`kfc045Yh@030<>m/`05045Yh@33_K<0
@FWQ0<>m/`2][Jd01P35_[D00`11JN40aKje0<Fn]@070<Fn]@80@FWQ1035_[D0102][Jd0a[ng045Y
h@11JN4<0<Jo]`80@FWQ1P36_kL00`2][Jd0@FWQ045Yh@060<O1^003045Yh@37`KP0al6h00H0al6h
00<0@FWQ0<O1^037`KP00`37`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j0P11JN470<O1^P03045Y
h@37`KX0[Jf]00<0b<6k0P11JN420<S1^`0300000038`K/0b<6k00`0b<6k00<0[Jf]0<S1^`38`K/0
0`11JN460<S1^`03045Yh@38`K/0b<6k00L0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f]
[@36`;`0a/2l00P0a/2l0P11JN460<K0_080@FWQ3`33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]
1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0
@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00@0[Jf]0;VbYP11JN40@FWQ3@2i/ZH00`2][Jd0_[N/
0;jg[0050;jg[080@FWQ1`2n]j`2045Yh@040:f][@31^[00`KZ`0<6j/080@FWQ3031^[030:f][@D0
@FWQ1P33_K<2045Yh@040<>m/`11JN40`kfc0<>m/`80@FWQ00@0`kfc045Yh@33_K<0[Jf]1P35_[D0
0`11JN40aKje0<Fn]@070<Fn]@80@FWQ1035_[D0102][Jd0a[ng045Yh@11JN4<0<Jo]`80@FWQ1P36
_kL00`2][Jd0@FWQ045Yh@060<O1^003045Yh@37`KP0al6h00H0al6h00<0@FWQ0<O1^037`KP00`37
`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j0P11JN470<O1^P03045Yh@37`KX0[Jf]00<0b<6k0P11
JN4A0<S1^`030:f][@38`K/0@FWQ0080@FWQ1`38`K/00`11JN40b<6k0<S1^`040<S1^`H0[Jf]4@37
`K`00`2][Jd0a/2l0<K0_0080<K0_080@FWQ1P36`;`2045Yh@l0`kfk00@0[Jf]0000002n^KP0_[Vh
0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V
0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00D0/J^M0:f][@2i/ZH0^K:V045Yh@0=0;VbYP030:f]
[@2n]j`0_[N/00D0_[N/0P11JN470;jg[080@FWQ00@0[Jf]0<6j/031^[00`KZ`0P11JN440<6j/003
045Yh@31^[00`KZ`00P0`KZ`00<0[Jf]0<>m/`11JN400P11JN460:f][@80@FWQ0P33_K<01011JN40
`kfc045Yh@11JN420<>m/`03045Yh@2][Jd0aKje00@0aKje0P11JN490<Fn]@80@FWQ1035_[D0102]
[Jd0a[ng045Yh@11JN4<0<Jo]`80@FWQ1P36_kL00`2][Jd0@FWQ045Yh@060<O1^003045Yh@37`KP0
al6h00H0al6h0P11JN440<O1^0030:f][@37`KX0al6j0080@FWQ0P37`KX00`000000al6j0<O1^P02
0<O1^P80@FWQ1`37`KX00`11JN40al6j0:f][@030<S1^`80@FWQ4@38`K/3045Yh@T0b<6k00<0@FWQ
0:f][@2][Jd0102][Jd30<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`02036`;`2
045Yh@D0a/2l0P11JN400`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V0@3o
ool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00X0/J^M0`2][Jd00`2i/ZH0@FWQ0;VbYP0<0;VbYP030:f][@2n]j`0_[N/00D0_[N/0P11JN47
0;jg[080@FWQ00L0[Jf]045Yh@11JN40`KZ`045Yh@31^[00@FWQ0080`KZ`00<0@FWQ0<6j/011JN40
1@31^[001@11JN40`KZ`0<6j/031^[00[Jf]0080`kfc0P11JN460<>m/`80@FWQ0P2][Jd01011JN40
[Jf]045Yh@11JN420<>m/`03045Yh@2][Jd0aKje00@0aKje0P11JN490<Fn]@80@FWQ1035_[D0102]
[Jd0a[ng045Yh@11JN4<0<Jo]`80@FWQ1P36_kL00`2][Jd0@FWQ045Yh@060<O1^003045Yh@37`KP0
al6h00H0al6h0P11JN440<O1^0030:f][@37`KX0al6j0080@FWQ1`37`KX2045Yh@L0al6j00<0@FWQ
0<O1^P2][Jd00`38`K/2045YhA00b<6k00<0@FWQ0:f][@11JN400P38`K/80:f][@03045Yh@38`K/0
b<6k00L0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0080<K0_080@FWQ1@36`;`2
045Yh@030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]
09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/
00D0_[N/0P11JN460;jg[080@FWQ00@0_[N/0:f][@31^[00`KZ`0P11JN420<6j/003045Yh@31^[00
`KZ`0080@FWQ1@31^[001@11JN40`KZ`0<6j/031^[00[Jf]0080`kfc00<0@FWQ0<>m/`33_K<01@33
_K<2045Yh@80`kfc00@0@FWQ0<>m/`11JN40@FWQ0P2][Jd00`11JN40[Jf]0:f][@040:f][@80@FWQ
1`35_[D6045Yh@80aKje00@0[Jf]0<Jo]`11JN40@FWQ3@36_kL2045Yh@D0a[ng00<0[Jf]045Yh@11
JN401P37`KP00`11JN40al6h0<O1^0060<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P02045Yh@L0
al6j0P11JN470<O1^P80@FWQ00@0[Jf]0<S1^`38`K/0b<6k0P11JN4<0<S1^`<0[Jf]00<0@FWQ0:f]
[@11JN400`2][Jd20<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01`38`K/00`2]
[Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00P0a/2l0P11JN450<K0_080@FWQ00<0[Jf]0<>m
^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2]
[Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2a
Zid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[0050;jg[080
@FWQ1P2n]j`2045Yh@030;jg[02][Jd0`KZ`00H0`KZ`0`11JN460<6j/005045Yh@31^[00`KZ`0<6j
/02][Jd00P33_K<00`11JN40`kfc0<>m/`050<>m/`06045Yh@33_K<0`kfc0<>m/`11JN40`kfc0P11
JN420<>m/`03045Yh@2][Jd0aKje00@0aKje0P11JN4:0:f][@D0aKje00@0[Jf]0<Jo]`11JN40@FWQ
3P36_kL3045Yh@<0a[ng00<0[Jf]045Yh@11JN401P37`KP00`11JN40al6h0<O1^0060<O1^080@FWQ
1037`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j0P11JN470<O1^P80@FWQ00@0[Jf]00000038`K/0
b<6k0P11JN480:f][@04045Yh@2][Jd0[Jf]0:f][@80b<6k0`11JN400`2][Jd0b<6k0<S1^`020<S1
^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`070<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`01`36`;`2045Yh@@0a/2l0P11JN400`36`;`0[Jf]0<>m^`070<>m^`<0[Jf]1033_K/00`2]
[Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80
[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP03
0:f][@2n]j`0_[N/00D0_[N/0P11JN450;jg[080@FWQ0P2n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0<0
@FWQ00<0[Jf]0<>m/`11JN401`33_K<2045Yh@<0`kfc00<0@FWQ0<>m/`11JN400`33_K<00`11JN40
[Jf]0<Fn]@040<Fn]@80@FWQ2P35_[D70:f][@80@FWQ202][Jd90<Jo]`80@FWQ00@0a[ng0:f][@11
JN40@FWQ1P37`KP00`11JN40al6h0<O1^0060<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P02045Y
h@L0al6j0P11JN470:f][@80@FWQ1@2][Jd2045Yh@H0b<6k00<0@FWQ0<S1^`11JN401038`K/01011
JN40b<6k0<S1^`2][Jd40<S1^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`070<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`2045Yh@@0a/2l0P11JN400`36`;`0[Jf]0<>m^`03
0<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]
0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M
00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/00H0_[N/0P11JN450;jg
[080@FWQ0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/080@FWQ2033_K<2045Yh@@0`kfc0P11JN430<>m
/`03045Yh@2][Jd0aKje00@0aKje0P11JN4?0<Fn]@030:f][@36_kL0@FWQ0080@FWQ1`36_kL;0:f]
[@@0@FWQ1P2][Jd00`11JN40[Jf]0:f][@060:f][@80@FWQ1`2][Jd2045Yh@L0[Jf]0P11JN470<O1
^P80@FWQ00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@L0b<6k0P11JN440<S1^`04045Yh@38`K/0b<6k
0:f][@<0b<6k0`11JN440<S1^`80@FWQ2@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00L0a/2l0P11JN420<K0_0<0@FWQ0P36`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]
0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f]
[@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]102n]j`4045Y
h@@0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01033_K<5045Y
h@@0`kfc0P11JN440<>m/`03045Yh@35_[D0aKje00<0aKje0P11JN4?0<Fn]@030:f][@36_kL0@FWQ
0080@FWQ1036_kL00`11JN40a[ng0<Jo]`0<0<Jo]`030:f][@11JN40@FWQ00H0al6h00<0@FWQ0<O1
^037`KP01P37`KP00`11JN40al6h0<O1^0030<O1^0030:f][@37`KX0al6j0080@FWQ1`37`KX2045Y
h@L0al6j0P11JN400`2][Jd0b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00D0b<6k00<0@FWQ0<S1
^`38`K/01038`K/00`11JN40b<6k0:f][@030<S1^`03045Yh@38`K/0@FWQ00@0b<6k0`11JN480<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`4045Yh@<0a/2l102][Jd>0<>m
^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3P
iP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02][Jd00`2][Jd20;jg[0@0@FWQ0P2n]j`2045Yh@<0_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`070<>m/`@0@FWQ0P33_K<2045Yh@80`kfc0`11JN450<Fn]@80
@FWQ3`35_[D00`2][Jd0a[ng045Yh@02045Yh@@0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL2045Yh@D0
a[ng00<0[Jf]045Yh@37`KP01P37`KP00`11JN40al6h0<O1^0060<O1^003045Yh@37`KP0al6h00<0
al6h00<0[Jf]0<O1^P37`KX00P11JN470<O1^P80@FWQ1`37`KX2045Yh@030:f][@38`K/0b<6k00<0
b<6k0P11JN450<S1^`03045Yh@38`K/0b<6k00H0b<6k1@11JN420<S1^`03045Yh@38`K/0b<6k0080
b<6k0`11JN480<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@36`;`3045Yh@03
0<K0_02][Jd0[Jf]00<0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0
_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]
0P2n]j`3045Yh@@0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`@0@FWQ
0P35_[D2045Yh@l0aKje00H0[Jf]0<Jo]`11JN40@FWQ0<Jo]`11JN430<Jo]`80@FWQ1P36_kL2045Y
h@D0a[ng00<0[Jf]045Yh@37`KP01P37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP01037`KP00`2]
[Jd0al6j0<O1^P02045Yh@H0al6j0P11JN480<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/01011
JN40b<6k0<S1^`38`K/2045Yh@X0b<6k00<0[Jf]0<S1^`38`K/02038`K/3045Yh@P0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=
0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y
0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00@0aKje00<0@FWQ0<Fn]@35_[D03@35_[D4045Yh@030<Jo]`11JN40
a[ng0080a[ng0P11JN470<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<O1^037`KP01P37`KP0
0`11JN40al6h045Yh@040<O1^080@FWQ1P37`KP00`2][Jd0al6j0<O1^P04045Yh@@0al6j0P11JN42
0<O1^P0300000037`KX0al6j00<0al6j0P11JN400`2][Jd0b<6k0<S1^`050<S1^`<0@FWQ3038`K/0
0`2][Jd0b<6k0<S1^`080<S1^`<0@FWQ2038`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]
0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00@0aKje00<0@FWQ0<Fn]@35_[D02035_[D00`11JN40aKje0<Fn]@02
0<Fn]@040:f][@36_kL0@FWQ045Yh@80a[ng1011JN490<Jo]`D0@FWQ00<0[Jf]0<O1^037`KP00`37
`KP4045Yh@80al6h1011JN480<O1^0030:f][@37`KX0al6j0080@FWQ0P37`KX4045Yh@L0al6j0`11
JN420<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02038`K/3045Yh@P0b<6k00<0
[Jf]0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00@0aKje00<0@FWQ0<Fn]@35_[D02035_[D00`11JN40aKje0<Fn]@020<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P02045YhA80al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`080<S1^`<0@FWQ2038`K/00`2][Jd0al6l0<O1_00;
0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@040<Fn]@03045Yh@35_[D0aKje00L0aKje0P11JN44
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P02
045YhA80al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`080<S1^`<0@FWQ2038`K/0
0`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j
/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00@0aKje0P11JN480<Fn
]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX00P11JN4B0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02038`K/2045Y
h@T0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0
`KZ`1`2][JdB0<>m/`030:f][@35_[D0aKje00D0aKje0P11JN470<Fn]@80@FWQ1035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00P11JN4B0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/00`11JN40b<6k0<S1^`040<S1^`H0
[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0
[Jf]2`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ1@35_[D3045Yh@@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ4037`KX00`11JN40
al6j0:f][@0F0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080
[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f]
[@35_[D0aKje00L0aKje00<0@FWQ0<Fn]@35_[D00P35_[D01011JN40aKje0<Fn]@11JN440<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P02045Yh@l0
al6j00@0@FWQ0<O1^P11JN40[Jf]5P38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR
0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][@D0aKje1011JN430<Fn]@03045Yh@35_[D0aKje
0080aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
0080@FWQ4037`KX00`11JN40al6j0:f][@0A0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0
/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP5045YhA80al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd0
0`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3P
iP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f]
[@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0
[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`
h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38
`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38
`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f]
[MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51979 .3309 m
.50976 .33083 L
s
.5365 .33082 m
.52647 .3309 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49472 .33377 m
.4914 .33048 L
s
.4914 .33048 m
.48807 .33038 L
s
.49639 .33381 m
.4914 .33048 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55485 .33045 m
.55153 .33375 L
s
.55485 .33045 m
.54986 .33379 L
s
.55818 .33035 m
.55485 .33045 L
s
.5 Mabswid
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49472 .33377 m
.49477 .33397 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55202 .3225 m
.56353 .32214 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54919 .33511 m
.54986 .33379 L
s
.5 Mabswid
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56631 .34772 m
.5666 .34937 L
s
.5678 .34672 m
.56827 .3493 L
s
.255 .412 .882 r
.52727 .34086 m
.53058 .33859 L
s
.53058 .33859 m
.53554 .33855 L
s
.52561 .34087 m
.53058 .33859 L
s
.53554 .33855 m
.53886 .34076 L
s
0 0 0 r
.45167 .32868 m
.45458 .32886 L
s
.255 .412 .882 r
.49087 .33818 m
.50244 .33844 L
s
.52395 .34538 m
.52561 .34087 L
s
.52561 .34538 m
.52727 .34086 L
s
.54712 .33836 m
.54877 .33832 L
s
.54382 .34068 m
.54712 .33836 L
s
.54547 .34065 m
.54712 .33836 L
s
.53886 .34076 m
.54218 .34522 L
s
0 0 0 r
.58313 .33895 m
.58494 .33527 L
s
.255 .412 .882 r
.54218 .34522 m
.54382 .34068 L
s
.54383 .34519 m
.54547 .34065 L
s
0 0 0 r
.59369 .32942 m
.59625 .33174 L
s
.59389 .32929 m
.59789 .33163 L
s
.255 .412 .882 r
.52395 .34538 m
.52395 .34989 L
s
.52561 .34538 m
.52561 .34989 L
s
.48089 .35593 m
.48098 .33786 L
s
.56198 .3402 m
.56526 .33783 L
s
.56526 .33783 m
.56855 .3377 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47924 .35587 m
.47934 .3378 L
s
.5587 .34482 m
.56198 .3402 L
s
.52395 .34989 m
.52561 .35441 L
s
.52561 .34989 m
.52727 .3544 L
s
.47604 .33992 m
.4793 .34457 L
s
.47113 .33746 m
.47604 .33992 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56855 .3377 m
.57349 .33975 L
s
.56855 .3377 m
.57185 .33982 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46785 .3373 m
.47113 .33746 L
s
.57185 .33982 m
.57516 .34419 L
s
.52561 .35441 m
.53059 .35665 L
s
.52727 .3544 m
.53059 .35665 L
s
.57349 .33975 m
.5768 .34411 L
s
.46456 .3394 m
.46785 .3373 L
s
.46292 .33931 m
.46785 .3373 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4963 .36233 m
.49631 .35901 L
s
.49798 .36135 m
.49798 .35907 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49738 .37 m
.49748 .33834 L
s
.49572 .36997 m
.49582 .3383 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54577 .36127 m
.54662 .36609 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54218 .34522 m
.54222 .36557 L
s
.54383 .34519 m
.54387 .36101 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55696 .32236 m
.55716 .36978 L
s
.5586 .32231 m
.55881 .36973 L
s
.54055 .3588 m
.53059 .35665 L
s
.46125 .34374 m
.46456 .3394 L
s
.45962 .34365 m
.46292 .33931 L
s
.49742 .3564 m
.49906 .36323 L
s
.57516 .34419 m
.57684 .3509 L
s
.54055 .3588 m
.54221 .36104 L
s
.5768 .34411 m
.57849 .35082 L
s
.5882 .33674 m
.59958 .33601 L
s
.52562 .36346 m
.52562 .36573 L
s
.52562 .36346 m
.52728 .36346 L
s
.52728 .36346 m
.52728 .36572 L
s
.54222 .36557 m
.54387 .36101 L
s
.4743 .35568 m
.48584 .3561 L
s
.50901 .36565 m
.51067 .3634 L
s
.51067 .3634 m
.51233 .36569 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45958 .34818 m
.46125 .34374 L
s
.52562 .36573 m
.52728 .36799 L
s
.51233 .36795 m
.51233 .36569 L
s
.49906 .36323 m
.50236 .36783 L
s
.50901 .36565 m
.51066 .36794 L
s
.45795 .34809 m
.45962 .34365 L
s
.54057 .36787 m
.54222 .36557 L
s
.57684 .3509 m
.57687 .35543 L
s
.52728 .36799 m
.53061 .37024 L
s
.51066 .37021 m
.51233 .36795 L
s
.57849 .35082 m
.57852 .35535 L
s
.53725 .37018 m
.54057 .36787 L
s
.50236 .36783 m
.50568 .37015 L
s
.55878 .36292 m
.56211 .36735 L
s
0 0 0 r
.60138 .35351 m
.60138 .35401 L
s
.255 .412 .882 r
.53061 .37024 m
.53725 .37018 L
s
.50568 .37015 m
.51066 .37021 L
s
.4579 .35488 m
.45958 .34818 L
s
0 0 0 r
.603 .35231 m
.60302 .3539 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57528 .3623 m
.57687 .35543 L
s
.45626 .35479 m
.45795 .34809 L
s
0 0 0 r
.58375 .36561 m
.58668 .37112 L
s
.255 .412 .882 r
.57692 .36223 m
.57852 .35535 L
s
.49075 .36985 m
.49738 .37 L
s
.55219 .36991 m
.55881 .36973 L
s
.56211 .36735 m
.56543 .36951 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43857 .33549 m
.44473 .36773 L
s
.43177 .3668 m
.43857 .33549 L
s
.57201 .36699 m
.57528 .3623 L
s
.57366 .36692 m
.57692 .36223 L
s
.45781 .36624 m
.4579 .35488 L
s
.56543 .36951 m
.56873 .36939 L
s
.45617 .36615 m
.45626 .35479 L
s
.56873 .36939 m
.57201 .36699 L
s
.56873 .36939 m
.57366 .36692 L
s
.48074 .38547 m
.48081 .37181 L
s
.47912 .37858 m
.48081 .37181 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59471 .33634 m
.59513 .38405 L
s
.59308 .33644 m
.5935 .38415 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6026 .35658 m
.60302 .3539 L
s
.60095 .35672 m
.60138 .35401 L
s
.6163 .37237 m
.6163 .37243 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61088 .33518 m
.61115 .36014 L
s
.60605 .33555 m
.6173 .33465 L
s
.61249 .33505 m
.61277 .36002 L
s
.43339 .36692 m
.4385 .34228 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58189 .39661 m
.5819 .39742 L
s
.58355 .3955 m
.58356 .39734 L
s
.255 .412 .882 r
.47579 .38302 m
.47912 .37858 L
s
.47912 .37858 m
.48074 .38547 L
s
.42572 .33444 m
.43177 .3668 L
s
.41893 .36572 m
.42572 .33444 L
s
.45781 .36624 m
.45939 .37315 L
s
.59493 .36126 m
.59823 .36561 L
s
.45617 .36615 m
.45775 .37307 L
s
.6237 .33408 m
.6348 .333 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47082 .3851 m
.47579 .38302 L
s
.45939 .37315 m
.461 .3778 L
s
.42053 .36586 m
.42563 .34124 L
s
.45775 .37307 m
.45935 .37771 L
s
.59823 .36561 m
.60313 .36756 L
s
.43986 .36739 m
.44962 .36804 L
s
.461 .3778 m
.46425 .38252 L
s
.46753 .38495 m
.47082 .3851 L
s
.45935 .37771 m
.4626 .38244 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46425 .38252 m
.46753 .38495 L
s
.4626 .38244 m
.46753 .38495 L
s
0 0 0 r
.5819 .39742 m
.58855 .39709 L
s
.255 .412 .882 r
.60313 .36756 m
.60637 .36734 L
s
.60959 .36482 m
.61115 .36014 L
s
.40983 .33292 m
.41141 .33308 L
s
.6112 .3647 m
.61277 .36002 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60637 .36734 m
.60959 .36482 L
s
.60637 .36734 m
.6112 .3647 L
s
.40664 .33486 m
.40983 .33292 L
s
.40822 .33503 m
.40983 .33292 L
s
.58858 .38443 m
.59513 .38405 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63006 .33348 m
.63048 .36535 L
s
.62847 .33363 m
.62888 .3655 L
s
.40658 .33941 m
.40822 .33503 L
s
.405 .33924 m
.40664 .33486 L
s
.40193 .33435 m
.405 .33924 L
s
.39884 .33172 m
.40193 .33435 L
s
.41415 .36528 m
.42534 .36628 L
s
.39416 .33117 m
.39884 .33172 L
s
.64584 .33408 m
.65048 .33126 L
s
.64277 .33898 m
.64584 .33408 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40635 .35536 m
.40658 .33941 L
s
.40471 .35977 m
.405 .33924 L
s
.6413 .34598 m
.64277 .33898 L
s
.62409 .36593 m
.63048 .36535 L
s
.6474 .3339 m
.65048 .33126 L
s
.64434 .3388 m
.6474 .3339 L
s
.6413 .34598 m
.64137 .35054 L
s
.39102 .33306 m
.39416 .33117 L
s
.38948 .33287 m
.39416 .33117 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65048 .33126 m
.65358 .33088 L
s
.64287 .34581 m
.64434 .3388 L
s
.64287 .34581 m
.64294 .35037 L
s
.65358 .33088 m
.65826 .33257 L
s
.64137 .35054 m
.64304 .35723 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40471 .35977 m
.40635 .35536 L
s
.64294 .35037 m
.64461 .35706 L
s
.3894 .33743 m
.39102 .33306 L
s
.39387 .34941 m
.40323 .35274 L
s
.40323 .35274 m
.40477 .35519 L
s
.38786 .33724 m
.38948 .33287 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4031 .36189 m
.40471 .35977 L
s
.65826 .33257 m
.66142 .33674 L
s
.64304 .35723 m
.64625 .36146 L
s
.62903 .37694 m
.63066 .37909 L
s
.62747 .37938 m
.62903 .37694 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62747 .37938 m
.62909 .38153 L
s
.38933 .34199 m
.3894 .33743 L
s
.64461 .35706 m
.64782 .36129 L
s
.38778 .3418 m
.38786 .33724 L
s
.39992 .36384 m
.4031 .36189 L
s
.62909 .38153 m
.63066 .37909 L
s
.3908 .34675 m
.39387 .34941 L
s
.38925 .34656 m
.39387 .34941 L
s
.38933 .34199 m
.3908 .34675 L
s
.38778 .3418 m
.38925 .34656 L
s
.64625 .36146 m
.65098 .36323 L
s
.39366 .36314 m
.39992 .36384 L
s
.64782 .36129 m
.65098 .36323 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3891 .35572 m
.39065 .3559 L
s
.39062 .35819 m
.39065 .3559 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65098 .36323 m
.65565 .36268 L
s
.39058 .36049 m
.39366 .36314 L
s
.38906 .35801 m
.3891 .35572 L
s
.67198 .32842 m
.67358 .33278 L
s
.67198 .32842 m
.67215 .33757 L
s
.6586 .35314 m
.66011 .35065 L
s
.6586 .35314 m
.66019 .35524 L
s
.66011 .35065 m
.66169 .35275 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38906 .35801 m
.39058 .36049 L
s
.65565 .36268 m
.65872 .36002 L
s
.66169 .35275 m
.66173 .35504 L
s
.65872 .36002 m
.66173 .35504 L
s
.67215 .33757 m
.67358 .33278 L
s
.67358 .33278 m
.67505 .33027 L
s
.67505 .33027 m
.67802 .32753 L
s
.3577 .32601 m
.36815 .32765 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67802 .32753 m
.68401 .3266 L
s
.37526 .35394 m
.37674 .35644 L
s
.3767 .35874 m
.37674 .35644 L
s
.37369 .35603 m
.37526 .35394 L
s
.68401 .3266 m
.68703 .32842 L
s
.6724 .35132 m
.67388 .34882 L
s
.6724 .35132 m
.67249 .35592 L
s
.37513 .36084 m
.3767 .35874 L
s
.67388 .34882 m
.67686 .34609 L
s
.67245 .35362 m
.67392 .35111 L
s
.67392 .35111 m
.67691 .34838 L
s
.37369 .35603 m
.37517 .35854 L
s
.67686 .34609 m
.68428 .34036 L
s
.67249 .35592 m
.67405 .35801 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37057 .36021 m
.37513 .36084 L
s
.67691 .34838 m
.68433 .34266 L
s
.68703 .32842 m
.68856 .33047 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36302 .35912 m
.36365 .32696 L
s
.36152 .3589 m
.36216 .32673 L
s
.67405 .35801 m
.67712 .35988 L
s
.68428 .34036 m
.68721 .3376 L
s
.36329 .34531 m
.36466 .35243 L
s
.36758 .35748 m
.37057 .36021 L
s
.36466 .35243 m
.36758 .35748 L
s
.68721 .3376 m
.68865 .33506 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68433 .34266 m
.68726 .33989 L
s
.68856 .33047 m
.6887 .33736 L
s
.67712 .35988 m
.68315 .35901 L
s
.68726 .33989 m
.6887 .33736 L
s
.35704 .35821 m
.36302 .35912 L
s
.68315 .35901 m
.68609 .35625 L
s
.68754 .35371 m
.68893 .34886 L
s
.68893 .34886 m
.68912 .35809 L
s
.3459 .3263 m
.34872 .33141 L
s
.34872 .33141 m
.35009 .33626 L
s
.69879 .32642 m
.70019 .32387 L
s
.69879 .32642 m
.70029 .32846 L
s
.68609 .35625 m
.68754 .35371 L
s
.70019 .32387 m
.70169 .3259 L
s
.68754 .35371 m
.68912 .35809 L
s
.35009 .33626 m
.35141 .34342 L
s
.34161 .32321 m
.3459 .3263 L
s
.34445 .32604 m
.34726 .33116 L
s
.34726 .33116 m
.34862 .33601 L
s
.34862 .33601 m
.34994 .34317 L
s
.34161 .32321 m
.34445 .32604 L
s
.35117 .35496 m
.35141 .34342 L
s
.70029 .32846 m
.70169 .3259 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3497 .35472 m
.34994 .34317 L
s
.32739 .32043 m
.34161 .32321 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34955 .36166 m
.35117 .35496 L
s
.70054 .33998 m
.70261 .36751 L
s
.69969 .368 m
.70054 .33998 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34808 .36142 m
.3497 .35472 L
s
.34798 .36605 m
.34955 .36166 L
s
.33189 .37026 m
.33303 .32157 L
s
.34651 .36581 m
.34808 .36142 L
s
.70084 .35385 m
.70115 .36776 L
s
.33047 .37 m
.33161 .32129 L
s
.34495 .37021 m
.34798 .36605 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34349 .36997 m
.34651 .36581 L
s
.34053 .3718 m
.34495 .37021 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69969 .368 m
.70125 .37241 L
s
.70125 .37241 m
.70261 .36751 L
s
.34053 .3718 m
.34349 .36997 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32621 .3692 m
.34053 .3718 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28296 .31427 m
.28428 .31228 L
s
.2831 .30958 m
.28428 .31228 L
s
.28179 .31156 m
.2831 .30958 L
s
.28179 .31156 m
.28296 .31427 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28178 .35432 m
.2822 .34014 L
s
.28053 .35398 m
.28262 .32601 L
s
.28262 .32601 m
.28303 .35466 L
s
.27206 .30861 m
.27319 .31134 L
s
.27297 .31841 m
.27319 .31134 L
s
.7734 .30621 m
.78503 .30232 L
s
.28164 .35906 m
.28303 .35466 L
s
.26976 .30549 m
.27206 .30861 L
s
.27177 .31803 m
.27304 .31605 L
s
.2717 .32039 m
.27297 .31841 L
s
.26508 .30395 m
.26976 .30549 L
s
.28053 .35398 m
.28164 .35906 L
s
.26932 .31965 m
.27177 .31803 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26925 .32201 m
.2717 .32039 L
s
.27126 .33458 m
.27261 .33021 L
s
.27232 .33968 m
.27261 .33021 L
s
.26332 .32249 m
.26932 .31965 L
s
.26324 .32486 m
.26925 .32201 L
s
.2627 .30553 m
.26508 .30395 L
s
.26999 .33659 m
.27126 .33458 L
s
.27126 .33458 m
.27232 .33968 L
s
.26754 .33823 m
.26999 .33659 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26148 .3075 m
.2627 .30553 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77812 .30468 m
.77969 .35448 L
s
.77695 .30506 m
.77851 .35484 L
s
.2605 .30237 m
.26148 .3075 L
s
.26019 .31184 m
.2605 .30237 L
s
.26019 .31184 m
.26148 .3075 L
s
.78503 .30232 m
.78736 .30389 L
s
.78503 .30232 m
.78848 .30349 L
s
.26286 .33674 m
.26754 .33823 L
s
.77494 .35591 m
.78665 .35228 L
s
.26095 .32409 m
.26332 .32249 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26087 .32647 m
.26324 .32486 L
s
.78736 .30389 m
.78975 .30783 L
s
.25973 .32608 m
.26095 .32409 L
s
.78848 .30349 m
.79086 .30742 L
s
.25965 .32846 m
.26087 .32647 L
s
.26064 .33361 m
.26286 .33674 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25957 .33084 m
.25973 .32608 L
s
.25957 .33084 m
.26064 .33361 L
s
.78975 .30783 m
.79102 .31218 L
s
.79086 .30742 m
.79212 .31177 L
s
.79102 .31218 m
.79235 .31892 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25046 .30108 m
.25247 .30666 L
s
.79212 .31177 m
.79345 .31852 L
s
.24733 .29745 m
.25046 .30108 L
s
.79235 .31892 m
.79275 .33085 L
s
.78665 .35228 m
.78884 .34914 L
s
.78665 .35228 m
.78997 .34876 L
s
.79345 .31852 m
.79385 .33046 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24845 .35194 m
.24886 .35772 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25183 .32572 m
.25191 .32334 L
s
.2509 .32055 m
.25191 .32334 L
s
.24523 .29661 m
.24733 .29745 L
s
.78884 .34914 m
.79093 .34359 L
s
.24949 .32971 m
.25183 .32572 L
s
.24974 .32253 m
.2509 .32055 L
s
.79188 .33841 m
.79275 .33085 L
s
.79093 .34359 m
.79188 .33841 L
s
.78997 .34876 m
.79204 .3432 L
s
.24974 .32253 m
.25074 .32533 L
s
.79299 .33803 m
.79385 .33046 L
s
.24307 .29814 m
.24523 .29661 L
s
.24204 .29771 m
.24523 .29661 L
s
.79204 .3432 m
.79299 .33803 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79712 .29782 m
.80441 .29484 L
s
.24726 .33131 m
.24949 .32971 L
s
.24085 .30206 m
.24307 .29814 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23983 .30163 m
.24204 .29771 L
s
.24408 .33009 m
.24726 .33131 L
s
.23958 .30882 m
.24085 .30206 L
s
.23857 .30839 m
.23983 .30163 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80199 .31524 m
.80327 .32202 L
s
.79826 .33126 m
.80248 .32964 L
s
.80133 .29613 m
.80248 .32964 L
s
.80029 .29656 m
.80144 .33004 L
s
.24207 .32687 m
.24408 .33009 L
s
.24104 .32646 m
.24408 .33009 L
s
.80327 .32202 m
.8055 .326 L
s
.23941 .31361 m
.23958 .30882 L
s
.24018 .32124 m
.24207 .32687 L
s
.23941 .31361 m
.24018 .32124 L
s
.2384 .31319 m
.23857 .30839 L
s
.23916 .32082 m
.24104 .32646 L
s
.2384 .31319 m
.23916 .32082 L
s
.22844 .28912 m
.23511 .29227 L
s
.8055 .326 m
.80762 .32757 L
s
.80762 .32757 m
.81061 .32631 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.231 .32466 m
.23221 .29093 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80945 .32191 m
.81053 .3239 L
s
.80945 .32191 m
.81036 .31908 L
s
.23004 .32423 m
.23125 .29048 L
s
.81036 .31908 m
.81143 .32106 L
s
.81061 .32631 m
.81151 .32348 L
s
.81143 .32106 m
.81151 .32348 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81733 .29629 m
.81807 .29102 L
s
.81733 .29629 m
.8175 .30111 L
s
.81807 .29102 m
.82071 .28723 L
s
.8175 .30111 m
.8186 .30549 L
s
.81825 .29584 m
.81899 .29056 L
s
.81825 .29584 m
.81843 .30066 L
s
.22721 .32293 m
.231 .32466 L
s
.81899 .29056 m
.82071 .28723 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81843 .30066 m
.81952 .30504 L
s
.21868 .28401 m
.22479 .28729 L
s
.82071 .28723 m
.82337 .28583 L
s
.8186 .30549 m
.82143 .30656 L
s
.22942 .34122 m
.23047 .33921 L
s
.2296 .33636 m
.23047 .33921 L
s
.81952 .30504 m
.82143 .30656 L
s
.22856 .33836 m
.2296 .33636 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81896 .31517 m
.81905 .31759 L
s
.81896 .31517 m
.81988 .31473 L
s
.81905 .31759 m
.82005 .31958 L
s
.22856 .33836 m
.22942 .34122 L
s
.82337 .28583 m
.8252 .28732 L
s
.81988 .31473 m
.81997 .31715 L
s
.82143 .30656 m
.82678 .30626 L
s
.82005 .31958 m
.82196 .32112 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21965 .31025 m
.21995 .30794 L
s
.22073 .30941 m
.22085 .30848 L
s
.5 Mabswid
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22113 .31255 m
.22212 .28589 L
s
.22026 .31209 m
.22125 .28542 L
s
.82196 .32112 m
.82551 .31934 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8252 .28732 m
.82709 .29122 L
s
.22007 .31696 m
.22113 .31255 L
s
.82709 .29122 m
.82775 .2859 L
s
.82709 .29122 m
.82791 .31311 L
s
.82775 .2859 m
.82931 .28252 L
s
.2192 .31651 m
.22026 .31209 L
s
.82793 .29075 m
.82858 .28542 L
s
.82793 .29075 m
.82857 .30777 L
s
.82858 .28542 m
.82931 .28252 L
s
.2174 .31804 m
.22007 .31696 L
s
.82931 .28252 m
.83013 .28204 L
s
.82678 .30626 m
.82773 .30823 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82551 .31934 m
.82715 .316 L
s
.2174 .31804 m
.2192 .31651 L
s
.20985 .2787 m
.21536 .2821 L
s
.82715 .316 m
.82791 .31311 L
s
.82791 .31311 m
.82857 .30777 L
s
.21571 .31713 m
.2174 .31804 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21098 .33203 m
.21295 .28065 L
s
.21018 .33158 m
.21216 .28017 L
s
.21334 .31331 m
.21571 .31713 L
s
.21192 .30748 m
.21334 .31331 L
s
.83305 .31524 m
.83847 .31196 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83714 .27765 m
.84139 .31006 L
s
.83542 .31385 m
.83714 .27765 L
s
.8362 .31338 m
.83742 .28498 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20785 .33021 m
.21098 .33203 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20324 .27667 m
.20444 .28258 L
s
.20444 .28258 m
.20486 .29043 L
s
.20466 .29534 m
.20486 .29043 L
s
.20256 .27617 m
.20374 .28208 L
s
.20374 .28208 m
.20415 .28994 L
s
.20132 .2727 m
.20324 .27667 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20366 .30224 m
.20466 .29534 L
s
.20396 .29486 m
.20415 .28994 L
s
0 0 0 r
.84756 .26656 m
.84917 .26215 L
s
.255 .412 .882 r
.84281 .27365 m
.84683 .30619 L
s
.84139 .31006 m
.84281 .27365 L
s
.20132 .2727 m
.20256 .27617 L
s
.20296 .30176 m
.20396 .29486 L
s
.8421 .30958 m
.8431 .28102 L
s
.20207 .30621 m
.20366 .30224 L
s
.19585 .25028 m
.20007 .25398 L
s
.20002 .27168 m
.20132 .2727 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20139 .30572 m
.20296 .30176 L
s
.19865 .27311 m
.20002 .27168 L
s
.19995 .30722 m
.20207 .30621 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19612 .30428 m
.19821 .2524 L
s
.19995 .30722 m
.20139 .30572 L
s
.19551 .30378 m
.19761 .25187 L
s
.19722 .27702 m
.19865 .27311 L
s
.19864 .30625 m
.19995 .30722 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84486 .30765 m
.84873 .30471 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19746 .30278 m
.19864 .30625 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19642 .29683 m
.19746 .30278 L
s
.19347 .26597 m
.19402 .2665 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19374 .30229 m
.19612 .30428 L
s
.85081 .27985 m
.85118 .27438 L
s
.85053 .28781 m
.85081 .27985 L
s
.85118 .27438 m
.85208 .26838 L
s
.85053 .28781 m
.85104 .30024 L
s
.1923 .2674 m
.19347 .26597 L
s
.19283 .26792 m
.19347 .26597 L
s
.85138 .27934 m
.85174 .27386 L
s
.85111 .2873 m
.85138 .27934 L
s
.85174 .27386 m
.85263 .26786 L
s
.85208 .26838 m
.85358 .26432 L
s
.85111 .2873 m
.85162 .29974 L
s
.19209 .27236 m
.19283 .26792 L
s
.85263 .26786 m
.85358 .26432 L
s
.85104 .30024 m
.85192 .30722 L
s
.19157 .27184 m
.1923 .2674 L
s
.85162 .29974 m
.85249 .30672 L
s
.85358 .26432 m
.8546 .26326 L
s
.19138 .28979 m
.19209 .27236 L
s
.19075 .26581 m
.19157 .27184 L
s
.19065 .29427 m
.19157 .27184 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85192 .30722 m
.8527 .31172 L
s
.85249 .30672 m
.85326 .31122 L
s
.8546 .26326 m
.85616 .26415 L
s
.18987 .26226 m
.19075 .26581 L
s
.8527 .31172 m
.85402 .31574 L
s
.19065 .29427 m
.19138 .28979 L
s
.85326 .31122 m
.85457 .31524 L
s
.18846 .26065 m
.18987 .26226 L
s
.19044 .28626 m
.19085 .28927 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18763 .28064 m
.19044 .28626 L
s
.19002 .29626 m
.19065 .29427 L
s
.85616 .26415 m
.8573 .26807 L
s
.85402 .31574 m
.85573 .31676 L
s
.18891 .29774 m
.19002 .29626 L
s
.85457 .31524 m
.85573 .31676 L
s
.18746 .26207 m
.18846 .26065 L
s
.18703 .26153 m
.18846 .26065 L
s
.85698 .26058 m
.85781 .28057 L
s
.8564 .28214 m
.85956 .27846 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85743 .26004 m
.85827 .28005 L
s
.187 .29569 m
.18891 .29774 L
s
.85573 .31676 m
.85676 .31577 L
s
.18682 .26653 m
.18746 .26207 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1821 .30044 m
.18297 .27982 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18684 .27708 m
.18763 .28064 L
s
.1864 .27655 m
.18763 .28064 L
s
.1864 .26599 m
.18703 .26153 L
s
.85676 .31577 m
.85813 .31175 L
s
.18661 .27154 m
.18682 .26653 L
s
.18661 .27154 m
.18684 .27708 L
s
.18619 .271 m
.1864 .26599 L
s
.18621 .29215 m
.187 .29569 L
s
.18619 .271 m
.1864 .27655 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86432 .27027 m
.86503 .28695 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85813 .31175 m
.85886 .3057 L
s
.18599 .28659 m
.18642 .28712 L
s
.18632 .28963 m
.18642 .28712 L
s
.85993 .25679 m
.86242 .25295 L
s
.859 .29763 m
.85963 .31277 L
s
.85886 .3057 m
.859 .29763 L
s
.18588 .28911 m
.18621 .29215 L
s
.18588 .28911 m
.18599 .28659 L
s
.85886 .3057 m
.85963 .31277 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18239 .28238 m
.18253 .27896 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86106 .25515 m
.86254 .29043 L
s
.86141 .2546 m
.8629 .2899 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86462 .26753 m
.86495 .2752 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86141 .292 m
.8629 .2899 L
s
0 0 0 r
.86664 .29505 m
.86702 .29566 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86226 .27474 m
.86293 .28178 L
s
0 0 0 r
.86668 .29468 m
.86702 .29566 L
s
.255 .412 .882 r
.1825 .28185 m
.18275 .28491 L
s
.18264 .28744 m
.18275 .28491 L
s
.18218 .28944 m
.18264 .28744 L
s
.18206 .28385 m
.1825 .28185 L
s
.86293 .28178 m
.8638 .28579 L
s
.18028 .24745 m
.18209 .25135 L
s
.18206 .28385 m
.18229 .28691 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1812 .28786 m
.18218 .28944 L
s
0 0 0 r
.17582 .23565 m
.17669 .23784 L
s
.255 .412 .882 r
.8638 .28579 m
.86454 .28726 L
s
.17975 .2852 m
.18125 .24968 L
s
.18069 .28426 m
.1812 .28786 L
s
.17949 .28467 m
.181 .24913 L
s
0 0 0 r
.17496 .27784 m
.17667 .23796 L
s
.255 .412 .882 r
.86454 .28726 m
.86541 .28567 L
s
.18034 .2781 m
.18069 .28426 L
s
0 0 0 r
.17472 .27729 m
.17645 .23738 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86491 .28111 m
.8653 .28312 L
s
.86491 .28111 m
.86508 .27804 L
s
.18034 .2781 m
.18039 .26994 L
s
.86508 .27804 m
.86546 .28004 L
s
.86541 .28567 m
.86557 .28259 L
s
.86546 .28004 m
.86557 .28259 L
s
.17876 .28306 m
.17975 .2852 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17464 .28514 m
.17465 .28522 L
s
.87006 .24645 m
.87033 .25791 L
s
.87006 .24645 m
.87011 .23805 L
s
.255 .412 .882 r
.86605 .24767 m
.86608 .25331 L
s
.86608 .25331 m
.8663 .2584 L
s
.86605 .24767 m
.86644 .24343 L
s
0 0 0 r
.17495 .27821 m
.17496 .27784 L
s
.87033 .25791 m
.87065 .26519 L
s
.87011 .23805 m
.87042 .23269 L
s
.87025 .24588 m
.87053 .25735 L
s
.87027 .23748 m
.87025 .24588 L
s
.255 .412 .882 r
.8663 .2584 m
.8667 .26294 L
s
.86622 .24711 m
.86627 .25275 L
s
.86627 .25275 m
.86648 .25785 L
s
.86622 .24711 m
.86644 .24343 L
s
0 0 0 r
.17464 .28514 m
.17472 .27729 L
s
.87053 .25735 m
.87084 .26463 L
s
.87042 .23269 m
.87027 .23748 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87065 .26519 m
.87132 .27558 L
s
.255 .412 .882 r
.17825 .26446 m
.17913 .24407 L
s
.86648 .25785 m
.86688 .26239 L
s
.17768 .26225 m
.17879 .26611 L
s
0 0 0 r
.87084 .26463 m
.87151 .27503 L
s
.255 .412 .882 r
.17809 .26391 m
.17897 .2435 L
s
.8667 .26294 m
.86731 .26384 L
s
.86644 .24343 m
.86684 .24173 L
s
0 0 0 r
.87067 .23152 m
.87042 .23269 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86688 .26239 m
.86731 .26384 L
s
.17858 .24492 m
.17864 .25114 L
s
0 0 0 r
.87132 .27558 m
.872 .28181 L
s
.255 .412 .882 r
.86714 .27316 m
.86725 .27572 L
s
.86714 .27316 m
.86732 .27262 L
s
0 0 0 r
.17452 .24366 m
.17457 .23523 L
s
.17419 .25517 m
.17452 .24366 L
s
.87105 .234 m
.87067 .23152 L
s
.87114 .23342 m
.87067 .23152 L
s
.255 .412 .882 r
.86725 .27572 m
.86753 .27774 L
s
.17834 .24066 m
.17858 .24492 L
s
0 0 0 r
.17387 .26247 m
.17419 .25517 L
s
.17457 .23523 m
.17441 .22985 L
s
.87151 .27503 m
.87217 .28126 L
s
.255 .412 .882 r
.86732 .27262 m
.86742 .27518 L
s
0 0 0 r
.17438 .24309 m
.17445 .23465 L
s
.17404 .2546 m
.17438 .24309 L
s
.17373 .26191 m
.17404 .2546 L
s
.255 .412 .882 r
.86753 .27774 m
.86797 .27922 L
s
0 0 0 r
.17445 .23465 m
.17441 .22985 L
s
.17325 .27289 m
.17387 .26247 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86684 .24173 m
.86717 .24315 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87154 .24014 m
.87105 .234 L
s
.17311 .27234 m
.17373 .26191 L
s
.17373 .26191 m
.17278 .25514 L
s
.872 .28181 m
.87263 .28384 L
s
.255 .412 .882 r
.17816 .23952 m
.17834 .24066 L
s
0 0 0 r
.17441 .22985 m
.17426 .22868 L
s
.255 .412 .882 r
.17683 .29783 m
.17749 .28239 L
s
.177 .28957 m
.17749 .28239 L
s
.86717 .24315 m
.86757 .24713 L
s
0 0 0 r
.87161 .23957 m
.87114 .23342 L
s
.87217 .28126 m
.87263 .28384 L
s
.255 .412 .882 r
.86797 .27922 m
.8685 .27705 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17267 .27913 m
.17325 .27289 L
s
.255 .412 .882 r
.17791 .24094 m
.17816 .23952 L
s
.17786 .24037 m
.17816 .23952 L
s
0 0 0 r
.17426 .22868 m
.17394 .23058 L
s
.255 .412 .882 r
.17649 .29365 m
.177 .28957 L
s
.17683 .29783 m
.177 .28957 L
s
0 0 0 r
.17255 .27859 m
.17311 .27234 L
s
.255 .412 .882 r
.86742 .24144 m
.86757 .24713 L
s
0 0 0 r
.87263 .28384 m
.8729 .28275 L
s
.255 .412 .882 r
.86749 .24087 m
.86764 .24657 L
s
.17759 .24494 m
.17791 .24094 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87161 .23957 m
.87215 .24998 L
s
.87154 .24014 m
.87209 .25055 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86757 .24713 m
.86856 .27025 L
s
.86743 .23774 m
.86749 .24087 L
s
.86764 .24657 m
.86842 .26455 L
s
.86742 .24144 m
.86743 .23774 L
s
.86731 .26384 m
.86815 .26309 L
s
0 0 0 r
.17219 .28117 m
.17267 .27913 L
s
.255 .412 .882 r
.86815 .26309 m
.86834 .2651 L
s
.8685 .27705 m
.86859 .27338 L
s
.86743 .23774 m
.86747 .23717 L
s
.86659 .21398 m
.86675 .21809 L
s
.17756 .24437 m
.17786 .24037 L
s
.17602 .29464 m
.17649 .29365 L
s
0 0 0 r
.8729 .28275 m
.87296 .27797 L
s
.8729 .28275 m
.87305 .27742 L
s
.17394 .23058 m
.17358 .23674 L
s
.87241 .2579 m
.87209 .25055 L
s
.17219 .28117 m
.17255 .27859 L
s
.255 .412 .882 r
.86856 .27025 m
.86859 .27338 L
s
0 0 0 r
.87247 .25733 m
.87215 .24998 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87282 .26949 m
.87241 .2579 L
s
.87296 .27797 m
.87282 .26949 L
s
.255 .412 .882 r
.86842 .26455 m
.86856 .27025 L
s
.17734 .24951 m
.17759 .24494 L
s
0 0 0 r
.87289 .26894 m
.87247 .25733 L
s
.87305 .27742 m
.87289 .26894 L
s
.87109 .22096 m
.87134 .22509 L
s
.255 .412 .882 r
.17732 .24895 m
.17756 .24437 L
s
0 0 0 r
.17196 .27952 m
.17219 .28117 L
s
.255 .412 .882 r
.17602 .29464 m
.17584 .29358 L
s
.17698 .25668 m
.17734 .24951 L
s
.17697 .25612 m
.17732 .24895 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86673 .21575 m
.86905 .26993 L
s
.86675 .21633 m
.86907 .27048 L
s
.17584 .29358 m
.17581 .28991 L
s
.17584 .29358 m
.17575 .28938 L
s
0 0 0 r
.1728 .2557 m
.17231 .26677 L
s
.255 .412 .882 r
.17643 .2696 m
.17698 .25668 L
s
0 0 0 r
.17203 .27472 m
.17196 .27952 L
s
.17278 .25514 m
.17245 .26252 L
s
.255 .412 .882 r
.17642 .26905 m
.17697 .25612 L
s
.17581 .28991 m
.17593 .28365 L
s
0 0 0 r
.17231 .26677 m
.17203 .27472 L
s
.17215 .27047 m
.17203 .27472 L
s
.17245 .26252 m
.17215 .27047 L
s
.255 .412 .882 r
.86753 .23515 m
.86783 .24146 L
s
.17575 .28938 m
.17589 .28311 L
s
.17612 .27792 m
.17643 .2696 L
s
.17593 .28365 m
.17612 .27792 L
s
.86905 .26993 m
.86907 .27213 L
s
.8673 .23142 m
.86753 .23515 L
s
.17609 .27738 m
.17642 .26905 L
s
.17589 .28311 m
.17609 .27738 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87127 .22273 m
.87465 .30061 L
s
.8713 .22332 m
.87469 .30115 L
s
.255 .412 .882 r
.86714 .23027 m
.8673 .23142 L
s
.86872 .26214 m
.86887 .26623 L
s
0 0 0 r
.1738 .23209 m
.17429 .22354 L
s
.17326 .24375 m
.1738 .23209 L
s
.17429 .22354 m
.17478 .21808 L
s
.17293 .25115 m
.17326 .24375 L
s
.17388 .23151 m
.17439 .22295 L
s
.17332 .24318 m
.17388 .23151 L
s
.255 .412 .882 r
.86705 .2317 m
.86714 .23027 L
s
.86693 .23113 m
.86714 .23027 L
s
0 0 0 r
.17439 .22295 m
.17478 .21808 L
s
.173 .25058 m
.17332 .24318 L
s
.255 .412 .882 r
.17677 .26613 m
.17636 .26944 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17252 .26172 m
.17293 .25115 L
s
.86962 .21445 m
.87071 .2186 L
s
.255 .412 .882 r
.86886 .26772 m
.86887 .26623 L
s
.17652 .26779 m
.17844 .22918 L
s
0 0 0 r
.17259 .26116 m
.173 .25058 L
s
.17478 .21808 m
.17506 .21689 L
s
.255 .412 .882 r
.86702 .23574 m
.86705 .2317 L
s
.86688 .23517 m
.86693 .23113 L
s
0 0 0 r
.17236 .26805 m
.17252 .26172 L
s
.255 .412 .882 r
.8687 .26662 m
.86886 .26772 L
s
0 0 0 r
.17506 .21689 m
.17522 .21941 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87031 .21682 m
.87372 .29524 L
s
.17245 .26749 m
.17259 .26116 L
s
.255 .412 .882 r
.86702 .23574 m
.86721 .24297 L
s
0 0 0 r
.87015 .21623 m
.87356 .2947 L
s
.255 .412 .882 r
.86839 .2629 m
.8687 .26662 L
s
.86827 .26235 m
.8687 .26662 L
s
0 0 0 r
.87449 .29901 m
.87469 .30115 L
s
.255 .412 .882 r
.86706 .2424 m
.86688 .23517 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17726 .26392 m
.17781 .24623 L
s
.17741 .26337 m
.17793 .24603 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17522 .21941 m
.17526 .22566 L
s
.17252 .27011 m
.17236 .26805 L
s
.255 .412 .882 r
.86721 .24297 m
.86744 .24818 L
s
.86791 .25657 m
.86839 .2629 L
s
0 0 0 r
.17252 .27011 m
.17245 .26749 L
s
.17574 .21452 m
.17661 .21215 L
s
.255 .412 .882 r
.86744 .24818 m
.86791 .25657 L
s
.86706 .2424 m
.86729 .24762 L
s
.86777 .25601 m
.86827 .26235 L
s
.86729 .24762 m
.86777 .25601 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17741 .26337 m
.17848 .24512 L
s
0 0 0 r
.1728 .269 m
.17252 .27011 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17328 .26413 m
.1728 .269 L
s
.17397 .25552 m
.17328 .26413 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86873 .22207 m
.86947 .23387 L
s
.86786 .21343 m
.86873 .22207 L
s
.8668 .20792 m
.86786 .21343 L
s
.86947 .23387 m
.8698 .24136 L
s
.86847 .22149 m
.86922 .23329 L
s
.86757 .21284 m
.86847 .22149 L
s
.87303 .29308 m
.87372 .29524 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17253 .29261 m
.17594 .21393 L
s
.17234 .29315 m
.17574 .21452 L
s
.8668 .20792 m
.86757 .21284 L
s
.86922 .23329 m
.86954 .24079 L
s
.17181 .29477 m
.17253 .29261 L
s
.17745 .22039 m
.17839 .21173 L
s
.17668 .2322 m
.17745 .22039 L
s
.86614 .20673 m
.8668 .20792 L
s
.17839 .21173 m
.17955 .20621 L
s
.17636 .23971 m
.17668 .2322 L
s
.17775 .2198 m
.17871 .21114 L
s
.17697 .23163 m
.17775 .2198 L
s
.17871 .21114 m
.17955 .20621 L
s
.17665 .23914 m
.17697 .23163 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86954 .24079 m
.86976 .25149 L
s
.8698 .24136 m
.87003 .25205 L
s
.86981 .25846 m
.87003 .25205 L
s
.17616 .25043 m
.17636 .23971 L
s
.8656 .2093 m
.86614 .20673 L
s
.86523 .20871 m
.86614 .20673 L
s
.86952 .2579 m
.86976 .25149 L
s
.17955 .20621 m
.18028 .20503 L
s
.17646 .24986 m
.17665 .23914 L
s
.17665 .23914 m
.181 .23227 L
s
.86517 .21563 m
.8656 .2093 L
s
.17616 .25043 m
.17645 .25685 L
s
.18028 .20503 m
.18129 .20701 L
s
.86906 .26057 m
.86981 .25846 L
s
.86478 .21505 m
.86523 .20871 L
s
.17646 .24986 m
.17677 .25629 L
s
.86906 .26057 m
.86952 .2579 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86517 .21563 m
.86526 .22636 L
s
.17645 .25685 m
.17729 .25896 L
s
.18129 .20701 m
.18181 .21337 L
s
.8684 .25945 m
.86906 .26057 L
s
.86478 .21505 m
.86485 .22578 L
s
.17677 .25629 m
.17729 .25896 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18664 .21443 m
.18666 .21447 L
s
.18667 .21357 m
.18711 .2139 L
s
0 0 0 r
.86526 .22636 m
.86558 .23391 L
s
.86754 .25454 m
.8684 .25945 L
s
.86717 .25398 m
.8684 .25945 L
s
.17729 .25896 m
.17839 .25729 L
s
.86485 .22578 m
.86518 .23334 L
s
.86558 .23391 m
.86646 .24584 L
s
.86646 .24584 m
.86754 .25454 L
s
.255 .412 .882 r
.18666 .21447 m
.18689 .21919 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86518 .23334 m
.86607 .24527 L
s
.86607 .24527 m
.86717 .25398 L
s
.255 .412 .882 r
.18596 .23047 m
.18599 .23036 L
s
0 0 0 r
.18009 .24422 m
.18057 .23284 L
s
.255 .412 .882 r
.18667 .22449 m
.18689 .21919 L
s
0 0 0 r
.17839 .25729 m
.17935 .25238 L
s
.18068 .23985 m
.181 .23227 L
s
.255 .412 .882 r
.18599 .23036 m
.18667 .22449 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17935 .25238 m
.18009 .24422 L
s
.17935 .25238 m
.17993 .24801 L
s
.17993 .24801 m
.18068 .23985 L
s
.255 .412 .882 r
.1853 .24642 m
.18532 .24631 L
s
0 0 0 r
.18558 .19794 m
.18578 .20492 L
s
.18494 .21308 m
.18558 .19794 L
s
.255 .412 .882 r
.18555 .24098 m
.186 .24043 L
s
.18544 .24364 m
.18555 .24098 L
s
0 0 0 r
.85938 .20106 m
.86073 .2098 L
s
.86073 .2098 m
.86171 .22175 L
s
.255 .412 .882 r
.18532 .24631 m
.18589 .24309 L
s
.186 .24043 m
.18589 .24309 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8576 .19552 m
.85938 .20106 L
s
.255 .412 .882 r
.85649 .22783 m
.85723 .2456 L
s
.85703 .22911 m
.85774 .24615 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86171 .22175 m
.86203 .22935 L
s
.85885 .20048 m
.86022 .20922 L
s
.86022 .20922 m
.86121 .22118 L
s
.18494 .21308 m
.18578 .20492 L
s
.18578 .20492 m
.18647 .20055 L
s
.85034 .16308 m
.85477 .16728 L
s
.18647 .20055 m
.18772 .19559 L
s
.8576 .19552 m
.85885 .20048 L
s
.86121 .22118 m
.86153 .22878 L
s
.86201 .24021 m
.86203 .22935 L
s
.255 .412 .882 r
.85723 .2456 m
.85847 .24698 L
s
0 0 0 r
.18772 .19559 m
.19004 .19325 L
s
.85646 .19435 m
.8576 .19552 L
s
.86151 .23965 m
.86153 .22878 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86131 .24674 m
.86201 .24021 L
s
.18398 .2359 m
.18466 .23152 L
s
.18366 .24354 m
.18398 .2359 L
s
.18466 .23152 m
.18589 .22658 L
s
.18382 .23972 m
.1845 .23534 L
s
.86078 .24618 m
.86151 .23965 L
s
.1845 .23534 m
.18573 .23039 L
s
.18366 .24354 m
.18401 .2468 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85543 .19698 m
.85646 .19435 L
s
.19004 .19325 m
.19111 .19589 L
s
.18589 .22658 m
.18909 .2161 L
s
.255 .412 .882 r
.85852 .26491 m
.85863 .26431 L
s
0 0 0 r
.85452 .20344 m
.85543 .19698 L
s
.18573 .23039 m
.18893 .21992 L
s
.18401 .2468 m
.18493 .24953 L
s
.85984 .24891 m
.86131 .24674 L
s
.255 .412 .882 r
.85822 .26334 m
.85852 .26491 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85984 .24891 m
.86078 .24618 L
s
.19111 .19589 m
.19158 .19912 L
s
.18909 .2161 m
.19048 .21114 L
s
.18493 .24953 m
.18721 .24733 L
s
.19111 .21057 m
.19158 .19912 L
s
.18893 .21992 m
.19032 .21497 L
s
.19048 .21114 m
.19127 .20675 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8587 .24781 m
.85984 .24891 L
s
.85231 .16488 m
.85563 .24507 L
s
.85294 .16548 m
.85627 .24561 L
s
.19032 .21497 m
.19111 .21057 L
s
.85734 .24286 m
.8587 .24781 L
s
.84568 .18507 m
.85007 .18853 L
s
.18721 .24733 m
.18858 .24238 L
s
.85579 .23407 m
.85734 .24286 L
s
.18858 .24238 m
.18936 .23798 L
s
.18936 .23798 m
.19032 .22974 L
s
.18968 .24513 m
.19032 .22974 L
s
.18936 .23798 m
.18968 .24513 L
s
.19649 .19127 m
.19737 .18687 L
s
.19649 .19127 m
.19706 .19453 L
s
.19737 .18687 m
.19795 .19012 L
s
.85365 .24343 m
.85627 .24561 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84613 .25308 m
.84792 .1868 L
s
.8466 .26482 m
.84865 .18737 L
s
.19706 .19453 m
.19795 .19012 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19512 .25968 m
.19628 .21373 L
s
.19365 .26074 m
.19628 .21373 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8401 .2037 m
.84737 .20869 L
s
.255 .412 .882 r
.20563 .19808 m
.20594 .19693 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19438 .26021 m
.19533 .2369 L
s
.255 .412 .882 r
.837 .19791 m
.83701 .19782 L
s
.837 .19791 m
.83702 .19802 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83565 .17828 m
.84087 .18166 L
s
.19365 .26074 m
.19406 .26801 L
s
.255 .412 .882 r
.83775 .21687 m
.83776 .21693 L
s
0 0 0 r
.19406 .26801 m
.19512 .25968 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83785 .21959 m
.83787 .21965 L
s
.83594 .21308 m
.83775 .21687 L
s
.83817 .22775 m
.83819 .22771 L
s
.83605 .2158 m
.83785 .21959 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83744 .1794 m
.8466 .26482 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72062 .17305 m
.72062 .17303 L
s
.71886 .17269 m
.71905 .17169 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71886 .17269 m
.71892 .17476 L
s
.72062 .17305 m
.72067 .17505 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66672 .16405 m
.66689 .16399 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66672 .16405 m
.66686 .16397 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39003 .127 m
.42296 .12346 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42087 .12365 m
.42265 .14807 L
s
.62426 .12363 m
.62641 .12791 L
s
.62222 .12753 m
.62426 .12363 L
s
.42265 .14807 m
.42296 .12346 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62437 .13181 m
.62641 .12791 L
s
.62222 .12753 m
.62437 .13181 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39472 .21284 m
.3961 .12626 L
s
.39678 .21262 m
.39814 .12602 L
s
.60099 .12174 m
.60951 .12237 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40959 .18642 m
.41006 .15337 L
s
.44624 .12571 m
.45056 .12132 L
s
.45056 .12132 m
.45486 .12106 L
s
.4441 .12585 m
.45056 .12132 L
s
.44188 .13422 m
.4441 .12585 L
s
.59241 .12117 m
.59675 .12555 L
s
.58811 .12091 m
.59241 .12117 L
s
.44402 .13407 m
.44624 .12571 L
s
.45486 .12106 m
.4613 .12479 L
s
.39743 .17115 m
.40982 .16986 L
s
.59675 .12555 m
.60111 .13405 L
s
.255 .412 .882 r
.56695 .13264 m
.56992 .13276 L
s
0 0 0 r
.46566 .12046 m
.47434 .12006 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58166 .12466 m
.58811 .12091 L
s
.58382 .12477 m
.58811 .12091 L
s
.4613 .12479 m
.46557 .13278 L
s
.57955 .13277 m
.58382 .12477 L
s
.57738 .13267 m
.58166 .12466 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42961 .16075 m
.43013 .16299 L
s
.42751 .16086 m
.42768 .16161 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44141 .17967 m
.44188 .13422 L
s
.46524 .17831 m
.46566 .12046 L
s
.44356 .17953 m
.44402 .13407 L
s
.46743 .17821 m
.46783 .12035 L
s
.54893 .11933 m
.56424 .11979 L
s
.49179 .12356 m
.49619 .11934 L
s
.49619 .11934 m
.50058 .11925 L
s
.4896 .12362 m
.49619 .11934 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50058 .11925 m
.50716 .12325 L
s
.52476 .11903 m
.54015 .11916 L
s
.57746 .14503 m
.57955 .13277 L
s
.48519 .13198 m
.4896 .12362 L
s
.48738 .13191 m
.49179 .12356 L
s
.57529 .14493 m
.57738 .13267 L
s
.50716 .12325 m
.51155 .13143 L
s
.48294 .14443 m
.48519 .13198 L
s
.48513 .14435 m
.48738 .13191 L
s
.57746 .14503 m
.57752 .1533 L
s
.57529 .14493 m
.57534 .1532 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62495 .17714 m
.62527 .20209 L
s
.62315 .20191 m
.62463 .15235 L
s
.62463 .15235 m
.62738 .20227 L
s
.38858 .21351 m
.42187 .21028 L
s
.4829 .1527 m
.48294 .14443 L
s
.48509 .15262 m
.48513 .14435 L
s
.41975 .21046 m
.42218 .18528 L
s
.42187 .21028 m
.42218 .18528 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57534 .1532 m
.57761 .16573 L
s
.57752 .1533 m
.57979 .16583 L
s
.59721 .17508 m
.60144 .16706 L
s
.55768 .11957 m
.55794 .17747 L
s
.5555 .1195 m
.55574 .17741 L
s
.4829 .1527 m
.48503 .16506 L
s
.43499 .18012 m
.44356 .17953 L
s
.48509 .15262 m
.48723 .165 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59292 .17898 m
.59721 .17508 L
s
.57979 .16583 m
.5842 .17435 L
s
.57761 .16573 m
.58203 .17424 L
s
.62538 .21044 m
.62738 .20227 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60312 .12189 m
.60401 .20885 L
s
.60099 .12174 m
.60185 .20871 L
s
.5093 .15625 m
.5115 .16038 L
s
.50709 .16043 m
.5093 .15625 L
s
.58859 .17873 m
.59292 .17898 L
s
.62315 .20191 m
.62538 .21044 L
s
.5842 .17435 m
.58859 .17873 L
s
.48503 .16506 m
.4894 .17325 L
s
.58203 .17424 m
.58859 .17873 L
s
.50709 .16043 m
.50929 .16455 L
s
.48723 .165 m
.4916 .17319 L
s
.5115 .16453 m
.5115 .16038 L
s
.45871 .17863 m
.46743 .17821 L
s
.50706 .1729 m
.5115 .16453 L
s
.4894 .17325 m
.496 .17725 L
s
.4916 .17319 m
.496 .17725 L
s
.50263 .17713 m
.50706 .1729 L
s
.54912 .17725 m
.55794 .17747 L
s
.496 .17725 m
.50263 .17713 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53355 .11908 m
.53367 .2063 L
s
.53136 .11906 m
.53145 .20628 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59535 .20832 m
.60401 .20885 L
s
.55582 .19829 m
.55805 .20254 L
s
.55363 .20243 m
.55582 .19829 L
s
.55586 .20668 m
.55805 .20254 L
s
.55363 .20243 m
.55586 .20668 L
s
.52478 .20625 m
.53367 .2063 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00@0[Jf]0?nV403oYQ00ojH@
0`00000;0?nV40T000000`3oYQ04000001`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V
0@3oool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00P0ojHA100000040?nV4@D000002@2]
[Jd010000000[Jf]0:f][@2][Jd2000000d0[Jf]0P00000:0:f][@D00000202][Jd30?nU40<00000
2@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ420:f][@030000002][Jd0[Jf]0080[Jf]0P0000020:f][@8000000P2]
[Jd70?nV4@040:f][@3oYQ000000000000D0ojH@0P00000;0?nV408000001`3oYQ000`2][Jd0ojD@
0?nU4002000000/0ojD@00<0[Jf]0000000000000`2][Jd00`000000[Jf]0:f][@06000000D0[Jf]
5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0
1`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0@0?nV4@T000002@2][Jd00`3oYQ4000000000
00060?nV4@040000003oYQ400000000000T0ojHA00<0[Jf]0000000000001`3oYQ000`000000ojH@
0?nV40090?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002000000/0ojD@0P0000040?nU40030000
003oYA00ojD@00800000103oYA000`2][Jd0oj<@0?nS40020?nS40030:f][@000000[Jf]00H0[Jf]
3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0
2P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@070?nV4@T000001P2][Jd01@3oYQ4000000000
003oYQ40[Jf]00L0ojHA0P0000070?nV4@040000003oYQ400000000000T0ojHA0P0000090?nV4003
0000003oYQ00ojH@00P0ojH@0P0000070?nV40030:f][@3oYA00ojD@008000002P3oYA02000000H0
ojD@00@000000?nU400000000000103oYA000`2][Jd0oj<@0?nS40020?nS408000001`3oXa0:0:f]
[@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ480:f][@8000002`3oYQ4200000003
0?nV4@2][Jd0ojHA00H0ojHA0P0000080?nV4@<000002@3oYQ42000000T0ojH@00<000000?nV403o
YQ00203oYQ02000000L0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU408000001P3oYA0010000000
ojD@0000000000040?nU40030:f][@3oXa00oj<@0080oj<@00<000000?nS40000000403oXa070:f]
[AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?oo
o`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@L0
[Jf]203oYQ42000000/0ojHA0P0000000`3oYQ40[Jf]0?nV4@050?nV4@8000002@3oYQ43000000P0
ojHA0P00000;0?nV40030000003oYQ00ojH@00L0ojH@0P0000070?nV40030:f][@3oYA00ojD@0080
00002@3oYA02000000P0ojD@0`0000040?nU40030:f][@3oXa00oj<@0080oj<@0P00000E0?nS4003
0:f][@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100
k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA0100ojHA1@2][Jd20?nV4@030:f][@3oYQ40ojHA00X0ojHA0P00000;0?nV4@800000
00<0ojHA0:f][@3oYQ401@3oYQ42000000X0ojHA0P0000080?nV4@8000005@3oYQ02000000L0ojH@
00<0[Jf]0?nU403oYA000P0000050?nU4004045Yh@3oYA00ojD@0?nU40800000203oYA03000000@0
ojD@00<0[Jf]0?nS403oXa000`3oXa000`000000oj<@0?nS400C0?nS40030:f][@3lX100o:0@00H0
o:0@1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0
fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]1`3oYQ400`2][Jd0ojHA
0?nV4@0:0?nV4@8000002`3oYQ42000000030?nV4@2][Jd0ojHA00D0ojHA0P00000:0?nV4@800000
203oYQ42000001D0ojH@0P0000070?nV40030:f][@3oYA00ojD@008000002@3oYA02000000T0ojD@
0P0000040?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1002`3lX1050:f][@P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=
0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0[Jf]0?nV4@3oYQ402P3o
YQ42000000/0ojHA0P0000000`3oYQ40[Jf]0?nV4@050?nV4@8000002P3oYQ42000000P0ojHA0P00
000E0?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002000000P0ojD@00<000000?nU400000002@3o
YA02000000@0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400@0?bP40H0[Jf]0P3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103K
RPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@2][JdB0?nV4@030:f][@3oYQ40
ojHA00X0ojHA0P00000<0?nV4@030000003oYQ40[Jf]00H0ojHA0P00000:0?nV4@8000001`3oYQ42
000000030:f][@3oYQ00ojH@01<0ojH@0P0000070?nV40030:f][@3oYA00ojD@00800000203oYA02
000000X0ojD@0P0000040?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005P3lX104
0:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@060=^:3@80[Jf]E`2`h>H1
0?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@@0[Jf]5`3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@800000303oYQ400`000000ojHA0:f][@060?nV
4@8000002P3oYQ42000000L0ojHA0P0000000`2][Jd0ojH@0?nV400C0?nV408000001`3oYQ000`2]
[Jd0ojD@0?nU4002000000P0ojD@0P00000:0?nU40800000103oYA000`2][Jd0oj<@0?nS400I0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ402P3oYQ42000000`0ojHA00<000000:f][@3oYQ401P3oYQ42000000X0
ojHA0P0000070?nV4@80000000<0[Jf]0?nV403oYQ004`3oYQ02000000L0ojH@00<0[Jf]0?nU403o
YA000P0000070?nU40030000003oYA00000000X0ojD@0P0000040?nU40030:f][@3oXa00oj<@01T0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]3@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]
2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ402P3oYQ42000000`0ojHA00<000000:f][@3oYQ40
1P3oYQ42000000X0ojHA0P0000070?nV4@80000000<0[Jf]0?nV403oYQ004`3oYQ02000000L0ojH@
00<0[Jf]0?nU403oYA000P0000070?nU40030000003oYA00000000X0ojD@0P0000040?nU40030:f]
[@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]
2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0
D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0:0?nV4@800000303oYQ400`000000[Jf]0?nV4@060?nV4@8000002P3oYQ42000000L0ojHA0P00
00000`2][Jd0ojH@0?nV400C0?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002000000L0ojD@00<0
00000?nU400000002P3oYA02000000@0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0:0?nV4@800000303oYQ400`000000[Jf]0?nV4@060?nV4@8000002P3oYQ42
000000H0ojHA00@000000?nV4@000000[Jf]5@3oYQ02000000L0ojH@00<0[Jf]0?nU403oYA000P00
00070?nU40030000003oYA00000000X0ojD@0P0000040?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]
0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00X0ojHA0P00000=0?nV4@030:f][@3oYQ40
ojHA00D0ojHA0P00000:0?nV4@8000001P3oYQ4010000000ojHA0000002][JdE0?nV408000001`3o
YQ000`2][Jd0ojD@0?nU4002000000P0ojD@0P00000:0?nU40800000103oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][A40k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3C
Q`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000001@3oYQ400`000000ojHA0?nV4@050?nV4@030:f]
[@3oYQ40ojHA00D0ojHA0P00000:0?nV4@8000001P3oYQ4010000000ojHA0000002][JdE0?nV4080
00001`3oYQ000`2][Jd0ojD@0?nU4002000000P0ojD@0P00000:0?nU40800000103oYA000`2][Jd0
oj<@0?nS40030?nS40030000003oXa00oj<@01@0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@05
0:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]
00d0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000001@3oYQ400`000000ojHA0?nV4@050?nV
4@030:f][@3oYQ40ojHA00D0ojHA0P00000:0?nV4@8000001P3oYQ4010000000ojHA0000002][JdE
0?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002000000P0ojD@0P00000:0?nU40800000103oYA00
0`2][Jd0oj<@0?nS40030?nS40030000003oXa00oj<@01@0oj<@00<0[Jf]0?bP403lX1005`3lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>7
3P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP
40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0:0?nV
4@8000001@3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000:0?nV
4@8000000P3oYQ450:f][@8000002`2][Jd00`000000[Jf]0:f][@080:f][@8000002P2][Jd20000
00<0[Jf]1@3oYA02000000X0ojD@0P0000040?nU40030:f][@3oXa00oj<@00<0oj<@00<000000?nS
403oXa00503oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue
2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000001@3oYQ400`000000
ojHA0?nV4@050?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000:0:f][@8000000P2][Jd50?nV4@80
000000<0[Jf]0?nV403oYQ001`3oYQ02000000X0ojH@0P0000070?nV40030:f][@3oYA00ojD@0080
00000`3oYA050:f][@8000002@2][Jd00`3oYA000000000000040?nU40030:f][@3oXa00oj<@00<0
oj<@00<000000?nS403oXa00503oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0
103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@800000
1@3oYQ4010000000ojHA0?nV4@3oYQ4<0:f][@8000002P3oYQ42000000L0ojHA00<000000?nV4@00
00002@3oYQ000`000000ojH@000000090?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002000000T0
ojD@0P0000080?nU40030:f][@000000000000T0[Jf]00<0oj<@0000003oXa005@3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0
/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f]
[@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ402P3oYQ42000000D0[Jf]00@000000:f][@2][Jd0[Jf]103oYQ400`2]
[Jd0@FWQ0?nV4@050?nV4@8000002P3oYQ42000000P0ojHA0P0000090?nV40030000003oYQ000000
00T0ojH@0P0000070?nV40030:f][@3oYA00ojD@008000002@3oYA02000000T0ojD@0P0000040?nU
40030:f][@3oXa00oj<@0080oj<@00<0[Jf]0000002][Jd01`2][Jd>0?nS40030:f][@3lX100o:0@
01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f]
[@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`040000002iM@/0^GD;0:f][DP0/>3V0@3oool0
05h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]
0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40
ojHA0080ojHA202][Jd2000000D0ojHA00<000000?nV4@3oYQ401@3oYQ400`2][Jd0ojHA0?nV4@05
0?nV4@8000002P3oYQ42000000P0ojHA0P00000:0?nV408000002@3oYQ02000000L0ojH@00<0[Jf]
0?nU403oYA000P0000090?nU408000002@3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000`3oXa00
0`000000oj<@0?nS40060?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/2
00000080[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f]
[A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]203oYQ420000
00D0ojHA00<000000?nV4@3oYQ401@3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002P3oYQ420000
00P0ojHA0P00000:0?nV40030000003oYQ00ojH@00P0ojH@0P0000070?nV40030:f][@3oYA00ojD@
008000002@3oYA02000000T0ojD@0`0000030?nU40030:f][@3oXa00oj<@00<0oj<@00<000000?nS
403oXa00403oXa080:f][AH0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0000000<0[Jf]0;3PiP2`h>H0A@2`h>H10?oo
o`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A40o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@H0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@80
00001@3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000:0?nV4@80
00002@3oYQ42000000T0ojH@00<000000?nV403oYQ00203oYQ02000000L0ojH@00<0[Jf]0?nU403o
YA000P0000090?nU40800000203oYA0010000000ojD@0000000000030?nU40030:f][@3oXa00oj<@
00<0oj<@00<000000?nS403oXa00503oXa00102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]2@3KRPd0
0`2][Jd0^GD;0;Ue2`050;Ue2`80000000<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2]
[Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203oYQ400`2]
[Jd0ojHA0?nV4@0:0?nV4@P000001`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002P3oYQ420000
00T0ojHA0P0000080?nV40030000003oYQ00ojH@00T0ojH@0P0000070?nV40030:f][@3oYA00ojD@
008000002P3oYA02000000L0ojD@00@000000?nU4000000000000`3oYA000`2][Jd0oj<@0?nS4003
0?nS40030000003oXa00oj<@01@0oj<@00<0[Jf]0?bP403lX1001`3lX1070:f][@P0o:0@00<0@FWQ
0:f][@3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd7
0=^:3@030:f][@2iM@/0^GD;00D0^GD;0P0000000`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3P
iP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0ojHA1@2][Jd=
0?nV4@030:f][@3oYQ40ojHA00X0ojHA0P0000050?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]
0?nV4@3oYQ401@3oYQ42000000X0ojHA0P0000090?nV4@030:f][@000000000000L0ojH@00<00000
0?nV403oYQ002@3oYQ02000000L0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU408000001P3oYA00
0`000000ojD@0?nU4002000000<0ojD@00<0[Jf]0?nS403oXa000`3oXa000`000000oj<@0?nS400D
0?nS40030:f][@3lX100o:0@00h0o:0@1P2][Jd20?bP4003045Yh@2][Jd0mY`?01D0mY`?00<0[Jf]
0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]
0;Ue2`2iM@/01@2iM@/2000000040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]
09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40040>nH40030:f][@3_V100kiP@00@0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0[Jf]4P3o
YQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000001@3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3o
YQ40ojHA00D0ojHA0P00000:0?nV4@8000002@3oYQ40102][Jd0ojH@0000000000040?nV40800000
303oYQ02000000L0ojH@00<0[Jf]0?nU403oYA000P00000;0?nU408000001@3oYA000`000000ojD@
0?nU4002000000<0ojD@00<0[Jf]0?nS403oXa000`3oXa000`000000oj<@0?nS400D0?nS40030:f]
[@3lX100o:0@01@0o:0@1@2][JdE0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0
1@3KRPd20:f][@@0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/2000000050:f][@28EPL0R5H708QF1`2]
[Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_
V1000P3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0B0?nT4@@0
[Jf]603oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000001@3oYQ400`000000ojHA0?nV4@050?nV4@03
0:f][@3oYQ40ojHA00D0ojHA0P00000:0?nV4@8000002@3oYQ40102][Jd0ojH@0?nV403oYQ040000
00h0ojH@0P0000060?nV40H00000303oYA02000000<0ojD@00@000000?nU403oYA00ojD@0P000003
0?nU40030:f][@3oXa00oj<@00<0oj<@00<000000?nS403oXa00503oXa000`2][Jd0o:0@0?bP400G
0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0
fhX=00L0fhX=0P2][Jd20=^:3@030:f][@2iM@/0^GD;00D0^GD;0P0000001@2][Jd0R5H708QF1`28
EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_
V100kiP@0080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00h0oj@A102]
[Jd00`3oY140[Jf]0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00X0ojHA0P0000050?nV4@030000003o
YQ40ojHA00D0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000H0ojHA1P0000090?nV4@030:f][@3o
YQ00ojH@01<0ojH@0P0000070?nV40030:f][@3oYA00ojD@0100ojD@0`0000040?nU408000000`3o
YA000`2][Jd0oj<@0?nS40020?nS40<000005@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02@3K
RPd20:f][@8000001P2iM@/2000000030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0`2][Jd;
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402P3oY1440:f][@D0oj@A00<0[Jf]
0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000001@3oYQ400`000000ojHA0?nV4@05
0?nV4@030:f][@3oYQ40ojHA0080ojHA0`00000G0?nV4@030:f][@3oYQ00ojH@01<0ojH@0P000007
0?nV40030:f][@3oYA00ojD@01L0ojD@0P0000030?nU40030:f][@3oXa00oj<@0080oj<@0`00000E
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0[Jf]
0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@0000000000000000@0^GD;0P00
00000`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@070?nT4@<0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3o
YQ40ojHA00X0ojHA0P0000050?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400C0?nV408000001`3oYQ000`2][Jd0ojD@0?nU400G0?nU408000000`3o
YA000`2][Jd0oj<@0?nS40020?nS40<000005@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd000000;Ue2`050;Ue2`80000000<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3P
iP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h20:f][@`0kiP@00<0
[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]303oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA00X0ojHA0P0000050?nV4@030000003oYQ40ojHA00<0ojHA00<0
00000?nV4@2][Jd07P3oYQ400`2][Jd0ojH@0?nV400C0?nV408000001`3oYQ000`2][Jd0ojD@0?nU
400G0?nU408000000`3oYA000`2][Jd0oj<@0?nS40020?nS40<000005@3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00H0[Jf]0000002][Jd0[Jf]0;Ue2`0000020;Ue2`80000000<0[Jf]08QF1`28
EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd0103CQ`h01P000000dhL>0:f][@2][Jd0dhL>0:f][@`0kiP@00<0[Jf]0?bP403lX100403lX100
0`2][Jd0oj@A0:f][@030:f][A00oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0;
0?nV4@8000001@3oYQ400`000000ojHA0?nV4@030?nV4@030000003oYQ40[Jf]01h0ojHA00<0[Jf]
0?nV403oYQ004`3oYQ02000000L0ojH@00<0[Jf]0?nU403oYA005`3oYA02000000<0ojD@00<0[Jf]
0?nS403oXa000P3oXa03000001D0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@060:f][@000000^GD;0;Ue2`2][Jd0^GD;
0P0000000`2iM@/000000:f][@0408QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P030000002][Jd0dhL>0080dhL>00<0[Jf]0>nH403_V100
2P3_V1000`2][Jd0o:0@0?bP400?0?bP40<0[Jf]503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA00/0ojHA0P00000;0?nV4@030000003oYQ40[Jf]01h0ojHA00<0[Jf]0?nV403oYQ00
4`3oYQ02000000L0ojH@00<0[Jf]0?nU403oYA005`3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00
0P3oXa03000001D0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/000000080^GD;
00H0[Jf]000000000000^GD;0000002][Jd408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00@0dhL>0P0000030=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP
403lX100303lX1030:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0;0?nV4@8000002`3oYQ400`000000ojHA0:f][@0N0?nV4@030:f][@3oYQ00ojH@
01<0ojH@0P0000070?nV40030:f][@3oYA00ojD@01L0ojD@0P0000030?nU40030:f][@3oXa00oj<@
0080oj<@0`00000E0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/00000
00<0^GD;0P0000000`2iM@/000000:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H02P2][Jd0
Uf0;09MP2`2GH0/0[Jf]0=>73P000000dhL>0:f][@0000040=>73P030:f][@3_V100kiP@00X0kiP@
00<0[Jf]0?bP403lX1002P3lX1020:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00/0ojHA0P00000;0?nV4@030000003oYQ40[Jf]01h0ojHA
00<0[Jf]0?nV403oYQ004`3oYQ02000000L0ojH@00<0[Jf]0?nU403oYA005`3oYA02000000<0ojD@
00<0[Jf]0?nS403oXa000P3oXa03000001D0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`0000000`2iM@/2000000030:f][@000000[Jf]00@0R5H70P2][Je20;3PiP40oooo
001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P0000000`2][Jd0dhL>000000040=>73P030:f]
[@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00/0ojHA0P00000;0?nV4@030000
003oYQ40[Jf]01L0ojHA7@2][Jd2000000l0[Jf]4P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00
0P3oXa03000001D0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`000000
0`2iM@/2000000040;Ue2`0000000000000000<0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd00P0000070=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403l
X100103lX1030:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA00/0ojHA0P00000;0?nV4@030000003oYQ40[Jf]00L0ojHA402][Jd70?nV4@03
0:f][@3oYQ00ojH@01<0ojH@0P0000070?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd20?nU4080
00000`3oYA000`2][Jd0oj<@0?nS40020?nS40<000005@3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;000000030;Ue2`80000000@0^GD;00000000000000001028EPL00`2]
[Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080000000<0dhL>0000003C
Q`h01@3CQ`h00`11JN40[Jf]0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd<0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@80
00002@3oYQ400`2][Jd00000000000090:f][AL0ojHA00<0[Jf]0?nV403oYQ004`3oYQ02000000L0
ojH@00@0[Jf]0?nU403oYA000000503oYA020:f][@800000202][Jd3000001D0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/
UPh0[Jf]0=^:3@0=0=^:3@030:f][@000000^GD;0080^GD;0P0000001@2iM@/000000000002][Jd0
000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020000
00030=>73P000000dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f]
[@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
00/0ojHA0P0000090:f][@050?nV4@00000000000?nV4@2][Jd07P3oYQ400`2][Jd0ojH@0?nV400C
0?nV408000001`3oYQ00102][Jd0ojD@00000000000F0?nU408000000`3oYA000`2][Jd0oj<@0?nS
40020?nS40<000001`2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]3@3KRPd00`2][Jd000000;Ue2`020;Ue2`80000000D0
^GD;0000002][Jd0[Jf]0000000308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0
[Jf]09MP2`2GH0/00P0000000`3CQ`h000000=>73P050=>73P030:f][@3_V100kiP@00/0kiP@0P2]
[JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@020?nV4@T0[Jf]0P00000:0?nV4@80000000<0ojHA0:f][@3oYQ407@3oYQ400`2][Jd0ojH@0?nV
400C0?nV408000001`3oYQ001@2][Jd0ojD@0000003oYA00000001D0ojD@0P0000030?nU40030:f]
[@3oXa00oj<@0080oj<@0`0000070?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@03
0:f][@000000^GD;0080^GD;0P0000001@2iM@/000000:f][@28EPL0000000<0R5H700<0[Jf]0;3P
iP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd000000:f][@02000000030=>73P000000dhL>00D0
dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0D0?nV4@P0[Jf]2@3oYQ42000000X0ojHA0P0000000`3oYQ40[Jf]0?nV4@0M0?nV4@03
0:f][@3oYQ00ojH@01<0ojH@0P0000070?nV40040:f][@3oYA000000000001H0ojD@0P0000030?nU
40030:f][@3oXa00oj<@0080oj<@00<000000?nS400000004@3oXa080:f][AL0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd0
0`2][Jd0^GD;000000020;Ue2`80000000H0^GD;0000002][Jd0R5H70000002][Jd208QF1`030:f]
[@2`h>H0/>3V0400/>3V0@3oool005T0/>3V0P0000001@2][Jd000000000003CQ`h0000000H0dhL>
00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A
0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA00/0ojHA
0P00000:0?nV4@80000000<0ojHA0:f][@3oYQ407@3oYQ400`2][Jd0ojH@0?nV400?0?nV40H00000
1`3oYQ00102][Jd0ojD@0?nU4000000F0?nU408000000`3oYA000`2][Jd0oj<@0?nS40020?nS4080
00005P3oXa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@030:f][@2iM@/00000
00@0000000@0^GD;000000000000R5H70P0000000`2][Jd000000:f][@120;3PiP40oooo001I0;3P
iP80000000D0Uf0;0000002][Jd0dhL>000000060=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd4
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@07
0?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@8000002P3oYQ42000000030?nV4@2][Jd0
ojHA01d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400C0?nU40H000000`3oYA00
0`2][Jd0oj<@0?nS40030?nS40030000003oXa00oj<@01@0oj<@00<0[Jf]0?bP403lX100203lX106
0:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/000000080^GD;0P000000102iM@/0000000000028
EPL2000000030:f][@00000000000480/>3V0@3oool005T0/>3V00L000000:f][@00000000000:f]
[@3CQ`h0000000H0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@H0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]403oYQ400`2][Jd0
ojHA0?nV4@0;0?nV4@800000103oYQ48000000030?nV4@2][Jd0ojHA01d0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@00<000000?nS403o
Xa00503oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`00
00000P2iM@/2000000040;Ue2`000000000008QF1`80000000<0R5H7000000000000@P2`h>H10?oo
o`00F02`h>H20000000609MP2`00000000000:f][@3CQ`h000000P3CQ`h01@000000dhL>0=>73P3C
Q`h0[Jf]00<0kiP@0P2][Jd80>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ40203oYQ49000000T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400E0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00T0fhX=0P2][Jd0103KRPd0[Jf]0;Ue2`0000020;Ue2`80000000@0^GD;000000000000
R5H70P0000000`28EPL00000000000120;3PiP40oooo001H0;3PiP8000000`2GH0/00`2][Jd00000
000000020=>73P060000003CQ`h0dhL>0=>73P2][Jd0kiP@0P2][Jd:0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0102][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f]
[@040;Ue2`000000^GD;0;Ue2`80000000@0^GD;000000000000[Jf]0P0000001028EPL000000000
000000110;3PiP40oooo001G0;3PiP<000000`2GH0/00`2][Jd00000000000020=>73P040000003C
Q`h0dhL>0=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A
102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l50:f][@/0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]00<000000;Ue2`2iM@/0
0P0000001`2iM@/000000000002][Jd0R5H700000028EPL00`0000110;3PiP40oooo001G0;3PiP<0
00000`2GH0/00`2][Jd000000=>73P020=>73P030000003CQ`h0dhL>0080[Jf]3@3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0<0=^:3@050:f][@2iM@/000000:f][@2iM@/00P0000001`2iM@/000000000002][Jd0
R5H700000028EPL0100000100;3PiP40oooo001G0;3PiP<000000`2GH0/00`2][Jd000000=>73P02
0=>73P050000003CQ`h0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3f
W0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@080:f][@2i
M@/000000;Ue2`000000^GD;0000002iM@/2000000040:f][@28EPL0000008QF1`@00000@02`h>H1
0?ooo`00E`2`h>H3000000<0Uf0;0P0000030=>73P050000002][Jd0dhL>0=>73P2][Jd03@3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?0180mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/00P0000000`2][Jd000000;Ue2`02000000040:f][@28EPL0000008QF1`@00000@02`
h>H10?ooo`00E`2`h>H2000000040:f][@2GH0/0Uf0;09MP2`8000000P3CQ`h00`2][Jd000000=>7
3P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080000000<0^GD;0000002iM@/00P00
0000102][Jd0R5H700000028EPL400000400/>3V0@3oool005L0/>3V0P0000001@2][Jd0Uf0;09MP
2`2GH0/000000080dhL>00<0[Jf]0=>73P0000000`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0000000P0^GD;0:f][@2][Jd000000:f][@28EPL00000
08QF1`@00000@02`h>H10?ooo`00E`2`h>H2000000030:f][@2GH0/0Uf0;0080000000D0dhL>0000
003CQ`h0dhL>000000030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX103
0:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`03000000<0^GD;00L00000045Yh@28EPL0000008QF1`000000[Jf]00800000
@02`h>H10?ooo`00E`2`h>H2000000030:f][@2GH0/0Uf0;0080000000D0[Jf]0000003CQ`h0dhL>
000000030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@
00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`03000000<0^GD;00L000000:f][@28EPL0000008QF1`000000[Jf]00800000@02`h>H10?oo
o`00E`2`h>H20000000709MP2`000000Uf0;0000002][Jd0dhL>000000020=>73P050000003CQ`h0
dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00<000000`2iM@/01`000000[Jf]0:f][@000000R5H70000002]
[Jd00P0000100;3PiP40oooo001G0;3PiP@0000000<0Uf0;0000002][Jd00P0000020=>73P040000
003CQ`h0dhL>0:f][@h0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f]
[@3KRPd03@3KRPd00`2][Jd0^GD;00000002000000<0^GD;00L000000:f][@2][Jd0000008QF1`00
0000[Jf]00800000@02`h>H10?ooo`00EP2`h>H50000000309MP2`000000[Jf]0080000000<0dhL>
0000003CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400<0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302]
[Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`0000000P0000030;Ue2`070000002]
[Jd0R5H700000028EPL000000:f][@0200000400/>3V0@3oool005H0/>3V0`0000001@2GH0/00000
0:f][@000000[Jf]0080000000<0dhL>0000003CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40<0
[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3o
YQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue
2`0000000P0000030;Ue2`070000002][Jd0R5H700000028EPL000000:f][@0200000400/>3V0@3o
ool005H0/>3V0`0000001@2GH0/0000009MP2`000000[Jf]0080000000<0dhL>0000003CQ`h00P3C
Q`h00`2][Jd0kiP@0>nH40090>nH4080[Jf]00<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V2P2]
[JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:
3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/00P0000030;Ue2`80000000D0R5H70000002][Jd0
00000:f][@0200000400/>3V0@3oool005H0/>3V0`0000001@2GH0/0000009MP2`000000[Jf]0080
000000<0dhL>0000003CQ`h00P3CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0`3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0
/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`0200000080^GD;0`0000001@28EPL0
000008QF1`000000[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H3000000030:f][@000000Uf0;0080
000000@0dhL>0000003CQ`h000000`3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f]
[J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`02000000<0^GD;0P0000001@28
EPL0000008QF1`000000[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H3000000030:f][@000000Uf0;
008000000`3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00D0kiP@0P2][Jd70>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H5
0:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00800000102iM@/01P2][Jd0000000000028
EPL000000:f][@<00000?`2`h>H10?ooo`00EP2`h>H50000000309MP2`000000[Jf]00<0dhL>00D0
00000=>73P3CQ`h0dhL>0:f][@030>nH4080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0
mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@04
0=^:3@2][Jd0^GD;0;Ue2`8000001@2iM@/01@000000R5H708QF1`000000[Jf]00<00000?`2`h>H1
0?ooo`00EP2`h>H400000080Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01P000000dhL>0=>73P3CQ`h0
[Jf]0>nH4080[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2]
[Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2]
[Jd20;Ue2`8000001@2iM@/0102][Jd0R5H708QF1`28EPL4000003l0/>3V0@3oool005H0/>3V1000
000209MP2`030:f][@3CQ`h0dhL>0080dhL>00@000000=>73P3CQ`h0dhL>0P2][Jd=0>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@8000001@2iM@/0102][Jd0R5H7
08QF1`28EPL4000003l0/>3V0@3oool005H0/>3V1000000209MP2`030:f][@3CQ`h0dhL>0080dhL>
00<000000=>73P3CQ`h00P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
2@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
303KRPd00`2][Jd0^GD;0;Ue2`02000000D0^GD;00@0[Jf]08QF1`28EPL0R5H71000000o0;3PiP40
oooo001F0;3PiP@000000P2GH0/00`2][Jd0dhL>0=>73P020=>73P050000002][Jd0[Jf]0=>73P2]
[Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0
[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2i
M@/0^GD;000000050;Ue2`040:f][@28EPL0R5H708QF1`@00000?`2`h>H10?ooo`00EP2`h>H30000
00<0Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]
0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/UPh0
k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/000000080[Jf]0`2i
M@/0102][Jd0R5H708QF1`28EPL4000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00<0dhL>00<0[Jf]0000003CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f]
[@2iM@/0^GD;0;Ue2`0000000P2iM@/0102][Jd0^GD;0;Ue2`2][Jd308QF1`040:f][@0000000000
000003l0/>3V0@3oool005H0/>3V0P0000001P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]00<0
dhL>0000003CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0`2]
[Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`000000
0`2iM@/30:f][@<0R5H700@0[Jf]045Yh@0000000000?`2`h>H10?ooo`00EP2`h>H2000000040:f]
[@2GH0/0Uf0;09MP2`80[Jf]0`3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP
403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`0000001@2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V0P00000409MP2`030:f][@3CQ`h0
dhL>0080dhL>00D000000=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00L0o:0@0`2]
[Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H2
000000<0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX103
0:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd000000000000o
0;3PiP40oooo001F0;3PiP8000000`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f]
[@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd000000000000o0;3P
iP40oooo001F0;3PiP8000000P2GH0/00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02]
[Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd0
00000000000o0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28
EPL0[Jf]08QF1`2][Jd2000003l0/>3V0@3oool005H0/>3V00@000000:f][@2GH0/0[Jf]0P2GH0/0
0`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@03
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001F0;3PiP030000002][Jd0
[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?
0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n
]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`h>H0
0`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2]
[Jd20:BNS`03045Yh@2TWXl0[Jf]00@0/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36
`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n
^KP0102][Jd0];2a0:f][@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL0
0P28EPL20:f][@800000?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3C
Q`h0dhL>00L0dhL>00H0[Jf]0>nH402][Jd0[Jf]0:BNS`11JN430:BNS`80@FWQ1P2aZid20:f][@D0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0
`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0
`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd70;ji^005045Yh@2][Jd0@FWQ045Yh@2d/;400P2][Jd0
0`3KRPd0[Jf]0;Ue2`090;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000n0;3PiP40oooo001F
0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@<0Y9j?00@0@FWQ
0:BNS`2TWXl0Y9j?0`11JN470;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd80;ji^003045Y
h@2n^KP0@FWQ0080@FWQ0`2d/;420:f][@X0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0
/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f]
[@2TWXl0@FWQ00<0Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?0P11JN420;6[W@03045Yh@2aZid0/J^M00D0
/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]2@2n^KP00`11JN40_[Vh0;ji^002045Yh@@0
];2a0P11JN420:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool005H0
/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P040=>73P80[Jf]0P2TWXl01@11JN40
Y9j?0:BNS`2TWXl0@FWQ00<0Y9j?0P11JN430;6[W@80@FWQ1`2aZid30:f][@l0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H6
0:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0080;ji^080@FWQ0P2n^KP00`2][Jd0@FWQ0;B`/@03
0;B`/@@0@FWQ00<0[Jf]0;Ue2`2iM@/01@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?P2`
h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]
045Yh@2][Jd00P2TWXl01@11JN40Y9j?0:BNS`2TWXl0@FWQ00<0Y9j?0P11JN430;6[W@<0@FWQ1`2a
Zid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0
[Jf]0;ji^02n^KP01`2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2d/;40];2a0080];2a1@11
JN420:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool005H0/>3V00<0
00000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P020=>73P040:f][@11JN40@FWQ0:f][@80Y9j?
00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@030:BNS`80@FWQ0`2aZid2045Yh@P0/J^M00<0[Jf]0;VbYP2i
/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^011
JN400P11JN450;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0@FWQ0;B`/@2d/;40];2a1011JN400`2d
/;40@FWQ0:f][@030:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool0
05L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P040:f][@2:QGD0@FWQ045Yh@<0[Jf]00D0
@FWQ0:BNS`2TWXl0Y9j?045Yh@030:BNS`80@FWQ0`2aZid2045Yh@@0/J^M0`11JN400`2aZid0[Jf]
0;VbYP070;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k
00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`<0@FWQ1`2n^KP00`11JN40_[Vh0;ji^0020;ji^004045Y
h@2d/;40];2a0;B`/@@0@FWQ00L0[Jf]045Yh@2d/;40[Jf]045Yh@2OVj00[Jf]0080^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f]
[@3CQ`h20:f][@80RXEe0P11JN40102][Jd0Y9j?045Yh@2][Jd30:BNS`05045Yh@2TWXl0Y9j?0:BN
S`11JN40102aZid2045Yh@<0/J^M00H0@FWQ0;6[W@2aZid0/J^M045Yh@2][Jd;0;VbYP@0[Jf]00<0
^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]3P33_K/00`2][Jd0@FWQ045Y
h@070;ji^080@FWQ0`2n^KP01P11JN40];2a0;B`/@2d/;40@FWQ0;B`/@80@FWQ0P2d/;400`11JN40
[Jf]045Yh@0209nKX0<0[Jf]1028EPL00`2][Jd000000000000n0;3PiP40oooo001F0;3PiP030:f]
[@2GH0/0Uf0;0080Uf0;0P2][Jd408Z5M@80@FWQ00@0[Jf]0:BNS`11JN40Y9j?0P2][Jd00`2TWXl0
@FWQ0:BNS`020:BNS`03045Yh@2aZid0/J^M0080/J^M0P11JN430;6[W@03045Yh@2aZid0/J^M0080
/J^M00<0@FWQ0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0_02][Jd0`kfk00h0`kfk00<0[Jf]045Yh@11
JN401`2n^KP2045Yh@<0_[Vh0P11JN420;B`/@04045Yh@2][Jd0@FWQ045Yh@80];2a00<0@FWQ0:f]
[@11JN400`2OVj000`11JN40[Jf]08QF1`0308QF1`030:f][@000000000003h0/>3V0@3oool005H0
/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe08Z5M@0308Z5M@80@FWQ00<0[Jf]045Yh@11
JN400`2TWXl00`2][Jd0@FWQ0:BNS`020:BNS`03045Yh@2aZid0/J^M0080/J^M0P11JN430;6[W@03
045Yh@2aZid0/J^M0080/J^M00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V045Yh@090;VbYP03
0:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0
`kfk0<>m^`050<>m^`D0@FWQ0`33_K/00`2][Jd0@FWQ045Yh@070;ji^080@FWQ0`2n^KP2045Yh@03
0;B`/@2][Jd0@FWQ0080];2a00H0@FWQ0;B`/@2d/;40@FWQ0:f][@11JN4309nKX003045Yh@2OVj00
[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/2
0:f][@H0RXEe1011JN440:BNS`05045Yh@2][Jd0Y9j?0:BNS`11JN40102aZid2045Yh@80/J^M00<0
@FWQ0;6[W@2aZid00`2aZid00`2][Jd0@FWQ0;VbYP020;VbYP80@FWQ00<0^K:V045Yh@11JN401`2i
/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33
_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36
`;`0102][Jd0`kfk0<>m^`33_K/4045Yh@<0`kfk0P11JN440<>m^`80@FWQ202n^KP01011JN40_[Vh
0;ji^02n^KP2045Yh@030:f][@2d/;40@FWQ0080];2a00<0@FWQ0;B`/@2d/;400`11JN4309nKX003
045Yh@2OVj00[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;
09MP2`2GH0/20:f][@L0RXEe00<0[Jf]045Yh@2TWXl00`2TWXl2045Yh@040:BNS`2][Jd0[Jf]045Y
h@@0/J^M0P11JN420;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]045Yh@2i/ZH00P2i/ZH00`11
JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f]
[@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@33_K/0`kfk00<0`kfk00<0@FWQ0<>m
^`33_K/00`33_K/2045Yh@<0`kfk0P11JN490;ji^0D0@FWQ0P2d/;401@11JN40];2a0;B`/@11JN40
];2a0080@FWQ00<0[Jf]045Yh@2OVj000P2OVj001011JN40Wi^P09nKX02][Jd208QF1`030:f][@2`
h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd708Z5M@030:f][@2TWXl0
Y9j?00<0Y9j?0P11JN430:BNS`03045Yh@2][Jd0/J^M0080/J^M00D0@FWQ0;6[W@2aZid0/J^M045Y
h@050;6[W@030:f][@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;Vb
YP020;VbYP03045Yh@2][Jd0_[N/00`0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40a/2l00<0[Jf]0<>m^`33_K/00`33
_K/00`11JN40`kfk0<>m^`030<>m^`80@FWQ0`33_K/2045Yh@T0_[Vh0P2][Jd00`2n^KP0@FWQ045Y
h@020;B`/@04045Yh@2d/;40];2a045Yh@<0];2a00@0[Jf]045Yh@2OVj00Wi^P0P11JN4209nKX080
[Jf]00<0R5H70:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0
RXEe00<0[Jf]0:BNS`2TWXl0102TWXl2045Yh@<0Y9j?00H0@FWQ0;6[W@2][Jd0[Jf]0;6[W@11JN43
0;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;VbYP03
0;VbYP04045Yh@2i/ZH0^K:V0;VbYP80@FWQ00<0[Jf]0;jg[02n]j`03`2n]j`40:f][A40`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/01033_K/01011JN40`kfk0<>m
^`33_K/2045Yh@L0_[Vh0P2][Jd30;ji^004045Yh@2d/;40];2a0;B`/@80@FWQ1@2d/;40102][Jd0
Wi^P045Yh@2OVj02045Yh@80Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f]
[@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`040:BNS`80@FWQ0`2TWXl01`11
JN40/J^M0;6[W@2aZid0[Jf]045Yh@2][Jd00P2aZid00`11JN40/J^M0;6[W@030;6[W@030:f][@2i
/ZH0^K:V00P0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045YhA80_[N/00<0[Jf]0<6j/031^[001@2]
[Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33_K/0`kfk00@0`kfk00L0
@FWQ0<>m^`33_K/0`kfk045Yh@2n^KP0@FWQ00<0_[Vh0`2][Jd50;ji^005045Yh@2d/;40];2a0;B`
/@11JN401P2d/;40102][Jd0Wi^P045Yh@2OVj02045Yh@0409nKX02][Jd0[Jf]071^N@80[Jf]@02`
h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f][@2TWXl0Y9j?00@0Y9j?0P11JN42
0:BNS`80@FWQ102aZid01@11JN40/J^M0:f][@2][Jd0@FWQ00D0/J^M00<0[Jf]0;VbYP2i/ZH0202i
/ZH00`11JN40^K:V0;VbYP030;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31
^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33_K/0`kfk00@0`kfk00D0
@FWQ0<>m^`33_K/0`kfk0:f][@02045Yh@030;ji^02][Jd0[Jf]00@0_[Vh00D0@FWQ0;ji^02n^KP0
_[Vh045Yh@020;B`/@03045Yh@2d/;40];2a00D0];2a00T0[Jf]09nKX011JN40Wi^P045Yh@2OVj00
[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0
0`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00@0Y9j?00<0@FWQ0:BNS`11JN400`11JN44
0;6[W@05045Yh@2aZid0/J^M0;6[W@11JN400P2][Jd30;6[W@030:f][@2i/ZH0^K:V00L0^K:V0P11
JN440;VbYP030:f][@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`030<>m^`03045Yh@33_K/0`kfk00D0`kfk00@0@FWQ0<>m^`33_K/0[Jf]0P11JN400`2][Jd0_[Vh
0;ji^0040;ji^005045Yh@2n^KP0_[Vh045Yh@2][Jd02P2d/;401P2][Jd0Wi^P09nKX011JN40Wi^P
0:f][@80Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C
0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`040:BNS`03045Yh@2TWXl0
Y9j?0080Y9j?00<0[Jf]0;6[W@2aZid00P2aZid01011JN40/J^M0;6[W@2aZid2045Yh@050;6[W@2]
[Jd0[Jf]0;6[W@2][Jd0202i/ZH00`11JN40^K:V045Yh@040;VbYP030:f][@2n]j`0_[N/0140_[N/
00<0[Jf]0<6j/031^[003`31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0140al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33_K/0`kfk00D0`kfk
00@0@FWQ0<>m^`2][Jd0[Jf]0P11JN420;ji^003045Yh@2n^KP0_[Vh0080_[Vh00D0@FWQ0;ji^02n
^KP0@FWQ0:f][@0:0;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f]
[Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]
0080RXEe00<0[Jf]0:BNS`2TWXl0102TWXl00`11JN40Y9j?0:BNS`020:BNS`030:f][@2aZid0/J^M
0080/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN430;6[W@030:f][@11JN40[Jf]00D0^K:V1011JN45
0;VbYP030:f][@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/011JN400`11JN4>0<6j/0030:f][@33_K<0
`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j0080al6j1011JN4?0<O1^P030:f][@38`K/0
b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0140al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33_K/0`kfk00@0`kfk00D0
[Jf]045Yh@2][Jd0`kfk0:f][@02045Yh@80_[Vh0P11JN440;ji^080@FWQ00<0_[Vh0:f][@2d/;40
2@2d/;400`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd01P2T
WXl00`11JN40Y9j?0:BNS`020:BNS`060:f][@2aZid0/J^M045Yh@2aZid0@FWQ0`2aZid2045Yh@<0
/J^M00<0@FWQ0:f][@11JN400`2][Jd4045Yh@L0^K:V00<0[Jf]0;jg[02n]j`04@2n]j`0102][Jd0
`KZ`0<6j/031^[06045Yh@X0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0@FWQ00<0@FWQ4P37`KX00`2]
[Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0040<O1_003045Yh@37`K`0al6l
00X0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`04045Yh@33_K/0`kfk
0<>m^`<0[Jf]00D0`kfk045Yh@33_K/0`kfk0:f][@02045Yh@<0_[Vh00<0@FWQ0;ji^02n^KP01@2n
^KP00`2][Jd0];2a0;B`/@080;B`/@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]1P2TWXl0
0`11JN40Y9j?0:BNS`020:BNS`040:f][@2aZid0/J^M0;6[W@80@FWQ102aZid2045Yh@<0/J^M00P0
@FWQ0;VbYP2i/ZH0^K:V045Yh@2][Jd0@FWQ0:f][@P0^K:V00<0@FWQ0;jg[02n]j`04@2n]j`0102]
[Jd0`KZ`0<6j/031^[02045Yh@@0`KZ`0P11JN450<6j/0<0@FWQ00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00@0[Jf]0<O1^P37`KX0al6j0P11JN4B0<O1^P030:f][@38`K/0b<6k00<0b<6k302]
[Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`00`37`K`2045Yh@`0al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`04045Yh@33_K/0[Jf]0:f][@@0`kfk
00@0@FWQ0<>m^`33_K/0[Jf]0`11JN420;ji^003045Yh@2n^KP0_[Vh00D0_[Vh00<0[Jf]0;B`/@2d
/;40202d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2T
WXl0102TWXl00`11JN40Y9j?0:BNS`020:BNS`030:f][@2aZid0/J^M00L0/J^M0P11JN420;6[W@03
045Yh@2][Jd0^K:V0080^K:V0P11JN420;VbYP@0[Jf]102i/ZH00`11JN40_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0080`KZ`0P11JN450<6j/080@FWQ1P31^[04045YhA<0`kfc00<0[Jf]0<Fn]@35
_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP0102][Jd0al6j0<O1^P37`KX2045Y
h@L0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00l0b<6k1011JN400`2][Jd0al6l0<O1_0030<O1
_080@FWQ3037`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk00<0[Jf]045Y
h@2][Jd01P33_K/01011JN40`kfk0<>m^`2][Jd2045Yh@030;ji^011JN40@FWQ00P0_[Vh00<0[Jf]
0;B`/@2d/;401P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F
0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@<0Y9j?0P11JN440:BNS`030:f][@2a
Zid0/J^M00P0/J^M0P11JN400`2aZid0@FWQ0:f][@030;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00H0
@FWQ0:f][@2][Jd0[Jf]0;VbYP11JN4B0;jg[0030:f][@31^[00`KZ`0080`KZ`0P11JN460<6j/003
045Yh@31^[00`KZ`00@0`KZ`0P11JN4E0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL02@36_kLW0:f][@80@FWQ1`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/03038`K/3045Yh@@0b<6k00<0@FWQ0<O1_037`K`01037`K`00`11JN40al6l0<O1_00:0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd00`33_K/0@FWQ0<>m^`060<>m^`04
045Yh@33_K/0`kfk0:f][@80@FWQ2`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a
0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0
Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@80Y9j?00<0@FWQ0:BNS`2TWXl00P2T
WXl00`2][Jd0/J^M0;6[W@0:0;6[W@03045Yh@2aZid0[Jf]00<0^K:V00<0@FWQ0;VbYP2i/ZH0102i
/ZH01`11JN40^K:V0;VbYP2i/ZH0[Jf]045Yh@2][Jd04@2n]j`00`2][Jd0`KZ`0<6j/0020<6j/080
@FWQ1P31^[02045Yh@D0`KZ`0P11JN4>0<>m/`@0@FWQ0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP0102][Jd0al6j0<O1^P37`KX2045Y
hA80al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/3045Yh@P0b<6k00<0@FWQ
0<S1^`38`K/01038`K/00`2][Jd0@FWQ0<O1_00A0<O1_0030:f][@36`;`0a/2l00h0a/2l102][Jd5
0<>m^`03045Yh@33_K/0`kfk00@0`kfk00@0@FWQ0<>m^`11JN40@FWQ3@2n^KP00`2][Jd0];2a0;B`
/@030;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0
?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?
00<0[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V0080^K:V
00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045Yh@@0^K:V00<0@FWQ0;jg[02][Jd00`2][Jd=0;jg[0030:f]
[@31^[00`KZ`0080`KZ`0P11JN460<6j/080@FWQ1@31^[02045Yh@`0`kfc0P11JN440<>m/`04045Y
h@33_K<0`kfc0:f][@80@FWQ5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00@0[Jf]0<O1^P37`KX0al6j0P11JN4B0<O1^P030:f][@38`K/0b<6k00/0b<6k1P11JN430<S1
^`040:f][@38`K/0@FWQ045Yh@<0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00@0b<6k00<0[Jf]
045Yh@37`K`04@37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`04
0<>m^`03045Yh@33_K/0`kfk00@0`kfk00@0@FWQ0<>m^`33_K/0[Jf]3@2n^KP0102][Jd0];2a0;B`
/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40
oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@@0
Y9j?00D0[Jf]0;6[W@2aZid0/J^M045Yh@0:0;6[W@030:f][@2i/ZH0^K:V0080^K:V00<0@FWQ0;Vb
YP2i/ZH00P2i/ZH2045Yh@@0^K:V00<0@FWQ0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j
/031^[000P31^[02045Yh@L0`KZ`00<0@FWQ0<6j/031^[000`31^[02045Yh@/0`kfc0P11JN460<>m
/`03045Yh@33_K<0@FWQ00P0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@050<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP0102][Jd0al6j0<O1^P37`KX2
045Yh@`0al6j00<000000<O1^P37`KX00P37`KX4045Yh@80b<6k1P11JN450<S1^`80@FWQ1@38`K/0
0`2][Jd0@FWQ045Yh@050<S1^`03045Yh@38`K/0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/01038`K/0
0`2][Jd0@FWQ0<O1_00A0<O1_0030:f][@36`;`0a/2l00D0a/2l102][Jd70<K0_0030:f][@33_K/0
`kfk00@0`kfk00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@80`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0
102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]
@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2]
[Jd20:BNS`050:f][@2aZid0/J^M0;6[W@11JN402@2aZid00`2][Jd0^K:V0;VbYP040;VbYPH0@FWQ
102i/ZH00`11JN40_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/0020<6j/080@FWQ
1`31^[000`11JN40`KZ`0<6j/0030<6j/080@FWQ2`33_K<2045Yh@H0`kfc0`11JN480<Fn]@03045Y
h@35_[D0aKje00<0aKje00<0@FWQ0<Fn]@35_[D01@35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`<0@FWQ
0`36_kL2045Yh@<0a[ng1@11JN400`36_kL0[Jf]0<O1^00D0<O1^080@FWQ0`37`KX2045Yh@80al6j
1011JN480<O1^P@0@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11JN450<S1^`030:f]
[@11JN40b<6k00H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ
4P37`K`00`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0[Jf]0<>m^`33_K/01033_K/00`11JN40`kfk
0<>m^`030<>m^`80@FWQ0P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P
09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:
QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]0`2aZid2045Yh@P0/J^M00<0[Jf]0;VbYP2i/ZH02@2i
/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@d0_[N/102][Jd00`2n]j`0[Jf]0<6j/0030<6j/080@FWQ
1`31^[000`11JN40`KZ`0<6j/0030<6j/080@FWQ2`33_K<2045Yh@L0`kfc0P11JN480<Fn]@03045Y
h@35_[D0aKje00<0aKje00<0@FWQ0<Fn]@35_[D01@35_[D00`2][Jd0a[ng0<Jo]`020<Jo]`80@FWQ
0`36_kL2045Yh@030<Jo]`11JN40@FWQ00H0a[ng1011JN4=0<O1^0@0@FWQ0`37`KP2045Yh@040:f]
[@37`KX0al6j0<O1^P80@FWQ00<0al6j045Yh@37`KX00P37`KX3045Yh@P0al6j0P11JN400`2][Jd0
b<6k0<S1^`040<S1^`80@FWQ1`38`K/2045Yh@D0b<6k0P11JN4C0<S1^`80@FWQ1P37`K`00`11JN40
al6l0<O1_0080<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`040<>m^`03045Yh@33_K/0`kfk00<0
`kfk0P11JN420<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl20:f][@80/J^M00<0@FWQ0;6[W@2aZid01`2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP80@FWQ
4@2n]j`50:f][@030<6j/011JN40@FWQ00L0`KZ`0P11JN440<6j/080@FWQ2`33_K<2045Yh@L0`kfc
0P11JN470<Fn]@<0@FWQ0`35_[D3045Yh@H0aKje00D0[Jf]0<Jo]`36_kL0a[ng045Yh@070<Jo]`<0
@FWQ1P36_kL2045Yh@030<Jo]`2][Jd0al6h00X0al6h0P11JN440<O1^003045Yh@37`KP0al6h0080
@FWQ00@0[Jf]0<O1^P37`KX0al6j0`11JN450<O1^P80@FWQ2037`KX2045Yh@030:f][@38`K/0b<6k
00@0b<6k0P11JN470<S1^`80@FWQ1@38`K/2045YhA80b<6k0P11JN400`2][Jd0al6l0<O1_0040<O1
_003045Yh@37`K`0al6l00<0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/01033_K/00`11JN40`kfk0<>m^`030<>m^`05045Yh@33_K/0`kfk0<>m^`2][Jd02P2n^KP2
0:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool0
05T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd90;6[
W@030:f][@2i/ZH0^K:V00d0^K:V0P11JN4B0;jg[0050:f][@31^[00`KZ`0<6j/02][Jd00P11JN44
0:f][@<0`KZ`0P11JN440<6j/080@FWQ2`33_K<2045Yh@L0`kfc0P11JN470<Fn]@<0@FWQ0`35_[D3
045Yh@H0aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`<0@FWQ1P36_kL2045Yh@030<Jo]`2][Jd0
al6h00T0al6h0P11JN460<O1^0<0@FWQ00<0al6h0:f][@37`KX00P37`KX3045Yh@H0al6j0P11JN47
0<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11JN440<S1^`80@FWQ4@38`K/2
045Yh@030<S1^`11JN40[Jf]00H0al6l00<0@FWQ0:f][@2][Jd00`2][Jd70<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/01033_K/00`11JN40`kfk0<>m^`030<>m^`05045Yh@33_K/0
`kfk0<>m^`2][Jd0202n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nK
X00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH2
045YhA80_[N/00<0[Jf]0<6j/031^[000P31^[000`11JN40`KZ`0<6j/0030<6j/0<0[Jf]0P11JN42
0:f][@80`KZ`0P11JN4<0<>m/`80@FWQ1P33_K<2045Yh@L0aKje00<0@FWQ0<Fn]@11JN400`35_[D3
045Yh@H0aKje00@0[Jf]0<Jo]`11JN40@FWQ2@36_kL2045Yh@H0a[ng0P11JN400`36_kL0[Jf]0<O1
^0090<O1^080@FWQ1`37`KP2045Yh@80al6h00<0[Jf]0<O1^P37`KX00P11JN470<O1^P80@FWQ1`37
`KX2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN470<S1^`80@FWQ1038`K/2045YhA00b<6k00H0
@FWQ0<S1^`11JN40@FWQ0<S1^`2][Jd20<O1_0@0[Jf]00<0@FWQ0<O1_037`K`02P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00@0`kfk00<0@FWQ0<>m^`33_K/00`33_K/01@11JN40
`kfk0<>m^`33_K/0[Jf]00D0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nK
X02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0
RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid00`2][Jd0
^K:V0;VbYP0=0;VbYP80@FWQ4P2n]j`00`2][Jd0`KZ`0<6j/0020<6j/003045Yh@31^[00`KZ`00H0
`KZ`0P11JN420<6j/080[Jf]0P11JN430:f][@T0`kfc0P11JN460<>m/`03045Yh@2][Jd0aKje00H0
aKje00<0@FWQ0<Fn]@11JN400`35_[D3045Yh@H0aKje00@0[Jf]0<Jo]`11JN40@FWQ2@36_kL00`11
JN40a[ng0<Jo]`050<Jo]`80@FWQ00<0a[ng0:f][@37`KP02@37`KP2045Yh@L0al6h0P11JN420<O1
^0030:f][@37`KX0al6j0080@FWQ0`37`KX010000000al6j0<O1^P37`KX2045Yh@L0al6j0P11JN40
0`2][Jd0b<6k0<S1^`040<S1^`80@FWQ1`38`K/2045Yh@@0b<6k0P11JN4?0<S1^`<0@FWQ1P2][Jd4
0<O1_003045Yh@37`K`0al6l00X0al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`03
0<>m^`03045Yh@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`33_K/00P33_K/0102][Jd0_[Vh0;ji^02n
^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`
h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0>0;VbYP80@FWQ4P2n]j`0
0`2][Jd0`KZ`0<6j/0020<6j/003045Yh@31^[00`KZ`00H0`KZ`0P11JN440<6j/0<0@FWQ0P33_K<7
0:f][@<0`kfc0`11JN440<>m/`03045Yh@2][Jd0aKje00H0aKje00<0@FWQ0<Fn]@11JN400`35_[D0
0`11JN40aKje045Yh@060<Fn]@040:f][@36_kL0@FWQ045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL01@36
_kL2045Yh@030<Jo]`2][Jd0al6h00T0al6h0P11JN470<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1
^P02045Yh@P0al6j0P11JN460<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11
JN440<S1^`80@FWQ2`38`K/40:f][@03045Yh@2][Jd0[Jf]00<0b<6k00<0[Jf]045Yh@37`K`01037
`K`00`11JN40al6l0<O1_00:0<O1_0030:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m^`33_K/00`33
_K/00`11JN40`kfk0<>m^`020<>m^`03045Yh@33_K/0`kfk0080`kfk00@0[Jf]0;ji^02][Jd0[Jf]
2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0
@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]0;6[W@2aZid02P2aZid30:f][@h0^K:V0P11JN4B0;jg[0030:f][@31^[00`KZ`0080`KZ`00<0
@FWQ0<6j/031^[001P31^[02045Yh@@0`KZ`0`11JN490<>m/`H0[Jf]0P11JN420<>m/`03045Yh@2]
[Jd0aKje00D0aKje0P11JN401035_[D0@FWQ0<Fn]@35_[D2045Yh@030<Fn]@11JN40aKje00D0aKje
00<0[Jf]045Yh@11JN402P36_kL00`11JN40a[ng0<Jo]`050<Jo]`80@FWQ00<0a[ng0:f][@37`KP0
2@37`KP2045Yh@L0al6h0P11JN420<O1^0030:f][@37`KX0al6j0080@FWQ2037`KX2045Yh@H0al6j
0P11JN40102][Jd0b<6k0<S1^`0000030<S1^`80@FWQ1`38`K/2045Yh@@0b<6k0P11JN430<S1^`D0
[Jf]00<0@FWQ0:f][@2][Jd00`38`K/2045Yh@D0b<6k0P11JN450<O1_003045Yh@37`K`0al6l00X0
al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33_K/0`kfk0080
@FWQ1033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0
/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
2`2aZid00`2][Jd0^K:V0:f][@030:f][@X0^K:V0P11JN4B0;jg[0030:f][@31^[00`KZ`0080`KZ`
00<0@FWQ0<6j/031^[001P31^[02045Yh@@0`KZ`0`11JN440<>m/`03045Yh@33_K<0`kfc00X0`kfc
0`11JN460:f][@030<Fn]@11JN40aKje0080aKje00@0@FWQ0<Fn]@11JN40@FWQ0P35_[D00`11JN40
aKje0<Fn]@030<Fn]@030:f][@11JN40@FWQ00X0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL2045Yh@03
0<Jo]`2][Jd0al6h00X0al6h0P11JN460<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P02045Yh@P0
al6j0P11JN460<O1^P80@FWQ00<0[Jf]0<S1^`0000001038`K/2045Yh@L0b<6k0P11JN440:f][@80
@FWQ0`2][Jd40<S1^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ1037`K`2045Yh@`0
al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`030<>m^`<0@FWQ0`33_K/30:f][@03
0<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40
oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V
0;VbYP030;VbYP<0[Jf]1`2i/ZH2045YhA80_[N/00<0[Jf]0<6j/031^[000P31^[000`11JN40`KZ`
0<6j/0060<6j/080@FWQ1031^[02045Yh@070<>m/`11JN40`kfc0<>m/`11JN40`kfc045Yh@050<>m
/`80@FWQ1P33_K<00`11JN40[Jf]0<Fn]@040<Fn]@030:f][@11JN40[Jf]0080[Jf]00@0@FWQ0:f]
[@11JN40@FWQ0P2][Jd00`11JN40aKje0<Fn]@030<Fn]@030:f][@11JN40@FWQ00L0a[ng1`11JN44
0<Jo]`80@FWQ00<0a[ng0:f][@37`KP02`37`KP00`11JN40al6h0<O1^0040<O1^080@FWQ0P37`KP0
0`2][Jd0al6j0<O1^P02045Yh@P0al6j0P11JN460<O1^P80@FWQ00<0[Jf]0<S1^`38`K/00`38`K/0
0`2][Jd0@FWQ045Yh@070:f][@80@FWQ1@38`K/2045Yh@L0b<6k0P11JN440<S1^`03045Yh@38`K/0
b<6k00@0b<6k0P11JN440<O1_0<0@FWQ3037`K`00`2][Jd0a/2l0<K0_00@0<K0_0040:f][@33_K/0
`kfk0<>m^`<0@FWQ0P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`
/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]102i/ZH00`11JN40[Jf]0;jg[00A0;jg[0030:f][@31^[00
`KZ`0080`KZ`00<0@FWQ0<6j/031^[001P31^[02045Yh@80`KZ`1011JN401`33_K<0@FWQ0<>m/`33
_K<0@FWQ0<>m/`11JN401@33_K<2045Yh@H0`kfc00<0@FWQ0:f][@35_[D01@35_[D01P11JN40aKje
0<Fn]@35_[D0@FWQ0<Fn]@80@FWQ0P35_[D00`11JN40[Jf]0:f][@040:f][@80@FWQ2@2][Jd90<Jo
]`80@FWQ00<0a[ng0:f][@37`KP03037`KP3045Yh@<0al6h0P11JN420<O1^0030:f][@37`KX0al6j
0080@FWQ1`37`KX00`2][Jd0@FWQ045Yh@060:f][@80@FWQ1P2][Jd00`38`K/0@FWQ045Yh@070<S1
^`80@FWQ1@38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`020<S1
^`03045Yh@2][Jd0@FWQ00@0al6l0`11JN4<0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`
/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`11JN40[Jf]0;jg[00A0;jg[003
0:f][@31^[00`KZ`0080`KZ`00<0@FWQ0<6j/031^[001@31^[02045Yh@D0`KZ`0P11JN420<>m/`80
@FWQ00<0`kfc045Yh@11JN401P33_K<00`11JN40`kfc0<>m/`040<>m/`03045Yh@2][Jd0aKje00D0
aKje00H0@FWQ0<Fn]@35_[D0aKje045Yh@35_[D2045Yh@80aKje00<0@FWQ0<Fn]@35_[D00`35_[D0
0`2][Jd0@FWQ045Yh@090<Jo]`T0[Jf]0P11JN4B0:f][@D0@FWQ1@2][Jd2045Yh@L0[Jf]0P11JN47
0<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11JN450<S1^`030:f][@11JN40
@FWQ00D0b<6k00<0@FWQ0<S1^`38`K/01P38`K/4045Yh@030<S1^`2][Jd0al6l00@0al6l0`11JN4<
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0
_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BN
S`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j
/031^[000P31^[000`11JN40`KZ`0<6j/0050<6j/080@FWQ1P31^[000`2][Jd0`kfc0<>m/`020<>m
/`80@FWQ1`33_K<00`11JN40`kfc0<>m/`030<>m/`03045Yh@33_K<0[Jf]00D0aKje00<0@FWQ0<Fn
]@35_[D00P35_[D00`11JN40aKje045Yh@030<Fn]@03045Yh@35_[D0aKje00<0aKje00<0[Jf]045Y
h@11JN404P36_kL3045Yh@030:f][@37`KP0al6h0140al6h0P11JN400`000000al6h0:f][@020<O1
^P80@FWQ1`37`KX2045Yh@P0al6j00<0@FWQ0:f][@38`K/01@38`K/2045Yh@L0b<6k0P11JN450<S1
^`040:f][@38`K/0@FWQ045Yh@<0b<6k00<0@FWQ0<S1^`38`K/03038`K/00`2][Jd0al6l0<O1_003
0<O1_0<0@FWQ3037`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f]
[@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]
00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/0020<6j/003045Yh@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j
/031^[001@31^[000`2][Jd0`kfc0<>m/`0<0<>m/`D0@FWQ0P33_K<00`2][Jd0aKje0<Fn]@030<Fn
]@03045Yh@35_[D0aKje00<0aKje0P11JN440<Fn]@03045Yh@35_[D0aKje0080aKje00<0[Jf]045Y
h@11JN404P36_kL3045Yh@050:f][@37`KP0al6h0<O1^011JN401`37`KP2045Yh@H0al6h00D0@FWQ
0<O1^037`KP0al6h0:f][@020<O1^P80@FWQ1`37`KX2045Yh@P0al6j0P11JN460<S1^`03045Yh@38
`K/0b<6k00H0b<6k0P11JN450<S1^`030:f][@38`K/0b<6k00@0@FWQ3`38`K/00`2][Jd0al6l0<O1
_0030<O1_0<0@FWQ3037`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m
^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3o
ool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/0020<6j/003045Yh@31^[00
`KZ`00D0`KZ`00<0@FWQ0<6j/031^[001@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00L0@FWQ0P35_[D2045Yh@@0aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0@FWQ045Yh@0B
0<Jo]`<0@FWQ00H0[Jf]0<O1^037`KP0@FWQ0<O1^011JN460<O1^080@FWQ1P37`KP01@11JN40al6h
0<O1^037`KP0[Jf]0080al6j0`11JN450<O1^P80@FWQ2@37`KX00`11JN40[Jf]045Yh@050<S1^`03
045Yh@38`K/0b<6k00@0b<6k1011JN450<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`00`37`K`3045Yh@`0al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33
_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?oo
o`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0080`KZ`00<0@FWQ0<6j/031
^[001031^[000`11JN40`KZ`0<6j/0060<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D02@35_[D2045Yh@80aKje1P11JN401035_[D0[Jf]045Yh@11JN4B0<Jo]`80@FWQ00<0a[ng045Y
h@37`KP00P37`KP2045Yh@L0al6h00<0@FWQ0<O1^037`KP00`37`KP00`11JN40al6h0<O1^0020<O1
^0030:f][@37`KX0al6j0080@FWQ00<0al6j045Yh@37`KX00`37`KX2045Yh@T0al6j00<0@FWQ0:f]
[@38`K/01@11JN4@0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`00`37`K`3045Y
h@`0al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/004045Y
h@D0`KZ`0P11JN480<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0@FWQ045Yh@0?0<Jo]`D0@FWQ00<0a[ng0:f][@11JN400`11JN490<O1^0D0@FWQ1@37`KP00`2]
[Jd0@FWQ045Yh@02045Yh@80al6j1011JN4;0<O1^P03045Yh@2][Jd0b<6k01D0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_0030<O1_080@FWQ2`37`K`50:f][A00a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]0P31^[06045Yh@T0
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@040:f][@36_kL0@FWQ045Y
h@T0a[ng00<0@FWQ0<Jo]`36_kL02036_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01<0al6j00<0@FWQ0:f][@38`K/02038`K/00`000000b<6k0<S1^`0:0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`01037`K`00`11JN40al6l0<O1_0040<O1_0D0[Jf]0P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f]
[ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@040:f][@36_kL0@FWQ045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL02036_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0al6j00<0@FWQ0:f][@38`K/05@38`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H1
0?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D0102][Jd0a[ng045Yh@11JN490<Jo]`03045Yh@36_kL0a[ng00P0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0C0<O1^P03045Yh@2][Jd0b<6k01D0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3P
iP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[003`31^[070:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`02045Y
h@P0a[ng00<0@FWQ0<Jo]`36_kL02036_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01<0al6j00<0@FWQ0:f][@38`K/03P38`K/00`11JN40b<6k0<S1^`040<S1^`030:f][@38`K/0b<6k
0100b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33
_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL00P11JN480<Jo
]`03045Yh@36_kL0a[ng00P0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0C0<O1
^P03045Yh@2][Jd0b<6k00d0b<6k00<0@FWQ0<S1^`11JN401@38`K/00`2][Jd0b<6k0<S1^`090<S1
^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0
[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@040:f][@36_kL0a[ng0<Jo
]`80@FWQ1P36_kL2045Yh@X0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0C0<O1
^P03045Yh@2][Jd0b<6k00h0b<6k00<0@FWQ0<S1^`38`K/01038`K/0102][Jd0b<6k0<S1^`38`K/8
0:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0[Jf]0<Jo
]`36_kL00P36_kL2045Yh@<0a[ng0P11JN400`36_kL0@FWQ0<Jo]`090<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX04037`KX4045Yh@030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m
^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0
aKje00<0[Jf]0<Jo]`36_kL01036_kL3045Yh@<0a[ng00<0@FWQ0<Jo]`36_kL02036_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd0
0`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3P
iP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00d0
al6j00<000000<O1^P37`KX01037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00
U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2]
[Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f]
[@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?oo
o`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f]
[I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k
1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn
0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52622 .3309 m
.5212 .33411 L
s
.52956 .33088 m
.52622 .3309 L
s
.51786 .33089 m
.51117 .33085 L
s
.53291 .33407 m
.52956 .33088 L
s
.53458 .33405 m
.52956 .33088 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55793 .33036 m
.54793 .33063 L
s
.49615 .3306 m
.49948 .33388 L
s
.48948 .33042 m
.49615 .3306 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5017 .33498 m
.50282 .33073 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51872 .35667 m
.51873 .33861 L
s
.51706 .35666 m
.51708 .3386 L
s
.52867 .3386 m
.54025 .33848 L
s
.5088 .33853 m
.51376 .34084 L
s
.50549 .33849 m
.5088 .33853 L
s
.50218 .34069 m
.50549 .33849 L
s
.50052 .34066 m
.50549 .33849 L
s
.51376 .34084 m
.51707 .34537 L
s
.49886 .34513 m
.50218 .34069 L
s
.4972 .3451 m
.50052 .34066 L
s
0 0 0 r
.58453 .33888 m
.58696 .33392 L
s
.59491 .3286 m
.59597 .32854 L
s
.58618 .33879 m
.58934 .33232 L
s
.49702 .35904 m
.49773 .3596 L
s
.59597 .32854 m
.59928 .33154 L
s
.50058 .35917 m
.50108 .35966 L
s
.255 .412 .882 r
.49719 .34961 m
.49886 .34513 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49554 .34958 m
.4972 .3451 L
s
0 0 0 r
.50274 .36292 m
.50108 .35966 L
s
.255 .412 .882 r
.56338 .34015 m
.5683 .33771 L
s
.56502 .34009 m
.5683 .33771 L
s
.5683 .33771 m
.57323 .3375 L
s
0 0 0 r
.50107 .3629 m
.49773 .3596 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57323 .3375 m
.57652 .33961 L
s
.5634 .34466 m
.56502 .34009 L
s
.56175 .34472 m
.56338 .34015 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58945 .32088 m
.6008 .32013 L
s
.49551 .35636 m
.49719 .34961 L
s
.56175 .34472 m
.56177 .34924 L
s
.49386 .35632 m
.49554 .34958 L
s
.5634 .34466 m
.56342 .34918 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4758 .33766 m
.48222 .36959 L
s
.46903 .36907 m
.4758 .33766 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57652 .33961 m
.57983 .34397 L
s
.51209 .35663 m
.5237 .35667 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53364 .33857 m
.53368 .37022 L
s
.53529 .33855 m
.53534 .3702 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57108 .37408 m
.57149 .37507 L
s
.56975 .37496 m
.56982 .37513 L
s
.255 .412 .882 r
.47067 .36914 m
.47576 .34443 L
s
.53532 .35661 m
.53699 .36338 L
s
.46269 .33704 m
.46903 .36907 L
s
.4559 .36841 m
.46269 .33704 L
s
.56177 .34924 m
.56344 .35371 L
s
.56342 .34918 m
.56509 .35365 L
s
.58469 .33693 m
.58632 .33684 L
s
.58143 .33936 m
.58469 .33693 L
s
.58307 .33928 m
.58469 .33693 L
s
.57983 .34397 m
.58143 .33936 L
s
.58147 .34388 m
.58307 .33928 L
s
.49548 .36769 m
.49551 .35636 L
s
.49382 .36765 m
.49386 .35632 L
s
.56344 .35371 m
.5684 .35579 L
s
.58147 .34388 m
.58158 .35974 L
s
.56509 .35365 m
.5684 .35579 L
s
0 0 0 r
.58625 .36393 m
.58638 .36464 L
s
.255 .412 .882 r
.53699 .36338 m
.54032 .36787 L
s
.45754 .3685 m
.46264 .34382 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54695 .36549 m
.5486 .36318 L
s
.5486 .36318 m
.55026 .36541 L
s
.5684 .35579 m
.57828 .35763 L
s
.44641 .33606 m
.44803 .33616 L
s
.54695 .36549 m
.54861 .36772 L
s
.54032 .36787 m
.54364 .37009 L
s
.55026 .36541 m
.55027 .36768 L
s
.44315 .33809 m
.44641 .33606 L
s
.44477 .33821 m
.44641 .33606 L
s
.52869 .37025 m
.53534 .3702 L
s
.49548 .36769 m
.49711 .37454 L
s
.54862 .36999 m
.55027 .36768 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56349 .36277 m
.5635 .36504 L
s
.56349 .36277 m
.56514 .36271 L
s
.49382 .36765 m
.49545 .3745 L
s
.59615 .34303 m
.59935 .33829 L
s
.59935 .33829 m
.60257 .33581 L
s
.54364 .37009 m
.54862 .36999 L
s
.51871 .38618 m
.51872 .37253 L
s
.51705 .37934 m
.51872 .37253 L
s
0 0 0 r
.5695 .37514 m
.57483 .37493 L
s
.255 .412 .882 r
.60257 .33581 m
.6058 .33557 L
s
.56514 .36271 m
.56515 .36498 L
s
0 0 0 r
.60438 .3513 m
.60441 .3538 L
s
.255 .412 .882 r
.4431 .34262 m
.44477 .33821 L
s
0 0 0 r
.60601 .35011 m
.60605 .35369 L
s
.255 .412 .882 r
.5635 .36504 m
.56516 .36725 L
s
.44148 .3425 m
.44315 .33809 L
s
.57828 .35763 m
.57994 .35982 L
s
.6058 .33557 m
.60905 .33759 L
s
.47727 .36941 m
.48718 .36975 L
s
.56516 .36725 m
.56848 .3694 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49711 .37454 m
.49876 .37912 L
s
.49545 .3745 m
.4971 .37909 L
s
.4383 .33774 m
.44148 .3425 L
s
.4351 .33523 m
.4383 .33774 L
s
.51372 .38387 m
.51705 .37934 L
s
.51705 .37934 m
.51871 .38618 L
s
.44295 .3585 m
.4431 .34262 L
s
.43028 .33483 m
.4351 .33523 L
s
.44128 .36294 m
.44148 .3425 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56848 .3694 m
.57507 .36913 L
s
.57997 .36436 m
.58158 .35974 L
s
.57983 .34397 m
.57997 .36436 L
s
.59432 .32057 m
.59474 .3681 L
s
.59594 .32046 m
.59637 .368 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60399 .35646 m
.60441 .3538 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60905 .33759 m
.61232 .34186 L
s
.6058 .33557 m
.61066 .33746 L
s
.49876 .37912 m
.50207 .38373 L
s
.61066 .33746 m
.61393 .34173 L
s
.4971 .37909 m
.50041 .38371 L
s
.57834 .36671 m
.57997 .36436 L
s
.50872 .38611 m
.51372 .38387 L
s
.57507 .36913 m
.57834 .36671 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42705 .33683 m
.43028 .33483 L
s
.42545 .33669 m
.43028 .33483 L
s
.50207 .38373 m
.50539 .38606 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50041 .38371 m
.50539 .38606 L
s
.50872 .38611 m
.50539 .38606 L
s
.61232 .34186 m
.614 .34854 L
s
.451 .36812 m
.46246 .36876 L
s
.61393 .34173 m
.61561 .34841 L
s
.42539 .34122 m
.42705 .33683 L
s
.42379 .34108 m
.42545 .33669 L
s
.59631 .36118 m
.59961 .36552 L
s
.58984 .36839 m
.59637 .368 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44128 .36294 m
.44295 .3585 L
s
.62505 .33396 m
.63614 .33286 L
s
.43007 .35298 m
.43973 .356 L
s
.43973 .356 m
.44133 .35839 L
s
.42534 .34576 m
.42539 .34122 L
s
.614 .34854 m
.61406 .35309 L
s
.42374 .34562 m
.42379 .34108 L
s
.61561 .34841 m
.61566 .35296 L
s
.59961 .36552 m
.60288 .36758 L
s
.42534 .34576 m
.42689 .35044 L
s
.43964 .3651 m
.44128 .36294 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61252 .36004 m
.61406 .35309 L
s
.42374 .34562 m
.42528 .35031 L
s
.42689 .35044 m
.43007 .35298 L
s
.42528 .35031 m
.43007 .35298 L
s
.61413 .35991 m
.61566 .35296 L
s
.60288 .36758 m
.60613 .36735 L
s
.43637 .36714 m
.43964 .3651 L
s
.60934 .36484 m
.61252 .36004 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60613 .36735 m
.60934 .36484 L
s
.60613 .36735 m
.61096 .36472 L
s
.61096 .36472 m
.61413 .35991 L
s
.42992 .36665 m
.43637 .36714 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6314 .33334 m
.63204 .38126 L
s
.62982 .3335 m
.63045 .38141 L
s
.42517 .35941 m
.42678 .35955 L
s
.42675 .36183 m
.42678 .35955 L
s
.42515 .36169 m
.42517 .35941 L
s
.42672 .36411 m
.42992 .36665 L
s
.39237 .33095 m
.40329 .33222 L
s
.42515 .36169 m
.42672 .36411 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39811 .36364 m
.3986 .33169 L
s
.39654 .36347 m
.39704 .33151 L
s
.63174 .35837 m
.63497 .36263 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64713 .33165 m
.64751 .35674 L
s
.64869 .33147 m
.64908 .35656 L
s
.64243 .33218 m
.65335 .33091 L
s
.40921 .36022 m
.41082 .3581 L
s
.41082 .3581 m
.41238 .36054 L
s
.41235 .36282 m
.41238 .36054 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41073 .36495 m
.41235 .36282 L
s
.40921 .36022 m
.41076 .36267 L
s
.63497 .36263 m
.63975 .36444 L
s
.40598 .36448 m
.41073 .36495 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39832 .34992 m
.39978 .35695 L
s
.65953 .33013 m
.67023 .32867 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62565 .38183 m
.63204 .38126 L
s
.40286 .36186 m
.40598 .36448 L
s
.63975 .36444 m
.6429 .36411 L
s
.39978 .35695 m
.40286 .36186 L
s
.64601 .36149 m
.64751 .35674 L
s
.6429 .36411 m
.64601 .36149 L
s
.6429 .36411 m
.64758 .36131 L
s
.64758 .36131 m
.64908 .35656 L
s
.38001 .33164 m
.383 .33661 L
s
.383 .33661 m
.38446 .34138 L
s
.37548 .32872 m
.38001 .33164 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39186 .36293 m
.39811 .36364 L
s
.38446 .34138 m
.38589 .34844 L
s
.37849 .33143 m
.38147 .33641 L
s
.38147 .33641 m
.38292 .34118 L
s
.37548 .32872 m
.37849 .33143 L
s
.38292 .34118 m
.38434 .34824 L
s
.38569 .3599 m
.38589 .34844 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66566 .32931 m
.66623 .36137 L
s
.66413 .32952 m
.66469 .36157 L
s
.38415 .3597 m
.38434 .34824 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36044 .32645 m
.37548 .32872 L
s
0 0 0 r
.68602 .31989 m
.6861 .31855 L
s
.255 .412 .882 r
.38403 .3666 m
.38569 .3599 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38249 .3664 m
.38415 .3597 L
s
.66007 .36215 m
.66623 .36137 L
s
.36549 .3757 m
.36642 .32739 L
s
.36398 .37548 m
.36492 .32716 L
s
.67792 .33443 m
.68084 .3294 L
s
.67655 .34153 m
.67792 .33443 L
s
.38241 .37101 m
.38403 .3666 L
s
.68084 .3294 m
.68527 .3264 L
s
.67943 .33421 m
.68233 .32916 L
s
.67805 .34131 m
.67943 .33421 L
s
.38087 .37081 m
.38249 .3664 L
s
.68233 .32916 m
.68527 .3264 L
s
.67655 .34153 m
.67663 .34612 L
s
.67805 .34131 m
.67814 .3459 L
s
.68527 .3264 m
.68824 .32592 L
s
.37925 .37523 m
.38241 .37101 L
s
.67663 .34612 m
.67827 .35279 L
s
.37771 .37503 m
.38087 .37081 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67814 .3459 m
.67978 .35257 L
s
.66339 .37557 m
.66489 .37307 L
s
.66339 .37557 m
.66497 .37769 L
s
.66489 .37307 m
.66647 .37519 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37461 .37694 m
.37925 .37523 L
s
.66497 .37769 m
.66647 .37519 L
s
.67827 .35279 m
.68137 .35696 L
s
.37461 .37694 m
.37771 .37503 L
s
.67978 .35257 m
.68288 .35673 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68824 .32592 m
.69271 .32748 L
s
.69271 .32748 m
.69574 .33157 L
s
.68137 .35696 m
.68591 .35859 L
s
.68288 .35673 m
.68591 .35859 L
s
.68591 .35859 m
.69038 .3579 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35947 .37483 m
.37461 .37694 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69314 .34818 m
.69457 .34563 L
s
.69314 .34818 m
.69467 .35025 L
s
.69457 .34563 m
.69609 .3477 L
s
.69038 .3579 m
.69329 .35511 L
s
.70575 .32284 m
.70728 .32718 L
s
.70575 .32284 m
.70595 .33206 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69329 .35511 m
.69614 .35001 L
s
.69609 .3477 m
.69614 .35001 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70595 .33206 m
.70728 .32718 L
s
.70728 .32718 m
.70866 .3246 L
s
.70866 .3246 m
.71146 .32175 L
s
.71146 .32175 m
.71711 .32061 L
s
.70627 .34592 m
.70765 .34334 L
s
.70627 .34592 m
.70637 .35055 L
s
.70765 .34334 m
.71046 .34049 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70632 .34823 m
.70771 .34566 L
s
.70771 .34566 m
.71052 .34281 L
s
.71711 .32061 m
.71997 .32234 L
s
.70637 .35055 m
.70786 .35261 L
s
.71046 .34049 m
.71745 .33448 L
s
.71052 .34281 m
.7175 .3368 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70786 .35261 m
.71079 .3544 L
s
.71997 .32234 m
.72142 .32437 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71745 .33448 m
.7202 .3316 L
s
.72142 .32437 m
.72159 .33131 L
s
.71079 .3544 m
.71648 .35333 L
s
.7175 .3368 m
.72025 .33392 L
s
.7202 .3316 m
.72154 .32899 L
s
.72025 .33392 m
.72159 .33131 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71648 .35333 m
.71924 .35045 L
s
.71924 .35045 m
.72059 .34785 L
s
.72059 .34785 m
.72188 .34291 L
s
.72188 .34291 m
.7221 .35222 L
s
.72059 .34785 m
.7221 .35222 L
s
.73101 .31995 m
.73231 .31732 L
s
.31271 .3219 m
.31413 .31989 L
s
.31283 .31726 m
.31413 .31989 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73231 .31732 m
.73372 .31933 L
s
.73101 .31995 m
.73243 .32196 L
s
.31142 .31927 m
.31283 .31726 L
s
.73243 .32196 m
.73372 .31933 L
s
.31142 .31927 m
.31271 .3219 L
s
.31241 .33352 m
.31305 .36184 L
s
.31033 .36125 m
.31241 .33352 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73209 .36189 m
.73273 .33358 L
s
.73309 .34757 m
.73345 .3616 L
s
.73273 .33358 m
.73482 .36131 L
s
.31169 .36155 m
.31205 .34751 L
s
.30075 .3167 m
.30201 .31935 L
s
.30182 .32635 m
.30201 .31935 L
s
.2982 .3137 m
.30075 .3167 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3005 .32602 m
.30188 .32401 L
s
.73209 .36189 m
.73357 .36629 L
s
.31157 .36624 m
.31305 .36184 L
s
.30043 .32835 m
.30182 .32635 L
s
.29302 .31234 m
.2982 .3137 L
s
0 0 0 r
.28241 .30173 m
.2848 .3024 L
s
.255 .412 .882 r
.29781 .3277 m
.3005 .32602 L
s
.73357 .36629 m
.73482 .36131 L
s
.31033 .36125 m
.31157 .36624 L
s
.29775 .33004 m
.30043 .32835 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30005 .34239 m
.3015 .33803 L
s
.30124 .3474 m
.3015 .33803 L
s
.29121 .33072 m
.29781 .3277 L
s
.2904 .31399 m
.29302 .31234 L
s
.29114 .33306 m
.29775 .33004 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29867 .34442 m
.30005 .34239 L
s
.30005 .34239 m
.30124 .3474 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29598 .34612 m
.29867 .34442 L
s
.28906 .31598 m
.2904 .31399 L
s
.28793 .31095 m
.28906 .31598 L
s
.28765 .32031 m
.28793 .31095 L
s
.28765 .32031 m
.28906 .31598 L
s
.2908 .34481 m
.29598 .34612 L
s
.28858 .33239 m
.29121 .33072 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28852 .33474 m
.29114 .33306 L
s
.28725 .3344 m
.28858 .33239 L
s
.28718 .33675 m
.28852 .33474 L
s
.28831 .34179 m
.2908 .34481 L
s
.28711 .3391 m
.28725 .3344 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28278 .33249 m
.28294 .3315 L
s
.5 Mabswid
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28711 .3391 m
.28831 .34179 L
s
.2767 .31004 m
.279 .31548 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27315 .30658 m
.2767 .31004 L
s
.27077 .30582 m
.27315 .30658 L
s
.27843 .33432 m
.2785 .33196 L
s
.27735 .32924 m
.2785 .33196 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27606 .33124 m
.27735 .32924 L
s
.27584 .33833 m
.27843 .33432 L
s
.27606 .33124 m
.27721 .33396 L
s
.26833 .30741 m
.27077 .30582 L
s
.26716 .30702 m
.27077 .30582 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27334 .33999 m
.27584 .33833 L
s
.26584 .31136 m
.26833 .30741 L
s
.26468 .31097 m
.26716 .30702 L
s
.26974 .3389 m
.27334 .33999 L
s
.26445 .31807 m
.26584 .31136 L
s
.2633 .31769 m
.26468 .31097 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26744 .3358 m
.26974 .3389 L
s
.26626 .33543 m
.26974 .3389 L
s
.2643 .32281 m
.26445 .31807 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26524 .3303 m
.26744 .3358 L
s
.26315 .32243 m
.2633 .31769 L
s
.2643 .32281 m
.26524 .3303 L
s
.26408 .32993 m
.26626 .33543 L
s
.25145 .29906 m
.25919 .30191 L
s
.26315 .32243 m
.26408 .32993 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25474 .33401 m
.25584 .3007 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25363 .33362 m
.25473 .30029 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25033 .33244 m
.25474 .33401 L
s
.23993 .29439 m
.24717 .29739 L
s
.25307 .35039 m
.25427 .34837 L
s
.25323 .34559 m
.25427 .34837 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79908 .29704 m
.80927 .29272 L
s
.25205 .3476 m
.25323 .34559 L
s
.24312 .32242 m
.24403 .29612 L
s
.25205 .3476 m
.25307 .35039 L
s
.24208 .32201 m
.24299 .29569 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24192 .32681 m
.24312 .32242 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80221 .29577 m
.80395 .34616 L
s
.24088 .3264 m
.24208 .32201 L
s
.23876 .32798 m
.24192 .32681 L
s
.80927 .29272 m
.81131 .29423 L
s
.80927 .29272 m
.81228 .29379 L
s
.22923 .28951 m
.23594 .29264 L
s
.23876 .32798 m
.24088 .3264 L
s
.81131 .29423 m
.81341 .29815 L
s
.23674 .32714 m
.23876 .32798 L
s
.2312 .34199 m
.23302 .29131 L
s
.81228 .29379 m
.81437 .2977 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8008 .34735 m
.81106 .34331 L
s
.80324 .29534 m
.80499 .34576 L
s
.23024 .34157 m
.23206 .29086 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23385 .32346 m
.23674 .32714 L
s
.81341 .29815 m
.81454 .30252 L
s
.81437 .2977 m
.81549 .30207 L
s
.23207 .31778 m
.23385 .32346 L
s
.81454 .30252 m
.81575 .30931 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81549 .30207 m
.81669 .30886 L
s
.81575 .30931 m
.81619 .32139 L
s
.81106 .34331 m
.81295 .34006 L
s
.81106 .34331 m
.81392 .33964 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81669 .30886 m
.81713 .32096 L
s
.81295 .34006 m
.81471 .33437 L
s
.8155 .32909 m
.81619 .32139 L
s
.81392 .33964 m
.81567 .33394 L
s
.81471 .33437 m
.8155 .32909 L
s
.22738 .34031 m
.2312 .34199 L
s
.81645 .32866 m
.81713 .32096 L
s
.81567 .33394 m
.81645 .32866 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81967 .28776 m
.82583 .2845 L
s
.5 Mabswid
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82236 .28637 m
.82362 .3203 L
s
.82324 .28591 m
.8245 .31986 L
s
.22103 .28777 m
.2226 .29354 L
s
.2226 .29354 m
.22322 .30125 L
s
.22304 .3061 m
.22322 .30125 L
s
.22016 .2873 m
.22172 .29307 L
s
.22172 .29307 m
.22233 .3008 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22089 .30928 m
.22092 .30852 L
s
.5 Mabswid
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21855 .28394 m
.22103 .28777 L
s
.22188 .31293 m
.22304 .3061 L
s
.22215 .30564 m
.22233 .3008 L
s
.82092 .32163 m
.8245 .31986 L
s
.21855 .28394 m
.22016 .2873 L
s
.221 .31248 m
.22215 .30564 L
s
.82396 .30527 m
.82511 .31211 L
s
.21115 .2621 m
.21669 .26557 L
s
.21688 .28299 m
.21855 .28394 L
s
.21994 .31689 m
.22188 .31293 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21907 .31644 m
.221 .31248 L
s
.82511 .31211 m
.82702 .31607 L
s
.21514 .28446 m
.21688 .28299 L
s
.21231 .31523 m
.21427 .26409 L
s
.21727 .31798 m
.21994 .31689 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21972 .34091 m
.21974 .34015 L
s
.5 Mabswid
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21151 .31476 m
.21348 .2636 L
s
.21727 .31798 m
.21907 .31644 L
s
.21334 .28836 m
.21514 .28446 L
s
.21559 .31707 m
.21727 .31798 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82702 .31607 m
.82881 .3176 L
s
.82881 .3176 m
.83131 .31623 L
s
.8303 .3118 m
.83121 .31379 L
s
.8303 .3118 m
.83103 .3089 L
s
.21403 .3137 m
.21559 .31707 L
s
.83103 .3089 m
.83193 .31088 L
s
.21259 .30788 m
.21403 .3137 L
s
.83131 .31623 m
.83203 .31332 L
s
.83193 .31088 m
.83203 .31332 L
s
.20823 .27764 m
.20898 .27813 L
s
.20917 .31336 m
.21231 .31523 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20667 .27909 m
.20823 .27764 L
s
.2074 .27959 m
.20823 .27764 L
s
.83656 .28555 m
.83712 .28017 L
s
.83656 .28555 m
.83675 .29043 L
s
.83712 .28017 m
.83922 .27624 L
s
.83675 .29043 m
.83769 .29485 L
s
.83731 .28506 m
.83786 .27968 L
s
.83731 .28506 m
.8375 .28995 L
s
.83786 .27968 m
.83922 .27624 L
s
.20647 .28398 m
.2074 .27959 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8375 .28995 m
.83843 .29436 L
s
.20575 .28349 m
.20667 .27909 L
s
.83922 .27624 m
.84134 .27474 L
s
.83769 .29485 m
.83999 .29584 L
s
.2058 .30116 m
.20647 .28398 L
s
.83843 .29436 m
.83999 .29584 L
s
.20453 .2776 m
.20575 .28349 L
s
.20488 .3056 m
.20575 .28349 L
s
.83807 .30466 m
.83817 .30712 L
s
.83807 .30466 m
.83882 .30418 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83817 .30712 m
.83901 .3091 L
s
.20324 .27414 m
.20453 .2776 L
s
.83882 .30418 m
.83891 .30664 L
s
.84134 .27474 m
.84281 .27618 L
s
.83999 .29584 m
.84426 .29537 L
s
.20488 .3056 m
.2058 .30116 L
s
.83901 .3091 m
.84057 .31061 L
s
.20122 .27262 m
.20324 .27414 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20446 .29773 m
.20508 .30067 L
s
.20044 .29232 m
.20446 .29773 L
s
.84281 .27618 m
.84434 .28009 L
s
.20407 .30758 m
.20488 .3056 L
s
.84057 .31061 m
.84339 .30869 L
s
0 0 0 r
.84804 .27028 m
.84856 .26625 L
s
.255 .412 .882 r
.20256 .30909 m
.20407 .30758 L
s
.19982 .27406 m
.20122 .27262 L
s
.19919 .27355 m
.20122 .27262 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84434 .28009 m
.8448 .27466 L
s
.84434 .28009 m
.84522 .30229 L
s
.8448 .27466 m
.84599 .27118 L
s
.19985 .30715 m
.20256 .30909 L
s
.845 .27958 m
.84545 .27415 L
s
.845 .27958 m
.84569 .29685 L
s
.84545 .27415 m
.84599 .27118 L
s
.19899 .27848 m
.19982 .27406 L
s
.84426 .29537 m
.84503 .29734 L
s
.84599 .27118 m
.84662 .27067 L
s
0 0 0 r
.85071 .28631 m
.85071 .28632 L
s
.255 .412 .882 r
.84339 .30869 m
.84465 .30525 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19836 .27797 m
.19919 .27355 L
s
.19923 .28885 m
.20044 .29232 L
s
.19859 .28835 m
.20044 .29232 L
s
.19879 .28341 m
.19899 .27848 L
s
.84465 .30525 m
.84522 .30229 L
s
.84522 .30229 m
.84569 .29685 L
s
.19879 .28341 m
.19923 .28885 L
s
.19816 .2829 m
.19836 .27797 L
s
.19816 .2829 m
.19859 .28835 L
s
.19864 .30369 m
.19985 .30715 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1982 .29824 m
.19884 .29874 L
s
.19874 .30122 m
.19884 .29874 L
s
.1981 .30072 m
.19864 .30369 L
s
.1981 .30072 m
.1982 .29824 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84925 .30429 m
.85332 .3008 L
s
.8519 .26598 m
.85545 .29878 L
s
.85105 .3028 m
.8519 .26598 L
s
.85163 .3023 m
.8522 .27342 L
s
.19282 .29373 m
.19328 .29673 L
s
.19318 .29922 m
.19328 .29673 L
s
.19252 .30121 m
.19318 .29922 L
s
.19217 .29572 m
.19282 .29373 L
s
.18794 .26003 m
.19128 .26377 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19217 .29572 m
.19262 .29872 L
s
.19089 .2997 m
.19252 .30121 L
s
0 0 0 r
.18284 .24861 m
.18459 .25075 L
s
.255 .412 .882 r
.18835 .29716 m
.18979 .26218 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85599 .26174 m
.85927 .29468 L
s
.85545 .29878 m
.85599 .26174 L
s
.18995 .29618 m
.19089 .2997 L
s
.18787 .29664 m
.18932 .26164 L
s
.85596 .29827 m
.85629 .26921 L
s
.18915 .29015 m
.18995 .29618 L
s
.18897 .28213 m
.18915 .29015 L
s
0 0 0 r
.86212 .24916 m
.86247 .24871 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86247 .24871 m
.86345 .25117 L
s
.86247 .24871 m
.86384 .25061 L
s
.255 .412 .882 r
.18648 .2951 m
.18835 .29716 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18248 .28957 m
.1829 .27969 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85791 .29622 m
.86055 .29312 L
s
0 0 0 r
.18248 .28957 m
.18263 .29717 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1846 .27686 m
.18544 .25677 L
s
.18422 .27632 m
.18506 .25623 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18312 .27472 m
.18581 .27845 L
s
.18422 .25764 m
.18474 .26375 L
s
.18329 .25348 m
.18422 .25764 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86488 .26526 m
.86527 .27447 L
s
.86458 .26794 m
.86489 .27533 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86153 .2678 m
.86168 .26222 L
s
.86148 .27589 m
.86153 .2678 L
s
.86168 .26222 m
.86215 .2561 L
s
.86148 .27589 m
.86201 .28851 L
s
.86189 .26725 m
.86202 .26168 L
s
.86185 .27535 m
.86189 .26725 L
s
.18265 .25238 m
.18329 .25348 L
s
.86202 .26168 m
.86247 .25555 L
s
.86185 .27535 m
.86238 .28798 L
s
.86215 .2561 m
.86299 .25192 L
s
.18322 .30971 m
.18386 .29451 L
s
.18316 .30159 m
.18386 .29451 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86247 .25555 m
.86299 .25192 L
s
.86201 .28851 m
.8627 .29558 L
s
.18194 .25379 m
.18265 .25238 L
s
.18165 .25324 m
.18265 .25238 L
s
.86238 .28798 m
.86306 .29505 L
s
.1822 .30563 m
.18316 .30159 L
s
.18316 .30159 m
.18322 .30971 L
s
.86299 .25192 m
.86358 .25081 L
s
.8627 .29558 m
.86327 .30013 L
s
.18116 .25774 m
.18194 .25379 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86306 .29505 m
.86362 .29961 L
s
.86358 .25081 m
.86449 .25167 L
s
.18089 .25718 m
.18165 .25324 L
s
.86327 .30013 m
.86418 .30418 L
s
.18104 .30663 m
.1822 .30563 L
s
.86362 .29961 m
.86451 .30366 L
s
.18068 .26225 m
.18116 .25774 L
s
.86449 .25167 m
.86519 .25562 L
s
.18042 .2617 m
.18089 .25718 L
s
.86418 .30418 m
.86525 .30517 L
s
.1804 .3056 m
.18104 .30663 L
s
.1801 .26931 m
.18068 .26225 L
s
.86451 .30366 m
.86525 .30517 L
s
.86487 .24802 m
.86574 .26832 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17985 .26877 m
.18042 .2617 L
s
.86499 .26996 m
.86659 .26613 L
s
.8651 .24746 m
.86596 .26777 L
s
.17989 .30201 m
.1804 .3056 L
s
.1796 .30148 m
.1804 .3056 L
s
.17955 .28204 m
.1801 .26931 L
s
.86525 .30517 m
.86584 .30413 L
s
0 0 0 r
.86936 .23625 m
.87053 .23219 L
s
.255 .412 .882 r
.17931 .2815 m
.17985 .26877 L
s
.17954 .29585 m
.17989 .30201 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17927 .29533 m
.1796 .30148 L
s
.17949 .29022 m
.17955 .28204 L
s
.17949 .29022 m
.17954 .29585 L
s
.86584 .30413 m
.86655 .30001 L
s
.17923 .28969 m
.17931 .2815 L
s
.17923 .28969 m
.17927 .29533 L
s
0 0 0 r
.86992 .23451 m
.87166 .27456 L
s
.255 .412 .882 r
.86655 .30001 m
.86682 .29384 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17496 .24529 m
.17495 .23688 L
s
.17467 .25677 m
.17496 .24529 L
s
.255 .412 .882 r
.86673 .28563 m
.86738 .301 L
s
.86673 .28563 m
.86682 .29384 L
s
.86682 .29384 m
.86738 .301 L
s
0 0 0 r
.17435 .26406 m
.17467 .25677 L
s
.17495 .23688 m
.17471 .23151 L
s
.1748 .24472 m
.17481 .2363 L
s
.17449 .25621 m
.1748 .24472 L
s
.17417 .2635 m
.17449 .25621 L
s
.17481 .2363 m
.17471 .23151 L
s
.1737 .27446 m
.17435 .26406 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17727 .27866 m
.1783 .2819 L
s
0 0 0 r
.17353 .27391 m
.17417 .2635 L
s
.255 .412 .882 r
.17774 .28028 m
.17866 .24228 L
s
.17669 .27594 m
.17866 .24228 L
s
0 0 0 r
.17471 .23151 m
.17449 .23034 L
s
.255 .412 .882 r
.17678 .27649 m
.17834 .24993 L
s
0 0 0 r
.87166 .27456 m
.87214 .28134 L
s
.17306 .2807 m
.1737 .27446 L
s
.17449 .23034 m
.17416 .23282 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86683 .24182 m
.86836 .27767 L
s
.8667 .24238 m
.86823 .27822 L
s
.86626 .24408 m
.86714 .24011 L
s
0 0 0 r
.87009 .23394 m
.87183 .27401 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8723 .2808 m
.87183 .27401 L
s
.17291 .28015 m
.17353 .27391 L
s
.255 .412 .882 r
.86779 .27984 m
.86836 .27767 L
s
0 0 0 r
.87133 .22576 m
.87097 .22986 L
s
.87275 .28338 m
.87214 .28134 L
s
.255 .412 .882 r
.8677 .26227 m
.86815 .26941 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17416 .23282 m
.17371 .23897 L
s
.87275 .28338 m
.8723 .2808 L
s
.17249 .28273 m
.17306 .2807 L
s
.17249 .28273 m
.17291 .28015 L
s
.17419 .228 m
.17405 .22566 L
s
.873 .28228 m
.87275 .28338 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86815 .26941 m
.86857 .27346 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17669 .27594 m
.17796 .23772 L
s
.1763 .27156 m
.17796 .23772 L
s
0 0 0 r
.17227 .28164 m
.17249 .28273 L
s
.255 .412 .882 r
.17631 .27211 m
.17763 .24542 L
s
.86857 .27346 m
.86885 .27495 L
s
0 0 0 r
.87313 .27695 m
.873 .28228 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17082 .30541 m
.17419 .228 L
s
.17077 .30487 m
.17414 .22742 L
s
.17225 .27685 m
.17227 .28164 L
s
.87294 .26846 m
.87313 .27695 L
s
.17243 .26836 m
.17225 .27685 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86868 .26555 m
.86875 .26869 L
s
.86875 .26869 m
.8689 .27072 L
s
.86885 .27495 m
.86901 .27331 L
s
0 0 0 r
.87119 .22811 m
.87343 .27954 L
s
.87124 .22752 m
.87348 .27899 L
s
.255 .412 .882 r
.86868 .26555 m
.86882 .26758 L
s
.17634 .26991 m
.17641 .27375 L
s
0 0 0 r
.87358 .27734 m
.87343 .27954 L
s
.255 .412 .882 r
.86894 .27017 m
.86901 .27331 L
s
.86882 .26758 m
.86894 .27017 L
s
0 0 0 r
.17105 .307 m
.17077 .30487 L
s
.255 .412 .882 r
.17802 .23198 m
.17797 .23256 L
s
0 0 0 r
.17364 .23375 m
.17407 .22521 L
s
.17313 .24539 m
.17364 .23375 L
s
.17407 .22521 m
.17447 .21976 L
s
.17281 .25278 m
.17313 .24539 L
s
.87171 .23327 m
.87223 .24492 L
s
.87127 .22473 m
.87171 .23327 L
s
.255 .412 .882 r
.17805 .23341 m
.17802 .23198 L
s
.17798 .23399 m
.17802 .23198 L
s
0 0 0 r
.17369 .23317 m
.17414 .22463 L
s
.17316 .24481 m
.17369 .23317 L
s
.255 .412 .882 r
.86749 .23467 m
.86776 .2404 L
s
.86776 .2404 m
.86798 .24557 L
s
.86715 .23036 m
.86749 .23467 L
s
0 0 0 r
.87084 .21928 m
.87127 .22473 L
s
.87223 .24492 m
.87255 .25231 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17414 .22463 m
.17447 .21976 L
s
.17284 .25221 m
.17316 .24481 L
s
.87165 .23269 m
.87219 .24434 L
s
.87119 .22414 m
.87165 .23269 L
s
.255 .412 .882 r
.86798 .24557 m
.86815 .25018 L
s
0 0 0 r
.17236 .26332 m
.17281 .25278 L
s
.255 .412 .882 r
.86742 .23409 m
.86771 .23983 L
s
.86771 .23983 m
.86793 .245 L
s
.86715 .23036 m
.86742 .23409 L
s
.17783 .23859 m
.17798 .23399 L
s
0 0 0 r
.87084 .21928 m
.87119 .22414 L
s
.87219 .24434 m
.87251 .25174 L
s
.87255 .25231 m
.87299 .26286 L
s
.255 .412 .882 r
.86793 .245 m
.86809 .24962 L
s
0 0 0 r
.1724 .26276 m
.17284 .25221 L
s
.17284 .25221 m
.17412 .24535 L
s
.17447 .21976 m
.17468 .21858 L
s
.255 .412 .882 r
.17792 .23801 m
.17805 .23341 L
s
.86684 .22862 m
.86715 .23036 L
s
.86804 .25109 m
.86815 .25018 L
s
0 0 0 r
.87251 .25174 m
.87294 .2623 L
s
.87061 .21809 m
.87084 .21928 L
s
.255 .412 .882 r
.17705 .25674 m
.17783 .23859 L
s
.86804 .25109 m
.86809 .24962 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17214 .26964 m
.17236 .26332 L
s
.17468 .21858 m
.17492 .2205 L
s
.255 .412 .882 r
.17792 .23801 m
.17834 .23169 L
s
.17691 .26139 m
.17792 .23801 L
s
.8686 .26056 m
.86871 .26316 L
s
.86854 .26 m
.8686 .26056 L
s
0 0 0 r
.87299 .26286 m
.8732 .26918 L
s
.1722 .26908 m
.1724 .26276 L
s
.255 .412 .882 r
.86871 .26316 m
.86876 .2652 L
s
0 0 0 r
.87049 .22061 m
.87061 .21809 L
s
.87034 .22002 m
.87061 .21809 L
s
.255 .412 .882 r
.17834 .23169 m
.17871 .22794 L
s
.86854 .26 m
.86865 .2626 L
s
0 0 0 r
.87294 .2623 m
.87312 .26862 L
s
.255 .412 .882 r
.86668 .23006 m
.86684 .22862 L
s
.86742 .25031 m
.86804 .25109 L
s
.17691 .26139 m
.17705 .25674 L
s
.86872 .2667 m
.86876 .2652 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17221 .2717 m
.17214 .26964 L
s
.255 .412 .882 r
.17714 .25618 m
.17734 .25302 L
s
0 0 0 r
.8705 .22685 m
.87049 .22061 L
s
.17492 .2205 m
.17492 .22674 L
s
.8732 .26918 m
.8731 .27124 L
s
.255 .412 .882 r
.1769 .26344 m
.17691 .26139 L
s
0 0 0 r
.17221 .2717 m
.1722 .26908 L
s
.255 .412 .882 r
.86668 .23006 m
.86659 .23411 L
s
0 0 0 r
.87032 .22626 m
.87034 .22002 L
s
.255 .412 .882 r
.86827 .26449 m
.86872 .2667 L
s
0 0 0 r
.87312 .26862 m
.8731 .27124 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17734 .25302 m
.17827 .24704 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1769 .26344 m
.17701 .26494 L
s
0 0 0 r
.17254 .27003 m
.17221 .2717 L
s
.8708 .23742 m
.8705 .22685 L
s
.255 .412 .882 r
.8662 .22833 m
.86659 .23411 L
s
.86571 .22457 m
.8662 .22833 L
s
0 0 0 r
.8731 .27124 m
.87287 .27013 L
s
.87062 .23685 m
.87032 .22626 L
s
.255 .412 .882 r
.86601 .22775 m
.86642 .23354 L
s
.86571 .22457 m
.86601 .22775 L
s
.86737 .25236 m
.86742 .25031 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86666 .23923 m
.8672 .2518 L
s
.86684 .23997 m
.8676 .25759 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86787 .26077 m
.86827 .26449 L
s
0 0 0 r
.17395 .24592 m
.17346 .25713 L
s
.255 .412 .882 r
.17827 .24704 m
.17852 .24505 L
s
.17827 .24704 m
.17859 .24492 L
s
0 0 0 r
.87287 .27013 m
.87243 .26527 L
s
.87287 .27013 m
.87228 .26471 L
s
.87113 .24488 m
.8708 .23742 L
s
.17298 .26517 m
.17254 .27003 L
s
.17412 .24535 m
.17379 .25282 L
s
.255 .412 .882 r
.8676 .25759 m
.86787 .26077 L
s
0 0 0 r
.87094 .24431 m
.87062 .23685 L
s
.255 .412 .882 r
.8672 .2518 m
.8676 .25759 L
s
0 0 0 r
.87113 .24488 m
.87179 .25666 L
s
.17346 .25713 m
.17298 .26517 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87243 .26527 m
.87179 .25666 L
s
.1733 .26087 m
.17298 .26517 L
s
.17379 .25282 m
.1733 .26087 L
s
.87094 .24431 m
.87161 .2561 L
s
.87161 .2561 m
.87228 .26471 L
s
.17682 .21832 m
.17689 .21146 L
s
.17624 .22637 m
.17689 .21146 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86653 .20742 m
.86854 .21157 L
s
.17624 .22637 m
.17682 .21832 L
s
.17682 .21832 m
.17725 .214 L
s
.17725 .214 m
.17798 .20909 L
s
.17798 .20909 m
.17926 .20672 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17527 .24885 m
.17569 .24452 L
s
.17495 .25636 m
.17527 .24885 L
s
.17569 .24452 m
.1764 .23962 L
s
.17511 .2526 m
.17553 .24828 L
s
.17553 .24828 m
.17624 .24338 L
s
.17495 .25636 m
.17504 .25957 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1764 .23962 m
.17829 .22923 L
s
.17926 .20672 m
.1798 .20928 L
s
.17624 .24338 m
.17813 .23299 L
s
.17504 .25957 m
.17543 .26222 L
s
.1798 .20928 m
.18001 .21244 L
s
.86223 .20091 m
.86512 .20505 L
s
.17543 .26222 m
.17666 .25999 L
s
.17829 .22923 m
.17916 .22431 L
s
.17953 .22373 m
.18001 .21244 L
s
.17813 .23299 m
.179 .22807 L
s
.17916 .22431 m
.17969 .21996 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86746 .2092 m
.87087 .28831 L
s
.86775 .20979 m
.87116 .28885 L
s
.179 .22807 m
.17953 .22373 L
s
.86395 .20327 m
.86735 .28292 L
s
.86354 .20268 m
.86694 .28239 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17666 .25999 m
.1775 .25509 L
s
.86993 .28669 m
.87116 .28885 L
s
.1775 .25509 m
.17802 .25074 L
s
.17802 .25074 m
.17872 .2426 L
s
.17807 .25776 m
.17872 .2426 L
s
.17802 .25074 m
.17807 .25776 L
s
.18308 .20457 m
.1837 .20021 L
s
.18308 .20457 m
.18338 .20775 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1837 .20021 m
.18401 .20339 L
s
.18338 .20775 m
.18401 .20339 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18111 .27192 m
.18258 .22668 L
s
.18017 .273 m
.18258 .22668 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18679 .24456 m
.18733 .23157 L
s
0 0 0 r
.85978 .20873 m
.86078 .22069 L
s
.8584 .19998 m
.85978 .20873 L
s
.85655 .19444 m
.8584 .19998 L
s
.86078 .22069 m
.8611 .2283 L
s
.85925 .20815 m
.86026 .22012 L
s
.85784 .1994 m
.85925 .20815 L
s
.86562 .28077 m
.86735 .28292 L
s
.18064 .27246 m
.18161 .2495 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18766 .23478 m
.18781 .23117 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85655 .19444 m
.85784 .1994 L
s
.86026 .22012 m
.86058 .22773 L
s
.86107 .23917 m
.8611 .2283 L
s
.86054 .23861 m
.86058 .22773 L
s
.18017 .273 m
.18031 .28014 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85757 .26392 m
.85921 .26567 L
s
.85602 .22672 m
.85614 .22963 L
s
.85747 .26158 m
.85757 .26392 L
s
.85657 .22802 m
.85665 .23003 L
s
.85802 .26288 m
.85809 .26445 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85537 .19327 m
.85655 .19444 L
s
.8543 .1959 m
.85537 .19327 L
s
.85366 .19532 m
.85537 .19327 L
s
.86032 .24571 m
.86107 .23917 L
s
.85976 .24516 m
.86054 .23861 L
s
.18031 .28014 m
.18111 .27192 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85334 .20237 m
.8543 .1959 L
s
.85268 .2018 m
.85366 .19532 L
s
.85315 .21328 m
.85334 .20237 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85878 .24789 m
.85976 .24516 L
s
.85878 .24789 m
.86032 .24571 L
s
.85249 .21272 m
.85268 .2018 L
s
.8576 .24679 m
.85878 .24789 L
s
.85315 .21328 m
.85347 .22095 L
s
.8562 .24184 m
.8576 .24679 L
s
.85557 .24129 m
.8576 .24679 L
s
.85249 .21272 m
.8528 .22039 L
s
.85347 .22095 m
.8546 .23304 L
s
.8546 .23304 m
.8562 .24184 L
s
.8528 .22039 m
.85395 .23249 L
s
.85395 .23249 m
.85557 .24129 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8444 .18786 m
.84626 .19667 L
s
.84626 .19667 m
.84749 .20878 L
s
.84183 .18231 m
.8444 .18786 L
s
.8436 .18729 m
.84549 .19611 L
s
.84549 .19611 m
.84673 .20822 L
s
.84749 .20878 m
.8478 .21649 L
s
.84183 .18231 m
.8436 .18729 L
s
.84673 .20822 m
.84704 .21594 L
s
.84751 .22754 m
.8478 .21649 L
s
.84016 .18118 m
.84183 .18231 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84674 .22699 m
.84704 .21594 L
s
.8386 .1839 m
.84016 .18118 L
s
.84627 .23421 m
.84751 .22754 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83198 .14971 m
.83824 .15374 L
s
.84547 .23367 m
.84674 .22699 L
s
.83714 .19051 m
.8386 .1839 L
s
.844 .23649 m
.84627 .23421 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83605 .21248 m
.83607 .21316 L
s
0 0 0 r
.844 .23649 m
.84547 .23367 L
s
.255 .412 .882 r
.83515 .21099 m
.83521 .21263 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83512 .21389 m
.83521 .21263 L
s
.83599 .21433 m
.83607 .21316 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83563 .15201 m
.83883 .23331 L
s
.84232 .23543 m
.844 .23649 L
s
.84044 .23046 m
.84232 .23543 L
s
.82517 .17228 m
.83113 .17558 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83837 .22159 m
.84044 .23046 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83515 .23121 m
.83883 .23331 L
s
.83473 .15143 m
.83793 .23278 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81745 .19147 m
.82708 .1962 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82469 .24135 m
.8282 .17392 L
s
.82514 .25326 m
.82919 .17447 L
s
.81203 .16586 m
.8188 .16904 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81433 .16691 m
.82514 .25326 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27208 .18805 m
.27335 .18866 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34564 .13371 m
.35012 .13299 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3494 .21872 m
.35126 .13272 L
s
.35131 .21843 m
.35315 .1324 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35012 .13299 m
.37637 .12881 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3744 .12909 m
.37591 .15329 L
s
.37591 .15329 m
.37637 .12881 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35219 .17723 m
.36374 .17546 L
s
.36341 .19192 m
.36407 .15907 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39635 .13031 m
.40254 .12552 L
s
.39418 .13872 m
.39635 .13031 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39839 .13007 m
.40254 .12552 L
s
.39622 .13848 m
.39839 .13007 L
s
.40254 .12552 m
.40665 .12507 L
s
.39345 .18396 m
.39418 .13872 L
s
.40665 .12507 m
.41279 .12851 L
s
.3955 .18373 m
.39622 .13848 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41701 .12402 m
.42538 .12324 L
s
.41624 .18166 m
.41701 .12402 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41279 .12851 m
.41684 .1363 L
s
.41834 .18147 m
.4191 .12382 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34372 .21962 m
.34825 .21897 L
s
.5 Mabswid
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34825 .21897 m
.37477 .21516 L
s
.37278 .21542 m
.37523 .1903 L
s
.37477 .21516 m
.37523 .1903 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44229 .12598 m
.4466 .12159 L
s
.4466 .12159 m
.45089 .1213 L
s
.44015 .12614 m
.4466 .12159 L
s
.43581 .13467 m
.44015 .12614 L
s
.43794 .1345 m
.44229 .12598 L
s
.45089 .1213 m
.45731 .12501 L
s
.43355 .14717 m
.43581 .13467 L
s
.38735 .18467 m
.3955 .18373 L
s
.43567 .147 m
.43794 .1345 L
s
.255 .412 .882 r
.42731 .16167 m
.4305 .1607 L
s
.42644 .16294 m
.42731 .16167 L
s
0 0 0 r
.45731 .12501 m
.46157 .13299 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57331 .12426 m
.57545 .12025 L
s
.57545 .12025 m
.57765 .12446 L
s
.255 .412 .882 r
.60798 .16088 m
.61156 .16034 L
s
0 0 0 r
.47467 .12004 m
.48995 .1195 L
s
.57551 .12847 m
.57765 .12446 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60591 .16362 m
.60798 .16088 L
s
0 0 0 r
.43345 .15541 m
.43355 .14717 L
s
.57331 .12426 m
.57551 .12847 L
s
.55145 .11939 m
.5602 .11965 L
s
.43558 .15525 m
.43567 .147 L
s
.49872 .11928 m
.5141 .11906 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54268 .11921 m
.54708 .1234 L
s
.53828 .11914 m
.54268 .11921 L
s
.53389 .1232 m
.53828 .11914 L
s
.53169 .12318 m
.53828 .11914 L
s
.43345 .15541 m
.43545 .16766 L
s
.54708 .1234 m
.5515 .13173 L
s
.43558 .15525 m
.43758 .1675 L
s
.5295 .13139 m
.53389 .1232 L
s
.5273 .13138 m
.53169 .12318 L
s
.40996 .18224 m
.41834 .18147 L
s
.52731 .14377 m
.5295 .13139 L
s
.5251 .14376 m
.5273 .13138 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43545 .16766 m
.43964 .17564 L
s
.43758 .1675 m
.44178 .17549 L
s
.4592 .15787 m
.46134 .16189 L
s
.457 .16212 m
.4592 .15787 L
s
.457 .16212 m
.45914 .16615 L
s
.52731 .14377 m
.52731 .15204 L
s
.5251 .14376 m
.5251 .15203 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50518 .17709 m
.5053 .11916 L
s
.50739 .17706 m
.5075 .11913 L
s
.43964 .17564 m
.44605 .17937 L
s
.46131 .16604 m
.46134 .16189 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44178 .17549 m
.44605 .17937 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48076 .20693 m
.48121 .11978 L
s
.48296 .20686 m
.4834 .11971 L
s
.4569 .17457 m
.46131 .16604 L
s
.52731 .15204 m
.52953 .1645 L
s
.5251 .15203 m
.52732 .16449 L
s
.44605 .17937 m
.45253 .17897 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45253 .17897 m
.4569 .17457 L
s
.54723 .17304 m
.55162 .16482 L
s
.52953 .1645 m
.53396 .17285 L
s
.52732 .16449 m
.53175 .17283 L
s
.54282 .17713 m
.54723 .17304 L
s
.53396 .17285 m
.5384 .17706 L
s
.53175 .17283 m
.5384 .17706 L
s
.49854 .1772 m
.50739 .17706 L
s
.5384 .17706 m
.54282 .17713 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57581 .17395 m
.57598 .19898 L
s
.57378 .19889 m
.57565 .14908 L
s
.57565 .14908 m
.57817 .19908 L
s
.55364 .11945 m
.55398 .20663 L
s
.55145 .11939 m
.55177 .20658 L
s
.57603 .20736 m
.57817 .19908 L
s
.57378 .19889 m
.57603 .20736 L
s
.50513 .19798 m
.50734 .20214 L
s
.5029 .20221 m
.50513 .19798 L
s
.47415 .20717 m
.48296 .20686 L
s
.5029 .20221 m
.50511 .20637 L
s
.50511 .20637 m
.50734 .20214 L
s
.54512 .20644 m
.55398 .20663 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P3o
YQ09000000/0ojH@0`0000030?nV40030:f][@000000000001`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/
UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00P0ojHA0P00000:
0?nV4@T000001`2][Jd2000000`0[Jf]0P0000030:f][@040000002][Jd0[Jf]0:f][@D000001`2]
[Jd00`000000[Jf]0:f][@0?0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o
0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ40603oYQ42000000030:f][@3oYQ40ojHA00D0ojHA00<0[Jf]0000000000000P2][Jd2
000000P0[Jf]103oYQ42000000030?nV4@2][Jd0ojH@00L0ojH@0P00000;0?nV408000001@3oYQ00
0`000000ojH@0:f][@02000000T0ojD@0P0000020?nU41@0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool0
07`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0?0?nV4@800000103oYQ43000000T0[Jf]0P0000060?nV4@030000003oYQ40ojHA
00T0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV408000002P3oYQ02000000L0ojH@00@000000:f]
[@0000000000203oYA0010000000ojD@0?nU4000000@0?nU40030:f][@3oXa00oj<@0080oj<@2@2]
[Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA00<0[Jf]0000000000000P2][Jd2
00000080[Jf]0P0000030?nV4@030:f][@3oYQ40ojHA00<0ojHA0P0000070?nV4@030000003oYQ40
ojHA00T0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV408000002P3oYQ02000000L0ojH@00@00000
0:f][@00000000002@3oYA0200000140ojD@00<0[Jf]0?nS403oXa002`3oXa0:0:f][@@0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2]
[JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01L0ojHA100000000`3oYQ40[Jf]0:f][@070:f][@8000001P3oYQ4010000000ojHA00000000
00030?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000090?nV4@030000003oYQ40ojHA00P0ojHA0P00
00000`3oYQ40[Jf]0?nV40070?nV408000002@3oYQ02000000T0ojH@0`00000:0?nU40030000003o
YA00ojD@00l0ojD@00<0[Jf]0?nS403oXa005@3oXa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0A0?nV4@H000000P2][Jd2000000030:f][@3oYQ40
ojHA00H0ojHA0P0000070?nV4@040000003oYQ400000000000<0ojHA00<0[Jf]0?nV4@3oYQ400P3o
YQ42000000T0ojHA00<000000?nV4@3oYQ40203oYQ42000000030?nV4@2][Jd0ojH@00L0ojH@0P00
00090?nV408000002@3oYQ03000001`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
40060:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`
h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0=
0?nV4@@00000102][Jd20?nV4@040:f][@3oYQ400000000000T0ojHA0P0000080?nV4@<000000`3o
YQ40102][Jd0ojHA0?nV4@3oYQ42000000/0ojHA00<000000?nV4@3oYQ401`3oYQ42000000030?nV
4@2][Jd0ojH@00L0ojH@0P0000090?nV408000002@3oYQ000`2][Jd000000000000L0?nU40030:f]
[@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1001P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3fW0l0
4`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`
h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA00/0ojHA0P0000000`2][Jd00000000000070?nV4@040:f][@3oYQ400000000000P0ojHA
0P0000090?nV4@<000000`3oYQ40102][Jd0ojHA0?nV4@3oYQ42000001D0ojHA0P0000000`3oYQ40
[Jf]0?nV40070?nV40800000203oYQ000`000000ojH@000000090?nV40030:f][@000000000001`0
ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400;0?bP40D0[Jf]203lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0
/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
503oY1400`2][Jd0ojHA0?nV4@050?nV4@H0[Jf]0`3oYQ42000000L0ojHA00@0[Jf]0?nV4@000000
0000203oYQ42000000X0ojHA0P0000030?nV4@040:f][@3oYQ40ojHA0?nV4@8000005@3oYQ420000
00030?nV4@2][Jd0ojH@00L0ojH@0P0000080?nV40030000003oYQ00000000T0ojH@00<0[Jf]0000
00000000703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@1P2][Jd20?bP
40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:
3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@050:f][@T0ojHA0P0000070?nV4@04
0:f][@3oYQ400000000000P0ojHA0P00000:0?nV4@8000000`3oYQ40102][Jd0ojHA0?nV4@3oYQ42
000001D0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV40800000203oYQ02000000X0ojH@00<0[Jf]
000000000000703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01H0o:0@102][JdE
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool0
06`0/>3V0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1440:f]
[@h0ojHA0P0000070?nV4@040:f][@3oYQ400000000000P0ojHA0P00000:0?nV4@8000000`3oYQ40
0`2][Jd0ojHA0?nV4@02000001H0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV40800000203oYQ02
000000X0ojH@00<0[Jf]000000000000703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA00l0ojHA0P0000070?nV
4@040:f][@3oYQ40ojHA000000P0ojHA0P00000:0?nV4@8000000P3oYQ40102][Jd0ojHA0?nV4@3o
YQ42000001H0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV408000001`3oYQ000`000000ojH@0000
000:0?nV40030:f][@000000000001`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42
000000L0ojHA00@0[Jf]0?nV4@3oYQ400000203oYQ42000000X0ojHA0P0000020?nV4@040:f][@3o
YQ40ojHA0?nV4@8000005P3oYQ42000000030?nV4@2][Jd0ojH@00L0ojH@0P0000070?nV40030000
003oYQ00000000X0ojH@00<0[Jf]000000000000703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102]
[Jd90?nT4@030:f][@3oYQ40ojHA00h0ojHA0P0000070?nV4@040:f][@3oYQ40ojHA000000P0ojHA
0P00000:0?nV4@8000000P3oYQ40102][Jd0ojHA0?nV4@3oYQ42000001H0ojHA0P0000000`3oYQ40
[Jf]0?nV40070?nV408000001`3oYQ000`000000ojH@0000000:0?nV40030:f][@000000000001`0
ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0
mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40
/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
0`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000L0ojHA00@0[Jf]0?nV4@3oYQ40
0000203oYQ42000000X0ojHA0P0000020?nV4@040:f][@3oYQ40ojHA0?nV4@8000005P3oYQ420000
00030?nV4@2][Jd0ojH@00L0ojH@0P0000070?nV40030000003oYQ00000000X0ojH@00<0[Jf]0000
000000002P3oYA000`000000ojD@0?nU400?0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2]
[Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0
ojHA0?nV4@0>0?nV4@8000001`3oYQ40102][Jd0ojHA0?nV4@0000080?nV4@8000002P3oYQ420000
0080ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P00000F0?nV4@80000000<0ojHA0:f][@3oYQ001`3oYQ02
000000L0ojH@00<000000?nV400000002P3oYQ000`2][Jd000000000000:0?nU40030000003oYA00
ojD@00l0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00T0fhX=00<000000=^:3@0000000P2iM@/0
0`2][Jd0/>3V0;3PiP1=0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]
0?bP403lX1003P3lX1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000L0ojHA00@0[Jf]
0?nV4@3oYQ400000203oYQ42000000T0ojHA0P0000030?nV4@040:f][@3oYQ40ojHA0?nV4@800000
5P3oYQ42000000030?nV4@2][Jd0ojH@00L0ojH@0P0000070?nV40030000003oYQ00000000X0ojH@
00<0[Jf]0000000000002P3oYA000`000000ojD@0?nU400?0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
3P3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@8000000`2iM@/00`2][Jd0/>3V0;3PiP1<0;3PiP40oooo
001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]
00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@8000001`3oYQ400`2][Jd0ojHA
0?nV4@090?nV4@8000002@3oYQ42000000<0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P00000F0?nV4@80
000000<0ojHA0:f][@3oYQ001`3oYQ02000000L0ojH@00<000000?nV400000002P3oYQ000`2][Jd0
00000000000:0?nU40030000003oYA00ojD@00l0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd2000000<0^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f]
[@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]
0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00h0ojHA0P0000070?nV4@030:f]
[@3oYQ40ojHA00T0ojHA0P0000090?nV4@8000000`3oYQ40102][Jd0ojHA0?nV4@3oYQ4200000180
ojHA102][Jd2000000X0[Jf]0P0000080:f][@8000002`2][Jd2000000D0[Jf]1@3oYA000`000000
ojD@0?nU400?0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<000000;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f]
[@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]
1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00l0ojHA0P0000040?nV4@040000
003oYQ40ojHA0:f][@/0ojHA0P0000090?nV4@8000000`3oYQ40102][Jd0ojHA0?nV4@3oYQ420000
0080ojHA2@2][Jd00`000000[Jf]0:f][@040:f][@@0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV
40800000203oYQ02000000X0ojH@00<0[Jf]0000000000001@3oYA050:f][@030000002][Jd0[Jf]
00P0[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030000002iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0
dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@P0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0?0?nV4@800000103oYQ4010000000
ojHA0?nV4@2][Jd;0?nV4@8000002@3oYQ42000000L0[Jf]0P0000020:f][@P0ojHA0P00000:0?nV
4@80000000<0ojHA0:f][@3oYQ001`3oYQ02000000P0ojH@00<000000?nV400000002@3oYQ000`2]
[Jd000000000000:0?nU40030000003oYA00ojD@00P0ojD@302][JdH0?nS40030:f][@3lX100o:0@
01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030000002iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?oo
o`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403l
X100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403`3oYQ420000
00@0ojHA00@000000?nV4@3oYQ40[Jf]2`3oYQ42000000030?nV4@2][Jd0[Jf]00H0[Jf]0P000003
0?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000090?nV4@030000003oYQ40000000T0ojHA0P000000
0`3oYQ40[Jf]0?nV40070?nV408000002@3oYQ02000000T0ojH@00<0[Jf]0000000000002P3oYA00
0`000000ojD@0?nU400?0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100
o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>
0:f][@3KRPd0303KRPd00`000000^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool0
05h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]
0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0?0?nV4@800000103oYQ40
10000000ojHA0?nV4@2][Jd40?nV4@L0[Jf]0P0000000`2][Jd0ojHA0?nV4@060?nV4@8000000`3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@8000002@3oYQ400`000000ojHA000000080?nV4@050000003o
YQ4000000?nV4@2][Jd0203oYQ02000000T0ojH@0P0000090?nV40030:f][@000000000000X0ojD@
00<000000?nU403oYA003`3oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][@d0fhX=
00<000000;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_
V100kiP@00/0kiP@0P2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403`3o
YQ42000000@0ojHA00<000000:f][@2][Jd01@2][Jd70?nV4@8000002@3oYQ42000000<0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ42000000X0ojHA0P0000080?nV4@050000003oYQ4000000?nV4@2][Jd0
203oYQ02000000T0ojH@0P0000090?nV40<000002P3oYA000`000000ojD@0?nU400?0?nU40030:f]
[@3oXa00oj<@01H0oj<@202][JdF0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh20:f][@8000002P3KRPd00`000000^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`
h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0?0?nV4@800000102][Jd010000000ojHA0?nV4@2][Jd;0?nV4@800000
2@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000X0ojHA00<000000?nV4@3oYQ40
1`3oYQ401@000000ojHA0000003oYQ40[Jf]00P0ojH@0P00000:0?nV40800000203oYQ03000000X0
ojD@00<000000?nU403oYA003`3oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP
40H0[Jf]403lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:
3@3KRPd0100000070=^:3@030000002iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?oo
o`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@@0
[Jf]0P0000040?nV4@040000003oYQ40ojHA0:f][@/0ojHA0P0000090?nV4@8000000`3oYQ400`2]
[Jd0ojHA0?nV4@030?nV4@8000002@3oYQ400`000000ojHA0?nV4@070?nV4@050000003oYQ400000
0?nV4@2][Jd0203oYQ02000000X0ojH@0P0000070?nV40040000002][Jd00000000000X0ojD@00<0
00000?nU403oYA003`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00L0o:0@1`2]
[Jd90?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh01@2][Jd0fhX=0=^:
3@000000fhX=0080[Jf]1`3KRPd00`000000^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V
0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]
103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
1P3oYQ450:f][@@0ojHA0P0000040?nV4@040000003oYQ40ojHA0:f][@/0ojHA0P0000090?nV4@80
00000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@800000203oYQ400`000000ojHA0?nV4@080?nV4@05
0000003oYQ4000000?nV4@2][Jd0203oYQ02000000/0ojH@0P0000060?nV40040000002][Jd00000
000000X0ojD@00<000000?nU403oYA003`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@00h0o:0@1P2][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
102][Jd0fhX=0=^:3@0000030=^:3@040:f][@3KRPd00000000000<0fhX=00<000000;Ue2`2iM@/0
1`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0
dhL>00<0[Jf]0>nH403_V100103_V1000`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060:f][@T0ojHA0P0000020?nV4@<0
00000P3oYQ400`2][Jd0ojHA0?nV4@090?nV4@8000002@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3o
YQ40103oYQ42000000L0ojHA00<000000?nV4@3oYQ40203oYQ401@000000ojHA0000003oYQ40[Jf]
00P0ojH@0P00000<0?nV408000000`3oYQ02000000040?nV402][Jd00000000000T0ojD@0`00000@
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100503lX1050:f][AD0mY`?00<0[Jf]
0>bF3P3/UPh0403/UPh01@2][Jd0fhX=0=^:3@3KRPd0000000<0fhX=0P2][Jd3000000030=^:3@00
0000000000P0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]1`3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A0180oj@A102][Jd>0?nV4@D000000P3oYQ4010000000ojHA
0?nV4@2][Jd;0?nV4@8000002@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000@0
ojHA0P00000;0?nV4@050000003oYQ4000000?nV4@2][Jd0103oYQ06000000h0ojH@0`0000030?nV
40030:f][@000000000000T0ojD@0`00000@0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0:f][@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh0403/UPh01@2]
[Jd0fhX=0=^:3@3KRPd0000000D0fhX=0P0000020=^:3@800000202iM@/01@2][Jd0R5H708QF1`28
EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_
V100kiP@0080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00h0oj@A102]
[Jd00`3oY140[Jf]0?nV4@0?0?nV4@8000001@3oYQ4010000000ojHA0?nV4@2][Jd;0?nV4@800000
2@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ401`3oYQ44000000d0ojHA00D000000?nV4@000000
ojHA0:f][@0N0?nV40030:f][@000000000000T0ojD@0`00000@0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]3@3fW0l00`2][Jd0
k9H>0>bF3P0@0>bF3P050:f][@3KRPd0fhX=0=^:3@0000001@3KRPd200000080[Jf]0P0000080;Ue
2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0
Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0`2][Jd;0>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1402P3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000D0
ojHA00@000000?nV4@3oYQ40[Jf]2`3oYQ42000000T0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA
01P0ojHA00D000000?nV4@000000ojHA0:f][@0N0?nV40030:f][@000000000000T0ojD@0`00000@
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`07
0?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P050:f][@3KRPd0fhX=0=^:3@0000001@3K
RPd200000080fhX=0`0000070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A0`2][Jd90?nT4@030:f][@3o
YQ40ojHA00h0ojHA0P0000050?nV4@040000003oYQ40ojHA0:f][@/0ojHA0P0000060?nV4@<00000
1@3oYQ400`2][Jd0ojHA0?nV4@0H0?nV4@050000003oYQ4000000?nV4@2][Jd07P3oYQ000`2][Jd0
0000000000090?nU40<00000403oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh01@2][Jd0
fhX=0=^:3@3KRPd0000000D0fhX=0P0000020=^:3@@000001P2iM@/00`2][Jd0R5H708QF1`0208QF
1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>7
3P80[Jf]303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd<0?nT
4@030:f][@3oYQ40ojHA00h0ojHA0P0000050?nV4@040000003oYQ40ojHA0:f][@P0ojHA1@00000>
0?nV4@030:f][@3oYQ40ojHA01P0ojHA00D000000?nV4@000000ojHA0:f][@0N0?nV40030:f][@00
0000000000T0ojD@0`00000@0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh01@2][Jd0fhX=0=^:
3@3KRPd0000000D0fhX=0P0000020=^:3@@000001P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]
00<0dhL>0:f][@3_V1002`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140[Jf]00<0[Jf]
403oY1400`2][Jd0ojHA0?nV4@0>0?nV4@8000001@3oYQ400`000000ojHA0:f][@0L0?nV4@030:f]
[@3oYQ40ojHA01P0ojHA00D000000?nV4@000000ojHA0:f][@0N0?nV40030:f][@000000000000T0
ojD@0`00000@0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh01@2][Jd0fhX=0=^:3@3KRPd0000000D0fhX=0P0000020=^:
3@<0000000<0^GD;0000002iM@/0102iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V
0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P050:f][@3CQ`h0dhL>
0=>73P2][Jd0303_V1000`2][Jd0o:0@0?bP400?0?bP40<0[Jf]503oY1400`2][Jd0ojHA0?nV4@0>
0?nV4@8000001@3oYQ400`000000ojHA0:f][@0L0?nV4@030:f][@3oYQ40ojHA01P0ojHA00D00000
0?nV4@000000ojHA0:f][@0N0?nV40030:f][@000000000000T0ojD@0`00000@0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@020=^:3@030000003KRPd0fhX=0080fhX=0P00
00020=^:3@8000000P2iM@/00`000000[Jf]0;Ue2`030;Ue2`030:f][@28EPL0R5H70080R5H70P2]
[Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h00`2][Jd0dhL>0=>7
3P020=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402]
[Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000D0ojHA00<000000?nV4@2][Jd00`3o
YQ400`000000ojHA0?nV4@0F0?nV4@030:f][@3oYQ40ojHA01P0ojHA00D000000?nV4@000000ojHA
0:f][@0N0?nV40030:f][@000000000000T0ojD@0`00000@0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>
0P2][Jd<0>bF3P030:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00P3KRPd200000080fhX=
0P0000020;Ue2`030000002iM@/0[Jf]00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0dhL>00<0dhL>
00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]103lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA0P0000050?nV4@030000003oYQ40[Jf]00<0ojHA
00<000000?nV4@3oYQ405P3oYQ400`2][Jd0ojHA0?nV4@0H0?nV4@050000003oYQ4000000?nV4@2]
[Jd07P3oYQ000`2][Jd00000000000090?nU40<00000403oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0
[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@020=^:3@<000000P3KRPd200000080fhX=00@0[Jf]0000002i
M@/0^GD;0P0000001@2iM@/0[Jf]0:f][@2iM@/0000000@0R5H70P2][Je20;3PiP40oooo001I0;3P
iP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd60=>73P030:f][@3_V100kiP@00X0kiP@00<0
[Jf]0?bP403lX1001`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0>0?nV4@8000001`3oYQ401@2][Jd0ojHA0?nV4@3oYQ40000001P0ojHA00<0[Jf]0?nV4@3oYQ40
5@3oYQ430:f][@030000002][Jd000000240[Jf]0P0000050:f][@@0ojD@0`00000@0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd0
0`0000030=^:3@030:f][@000000^GD;0080^GD;00@000000;Ue2`2iM@/0^GD;0P00000408QF1`80
[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_
V1002P3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA00h0ojHA0P0000070?nV4@050:f][@3oYQ40ojHA0?nV4@000000603oYQ400`2]
[Jd0ojHA0?nV4@050?nV4A00[Jf]0`3oYQ401@000000ojHA0000003oYQ40[Jf]01h0ojH@00<0[Jf]
0000000000001@3oYA040:f][@<000002@2][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd4
0>bF3P030:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00P3KRPd01P000000fhX=0=^:3@3K
RPd0[Jf]000000<0^GD;00@000000;Ue2`2iM@/0^GD;0P00000508QF1`030:f][@2`h>H0/>3V0400
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00X0
kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0>0?nV4@8000001`3oYQ401@2][Jd0ojHA0?nV4@3oYQ40000001@0ojHA302][JdC0?nV
4@050000003oYQ4000000?nV4@2][Jd0203oYQ000`000000ojH@0?nV400C0?nV40030:f][@000000
000000T0ojD@0`0000090?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00<0fhX=00<00000
0=^:3@3KRPd00P3KRPd00`000000fhX=0=^:3@020=^:3@050000002iM@/0^GD;0;Ue2`0000000`2i
M@/00`000000[Jf]0000000408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/000000:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2]
[Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000L0ojHA00D0
[Jf]0?nV4@3oYQ40ojHA0000000:0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0H0?nV4@050000
003oYQ4000000?nV4@2][Jd01`3oYQ02000001D0ojH@00<0[Jf]0000000000002@3oYA000`000000
ojD@0000000@0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]0`3KRPd00`000000
fhX=0=^:3@020=^:3@030000003KRPd0fhX=0080fhX=00D000000;Ue2`2iM@/0^GD;000000030;Ue
2`050000002][Jd0000008QF1`0000000P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3P
iP050:f][@2GH0/000000000002][Jd0203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]4@3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA0P0000070?nV4@030:f][@3oYQ40
ojHA008000002P2][Jd>0?nV4@030:f][@3oYQ40ojHA01P0ojHA00D000000?nV4@000000ojHA0:f]
[@060?nV40040000003oYQ00ojH@000001@0ojH@00<0[Jf]0000000000002@3oYA0200000140ojD@
00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]0P3KRPd01@000000
fhX=0=^:3@3KRPd0000000@0fhX=00D000000;Ue2`2iM@/0^GD;000000030;Ue2`080000002][Jd0
00000:f][@28EPL0000008QF1`2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0000009MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA00h0ojHA0P0000040?nV4@H0[Jf]0P00000H0?nV4@030:f][@3oYQ40ojHA01P0
ojHA00D000000?nV4@000000ojHA0:f][@070?nV408000005@3oYQ000`2][Jd000000000000:0?nU
40030000003oYA00ojD@00l0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AL0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@80[Jf]00D00000
0=^:3@3KRPd0fhX=000000040=^:3@030000002iM@/0^GD;0080^GD;00D000000;Ue2`2iM@/00000
0:f][@02000000040:f][@00000000000:f][D80/>3V0@3oool005T0/>3V00D0000009MP2`000000
Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0>0?nV4@800000102][Jd30?nV4@03
0:f][@3oYQ40ojHA00800000603oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@H0000000<0ojHA0:f][@3o
YQ001`3oYQ000`000000ojH@0?nV400@0?nV40H000002P3oYA000`000000ojD@0?nU400?0?nU4003
0:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@050000002][Jd0fhX=
0=^:3@000000103KRPd00`000000^GD;0;Ue2`020;Ue2`080000002iM@/0^GD;0000002][Jd0R5H7
00000028EPL2000000030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V0P00000209MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA1`2][Jd2000000L0ojHA
00<0[Jf]0?nV4@3oYQ400P00000H0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00<0fhX=00<000000=^:3@2][Jd00P0000040=^:3@030000002iM@/0^GD;0080^GD;
00P000000;Ue2`00000000000:f][@28EPL0000008QF1`<00000@P2`h>H10?ooo`00F02`h>H30000
0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1P3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd7
0?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@02000001P0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:3@02000000050:f][@3KRPd0
fhX=045Yh@000000102iM@/02`000000^GD;000000000000[Jf]08QF1`000000R5H70000002][Jd0
00000480/>3V0@3oool005P0/>3V00<000000:f][@0000000P2GH0/00`2][Jd0dhL>0=>73P060=>7
3P040:f][@3_V100kiP@0>nH4080[Jf]203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01<0oj@A1@2][Jd=0?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@02000001P0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P0000001@3KRPd0[Jf]0:f][@3K
RPd0000000@0^GD;00/000000;Ue2`00000000000:f][@28EPL0000008QF1`000000R5H700000012
0;3PiP40oooo001H0;3PiP030000002][Jd000000080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102]
[Jd0kiP@0:f][@2][Jd:0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY144
0:f][@030?nT4@2][Jd0ojHA00l0ojHA0P0000070?nV4@030:f][@000000000000800000603oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0102][Jd@
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:3@02
000000<0fhX=00<0[Jf]0000000000000`2iM@/030000000^GD;000000000000^GD;0:f][@000000
R5H700000028EPL000000:f][D40/>3V0@3oool005P0/>3V00<000000:f][@0000000P2GH0/00`2]
[Jd0dhL>0=>73P060=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA00h0ojHA0P0000000`3oYQ400000000000050000
01`0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00@0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`00
0000fhX=0=^:3@02000000@0fhX=0P0000030;Ue2`060000002iM@/000000000002iM@/0[Jf]0`00
00000`28EPL000000:f][@110;3PiP40oooo001G0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P05
0=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd9
0?nT4@030:f][@3oYQ40ojHA00/0ojHA1P0000060?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd6
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd010000000fhX=00000000
00040=^:3@8000000P2][Jd01`2iM@/000000;Ue2`2iM@/000000;Ue2`2][Jd00`0000001028EPL0
00000000000000100;3PiP40oooo001G0;3PiP@000000P2GH0/00`2][Jd0dhL>0=>73P040=>73P03
0:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0
[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00h0mY`?102][Jd20?JL3`03
0:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd010000000fhX=0000000000040=^:
3@8000000P2iM@/01`2][Jd000000;Ue2`2iM@/000000;Ue2`2][Jd00`0000001028EPL000000000
000000100;3PiP40oooo001G0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P030=>73P040:f][@3C
Q`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`@0[Jf]4@3/UPh00`2][Jd0fhX=
0=^:3@030=^:3@040000003KRPd00000000000@0fhX=0P0000030;Ue2`060000002iM@/0^GD;0000
002iM@/0[Jf]0`0000001028EPL000000000000000100;3PiP40oooo001G0;3PiP<000000`2GH0/0
102][Jd0dhL>0=>73P3CQ`h20:f][@<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP
400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00<0fhX=00@000000=^:3@0000000000
103KRPd2000000<0^GD;00H000000:f][@2iM@/000000;Ue2`2][Jd20000000308QF1`0000000000
00800000@02`h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;0:f][@80dhL>00<0[Jf]0=>7
3P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3l
X100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@030=^:3@040000003KRPd00000
000000@0fhX=0P0000030;Ue2`060000002iM@/0[Jf]0000002iM@/0[Jf]0P0000000`28EPL00000
0000000200000400/>3V0@3oool005L0/>3V00T000000:f][@000000Uf0;0000002GH0/0[Jf]0=>7
3P2][Jd01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP
40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL
3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00<0fhX=00@000000=^:
3@0000000000103KRPd2000000<0^GD;00<000000;Ue2`2iM@/00P000000102][Jd0000000000028
EPL400000400/>3V0@3oool005L0/>3V00P000000:f][@000000Uf0;0000002GH0/0@FWQ0:f][@L0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2][Jd0
oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@030=^:3@040000003KRPd000000000
00<0fhX=0`0000020;Ue2`040000002iM@/0^GD;0;Ue2`80000000H0[Jf]000000000000R5H70000
002][Jd200000400/>3V0@3oool005L0/>3V00L000000:f][@000000Uf0;0000002GH0/0[Jf]00P0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0
fhX=0=^:3@040=^:3@<00000103KRPd200000080^GD;00@000000;Ue2`2iM@/0^GD;0P0000001P2]
[Jd0000000000028EPL000000:f][@800000@02`h>H10?ooo`00E`2`h>H30000000409MP2`000000
[Jf]0:f][@L0dhL>00<0[Jf]0>nH403_V100303_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>
0`2][Jd00`3/UPh0[Jf]0=^:3@050=^:3@8000001P3KRPd0102][Jd000000000000000030;Ue2`80
000000H0[Jf]000000000000R5H70000002][Jd200000400/>3V0@3oool005L0/>3V0`000000102G
H0/000000:f][@2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3o
YQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]1@3KRPd2000000H0fhX=00<0[Jf]0;Ue2`000000102i
M@/2000000060:f][@000000000008QF1`000000[Jf]0P0000100;3PiP40oooo001F0;3PiP<00000
0P2GH0/00`000000Uf0;0:f][@070=>73P030:f][@3_V100kiP@00/0kiP@0`2][Jd@0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]
J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]0`3KRPd2000000H0fhX=00<0[Jf]0;Ue2`2i
M@/01@2iM@/01`000000[Jf]000000000000R5H700000011JN400P0000100;3PiP40oooo001F0;3P
iP<0000000D0Uf0;0:f][@000000Uf0;0:f][@070=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd0
0`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@80[Jf]00<0fhX=0000000000001P3K
RPd00`2][Jd0^GD;0;Ue2`050;Ue2`070000002][Jd000000000002][Jd00000045Yh@0200000400
/>3V0@3oool005H0/>3V10000000102][Jd0000009MP2`2][Jd70=>73P030:f][@3_V100kiP@00L0
kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=00<0[Jf]0000000000001P3KRPd00`2][Jd0
^GD;0;Ue2`050;Ue2`030000002][Jd000000080R5H700@00000045Yh@0000000000@02`h>H10?oo
o`00EP2`h>H40000000409MP2`000000Uf0;0:f][@L0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f]
[@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd2000000030:f][@3KRPd0fhX=00<0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/200000080R5H700@00000045Yh@0000000000@02`h>H10?ooo`00EP2`h>H20000
00060:f][@000000Uf0;0000002GH0/0[Jf]1`3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203o
YQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@050=^:3@040000003KRPd0[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/200000080R5H700@000000:f][@0000000000@02`h>H10?ooo`00EP2`h>H2000000060:f]
[@00000000000000002GH0/0[Jf]1`3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`
h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00D0fhX=00@000000=^:3@3KRPd0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`080;Ue2`050:f]
[@28EPL0R5H70000002][Jd00P0000100;3PiP40oooo001F0;3PiP80000000D0[Jf]000000000000
00000:f][@080=>73P040:f][@3_V100[Jf]0:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@050=^:3@030000003KRPd0fhX=00<0fhX=0P2][Jd90;Ue2`050:f][@28EPL0R5H7
0000002][Jd00P0000100;3PiP40oooo001F0;3PiPH0000000<0[Jf]0=>73P3CQ`h01P3CQ`h20:f]
[@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f]
[A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@030000003KRPd0fhX=
00@0fhX=0`2][Jd70;Ue2`050:f][@28EPL0R5H70000002][Jd00P0000100;3PiP40oooo001F0;3P
iPH0000000<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@h0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00D0[Jf]08QF1`28EPL000000:f]
[@03000003l0/>3V0@3oool005H0/>3V1P0000000`2][Jd0dhL>0=>73P030=>73P80[Jf]00<0dhL>
0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS
0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]
0;Ue2`2iM@/0^GD;0:f][@050;Ue2`050:f][@28EPL0R5H70000002][Jd00`00000o0;3PiP40oooo
001F0;3PiP<0000000@0Uf0;000000000000[Jf]103CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0
kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`03
0:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80
[Jf]0`2iM@/01@2][Jd0R5H708QF1`000000[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H200000005
0:f][@2GH0/0000009MP2`2][Jd00`3CQ`h00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/0102][Jd0^GD;0;Ue2`2][Jd208QF1`030000002][Jd0
000000800000?`2`h>H10?ooo`00EP2`h>H2000000060:f][@2GH0/0000009MP2`2][Jd0dhL>0P2]
[Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2]
[Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@80R5H700<0
00000:f][@0000000P00000o0;3PiP40oooo001F0;3PiP060000002][Jd0[Jf]09MP2`000000Uf0;
0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V
0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H71000000o0;3PiP40oooo001F0;3PiP07
0000002][Jd0Uf0;09MP2`000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0P28EPL4000003l0/>3V0@3oool0
05H0/>3V00D000000:f][@2GH0/0Uf0;000000020:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?
0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd2
08QF1`@00000?`2`h>H10?ooo`00EP2`h>H01@000000[Jf]09MP2`2GH0/000000080[Jf]203CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0
^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^003
0:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H70:f][@28
EPL000000:f][@800000?`2`h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2GH0/0000009MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0
^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`06
0:f][@28EPL0[Jf]08QF1`000000[Jf]0P00000o0;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;
0:f][@000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@00X0kiP@0`2][Jd80;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][MP0/>3V102][Jd80<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/01P2][Jd0R5H708QF1`2][Jd000000:f][@800000?`2`h>H10?ooo`00EP2`h>H01`000000[Jf]
09MP2`2][Jd0000009MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;
00L0^GD;00H0[Jf]08QF1`28EPL0R5H70000002][Jd2000003l0/>3V0@3oool005H0/>3V00L00000
0:f][@2][Jd0Uf0;0000002GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`060:f][@28EPL0R5H708QF1`000000[Jf]0P00000o0;3PiP40oooo001F0;3PiP07
0000002][Jd0[Jf]09MP2`000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0
102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`030:f][@28EPL0R5H70080000000<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H0
0`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2]
[Jd3045Yh@030:BNS`2][Jd0/J^M00<0/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36
`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n
^KP0102][Jd0];2a0:f][@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0
R5H70000002][Jd2000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P070=>73P050:f][@3_V100[Jf]0:f][@2TWXl00P11JN40102TWXl0@FWQ0:BNS`2][Jd6
0;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@L0_[Vh0P11JN430;B`/@80[Jf]00<0
fhX=0:f][@2iM@/02@2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000400/>3V0@3oool005D0/>3V
00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]00<0@FWQ0:BNS`2TWXl0
0P11JN420:BNS`03045Yh@2][Jd0/J^M00L0/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@L0
_[Vh0`11JN400`2][Jd0];2a0;B`/@030;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20000
0400/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P060=>73P05
0:f][@2TWXl0Y9j?045Yh@2TWXl00`11JN420:BNS`05045Yh@2][Jd0/J^M0;6[W@11JN401`2aZid2
0:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@
0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd:0;ji^080@FWQ00<0[Jf]0;B`/@2d/;400`2d/;40
1011JN40];2a0:f][@2][Jd80;Ue2`060:f][@28EPL0R5H708QF1`2][Jd00000@02`h>H10?ooo`00
E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd30:BNS`04045Y
h@2TWXl0@FWQ045Yh@<0Y9j?0P11JN430;6[W@80@FWQ1`2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f]
[@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00:0;ji^080@FWQ00<0[Jf]0;B`/@2d/;400`2d/;401@11
JN40];2a0;B`/@11JN40[Jf]00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E
0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h30:f][@05045Yh@2TWXl0
Y9j?045Yh@2TWXl00P11JN430:BNS`80@FWQ102aZid3045Yh@H0/J^M00<0[Jf]0;VbYP2][Jd00`2]
[Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`11
JN440;ji^080@FWQ00<0_[Vh0:f][@2d/;400`2d/;401@11JN40];2a0;B`/@2d/;40@FWQ0080[Jf]
1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd0
0`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@2:QGD0RXEe0:f][@2TWXl00`11JN400`2TWXl0
@FWQ045Yh@030:BNS`80@FWQ102aZid01011JN40/J^M0;6[W@2aZid3045Yh@80/J^M00<0[Jf]0;Vb
YP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji
^011JN400P11JN420;ji^003045Yh@2n^KP0_[Vh0080_[Vh0P11JN400`2n^KP0[Jf]0;B`/@030;B`
/@D0@FWQ102][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`060:f][@3CQ`h0dhL>0=>73P2][Jd0@FWQ0P2:QGD30:f][@80@FWQ00<0
Y9j?045Yh@11JN400`2TWXl2045Yh@@0/J^M00<0@FWQ0;6[W@2aZid00P2aZid3045Yh@030;6[W@2]
[Jd0^K:V00L0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00@0[Jf]045Yh@11JN40@FWQ102n^KP01011JN40_[Vh
0;ji^02n^KP2045Yh@030;ji^02][Jd0];2a00H0];2a00L0[Jf]045Yh@2d/;40[Jf]045Yh@2OVj00
[Jf]0080^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0
[Jf]00<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]0P11JN4208Z5M@03045Yh@2TWXl0Y9j?0080@FWQ00<0
Y9j?045Yh@11JN400`2TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2aZid0/J^M0080/J^M0P11
JN420;6[W@030:f][@11JN40^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`
h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l00l0a/2l0`2][Jd>0<>m^`040:f][@2n^KP0@FWQ045Yh@@0_[Vh00@0@FWQ0;ji^02n^KP0
_[Vh0P11JN400`2n^KP0[Jf]0;B`/@040;B`/@80[Jf]00L0];2a045Yh@2d/;40[Jf]045Yh@2OVj00
@FWQ00<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;
00<0Uf0;0P2][Jd308Z5M@04045Yh@2:QGD0RXEe045Yh@80Y9j?0P11JN400`2][Jd0@FWQ045Yh@03
0:BNS`030:f][@11JN40/J^M00<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@80/J^M00<0[Jf]
0;VbYP11JN400P11JN4;0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/03P33_K/0102][Jd0_[Vh045Yh@11
JN450;ji^003045Yh@2n^KP0_[Vh0080@FWQ00<0_[Vh0:f][@2d/;400P2d/;420:f][@<0];2a00<0
@FWQ0;B`/@2][Jd00P11JN4309nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0?P2`
h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@2:QGD0RXEe00D0RXEe00@0@FWQ
0:BNS`2TWXl0@FWQ0P2TWXl2045Yh@<0Y9j?00<0[Jf]045Yh@2aZid00`2aZid00`11JN40/J^M0;6[
W@020;6[W@80@FWQ0P2aZid00`2][Jd0^K:V045Yh@0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37
`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n
^KP0@FWQ045Yh@D0_[Vh00L0@FWQ0;ji^02n^KP0@FWQ0;ji^011JN40[Jf]0080];2a00@0[Jf]0;B`
/@2d/;40@FWQ0P2d/;401011JN40];2a0:f][@11JN4509nKX0050:f][@28EPL0R5H708QF1`2][Jd0
@02`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@11JN40RXEe00H0RXEe00@0
@FWQ0:BNS`2TWXl0@FWQ0P2TWXl2045Yh@050:f][@2TWXl0Y9j?0:f][@11JN40102aZid00`11JN40
/J^M0;6[W@020;6[W@80@FWQ0P2aZid00`2][Jd0^K:V045Yh@070;VbYP03045Yh@2i/ZH0^K:V00@0
^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0
`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0@FWQ045Yh@050;ji^004045Yh@2n^KP0_[Vh0;ji
^080@FWQ0`2][Jd20;B`/@80@FWQ0P2d/;400`11JN40];2a045Yh@0609nKX0050:f][@28EPL0R5H7
08QF1`2][Jd0@02`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@11JN40RXEe
00H0RXEe00@0[Jf]045Yh@2TWXl0@FWQ0P2TWXl2045Yh@050:BNS`2][Jd0[Jf]0:f][@11JN40102a
Zid00`11JN40/J^M0;6[W@020;6[W@80@FWQ0P2aZid00`2][Jd0^K:V045Yh@050;VbYP80@FWQ00<0
^K:V045Yh@2i/ZH0102i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j
/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0:f]
[@030:f][@d0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0@FWQ045Yh@050;ji^080@FWQ0P2n
^KP2045Yh@030:f][@2d/;40];2a0080];2a0P11JN401@2d/;40@FWQ0;B`/@2d/;40[Jf]00L0Wi^P
00@0[Jf]08QF1`28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`020:f][@03045Y
h@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`11JN400`2TWXl2045Yh@<0Y9j?0P11JN440;6[W@03045Y
h@2aZid0/J^M0080/J^M00L0@FWQ0;6[W@2aZid0/J^M0:f][@2i/ZH0@FWQ00@0^K:V0P11JN430;Vb
YP80@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][JdA0<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]045Yh@11JN401@2n^KP2045Yh@070;ji^02][Jd0@FWQ045Yh@2][Jd0];2a045Y
h@030;B`/@03045Yh@2d/;40@FWQ0080];2a00<0[Jf]09nKX02OVj001@2OVj020:f][@0308QF1`2]
[Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd608Z5M@030:f][@2T
WXl0Y9j?00@0Y9j?0`11JN420:BNS`80@FWQ0P2][Jd20;6[W@03045Yh@2aZid0/J^M0080/J^M00L0
@FWQ0;6[W@2aZid0/J^M0:f][@2i/ZH0@FWQ00@0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH01P11JN40
^K:V0;VbYP2i/ZH0[Jf]045YhA00_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@11JN40@FWQ00D0_[Vh0P11JN401@2][Jd0_[Vh045Yh@11JN40[Jf]0080@FWQ102d
/;401@11JN40];2a0;B`/@2d/;40[Jf]00L0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00
EP2`h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`030:BNS`@0@FWQ
0P2TWXl2045Yh@80/J^M0P2][Jd00`11JN40/J^M0;6[W@020;6[W@07045Yh@2aZid0/J^M0;6[W@2]
[Jd0^K:V045Yh@040;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00H0@FWQ0;VbYP2i/ZH0[Jf]045Yh@2n
]j`5045Yh@/0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@11JN40@FWQ00<0_[Vh0P2][Jd2045Yh@80_[Vh0P11JN400`2][Jd0];2a045Y
h@080;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F
0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00<0[Jf]0:BNS`2TWXl0102TWXl3045Yh@030:BNS`11JN40
@FWQ00D0/J^M00<0@FWQ0:f][@2][Jd00P2aZid01`11JN40/J^M0;6[W@2aZid0[Jf]0;VbYP11JN40
0`2i/ZH2045Yh@H0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]0P11JN440;jg[003045Yh@2n]j`0_[N/00T0
_[N/00<0[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`04
0:f][@11JN40@FWQ0;ji^080[Jf]0P2n^KP2045Yh@80_[Vh0`11JN400`2d/;40@FWQ0;B`/@070;B`
/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0
/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00H0
Y9j?1011JN440;6[W@80@FWQ0P2aZid20:f][@05045Yh@2aZid0/J^M0;6[W@2][Jd00P11JN430;Vb
YP80@FWQ202i/ZH00`2][Jd0_[N/045Yh@060;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg
[02n]j`00P2n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1
^`H0[Jf]4@37`K`0102][Jd0a/2l0<K0_011JN4?0<K0_0030:f][@33_K/0`kfk00h0`kfk00@0[Jf]
045Yh@11JN40[Jf]102n^KP2045Yh@80_[Vh0P11JN400`2][Jd0@FWQ0;B`/@080;B`/@030:f][@2O
Vj00Wi^P0080Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0[Jf]0;6[W@2aZid00P2aZid2045Yh@@0/J^M00D0@FWQ0:f][@2][Jd0/J^M0:f][@02045Yh@<0
^K:V0P11JN480;VbYP030:f][@2n]j`0@FWQ00H0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@@0
_[N/00<0[Jf]0<6j/031^[003`31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX3045YhA@0
b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04@37`K`0102][Jd0
a/2l045Yh@11JN4?0<K0_0030:f][@33_K/0`kfk00d0`kfk0P2][Jd2045Yh@D0_[Vh0P11JN420;ji
^080@FWQ00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^
N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:
QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid00`11
JN40/J^M045Yh@030;6[W@03045Yh@2aZid0/J^M0080[Jf]0P11JN430;VbYP80@FWQ202i/ZH00`2]
[Jd0_[N/0;jg[0060;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`2]
[Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
0180al6j1011JN4F0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_009
0<O1_0@0@FWQ1037`K`0102][Jd0a/2l0<K0_011JN4?0<K0_0030:f][@33_K/0`kfk00X0`kfk0`2]
[Jd00`33_K/0[Jf]0;ji^002045Yh@@0_[Vh0P11JN401@2n^KP0@FWQ045Yh@2n^KP0[Jf]00X0];2a
00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00<0
[Jf]0;6[W@2aZid00P2aZid00`11JN40/J^M045Yh@030;6[W@05045Yh@2aZid0/J^M0;6[W@2][Jd0
0P11JN420:f][@030;VbYP11JN40@FWQ00P0^K:V00<0[Jf]0;jg[02n]j`01P2n]j`00`11JN40_[N/
0;jg[0080;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01@0al6j
0P11JN4A0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0060<O1_003045Yh@37`K`0@FWQ00@0al6l
00D0@FWQ0<O1_037`K`0al6l0:f][@0B0<K0_0030:f][@33_K/0`kfk00L0`kfk0`2][Jd40<>m^`04
0:f][@2n^KP0@FWQ045Yh@@0_[Vh0P11JN440;ji^0030:f][@2d/;40];2a00P0];2a0P2][Jd609nK
X0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`03
0:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`030:f][@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@11
JN400P2aZid2045Yh@<0/J^M00<0[Jf]045Yh@11JN400P2i/ZH00`2][Jd0@FWQ045Yh@080;VbYP03
0:f][@2n]j`0_[N/00H0_[N/00<0@FWQ0;jg[02n]j`0202n]j`00`2][Jd0`KZ`0<6j/00A0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01@0al6j0P11JN450<S1^``0
[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@11JN40al6l00H0al6l00<0@FWQ0<O1_011
JN401@37`K`01011JN40al6l0<O1_02][JdB0<K0_0030:f][@33_K/0`kfk00D0`kfk0P2][Jd70<>m
^`040:f][@2n^KP0@FWQ045Yh@@0_[Vh0P11JN440;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]
09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]
0;6[W@2aZid00P2aZid00`11JN40/J^M0;6[W@04045Yh@<0/J^M00<0[Jf]045Yh@11JN40102i/ZH0
0`11JN40[Jf]0:f][@020:f][@@0^K:V00<0[Jf]0;jg[02n]j`0102n]j`3045Yh@T0_[N/00<0[Jf]
0<6j/031^[004@31^[04045YhA<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^PX0[Jf]0P11JN450:f][A40b<6k00<0[Jf]
0<S1^`38`K/04P38`K/2045Yh@030<O1_011JN40@FWQ00D0al6l0P11JN460<O1_004045Yh@37`K`0
al6l0:f][A80a/2l00<0[Jf]0<>m^`33_K/00P33_K/30:f][@T0`kfk00@0[Jf]0;ji^011JN40@FWQ
102n^KP2045Yh@@0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0
L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@T0
Y9j?00<0[Jf]0;6[W@2aZid00P2aZid00`11JN40/J^M0;6[W@070;6[W@030:f][@11JN40@FWQ00@0
^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH01@2][Jd0@FWQ0:f][@2i/ZH0[Jf]00@0_[N/1011JN4:0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]045Yh@11JN401011JN4?0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@X0al6j0P11JN4F0<S1^`030:f][@38`K/0b<6k
00D0b<6k1`11JN440<S1^`80@FWQ00D0b<6k0:f][@37`K`0al6l045Yh@060<O1_003045Yh@37`K`0
al6l00@0al6l00@0@FWQ0<O1_037`K`0[Jf]4P36`;`00`2][Jd0`kfk0:f][@020:f][@`0`kfk00@0
[Jf]0;ji^011JN40@FWQ102n^KP2045Yh@@0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40102][Jd0];2a
0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0
Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd70:BNS`030:f][@2aZid0/J^M
0080/J^M00<0@FWQ0;6[W@2aZid01`2aZid00`2][Jd0@FWQ045Yh@040;VbYP03045Yh@2i/ZH0^K:V
00<0^K:V0P11JN430:f][@80_[N/0`11JN4<0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]045Y
h@11JN401033_K<2045Yh@D0`kfc1`11JN400`33_K<0[Jf]0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0A0<O1^P0300000037`KX0al6j
0080@FWQ5P38`K/6045Yh@D0b<6k00<0@FWQ0<S1^`38`K/01@38`K/01011JN40b<6k0<S1^`2][Jd3
0<O1_003045Yh@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01037`K`01011JN40al6l0<O1_02]
[Jd@0<K0_0@0[Jf]3`33_K/0102][Jd0_[Vh045Yh@11JN440;ji^003045Yh@2n^KP0_[Vh00<0_[Vh
00<0[Jf]0;B`/@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii
071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0
Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid00`11JN40
/J^M0;6[W@070;6[W@<0@FWQ1@2i/ZH00`11JN40^K:V0;VbYP020;VbYP80@FWQ00@0^K:V0000002n
]j`0[Jf]0P11JN400`2][Jd0_[N/0;jg[0070;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd05031^[00
0`2][Jd0@FWQ045Yh@050<>m/`80@FWQ1`33_K<2045Yh@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX04037`KX0
10000000al6j0<O1^P37`KX2045Yh@d0b<6k1`11JN420<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k
00<0@FWQ0<S1^`38`K/01038`K/01@11JN40b<6k0<S1^`38`K/0[Jf]00l0al6l0P11JN420<O1_004
0:f][@36`;`0a/2l045Yh@P0a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk00h0`kfk00@0[Jf]0;ji
^011JN40@FWQ102n^KP00`11JN40_[Vh0;ji^0030;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d
/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0
[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0/J^M
0;6[W@020;6[W@03045Yh@2aZid0/J^M00L0/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH00`11JN40^K:V
0;VbYP020;VbYP05045Yh@2i/ZH0^K:V0:f][@2n]j`00P11JN420;jg[0@0[Jf]1@2n]j`01@11JN40
_[N/0;jg[02n]j`0[Jf]01@0`KZ`00<0[Jf]045Yh@11JN401P33_K<00`11JN40`kfc0<>m/`050<>m
/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@080<Fn]@@0@FWQ1035_[D2045Yh@80aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01@0al6j0P11JN420<S1
^`<0@FWQ2`38`K/00`11JN40b<6k0<S1^`030<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k00<0@FWQ
0<S1^`38`K/01038`K/01@11JN40b<6k0<S1^`38`K/0[Jf]00h0al6l0P11JN430<O1_0040:f][@36
`;`0a/2l045Yh@@0a/2l102][Jd70<K0_0030:f][@33_K/0`kfk00h0`kfk00@0[Jf]0;ji^011JN40
@FWQ102n^KP00`11JN40_[Vh0;ji^0030;ji^0040:f][@2d/;40];2a0:f][@L0];2a00<0[Jf]09nK
X02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]
00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid00P2aZid00`11
JN40/J^M0;6[W@060;6[W@030:f][@2i/ZH0^K:V00H0^K:V00D0@FWQ0;VbYP2i/ZH0^K:V045Yh@03
0;VbYP030:f][@2n]j`0@FWQ00H0_[N/00<0@FWQ0:f][@2][Jd00P2][Jd00`2n]j`0@FWQ0;jg[002
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]045Yh@11JN401P33_K<2045Yh@H0`kfc0P11JN43
0<>m/`030:f][@35_[D0aKje00H0aKje0P11JN440<Fn]@03045Yh@35_[D0aKje0080@FWQ0`35_[D0
1@2][Jd0a[ng0<Jo]`36_kL0@FWQ00H0a[ng00<0@FWQ0<Jo]`36_kL02P36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j00L0al6j0`11JN450<O1^P80@FWQ0`37`KX4045Yh@<0b<6k0P11
JN490<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`38`K/00`11JN40b<6k
0<S1^`040<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd03@37`K`2045Yh@@0al6l00@0[Jf]0<K0_036
`;`0@FWQ102][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00@0[Jf]0;ji^011JN40@FWQ0`2n^KP0
0`11JN40_[Vh0;ji^0040;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0
[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BN
S`80[Jf]00H000000;6[W@2aZid0@FWQ0;6[W@11JN480;6[W@030:f][@2i/ZH0^K:V00L0^K:V0`11
JN440;VbYP030:f][@2n]j`0@FWQ00D0_[N/0P11JN440;jg[0060:f][@11JN40[Jf]0:f][@2n]j`0
[Jf]5031^[000`2][Jd0@FWQ045Yh@060<>m/`80@FWQ1P33_K<2045Yh@<0`kfc00<0[Jf]0<Fn]@35
_[D01@35_[D2045Yh@H0aKje00@0@FWQ0<Fn]@11JN40@FWQ0`35_[D01@2][Jd0a[ng0<Jo]`36_kL0
@FWQ00H0a[ng00<0@FWQ0<Jo]`36_kL02P36_kL00`2][Jd0@FWQ045Yh@02045Yh@<0al6h00<0@FWQ
0<O1^037`KP00P37`KP7045Yh@<0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@<0al6j0P11JN42
0<O1^P03045Yh@37`KX0al6j00<0al6j0`11JN450<S1^`80@FWQ2038`K/00`11JN40b<6k0<S1^`03
0<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00`38`K/2045Yh@<0b<6k00<0
[Jf]0<O1_037`K`02P37`K`2045Yh@<0al6l1@2][Jd00`11JN40a/2l0<K0_00=0<K0_0030:f][@33
_K/0`kfk00h0`kfk00@0[Jf]0;ji^011JN40@FWQ0`2n^KP00`11JN40_[Vh0;ji^0030;ji^080[Jf]
2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2]
[Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd20;6[W@80@FWQ202aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP040:f][@2n]j`0_[N/045Yh@@0_[N/0P11JN450;jg[003045Yh@2n]j`0_[N/00D0[Jf]
4@31^[000`2][Jd0@FWQ045Yh@070<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN430<>m/`030:f]
[@35_[D0aKje00D0aKje0P11JN460<Fn]@<0@FWQ1035_[D01@2][Jd0a[ng0<Jo]`36_kL0@FWQ00H0
a[ng00<0@FWQ0<Jo]`36_kL02@36_kL3045Yh@<0al6h0P11JN400`37`KP0@FWQ0<O1^0060<O1^080
@FWQ1@37`KP00`2][Jd0al6j0<O1^P050<O1^P03045Yh@37`KX0al6j00@0al6j0`11JN450<O1^P80
@FWQ1`38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00`38`K/0102][Jd0b<6k045Yh@11JN470<S1
^`03045Yh@38`K/0b<6k00<0b<6k0P11JN430<S1^`030:f][@37`K`0al6l00T0al6l0P11JN440:f]
[@80al6l00@0[Jf]0<K0_036`;`0@FWQ3`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`040:f][@2n^KP0
@FWQ045Yh@80_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0
[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00@0[Jf]
0;jg[02n]j`0@FWQ102n]j`2045Yh@D0_[N/00D0@FWQ0;jg[02n]j`0_[N/0:f][@030<6j/0L0[Jf]
2P31^[000`2][Jd0@FWQ045Yh@070<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN430<>m/`030:f]
[@35_[D0aKje00D0aKje0P11JN470<Fn]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo]`03045Yh@@0a[ng
00<0@FWQ0<Jo]`11JN402@36_kL2045Yh@030:f][@37`KP0al6h00<0al6h00<0@FWQ0<O1^011JN40
1`37`KP2045Yh@D0al6h00<0[Jf]0<O1^P37`KX01037`KX2045Yh@L0al6j0P11JN450<O1^P80@FWQ
1`38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00`38`K/0102][Jd0b<6k045Yh@11JN470<S1^`03
045Yh@38`K/0b<6k00<0b<6k0P11JN430<S1^`030:f][@37`K`0al6l00D0al6l0P2][Jd3045Yh@@0
al6l00@0@FWQ0<O1_037`K`0[Jf]0P36`;`00`11JN40a/2l0<K0_00=0<K0_0030:f][@33_K/0`kfk
00h0`kfk00D0[Jf]0;ji^011JN40@FWQ0;ji^002045Yh@80_[Vh0P2][Jd30;ji^0030:f][@2d/;40
];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5
M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[
W@030:f][@2i/ZH0@FWQ00h0^K:V00@0[Jf]0;jg[02n]j`0_[N/1011JN400`2n]j`0@FWQ0;jg[004
0;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd02P31^[070:f][@<0`KZ`00<0[Jf]045Yh@11JN401`33
_K<2045Yh@D0`kfc0P11JN430<>m/`030:f][@35_[D0aKje00D0aKje0P11JN470<Fn]@80@FWQ1035
_[D00`2][Jd0a[ng0<Jo]`03045Yh@@0a[ng0`11JN490<Jo]`03045Yh@36_kL0[Jf]00H0al6h0P11
JN470<O1^080@FWQ1P37`KP00`2][Jd0al6j0<O1^P030<O1^P80@FWQ1`37`KX2045Yh@D0al6j0P11
JN470<S1^`03045Yh@38`K/0@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/0102][Jd0b<6k045Y
h@11JN470<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN430<S1^`050:f][@37`K`0al6l0:f][@11
JN400`2][Jd20<O1_080@FWQ1@37`K`01011JN40al6l0<O1_02][Jd20<K0_003045Yh@36`;`0a/2l
00d0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh045Yh@02045Yh@040;ji^02][Jd0[Jf]
0:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0
/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@040:f][@2i/ZH0@FWQ045Yh@d0^K:V00<0[Jf]
0;jg[02n]j`01P2n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/00?
0<6j/0@0[Jf]0P11JN400`2][Jd0`kfc0<>m/`040<>m/`80@FWQ1@33_K<00`11JN40`kfc0<>m/`02
0<>m/`030:f][@35_[D0aKje00D0aKje0P11JN470<Fn]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo]`03
045Yh@@0a[ng0`11JN480<Jo]`80@FWQ00<0a[ng0:f][@37`KP01P37`KP00`11JN40al6h0<O1^005
0<O1^080@FWQ1P37`KP00`2][Jd0al6j0<O1^P030<O1^P80@FWQ1`37`KX2045Yh@D0al6j0P11JN48
0<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`030<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k0P11
JN440<S1^`80@FWQ1P2][Jd00`11JN40al6l045Yh@040<O1_003045Yh@37`K`0al6l00@0al6l00@0
@FWQ0<O1_037`K`0[Jf]0P36`;`00`11JN40a/2l0<K0_00>0<K0_0030:f][@33_K/0`kfk00d0`kfk
00@0[Jf]045Yh@11JN40_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02O
Vj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00@0/J^M0:f][@2i/ZH0
@FWQ3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/004
0:f][@11JN40@FWQ0<>m/`H0[Jf]0P11JN450<>m/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn
]@35_[D01P35_[D2045Yh@H0aKje0P11JN440<Fn]@060:f][@36_kL0a[ng045Yh@36_kL0@FWQ1036
_kL00`11JN40a[ng045Yh@080<Jo]`80@FWQ00<0a[ng0:f][@37`KP01@37`KP2045Yh@L0al6h0P11
JN460<O1^0030:f][@37`KX0al6j00<0al6j0P11JN470<O1^P80@FWQ1@37`KX2045Yh@@0b<6k00@0
00000<S1^`38`K/0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11JN40
@FWQ1`38`K/2045Yh@@0[Jf]0P11JN430<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1037`K`00`11
JN40al6l0<O1_0030<O1_0<0@FWQ00@0al6l0:f][@36`;`0a/2l0P11JN4?0<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2O
Vj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@02
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]
0;jg[02n]j`02`2n]j`2045Yh@<0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0@FWQ0<>m/`07
0<>m/`80@FWQ1@2][Jd00`11JN40[Jf]0<>m/`020<>m/`030:f][@35_[D0aKje00L0aKje00<0@FWQ
0<Fn]@35_[D01035_[D2045Yh@@0aKje00@0[Jf]0<Jo]`36_kL0@FWQ0P36_kL01`11JN40a[ng0<Jo
]`36_kL0@FWQ0<Jo]`11JN402036_kL2045Yh@030<Jo]`2][Jd0al6h00D0al6h0P11JN470<O1^080
@FWQ1P37`KP00`2][Jd0al6j0<O1^P030<O1^P80@FWQ1`37`KX2045Yh@D0al6j0P11JN430<S1^`03
00000038`K/0b<6k0080b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11
JN40@FWQ1`2][Jd2045Yh@D0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@030<O1_003045Yh@37`K`0
al6l00<0al6l00<0@FWQ0<O1_037`K`00`37`K`01@11JN40al6l045Yh@37`K`0[Jf]0080a/2l0P11
JN4?0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0
[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0
_[N/00/0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]045Yh@33_K<01`33_K<2
045Yh@D0`kfc00<0@FWQ0<>m/`2][Jd0202][Jd50<Fn]@<0@FWQ0`35_[D2045Yh@@0aKje00@0[Jf]
0<Jo]`11JN40@FWQ0P36_kL00`11JN40a[ng0<Jo]`02045Yh@030<Jo]`11JN40a[ng00H0a[ng0P11
JN420<Jo]`030:f][@37`KP0al6h00@0al6h0P11JN470<O1^080@FWQ1P37`KP00`2][Jd0al6j0<O1
^P040<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN450<O1^P80@FWQ2038`K/2045Yh@H0b<6k00<0
@FWQ0:f][@2][Jd01@2][Jd2045Yh@L0b<6k0P11JN450<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd0
0`37`K`00`11JN40al6l0<O1_0030<O1_0H0@FWQ1037`K`00`2][Jd0a/2l0<K0_002045Yh@l0a/2l
00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0
[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg
[00;0;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@11JN40`kfc00L0`kfc0P11
JN450<>m/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@P0[Jf]1@11JN440<Fn]@040:f][@36
_kL0@FWQ045Yh@80a[ng00<0@FWQ0<Jo]`36_kL00P11JN420<Jo]`03045Yh@36_kL0a[ng00@0a[ng
0P11JN420<Jo]`030:f][@37`KP0al6h00@0al6h0P11JN470<O1^080@FWQ1P37`KP00`2][Jd0al6j
0<O1^P050<O1^P@0@FWQ0`37`KX2045Yh@D0al6j0P11JN450<S1^`<0[Jf]0P11JN460:f][@03045Y
h@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@D0b<6k0P11JN420<S1^`04
0:f][@37`K`0al6l045YhA40al6l00@0[Jf]0<K0_011JN40@FWQ3`36`;`00`2][Jd0`kfk0<>m^`06
0<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je9
0;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V
00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/00/0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]045Yh@33_K<01`33_K<2045Yh@D0`kfc0P11JN430<>m/`030:f][@35_[D0@FWQ
00h0aKje0P11JN460:f][@80@FWQ0P2][Jd01011JN40[Jf]0:f][@11JN420:f][@030<Jo]`11JN40
a[ng00D0a[ng0P11JN420<Jo]`030:f][@37`KP0al6h0080al6h1`11JN440<O1^080@FWQ1P37`KP0
0`2][Jd0al6j0<O1^P090<O1^PD0@FWQ1@2][Jd00`11JN40[Jf]0:f][@040:f][@80b<6k0P11JN47
0<S1^`80@FWQ1038`K/0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1P38`K/2045Yh@040<S1^`2]
[Jd0al6l045YhA80al6l00@0[Jf]0<K0_011JN40@FWQ3`36`;`00`2][Jd0`kfk0<>m^`020<>m^`@0
[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`
h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M
00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/00`0_[N/0P11JN430;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]045Yh@33_K<01`33_K<2045Yh@D0`kfc00<0@FWQ0<>m/`11JN40
0P33_K<00`2][Jd0@FWQ045Yh@060<Fn]@80@FWQ1P35_[D2045Yh@@0aKje00@0[Jf]0<Jo]`11JN40
@FWQ0`36_kL00`11JN40a[ng045Yh@020<Jo]`030:f][@11JN40[Jf]00D0[Jf]0P11JN4B0:f][@80
@FWQ4P2][Jd30<O1^P80@FWQ1@37`KX00`11JN40[Jf]0<S1^`060<S1^`80@FWQ1`38`K/2045Yh@@0
b<6k00<0[Jf]0<S1^`11JN402038`K/2045Yh@P0b<6k0`11JN4C0<O1_0040:f][@36`;`0@FWQ045Y
h@l0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`
/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@`0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]045Yh@33_K<01`33_K<2045Yh@D0`kfc00H0@FWQ0<>m/`33_K<0@FWQ0<>m/`2][Jd2
045Yh@H0aKje0P11JN460<Fn]@03045Yh@35_[D0aKje00<0aKje00<0[Jf]0<Jo]`11JN401036_kL0
0`11JN40a[ng045Yh@030<Jo]`03045Yh@36_kL0a[ng00@0a[ng0P11JN420<Jo]`030:f][@37`KP0
al6h00d0al6h0P11JN460<O1^0030:f][@37`KX0al6j00`0al6j00<0@FWQ0<O1^P37`KX01037`KX2
045Yh@H0b<6k0P11JN480<S1^`<0@FWQ0`38`K/00`2][Jd0b<6k045Yh@060<S1^`@0@FWQ2@38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0@FWQ045Yh@d0a/2l102][Jd>0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U
0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd80;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0@FWQ0<>m/`070<>m/`04045Yh@33_K<0`kfc0<>m/`@0@FWQ0`33_K<2045Yh@030<Fn]@11
JN40aKje00H0aKje00<0@FWQ0<Fn]@35_[D01035_[D00`11JN40aKje0<Fn]@030<Fn]@030:f][@11
JN40@FWQ00@0a[ng00<0@FWQ0<Jo]`11JN400`36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ0P36
_kL00`2][Jd0al6h0<O1^00=0<O1^080@FWQ1@37`KP00`11JN40[Jf]0<O1^P050<O1^P03045Yh@37
`KX0al6j00D0al6j00@0@FWQ0<O1^P37`KX000000`37`KX00`11JN40[Jf]045Yh@050<S1^`80@FWQ
2038`K/8045YhA@0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l045Yh@090<K0_0D0[Jf]
0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40
0`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]102n]j`00`11JN40_[N/0;jg
[0020;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]045Yh@33_K<01`33_K<00`11JN40`kfc0<>m
/`090<>m/`030:f][@11JN40@FWQ00L0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn
]@040<Fn]@030:f][@11JN40@FWQ00@0a[ng0P11JN450<Jo]`03045Yh@36_kL0a[ng00<0a[ng0P11
JN420<Jo]`030:f][@37`KP0al6h00d0al6h0`11JN430<O1^003045Yh@37`KP0@FWQ00H0al6j00<0
@FWQ0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P050<O1^P04045Yh@2][Jd0b<6k045Yh@<0b<6k
0P11JN490<S1^`80@FWQ1038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_011JN401@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh
0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/
102][Jd50;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]045Yh@33_K<01`33_K<00`11JN40`kfc
0<>m/`090<>m/`030:f][@35_[D0aKje00P0aKje1@11JN460<Fn]@@0@FWQ1@36_kL00`11JN40a[ng
0<Jo]`030<Jo]`03045Yh@36_kL0a[ng00<0a[ng0P11JN420<Jo]`030:f][@37`KP0al6h00d0al6h
0P11JN400`37`KP0@FWQ0<O1^0020<O1^080@FWQ1P37`KX00`11JN40al6j0<O1^P040<O1^P03045Y
h@37`KX0al6j00<0al6j1011JN420<S1^`@0@FWQ2P38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00
J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]
00<0_[N/0:f][@31^[004`31^[000`2][Jd0@FWQ0<>m/`060<>m/`03045Yh@33_K<0`kfc00X0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng045Yh@02045Yh@<0a[ng00@0@FWQ0<Jo]`36_kL0
a[ng1P11JN420<Jo]`80@FWQ0P36_kL00`2][Jd0al6h0<O1^00:0<O1^0D0@FWQ0P37`KP4045Yh@03
0:f][@37`KX0al6j00D0al6j1P11JN490<O1^P030:f][@38`K/0b<6k00h0b<6k0P11JN440<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0@FWQ
0<>m/`060<>m/`03045Yh@33_K<0`kfc00X0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0B0<Jo]`80@FWQ00<0a[ng0:f][@37`KP01P37`KP00`11JN40al6h0<O1^00=0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00;0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2]
[Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j
/031^[070:f][@X0`KZ`00<0[Jf]045Yh@33_K<01@33_K<00`11JN40`kfc0<>m/`0;0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04P36_kL2045Yh@030<Jo]`2][Jd0al6h00H0al6h
00<0@FWQ0<O1^037`KP03@37`KP00`2][Jd0al6j0<O1^P070<O1^P0300000037`KX0al6j00X0al6j
00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/02038`K/00`11JN40b<6k
0<S1^`080<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`
h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00P0`KZ`1`2][Jd00`31^[00@FWQ045Yh@02045Yh@D0`kfc0P11JN4=0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04P36_kL2045Yh@030<Jo]`2][Jd0al6h00D0al6h0P11
JN4?0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00<0
[Jf]0<S1^`38`K/01`38`K/00`11JN40b<6k045Yh@090<S1^`030:f][@37`K`0al6l00D0[Jf]3@37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n
^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0D0[Jf]1P11JN4>0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL04`36_kL00`11JN40a[ng0:f][@060<O1^080@FWQ3`37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00h0b<6k0P11JN440<S1^`030:f][@38`K/0
b<6k00P0b<6k00<0@FWQ0<S1^`38`K/01@38`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3P
iP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0C0<Jo]`03045Yh@36_kL0[Jf]00H0al6h0P11JN4?0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/7
0:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f]
[@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0C0<Jo
]`80@FWQ00<0[Jf]0<O1^037`KP00`37`KP3045Yh@l0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0<0<S1^`@0@FWQ1038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR
0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0[Jf]0<Jo]`36_kL05036_kL2045Y
h@@0al6h0P11JN400`37`KP0@FWQ0<O1^00>0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@11JN40@FWQ0080
@FWQ0`37`KP00`11JN40al6h0<O1^00=0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V
0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h
:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3o
ool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec
0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?oo
o`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V
102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0
/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3P
iP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]
X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H1
0?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52764 .33089 m
.53432 .33084 L
s
.52429 .33411 m
.52764 .33089 L
s
.53432 .33084 m
.53767 .33401 L
s
.50925 .33082 m
.50757 .33401 L
s
.51092 .33405 m
.50925 .33082 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52262 .33732 m
.52429 .33411 L
s
.55601 .33042 m
.54935 .33059 L
s
.50924 .33724 m
.51092 .33405 L
s
.50757 .33401 m
.50924 .33724 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53883 .33622 m
.53935 .3372 L
s
.53935 .3372 m
.53974 .33565 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59491 .3286 m
.59572 .32855 L
s
.255 .412 .882 r
.54001 .34074 m
.54331 .33843 L
s
.54331 .33843 m
.54662 .33837 L
s
.53835 .34076 m
.54331 .33843 L
s
0 0 0 r
.53519 .35913 m
.53604 .35979 L
s
.255 .412 .882 r
.54662 .33837 m
.55158 .34051 L
s
.53505 .34531 m
.53835 .34076 L
s
.53671 .34529 m
.54001 .34074 L
s
0 0 0 r
.53874 .35913 m
.53939 .35974 L
s
.255 .412 .882 r
.55158 .34051 m
.5549 .34493 L
s
.48378 .33796 m
.48542 .33801 L
s
.5334 .34984 m
.53505 .34531 L
s
.53506 .34983 m
.53671 .34529 L
s
.48047 .3401 m
.48378 .33796 L
s
.48212 .34015 m
.48378 .33796 L
s
0 0 0 r
.5394 .36297 m
.53604 .35979 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54108 .36295 m
.53939 .35974 L
s
.255 .412 .882 r
.48045 .34461 m
.48212 .34015 L
s
.4788 .34455 m
.48047 .3401 L
s
.53175 .35664 m
.5334 .34984 L
s
.53341 .35662 m
.53506 .34983 L
s
.47227 .33751 m
.47554 .3399 L
s
.46735 .33728 m
.47227 .33751 L
s
.47554 .3399 m
.4788 .34455 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5664 .33778 m
.57789 .33728 L
s
.55652 .33812 m
.5566 .35619 L
s
.55487 .33817 m
.55494 .35623 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46406 .33937 m
.46735 .33728 L
s
.46242 .33928 m
.46735 .33728 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49356 .36992 m
.50028 .3384 L
s
.49522 .36995 m
.50026 .34516 L
s
.48037 .36045 m
.48045 .34461 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54029 .36467 m
.54108 .36618 L
s
.255 .412 .882 r
.47869 .36492 m
.4788 .34455 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51351 .33858 m
.52013 .37026 L
s
.50683 .37016 m
.51351 .33858 L
s
0 0 0 r
.50746 .39218 m
.50762 .38868 L
s
.51068 .38868 m
.51083 .39222 L
s
.255 .412 .882 r
.50849 .37018 m
.51351 .34534 L
s
.50028 .3384 m
.50683 .37016 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57289 .37286 m
.57291 .37501 L
s
.57455 .37176 m
.57457 .37494 L
s
.255 .412 .882 r
.53175 .35664 m
.53176 .36796 L
s
.53341 .35662 m
.53342 .36795 L
s
.46239 .3438 m
.46406 .33937 L
s
.46076 .34372 m
.46242 .33928 L
s
.54998 .35636 m
.56155 .35603 L
s
0 0 0 r
.50915 .3922 m
.50915 .38868 L
s
.255 .412 .882 r
.46236 .34833 m
.46239 .3438 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46072 .34824 m
.46076 .34372 L
s
.53176 .36796 m
.53343 .37476 L
s
.53342 .36795 m
.53509 .37475 L
s
.46236 .34833 m
.46396 .35294 L
s
.46723 .35537 m
.47708 .35806 L
s
.47708 .35806 m
.47872 .36039 L
s
.57309 .3556 m
.57478 .36233 L
s
.51514 .37024 m
.52511 .37026 L
s
.46072 .34824 m
.46232 .35286 L
s
.47869 .36492 m
.48037 .36045 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46396 .35294 m
.46723 .35537 L
s
.48859 .36979 m
.50019 .37006 L
s
.46232 .35286 m
.46723 .35537 L
s
.60073 .3382 m
.60556 .33559 L
s
.59915 .34283 m
.60073 .3382 L
s
.60234 .33808 m
.60556 .33559 L
s
.60077 .34272 m
.60234 .33808 L
s
.53343 .37476 m
.5351 .37929 L
s
.53509 .37475 m
.53676 .37927 L
s
.60556 .33559 m
.61039 .33522 L
s
.42843 .33468 m
.43969 .33558 L
s
.47703 .36713 m
.47869 .36492 L
s
0 0 0 r
.57291 .37501 m
.57956 .37472 L
s
.255 .412 .882 r
.59915 .34283 m
.59919 .34736 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47372 .36927 m
.47703 .36713 L
s
.5351 .37929 m
.53844 .38381 L
s
.53676 .37927 m
.5401 .38378 L
s
.43451 .36701 m
.43485 .33521 L
s
.62619 .31799 m
.63726 .31686 L
s
.4329 .36688 m
.43325 .33508 L
s
.46226 .36193 m
.4639 .36201 L
s
.46388 .36428 m
.4639 .36201 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56657 .36947 m
.57317 .36921 L
s
.55503 .37893 m
.55666 .37206 L
s
.55666 .37206 m
.55672 .38572 L
s
.57478 .36233 m
.57809 .36672 L
s
0 0 0 r
.59648 .35738 m
.59665 .35697 L
s
.255 .412 .882 r
.57298 .33751 m
.57317 .36921 L
s
.57133 .33758 m
.57152 .36928 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60118 .35365 m
.60242 .35659 L
s
.59989 .3546 m
.60079 .35673 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59919 .34736 m
.60086 .35179 L
s
.61039 .33522 m
.61363 .33722 L
s
.60077 .34272 m
.60081 .34725 L
s
.60081 .34725 m
.60248 .35168 L
s
.46224 .3642 m
.46226 .36193 L
s
.46713 .36899 m
.47372 .36927 L
s
.57809 .36672 m
.5814 .36884 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55173 .38357 m
.55503 .37893 L
s
.55503 .37893 m
.55672 .38572 L
s
.58464 .36412 m
.58626 .36176 L
s
.58626 .36176 m
.58792 .36395 L
s
.53844 .38381 m
.54343 .38601 L
s
.46224 .3642 m
.46386 .36655 L
s
.5401 .38378 m
.54343 .38601 L
s
.61363 .33722 m
.6169 .34149 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58464 .36412 m
.5863 .36631 L
s
.46386 .36655 m
.46713 .36899 L
s
.60086 .35179 m
.60574 .35372 L
s
.54676 .38595 m
.55173 .38357 L
s
.54676 .38595 m
.54343 .38601 L
s
.58792 .36395 m
.58794 .36622 L
s
.5814 .36884 m
.58632 .36858 L
s
.60248 .35168 m
.60574 .35372 L
s
.61845 .33682 m
.62162 .33427 L
s
.6169 .34149 m
.61845 .33682 L
s
.58632 .36858 m
.58794 .36622 L
s
.62162 .33427 m
.62321 .33413 L
s
.62005 .33668 m
.62162 .33427 L
s
.6185 .34135 m
.62005 .33668 L
s
.44591 .36325 m
.44755 .36108 L
s
.44755 .36108 m
.44916 .36346 L
s
.60574 .35372 m
.61545 .35525 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44914 .36573 m
.44916 .36346 L
s
.6185 .34135 m
.61869 .35726 L
s
.60094 .36088 m
.60097 .36315 L
s
.60094 .36088 m
.60257 .36077 L
s
.44749 .36791 m
.44914 .36573 L
s
.44591 .36325 m
.44751 .36563 L
s
.60257 .36077 m
.60259 .36304 L
s
.43466 .35335 m
.4362 .36029 L
s
.60097 .36315 m
.60261 .36532 L
s
.44261 .36759 m
.44749 .36791 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60261 .36532 m
.60588 .36737 L
s
.41093 .33304 m
.41564 .33578 L
s
.41564 .33578 m
.41876 .34062 L
s
.4362 .36029 m
.43939 .36508 L
s
.41876 .34062 m
.4203 .34531 L
s
.43939 .36508 m
.44261 .36759 L
s
.41093 .33304 m
.41406 .33562 L
s
.41406 .33562 m
.41717 .34047 L
s
.61545 .35525 m
.61708 .3574 L
s
.41717 .34047 m
.41871 .34517 L
s
.39525 .3313 m
.41093 .33304 L
s
.4203 .34531 m
.42181 .35228 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41871 .34517 m
.42021 .35214 L
s
.63284 .34002 m
.63593 .33516 L
s
.63593 .33516 m
.63905 .33255 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61713 .36195 m
.61869 .35726 L
s
.60588 .36737 m
.61235 .36689 L
s
.6169 .34149 m
.61713 .36195 L
s
.63253 .31736 m
.63317 .3651 L
s
.63095 .31752 m
.63159 .36525 L
s
.42167 .36368 m
.42181 .35228 L
s
.42806 .3665 m
.43451 .36701 L
s
.63905 .33255 m
.6422 .33221 L
s
.61235 .36689 m
.61555 .36436 L
s
.42007 .36354 m
.42021 .35214 L
s
.61555 .36436 m
.61713 .36195 L
s
.6422 .33221 m
.64536 .33413 L
s
.6422 .33221 m
.64692 .33395 L
s
0 0 0 r
.64251 .35334 m
.64253 .35319 L
s
.255 .412 .882 r
.41998 .37039 m
.42167 .36368 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41839 .37025 m
.42007 .36354 L
s
.6268 .36569 m
.63317 .3651 L
s
.63308 .35824 m
.63632 .3625 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64692 .33395 m
.65011 .33814 L
s
.64536 .33413 m
.64855 .33832 L
s
.41833 .37483 m
.41998 .37039 L
s
.64855 .33832 m
.65022 .34498 L
s
.41673 .37468 m
.41839 .37025 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65011 .33814 m
.65178 .3448 L
s
.63632 .3625 m
.63951 .36447 L
s
.41507 .37912 m
.41833 .37483 L
s
.41348 .37898 m
.41673 .37468 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65022 .34498 m
.65029 .34955 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65178 .3448 m
.65185 .34937 L
s
.66083 .32996 m
.67152 .32849 L
s
.63951 .36447 m
.64266 .36414 L
s
.64884 .35659 m
.65029 .34955 L
s
.41027 .38097 m
.41507 .37912 L
s
.6504 .35641 m
.65185 .34937 L
s
.41027 .38097 m
.41348 .37898 L
s
.64266 .36414 m
.64577 .36151 L
s
.64266 .36414 m
.64734 .36134 L
s
.64577 .36151 m
.64884 .35659 L
s
.64734 .36134 m
.6504 .35641 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3992 .37986 m
.39992 .33184 L
s
.40077 .38002 m
.40149 .33202 L
s
.39449 .37935 m
.41027 .38097 L
s
0 0 0 r
.686 .31856 m
.68887 .3181 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66696 .32913 m
.66781 .37733 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67756 .3276 m
.68801 .32596 L
s
.5 Mabswid
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66741 .35431 m
.67054 .35849 L
s
.68206 .32691 m
.68256 .35216 L
s
.68355 .32668 m
.68405 .35193 L
s
.67054 .35849 m
.67515 .36016 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66543 .32934 m
.66628 .37752 L
s
.66165 .3781 m
.66781 .37733 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67515 .36016 m
.67818 .35973 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68794 .34621 m
.68796 .34722 L
s
.68942 .34483 m
.68946 .34694 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69391 .32497 m
.70409 .32315 L
s
.67818 .35973 m
.68115 .35699 L
s
.67818 .35973 m
.68265 .35677 L
s
.68115 .35699 m
.68256 .35216 L
s
.68265 .35677 m
.68405 .35193 L
s
.34484 .32842 m
.34634 .32638 L
s
.34494 .32382 m
.34634 .32638 L
s
.34344 .32586 m
.34494 .32382 L
s
.34344 .32586 m
.34484 .32842 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69975 .32395 m
.70045 .35624 L
s
.69829 .32421 m
.69899 .35649 L
s
.34458 .33994 m
.34544 .36796 L
s
.34252 .36747 m
.34458 .33994 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69459 .35722 m
.70045 .35624 L
s
.34397 .36772 m
.34428 .3538 L
s
.33198 .32368 m
.33335 .32627 L
s
.33318 .33319 m
.33335 .32627 L
s
.71141 .32871 m
.71413 .32353 L
s
.71014 .33591 m
.71141 .32871 L
s
.32921 .32081 m
.33198 .32368 L
s
.71413 .32353 m
.7183 .32037 L
s
.71283 .32843 m
.71555 .32325 L
s
.71157 .33564 m
.71283 .32843 L
s
.71014 .33591 m
.71025 .34054 L
s
.33176 .33292 m
.33324 .33088 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32362 .31964 m
.32921 .32081 L
s
.71555 .32325 m
.7183 .32037 L
s
.33171 .33523 m
.33318 .33319 L
s
.71157 .33564 m
.71167 .34026 L
s
.69783 .37064 m
.69924 .36808 L
s
.69783 .37064 m
.69934 .37272 L
s
.69924 .36808 m
.70076 .37016 L
s
.71025 .34054 m
.71184 .34721 L
s
.34387 .37236 m
.34544 .36796 L
s
.32888 .33467 m
.33176 .33292 L
s
.7183 .32037 m
.7211 .31979 L
s
.71167 .34026 m
.71326 .34695 L
s
.32883 .33699 m
.33171 .33523 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69934 .37272 m
.70076 .37016 L
s
.34252 .36747 m
.34387 .37236 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7211 .31979 m
.72531 .32121 L
s
.33138 .34913 m
.33291 .34477 L
s
.3327 .35405 m
.33291 .34477 L
s
.71184 .34721 m
.71479 .35132 L
s
.32079 .32136 m
.32362 .31964 L
s
.71326 .34695 m
.71621 .35104 L
s
.32991 .35118 m
.33138 .34913 L
s
.33138 .34913 m
.3327 .35405 L
s
.31935 .32338 m
.32079 .32136 L
s
.71479 .35132 m
.71909 .35282 L
s
.72531 .32121 m
.72818 .32524 L
s
.32703 .35296 m
.32991 .35118 L
s
.31809 .31845 m
.31935 .32338 L
s
.31785 .32772 m
.31809 .31845 L
s
.71621 .35104 m
.71909 .35282 L
s
.31785 .32772 m
.31935 .32338 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32171 .34021 m
.32883 .33699 L
s
.32177 .33788 m
.32888 .33467 L
s
.32142 .35184 m
.32703 .35296 L
s
.31894 .33963 m
.32177 .33788 L
s
.71909 .35282 m
.72329 .35198 L
s
.31888 .34195 m
.32171 .34021 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3175 .34166 m
.31894 .33963 L
s
.72584 .34209 m
.72716 .33947 L
s
.72584 .34209 m
.72728 .34413 L
s
.72716 .33947 m
.7286 .34151 L
s
.31744 .34399 m
.31888 .34195 L
s
.72329 .35198 m
.72601 .34908 L
s
.31871 .34894 m
.32142 .35184 L
s
.31738 .34632 m
.3175 .34166 L
s
.72601 .34908 m
.72865 .34384 L
s
.7286 .34151 m
.72865 .34384 L
s
.31738 .34632 m
.31871 .34894 L
s
.7375 .3161 m
.73896 .32043 L
s
.7375 .3161 m
.73774 .3254 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30585 .31795 m
.3084 .32324 L
s
.30193 .31465 m
.30585 .31795 L
s
.73774 .3254 m
.73896 .32043 L
s
.73896 .32043 m
.74023 .31778 L
s
.74023 .31778 m
.74282 .31481 L
s
.74282 .31481 m
.74806 .31348 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29931 .31398 m
.30193 .31465 L
s
0 0 0 r
.28476 .3024 m
.2848 .30241 L
s
.255 .412 .882 r
.30791 .34188 m
.30797 .33955 L
s
.30669 .3369 m
.30797 .33955 L
s
.30528 .33893 m
.30669 .3369 L
s
.73811 .33939 m
.73939 .33674 L
s
.73811 .33939 m
.73824 .34406 L
s
.3051 .34594 m
.30791 .34188 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73939 .33674 m
.742 .33378 L
s
.29663 .31564 m
.29931 .31398 L
s
.29534 .31531 m
.29931 .31398 L
s
.73817 .34172 m
.73945 .33908 L
s
.73945 .33908 m
.74206 .33611 L
s
.30528 .33893 m
.30656 .34157 L
s
.73824 .34406 m
.73964 .34609 L
s
.742 .33378 m
.74845 .32748 L
s
.74806 .31348 m
.75072 .31513 L
s
.74206 .33611 m
.74851 .32982 L
s
.73964 .34609 m
.74238 .34781 L
s
.29391 .31964 m
.29663 .31564 L
s
.30237 .34766 m
.3051 .34594 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29263 .3193 m
.29534 .31531 L
s
.75072 .31513 m
.75207 .31713 L
s
.74238 .34781 m
.74766 .34655 L
s
.74845 .32748 m
.75098 .32448 L
s
.2984 .34671 m
.30237 .34766 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74851 .32982 m
.75104 .32682 L
s
.75207 .31713 m
.75227 .32414 L
s
.29243 .32632 m
.29391 .31964 L
s
.75098 .32448 m
.7522 .3218 L
s
.29114 .32598 m
.29263 .3193 L
s
.75104 .32682 m
.75227 .32414 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29585 .34372 m
.2984 .34671 L
s
.29455 .3434 m
.2984 .34671 L
s
.2923 .331 m
.29243 .32632 L
s
.74766 .34655 m
.75021 .34356 L
s
.29101 .33067 m
.29114 .32598 L
s
.29339 .33837 m
.29585 .34372 L
s
.2923 .331 m
.29339 .33837 L
s
.75021 .34356 m
.75144 .34088 L
s
.2778 .30801 m
.28647 .31054 L
s
.75144 .34088 m
.7526 .33586 L
s
.7526 .33586 m
.75287 .34525 L
s
.75144 .34088 m
.75287 .34525 L
s
.2921 .33804 m
.29455 .3434 L
s
.29101 .33067 m
.2921 .33804 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76088 .31234 m
.76206 .30964 L
s
.76088 .31234 m
.7622 .31433 L
s
.76206 .30964 m
.76337 .31163 L
s
.7622 .31433 m
.76337 .31163 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28175 .3424 m
.28272 .30947 L
s
.28051 .34205 m
.28149 .30911 L
s
.76255 .32607 m
.76463 .35405 L
s
.76213 .35472 m
.76255 .32607 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76296 .3402 m
.76338 .35438 L
s
.2768 .341 m
.28175 .3424 L
s
.26473 .30383 m
.27297 .30652 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76213 .35472 m
.76352 .35912 L
s
.76352 .35912 m
.76463 .35405 L
s
.28001 .35862 m
.28133 .35659 L
s
.28015 .35388 m
.28133 .35659 L
s
.26859 .33137 m
.2694 .30538 L
s
.27884 .35591 m
.28015 .35388 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26741 .331 m
.26823 .30499 L
s
.27884 .35591 m
.28001 .35862 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26726 .33574 m
.26859 .33137 L
s
.26608 .33537 m
.26741 .331 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26367 .337 m
.26726 .33574 L
s
.25238 .29941 m
.26015 .30225 L
s
.26367 .337 m
.26608 .33537 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25514 .35109 m
.25678 .30104 L
s
.26136 .33625 m
.26367 .337 L
s
.25402 .35071 m
.25567 .30064 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25802 .33272 m
.26136 .33625 L
s
.25592 .32718 m
.25802 .33272 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2507 .34956 m
.25514 .35109 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24275 .29801 m
.24466 .30363 L
s
.24466 .30363 m
.24547 .31122 L
s
.2453 .316 m
.24547 .31122 L
s
.24173 .29758 m
.24362 .30321 L
s
.24362 .30321 m
.24442 .3108 L
s
.23978 .29433 m
.24275 .29801 L
s
.24401 .32277 m
.2453 .316 L
s
.24425 .31558 m
.24442 .3108 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23978 .29433 m
.24173 .29758 L
s
.24296 .32236 m
.24425 .31558 L
s
.23063 .27311 m
.23737 .2763 L
s
.23777 .29345 m
.23978 .29433 L
s
.24176 .32675 m
.24401 .32277 L
s
.24073 .32634 m
.24296 .32236 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23571 .29497 m
.23777 .29345 L
s
.23264 .32539 m
.23444 .27494 L
s
.2386 .32791 m
.24176 .32675 L
s
.23167 .32496 m
.23348 .27449 L
s
.2386 .32791 m
.24073 .32634 L
s
.23358 .29889 m
.23571 .29497 L
s
.23658 .32708 m
.2386 .32791 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23468 .32382 m
.23658 .32708 L
s
.23289 .31814 m
.23468 .32382 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22724 .28853 m
.22816 .28898 L
s
.2288 .32367 m
.23264 .32539 L
s
.22532 .29002 m
.22724 .28853 L
s
.22623 .29048 m
.22724 .28853 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22515 .29484 m
.22623 .29048 L
s
.22425 .29439 m
.22532 .29002 L
s
.22452 .31178 m
.22515 .29484 L
s
.22265 .28863 m
.22425 .29439 L
s
.22344 .31618 m
.22425 .29439 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22099 .28528 m
.22265 .28863 L
s
.82398 .28551 m
.82588 .33657 L
s
.22344 .31618 m
.22452 .31178 L
s
.21842 .28387 m
.22099 .28528 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82485 .28504 m
.82676 .33613 L
s
.22281 .30845 m
.22362 .31133 L
s
.21769 .30328 m
.22281 .30845 L
s
.22245 .31817 m
.22344 .31618 L
s
.22059 .31971 m
.22245 .31817 L
s
.21666 .28534 m
.21842 .28387 L
s
.21583 .28486 m
.21842 .28387 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82134 .28691 m
.82988 .28219 L
s
.21714 .31791 m
.22059 .31971 L
s
.21565 .28972 m
.21666 .28534 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21483 .28924 m
.21583 .28486 L
s
.82988 .28219 m
.83159 .28366 L
s
.82988 .28219 m
.83239 .28317 L
s
.21611 .29992 m
.21769 .30328 L
s
.21528 .29945 m
.21769 .30328 L
s
.21546 .29458 m
.21565 .28972 L
s
.21546 .29458 m
.21611 .29992 L
s
.21465 .29411 m
.21483 .28924 L
s
.83159 .28366 m
.83337 .28756 L
s
.21465 .29411 m
.21528 .29945 L
s
.21555 .31455 m
.21714 .31791 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21491 .30921 m
.21574 .30967 L
s
.21564 .31211 m
.21574 .30967 L
s
.83239 .28317 m
.83415 .28708 L
s
.21482 .31165 m
.21555 .31455 L
s
.21482 .31165 m
.21491 .30921 L
s
.83337 .28756 m
.83434 .29196 L
s
.83415 .28708 m
.83511 .29147 L
s
.83434 .29196 m
.83539 .29881 L
s
.83511 .29147 m
.83616 .29833 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82322 .33788 m
.83183 .33347 L
s
.83183 .33347 m
.83337 .33011 L
s
.83183 .33347 m
.83417 .32965 L
s
.83539 .29881 m
.83587 .31106 L
s
.83616 .29833 m
.83664 .31059 L
s
.83337 .33011 m
.83478 .32428 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83838 .27681 m
.84328 .2733 L
s
.83538 .3189 m
.83587 .31106 L
s
.83417 .32965 m
.83557 .32382 L
s
.83478 .32428 m
.83538 .3189 L
s
.83615 .31843 m
.83664 .31059 L
s
.20781 .30498 m
.20848 .30791 L
s
.20838 .31036 m
.20848 .30791 L
s
.83557 .32382 m
.83615 .31843 L
s
.20753 .31235 m
.20838 .31036 L
s
.20697 .30696 m
.20781 .30498 L
s
.20047 .27203 m
.20522 .27557 L
s
.84053 .27532 m
.84189 .30973 L
s
.20697 .30696 m
.20762 .30989 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20531 .31093 m
.20753 .31235 L
s
.84123 .27481 m
.84259 .30925 L
s
.20177 .30853 m
.20313 .27407 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83973 .31116 m
.84259 .30925 L
s
.20109 .30805 m
.20245 .27356 L
s
.20396 .30751 m
.20531 .31093 L
s
.84201 .29445 m
.84299 .30136 L
s
.20275 .30161 m
.20396 .30751 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20235 .29372 m
.20275 .30161 L
s
.84299 .30136 m
.84455 .30532 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19909 .30659 m
.20177 .30853 L
s
.84455 .30532 m
.84598 .30682 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84598 .30682 m
.84791 .30535 L
s
.19593 .28873 m
.19673 .26895 L
s
.1936 .2867 m
.19777 .29024 L
s
.84708 .30089 m
.84781 .30287 L
s
.84708 .30089 m
.84761 .29791 L
s
.19534 .28822 m
.19614 .26843 L
s
.84761 .29791 m
.84834 .2999 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19488 .26986 m
.19584 .27584 L
s
.84791 .30535 m
.84844 .30238 L
s
.84834 .2999 m
.84844 .30238 L
s
.19331 .26581 m
.19488 .26986 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85157 .27402 m
.85192 .26854 L
s
.85157 .27402 m
.85177 .27898 L
s
.85192 .26854 m
.85342 .26448 L
s
.19224 .26475 m
.19331 .26581 L
s
.19462 .32109 m
.19523 .30612 L
s
.19433 .31311 m
.19523 .30612 L
s
.85177 .27898 m
.85253 .28343 L
s
.85212 .2735 m
.85246 .26802 L
s
.85212 .2735 m
.85232 .27846 L
s
.85246 .26802 m
.85342 .26448 L
s
.85232 .27846 m
.85307 .28292 L
s
.1911 .26618 m
.19224 .26475 L
s
.1906 .26565 m
.19224 .26475 L
s
.85342 .26448 m
.85494 .26289 L
s
.85253 .28343 m
.85424 .28438 L
s
.19296 .31712 m
.19433 .31311 L
s
.19433 .31311 m
.19462 .32109 L
s
.85307 .28292 m
.85424 .28438 L
s
.85293 .29339 m
.85303 .29588 L
s
.85293 .29339 m
.85348 .29288 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1899 .2701 m
.1911 .26618 L
s
.85303 .29588 m
.85368 .29787 L
s
.85348 .29288 m
.85358 .29538 L
s
.18941 .26957 m
.1906 .26565 L
s
.85494 .26289 m
.85602 .26431 L
s
.19117 .31816 m
.19296 .31712 L
s
.85424 .28438 m
.85732 .28376 L
s
.85368 .29787 m
.85485 .29936 L
s
.18921 .27455 m
.1899 .2701 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85602 .26431 m
.85716 .26823 L
s
.18873 .27403 m
.18941 .26957 L
s
.85485 .29936 m
.85688 .29733 L
s
.19009 .31717 m
.19117 .31816 L
s
.18842 .28153 m
.18921 .27455 L
s
.18795 .281 m
.18873 .27403 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85716 .26823 m
.8574 .2627 L
s
.85716 .26823 m
.85809 .29076 L
s
.8574 .2627 m
.85818 .25913 L
s
.18915 .31366 m
.19009 .31717 L
s
.18864 .31316 m
.19009 .31717 L
s
0 0 0 r
.86212 .24916 m
.86363 .24712 L
s
.255 .412 .882 r
.1879 .29405 m
.18842 .28153 L
s
.85761 .2677 m
.85785 .26216 L
s
.85761 .2677 m
.85834 .28522 L
s
.85785 .26216 m
.85818 .25913 L
s
.85732 .28376 m
.85788 .28574 L
s
.18743 .29354 m
.18795 .281 L
s
.85688 .29733 m
.85773 .29379 L
s
.85818 .25913 m
.8586 .25859 L
s
.18835 .30763 m
.18915 .31366 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18786 .30713 m
.18864 .31316 L
s
.1879 .29405 m
.18807 .3021 L
s
.18807 .3021 m
.18835 .30763 L
s
.85773 .29379 m
.85809 .29076 L
s
.18743 .29354 m
.18759 .30159 L
s
.85809 .29076 m
.85834 .28522 L
s
.18759 .30159 m
.18786 .30713 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86372 .27565 m
.86539 .27884 L
s
.86402 .27293 m
.86524 .27524 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86419 .29813 m
.86453 .29897 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18315 .29086 m
.18554 .29399 L
s
0 0 0 r
.86569 .25797 m
.86574 .25922 L
s
.86565 .25832 m
.86574 .25922 L
s
.255 .412 .882 r
.18427 .25505 m
.1843 .29243 L
s
.18142 .28823 m
.18427 .25505 L
s
.18174 .28876 m
.18395 .26258 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86089 .29268 m
.86348 .28901 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86199 .25367 m
.86475 .28689 L
s
.86199 .25367 m
.86206 .29111 L
s
.86231 .26121 m
.86243 .29059 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18142 .28823 m
.18171 .25063 L
s
.17916 .28397 m
.18171 .25063 L
s
.17941 .2845 m
.18139 .2582 L
s
.86435 .24923 m
.8668 .28262 L
s
.86435 .24923 m
.86475 .28689 L
s
0 0 0 r
.86911 .23703 m
.86912 .23691 L
s
.255 .412 .882 r
.86467 .25682 m
.86504 .28636 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86912 .23691 m
.86953 .23576 L
s
.255 .412 .882 r
.17848 .28236 m
.18021 .2861 L
s
0 0 0 r
.86953 .23576 m
.87006 .23823 L
s
.86953 .23576 m
.87022 .23765 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17549 .24692 m
.17542 .23852 L
s
.17523 .25837 m
.17549 .24692 L
s
.255 .412 .882 r
.17942 .24503 m
.1796 .24559 L
s
.86611 .28423 m
.86741 .281 L
s
0 0 0 r
.17491 .26565 m
.17523 .25837 L
s
.17542 .23852 m
.17509 .23316 L
s
.17529 .24635 m
.17525 .23795 L
s
.17502 .25781 m
.17529 .24635 L
s
.255 .412 .882 r
.17897 .24644 m
.17942 .24503 L
s
.17913 .247 m
.17942 .24503 L
s
0 0 0 r
.87006 .23823 m
.87054 .24491 L
s
.1747 .26509 m
.17502 .25781 L
s
.17525 .23795 m
.17509 .23316 L
s
.17423 .27603 m
.17491 .26565 L
s
.87022 .23765 m
.8707 .24434 L
s
.255 .412 .882 r
.17875 .25153 m
.17913 .247 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17404 .27548 m
.1747 .26509 L
s
.17509 .23316 m
.17481 .232 L
s
.87054 .24491 m
.87228 .2851 L
s
.255 .412 .882 r
.1786 .25097 m
.17897 .24644 L
s
.17799 .26941 m
.17875 .25153 L
s
0 0 0 r
.8707 .24434 m
.87244 .28455 L
s
.17353 .28225 m
.17423 .27603 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17481 .232 m
.17432 .2339 L
s
.255 .412 .882 r
.17854 .24475 m
.1786 .25097 L
s
.17761 .27399 m
.1786 .25097 L
s
0 0 0 r
.17336 .28171 m
.17404 .27548 L
s
.255 .412 .882 r
.17841 .24106 m
.17854 .24475 L
s
.17761 .27399 m
.17799 .26941 L
s
.86714 .24956 m
.86723 .25523 L
s
.86723 .25523 m
.86741 .26346 L
s
0 0 0 r
.17287 .28429 m
.17353 .28225 L
s
.255 .412 .882 r
.86741 .26346 m
.86796 .27627 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86714 .24956 m
.86714 .24332 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17813 .23935 m
.17841 .24106 L
s
.17779 .26575 m
.17783 .26886 L
s
.86725 .249 m
.86735 .25467 L
s
.86735 .25467 m
.86755 .2629 L
s
0 0 0 r
.17432 .2339 m
.17383 .24004 L
s
.255 .412 .882 r
.86724 .24275 m
.86725 .249 L
s
.17725 .25986 m
.17779 .26575 L
s
0 0 0 r
.17287 .28429 m
.17336 .28171 L
s
.255 .412 .882 r
.86755 .2629 m
.8681 .27573 L
s
.86714 .24332 m
.86729 .23906 L
s
.17736 .27601 m
.17761 .27399 L
s
0 0 0 r
.87134 .22527 m
.87104 .22937 L
s
.255 .412 .882 r
.86724 .24275 m
.86729 .23906 L
s
0 0 0 r
.87286 .28291 m
.87228 .2851 L
s
.255 .412 .882 r
.86796 .27627 m
.86843 .28344 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17304 .25836 m
.1747 .26509 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17699 .27749 m
.17736 .27601 L
s
.17789 .24077 m
.17813 .23935 L
s
.17784 .2402 m
.17813 .23935 L
s
.8681 .27573 m
.86856 .2829 L
s
0 0 0 r
.17247 .28265 m
.17287 .28429 L
s
.255 .412 .882 r
.86729 .23906 m
.86741 .23791 L
s
.17659 .27531 m
.17699 .27749 L
s
.17762 .24533 m
.17789 .24077 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86856 .2829 m
.8689 .28752 L
s
.86843 .28344 m
.86878 .28806 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .23791 m
.86763 .23876 L
s
0 0 0 r
.17312 .25892 m
.17264 .26995 L
s
.255 .412 .882 r
.86878 .28806 m
.86924 .29215 L
s
.17725 .25986 m
.17723 .25617 L
s
.17725 .25986 m
.17718 .25561 L
s
.17758 .24476 m
.17784 .2402 L
s
0 0 0 r
.17241 .27787 m
.17247 .28265 L
s
.17304 .25836 m
.17272 .26571 L
s
.255 .412 .882 r
.8689 .28752 m
.86934 .29162 L
s
.1774 .25047 m
.17762 .24533 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17264 .26995 m
.17241 .27787 L
s
.17248 .27363 m
.17241 .27787 L
s
.255 .412 .882 r
.17723 .25617 m
.1774 .25047 L
s
0 0 0 r
.17272 .26571 m
.17248 .27363 L
s
.255 .412 .882 r
.17736 .24991 m
.17758 .24476 L
s
.86763 .23876 m
.86786 .24277 L
s
.17657 .27164 m
.17659 .27531 L
s
.17718 .25561 m
.17736 .24991 L
s
0 0 0 r
.17404 .22498 m
.17373 .23173 L
s
.17341 .23966 m
.17404 .22498 L
s
.255 .412 .882 r
.17679 .26648 m
.17674 .26592 L
s
.17668 .26905 m
.17679 .26648 L
s
.86753 .23505 m
.86842 .25566 L
s
.17663 .2685 m
.17657 .27164 L
s
.17674 .26592 m
.17663 .2685 L
s
.86832 .25342 m
.86838 .25734 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86934 .29162 m
.86961 .29314 L
s
.86924 .29215 m
.86961 .29314 L
s
0 0 0 r
.87128 .22703 m
.87352 .27852 L
s
.87123 .22761 m
.87347 .27907 L
s
.17373 .23173 m
.17341 .23966 L
s
.17391 .22747 m
.17373 .23173 L
s
.255 .412 .882 r
.86752 .23447 m
.86841 .2551 L
s
0 0 0 r
.17413 .22263 m
.17391 .22747 L
s
.255 .412 .882 r
.86961 .29314 m
.86974 .29207 L
s
0 0 0 r
.87075 .21878 m
.87128 .22291 L
s
.87359 .27687 m
.87347 .27907 L
s
.17439 .22026 m
.17413 .22263 L
s
.255 .412 .882 r
.86974 .28786 m
.86974 .29207 L
s
0 0 0 r
.17244 .26178 m
.17261 .25752 L
s
.17212 .26918 m
.17244 .26178 L
s
.17261 .25752 m
.17281 .25269 L
s
.87112 .22114 m
.87289 .26182 L
s
.17228 .26548 m
.17245 .26122 L
s
.17245 .26122 m
.17265 .25639 L
s
.17196 .27233 m
.17212 .26918 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87104 .22055 m
.87281 .26126 L
s
.87444 .30133 m
.87465 .30452 L
s
.87432 .29707 m
.87444 .30133 L
s
.255 .412 .882 r
.86953 .28158 m
.86974 .28786 L
s
0 0 0 r
.17281 .25269 m
.17342 .24243 L
s
.17442 .22277 m
.17439 .22026 L
s
.87452 .30026 m
.87432 .29707 L
s
.255 .412 .882 r
.86644 .22698 m
.86725 .23102 L
s
0 0 0 r
.17265 .25639 m
.17326 .24613 L
s
.255 .412 .882 r
.86919 .27324 m
.86986 .28885 L
s
.86919 .27324 m
.86953 .28158 L
s
0 0 0 r
.17184 .27494 m
.17196 .27233 L
s
.255 .412 .882 r
.86953 .28158 m
.86986 .28885 L
s
0 0 0 r
.87465 .30452 m
.87452 .30026 L
s
.255 .412 .882 r
.1766 .26408 m
.17675 .26093 L
s
.17648 .26668 m
.1766 .26408 L
s
.17642 .26873 m
.17648 .26668 L
s
.1767 .26297 m
.17675 .26093 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17438 .22588 m
.17442 .22277 L
s
.255 .412 .882 r
.86697 .22929 m
.86853 .26568 L
s
.17653 .26613 m
.1767 .26297 L
s
0 0 0 r
.17205 .27272 m
.17184 .27494 L
s
.17342 .24243 m
.17378 .23757 L
s
.255 .412 .882 r
.17662 .26707 m
.17642 .26873 L
s
0 0 0 r
.17389 .23699 m
.17438 .22588 L
s
.255 .412 .882 r
.86685 .22871 m
.86842 .26513 L
s
0 0 0 r
.17326 .24613 m
.17362 .24127 L
s
.17378 .23757 m
.17405 .23328 L
s
.87313 .26871 m
.87289 .26182 L
s
.17362 .24127 m
.17389 .23699 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87305 .26815 m
.87281 .26126 L
s
.255 .412 .882 r
.86842 .26513 m
.86881 .26734 L
s
0 0 0 r
.86882 .21225 m
.8702 .21641 L
s
.255 .412 .882 r
.17662 .26707 m
.17691 .26336 L
s
0 0 0 r
.87301 .27077 m
.87313 .26871 L
s
.17238 .26788 m
.17205 .27272 L
s
.255 .412 .882 r
.86774 .24948 m
.86795 .25674 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1773 .26375 m
.17807 .24579 L
s
.17716 .26431 m
.17795 .246 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17691 .26336 m
.17737 .25703 L
s
0 0 0 r
.87301 .27077 m
.87305 .26815 L
s
.17265 .26359 m
.17238 .26788 L
s
.17309 .25557 m
.17265 .26359 L
s
.17244 .2705 m
.17309 .25557 L
s
.255 .412 .882 r
.17737 .25703 m
.17783 .24864 L
s
0 0 0 r
.17265 .26359 m
.17244 .2705 L
s
.255 .412 .882 r
.86789 .26085 m
.86795 .25674 L
s
0 0 0 r
.17564 .21805 m
.17601 .21375 L
s
.17568 .22118 m
.17564 .21805 L
s
.17601 .21375 m
.17606 .21687 L
s
.87276 .26966 m
.87301 .27077 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17606 .21687 m
.17568 .22118 L
s
.255 .412 .882 r
.86768 .26236 m
.86789 .26085 L
s
0 0 0 r
.87214 .26424 m
.87276 .26966 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87146 .25562 m
.87214 .26424 L
s
.255 .412 .882 r
.86676 .25282 m
.86708 .256 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86948 .21403 m
.87175 .26631 L
s
.86968 .21463 m
.87194 .26687 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87109 .26464 m
.87194 .26687 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17292 .28489 m
.1739 .26228 L
s
.5 Mabswid
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17314 .28434 m
.17488 .23981 L
s
.17272 .28543 m
.17488 .23981 L
s
.86769 .21991 m
.86847 .23173 L
s
.86674 .21125 m
.86769 .21991 L
s
.1726 .29245 m
.17272 .28543 L
s
.86555 .20573 m
.86674 .21125 L
s
.8664 .21066 m
.86738 .21932 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86738 .21932 m
.86817 .23115 L
s
.86847 .23173 m
.86879 .23924 L
s
.86555 .20573 m
.8664 .21066 L
s
.86817 .23115 m
.8685 .23867 L
s
.86879 .23924 m
.86898 .24996 L
s
.17314 .28434 m
.1726 .29245 L
s
.8648 .20454 m
.86555 .20573 L
s
.8685 .23867 m
.86867 .2494 L
s
.86868 .25639 m
.86898 .24996 L
s
.86417 .20712 m
.8648 .20454 L
s
.86376 .20653 m
.8648 .20454 L
s
.86835 .25583 m
.86867 .2494 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86366 .21347 m
.86417 .20712 L
s
.86781 .25851 m
.86868 .25639 L
s
.86323 .21289 m
.86376 .20653 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86781 .25851 m
.86835 .25583 L
s
.86366 .21347 m
.86371 .22423 L
s
.86706 .25739 m
.86781 .25851 L
s
.86323 .21289 m
.86326 .22365 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86371 .22423 m
.86403 .2318 L
s
.86611 .25248 m
.86706 .25739 L
s
.8657 .25192 m
.86706 .25739 L
s
.86326 .22365 m
.86358 .23123 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86403 .2318 m
.86495 .24375 L
s
.86495 .24375 m
.86611 .25248 L
s
.86358 .23123 m
.86452 .24319 L
s
.86452 .24319 m
.8657 .25192 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85411 .19101 m
.85426 .19468 L
s
.85467 .19235 m
.85478 .1951 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85605 .19394 m
.8599 .19805 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8561 .22692 m
.85622 .22969 L
s
.85554 .22559 m
.8557 .22928 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84887 .18755 m
.8536 .19161 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85832 .19628 m
.86169 .27657 L
s
.85777 .1957 m
.86114 .27604 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85941 .27444 m
.86169 .27657 L
s
.85097 .18928 m
.8543 .2702 L
s
.85164 .18986 m
.85498 .27073 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84483 .19563 m
.84607 .20775 L
s
.84292 .18681 m
.84483 .19563 L
s
.84029 .18126 m
.84292 .18681 L
s
.84403 .19507 m
.84529 .20719 L
s
.84211 .18624 m
.84403 .19507 L
s
.84607 .20775 m
.84639 .21547 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84029 .18126 m
.84211 .18624 L
s
.84529 .20719 m
.8456 .21492 L
s
.85218 .26863 m
.85498 .27073 L
s
.84607 .22653 m
.84639 .21547 L
s
.83858 .18013 m
.84029 .18126 L
s
.84528 .22599 m
.8456 .21492 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83697 .18287 m
.83858 .18013 L
s
.83608 .18231 m
.83858 .18013 L
s
.84478 .23322 m
.84607 .22653 L
s
.84397 .23268 m
.84528 .22599 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84245 .23551 m
.84478 .23322 L
s
.84245 .23551 m
.84397 .23268 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83456 .18894 m
.83608 .18231 L
s
.83548 .18949 m
.83697 .18287 L
s
.83501 .20059 m
.83548 .18949 L
s
.83408 .20004 m
.83456 .18894 L
s
.84073 .23444 m
.84245 .23551 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83501 .20059 m
.83532 .20837 L
s
.83881 .22948 m
.84073 .23444 L
s
.83791 .22895 m
.84073 .23444 L
s
.83408 .20004 m
.83438 .20783 L
s
.83532 .20837 m
.83669 .2206 L
s
.83669 .2206 m
.83881 .22948 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83577 .22007 m
.83791 .22895 L
s
.83438 .20783 m
.83577 .22007 L
s
.8234 .17517 m
.82577 .18404 L
s
.82577 .18404 m
.82724 .19628 L
s
.80769 .13703 m
.81575 .14082 L
s
.82005 .16966 m
.8234 .17517 L
s
.82234 .17463 m
.82474 .1835 L
s
.82474 .1835 m
.82622 .19575 L
s
.82724 .19628 m
.82754 .2041 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82005 .16966 m
.82234 .17463 L
s
.82622 .19575 m
.82651 .20357 L
s
.82696 .21534 m
.82754 .2041 L
s
.81787 .16859 m
.82005 .16966 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81236 .13919 m
.81537 .22159 L
s
.82592 .21482 m
.82651 .20357 L
s
.81121 .13864 m
.81421 .2211 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81578 .17143 m
.81787 .16859 L
s
.82517 .22218 m
.82696 .21534 L
s
.82411 .22167 m
.82592 .21482 L
s
.81379 .17821 m
.81578 .17143 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82211 .2246 m
.82517 .22218 L
s
.82211 .2246 m
.82411 .22167 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81991 .22359 m
.82211 .2246 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81752 .21863 m
.81991 .22359 L
s
.81494 .20972 m
.81752 .21863 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79877 .16027 m
.80626 .16333 L
s
.81066 .21962 m
.81537 .22159 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78898 .18009 m
.80088 .18445 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78264 .15437 m
.7909 .15728 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78544 .15533 m
.79775 .24244 L
s
.79734 .23038 m
.80257 .16179 L
s
.79775 .24244 m
.80381 .16231 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2705 .19508 m
.27184 .18811 L
s
.27033 .19545 m
.2705 .19508 L
s
.27194 .19464 m
.27328 .18774 L
s
.27024 .19826 m
.27194 .19464 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30795 .22624 m
.31023 .14097 L
s
.30967 .22588 m
.31193 .14058 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30517 .14218 m
.33306 .13607 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33125 .13643 m
.33248 .16037 L
s
.33248 .16037 m
.33306 .13607 L
s
.31075 .18503 m
.32122 .18283 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32081 .19916 m
.32163 .16657 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30283 .22733 m
.33101 .22177 L
s
.35146 .13673 m
.35724 .13172 L
s
.3494 .14517 m
.35146 .13673 L
s
.35335 .13641 m
.35724 .13172 L
s
.35129 .14485 m
.35335 .13641 L
s
.35724 .13172 m
.36107 .1311 L
s
.34842 .19011 m
.3494 .14517 L
s
.35032 .1898 m
.35129 .14485 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36107 .1311 m
.36679 .13426 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36679 .13426 m
.37054 .14183 L
s
.37077 .12962 m
.37865 .1285 L
s
.32919 .2221 m
.3316 .1971 L
s
.33101 .22177 m
.3316 .1971 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34278 .19104 m
.35032 .1898 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36967 .18693 m
.37077 .12962 L
s
.37164 .18666 m
.37273 .12933 L
s
.3926 .13075 m
.39876 .12595 L
s
.38842 .13942 m
.3926 .13075 L
s
.39462 .13051 m
.39876 .12595 L
s
.39044 .13917 m
.39462 .13051 L
s
.39876 .12595 m
.40285 .12549 L
s
.3862 .15195 m
.38842 .13942 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38821 .1517 m
.39044 .13917 L
s
.40285 .12549 m
.40897 .12891 L
s
.38606 .16015 m
.3862 .15195 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38808 .15991 m
.38821 .1517 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40897 .12891 m
.413 .13667 L
s
.36379 .18775 m
.37164 .18666 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38606 .16015 m
.38787 .17225 L
s
.38808 .15991 m
.38989 .17201 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4257 .12321 m
.44052 .12202 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38787 .17225 m
.39179 .18002 L
s
.38989 .17201 m
.39383 .17979 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44907 .12142 m
.46415 .12054 L
s
.39179 .18002 m
.39786 .18348 L
s
.255 .412 .882 r
.56546 .13258 m
.56992 .13276 L
s
0 0 0 r
.39383 .17979 m
.39786 .18348 L
s
.41057 .16154 m
.4126 .16546 L
s
.40843 .16587 m
.41057 .16154 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40843 .16587 m
.41045 .1698 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43244 .16428 m
.43337 .16054 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45502 .17883 m
.45552 .12102 L
s
.4572 .17871 m
.45767 .12089 L
s
.41254 .16959 m
.4126 .16546 L
s
.39786 .18348 m
.40405 .18283 L
s
.48371 .1238 m
.4881 .11955 L
s
.4881 .11955 m
.49248 .11943 L
s
.48152 .12388 m
.4881 .11955 L
s
.49248 .11943 m
.49685 .12343 L
s
.40826 .17827 m
.41254 .16959 L
s
.47711 .13227 m
.48152 .12388 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4793 .13219 m
.48371 .1238 L
s
.50125 .11923 m
.51003 .1191 L
s
.52543 .11904 m
.52763 .12315 L
s
.52323 .12314 m
.52543 .11904 L
s
.255 .412 .882 r
.55695 .16163 m
.55698 .16697 L
s
.55478 .1602 m
.55478 .1611 L
s
0 0 0 r
.40405 .18283 m
.40826 .17827 L
s
.49685 .12343 m
.50121 .13157 L
s
.52543 .12726 m
.52763 .12315 L
s
.52323 .12314 m
.52543 .12726 L
s
.47486 .14473 m
.47711 .13227 L
s
.47704 .14464 m
.4793 .13219 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47481 .15299 m
.47486 .14473 L
s
.47699 .15291 m
.47704 .14464 L
s
.255 .412 .882 r
.55478 .1611 m
.55698 .16697 L
s
0 0 0 r
.47481 .15299 m
.47692 .16534 L
s
.47699 .15291 m
.47911 .16526 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43103 .20957 m
.43203 .12268 L
s
.43317 .20941 m
.43415 .12251 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44853 .17921 m
.4572 .17871 L
s
.47692 .16534 m
.48126 .1735 L
s
.47911 .16526 m
.48346 .17343 L
s
.49668 .17307 m
.50112 .16467 L
s
.48126 .1735 m
.48785 .17746 L
s
.48346 .17343 m
.48785 .17746 L
s
.42464 .21006 m
.43317 .20941 L
s
.49226 .17734 m
.49668 .17307 L
s
.48785 .17746 m
.49226 .17734 L
s
.45485 .19969 m
.45699 .20375 L
s
.45264 .20399 m
.45485 .19969 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50101 .20643 m
.50125 .11923 L
s
.50323 .2064 m
.50344 .11919 L
s
.52544 .1479 m
.52768 .19787 L
s
.52323 .19786 m
.52544 .1479 L
s
.52545 .1728 m
.52545 .19786 L
s
.45264 .20399 m
.45478 .20806 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45478 .20806 m
.45699 .20375 L
s
.52546 .20625 m
.52768 .19787 L
s
.52323 .19786 m
.52546 .20625 L
s
.49436 .20656 m
.50323 .2064 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00103o
YQ05000000L0ojH@00<000000?nV403oYQ002@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@08
0?nV4@P00000103oYQ470:f][@<00000102][Jd2000000T0[Jf]0P00000K0:f][@l0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@P0000000<0ojHA0:f]
[@2][Jd0102][Jd2000000L0[Jf]1@3oYQ42000000030:f][@3oYQ00ojH@008000000P3oYQ020000
00T0ojH@00<000000?nV400000002P3oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@H0[Jf]0P0000040:f][@H0ojHA0P00000;0?nV4@80
000000<0ojHA0:f][@3oYQ000`3oYQ0010000000ojH@0000000000090?nV408000002`3oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?oo
o`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA00`0ojHA100000060:f][@@0ojHA00@0[Jf]0?nV4@00000000002P3oYQ420000
00X0ojHA0P0000020?nV4@030:f][@3oYQ00ojH@0080ojH@00@000000?nV4000000000002P3oYQ00
0`000000ojH@0?nV40090?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa0:
0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00@0[Jf]0?nV4@000000ojHA0P0000070:f][@800000103oYQ42
000000P0ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000X0ojHA0P0000020?nV4@030:f][@3o
YQ00ojH@00<0ojH@0`00000F0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005@3o
Xa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`
h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0C
0?nV4@030000003oYQ40[Jf]0080[Jf]0`0000000`2][Jd0ojHA0?nV4@050?nV4@8000001P3oYQ40
0`000000ojHA0?nV4@060?nV4@040:f][@3oYQ400000000000X0ojHA0P0000090?nV4@8000000`3o
YQ400`2][Jd0ojH@0?nV40030?nV40<000005P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1001P2][JdB0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ40102][Jd000000000002][Jd2000000040?nV4@2]
[Jd00000000000P0ojHA0P0000080?nV4@030000003oYQ40ojHA00D0ojHA00@0[Jf]0?nV4@000000
00002P3oYQ42000000T0ojHA0P0000030?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00000F0?nV4003
0:f][@3oYA00ojD@00L0ojD@00<0@FWQ0?nU403oYA004P3oYA000`2][Jd0oj<@0?nS400I0?nS4003
0:f][@3lX100o:0@00H0o:0@1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@@0[Jf]
0P0000050?nV4@040000002][Jd00000000000L0ojHA0P0000090?nV4@030000003oYQ40ojHA00D0
ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000T0ojHA0P0000030?nV4@030:f][@3oYQ00ojH@
00@0ojH@0P00000F0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2]
[Jd0o:0@0?bP400;0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@030?nV4@<0
00001@2][Jd30?nV4@8000001P3oYQ4010000000[Jf]0000000000070?nV4@8000002P3oYQ400`00
0000ojHA0?nV4@040?nV4@040:f][@3oYQ400000000000X0ojHA0P0000080?nV4@030000003oYQ40
000000<0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000001H0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@1P2][Jd20?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd000000=^:3@040=^:3@80[Jf]F@2`h>H1
0?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY140503oY1400`2][Jd0ojHA00000003000000030:f][@000000000000P0ojHA0P0000070?nV
4@<000001P3oYQ4200000180ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000P0ojHA0P000004
0?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00000F0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400F0?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P040:f][@3KRPd00000000000D0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1@0000000`2][Jd0ojHA0?nV4@02
0?nV4@8000001`3oYQ42000000P0ojHA0`0000060?nV4@8000004P3oYQ40102][Jd0ojHA00000000
000:0?nV4@800000203oYQ42000000@0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000001H0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`00
00050=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0>0?nT4@@0000000<0[Jf]0?nT4@2][Jd01P3oYQ42000000L0ojHA0P000008
0?nV4@030:f][@000000000000H0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA008000002P3oYQ42
000000L0ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@0?nV40040?nV408000005P3oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P040:f][@3KRPd0
fhX=000000T0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd20?nT4@040000003oY140oj@A0:f][@H0ojHA0P00
00070?nV4@800000203oYQ400`2][Jd00000000000060?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV
4@02000000X0ojHA0P0000070?nV4@030000003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ00103o
YQ02000001H0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh0102][Jd0fhX=0=^:3@00000;0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102]
[Jd60?nT4@040000003oY140oj@A0:f][@H0ojHA0P0000070?nV4@800000203oYQ400`2][Jd00000
000000050?nV4@8000004P3oYQ400`2][Jd0ojHA0?nV4@02000000X0ojHA0P0000070?nV4@030000
003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000001H0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
2`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0102][Jd0fhX=0=^:3@00000;0=^:3@80
[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A
0?nT4@030?nT4@@0[Jf]2P3oY14010000000oj@A0?nT4@2][Jd60?nV4@8000001`3oYQ42000000P0
ojHA00<0[Jf]0000000000001@3oYQ4200000180ojHA00<0[Jf]0?nV4@3oYQ400P00000:0?nV4@80
00001`3oYQ400`000000ojHA000000040?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00000:0?nV4003
0000003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL3`2][Jd0k9H>0140
k9H>00<0[Jf]0=^:3@0000002`3KRPd00`2][Jd0^GD;0:f][@1@0;3PiP40oooo001U0;3PiP030:f]
[@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][@h0oj@A
00@000000?nT4@3oY140[Jf]1`3oYQ400`000000ojHA0?nV4@050?nV4@800000203oYQ400`2][Jd0
0000000000050?nV4@8000004P3oYQ400`2][Jd0ojHA0?nV4@02000000X0ojHA0P0000070?nV4@03
0000003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000X0ojH@00<000000?nV403o
YQ002@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0000000;0=^:3@04
0:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2]
[Jd0o:0@0?bP400>0?bP40<0[Jf]4P3oY14010000000oj@A0?nT4@2][Jd70?nV4@030000003oYQ40
ojHA00D0ojHA0P0000080?nV4@030:f][@000000000000D0ojHA0P00000B0?nV4@030:f][@3oYQ40
ojHA008000002P3oYQ42000000L0ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@0?nV4004
0?nV408000002P3oYQ000`000000ojH@0?nV40090?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0000000/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f]
[@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP
400<0?bP4080[Jf]00<0o:0@0:f][@3oY1404P3oY14010000000oj@A0?nT4@2][Jd70?nV4@030000
003oYQ40ojHA00D0ojHA0P0000080?nV4@030:f][@000000000000D0ojHA0P00000B0?nV4@030:f]
[@3oYQ40ojHA008000002P3oYQ42000000L0ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@
0?nV40040?nV408000002P3oYQ000`000000ojH@0?nV40090?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@8000002P3/UPh00`2][Jd0fhX=0000000;0=^:3@030:f]
[@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT
4@0A0?nT4@040000003oY140oj@A0:f][@L0ojHA00<000000?nV4@3oYQ401@3oYQ42000000P0ojHA
00<0[Jf]0000000000001@3oYQ4200000180ojHA00<0[Jf]0?nV4@3oYQ400P00000:0?nV4@800000
1`3oYQ400`2][Jd000000000000;0:f][@8000002P2][Jd00`000000[Jf]0:f][@0A0:f][AL0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh0103/UPh00`2][Jd0000000000002000000L0k9H>00<0[Jf]0=^:3@000000
2`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V00<0
[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0P2]
[Jd60?bP40030:f][@3oY140oj@A0140oj@A00<000000?nT4@2][Jd0203oYQ400`000000ojHA0?nV
4@050?nV4@800000203oYQ42000000H0ojHA0P00000B0?nV4@030:f][@3oYQ40ojHA008000000`3o
YQ470:f][@8000001`2][Jd00`3oYQ400000000000040?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00
000:0?nV40030000003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh01@3/UPh00`000000k9H>0:f][@020:f][@H0k9H>00<0[Jf]0=^:3@0000002`3K
RPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]
0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd8
0?bP40030:f][@3oY140oj@A0140oj@A00<000000?nT4@2][Jd0203oYQ400`000000ojHA0?nV4@05
0?nV4@800000203oYQ42000000H0ojHA0P00000:0?nV4@040000003oYQ40ojHA0?nV4@L0[Jf]0P00
00030:f][@L0ojHA0P0000080?nV4@030000003oYQ40000000<0ojHA00<0[Jf]0?nV403oYQ00103o
YQ02000000X0ojH@00<000000?nV403oYQ002@3oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01@3/
UPh00`000000k9H>0>bF3P020>bF3P80[Jf]0P0000020>bF3P040:f][@3KRPd00000000000X0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3C
Q`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@
00<0[Jf]0?nT4@3oY140403oY142000000030?nT4@2][Jd0ojHA00l0ojHA0P0000080?nV4@800000
1P3oYQ42000000D0ojHA1@2][Jd010000000[Jf]0:f][@2][Jd40?nV4@030:f][@3oYQ40ojHA0080
00002P3oYQ42000000T0ojHA0P0000030?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00000:0?nV4003
0000003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40020?nS40X0
[Jf]3P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh01P3/UPh00`000000k9H>0>bF3P030>bF3P80[Jf]0P000000102][Jd0fhX=00000000000:0=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0
dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3lX1000`2]
[Jd0oj@A0?nT4@0@0?nT4@80000000<0oj@A0:f][@3oYQ403`3oYQ42000000P0ojHA0P0000030?nV
4@<0[Jf]0P0000050:f][@@0ojHA00<000000?nV4@0000001P3oYQ400`2][Jd0ojHA0?nV4@020000
00X0ojHA0P0000090?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV40040?nV408000002P3oYQ000`00
0000ojH@0?nV40090?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f]
[@@0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00H0k9H>00<000000>bF3P3/UPh01@3/UPh010000000[Jf]0:f][@3KRPd2000000X0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@
00/0kiP@0P2][Jd@0?bP40030:f][@3oY140oj@A0100oj@A0P0000001@3oY140[Jf]0?nV4@3oYQ40
000000d0ojHA0P0000060?nV4@80[Jf]0P0000030:f][@<0ojHA0P0000090?nV4@030000003oYQ40
000000H0ojHA00<0[Jf]0?nV4@3oYQ400P00000:0?nV4@8000002@3oYQ42000000<0ojHA00<0[Jf]
0?nV403oYQ000`3oYQ03000000X0ojH@00<000000?nV403oYQ002@3oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdF0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh01P3/UPh00`000000k9H>0>bF3P050>bF3P040000003/UPh0[Jf]0:f][@8000002P3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]
0>nH403_V1002@3_V1030:f][A40o:0@00<0[Jf]0?nT4@3oY140403oY142000000050?nT4@2][Jd0
ojHA0?nV4@0000003@3oYQ400`000000ojHA0:f][@050:f][@80ojHA0P0000070?nV4@800000203o
YQ400`000000ojHA000000060?nV4@030:f][@3oYQ40ojHA008000002P3oYQ42000000X0ojHA0P00
00020?nV4@030:f][@3oYQ00ojH@0080ojH@00@000000?nV4000000000002P3oYQ000`000000ojH@
0?nV40090?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@
0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P060>bF3P03
0000003/UPh0k9H>00D0k9H>00@000000>bF3P2][Jd0fhX=0P0000000`2][Jd000000=^:3@070=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0
Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY140403oY142000000050?nT4@2][Jd0ojHA0?nV4@0000002P3oYQ430:f]
[@030000002][Jd0ojHA00L0ojHA0P0000070?nV4@8000002@3oYQ42000000H0ojHA00<0[Jf]0?nV
4@3oYQ400P00000:0?nV4@8000002P3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ000P3oYQ001000
0000ojH@00000000000:0?nV40030000003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh00`000000k9H>0>bF3P050>bF3P040000003/UPh0
[Jf]0=^:3@<0000000<0[Jf]0000003KRPd01P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28
EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH
40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0100oj@A0P00
00001@3oY140[Jf]0?nV4@3oYQ40000000D0ojHA1@2][Jd30?nV4@030000003oYQ40ojHA00L0ojHA
0P0000070?nV4@8000002@3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ40ojHA00800000
2P3oYQ42000000/0ojHA0P0000000`3oYQ40[Jf]0?nV40020?nV40030000003oYQ00ojH@00800000
2P3oYQ000`000000ojH@0?nV40090?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400>0?bP40H0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh01@3/UPh010000000k9H>0:f][@3KRPd300000003
0=^:3@000000000000H0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3P
iP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V1000`2]
[Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140403oY1420000
00050?nT4@2][Jd0ojHA0?nV4@0000001@2][Jd80?nV4@030000003oYQ40ojHA00L0ojHA0P000007
0?nV4@8000002@3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ40ojHA008000002P3oYQ42
000000`0ojHA0P000000102][Jd0ojH@0?nV400000030?nV408000002@3oYQ03000000X0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01@0o:0@1@2]
[JdE0?JL3`030:f][@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh0103/UPh2000000030>bF3P2]
[Jd0fhX=008000000`3KRPd2000000030:f][@3KRPd0fhX=0080fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@080=>73P030:f][@3_V100kiP@0080kiP@0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY140403oY142000000@0[Jf]00<000000?nV4@3oYQ402`3oYQ400`000000ojHA
0?nV4@070?nV4@800000203oYQ42000000L0ojHA00<000000?nV4@3oYQ401P3oYQ400`2][Jd0ojHA
0?nV4@02000000X0ojHA0P00000>0?nV4@<00000103oYQ02000000T0ojH@0`00000:0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P060>bF3P030000003/UPh0k9H>00@0k9H>
00D000000>bF3P3/UPh0[Jf]0=^:3@02000000<0fhX=0P0000000`3KRPd0[Jf]0:f][@020=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@T0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0>0?nT4@80[Jf]0P0000001@3oY140[Jf]0?nV4@3oYQ40
000000d0ojHA00<000000?nV4@3oYQ401`3oYQ42000000P0ojHA0P0000070?nV4@030000003oYQ40
ojHA00H0ojHA00<0[Jf]0?nV4@3oYQ400P0000060?nV4@H000003P3oYQ400`2][Jd0ojH@0?nV4004
0?nV408000002@3oYQ03000000X0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][@d0mY`?00<0[Jf]
0>bF3P3/UPh01`3/UPh00`000000k9H>0>bF3P030>bF3P050000003/UPh0k9H>0:f][@3KRPd00P00
00040=^:3@040000003KRPd0fhX=0=^:3@<0[Jf]2@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>7
3P060=>73P<0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00X0oj@A102]
[Jd20?nT4@80000000D0oj@A0:f][@3oYQ40ojHA0000000=0?nV4@030000003oYQ40ojHA00L0ojHA
0P0000090?nV4@8000001@3oYQ400`000000ojHA0?nV4@070?nV4@030:f][@3oYQ40ojHA00800000
6P3oYQ400`2][Jd0ojH@0?nV40040?nV408000002@3oYQ03000000X0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
1`3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh2000000@0k9H>00@000000>bF3P3/UPh0
[Jf]0P3KRPd00`000000fhX=0=^:3@020=^:3@800000103KRPd00`2][Jd0^GD;000000070;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00L0oj@A0`2][Jd60?nT4@040000003oY140oj@A0:f][@<000003@3oYQ400`00
0000ojHA0?nV4@070?nV4@8000002`3oYQ45000000X0ojHA00<0[Jf]0?nV4@3oYQ400P00000J0?nV
4@030:f][@3oYQ00ojH@00@0ojH@0P0000090?nV40<000002P3oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;0?JL
3`@0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P070>bF3P030000003/UPh000000080000000D0k9H>0000
003/UPh0k9H>0:f][@020=^:3@030000003KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P3KRPd4
000000H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX100403lX100
0`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]2@3oY14400000080ojHA00<000000?nV4@3oYQ402`3oYQ40
0`000000ojHA0?nV4@070?nV4@8000006P3oYQ400`2][Jd0ojHA0?nV4@02000001X0ojHA00<0[Jf]
0?nV403oYQ00103oYQ02000000T0ojH@0`00000:0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00l0mY`?102][Jd0
0`3fW0l0[Jf]0>bF3P080>bF3P030000003/UPh0k9H>0080k9H>0P0000020>bF3P040:f][@3KRPd0
fhX=000000D0fhX=00<000000=^:3@3KRPd00P3KRPd2000000030:f][@000000^GD;00D0^GD;00<0
[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd01P3CQ`h20:f][@030=>73P2][Jd0kiP@00/0kiP@00<0[Jf]0?bP403lX100403l
X1000`2][Jd0oj@A0:f][@030:f][@d0oj@A00@000000?nT4@3oY140[Jf]0P3oYQ400`000000ojHA
0?nV4@0;0?nV4@030000003oYQ40ojHA00H0ojHA00<0[Jf]0000000000006P3oYQ400`2][Jd0ojHA
0?nV4@02000001X0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000T0ojH@0`00000:0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?01<0mY`?0`2][Jd80>bF3P030000003/UPh0k9H>00<0k9H>00@000000>bF3P3/UPh0
[Jf]0P3KRPd00`000000fhX=0=^:3@030=^:3@030000003KRPd0fhX=0080fhX=00<000000;Ue2`2i
M@/00P0000020;Ue2`040000002iM@/0^GD;0:f][@@0R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0<
0>nH40030:f][@3lX100o:0@00l0o:0@0`2][JdA0?nT4@040000003oY140oj@A0:f][@80ojHA00<0
00000?nV4@3oYQ402`3oYQ400`000000ojHA0?nV4@040?nV4@<00000703oYQ400`2][Jd0ojHA0?nV
4@02000001X0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000T0ojH@0`00000:0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd50>bF3P030000003/UPh0k9H>00<0k9H>00@0
00000>bF3P3/UPh0[Jf]0P3KRPd00`000000fhX=0=^:3@030=^:3@030000003KRPd0fhX=0080fhX=
00<000000;Ue2`2iM@/00P0000001P2][Jd0^GD;0;Ue2`000000^GD;0:f][@@0R5H70P2][Je20;3P
iP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h00`2][Jd0dhL>0=>73P020=>7
3P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402][Jd0oj@A
0140oj@A00@000000?nT4@3oY140[Jf]0P3oYQ400`000000ojHA0?nV4@080?nV4@@00000203oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA008000006P3oYQ400`2][Jd0ojH@0?nV4004
0?nV408000002@3oYQ03000000X0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P02
0>bF3P80[Jf]0`3/UPh00`000000k9H>0>bF3P030>bF3P040000003/UPh0k9H>0:f][@80fhX=00<0
00000=^:3@3KRPd00`3KRPd00`000000fhX=0=^:3@020=^:3@030000002iM@/0^GD;0080000000<0
^GD;0:f][@2iM@/00P0000000`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH
400:0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd40?bP40030:f][@3oY140oj@A0100oj@A00@0
00000?nT4@3oY140[Jf]0P3oYQ400`000000ojHA0?nV4@0D0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ400P00000J0?nV4@030:f][@3oYQ00ojH@00@0ojH@0P0000090?nV40<00000
2P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd00`3/UPh00000
0>bF3P030>bF3P040000003/UPh0k9H>0:f][@80fhX=00<000000=^:3@3KRPd00`3KRPd2000000<0
fhX=00@000000;Ue2`2iM@/0^GD;0P0000001@2iM@/0[Jf]0000002iM@/0@FWQ00@0R5H70P2][Je2
0;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd60=>73P030:f][@3_
V100kiP@00X0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY140403o
Y14010000000oj@A0?nT4@2][Jd20?nV4@030000003oYQ40ojHA01@0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@02000001<0ojHA3P2][Jd2000000T0[Jf]0`00000B0:f][AL0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh01`3/UPh00`2][Jd000000:f][@030>bF3P040000003/UPh0k9H>0:f][@80
fhX=00<000000=^:3@3KRPd00`3KRPd200000080fhX=0P0000030;Ue2`8000000P2iM@/010000000
[Jf]00000000000308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@P0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]2@3lX1000`2]
[Jd0oj@A0?nT4@0@0?nT4@040000003oY140oj@A0:f][@80ojHA00<000000?nV4@3oYQ400P3oYQ40
0`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ400P000003
0?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV40040?nV408000002@3oYQ03000000X0ojH@00<0[Jf]
0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh010000000k9H>0:f][@2]
[Jd200000080k9H>00@0[Jf]0=^:3@3KRPd000001@3KRPd200000080fhX=0P0000030;Ue2`800000
0P2iM@/010000000^GD;0:f][@00000408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403l
X1000P3lX1020:f][@`0o:0@00<0[Jf]0?nT4@3oY140403oY14010000000oj@A0?nT4@2][Jd20?nV
4@030000003oYQ40ojHA0080ojHA00<000000?nV4@3oYQ403`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV
4@L0[Jf]0P0000030:f][@L0ojHA00<000000?nV4@3oYQ403@3oYQ400`2][Jd0ojH@0?nV40040?nV
408000002@3oYQ03000000X0ojH@00<0[Jf]0?nU403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00P0k9H>00@000000>bF
3P3/UPh0k9H>0P0000000`2][Jd0k9H>0:f][@020=^:3@030000003KRPd0fhX=00<0fhX=0P000002
0=^:3@80000000<0[Jf]0;Ue2`2iM@/00P0000020;Ue2`030000002iM@/0[Jf]008000000`28EPL0
0`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080[Jf]203CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0@0?nT
4@040000003oY140oj@A0:f][@L0ojHA00<000000?nV4@3oYQ403`3oYQ400`2][Jd0ojHA0?nV4@0<
0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@02000000T0ojHA0P00000?0?nV4@030:f][@3oYQ00
ojH@00@0ojH@0P0000090?nV40030000003oYQ00000000X0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh010000000k9H>0>bF3P3/UPh2000000050>bF3P2]
[Jd0[Jf]0:f][@3KRPd00P0000050=^:3@030000003KRPd0fhX=0080000000<0[Jf]0;Ue2`2iM@/0
0P0000020;Ue2`040000002iM@/0[Jf]000000@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00
F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][A40o:0@
00<0[Jf]0?nT4@3oY140403oY14010000000oj@A0?nT4@2][Jd70?nV4@030000003oYQ40ojHA00l0
ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ400P0000090?nV4@03
0000003oYQ40000000h0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000T0ojH@0P00000;0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00P0k9H>00D000000>bF3P3/
UPh0k9H>000000030>bF3P030:f][@3KRPd0[Jf]008000001@3KRPd00`000000fhX=0=^:3@020000
00050:f][@2iM@/0^GD;0;Ue2`0000000P2iM@/01@000000^GD;0:f][@000000[Jf]00<0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0
[Jf]0>nH403_V1002@3_V1030:f][A80o:0@00<0[Jf]0?nT4@3oY140403oY14010000000oj@A0?nT
4@2][Jd70?nV4@030000003oYQ40ojHA00`0ojHA202][JdH0?nV4@030:f][@3oYQ40ojHA00800000
203oYQ400`000000ojHA0000000?0?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00000:0?nV40030000
003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]
5`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00P0k9H>00D000000>bF3P3/UPh0
k9H>000000030>bF3P030:f][@3KRPd0fhX=0080000000<0[Jf]0=^:3@3KRPd00P3KRPd00`000000
fhX=0=^:3@02000000050:f][@2iM@/0^GD;0;Ue2`0000000P2iM@/02@000000^GD;0:f][@000000
R5H70:f][@28EPL000000:f][@120;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A0100oj@A0P0000020?nT4@030:f][@3oYQ40ojHA00D0ojHA00<000000?nV4@3oYQ40
1P3oYQ460:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@02000000P0ojHA
00<000000?nV4@0000003`3oYQ400`2][Jd0ojH@0?nV4006000000X0ojH@00<000000?nV403oYQ00
2@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100
o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh010000000
k9H>0>bF3P0000030>bF3P030:f][@3KRPd0fhX=0080000000<0fhX=0:f][@2][Jd00P3KRPd00`00
0000fhX=0=^:3@02000000050:f][@2iM@/0^GD;0;Ue2`0000000P2iM@/010000000^GD;0:f][@00
000208QF1`80000000<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00<0[Jf]
0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A0100oj@A0P0000020?nT4@030:f][@3oYQ40ojHA00D0ojHA00<00000
0?nV4@2][Jd01P2][Jd90?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@0000000P000009
0?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100203lX1060:f][@X0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P080>bF3P040000003/UPh0k9H>000000<0k9H>00<0
[Jf]0=^:3@3KRPd00P0000030=^:3@030:f][@00000000000080fhX=0P0000001@2][Jd0^GD;0;Ue
2`2iM@/000000080^GD;00@000000;Ue2`2][Jd000000P28EPL300000480/>3V0@3oool005T0/>3V
0P2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@H0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0@0?nT4@8000000P3oY140102][Jd0ojHA
0?nV4@3oYQ430:f][@80000000<0[Jf]0?nV4@3oYQ403P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@<0
00007@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00P0k9H>00@000000>bF3P3/UPh000000`3/UPh00`2][Jd0fhX=0=^:3@020000
00@0fhX=0P0000001@2][Jd0fhX=000000000000[Jf]00<0^GD;00L000000;Ue2`2iM@/000000;Ue
2`2][Jd000000080R5H70`0000120;3PiP40oooo001H0;3PiP030000002][Jd0Uf0;0080Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@P0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0@0?nT4@80000000<0oj@A0:f][@2][Jd00`2][Jd30?nV4@800000
4@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
5@3lX1060:f][A@0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh010000000k9H>0>bF3P0000030>bF3P03
0:f][@3KRPd0fhX=00800000103KRPd2000000050=^:3@2][Jd000000000002][Jd00`2iM@/00`00
0000^GD;0;Ue2`02000000040:f][@000000R5H708QF1`@00000@@2`h>H10?ooo`00F02`h>H00`00
0000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2P3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A00H0[Jf]000000000000[Jf]0?nT
4@2][Jd60?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0[Jf]0>bF3P3/UPh0
203/UPh010000000k9H>0>bF3P0000030>bF3P030:f][@3KRPd0fhX=00<000000`3KRPd200000080
fhX=0P0000001@2][Jd0^GD;0;Ue2`2iM@/000000080^GD;0P000000102iM@/0000008QF1`28EPL4
00000440/>3V0@3oool005P0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>7
3P80[Jf]303_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd00`3o
Y1400000000000020?nT4@030:f][@3oYQ40ojHA00@0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00@0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00P0k9H>00@000000>bF3P3/UPh000000`3/UPh0
0`2][Jd0fhX=0=^:3@03000000<0fhX=0P0000030=^:3@80000000@0[Jf]0;Ue2`2iM@/000000P2i
M@/2000000060;Ue2`000000000008QF1`000000R5H70P0000110;3PiP40oooo001H0;3PiP030000
002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]1@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ40
103oYQ4200000140ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]0>bF3P3/UPh0
203/UPh010000000k9H>0>bF3P0000030>bF3P030:f][@3KRPd0000000<000000P3KRPd2000000@0
fhX=0P000000102iM@/0[Jf]0:f][@0000020;Ue2`80000000H0^GD;0:f][@000000R5H700000028
EPL300000400/>3V0@3oool005L0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>00<0
[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00<0oj@A102]
[Jd90?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@030?nV4@<000004@3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0>0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P080>bF3P040000003/UPh00000000000@0k9H>
00<0[Jf]0=^:3@0000000P0000020=^:3@800000103KRPd2000000<0^GD;00<000000;Ue2`2iM@/0
0P0000001P2iM@/0[Jf]00000028EPL0000008QF1`<00000@02`h>H10?ooo`00E`2`h>H00`000000
[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00<0dhL>00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]3@3oY14200000080oj@A00<0[Jf]0?nV
4@0000000`0000000`3oYQ4000000?nV4@0A0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?102][Jd:0>bF
3P<00000103/UPh00`2][Jd0fhX=0=^:3@020=^:3@80000000<0fhX=0000003KRPd00`3KRPd20000
00<0^GD;00<000000:f][@2iM@/00P0000001P2iM@/0[Jf]00000028EPL0000008QF1`<00000@02`
h>H10?ooo`00E`2`h>H00`000000[Jf]0:f][@0309MP2`040:f][@3CQ`h0dhL>0=>73P80[Jf]0`3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00h0o:0@0`2][JdA0?nT4@H00000603o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]1`3/UPh3000000@0k9H>00<0
[Jf]0=^:3@3KRPd00`3KRPd2000000D0fhX=0P0000030;Ue2`030000002iM@/0[Jf]0080000000H0
@FWQ0:f][@000000R5H700000028EPL300000400/>3V0@3oool005L0/>3V00<000000:f][@2][Jd0
0`2GH0/0102][Jd0dhL>0=>73P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100303lX1020:f][@030?bP402][Jd0oj@A00l0oj@A0`0000030?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]1@3/UPh3000000@0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd200000080^GD;00<000000;Ue2`2iM@/00P0000001P2iM@/0
[Jf]00000028EPL0000008QF1`<00000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]0:f][@0309MP
2`030:f][@3CQ`h0[Jf]00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP
40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]0P3/UPh3000000@0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd200000080^GD;00<000000;Ue2`2iM@/00P0000020:f][@0400000028EPL00000
08QF1`<00000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]0:f][@0309MP2`80[Jf]1`3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f][@3oY140oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00L0k9H>0P2][Jd2000000D0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd000000;Ue2`020000
00<0^GD;00L000000;Ue2`2][Jd0000008QF1`000000R5H700<00000@02`h>H10?ooo`00EP2`h>H2
000000030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00T0k9H>0P0000000`2][Jd0k9H>0>bF3P020>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0000000000000P0000030;Ue2`070000002iM@/0[Jf]00000028EPL00000
08QF1`0300000400/>3V0@3oool005H0/>3V0P000000102][Jd0Uf0;09MP2`2GH0/20:f][@L0dhL>
00<0[Jf]0>nH403_V100303_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00T0k9H>0P0000001P3/UPh0
[Jf]0:f][@2][Jd0k9H>0:f][@h0fhX=00<0[Jf]000000000000102iM@/01`000000^GD;0:f][@00
0000R5H700000028EPL00`0000100;3PiP40oooo001F0;3PiP80000000@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0
/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P0:0>bF3P030000003/UPh0k9H>0080k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00@0
^GD;00L000000;Ue2`2][Jd000000:f][@000000R5H700<00000@02`h>H10?ooo`00EP2`h>H20000
00060:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40<0[Jf]403l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303o
YQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P0:0>bF3P030000003/UPh0k9H>00<0k9H>00@0[Jf]0=^:3@2][Jd0[Jf]
2`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`050000002iM@/0[Jf]0000002][Jd01@0000100;3PiP40
oooo001F0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f]
[@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P030000003/UPh0k9H>00<0k9H>
00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00@0^GD;00D000000;Ue2`2]
[Jd0000008QF1`0500000400/>3V0@3oool005H0/>3V0P0000000`2][Jd0Uf0;0:f][@0209MP2`03
0:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0
[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00T0k9H>00<000000>bF3P3/
UPh00`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`05
0000002iM@/0[Jf]00000028EPL01P00000o0;3PiP40oooo001F0;3PiP8000000P2][Jd309MP2`03
0:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0
[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/01@000000^GD;0:f][@000000R5H7
0080000000@0[Jf]0000000000000000?`2`h>H10?ooo`00EP2`h>H200000080[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd70>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f]
[@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00@0^GD;00D000000;Ue2`2][Jd0000008QF1`02
000000040:f][@0000000000000003l0/>3V0@3oool005H0/>3V0P0000000`2][Jd0Uf0;09MP2`02
09MP2`030:f][@3CQ`h0dhL>00D0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd90>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V
1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/01@2iM@/010000000^GD;0;Ue2`00000208QF1`03
0000002][Jd0000000800000?`2`h>H10?ooo`00EP2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2]
[Jd0203CQ`h0102][Jd0kiP@0:f][@2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd20:f][@H0^GD;00@000000;Ue2`2iM@/000000P28EPL00`000000[Jf]00000002
000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd=
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@@0^GD;0P000000
102iM@/0000008QF1`28EPL5000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00L0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3o
Y1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303K
RPd0102][Jd0^GD;0;Ue2`2][Jd30;Ue2`80000000@0^GD;00000028EPL0R5H71@00000o0;3PiP40
oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80[Jf]00<0dhL>0:f][@3_
V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0
[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2i
M@/0^GD;0:f][@020;Ue2`80000000<0^GD;0000000000000P28EPL4000003l0/>3V0@3oool005H0
/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/2
0:f][@80000000<0^GD;0:f][@0000000P28EPL010000000[Jf]00000000000o0;3PiP40oooo001F
0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0dhL>0080dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80000000<0^GD;0:f][@0000000P28
EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H2000000060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>
0P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V
0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/200000080[Jf]
00<0000008QF1`28EPL00P2][Jd2000003l0/>3V0@3oool005H0/>3V0P000000102][Jd0Uf0;09MP
2`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]
0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/2000000030;Ue2`2][Jd0000000<0R5H700<0[Jf]00000000
0000?`2`h>H10?ooo`00EP2`h>H2000000@0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk
102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/2000000030;Ue
2`2][Jd0000000<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H2000000<0Uf0;0P2]
[Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2]
[Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`030;Ue2`<0000000<0^GD;0:f][@0000000`28EPL00`2][Jd000000000
000o0;3PiP40oooo001F0;3PiP8000000`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H4
0:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<
0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P000000102iM@/0[Jf]0000002][Jd208QF1`030:f][@00
0000000003l0/>3V0@3oool005H0/>3V0P00000209MP2`030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH0
0`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd000000:f][@02
08QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00@000000:f][@2GH0/0[Jf]0P2GH0/0
0`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00X0kiP@0`2][Jd00`11JN40/J^M0;6[W@05
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][MP0/>3V102][Jd8
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@/0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/20000000408QF1`2][Jd0R5H70:f][@800000?`2`h>H10?ooo`00EP2`h>H0
10000000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100203_
V1020:f][@80/J^M0`11JN460;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n
]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n
^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0000008QF1`28EPL20:f][@800000
?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1001P3_V1040:f][@80/J^M0P11JN470;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF
1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3C
Q`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]
0P11JN470;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V
1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H7
08QF1`0208QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3C
Q`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd20:BNS`03045Yh@2TWXl0[Jf]00@0/J^M
0P11JN470;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f][@2][Jd30=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`h>H0/>3V03d0
/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P040:f]
[@3_V100[Jf]0:f][@<0Y9j?00@0@FWQ0:BNS`11JN40[Jf]102aZid2045Yh@80[Jf]1@2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f]
[JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102]
[Jd0_[Vh0;ji^02n^KP20:f][@L0_[Vh0`11JN401P2d/;40@FWQ0:f][@2][Jd0fhX=0:f][@X0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;
00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@@0Y9j?00D0@FWQ0:BNS`2TWXl0@FWQ0:f][@040;6[W@80
@FWQ0P2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]202n^KP3045Yh@<0];2a00@0@FWQ0;B`
/@2][Jd0[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V00<00000
0:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@11JN40Y9j?00@0Y9j?00@0@FWQ
0:BNS`2TWXl0Y9j?1011JN400`2aZid0@FWQ045Yh@040;6[W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03033
_K/30:f][@/0_[Vh0P11JN430;B`/@04045Yh@2d/;40];2a0;B`/@80[Jf]202iM@/0102][Jd0R5H7
08QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>
0=>73P040=>73P80[Jf]0P11JN450:BNS`04045Yh@2TWXl0Y9j?0:BNS`<0@FWQ0P2aZid2045Yh@H0
/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0
`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP02`2n^KP2045Y
h@<0];2a0P11JN420;B`/@03045Yh@2d/;40[Jf]00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je0
0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h30:f]
[@80@FWQ1@2TWXl01P11JN40Y9j?0:BNS`2][Jd0/J^M045Yh@<0/J^M0`11JN460;6[W@030:f][@2i
/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji
^00:0;ji^080@FWQ00<0[Jf]0;B`/@2d/;400P11JN420;B`/@80@FWQ00<0];2a0:f][@2][Jd01@2i
M@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@040=>73P040:f][@2:QGD0RXEe0:f][@80@FWQ1@2TWXl01P11JN40Y9j?0:BNS`2][Jd0/J^M
045Yh@<0/J^M0P11JN400`2aZid0@FWQ0;6[W@040;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd8
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@
0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P11JN40
0`2][Jd0];2a0;B`/@02045Yh@80];2a0P11JN450:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2]
[Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h01@2][Jd0RXEe08Z5
M@2:QGD0[Jf]0080@FWQ1@2TWXl01P11JN40Y9j?0:BNS`2][Jd0/J^M045Yh@<0/J^M0P11JN420;6[
W@80@FWQ0`2aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn
]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh
00X0_[Vh0P11JN401@2][Jd0];2a0;B`/@2d/;40@FWQ0080];2a0P11JN401P2d/;40@FWQ0:f][@2O
Vj00@FWQ0:f][@80^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40
oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd408Z5M@040:f][@11JN40@FWQ
0:f][@@0Y9j?0P11JN40102TWXl0[Jf]0;6[W@11JN430;6[W@80@FWQ0P2aZid2045Yh@<0/J^M00<0
[Jf]045Yh@2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36
`;`30:f][@h0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP2045Yh@070:f][@2d/;40];2a0;B`/@11JN40
];2a0:f][@02045Yh@030;B`/@11JN40[Jf]0080Wi^P00@0@FWQ0:f][@2][Jd0[Jf]1028EPL00`2]
[Jd000000;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd2045Yh@@0
RXEe00@0[Jf]045Yh@11JN40Y9j?0P2][Jd20:BNS`80@FWQ00@0Y9j?0:f][@2aZid0@FWQ0P2aZid2
045Yh@@0/J^M0P11JN420;6[W@040:f][@2i/ZH0@FWQ045Yh@`0^K:V0`2][JdA0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P11JN401`2][Jd0];2a0;B`/@2d/;40@FWQ0:f][@2d
/;400P11JN400`2d/;40@FWQ0:f][@0509nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0000002`
h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`040:f][@2:QGD0@FWQ045Yh@@0
RXEe00<0[Jf]045Yh@11JN400`2TWXl20:f][@060:BNS`11JN40Y9j?0:f][@2aZid0@FWQ0P2aZid2
045Yh@@0/J^M0P11JN420;6[W@030:f][@2i/ZH0@FWQ00<0@FWQ00<0^K:V045Yh@2i/ZH0202i/ZH0
0`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]
0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080@FWQ00D0[Jf]0;B`/@2d/;40[Jf]045Y
h@020;B`/@80@FWQ00<0];2a045Yh@2][Jd01P2OVj001P2][Jd0R5H708QF1`28EPL0[Jf]000003l0
/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd208Z5M@06045Yh@2:QGD0RXEe045Y
h@2:QGD0[Jf]0`11JN40202TWXl0@FWQ0:BNS`2TWXl0[Jf]0:BNS`11JN40[Jf]0P11JN420;6[W@80
@FWQ102aZid2045Yh@80/J^M00@0[Jf]0;VbYP11JN40@FWQ102i/ZH2045Yh@L0^K:V00<0[Jf]0;jg
[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0090;ji^080@FWQ0`2][Jd0102d/;40@FWQ0;B`/@2d/;44
045Yh@030:f][@2OVj00Wi^P00@0Wi^P00H0[Jf]08QF1`28EPL0R5H70:f][@00000o0;3PiP40oooo
001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]0P2:QGD01@11JN40RXEe08Z5M@11JN40RXEe00H0
@FWQ0`2TWXl20:f][@<0@FWQ0P2aZid2045Yh@@0/J^M0P11JN420;6[W@040:f][@2i/ZH0@FWQ045Y
h@D0^K:V0`11JN400`2i/ZH0@FWQ045Yh@020;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg
[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1
_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00T0_[Vh0P11JN40102][Jd0];2a0;B`/@2d/;42045Yh@060;B`/@11JN40@FWQ045Yh@2d/;40[Jf]
1`2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]
0P2:QGD01P11JN40RXEe08Z5M@11JN40RXEe0:f][@D0@FWQ0P2TWXl2045Yh@040:BNS`2][Jd0@FWQ
045Yh@80/J^M0P11JN450;6[W@05045Yh@2aZid0/J^M0:f][@2i/ZH00P11JN450;VbYP03045Yh@2i
/ZH0^K:V00<0^K:V0P11JN400`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][Jd?0<K0_003045Yh@36
`;`0[Jf]0100`kfk00<0[Jf]0;ji^02n^KP0202n^KP0102][Jd0@FWQ045Yh@2][Jd30;B`/@80@FWQ
00<0];2a045Yh@11JN400P2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]00<0R5H70:f][@2`h>H0
?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@80RXEe00D0@FWQ08Z5M@2:QGD0
@FWQ0:f][@030:BNS`03045Yh@2TWXl0@FWQ0080Y9j?00@0@FWQ0:BNS`2TWXl0[Jf]0P11JN40102]
[Jd0/J^M045Yh@11JN450;6[W@05045Yh@2aZid0/J^M0:f][@2i/ZH00P11JN450;VbYP03045Yh@2i
/ZH0^K:V00<0^K:V1011JN4@0;jg[0@0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l00h0a/2l0P11JN400`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd0102n^KP0@FWQ0;ji^02][Jd30;B`/@@0@FWQ
0`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V
0P2][Jd306=PD`040:f][@2:QGD0RXEe045Yh@80RXEe00<0@FWQ0:f][@2TWXl00`2TWXl01@11JN40
Y9j?0:BNS`2TWXl0@FWQ0080Y9j?00D0[Jf]045Yh@2aZid0/J^M0:f][@02045Yh@D0/J^M00D0@FWQ
0;6[W@2aZid0[Jf]0;VbYP02045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@030:f][@2n
]j`0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`02@2n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0
_0070<K0_003045Yh@36`;`0a/2l00@0a/2l0P11JN400`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00<0_[Vh0`2][Jd40;ji^003045Yh@2][Jd0];2a0080];2a0P11JN450;B`/@030:f][@2O
Vj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<2
0:f][@0308Z5M@11JN40RXEe0080@FWQ00<0[Jf]0:BNS`2TWXl01P2TWXl01@11JN40Y9j?0:BNS`2]
[Jd0@FWQ00<0/J^M0P11JN420:f][@<0/J^M00D0@FWQ0;6[W@2aZid0[Jf]0;VbYP02045Yh@D0^K:V
00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@030:f][@2n]j`0_[N/0080_[N/0P11JN400`2n]j`0@FWQ
0;jg[0090;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`0
0P11JN400`36`;`0@FWQ045Yh@050<K0_003045Yh@2][Jd0`kfk00l0`kfk00@0[Jf]0;ji^02n^KP0
_[Vh0P2][Jd70;ji^003045Yh@2][Jd0];2a0080];2a00<0@FWQ0;B`/@2d/;40102d/;400`2][Jd0
Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f]
[@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2][Jd0RXEe0`11JN400`2][Jd0Y9j?0:BNS`070:BNS`04
045Yh@2TWXl0[Jf]045Yh@<0/J^M0P11JN420;6[W@<0[Jf]00D0@FWQ0;6[W@2aZid0[Jf]0;VbYP02
045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@@0_[N/0P11JN430;jg[080@FWQ202n]j`0
0`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/03038`K/6045Yh@80b<6k00<0[Jf]0<S1^`38`K/04038`K/6
0:f][A40al6l00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l045Yh@040<K0_003045Yh@36`;`0
a/2l00@0a/2l00<0[Jf]0<>m^`33_K/03P33_K/0102][Jd0_[Vh0:f][@2][Jd90;ji^003045Yh@2]
[Jd0];2a0080];2a00<0@FWQ0;B`/@2d/;40102d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2O
Vj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0
[Jf]08Z5M@2:QGD0[Jf]0P2:QGD00`11JN40[Jf]0:BNS`090:BNS`80@FWQ102aZid2045Yh@@0/J^M
0P11JN40102][Jd0/J^M0:f][@2i/ZH2045Yh@@0^K:V0P11JN450;VbYP80@FWQ102n]j`00`11JN40
_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`00P11JN4@0<6j/0P0
[Jf]4033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00h0b<6k0P11JN440<S1^`03
0:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00h0al6l00@0@FWQ0<O1_037
`K`0[Jf]1036`;`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`01036`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`<0[Jf]2`2n^KP00`11JN40[Jf]0;B`/@020;B`/@03045Yh@2d/;40];2a00@0];2a00<0[Jf]09nK
X02OVj000P2][Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`080:f][@2:QGD0RXEe08Z5M@2][Jd0RXEe045Yh@2][Jd;0:BNS`030:f][@2a
Zid0/J^M0080/J^M0`11JN430;6[W@80@FWQ00@0/J^M0:f][@2][Jd0[Jf]0P11JN440;VbYP80@FWQ
1@2i/ZH2045Yh@@0_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0020;jg[005045Y
h@2n]j`0@FWQ0:f][@31^[000P11JN4@0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00@0[Jf]0<S1^`38
`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00d0al6l00D0@FWQ0<O1_011JN40@FWQ0:f][@04
0<K0_080@FWQ1P36`;`00`11JN40a/2l0<K0_0030<K0_0030:f][@33_K/0`kfk00X0`kfk0`2][Jd0
0`33_K/0[Jf]0;ji^00;0;ji^003045Yh@2][Jd0];2a0080];2a00<0@FWQ0;B`/@2d/;40102d/;40
0`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2]
[Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd02`2TWXl0102]
[Jd0/J^M0;6[W@2aZid4045Yh@<0/J^M0P11JN420;6[W@050:f][@2i/ZH0@FWQ045Yh@2][Jd00`2i
/ZH2045Yh@D0^K:V0P11JN430;jg[080@FWQ1`2n]j`01011JN40_[N/0;jg[02n]j`2045Yh@030;jg
[02][Jd0`KZ`0080`KZ`00<0@FWQ0<6j/031^[001031^[000`11JN40`KZ`0<6j/0060<6j/0030:f]
[@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00h0b<6k0P11JN480:f][A80b<6k
00<0[Jf]0<O1_037`K`00`37`K`4045Yh@@0al6l0P11JN440<O1_003045Yh@36`;`0a/2l0080a/2l
00<0@FWQ0<K0_036`;`01036`;`2045Yh@D0a/2l00<0[Jf]0<>m^`33_K/01`33_K/30:f][@@0`kfk
00<0[Jf]0;ji^02n^KP02P2n^KP00`11JN40[Jf]0;B`/@020;B`/@03045Yh@2d/;40];2a00@0];2a
0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`030:f][@2aZid0/J^M0080/J^M0`11
JN420;6[W@80@FWQ0`2aZid01@2][Jd0^K:V045Yh@11JN40^K:V00<0[Jf]0P11JN450;VbYP03045Y
h@2][Jd0_[N/0080_[N/0P11JN4;0;jg[004045Yh@2n]j`0_[N/0:f][@@0`KZ`00<0@FWQ0<6j/031
^[000P31^[02045Yh@P0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0
[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^`/0[Jf]0P11JN440<S1^`030:f][@38`K/0b<6k0180
b<6k0`11JN420<O1_0<0@FWQ1P37`K`2045Yh@D0al6l00<0[Jf]045Yh@36`;`00P36`;`00`11JN40
a/2l0<K0_0040<K0_003045Yh@36`;`0a/2l00<0a/2l00<0@FWQ0:f][@33_K/01P33_K/20:f][@L0
`kfk00<0[Jf]0;ji^02n^KP02P2n^KP00`11JN40[Jf]0;B`/@020;B`/@03045Yh@2d/;40];2a00@0
];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0
/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid01@2aZid3045Yh@@0/J^M00@0[Jf]0;VbYP11JN40@FWQ102i/ZH2045Y
h@80[Jf]0`2i/ZH00`11JN40[Jf]0;jg[0020;jg[080@FWQ2`2n]j`00`11JN40_[N/0:f][@050<6j
/003045Yh@31^[00`KZ`0080`KZ`00<0@FWQ0<6j/011JN401`31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX02P37`KXA0:f][@/0b<6k0P11JN440<S1^`030:f][@38`K/0b<6k00h0b<6k1011JN400`38
`K/0[Jf]0<O1_0040<O1_003045Yh@37`K`0al6l00@0al6l00<0@FWQ0<O1_037`K`01037`K`00`2]
[Jd0a/2l0<K0_0080<K0_080@FWQ1@36`;`00`11JN40[Jf]0<>m^`030<>m^`<0[Jf]2@33_K/00`2]
[Jd0_[Vh0;ji^00:0;ji^005045Yh@2][Jd0];2a0;B`/@11JN401@2d/;430:f][@L0Wi^P00D0[Jf]
071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:
QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0102][Jd0^K:V045Yh@11JN440;VbYP80@FWQ
0P2i/ZH30:f][@03045Yh@2][Jd0_[N/0080_[N/0P11JN4=0;jg[0030:f][@31^[00`KZ`00<0`KZ`
00<0@FWQ0<6j/031^[000`31^[000`11JN40`KZ`0<6j/0060<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k
0<S1^`0>0<S1^`80@FWQ1038`K/00`2][Jd0b<6k0<S1^`060<S1^`H0@FWQ1@38`K/00`11JN40b<6k
0:f][@050<O1_003045Yh@37`K`0al6l00<0al6l0P11JN460<O1_0030:f][@36`;`0a/2l00L0a/2l
0P11JN460<K0_003045Yh@2][Jd0`kfk00<0[Jf]3033_K/00`2][Jd0_[Vh0;ji^00:0;ji^005045Y
h@2][Jd0];2a0;B`/@11JN40102d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii
071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]
0:BNS`2TWXl00P2][Jd70:BNS`030:f][@2aZid0/J^M00`0/J^M00D0[Jf]0;VbYP11JN40^K:V045Y
h@030;VbYP80@FWQ1@2i/ZH00`11JN40[Jf]0:f][@020;jg[080@FWQ3@2n]j`00`2][Jd0`KZ`0<6j
/0030<6j/003045Yh@31^[00`KZ`00`0`KZ`00<0[Jf]0<>m/`33_K<03@33_K<4045Yh@80`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ1038`K/00`11JN40b<6k0<S1
^`080<S1^`80@FWQ1`38`K/00`11JN40b<6k0:f][@050<O1_003045Yh@37`K`0al6l00<0al6l0P11
JN460<O1_0030:f][@36`;`0a/2l00D0a/2l0`11JN460<K0_0040:f][@11JN40[Jf]0:f][@l0`kfk
00<0[Jf]0;ji^02n^KP02P2n^KP01011JN40[Jf]0;B`/@11JN430;B`/@80[Jf]0`2d/;400`2][Jd0
Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0
Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@050:f][@2i/ZH0@FWQ0;VbYP11JN400`2i/ZH00`11JN40^K:V0;VbYP04
0;VbYP03045Yh@2][Jd0_[N/0080[Jf]0P11JN4=0;jg[0030:f][@31^[00`KZ`0080`KZ`0P11JN4>
0<6j/0030:f][@33_K<0`kfc00l0`kfc1`11JN4D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00X0b<6k00@0@FWQ
0<S1^`38`K/0b<6k0P11JN420<S1^`80@FWQ00<0[Jf]045Yh@11JN402038`K/2045Yh@L0b<6k00<0
@FWQ0<S1^`2][Jd01@37`K`00`11JN40al6l0<O1_0030<O1_003045Yh@37`K`0al6l00D0al6l00<0
[Jf]0<K0_036`;`01036`;`3045Yh@80a/2l1@2][Jd00`36`;`0@FWQ0:f][@0@0<>m^`030:f][@2n
^KP0_[Vh00X0_[Vh00D0@FWQ0:f][@2d/;40@FWQ0;B`/@020:f][@D0];2a00<0[Jf]09nKX02OVj00
1@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0
RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0
^K:V045Yh@020;VbYP04045Yh@2i/ZH0^K:V045Yh@H0^K:V00<0@FWQ0:f][@2n]j`00`2n]j`00`11
JN40[Jf]0:f][@020:f][@T0_[N/00<0[Jf]0<6j/031^[000`11JN4?0<6j/0030:f][@33_K<0`kfc
00l0`kfc0P11JN420<>m/`030:f][@35_[D0aKje0080@FWQ1@35_[D7045Yh@H0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00?0<O1^00300000037`KP0al6h0080al6h00<0[Jf]0<O1
^P37`KX05@37`KX0102][Jd0b<6k0<S1^`38`K/4045Yh@@0b<6k00<0@FWQ0<S1^`38`K/00P38`K/2
045Yh@060<S1^`11JN40b<6k0<S1^`2][Jd0b<6k0P11JN470<S1^`80@FWQ1`38`K/00`11JN40b<6k
0:f][@050<O1_003045Yh@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01@37`K`00`2][Jd0a/2l
0<K0_0030<K0_080@FWQ102][Jd00`36`;`0@FWQ0<K0_0030<K0_003045Yh@2][Jd0`kfk00l0`kfk
00<0[Jf]0;ji^02n^KP02P2n^KP3045Yh@030;B`/@2][Jd0];2a00H0];2a00<0[Jf]09nKX02OVj00
1@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe
00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid02`2aZid0102][Jd0^K:V
0;VbYP11JN430;VbYP80@FWQ1`2i/ZH00`11JN40[Jf]0;jg[0030;jg[003045Yh@2n]j`0_[N/0080
_[N/0P2][Jd00`11JN40[Jf]0;jg[0040;jg[0D0@FWQ4031^[000`2][Jd0`kfc0<>m/`0?0<>m/`80
@FWQ0P33_K<0102][Jd0aKje0<Fn]@35_[D2045Yh@L0aKje0P11JN480<Fn]@030:f][@36_kL0a[ng
00<0a[ng1011JN450<Jo]`80@FWQ1`36_kL00`2][Jd0al6h0<O1^00C0<O1^004045Yh@2][Jd0al6j
0<O1^P80@FWQ1037`KX7045Yh@P0al6j00<0[Jf]0<S1^`11JN400P11JN430<S1^`80@FWQ00<0b<6k
045Yh@11JN401038`K/3045Yh@<0b<6k00<0[Jf]0<S1^`38`K/00P11JN460<S1^`80@FWQ1`38`K/0
0`11JN40b<6k0:f][@050<O1_003045Yh@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01@37`K`0
0`2][Jd0a/2l0<K0_0030:f][@03045Yh@2][Jd0a/2l00@0a/2l00<0@FWQ0<K0_036`;`00P36`;`0
0`11JN40[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00T0_[Vh0P11JN430:f][@P0];2a00<0[Jf]
09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]
00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@d0/J^M00@0[Jf]0;VbYP2i/ZH0@FWQ302i/ZH0
0`11JN40[Jf]0;jg[0030;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11JN400`2n]j`0[Jf]0:f][@02
0:f][@@0@FWQ2@31^[000`11JN40`KZ`0<6j/0060<6j/0030:f][@33_K<0`kfc00l0`kfc0P11JN42
0<>m/`040:f][@35_[D0aKje0<Fn]@80@FWQ1`35_[D2045Yh@P0aKje00@0[Jf]0<Jo]`36_kL0a[ng
0`11JN430<Jo]`80@FWQ00<0a[ng045Yh@11JN402036_kL00`11JN40[Jf]0<O1^0040<O1^003045Y
h@37`KP0al6h00/0al6h0P11JN401037`KP0@FWQ045Yh@37`KX2045Yh@L0al6j00<0@FWQ0<O1^P37
`KX02@37`KX0102][Jd0b<6k045Yh@11JN450<S1^`<0@FWQ1@38`K/2045Yh@@0b<6k00<0[Jf]0<S1
^`38`K/00P11JN460<S1^`80@FWQ1`38`K/00`11JN40b<6k0:f][@050<O1_003045Yh@37`K`0al6l
00<0al6l00<0@FWQ0<O1_037`K`00`37`K`20:f][@03045Yh@2][Jd0[Jf]00<0a/2l00<0@FWQ0<K0
_036`;`00`36`;`2045Yh@@0a/2l00<0@FWQ0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^00:0;ji
^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0
/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@040:f][@2i/ZH0^K:V045Y
h@X0^K:V0`11JN400`2][Jd0_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg
[02n]j`00P2n]j`2045Yh@@0[Jf]2031^[000`11JN40`KZ`0<6j/0060<6j/0030:f][@33_K<0`kfc
00l0`kfc0P11JN420<>m/`030:f][@35_[D0aKje0080aKje0P11JN460<Fn]@80@FWQ2035_[D00`2]
[Jd0a[ng0<Jo]`02045Yh@H0a[ng00@0@FWQ0<Jo]`11JN40@FWQ2036_kL00`11JN40[Jf]0<O1^004
0<O1^003045Yh@37`KP0al6h00T0al6h0`11JN420<O1^0030:f][@37`KX0@FWQ0080@FWQ1`37`KX0
0`11JN40al6j0<O1^P090<O1^P030:f][@11JN40@FWQ00L0b<6k0P11JN450<S1^`80@FWQ1038`K/0
0`2][Jd0b<6k0<S1^`02045Yh@H0b<6k0P11JN470<S1^`80@FWQ00<0[Jf]0<O1_037`K`00`37`K`2
045Yh@@0al6l00<0@FWQ0:f][@2][Jd00`2][Jd01037`K`0@FWQ0:f][@11JN440<K0_003045Yh@36
`;`0a/2l00<0a/2l0P11JN430<K0_080@FWQ00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`
h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@02
0:f][@T0/J^M00@0[Jf]0;VbYP2i/ZH0@FWQ3@2i/ZH00`2][Jd0_[N/0;jg[0030;jg[003045Yh@2n
]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`00`2n]j`00`11JN40_[N/0:f][@030<6j/0L0[Jf]00<0
`KZ`045Yh@31^[001`31^[000`2][Jd0`kfc0<>m/`0?0<>m/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn
]@020<Fn]@80@FWQ1P35_[D2045Yh@P0aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ2@36
_kL00`11JN40[Jf]0<O1^0030<O1^080@FWQ2P37`KP2045Yh@@0al6h00<0[Jf]0<O1^P11JN400P11
JN470<O1^P03045Yh@37`KX0al6j00T0al6j00<0[Jf]045Yh@11JN401`38`K/2045Yh@H0b<6k00<0
@FWQ0<S1^`38`K/00P38`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@D0b<6k0P11JN470<S1^`80@FWQ
00<0[Jf]0<O1_037`K`00`37`K`2045Yh@@0[Jf]00<0@FWQ0<O1_037`K`01@37`K`2045Yh@@0a/2l
00<0@FWQ0<K0_036`;`00`36`;`2045Yh@<0a/2l0P11JN400`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00
102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BN
S`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@040:f][@2i/ZH0^K:V045Yh@d0^K:V
00<0[Jf]0;jg[02n]j`0102n]j`01@11JN40_[N/0;jg[02n]j`0@FWQ00D0_[N/00<0@FWQ0;jg[02]
[Jd01@31^[000`11JN40`KZ`0<6j/0020<6j/0030:f][@11JN40[Jf]00@0[Jf]0`31^[000`2][Jd0
`kfc0<>m/`0?0<>m/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn]@030<Fn]@03045Yh@35_[D0aKje00@0
aKje0P11JN480<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@P0a[ng0`11JN440<O1^0<0
@FWQ2037`KP2045Yh@H0al6h00@0[Jf]0<O1^P11JN40@FWQ1`37`KX00`11JN40al6j0<O1^P090<O1
^P030:f][@11JN40@FWQ00L0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k0080b<6k00@0[Jf]0<S1
^`38`K/0b<6k0P11JN450<S1^`80@FWQ1`38`K/2045Yh@030:f][@000000al6l00<0[Jf]0P11JN44
0<O1_080@FWQ1P37`K`00`11JN40a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l0080a/2l00<0@FWQ
0<K0_011JN400`36`;`2045Yh@030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP3
0:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0
/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@040:f][@2i/ZH0^K:V045Yh@d0^K:V00<0[Jf]
0;jg[02n]j`01@2n]j`3045Yh@H0_[N/00<0@FWQ0;jg[02][Jd01031^[02045Yh@D0`KZ`00<0@FWQ
0<6j/031^[000`31^[070:f][@h0`kfc0P11JN420<>m/`030:f][@35_[D0aKje00<0aKje00<0@FWQ
0<Fn]@35_[D01035_[D2045Yh@P0aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ2036_kL3
045Yh@@0al6h0`11JN480<O1^003045Yh@37`KP0al6h00D0al6h00@0[Jf]0<O1^P11JN40@FWQ1`37
`KX00`11JN40al6j0<O1^P090<O1^P030:f][@11JN40@FWQ00L0b<6k0P11JN460<S1^`03045Yh@38
`K/0b<6k0080b<6k00@0[Jf]0<S1^`38`K/0b<6k0P11JN450<S1^`80@FWQ1P38`K/00`2][Jd0@FWQ
045Yh@030:f][@<0al6l0P11JN440<O1_080@FWQ1P37`K`00`11JN40a/2l0<K0_0040<K0_0@0@FWQ
1P36`;`3045Yh@030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^003
0:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40
oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@070;6[W@<0[Jf]00D0/J^M0:f][@11JN40^K:V045Yh@0=0;VbYP030:f][@2n]j`0_[N/00l0
_[N/00<0@FWQ0:f][@31^[000`31^[02045Yh@D0`KZ`00<0@FWQ0<6j/031^[001P31^[00102][Jd0
`kfc0<>m/`33_K<70:f][@L0`kfc0P11JN420<>m/`030:f][@35_[D0aKje00<0aKje0P11JN450<Fn
]@80@FWQ2035_[D00`2][Jd0a[ng0<Jo]`02045Yh@L0a[ng0P11JN480<Jo]`<0@FWQ1037`KP00`11
JN40al6h045Yh@080<O1^003045Yh@37`KP0al6h00D0al6h00@0[Jf]0<O1^P11JN40@FWQ1`37`KX0
0`11JN40al6j0<O1^P090<O1^P030:f][@11JN40@FWQ00L0b<6k0P11JN460<S1^`03045Yh@38`K/0
b<6k0080b<6k00@0[Jf]0<S1^`38`K/0b<6k0P11JN450<S1^`80@FWQ1P2][Jd01038`K/0@FWQ045Y
h@2][Jd50<O1_080@FWQ1@37`K`2045Yh@@0al6l00<0@FWQ0:f][@36`;`03`36`;`3045Yh@030:f]
[@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@03
0:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe
08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@80@FWQ
3@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[080@FWQ0P31^[03045Yh@D0`KZ`00<0@FWQ0<6j/031^[00
1P31^[000`2][Jd0`kfc0<>m/`080<>m/`L0[Jf]0P11JN420<>m/`030:f][@35_[D0aKje00<0aKje
0P11JN450<Fn]@03045Yh@35_[D0aKje00L0aKje00@0[Jf]0<Jo]`36_kL0a[ng0P11JN460<Jo]`80
@FWQ2036_kL00`11JN40a[ng045Yh@030<O1^080@FWQ00<0al6h045Yh@37`KP01`37`KP00`11JN40
al6h0<O1^0050<O1^0040:f][@37`KX0@FWQ045Yh@L0al6j00<0@FWQ0<O1^P37`KX02@37`KX0102]
[Jd0b<6k045Yh@11JN460<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`020<S1^`040:f][@38`K/0
b<6k0<S1^`80@FWQ1@2][Jd2045Yh@L0b<6k0P11JN400`2][Jd0al6l0<O1_0030<O1_080@FWQ1P37
`K`2045Yh@80al6l00<0@FWQ0<O1_02][Jd04036`;`3045Yh@030:f][@33_K/0`kfk00`0`kfk0`2]
[Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N
0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]
0;VbYP2][Jd00`2][Jd:0;VbYP03045Yh@2][Jd0_[N/0140_[N/00@0[Jf]0<6j/011JN40@FWQ0P31
^[000`11JN40`KZ`0<6j/0020<6j/080@FWQ2031^[000`2][Jd0`kfc0<>m/`0?0<>m/`80@FWQ202]
[Jd2045Yh@D0aKje00<0@FWQ0<Fn]@35_[D01`35_[D0102][Jd0a[ng0<Jo]`36_kL2045Yh@H0a[ng
0P11JN480<Jo]`03045Yh@36_kL0@FWQ00<0al6h0P11JN400`37`KP0@FWQ0<O1^0060<O1^080@FWQ
1`37`KP0102][Jd0al6j045Yh@11JN470<O1^P03045Yh@37`KX0al6j00T0al6j00@0[Jf]0<S1^`00
0000b<6k0`11JN430<S1^`80@FWQ1P38`K/00`11JN40[Jf]0:f][@050:f][@80@FWQ1P38`K/2045Y
h@L0b<6k0P11JN400`2][Jd0al6l0<O1_0030<O1_080@FWQ1`37`K`3045Yh@80al6l00<0[Jf]0<K0
_036`;`03P36`;`3045Yh@030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji
^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0
RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@H0
^K:V0P11JN400`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN480<6j/003
0:f][@33_K<0`kfc00l0`kfc0P11JN420<>m/`030:f][@35_[D0aKje00<0aKje0P11JN450:f][@03
045Yh@2][Jd0[Jf]0080[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`030<Jo]`@0@FWQ0P36_kL2045Yh@L0
a[ng0P11JN400`36_kL0[Jf]045Yh@020<O1^080@FWQ0P37`KP00`11JN40al6h0<O1^0040<O1^080
@FWQ1`37`KP7045Yh@@0al6j00<0@FWQ0<O1^P37`KX02@37`KX00`2][Jd0b<6k0<S1^`030<S1^`03
0:f][@11JN40@FWQ00<0@FWQ1P2][Jd00`11JN40b<6k0<S1^`020<S1^`030:f][@38`K/0b<6k0080
@FWQ1`38`K/2045Yh@D0b<6k0P11JN400`38`K/0[Jf]0<O1_0040<O1_080@FWQ3@37`K`00`2][Jd0
a/2l0<K0_00=0<K0_004045Yh@36`;`0@FWQ0:f][@P0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh
00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3oool00640/>3V0P2][Jd:0:BNS`03
0:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@<0^K:V0P11JN400`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN480<6j/0030:f][@33_K<0`kfc00l0
`kfc0P11JN420<>m/`030:f][@35_[D0aKje00<0aKje0P11JN450<Fn]@80@FWQ0`35_[D?0:f][@@0
@FWQ1`36_kL2045Yh@030<Jo]`2][Jd0@FWQ0080al6h00D0@FWQ0<O1^037`KP0al6h045Yh@060<O1
^080@FWQ1`37`KP00`2][Jd0al6j0<O1^P080<O1^P03045Yh@2][Jd0[Jf]00l0[Jf]1038`K/2045Y
h@H0b<6k00<0@FWQ0<S1^`38`K/00P38`K/0102][Jd0b<6k0<S1^`11JN480<S1^`80@FWQ1@38`K/2
045Yh@030<S1^`2][Jd0al6l0080al6l0`11JN4>0<O1_0030:f][@36`;`0a/2l00d0a/2l0P11JN40
0`36`;`0[Jf]0<>m^`030<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40
];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BN
S`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@03045Yh@2][Jd0_[N/
0140_[N/00<0[Jf]0<6j/031^[002031^[02045Yh@P0`KZ`00<0[Jf]0<>m/`33_K<03`33_K<2045Y
h@80`kfc00<0[Jf]0<Fn]@35_[D00`35_[D2045Yh@D0aKje0P11JN480<Fn]@030:f][@36_kL0a[ng
00T0a[ng0P11JN470:f][@80@FWQ0P2][Jd01011JN40[Jf]045Yh@11JN430:f][@03045Yh@2][Jd0
[Jf]00@0[Jf]0P11JN4B0:f][@80@FWQ2P37`KX00`2][Jd0b<6k0<S1^`070<S1^`03045Yh@38`K/0
b<6k00D0b<6k0P11JN430<S1^`040:f][@38`K/0@FWQ045Yh@P0b<6k2011JN420<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03P36`;`01011JN40a/2l0:f][@33_K/30:f][@/0`kfk
00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`
h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n
]j`00`2][Jd0`KZ`0<6j/0080<6j/080@FWQ2031^[000`2][Jd0`kfc0<>m/`0?0<>m/`80@FWQ0P33
_K<00`2][Jd0aKje0<Fn]@030<Fn]@80@FWQ1@35_[D00`11JN40aKje045Yh@040<Fn]@04045Yh@35
_[D0aKje0:f][@<0a[ng0P11JN460<Jo]`80@FWQ1`36_kL2045Yh@040<Jo]`2][Jd0@FWQ0<O1^080
@FWQ0`37`KP00`11JN40al6h0<O1^0040<O1^080@FWQ1`37`KP00`2][Jd0al6j0<O1^P080<O1^P80
@FWQ1@37`KX00`11JN40al6j0<O1^P020<O1^P040:f][@38`K/0@FWQ045Yh@H0b<6k00<0@FWQ0<S1
^`38`K/01@38`K/00`11JN40b<6k045Yh@020<S1^`030:f][@38`K/0@FWQ00T0b<6k0P11JN480<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03P36`;`40:f][@h0`kfk00<0[Jf]0;ji
^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0/>3V0@3oool006D0
/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[002031^[02045Yh@P0`KZ`00<0[Jf]0<>m/`33
_K<03`33_K<2045Yh@80`kfc00<0[Jf]0<Fn]@35_[D00`35_[D2045Yh@D0aKje00<0@FWQ0<Fn]@11
JN400`35_[D01@11JN40aKje045Yh@35_[D0[Jf]00<0a[ng0P11JN460<Jo]`03045Yh@36_kL0a[ng
00H0a[ng00H0@FWQ0<Jo]`36_kL0[Jf]045Yh@37`KP2045Yh@<0al6h00<0@FWQ0<O1^037`KP01037
`KP2045Yh@L0al6h00<0[Jf]0<O1^P37`KX02037`KX00`11JN40al6j045Yh@030<O1^P03045Yh@37
`KX0@FWQ00<0al6j00@0[Jf]0<S1^`11JN40@FWQ1P38`K/00`11JN40b<6k0<S1^`050<S1^`03045Y
h@38`K/0b<6k00@0@FWQ2P38`K/2045Yh@P0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh
00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2a
Zid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n
]j`00`2][Jd0`KZ`0<6j/0080<6j/080@FWQ2031^[000`2][Jd0`kfc0<>m/`0?0<>m/`80@FWQ0P33
_K<00`2][Jd0aKje0<Fn]@030<Fn]@80@FWQ0P35_[D2045Yh@050<Fn]@11JN40aKje0<Fn]@11JN40
0`35_[D2045Yh@030<Fn]@2][Jd0a[ng0080a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40a[ng
0<Jo]`050<Jo]`80@FWQ0P36_kL0102][Jd0al6h045Yh@11JN450<O1^003045Yh@37`KP0al6h00<0
al6h0P11JN420<O1^00300000037`KP0al6h0080al6h00<0[Jf]0<O1^P37`KX02037`KX00`11JN40
al6j045Yh@040<O1^P80@FWQ0`37`KX0102][Jd0b<6k0<S1^`11JN450<S1^`03045Yh@38`K/0b<6k
00<0b<6k1011JN440<S1^`030:f][@38`K/0b<6k00T0b<6k0P11JN480<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2]
[Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f]
[@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN480<6j/0030:f][@33_K<0`kfc
00l0`kfc0P11JN420<>m/`030:f][@35_[D0aKje0080aKje0P11JN450<Fn]@80@FWQ0`35_[D4045Y
h@80aKje00<0[Jf]0<Jo]`36_kL00P36_kL00`11JN40a[ng0<Jo]`040<Jo]`03045Yh@36_kL0a[ng
00D0a[ng0P11JN420<Jo]`040:f][@37`KP0@FWQ045Yh@D0al6h00<0@FWQ0<O1^037`KP00`37`KP2
045Yh@L0al6h00<0[Jf]0<O1^P37`KX02037`KX01011JN40al6j0<O1^P11JN430<O1^P03045Yh@37
`KX0al6j0080al6j00@0[Jf]0<S1^`38`K/0b<6k1@11JN4>0<S1^`030:f][@38`K/0b<6k00T0b<6k
0P11JN480<S1^`030:f][@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`03037`K`00`2][Jd0a/2l
0<K0_0050:f][@/0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f]
[@2d/;40];2a0:f][E80/>3V0@3oool006/0/>3V0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`00T0`KZ`00<0@FWQ0<6j/031^[00
1`31^[000`2][Jd0`kfc0<>m/`0?0<>m/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn]@020<Fn]@80@FWQ
4035_[D00`2][Jd0a[ng0<Jo]`030<Jo]`H0@FWQ1@36_kL7045Yh@040:f][@37`KP0@FWQ045Yh@<0
al6h1P11JN420<O1^080@FWQ1`37`KP00`2][Jd0al6j0<O1^P050<O1^P@0@FWQ0`37`KX4045Yh@@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ2038`K/00`2][Jd0
al6l0<O1_0020<O1_003045Yh@37`K`0@FWQ00/0al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`50:f][@L0`KZ`00<0@FWQ0<6j/031^[00
1`31^[000`2][Jd0`kfc0<>m/`0?0<>m/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn]@020<Fn]@80@FWQ
4035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00`0al6h0P11JN470<O1^0040:f]
[@37`KX0al6j045Yh@P0al6j00<000000<O1^P37`KX02037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k00T0b<6k0P11JN480<S1^`030:f][@37`K`0al6l0080al6l0P11JN470<O1_0D0
[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]0<>m/`33
_K<03`33_K<2045Yh@80`kfc00<0[Jf]0<Fn]@35_[D00P35_[D00`11JN40aKje0<Fn]@0?0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03@37`KP00`11JN40al6h0<O1^0050<O1^004
0:f][@37`KX0al6j045YhA<0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1
^`80@FWQ2038`K/00`2][Jd0al6l0<O1_0030<O1_003045Yh@37`K`0[Jf]00D0[Jf]1`37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f]
[EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0?0<>m/`80
@FWQ0P33_K<00`2][Jd0aKje0<Fn]@020<Fn]@03045Yh@35_[D0aKje00l0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00=0<O1^003045Yh@37`KP0al6h00D0al6h00@0[Jf]0<O1^P11
JN40@FWQ4`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k0P11JN480<S1
^`030:f][@37`K`0al6l00D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0
[Jf]3P33_K<2045Yh@80`kfc00D0[Jf]0<Fn]@35_[D0aKje045Yh@0B0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP03@37`KP00`11JN40al6h0<O1^0050<O1^0040:f][@37`KX0@FWQ
045YhA<0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`060<S1^`D0@FWQ1@38`K/6
0:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<7
0:f][@@0`kfc1@11JN420<>m/`030:f][@35_[D0aKje0080@FWQ4P35_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h00d0al6h0P11JN460<O1^0040:f][@37`KX0@FWQ045YhA<0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f]
[@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]1P11JN4D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03P37`KP2045Yh@D0al6h00@0[Jf]
045Yh@11JN40@FWQ4`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]
2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN440<O1^080@FWQ00<0al6j045Yh@37`KX04P37
`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP04@37`KP4045Yh@040:f][@37`KX0al6j045YhA<0al6j00<0[Jf]0<S1^`38`K/00`38
`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd8
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0
/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40
oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`
h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd7
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2]
[Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo
002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H1
0?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00
g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54743 .33064 m
.54577 .33388 L
s
.5491 .33381 m
.54743 .33064 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57906 .33919 m
.57909 .34238 L
s
.255 .412 .882 r
.52154 .33862 m
.5232 .33862 L
s
.51823 .34086 m
.52154 .33862 L
s
.51988 .34087 m
.52154 .33862 L
s
.50995 .33855 m
.51326 .34083 L
s
.50499 .33848 m
.50995 .33855 L
s
.50168 .34068 m
.50499 .33848 L
s
.50002 .34065 m
.50499 .33848 L
s
0 0 0 r
.57836 .33966 m
.57909 .34238 L
s
.255 .412 .882 r
.51823 .34537 m
.51988 .34087 L
s
.51657 .34536 m
.51823 .34086 L
s
.51326 .34083 m
.51657 .34536 L
s
0 0 0 r
.56499 .3486 m
.56584 .3494 L
s
.255 .412 .882 r
.50001 .34516 m
.50168 .34068 L
s
.49835 .34512 m
.50002 .34065 L
s
0 0 0 r
.56297 .34994 m
.56586 .35262 L
s
.255 .412 .882 r
.5 .34967 m
.50001 .34516 L
s
.49834 .34964 m
.49835 .34512 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46546 .33718 m
.47694 .3377 L
s
0 0 0 r
.60202 .32812 m
.59714 .33168 L
s
.255 .412 .882 r
.5 .34967 m
.50164 .35422 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59627 .33348 m
.59714 .33168 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49834 .34964 m
.49998 .35419 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47182 .36919 m
.47202 .3375 L
s
.47017 .36912 m
.47038 .33742 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57602 .33963 m
.58092 .33713 L
s
.57277 .3443 m
.57602 .33963 L
s
.50164 .35422 m
.50495 .35654 L
s
.57766 .33955 m
.58092 .33713 L
s
.58092 .33713 m
.58419 .33696 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5381 .33851 m
.5448 .37007 L
s
.53151 .37023 m
.5381 .33851 L
s
0 0 0 r
.54593 .39206 m
.54607 .3886 L
s
.54914 .38859 m
.54929 .392 L
s
.255 .412 .882 r
.51822 .36119 m
.51823 .34537 L
s
.51655 .36571 m
.51657 .34536 L
s
.53317 .37022 m
.53811 .34528 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5448 .37007 m
.55132 .33826 L
s
.54646 .37003 m
.55134 .34503 L
s
.55132 .33826 m
.55806 .36975 L
s
.57441 .34422 m
.57766 .33955 L
s
.49998 .35419 m
.50495 .35654 L
s
.5149 .35891 m
.50495 .35654 L
s
.57115 .34889 m
.57277 .3443 L
s
.58419 .33696 m
.5891 .33894 L
s
.5149 .35891 m
.51656 .36118 L
s
.5728 .34882 m
.57441 .34422 L
s
.51655 .36571 m
.51822 .36119 L
s
.56955 .35574 m
.57115 .34889 L
s
.57119 .35568 m
.5728 .34882 L
s
0 0 0 r
.5476 .3886 m
.54761 .39203 L
s
.255 .412 .882 r
.5891 .33894 m
.5924 .34327 L
s
.59234 .33649 m
.5925 .3546 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49996 .36325 m
.50162 .36328 L
s
.50161 .36555 m
.50162 .36328 L
s
.51489 .36797 m
.51655 .36571 L
s
.59397 .33639 m
.59413 .3545 L
s
.49995 .36552 m
.49996 .36325 L
s
.44754 .33613 m
.45239 .33871 L
s
.45239 .33871 m
.45561 .34343 L
s
.51156 .37022 m
.51489 .36797 L
s
.56955 .35574 m
.56961 .36708 L
s
.49995 .36552 m
.5016 .36781 L
s
.44754 .33613 m
.45076 .3386 L
s
.45076 .3386 m
.45398 .34333 L
s
.43139 .33493 m
.44754 .33613 L
s
.57119 .35568 m
.57126 .36702 L
s
.45561 .34343 m
.4572 .34805 L
s
.52652 .37026 m
.53816 .37017 L
s
.5016 .36781 m
.50492 .37014 L
s
.47191 .35558 m
.47351 .36245 L
s
.45398 .34333 m
.45557 .34795 L
s
.50492 .37014 m
.51156 .37022 L
s
.4834 .36509 m
.48506 .36287 L
s
.48506 .36287 m
.4867 .36519 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48669 .36746 m
.4867 .36519 L
s
.4572 .34805 m
.45878 .35493 L
s
0 0 0 r
.57763 .37156 m
.579 .36878 L
s
.255 .412 .882 r
.4834 .36509 m
.48504 .36741 L
s
0 0 0 r
.56949 .37514 m
.57432 .37495 L
s
.255 .412 .882 r
.45557 .34795 m
.45715 .35484 L
s
.48503 .36968 m
.48669 .36746 L
s
.55309 .36989 m
.56302 .36959 L
s
0 0 0 r
.57432 .37495 m
.57763 .37156 L
s
.255 .412 .882 r
.47351 .36245 m
.47678 .36712 L
s
.48007 .36951 m
.48503 .36968 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43733 .38321 m
.43783 .33544 L
s
.4587 .36629 m
.45878 .35493 L
s
.43571 .3831 m
.43622 .33531 L
s
.47678 .36712 m
.48007 .36951 L
s
.45706 .3662 m
.45715 .35484 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57126 .36702 m
.57295 .37377 L
s
.56961 .36708 m
.5713 .37384 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60854 .33536 m
.60887 .36715 L
s
.5876 .35488 m
.59901 .35418 L
s
.60369 .33572 m
.61497 .33485 L
s
.46524 .3689 m
.47182 .36919 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5713 .37384 m
.57298 .37832 L
s
.57295 .37377 m
.57463 .37825 L
s
.457 .37303 m
.4587 .36629 L
s
.45537 .37294 m
.45706 .3662 L
s
.57298 .37832 m
.5763 .38274 L
s
.57463 .37825 m
.57795 .38267 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45533 .37749 m
.457 .37303 L
s
.61034 .35338 m
.61203 .36008 L
s
.45369 .3774 m
.45537 .37294 L
s
.5763 .38274 m
.58126 .3848 L
s
.59426 .37041 m
.59438 .3841 L
s
.59269 .37734 m
.59426 .37041 L
s
.57795 .38267 m
.58126 .3848 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45202 .38187 m
.45533 .37749 L
s
.58126 .3848 m
.58455 .38464 L
s
0 0 0 r
.61622 .37243 m
.61719 .37236 L
s
.255 .412 .882 r
.45038 .38178 m
.45369 .3774 L
s
.58945 .38209 m
.59269 .37734 L
s
.59269 .37734 m
.59438 .3841 L
s
.58455 .38464 m
.58945 .38209 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4471 .38386 m
.45202 .38187 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61203 .36008 m
.6153 .36438 L
s
.60401 .3675 m
.61049 .36703 L
s
.61015 .33524 m
.61049 .36703 L
s
.4471 .38386 m
.45038 .38178 L
s
.63727 .33502 m
.64196 .33224 L
s
.63576 .33973 m
.63727 .33502 L
s
.6153 .36438 m
.61855 .3664 L
s
.63885 .33485 m
.64196 .33224 L
s
.63734 .33956 m
.63885 .33485 L
s
.63576 .33973 m
.63582 .34428 L
s
.64196 .33224 m
.64665 .33171 L
s
.43086 .38274 m
.4471 .38386 L
s
.63734 .33956 m
.6374 .34411 L
s
.6217 .36157 m
.62328 .35915 L
s
.62328 .35915 m
.62491 .36129 L
s
.6217 .36157 m
.62333 .36371 L
s
.63582 .34428 m
.63746 .34867 L
s
.61855 .3664 m
.62336 .36599 L
s
.6374 .34411 m
.63904 .3485 L
s
.62491 .36129 m
.62493 .36357 L
s
.64665 .33171 m
.64981 .33362 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62336 .36599 m
.62493 .36357 L
s
.63746 .34867 m
.64222 .35045 L
s
.63904 .3485 m
.64222 .35045 L
s
.66186 .31386 m
.67251 .31235 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64981 .33362 m
.65299 .3378 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64222 .35045 m
.65165 .35168 L
s
.63759 .35779 m
.63763 .36008 L
s
.63759 .35779 m
.63917 .35763 L
s
.65446 .33305 m
.65752 .33039 L
s
.65299 .3378 m
.65446 .33305 L
s
.63917 .35763 m
.63921 .35992 L
s
.63763 .36008 m
.63924 .3622 L
s
.65299 .3378 m
.65332 .35837 L
s
.65601 .33286 m
.65752 .33039 L
s
.65454 .33761 m
.65601 .33286 L
s
.65752 .33039 m
.65906 .33019 L
s
.65454 .33761 m
.6548 .3536 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63924 .3622 m
.64243 .36417 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64243 .36417 m
.64871 .36348 L
s
.65165 .35168 m
.65324 .35379 L
s
.3789 .33377 m
.38047 .3317 L
s
.37898 .32921 m
.38047 .3317 L
s
.37742 .33128 m
.37898 .32921 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65332 .35837 m
.6548 .3536 L
s
.64871 .36348 m
.65179 .36084 L
s
.37742 .33128 m
.3789 .33377 L
s
.65179 .36084 m
.65332 .35837 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66796 .31301 m
.66883 .36103 L
s
.66644 .31323 m
.66729 .36123 L
s
.66837 .33581 m
.67133 .33081 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67133 .33081 m
.67432 .32808 L
s
.67432 .32808 m
.67733 .32764 L
s
.3787 .34521 m
.37975 .37298 L
s
.37668 .37259 m
.3787 .34521 L
s
.67733 .32764 m
.68038 .32947 L
s
.67733 .32764 m
.68188 .32924 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66269 .36182 m
.66883 .36103 L
s
.36532 .32952 m
.36678 .33203 L
s
.36665 .33891 m
.36678 .33203 L
s
.36238 .32676 m
.36532 .32952 L
s
.68038 .32947 m
.68346 .33358 L
s
.6687 .35413 m
.67184 .35832 L
s
.35643 .3258 m
.36238 .32676 L
s
.68188 .32924 m
.68495 .33335 L
s
.37821 .37278 m
.37846 .35897 L
s
.36514 .33868 m
.36669 .33661 L
s
.3651 .34097 m
.36665 .33891 L
s
.3621 .34052 m
.36514 .33868 L
s
.68346 .33358 m
.68509 .34024 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67184 .35832 m
.67492 .3602 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36206 .34281 m
.3651 .34097 L
s
.37813 .3774 m
.37975 .37298 L
s
.35343 .32761 m
.35643 .3258 L
s
.35458 .34394 m
.3621 .34052 L
s
.36483 .35477 m
.36643 .35039 L
s
.36625 .3596 m
.36643 .35039 L
s
.35453 .34624 m
.36206 .34281 L
s
.67492 .3602 m
.67795 .35977 L
s
.37668 .37259 m
.37813 .3774 L
s
.68509 .34024 m
.68518 .34483 L
s
.35192 .32965 m
.35343 .32761 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68495 .33335 m
.68658 .34 L
s
.68658 .34 m
.68667 .3446 L
s
.67795 .35977 m
.68092 .35703 L
s
.67795 .35977 m
.68242 .3568 L
s
.68383 .35197 m
.68518 .34483 L
s
.36329 .35685 m
.36483 .35477 L
s
.36483 .35477 m
.36625 .3596 L
s
.35055 .32481 m
.35192 .32965 L
s
.35035 .334 m
.35055 .32481 L
s
.69515 .32476 m
.70531 .32293 L
s
.68532 .35174 m
.68667 .3446 L
s
.68092 .35703 m
.68383 .35197 L
s
.35035 .334 m
.35192 .32965 L
s
.36024 .35871 m
.36329 .35685 L
s
.68242 .3568 m
.68532 .35174 L
s
.35158 .34576 m
.35458 .34394 L
s
.35429 .35778 m
.36024 .35871 L
s
.35153 .34807 m
.35453 .34624 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35006 .34782 m
.35158 .34576 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35001 .35013 m
.35153 .34807 L
s
.34996 .35244 m
.35006 .34782 L
s
.35138 .35499 m
.35429 .35778 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34996 .35244 m
.35138 .35499 L
s
.33746 .32474 m
.34023 .32989 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33324 .32161 m
.33746 .32474 L
s
.71103 .32183 m
.72089 .31983 L
s
.33041 .32105 m
.33324 .32161 L
s
.70153 .34908 m
.70454 .3532 L
s
.33981 .34837 m
.33986 .34605 L
s
.33848 .34348 m
.33986 .34605 L
s
.32754 .32278 m
.33041 .32105 L
s
.32614 .32249 m
.33041 .32105 L
s
.71528 .32099 m
.71588 .34644 L
s
.33699 .34553 m
.33848 .34348 L
s
.33683 .35248 m
.33981 .34837 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32073 .312 m
.32075 .31132 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71669 .3207 m
.71729 .34616 L
s
.70454 .3532 m
.70892 .35475 L
s
0 0 0 r
.72719 .31232 m
.72912 .31034 L
s
.255 .412 .882 r
.33699 .34553 m
.33837 .34811 L
s
.32463 .32683 m
.32754 .32278 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69618 .37324 m
.70204 .37227 L
s
.70098 .32372 m
.70204 .37227 L
s
.69953 .32399 m
.70058 .37252 L
s
.32323 .32654 m
.32614 .32249 L
s
.33391 .35427 m
.33683 .35248 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70892 .35475 m
.71178 .35422 L
s
.32306 .33349 m
.32463 .32683 L
s
.32964 .35347 m
.33391 .35427 L
s
.71178 .35422 m
.71457 .35136 L
s
.71178 .35422 m
.71599 .35109 L
s
.71457 .35136 m
.71588 .34644 L
s
.71599 .35109 m
.71729 .34616 L
s
.32295 .33813 m
.32306 .33349 L
s
.32687 .35059 m
.32964 .35347 L
s
.32546 .35032 m
.32964 .35347 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31998 .34208 m
.32002 .34039 L
s
.5 Mabswid
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32167 .3332 m
.32323 .32654 L
s
.32156 .33784 m
.32167 .3332 L
s
.30704 .3159 m
.31651 .3181 L
s
.32295 .33813 m
.32417 .34538 L
s
.32417 .34538 m
.32687 .35059 L
s
.32156 .33784 m
.32278 .3451 L
s
.32278 .3451 m
.32546 .35032 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73053 .31772 m
.73137 .35029 L
s
.72642 .31864 m
.73595 .31647 L
s
.31158 .34976 m
.31242 .31717 L
s
.31022 .34946 m
.31107 .31685 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72724 .35116 m
.73274 .34999 L
s
.73189 .31741 m
.73274 .34999 L
s
.29263 .31224 m
.30173 .3146 L
s
.30617 .34854 m
.31158 .34976 L
s
.7428 .32184 m
.74531 .31652 L
s
.74167 .32916 m
.7428 .32184 L
s
.73035 .36461 m
.73167 .36198 L
s
.73035 .36461 m
.73179 .36667 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74167 .32916 m
.74179 .33382 L
s
.74531 .31652 m
.74916 .31319 L
s
.73167 .36198 m
.7331 .36404 L
s
.74412 .32151 m
.74662 .31619 L
s
.74299 .32884 m
.74412 .32151 L
s
.74299 .32884 m
.74312 .33351 L
s
.74662 .31619 m
.74916 .31319 L
s
.74179 .33382 m
.74331 .34052 L
s
.29709 .33931 m
.2978 .3136 L
s
.73179 .36667 m
.7331 .36404 L
s
.74312 .33351 m
.74463 .3402 L
s
.29578 .33898 m
.2965 .31326 L
s
.30979 .36586 m
.31121 .3638 L
s
.30991 .36116 m
.31121 .3638 L
s
.74916 .31319 m
.75174 .31251 L
s
.3085 .36321 m
.30991 .36116 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3085 .36321 m
.30979 .36586 L
s
.74331 .34052 m
.74608 .34457 L
s
.75174 .31251 m
.75565 .31381 L
s
.74463 .3402 m
.7474 .34425 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74608 .34457 m
.75008 .34595 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29565 .34367 m
.29709 .33931 L
s
.7474 .34425 m
.75008 .34595 L
s
.75565 .31381 m
.75832 .31779 L
s
.29435 .34335 m
.29578 .33898 L
s
.27884 .30832 m
.28754 .31084 L
s
.2917 .34504 m
.29565 .34367 L
s
.75008 .34595 m
.75396 .34497 L
s
.2917 .34504 m
.29435 .34335 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76584 .33807 m
.76599 .33803 L
s
.28368 .33243 m
.2839 .33311 L
s
.28348 .33915 m
.28374 .33859 L
s
.255 .412 .882 r
.75625 .3349 m
.75746 .33221 L
s
.75625 .3349 m
.75759 .33691 L
s
.28913 .34438 m
.2917 .34504 L
s
.75396 .34497 m
.75646 .34196 L
s
.75746 .33221 m
.75879 .33422 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75646 .34196 m
.75886 .33657 L
s
.75879 .33422 m
.75886 .33657 L
s
.28539 .34101 m
.28913 .34438 L
s
.28302 .33561 m
.28539 .34101 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76576 .33047 m
.76576 .3306 L
s
.76698 .32888 m
.76702 .33019 L
s
.5 Mabswid
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76681 .30824 m
.76709 .31764 L
s
.76681 .30824 m
.76817 .31257 L
s
.76709 .31764 m
.76817 .31257 L
s
.76817 .31257 m
.76931 .30985 L
s
.76931 .30985 m
.77166 .30676 L
s
.77166 .30676 m
.77641 .30524 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28107 .35891 m
.28254 .30941 L
s
.28232 .35925 m
.28378 .30977 L
s
.76752 .33177 m
.76867 .32906 L
s
.76752 .33177 m
.76766 .3365 L
s
.76867 .32906 m
.77103 .32597 L
s
.76759 .33413 m
.76874 .33142 L
s
.76874 .33142 m
.7711 .32833 L
s
.76766 .3365 m
.76896 .33851 L
s
.27735 .35789 m
.28232 .35925 L
s
.77641 .30524 m
.77883 .30683 L
s
.26797 .30729 m
.27019 .31277 L
s
.27019 .31277 m
.27115 .32022 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7679 .35959 m
.76794 .3609 L
s
.76668 .36116 m
.76668 .3613 L
s
.5 Mabswid
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76896 .33851 m
.77146 .34016 L
s
.7711 .32833 m
.77693 .32176 L
s
.77103 .32597 m
.77686 .3194 L
s
.27101 .32495 m
.27115 .32022 L
s
.26455 .30377 m
.26797 .30729 L
s
.2668 .30691 m
.269 .31239 L
s
.269 .31239 m
.26996 .31985 L
s
.26982 .32458 m
.26996 .31985 L
s
.2696 .33168 m
.27101 .32495 L
s
.26455 .30377 m
.2668 .30691 L
s
.77146 .34016 m
.77626 .33872 L
s
.77883 .30683 m
.78007 .3088 L
s
.26841 .33131 m
.26982 .32458 L
s
.77686 .3194 m
.77913 .31627 L
s
.25385 .28319 m
.26165 .28608 L
s
.77693 .32176 m
.77921 .31864 L
s
.26225 .30298 m
.26455 .30377 L
s
.78007 .3088 m
.7803 .31589 L
s
.26708 .33568 m
.2696 .33168 L
s
.77913 .31627 m
.78022 .31353 L
s
.77921 .31864 m
.7803 .31589 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2659 .33531 m
.26841 .33131 L
s
.2599 .30455 m
.26225 .30298 L
s
.25664 .33467 m
.25827 .28485 L
s
.77626 .33872 m
.77856 .33561 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25552 .33428 m
.25716 .28444 L
s
.2635 .33695 m
.26708 .33568 L
s
.77856 .33561 m
.77966 .33286 L
s
.77966 .33286 m
.78067 .32774 L
s
.78067 .32774 m
.78097 .33724 L
s
.77966 .33286 m
.78097 .33724 L
s
.2575 .3085 m
.2599 .30455 L
s
.2635 .33695 m
.2659 .33531 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78797 .30367 m
.78901 .3009 L
s
.78797 .30367 m
.78917 .30564 L
s
.26119 .33619 m
.2635 .33695 L
s
.78901 .3009 m
.7902 .30286 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78917 .30564 m
.7902 .30286 L
s
.25898 .33305 m
.26119 .33619 L
s
.25687 .32751 m
.25898 .33305 L
s
.78956 .31751 m
.79162 .34578 L
s
.78938 .34654 m
.78956 .31751 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25005 .29852 m
.25112 .29893 L
s
.24783 .30006 m
.25005 .29852 L
s
.24889 .30048 m
.25005 .29852 L
s
.25219 .33311 m
.25664 .33467 L
s
.79003 .33181 m
.7905 .34616 L
s
.24767 .30482 m
.24889 .30048 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24661 .30441 m
.24783 .30006 L
s
.78938 .34654 m
.79066 .35095 L
s
.2471 .32154 m
.24767 .30482 L
s
.24467 .2988 m
.24661 .30441 L
s
.24587 .32592 m
.24661 .30441 L
s
.79066 .35095 m
.79162 .34578 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24268 .29556 m
.24467 .2988 L
s
.24587 .32592 m
.2471 .32154 L
s
.23962 .29426 m
.24268 .29556 L
s
.24506 .31833 m
.24604 .32113 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23895 .31342 m
.24506 .31833 L
s
.24473 .32792 m
.24587 .32592 L
s
.23753 .29578 m
.23962 .29426 L
s
.23654 .29534 m
.23962 .29426 L
s
.24256 .3295 m
.24473 .32792 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23637 .30014 m
.23753 .29578 L
s
.23845 .32785 m
.24256 .3295 L
s
.23539 .2997 m
.23654 .29534 L
s
.23703 .31017 m
.23895 .31342 L
s
.23603 .30974 m
.23895 .31342 L
s
.2362 .30493 m
.23637 .30014 L
s
.2362 .30493 m
.23703 .31017 L
s
.23522 .3045 m
.23539 .2997 L
s
.23522 .3045 m
.23603 .30974 L
s
0 0 0 r
.22085 .27799 m
.22257 .27885 L
s
.255 .412 .882 r
.23652 .3246 m
.23845 .32785 L
s
.23569 .31936 m
.23669 .31979 L
s
.2366 .32219 m
.23669 .31979 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23561 .32177 m
.23652 .3246 L
s
.23561 .32177 m
.23569 .31936 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22705 .31546 m
.22789 .31833 L
s
.2278 .32075 m
.22789 .31833 L
s
.21746 .28332 m
.22349 .28661 L
s
.22678 .32274 m
.2278 .32075 L
s
.22603 .31745 m
.22705 .31546 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22603 .31745 m
.22687 .32031 L
s
.22403 .32142 m
.22678 .32274 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21959 .31919 m
.22086 .28521 L
s
.21872 .31874 m
.21999 .28474 L
s
.22232 .3181 m
.22403 .32142 L
s
.22073 .31234 m
.22232 .3181 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22013 .30459 m
.22073 .31234 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21617 .31738 m
.21959 .31919 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21184 .29993 m
.21259 .28043 L
s
.20874 .29803 m
.21424 .30135 L
s
.21105 .29946 m
.2118 .27995 L
s
.21017 .2814 m
.21152 .28725 L
s
.208 .27749 m
.21017 .2814 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20654 .2765 m
.208 .27749 L
s
.21061 .33183 m
.21118 .31707 L
s
.21011 .32398 m
.21118 .31707 L
s
0 0 0 r
.19988 .26859 m
.19999 .2685 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20502 .27795 m
.20654 .2765 L
s
.20431 .27745 m
.20654 .2765 L
s
.20836 .32799 m
.21011 .32398 L
s
.21011 .32398 m
.21061 .33183 L
s
.83972 .27589 m
.84643 .27082 L
s
.20342 .28185 m
.20502 .27795 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20274 .28135 m
.20431 .27745 L
s
.20599 .32908 m
.20836 .32799 L
s
.84182 .27439 m
.84387 .32617 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8425 .27388 m
.84456 .3257 L
s
.20254 .28627 m
.20342 .28185 L
s
.20186 .28577 m
.20274 .28135 L
s
.20157 .29316 m
.20254 .28627 L
s
.20452 .32815 m
.20599 .32908 L
s
.2009 .29266 m
.20186 .28577 L
s
0 0 0 r
.19778 .3032 m
.19813 .29452 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1982 .31074 m
.19828 .31105 L
s
.255 .412 .882 r
.20317 .32474 m
.20452 .32815 L
s
.20247 .32427 m
.20452 .32815 L
s
0 0 0 r
.19724 .29917 m
.19745 .29388 L
s
.255 .412 .882 r
.20108 .3055 m
.20157 .29316 L
s
0 0 0 r
.19778 .3032 m
.1982 .31074 L
s
.255 .412 .882 r
.84175 .32758 m
.84852 .32284 L
s
.20041 .30501 m
.2009 .29266 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20196 .31884 m
.20317 .32474 L
s
.84643 .27082 m
.84777 .27226 L
s
.84643 .27082 m
.84837 .27174 L
s
.20108 .3055 m
.20147 .31341 L
s
.20127 .31836 m
.20247 .32427 L
s
.20147 .31341 m
.20196 .31884 L
s
.20041 .30501 m
.20079 .31292 L
s
.20079 .31292 m
.20127 .31836 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84777 .27226 m
.84917 .27617 L
s
.84837 .27174 m
.84976 .27565 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84917 .27617 m
.84996 .2806 L
s
.19406 .30256 m
.1977 .30553 L
s
.84976 .27565 m
.85055 .28009 L
s
.19489 .2673 m
.19584 .30405 L
s
.19126 .30005 m
.19489 .2673 L
s
.1918 .30056 m
.19459 .27473 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85055 .28009 m
.85142 .28702 L
s
.84996 .2806 m
.85085 .28753 L
s
.84852 .32284 m
.84967 .31938 L
s
.84852 .32284 m
.85028 .3189 L
s
.85085 .28753 m
.85135 .29996 L
s
.85142 .28702 m
.85193 .29946 L
s
.84967 .31938 m
.85068 .31342 L
s
.85281 .26509 m
.85631 .26136 L
s
.85107 .30794 m
.85135 .29996 L
s
.85028 .3189 m
.85128 .31293 L
s
.85068 .31342 m
.85107 .30794 L
s
.85166 .30744 m
.85193 .29946 L
s
.85128 .31293 m
.85166 .30744 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85437 .2635 m
.85581 .29842 L
s
.19062 .26308 m
.19126 .30005 L
s
.18726 .29597 m
.19062 .26308 L
s
.85487 .26297 m
.85631 .29791 L
s
.18772 .29649 m
.19032 .27054 L
s
.85424 .29994 m
.85631 .29791 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85569 .2829 m
.85649 .28988 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85649 .28988 m
.85766 .29387 L
s
.18591 .29443 m
.18918 .29802 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85766 .29387 m
.85869 .29535 L
s
.18611 .2577 m
.18652 .25824 L
s
.18522 .25911 m
.18611 .2577 L
s
.18561 .25966 m
.18611 .2577 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85869 .29535 m
.86 .2938 L
s
.18501 .26413 m
.18561 .25966 L
s
.85936 .28928 m
.8599 .29128 L
s
.85936 .28928 m
.85969 .28625 L
s
.18463 .26359 m
.18522 .25911 L
s
.85969 .28625 m
.86021 .28824 L
s
.18427 .28173 m
.18501 .26413 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18191 .28331 m
.18232 .27854 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86 .2938 m
.86032 .29076 L
s
.18411 .25748 m
.18463 .26359 L
s
.18368 .28625 m
.18463 .26359 L
s
.86021 .28824 m
.86032 .29076 L
s
.18352 .25387 m
.18411 .25748 L
s
.18368 .28625 m
.18427 .28173 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18255 .25221 m
.18352 .25387 L
s
.18362 .27815 m
.18389 .2812 L
s
.86192 .26184 m
.86205 .25626 L
s
.86192 .26184 m
.86213 .26688 L
s
.86205 .25626 m
.8629 .25209 L
s
.1817 .2724 m
.18362 .27815 L
s
.1832 .28825 m
.18368 .28625 L
s
.86213 .26688 m
.86268 .27138 L
s
.86226 .2613 m
.86238 .25571 L
s
.86226 .2613 m
.86247 .26634 L
s
.86238 .25571 m
.8629 .25209 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86247 .26634 m
.86302 .27084 L
s
.18237 .28973 m
.1832 .28825 L
s
.18185 .25362 m
.18255 .25221 L
s
.18156 .25307 m
.18255 .25221 L
s
.86268 .27138 m
.86376 .27229 L
s
.8629 .25209 m
.86377 .25043 L
s
.86302 .27084 m
.86376 .27229 L
s
.86311 .28149 m
.86322 .28402 L
s
.86311 .28149 m
.86344 .28096 L
s
.18105 .28762 m
.18237 .28973 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86322 .28402 m
.86366 .28603 L
s
.18135 .25812 m
.18185 .25362 L
s
.86344 .28096 m
.86355 .28349 L
s
.86377 .25043 m
.86441 .25184 L
s
.18121 .26879 m
.1817 .2724 L
s
.18092 .26824 m
.1817 .2724 L
s
.18108 .25757 m
.18156 .25307 L
s
.86376 .27229 m
.86553 .27158 L
s
.86366 .28603 m
.8644 .28751 L
s
.18114 .26318 m
.18135 .25812 L
s
.18114 .26318 m
.18121 .26879 L
s
.18086 .26263 m
.18108 .25757 L
s
.86441 .25184 m
.86512 .25579 L
s
0 0 0 r
.17626 .24492 m
.17653 .2416 L
s
.255 .412 .882 r
.18056 .28401 m
.18105 .28762 L
s
.18086 .26263 m
.18092 .26824 L
s
.8644 .28751 m
.86555 .28538 L
s
.18049 .27839 m
.18078 .27893 L
s
.18067 .28147 m
.18078 .27893 L
s
.18038 .28094 m
.18056 .28401 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18038 .28094 m
.18049 .27839 L
s
0 0 0 r
.86917 .23856 m
.8693 .23642 L
s
.17622 .24881 m
.17626 .24492 L
s
.17619 .24073 m
.17626 .24492 L
s
.255 .412 .882 r
.86512 .25579 m
.86514 .25017 L
s
.86512 .25579 m
.8661 .27867 L
s
0 0 0 r
.17593 .23597 m
.17619 .24073 L
s
.255 .412 .882 r
.86514 .25017 m
.86546 .24651 L
s
0 0 0 r
.8693 .23642 m
.87004 .23411 L
s
.255 .412 .882 r
.86536 .25524 m
.86536 .24961 L
s
.86536 .25524 m
.86611 .27303 L
s
.86536 .24961 m
.86546 .24651 L
s
0 0 0 r
.17522 .23365 m
.17593 .23597 L
s
.255 .412 .882 r
.86553 .27158 m
.86588 .27358 L
s
0 0 0 r
.86997 .25704 m
.87024 .25817 L
s
.255 .412 .882 r
.86555 .28538 m
.86596 .28176 L
s
.86546 .24651 m
.86567 .24595 L
s
0 0 0 r
.87013 .26067 m
.8704 .2618 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86596 .28176 m
.8661 .27867 L
s
0 0 0 r
.17516 .27031 m
.1752 .2724 L
s
.255 .412 .882 r
.8661 .27867 m
.86611 .27303 L
s
0 0 0 r
.17488 .26556 m
.17516 .27031 L
s
.17501 .27395 m
.17505 .27604 L
s
.87146 .26265 m
.87024 .25817 L
s
.17472 .2692 m
.17501 .27395 L
s
.17453 .28489 m
.17473 .28334 L
s
.87004 .23411 m
.87051 .23658 L
s
.8704 .2618 m
.87162 .26631 L
s
.17427 .25547 m
.17488 .26556 L
s
.17477 .23613 m
.17522 .23365 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17412 .25912 m
.17472 .2692 L
s
.17393 .28746 m
.17453 .28489 L
s
.87051 .23658 m
.87081 .23964 L
s
.87115 .28434 m
.8717 .28681 L
s
.255 .412 .882 r
.17837 .27352 m
.17846 .27662 L
s
.17835 .27918 m
.17846 .27662 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17805 .2812 m
.17835 .27918 L
s
0 0 0 r
.17448 .23919 m
.17477 .23613 L
s
.255 .412 .882 r
.17808 .27554 m
.17837 .27352 L
s
.17805 .23869 m
.17876 .24268 L
s
0 0 0 r
.87062 .23179 m
.87081 .23964 L
s
.87125 .24635 m
.87062 .23179 L
s
.17317 .28529 m
.17393 .28746 L
s
.87081 .23964 m
.87125 .24635 L
s
.255 .412 .882 r
.17808 .27554 m
.17816 .27864 L
s
0 0 0 r
.17427 .25547 m
.17414 .25069 L
s
.255 .412 .882 r
.17752 .27958 m
.17805 .2812 L
s
0 0 0 r
.17412 .25912 m
.17398 .25434 L
s
.174 .25012 m
.17448 .23919 L
s
.8717 .28681 m
.87242 .28463 L
s
.17414 .25069 m
.17416 .24647 L
s
.87146 .26265 m
.87191 .26519 L
s
.17398 .25434 m
.174 .25012 L
s
.87162 .26631 m
.87207 .26886 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17685 .27686 m
.17839 .24097 L
s
.86702 .24085 m
.86805 .27892 L
s
.17733 .27593 m
.17752 .27958 L
s
.17675 .27632 m
.17829 .2404 L
s
0 0 0 r
.17301 .28053 m
.17317 .28529 L
s
.255 .412 .882 r
.86735 .24852 m
.86819 .27838 L
s
0 0 0 r
.8722 .2683 m
.87191 .26519 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87131 .22653 m
.87111 .22887 L
s
.87236 .27197 m
.87207 .26886 L
s
.255 .412 .882 r
.1773 .2697 m
.17733 .27593 L
s
0 0 0 r
.87242 .28463 m
.87255 .27987 L
s
.17303 .27631 m
.17301 .28053 L
s
.17321 .26842 m
.17303 .27631 L
s
.17257 .28311 m
.17321 .26842 L
s
.17303 .27631 m
.17257 .28311 L
s
.87252 .27564 m
.8722 .2683 L
s
.255 .412 .882 r
.1773 .2697 m
.17752 .26144 L
s
0 0 0 r
.87255 .27987 m
.87252 .27564 L
s
.17401 .23148 m
.17412 .22724 L
s
.17381 .23455 m
.17401 .23148 L
s
.17412 .22724 m
.17393 .23031 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86756 .28055 m
.86856 .27675 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86702 .24085 m
.86889 .27457 L
s
.17651 .27468 m
.17685 .27686 L
s
0 0 0 r
.17393 .23031 m
.17381 .23455 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8715 .22902 m
.87178 .23752 L
s
.255 .412 .882 r
.86751 .23628 m
.86889 .27457 L
s
0 0 0 r
.87131 .22359 m
.8715 .22902 L
s
.17301 .2529 m
.17104 .29673 L
s
.17113 .29781 m
.17301 .2529 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86784 .24399 m
.86895 .27402 L
s
.86751 .23628 m
.86906 .27018 L
s
0 0 0 r
.87131 .22653 m
.87355 .27805 L
s
.87127 .22712 m
.87351 .27861 L
s
.255 .412 .882 r
.17731 .24869 m
.17752 .24297 L
s
.17699 .25699 m
.17731 .24869 L
s
.17752 .24297 m
.17776 .23668 L
s
0 0 0 r
.87124 .22241 m
.87131 .22359 L
s
.255 .412 .882 r
.17644 .2699 m
.17699 .25699 L
s
.1773 .24813 m
.17753 .2424 L
s
.17698 .25643 m
.1773 .24813 L
s
.17753 .2424 m
.17779 .23611 L
s
.17642 .26935 m
.17698 .25643 L
s
.17776 .23668 m
.17798 .23238 L
s
0 0 0 r
.17108 .29727 m
.17205 .27502 L
s
.87129 .22491 m
.87124 .22241 L
s
.87121 .22432 m
.87124 .22241 L
s
.255 .412 .882 r
.17779 .23611 m
.17798 .23238 L
s
.17609 .27713 m
.17644 .2699 L
s
0 0 0 r
.87359 .2764 m
.87351 .27861 L
s
.255 .412 .882 r
.17608 .27658 m
.17642 .26935 L
s
.17798 .23238 m
.17905 .22661 L
s
.86895 .26853 m
.86908 .27183 L
s
0 0 0 r
.17076 .30471 m
.17113 .29781 L
s
.255 .412 .882 r
.17586 .28178 m
.17609 .27713 L
s
0 0 0 r
.87153 .2317 m
.87129 .22491 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17586 .28124 m
.17608 .27658 L
s
0 0 0 r
.87145 .23112 m
.87121 .22432 L
s
.255 .412 .882 r
.17565 .2859 m
.17586 .28178 L
s
0 0 0 r
.17104 .29673 m
.17076 .30471 L
s
.87153 .2317 m
.87331 .27252 L
s
.255 .412 .882 r
.17567 .28536 m
.17586 .28124 L
s
0 0 0 r
.87145 .23112 m
.87322 .27196 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17564 .2869 m
.17565 .2859 L
s
.17564 .2869 m
.17567 .28536 L
s
.86721 .23657 m
.86754 .24234 L
s
.86754 .24234 m
.86798 .25069 L
s
.86672 .23024 m
.86721 .23657 L
s
.86798 .25069 m
.86854 .26371 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86708 .236 m
.86743 .24177 L
s
.86743 .24177 m
.86788 .25013 L
s
.86658 .22966 m
.86708 .236 L
s
.86614 .22591 m
.86672 .23024 L
s
.86788 .25013 m
.86844 .26316 L
s
0 0 0 r
.86862 .21175 m
.87007 .2159 L
s
.255 .412 .882 r
.86614 .22591 m
.86658 .22966 L
s
.86854 .26371 m
.86877 .27099 L
s
0 0 0 r
.87291 .2703 m
.87331 .27252 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17614 .28366 m
.17774 .24635 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86844 .26316 m
.86866 .27044 L
s
.86577 .22475 m
.86614 .22591 L
s
.86877 .27099 m
.86888 .27568 L
s
.86866 .27044 m
.86876 .27513 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86885 .27983 m
.86888 .27568 L
s
.8687 .27929 m
.86876 .27513 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17626 .28312 m
.17638 .28038 L
s
.17759 .25213 m
.17785 .24617 L
s
.17564 .2869 m
.17669 .28149 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86849 .28084 m
.8687 .27929 L
s
.86849 .28084 m
.86885 .27983 L
s
0 0 0 r
.86931 .21353 m
.87157 .26584 L
s
.86951 .21412 m
.87178 .2664 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86812 .27976 m
.86849 .28084 L
s
0 0 0 r
.86524 .20523 m
.86755 .20938 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87089 .26417 m
.87178 .2664 L
s
.5 Mabswid
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86629 .207 m
.86807 .24835 L
s
.86662 .2076 m
.8684 .24892 L
s
.87272 .29225 m
.87276 .28901 L
s
.87239 .28469 m
.87276 .28901 L
s
.87233 .28793 m
.87239 .28469 L
s
.87233 .28793 m
.87272 .29225 L
s
.8684 .25592 m
.8684 .24892 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86805 .25536 m
.86807 .24835 L
s
.86048 .19873 m
.86367 .20286 L
s
.8675 .25804 m
.8684 .25592 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8675 .25804 m
.86805 .25536 L
s
.86237 .20108 m
.86462 .25414 L
s
.86191 .20049 m
.86417 .25359 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86673 .25692 m
.8675 .25804 L
s
.86534 .25145 m
.86673 .25692 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86414 .24271 m
.86534 .25145 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86273 .25192 m
.86462 .25414 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85777 .20658 m
.85881 .21857 L
s
.8563 .19783 m
.85777 .20658 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85881 .21857 m
.85913 .2262 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8572 .20601 m
.85825 .218 L
s
.85571 .19724 m
.8572 .20601 L
s
.85433 .19228 m
.8563 .19783 L
s
.85433 .19228 m
.85571 .19724 L
s
.85825 .218 m
.85857 .22563 L
s
.85905 .23711 m
.85913 .2262 L
s
.85306 .19111 m
.85433 .19228 L
s
.85848 .23655 m
.85857 .22563 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8519 .19376 m
.85306 .19111 L
s
.85123 .19319 m
.85306 .19111 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85762 .24311 m
.85848 .23655 L
s
.85822 .24367 m
.85905 .23711 L
s
.85086 .20026 m
.8519 .19376 L
s
.85655 .24586 m
.85822 .24367 L
s
.85016 .19969 m
.85123 .19319 L
s
.85655 .24586 m
.85762 .24311 L
s
.85063 .21119 m
.85086 .20026 L
s
.84992 .21063 m
.85016 .19969 L
s
.85528 .24477 m
.85655 .24586 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85063 .21119 m
.85094 .21888 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8538 .23981 m
.85528 .24477 L
s
.85312 .23927 m
.85528 .24477 L
s
.84992 .21063 m
.85023 .21833 L
s
.85094 .21888 m
.85212 .231 L
s
.85212 .231 m
.8538 .23981 L
s
.83957 .18078 m
.84526 .18476 L
s
.85023 .21833 m
.85142 .23045 L
s
.85142 .23045 m
.85312 .23927 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84289 .18305 m
.84616 .26453 L
s
.84208 .18248 m
.84534 .26402 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83633 .19221 m
.83683 .19329 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83782 .23018 m
.83827 .22971 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82949 .17464 m
.83606 .17853 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84282 .26247 m
.84616 .26453 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82385 .18305 m
.82534 .1953 L
s
.82144 .17418 m
.82385 .18305 L
s
.81803 .16867 m
.82144 .17418 L
s
.8228 .18251 m
.82429 .19477 L
s
.82036 .17364 m
.8228 .18251 L
s
.82534 .1953 m
.82564 .20313 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83238 .1763 m
.83557 .25839 L
s
.83331 .17686 m
.83651 .2589 L
s
.81803 .16867 m
.82036 .17364 L
s
.82429 .19477 m
.82459 .2026 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81581 .1676 m
.81803 .16867 L
s
.82504 .21438 m
.82564 .20313 L
s
.83266 .25688 m
.83651 .2589 L
s
.82398 .21387 m
.82459 .2026 L
s
.255 .412 .882 r
.23406 .17893 m
.23447 .17842 L
s
0 0 0 r
.81368 .17046 m
.81581 .1676 L
s
.81252 .16993 m
.81581 .1676 L
s
.82321 .22123 m
.82504 .21438 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82212 .22072 m
.82398 .21387 L
s
.81164 .17726 m
.81368 .17046 L
s
.81047 .17674 m
.81252 .16993 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80808 .20011 m
.80833 .20709 L
s
.5 Mabswid
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82008 .22367 m
.82321 .22123 L
s
.82008 .22367 m
.82212 .22072 L
s
.81089 .18854 m
.81164 .17726 L
s
.8097 .18803 m
.81047 .17674 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81783 .22266 m
.82008 .22367 L
s
.81089 .18854 m
.81118 .19643 L
s
.8097 .18803 m
.80999 .19593 L
s
.255 .412 .882 r
.80833 .20709 m
.80856 .20811 L
s
0 0 0 r
.8154 .21771 m
.81783 .22266 L
s
.81424 .21721 m
.81783 .22266 L
s
.81118 .19643 m
.81279 .20879 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81279 .20879 m
.8154 .21771 L
s
.80999 .19593 m
.8116 .20829 L
s
.8116 .20829 m
.81424 .21721 L
s
.7777 .12535 m
.78747 .1288 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79653 .16329 m
.79938 .17217 L
s
.79938 .17217 m
.80107 .18453 L
s
.79244 .15785 m
.79653 .16329 L
s
.79522 .16279 m
.79809 .17168 L
s
.79809 .17168 m
.79979 .18404 L
s
.79244 .15785 m
.79522 .16279 L
s
.80107 .18453 m
.80135 .19245 L
s
.78976 .15687 m
.79244 .15785 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80048 .20388 m
.80135 .19245 L
s
.79979 .18404 m
.80007 .19196 L
s
.78335 .12731 m
.7861 .21074 L
s
.78195 .12682 m
.78469 .21029 L
s
.79919 .2034 m
.80007 .19196 L
s
.78716 .15985 m
.78976 .15687 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79817 .2109 m
.80048 .20388 L
s
.78465 .16682 m
.78716 .15985 L
s
.79685 .21043 m
.79919 .2034 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79433 .21349 m
.79817 .2109 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79433 .21349 m
.79685 .21043 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26938 .15218 m
.29392 .14503 L
s
.79163 .21256 m
.79433 .21349 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76678 .14932 m
.7757 .15208 L
s
.78875 .20764 m
.79163 .21256 L
s
.7857 .19871 m
.78875 .20764 L
s
.7804 .20894 m
.7861 .21074 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76835 .18756 m
.76991 .1908 L
s
.76852 .19317 m
.76991 .1908 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75504 .16985 m
.7556 .17 L
s
.7556 .17 m
.76903 .17373 L
s
.74788 .14409 m
.7575 .14666 L
s
.27391 .19433 m
.2831 .19176 L
s
.29231 .14545 m
.29323 .1691 L
s
.29323 .1691 m
.29392 .14503 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27114 .23517 m
.27379 .15079 L
s
.27265 .23475 m
.27528 .15033 L
s
.28261 .20792 m
.28358 .17565 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76437 .22042 m
.77129 .15069 L
s
.26669 .23644 m
.28104 .23267 L
s
.28104 .23267 m
.29147 .22993 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31038 .14493 m
.31563 .13974 L
s
.30847 .15338 m
.31038 .14493 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31927 .14124 m
.31931 .13962 L
s
.5 Mabswid
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31209 .14454 m
.31563 .13974 L
s
.31017 .15298 m
.31209 .14454 L
s
.30726 .19793 m
.30847 .15338 L
s
.31563 .13974 m
.31911 .13897 L
s
.30897 .19756 m
.31017 .15298 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75113 .14494 m
.76474 .23262 L
s
.76474 .23262 m
.77277 .15115 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31911 .13897 m
.32428 .14187 L
s
.28985 .23032 m
.29218 .20549 L
s
.29147 .22993 m
.29218 .20549 L
s
.32428 .14187 m
.32764 .14922 L
s
.32794 .1371 m
.33515 .13566 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31832 .17798 m
.31837 .17635 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32654 .19397 m
.32794 .1371 L
s
.32834 .19363 m
.32973 .13674 L
s
.30219 .19907 m
.30897 .19756 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34799 .13733 m
.35373 .1323 L
s
.34407 .1461 m
.34799 .13733 L
s
.34194 .15862 m
.34407 .1461 L
s
.34987 .137 m
.35373 .1323 L
s
.34594 .14577 m
.34987 .137 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35373 .1323 m
.35753 .13167 L
s
.3438 .15829 m
.34594 .14577 L
s
.32118 .19501 m
.32834 .19363 L
s
.35753 .13167 m
.36321 .13481 L
s
.34175 .16677 m
.34194 .15862 L
s
.34361 .16644 m
.3438 .15829 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34175 .16677 m
.34334 .1787 L
s
.34361 .16644 m
.34521 .17838 L
s
.36321 .13481 m
.36693 .14236 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34334 .1787 m
.34691 .18626 L
s
.34521 .17838 m
.3488 .18595 L
s
.37895 .12845 m
.39297 .12664 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34691 .18626 m
.35251 .18945 L
s
.3488 .18595 m
.35251 .18945 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3645 .16717 m
.36637 .17098 L
s
.36247 .17155 m
.3645 .16717 L
s
.36247 .17155 m
.36433 .17537 L
s
.35251 .18945 m
.35827 .18857 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40111 .12568 m
.41556 .12416 L
s
.36628 .17509 m
.36637 .17098 L
s
.36222 .18388 m
.36628 .17509 L
s
.35827 .18857 m
.36222 .18388 L
s
.40643 .18259 m
.40727 .12501 L
s
.40851 .18238 m
.40934 .12479 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38342 .2141 m
.38492 .12765 L
s
.38544 .21387 m
.38693 .12739 L
s
.4323 .12675 m
.43871 .12215 L
s
.42798 .1353 m
.4323 .12675 L
s
.43442 .12658 m
.43871 .12215 L
s
.43871 .12215 m
.44298 .12184 L
s
.43009 .13512 m
.43442 .12658 L
s
.44298 .12184 m
.44721 .12564 L
s
.42572 .14781 m
.42798 .1353 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42783 .14763 m
.43009 .13512 L
s
.45154 .12126 m
.46016 .12075 L
s
.44721 .12564 m
.45143 .13358 L
s
.42562 .15605 m
.42572 .14781 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42773 .15587 m
.42783 .14763 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47534 .12001 m
.47749 .12403 L
s
.47314 .12421 m
.47534 .12001 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47314 .12421 m
.47529 .12823 L
s
.42562 .15605 m
.42759 .16827 L
s
.47529 .12823 m
.47749 .12403 L
s
.42773 .15587 m
.42971 .1681 L
s
.40023 .18322 m
.40851 .18238 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37738 .21483 m
.38544 .21387 L
s
.255 .412 .882 r
.50503 .1608 m
.50504 .15743 L
s
0 0 0 r
.42759 .16827 m
.43174 .17622 L
s
.42971 .1681 m
.43387 .17606 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50939 .15785 m
.5113 .15742 L
s
0 0 0 r
.43174 .17622 m
.4381 .1799 L
s
.255 .412 .882 r
.50721 .16077 m
.50939 .15785 L
s
0 0 0 r
.43387 .17606 m
.4381 .1799 L
s
.40613 .20335 m
.40816 .20732 L
s
.40399 .20772 m
.40613 .20335 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44674 .17517 m
.45113 .16661 L
s
.40399 .20772 m
.40601 .21169 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4381 .1799 m
.44239 .17961 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45076 .20828 m
.45154 .12126 L
s
.45293 .20816 m
.45369 .12113 L
s
.47516 .14885 m
.47706 .19868 L
s
.47267 .19885 m
.47516 .14885 L
s
.40601 .21169 m
.40816 .20732 L
s
.44239 .17961 m
.44674 .17517 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47487 .19876 m
.47502 .17373 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44426 .20867 m
.45293 .20816 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47267 .19885 m
.47482 .20714 L
s
.47482 .20714 m
.47706 .19868 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@090?nV4@D000001P3oYQ400`2][Jd000000:f][@0c
0:f][@l0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA0080ojHA100000030:f][@8000002@2][Jd2000000D0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0
/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0@0?nV4@D0000000<0ojHA0:f][@2][Jd01@2][Jd2000000<0[Jf]00@0ojHA0000003o
YQ40ojHA0P0000090?nV4@030000003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P020>bF3P8000001P3/UPh20:f]
[FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@@000000P3oYQ400`2][Jd0000000000003000000@0
[Jf]103oYQ40102][Jd0ojHA0000000000060?nV4@040000003oYQ400000000000T0ojHA0P000005
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;
0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh2000000H0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ450000
00D0[Jf]103oYQ42000000P0ojHA00<0[Jf]0000000000001`3oYQ4010000000ojHA00000000000:
0?nV4@030000003oYQ40ojHA00<0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01D0oj<@1`2][JdH0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh4000000L0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA1`2][Jd30?nV4@8000002@3oYQ420000
00P0ojHA00<0[Jf]000000000000203oYQ4300000100ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1001P2][JdB0?bP
40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh2000000X0k9H>0`2][JeO0;3P
iP40oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00l0
ojHA100000020:f][@80ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000080?nV4@80
00002@3oYQ4300000100ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1001P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3f
W0l04`3fW0l00`2][Jd0k9H>0>bF3P040>bF3P8000002P3/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0
/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@80[Jf]0P000000102][Jd0ojHA0?nV4@3oYQ4200000080
ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000080?nV4@8000002P3oYQ4200000100
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0
oj<@00<0[Jf]0?bP403lX1002`3lX1050:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P030>bF3P8000002P3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00
K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA0080ojHA1@0000040:f][@030?nV4@000000000000H0ojHA00@000000?nV4@3oYQ40
[Jf]1`3oYQ42000000T0ojHA0P0000080?nV4@8000002P3oYQ4200000100ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X100403lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P030>bF3P80
00002P3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@
0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd00000
0?nV4@020:f][@80000000<0[Jf]0?nV4@3oYQ401@3oYQ42000000L0ojHA00<000000?nV4@2][Jd0
1`3oYQ42000000T0ojHA0P0000080?nV4@8000002P3oYQ4200000100ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
5P3lX1040:f][AD0mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh2000000X0k9H>00<0[Jf]0=^:3@3KRPd0
1P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1404`3oY142000000040:f][@00000000000?nV4@8000001`3oYQ42000000P0ojHA
00<000000?nV4@2][Jd01`3oYQ42000000T0ojHA0P0000080?nV4@8000002P3oYQ4200000100ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0:f][@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh0
0`3/UPh2000000X0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2]
[Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1430:f][@030000003o
Y140[Jf]00<0ojHA0`0000070?nV4@8000002@3oYQ400`000000[Jf]0?nV4@060?nV4@8000002@3o
YQ42000000L0ojHA0P00000;0?nV4@800000403oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00<0k9H>0P00000:0>bF3P030:f][@3K
RPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00L0oj@A0P0000020?nT4@@0[Jf]0P3oY14010000000oj@A0?nT4@2]
[Jd30?nV4@<000001P3oYQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P00
00070?nV4@8000002`3oYQ4200000100ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`070?JL3`80[Jf]0`0000080?JL3`030:f][@3/UPh0k9H>00<0k9H>0P00000:0>bF3P030:f][@3K
RPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140103oY143000000040:f][@000000
[Jf]0:f][@H0oj@A00@000000?nT4@3oY140[Jf]103oYQ42000000H0ojHA0P00000;0?nV4@030:f]
[@3oYQ40ojHA00D0ojHA0P0000090?nV4@8000001`3oYQ42000000/0ojHA0P00000@0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l4000000D0mY`?00<0[Jf]0>bF3P3/UPh0
0`3/UPh2000000X0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2]
[Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00@0[Jf]0?nT4@3oY140oj@A0`0000030:f][@030?nT
4@000000oj@A00H0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA0080ojHA0P0000060?nV4@800000
2`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002@3oYQ42000000L0ojHA0P00000;0?nV4@800000
2P3oYQ400`000000ojHA0?nV4@030?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
2`3fW0l010000000mY`?0?JL3`3fW0l40:f][@030000002][Jd0k9H>00D0k9H>00<000000>bF3P3/
UPh02@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V
00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40040:f][@000000000000000080
[Jf]1@3oY1400`000000oj@A0?nT4@050?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@020?nV4@80
00001P3oYQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000070?nV4@80
00002`3oYQ42000000X0ojHA00<000000?nV4@3oYQ400`3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?00/0mY`?00<000000?JL3`3fW0l01@3fW0l0102][Jd000000000000000040>bF
3P030000003/UPh0k9H>00T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?
0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003P3lX104
000000P0oj@A00<000000?nT4@3oY1401@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ42
000000D0ojHA0P00000<0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P0000090?nV4@8000001`3oYQ42
000000/0ojHA0P00000:0?nV4@030000003oYQ40ojHA00<0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100
0`2][Jd0mY`?0?JL3`0<0?JL3`030000003fW0l0mY`?00D0mY`?00D0[Jf]00000000000000000:f]
[@020>bF3P030000003/UPh0k9H>00T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue
2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f]
[@3lX100o:0@00`0o:0@0P2][Jd0103lX100[Jf]0000000000080?nT4@030000003oY140oj@A00D0
oj@A0P0000020?nT4@030:f][@3oYQ40ojHA0080ojHA0P0000050?nV4@800000303oYQ400`2][Jd0
ojHA0?nV4@050?nV4@800000203oYQ42000000P0ojHA0P00000;0?nV4@8000002P3oYQ400`000000
ojHA0?nV4@030?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l00`000000
mY`?0?JL3`050?JL3`030:f][@00000000000080k9H>0P2][Jd00`000000k9H>0>bF3P090>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool00680/>3V
00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@
0`2][Jd30?bP40030:f][@000000000000P0oj@A00<000000?nT4@3oY1401@3oY14200000080oj@A
00<0[Jf]0?nV4@3oYQ400P3oYQ42000000D0ojHA0P00000<0?nV4@030:f][@3oYQ40ojHA00D0ojHA
0P0000080?nV4@800000203oYQ42000000/0ojHA0P0000090?nV4@030:f][@000000[Jf]02/0[Jf]
5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
303fW0l00`000000mY`?0?JL3`050?JL3`030:f][@000000000000@0k9H>00@000000:f][@2][Jd0
0000203/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`
h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]000000000000203oY1400`000000oj@A
0?nT4@050?nT4@80000000<0oj@A0:f][@3oYQ40103oYQ42000000D0ojHA0P00000<0?nV4@030:f]
[@3oYQ40ojHA00D0ojHA0P0000080?nV4@800000203oYQ42000000H0ojHA1@2][Jd2000000T0[Jf]
00<0ojHA0000003oYQ40103oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@
402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`0<0?JL3`030000003fW0l0mY`?00D0mY`?00<0[Jf]000000000000103/UPh010000000k9H>
0000002][Jd2000000H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`03
0:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@000000000000P0oj@A
00<000000?nT4@3oY1401@3oY142000000030?nT4@2][Jd0ojHA00@0ojHA0P0000050?nV4@800000
303oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42000000@0ojHA102][Jd2000000H0[Jf]
1@3oYQ42000000X0ojHA00<000000?nV4@3oYQ400`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01D0ojD@302][JdH0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
303fW0l00`000000mY`?0?JL3`050?JL3`030:f][@000000000000@0k9H>00<000000>bF3P000000
0P3/UPh2000000030:f][@3/UPh0k9H>0080k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd00000
000000080?nT4@030000003oY140oj@A00D0oj@A0P0000000`3oY140[Jf]0?nV4@040?nV4@800000
1@3oYQ42000000`0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000D0ojHA0`2][Jd2000000@0[Jf]
103oYQ42000000/0ojHA0P0000090?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`2][Jd0mY`?0?JL3`0<0?JL3`030000003fW0l0mY`?00D0mY`?0P0000050>bF3P030000
003/UPh0000000<0k9H>0P0000030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f][@000000000000P0oj@A
00<000000?nT4@3oY1401@3oY142000000030?nT4@2][Jd0ojHA00@0ojHA0P0000050?nV4@800000
303oYQ400`2][Jd0ojHA0?nV4@020?nV4@<0[Jf]0P0000050:f][@<0ojHA0P0000080?nV4@030:f]
[@000000000000T0ojHA00<000000?nV4@0000002@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS40030:f]
[@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03@3fW0l00`000000mY`?0?JL3`040?JL3`800000
1@3/UPh2000000@0k9H>0P0000030>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]
A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][A00o:0@00<0
[Jf]000000000000203oY1400`000000oj@A0?nT4@050?nT4@80000000<0oj@A0:f][@3oYQ40103o
YQ42000000D0ojHA0P00000:0?nV4@030000002][Jd0[Jf]00@0[Jf]0`3oYQ42000000P0ojHA0P00
00080?nV4@030:f][@000000000000T0ojHA0`0000090?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AH0o:0@00<0
[Jf]0?JL3`3fW0l03@3fW0l00`000000mY`?0?JL3`040?JL3`8000001@3/UPh2000000@0k9H>0P00
00040>bF3P<0[Jf]00<0fhX=0000003KRPd0203KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`
h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A40o:0@00<0[Jf]
000000000000203oY1400`000000oj@A0?nT4@050?nT4@80000000<0oj@A0:f][@3oYQ40103oYQ42
000000D0ojHA0P0000040?nV4@D0[Jf]0P0000000`3oYQ40[Jf]0?nV4@060?nV4@800000203oYQ42
000000P0ojHA00<0[Jf]0000000000002@3oYQ400`000000ojHA000000090?nV4@8000001@3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l03@3fW0l00`000000mY`?0?JL
3`040?JL3`8000001@3/UPh00`000000k9H>0>bF3P040>bF3P8000000`3/UPh01P2][Jd0fhX=0=^:
3@000000[Jf]000000P0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40
oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd000000000000@0?nT4@80000000<0oj@A0:f][@3oYQ40
103oYQ42000000D0ojHA0P0000040:f][@D0ojHA0P0000000`3oYQ40[Jf]0?nV4@060?nV4@030000
003oYQ40ojHA00L0ojHA0P0000080?nV4@030:f][@000000000000P0ojHA0P0000000`3oYQ400000
0?nV4@080?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40070?bP40L0[Jf]2@3lX1000`2][Jd0mY`?
0?JL3`0=0?JL3`8000001@3fW0l2000000D0k9H>0P0000050>bF3P8000000`3/UPh01@2][Jd0fhX=
0=^:3@000000fhX=008000001`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0
/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH4080
[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@00000000000100oj@A0P0000000`3oY140
[Jf]0?nV4@040?nV4@80000000<0ojHA0:f][@2][Jd00P2][Jd2000000T0ojHA0P0000000`3oYQ40
[Jf]0?nV4@050?nV4@8000002@3oYQ42000000P0ojHA00@0[Jf]0?nV4@00000000001`3oYQ420000
00030?nV4@000000ojHA00P0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1P2][Jd30?bP
40030:f][@3fW0l0mY`?00d0mY`?00<000000?JL3`0000000`0000000`3fW0l00000000000050>bF
3P8000001@3/UPh2000000<0k9H>00@0[Jf]0=^:3@3KRPd000000P3KRPd00`000000[Jf]0=^:3@05
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0
102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH403_V100103_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@000000000000<0oj@A00<000000?nT4@3oY1402P3o
Y14010000000oj@A0?nT4@2][Jd20?nV4@<0[Jf]0P0000000`2][Jd0ojHA0?nV4@030?nV4@800000
203oYQ42000000030?nV4@2][Jd0ojHA00D0ojHA0P0000090?nV4@800000203oYQ40102][Jd0ojHA
0000000000060?nV4@050000003oYQ4000000?nV4@0000002@3oYQ43000000@0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100503lX1050:f][@h0mY`?00<000000?JL3`3fW0l00`3fW0l3000000D0k9H>0P0000050>bF
3P8000000`3/UPh00`2][Jd0fhX=000000030=^:3@8000000P2][Jd01@3KRPd000000=^:3@3KRPd0
[Jf]00T0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@000000000000<0oj@A00<000000?nT4@3oY1402@3oY142000000030?nT4@2]
[Jd0[Jf]0080[Jf]0`3oYQ42000000H0ojHA0P0000090?nV4@030000003oYQ40[Jf]00H0ojHA0P00
00090?nV4@800000203oYQ400`2][Jd0ojHA0?nV4@02000000@0ojHA00H000000?nV4@3oYQ400000
0?nV4@0000090?nV4@<00000103oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]00<0
[Jf]2`3fW0l00`000000mY`?0?JL3`030?JL3`8000001@3/UPh2000000D0k9H>0P0000030>bF3P03
0:f][@3KRPd0000000@0fhX=00<000000=^:3@3KRPd00P2][Jd2000000030:f][@2iM@/0^GD;00L0
^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd00000000000030?nT4@030000003oY140oj@A00P0oj@A00H0[Jf]000000000000[Jf]0?nT4@2]
[Jd50?nV4@8000001P3oYQ42000000P0ojHA00@000000?nV4@3oYQ40[Jf]1P3oYQ42000000T0ojHA
0P0000080?nV4@040:f][@3oYQ40ojHA0?nV4@8000000P3oYQ401`000000ojHA0?nV4@3oYQ400000
0?nV4@0000002@3oYQ43000000@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`03
0?JL3`@0[Jf]1`3fW0l00`000000mY`?0?JL3`030?JL3`8000001@3/UPh2000000D0k9H>0P000003
0>bF3P030:f][@3KRPd0000000@0fhX=00<000000=^:3@3KRPd00P3KRPd3000000T0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;
0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd00000000000030?nT4@030000003oY140oj@A00@0oj@A102][Jd00`3oY1400000000000020?nT
4@030:f][@3oYQ40ojHA00<0ojHA0P0000060?nV4@800000203oYQ4010000000ojHA0?nV4@2][Jd6
0?nV4@8000002@3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000@0ojHA00<00000
0?nV4@0000002@3oYQ43000000@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`07
0?JL3`@0[Jf]0`3fW0l00`000000mY`?0?JL3`030?JL3`8000001@3/UPh2000000H0k9H>0P000002
0>bF3P030:f][@3KRPd0000000D0fhX=00@000000=^:3@3KRPd0fhX=0P0000000`2][Jd0^GD;0000
00070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@000000000000<0oj@A00@000000?nT4@3oY140oj@A0`2][Jd50?nT4@800000
0P3oY1400`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ42000000H0ojHA00D000000?nV4@3oYQ40
ojHA0:f][@060?nV4@8000001P3oYQ45000000P0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000
ojHA000000090?nV4@<00000103oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00/0
mY`?0`2][Jd00`000000mY`?0?JL3`030?JL3`030000003/UPh0k9H>00@0k9H>0P0000060>bF3P80
00000P3/UPh00`2][Jd00000000000050=^:3@040000003KRPd0fhX=0=^:3@8000000P2][Jd00`2i
M@/00000000000050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd<0>nH40030:f][@3lX100o:0@
0100o:0@00<0[Jf]0000000000000`3oY14010000000[Jf]0:f][@2][Jd80?nT4@8000000P3oY140
0`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ42000000H0ojHA00D000000?nV4@3oYQ40ojHA0:f]
[@060?nV4@8000004`3oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40000000T0ojHA0`00
00040?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l00`000000[Jf]0:f]
[@020:f][@030?JL3`000000k9H>00D0k9H>0P0000060>bF3P8000000P3/UPh00`2][Jd000000000
00050=^:3@040000003KRPd0fhX=0=^:3@80000000<0[Jf]0;Ue2`2][Jd00`0000040;Ue2`030:f]
[@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00H0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400;0>nH40030:f][@3lX100o:0@0100o:0@
00<0[Jf]0000000000000`2][Jd00`000000oj@A0?nT4@090?nT4@8000000P3oY1400`2][Jd0ojHA
0?nV4@030?nV4@800000203oYQ42000000@0ojHA00D000000?nV4@3oYQ40ojHA0:f][@070?nV4@80
00004`3oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40000000P0ojHA0P0000000`3oYQ40
00000?nV4@030?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l00`000000
mY`?0?JL3`020?JL3`80000000<0[Jf]0>bF3P3/UPh00`3/UPh2000000H0k9H>0P0000020>bF3P03
0:f][@000000000000D0fhX=00@000000=^:3@3KRPd0fhX=0P0000000`2][Jd0^GD;0;Ue2`020000
00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00`0kiP@00<0[Jf]
0?bP403lX1003`3lX1020:f][@8000000`3oY1400`000000oj@A0?nT4@090?nT4@8000000P3oY140
0`2][Jd0ojHA0?nV4@030?nV4@8000002P3oYQ44000000@0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42
000001<0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA000000080?nV4@80000000<0ojHA
0000003oYQ400`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00h0mY`?00<00000
0?JL3`3fW0l00P3fW0l2000000040>bF3P2][Jd0[Jf]0:f][@80k9H>0P0000060>bF3P8000000P3/
UPh00`2][Jd00000000000050=^:3@040000003KRPd0fhX=0=^:3@80000000<0[Jf]0;Ue2`2iM@/0
0P0000000`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo
001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h00`2][Jd0dhL>0=>73P020=>73P030:f]
[@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@040?bP402][Jd00000000000<0
oj@A00<000000?nT4@3oY1402@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ400`3oYQ4200000180
ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000001<0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000
ojHA000000080?nV4@80000000<0ojHA0000003oYQ400`3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?00l0mY`?00@000000?JL3`3fW0l0mY`?0P0000040>bF3P80[Jf]00<0k9H>0000
003/UPh01@3/UPh200000080k9H>00<0[Jf]0000000000001@3KRPd200000080fhX=0P0000000`2]
[Jd0^GD;0;Ue2`02000000060;Ue2`2][Jd0^GD;0;Ue2`000000[Jf]1028EPL20:f][D80/>3V0@3o
ool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0dhL>00<0dhL>00<0
[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]103lX10200000080oj@A0`00
000;0?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@030?nV4@8000004P3oYQ400`2][Jd0ojHA0?nV
4@050?nV4@8000004`3oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40000000P0ojHA0P00
00000`3oYQ4000000?nV4@030?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3f
W0l010000000mY`?0?JL3`3fW0l2000000H0k9H>00<0[Jf]0000002][Jd01@3/UPh200000080k9H>
00<0[Jf]0000000000001@3KRPd200000080fhX=0P0000000`2][Jd0@FWQ0;Ue2`0200000080^GD;
00@0[Jf]000000000000[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0
Uf0;0:f][@3CQ`h20:f][@H0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40070?bP
40<0[Jf]1P3lX10400000080oj@A00<000000?nT4@3oY1402@3oY14200000080oj@A00<0[Jf]0?nV
4@3oYQ401000000C0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000C0?nV4@030:f][@3oYQ40ojHA
00T0ojHA00<000000?nV4@000000203oYQ42000000030:f][@000000[Jf]02X0[Jf]5`3oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l01000
0000mY`?0?JL3`3fW0l2000000L0k9H>00<000000>bF3P2][Jd00P2][Jd20>bF3P8000000P3/UPh0
0`2][Jd00000000000050=^:3@8000000P3KRPd2000000030:f][@2iM@/0^GD;008000000`2iM@/2
000000030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP040:f][@2GH0/0Uf0;
09MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd9
0?bP40800000103oY1400`000000oj@A0?nT4@090?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000C0?nV4@030:f][@3oYQ40ojHA00D0ojHA102][Jd0
0`000000[Jf]000000080:f][@80000000<0ojHA0000003oYQ400`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`040000003fW0l0mY`?0?JL3`8000001`3/
UPh00`000000k9H>0>bF3P020>bF3P80[Jf]0P0000020>bF3P030:f][@000000000000D0fhX=0P00
00020=^:3@80000000<0[Jf]0;Ue2`2iM@/00P0000020;Ue2`80000000<0^GD;00000028EPL01028
EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3C
Q`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd<0?bP40800000103o
Y1400`000000oj@A0?nT4@070?nT4@<000000`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA00D0ojHA0P00000?0?nV4@`0[Jf]103oYQ400`000000ojHA000000080?nV4@80000000<0
ojHA0000003oYQ400`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01D0ojD@302]
[JdH0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l010000000mY`?0?JL
3`3fW0l2000000L0k9H>00<000000>bF3P3/UPh0103/UPh2000000030:f][@3/UPh0[Jf]00800000
1@3KRPd2000000<0fhX=0P000000102][Jd0^GD;0000000000020;Ue2`80000000@0^GD;0000002]
[Jd000000`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080
[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]3P3lX102000000@0
oj@A00<000000?nT4@3oY1403@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00D0
ojHA0P0000050?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40000000P0
ojHA00<000000?nV4@0000001@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0>0?JL3`040000003fW0l0mY`?0?JL3`8000001`3/UPh00`000000k9H>0>bF3P040>bF
3P80000000<0k9H>0:f][@2][Jd00P0000060=^:3@040000003KRPd0fhX=0=^:3@80000000@0[Jf]
0;Ue2`00000000000P2iM@/2000000050;Ue2`000000[Jf]08QF1`0000000P28EPL00`2][Jd0/>3V
0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080[Jf]203CQ`h00`2][Jd0kiP@0>nH
400;0>nH4080[Jf]4@3lX102000000@0oj@A00<000000?nT4@3oY1403@3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA0`2][Jd2000000D0[Jf]103oYQ400`000000ojHA0?nV
4@070?nV4@030:f][@3oYQ40ojHA00T0ojHA00<000000?nV4@000000203oYQ400`000000ojHA0000
00050?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00l0mY`?00D0
00000?JL3`3fW0l000000:f][@070>bF3P8000001@3/UPh200000080k9H>00@0[Jf]000000000000
[Jf]1@3KRPd010000000fhX=0=^:3@3KRPd2000000040:f][@2iM@/0000000000080^GD;0P000000
102iM@/000000000002][Jd20000000308QF1`2][Jd0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00T0kiP@0`2][JdB0?bP40800000103o
Y1400`000000oj@A0?nT4@020?nT4@030000003oY140oj@A00P0oj@A00<0[Jf]0?nV4@3oYQ40503o
YQ480:f][@<0ojHA0P0000080?nV4@8000002@3oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003o
YQ40000000T0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AL0o:0@00<0[Jf]0?JL3`3fW0l03`3f
W0l01@000000mY`?0?JL3`000000[Jf]00L0k9H>0P0000050>bF3P8000000P3/UPh0102][Jd0fhX=
0000000000020:f][@<0fhX=00@000000=^:3@3KRPd0fhX=0P000000102][Jd0^GD;0;Ue2`000002
0;Ue2`80000000P0^GD;0:f][@000000R5H700000028EPL000000:f][D80/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]000000000000103oY1400`000000oj@A0?nT4@020?nT4@03
0000003oY140oj@A00P0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ460:f][@<0ojHA00<0[Jf]0?nV4@3o
YQ401@3oYQ42000000P0ojHA00<000000?nV4@000000203oYQ400`2][Jd0ojHA0?nV4@090?nV4@03
0000003oYQ40000000T0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX1070:f]
[A00o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l01P000000mY`?0?JL3`000000mY`?0:f][@H0k9H>00<0
00000>bF3P0000000`3/UPh2000000<0k9H>00@0[Jf]0=^:3@00000000000P3KRPd20:f][@030=^:
3@000000fhX=0080fhX=0P000000102][Jd0^GD;0;Ue2`0000020;Ue2`80000000P0^GD;0:f][@00
0000R5H70000002][Jd000000:f][D80/>3V0@3oool005T0/>3V0P2][Jd209MP2`030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd00000000000040?nT4@030000003oY140oj@A0080oj@A00<000000?nT4@3oY140203oY140
0`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42
000000T0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ4600000100ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100203lX106
0:f][@X0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l01P000000mY`?0?JL3`000000mY`?0:f][@@0k9H>
00D000000>bF3P000000k9H>000000030>bF3P8000000`3/UPh0102][Jd0@FWQ0000000000040=^:
3@8000000`3KRPd2000000040:f][@2iM@/0^GD;00000080^GD;0P0000001P2iM@/0[Jf]00000028
EPL000000:f][@800000@P2`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@00
0000000000T0oj@A00<000000?nT4@3oY140203oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA
00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA00<000000?nV4@3oYQ401`3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1`2][Jd30?bP40030:f][@3fW0l0mY`?00l0mY`?
00H000000?JL3`00000000000?JL3`2][Jd50>bF3P8000000P3/UPh010000000k9H>0>bF3P000004
0>bF3P040:f][@3KRPd00000000000@0fhX=0P0000020:f][@040=^:3@00000000000:f][@80^GD;
00<000000;Ue2`2iM@/00P0000001P2iM@/0[Jf]00000028EPL0000008QF1`800000@P2`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd8
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]000000000000203oY142000000T0oj@A1@2][JdF
0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000C0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1005@3lX1060:f][@l0mY`?00H000000?JL3`00000000000?JL3`2][Jd90>bF3P<00000
1@3/UPh0102][Jd0fhX=0000000000040=^:3@8000000P3KRPd0102][Jd000000000002][Jd20;Ue
2`030000002iM@/0^GD;0080000000T0^GD;0:f][@000000R5H700000028EPL000000:f][@000000
@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f]
[@2][Jd:0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]000000000000203oY142000000D0oj@A
102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA1@00000C0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][@`0mY`?
0`0000000`3fW0l0[Jf]0>bF3P0@0>bF3P030:f][@3KRPd0fhX=008000000`3KRPd2000000<0fhX=
0P000000102][Jd0^GD;0;Ue2`0000020;Ue2`8000000P2iM@/30000000408QF1`000000[Jf]0000
0440/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>0P2][Jd<0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]000000000000203oY142000000030?nT4@2][Jd0[Jf]0080
[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd70?JL3`<0
000000<0mY`?0:f][@3/UPh0403/UPh00`2][Jd0fhX=0=^:3@02000000<0fhX=0P0000030=^:3@80
00000P2][Jd0102iM@/000000;Ue2`2iM@/200000080^GD;0`0000001028EPL000000:f][@000011
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P80[Jf]3@3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@000000000000L0oj@A00@0[Jf]0000002][Jd0[Jf]2@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd20?JL3`<0000000<0mY`?
0:f][@3/UPh0403/UPh01@2][Jd0fhX=0=^:3@3KRPd000000080fhX=0P0000040=^:3@80000000@0
[Jf]0;Ue2`2][Jd000000P2iM@/200000080^GD;0`0000001028EPL000000:f][@0000110;3PiP40
oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P040=>73P030:f][@3CQ`h0[Jf]00d0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd00000000000030?nT4@@0[Jf]00<0oj@A0000003oY140
2P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00h0mY`?0P2][Jd3000000030?JL
3`2][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3KRPd00P0000000`3KRPd00000000000040=^:3@800000
00H0[Jf]0;Ue2`2iM@/000000:f][@2iM@/200000080^GD;0`0000001028EPL000000:f][@000011
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P030=>73P040:f][@3CQ`h0dhL>
0:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd00000000000030:f][@D0oj@A00<00000
0?nT4@3oY1402@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0100mY`?0P000004
0:f][A40k9H>00@0[Jf]0=^:3@3KRPd0fhX=0`0000050=^:3@80000000H0[Jf]0;Ue2`2iM@/00000
0;Ue2`2][Jd200000080^GD;0`0000000`28EPL000000:f][@0200000400/>3V0@3oool005P0/>3V
0P2][Jd309MP2`040:f][@3CQ`h0dhL>0=>73P80[Jf]0`3CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00h0o:0@0P2][Jd2000000L0oj@A0P00000;0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0403fW0l200000080mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P03
0:f][@3KRPd0fhX=00T0fhX=0P0000000`2][Jd0^GD;0;Ue2`02000000030;Ue2`00000000000080
^GD;0`0000000`28EPL000000:f][@0200000400/>3V0@3oool005L0/>3V00<000000:f][@2][Jd0
0`2GH0/0102][Jd0dhL>0=>73P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100303lX1020:f][@040?bP402][Jd00000000000L0oj@A0P00000;0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04@3fW0l010000000mY`?0?JL3`2][Jd40>bF3P80[Jf]303/UPh0
0`2][Jd0fhX=0=^:3@090=^:3@80000000<0[Jf]0;Ue2`2iM@/00P0000020;Ue2`030000002][Jd0
^GD;00<0000000<0R5H70000002][Jd00P0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]
00<0Uf0;00<0[Jf]0=>73P2][Jd01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00T0o:0@0`2][Jd30?bP40030:f][@000000000000L0oj@A0P00000;0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04@3fW0l010000000mY`?0?JL3`2][Jd60>bF3P<0[Jf]2@3/UPh0
0`2][Jd0fhX=0=^:3@090=^:3@80000000<0[Jf]0;Ue2`2iM@/00P0000020;Ue2`030000002iM@/0
[Jf]0080000000<0R5H700000028EPL00`0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]
00<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f]
[@H0o:0@00<0[Jf]0000000000001P3oY143000000/0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`0A0?JL3`040000003fW0l0mY`?0:f][@T0k9H>0`2][Jd60>bF3P030:f][@3KRPd0
fhX=00T0fhX=0P0000000`2][Jd0^GD;0;Ue2`0200000080^GD;00<000000;Ue2`2iM@/00P000000
0`28EPL0000008QF1`0300000400/>3V0@3oool005L0/>3V00<000000:f][@2GH0/00`2GH0/00`2]
[Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f]
[@P0o:0@00<0[Jf]0000000000000P3oY144000000d0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0A0?JL3`040000003fW0l0mY`?
0:f][@`0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00T0fhX=0P0000000`2][Jd0^GD;0;Ue2`02
00000080^GD;00<000000;Ue2`2iM@/00P0000000`28EPL0000008QF1`0300000400/>3V0@3oool0
05L0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V100303_V100102]
[Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0000000000000P00000A0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@
0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00X0fhX=0P000000
0`3KRPd0[Jf]0;Ue2`0200000080^GD;00<000000;Ue2`2iM@/00P0000000`28EPL0000008QF1`03
00000400/>3V0@3oool005L0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@L0dhL>00<0[Jf]0>nH
403_V100303_V100102][Jd0o:0@0:f][@2][Jd=0?bP408000005@3oY1400`2][Jd0ojHA0?nV4@0H
0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@X0fhX=0P000000
0`3KRPd0[Jf]0;Ue2`02000000<0^GD;00L000000;Ue2`00000000000:f][@000000R5H700<00000
@02`h>H10?ooo`00E`2`h>H01`000000[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd01`3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f]
[@T0fhX=0P000000102][Jd0^GD;0000000000030;Ue2`070000002iM@/000000000002][Jd00000
08QF1`0300000400/>3V0@3oool005L0/>3V00@000000:f][@2GH0/0[Jf]0P2GH0/00`2][Jd0dhL>
0=>73P050=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]
P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f]
[@3KRPd0fhX=0=^:3@80[Jf]1`3KRPd2000000040:f][@2iM@/00000000000<0^GD;00<000000;Ue
2`0000000P28EPL00`000000R5H70000000200000400/>3V0@3oool005L0/>3V00@000000:f][@2G
H0/0[Jf]0P2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd30>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV
4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd50=^:3@80000000@0[Jf]0;Ue2`0000000000102iM@/2
00000080R5H700D000000:f][@000000[Jf]000000100;3PiP40oooo001G0;3PiP030000002][Jd0
[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ47
0:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@050=^:3@80[Jf]0`3KRPd2000000040:f][@2iM@/0^GD;000000@0^GD;00T0
00000:f][@28EPL0R5H70000002][Jd000000:f][@000000@02`h>H10?ooo`00E`2`h>H00`000000
[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@L0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0
ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@040=^:3@00000000000:f][@80^GD;00<000000;Ue
2`2iM@/00`2iM@/0202][Jd0R5H708QF1`000000R5H70000002][Jd00000@02`h>H10?ooo`00E`2`
h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00D0dhL>00@0[Jf]0>nH403_V100kiP@
0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA
0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@040:f][@00000000000:f][@80^GD;00<000000;Ue
2`2iM@/0102iM@/00`2][Jd0R5H700000002000000030:f][@000000/>3V03l0/>3V0@3oool005L0
/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f]
[@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f]
[AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80000000@0[Jf]0;Ue
2`2iM@/000001P2iM@/00`2][Jd0R5H700000002000000030:f][@000000/>3V03l0/>3V0@3oool0
05H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd=0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd2000000<0[Jf]00<000000;Ue2`2iM@/0102iM@/0
0`2][Jd0R5H700000002000000030:f][@000000000003l0/>3V0@3oool005H0/>3V0P0000001@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00L0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd02P3KRPd2000000040:f][@2iM@/0^GD;000000H0^GD;00H0[Jf]08QF1`000000R5H7
00000011JN42000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/00`2][Jd0dhL>
0=>73P030=>73P80[Jf]00<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f]
[@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=00P0fhX=0`0000001@2][Jd0^GD;0;Ue2`000000[Jf]00D0^GD;00H0[Jf]08QF1`28
EPL0R5H700000011JN42000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/00`2]
[Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@
0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
0`2][Jd0fhX=0=^:3@090=^:3@80000000D0[Jf]0;Ue2`2iM@/000000;Ue2`020:f][@<0^GD;00H0
[Jf]08QF1`28EPL0R5H700000011JN42000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd0
0`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0
^GD;0;Ue2`0000030;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H700@0[Jf]045Yh@0000000000?`2`
h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`040:f][@3CQ`h0[Jf]0:f][@D0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0000000000040;Ue2`<0[Jf]0`28EPL0102][Jd0@FWQ
00000000000o0;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;0P2][Jd70=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]
00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0000
00H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3PiP03
0000002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0[Jf]00000000
0000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]203CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]
kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][@<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP
2`0209MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2]
[Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33
_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H70:f][@0208QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00L00000
0:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V
0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@000000000003l0/>3V
0@3oool005D0/>3V0P0000000`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL0R5H70:f][@28EPL0
[Jf]0P00000o0;3PiP40oooo001E0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>
0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][@800000?`2`h>H10?ooo`00E@2`h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>
0=>73P060=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H7
08QF1`28EPL0[Jf]045Yh@800000?`2`h>H10?ooo`00E@2`h>H200000080[Jf]0`2GH0/00`2][Jd0
dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f]
[@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f]
[@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H7
0080R5H70P2][Je00;3PiP40oooo001E0;3PiP80000000<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080[Jf]00D0Y9j?045Yh@2TWXl0Y9j?0:f][@04
0;6[W@80[Jf]1`2aZid00`2][Jd0@FWQ045Yh@0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je00;3PiP40oooo001E
0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P040:f][@3_V100[Jf]0:f][@80@FWQ
0P2TWXl2045Yh@030:f][@2aZid0/J^M00@0/J^M0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00<0@FWQ
2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]
3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0
_[Vh0P2][Jd80;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/01P2]
[Jd0R5H708QF1`28EPL0[Jf]00000400/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/0
0`2][Jd0dhL>0=>73P070=>73P80[Jf]0P2TWXl2045Yh@<0Y9j?0P11JN480;6[W@80[Jf]0`2aZid0
0`2][Jd0^K:V0;VbYP02045Yh@`0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;
0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=
0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][@X0^GD;00H0
[Jf]08QF1`28EPL0R5H70:f][@0000100;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;
00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0@FWQ0:BNS`020:BNS`80@FWQ0`2TWXl00`11JN40[Jf]
0;6[W@090;6[W@80[Jf]00@0/J^M0:f][@2i/ZH0^K:V0P11JN4<0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0
];2a0;B`/@050;B`/@80[Jf]202iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]00800000?`2`h>H10?oo
o`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd00`11JN40
Y9j?0:BNS`020:BNS`80@FWQ0`2TWXl00`11JN40[Jf]0;6[W@0;0;6[W@<0[Jf]00<0^K:V045Yh@11
JN40302i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33
_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`
/@2d/;401@2d/;42045Yh@030:f][@2iM@/0^GD;00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd0
0`000000/>3V0;3PiP0m0;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>7
3P3CQ`h00`3CQ`h0102][Jd0@FWQ0:f][@11JN440:BNS`80@FWQ0`2TWXl00`11JN40/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0[Jf]0080@FWQ00<0[Jf]0;VbYP2i/ZH02@2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`06
0<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00@0];2a0P11JN40
0`2d/;40[Jf]0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`
h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>0080dhL>00D0[Jf]
08Z5M@11JN40[Jf]045Yh@040:BNS`80@FWQ0`2TWXl00`11JN40/J^M0;6[W@050;6[W@@0@FWQ0`2a
Zid00`2][Jd0^K:V0;VbYP02045Yh@040;VbYP2][Jd0[Jf]0:f][@P0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]
4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
0P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@040;B`/@80@FWQ
1@2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`000000/>3V
0:f][@0309MP2`0;0:f][@3CQ`h0dhL>0=>73P2][Jd0@FWQ08Z5M@11JN40[Jf]045Yh@2][Jd00P2T
WXl3045Yh@<0Y9j?00<0@FWQ0;6[W@2aZid0102aZid2045Yh@80/J^M00D0@FWQ0;6[W@2aZid0/J^M
0:f][@020;VbYP80@FWQ102i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V
302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f]
[@2d/;40];2a00@0];2a0P11JN420;B`/@040:f][@11JN40Wi^P0:f][@80^GD;00@0[Jf]08QF1`28
EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00@0[Jf]0=>73P2]
[Jd0[Jf]0P11JN401P2:QGD0@FWQ0:f][@11JN40Y9j?0:f][@80Y9j?0P11JN430:BNS`03045Yh@2a
Zid0/J^M00@0/J^M0P11JN430;6[W@@0@FWQ0P2i/ZH2045Yh@L0^K:V102][Jd00`2i/ZH0[Jf]0;jg
[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0
[Jf]0;B`/@2d/;400`2d/;400`2][Jd0@FWQ045Yh@020;B`/@040:f][@11JN40@FWQ045Yh@<0[Jf]
1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;00<0Uf0;0P2]
[Jd308Z5M@05045Yh@2:QGD0@FWQ0:f][@11JN400P2TWXl20:f][@80Y9j?00@0@FWQ0:BNS`2TWXl0
@FWQ1P2aZid2045Yh@<0/J^M0`11JN400`2][Jd0^K:V0;VbYP02045Yh@/0^K:V0`2][JdA0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0
[Jf]0<>m^`0:0<>m^`05045Yh@33_K/0`kfk0<>m^`2][Jd03P2n^KP0102][Jd0];2a0;B`/@2d/;42
0:f][@80];2a00D0@FWQ0;B`/@2d/;40[Jf]045Yh@0409nKX0030:f][@28EPL0R5H70080R5H700<0
[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@2:QGD0
RXEe00<0RXEe0P11JN400`2][Jd0@FWQ0:BNS`030:BNS`80[Jf]0P2TWXl00`11JN40[Jf]0;6[W@05
0;6[W@80@FWQ102aZid00`11JN40/J^M0:f][@020;VbYP80@FWQ00<0^K:V045Yh@11JN402@2i/ZH0
0`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]
0<>m^`33_K/02033_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`/@2]
[Jd40;B`/@05045Yh@2d/;40];2a0:f][@11JN401@2OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400
/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@H0RXEe0`11JN460:BNS`040:f]
[@2TWXl0@FWQ045Yh@H0/J^M0P11JN440;6[W@03045Yh@2aZid0[Jf]0080^K:V0`11JN400`2i/ZH0
@FWQ045Yh@080;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0140
`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0
a/2l102][Jd90<K0_0030:f][@33_K/0`kfk0080`kfk0P11JN450<>m^`03045Yh@33_K/0`kfk0080
`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][@D0];2a00D0@FWQ0;B`/@2d/;40[Jf]045Yh@0509nK
X0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/2
0:f][@L0RXEe00<0[Jf]045Yh@2TWXl01P2TWXl00`2][Jd0@FWQ045Yh@060;6[W@80@FWQ102aZid0
0`11JN40/J^M0:f][@020;VbYP80@FWQ0`2i/ZH2045Yh@L0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`4
0:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@11JN40`kfk0080@FWQ0P33_K/0
0`11JN40`kfk0<>m^`070<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd70;B`/@05045Yh@2d/;40
];2a0:f][@11JN401P2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2G
H0/0Uf0;00<0[Jf]1`2:QGD00`2][Jd0@FWQ0:BNS`070:BNS`80@FWQ00<0[Jf]0;6[W@2aZid0102a
Zid00`11JN40/J^M0;6[W@020;6[W@04045Yh@2aZid0[Jf]0;VbYP<0@FWQ0`2i/ZH2045Yh@@0^K:V
0`11JN400`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][JdA0<K0_0030:f][@11JN40@FWQ00@0`kfk
00<0@FWQ0<>m^`33_K/01`33_K/00`2][Jd0_[Vh0;ji^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;40
1P2d/;401@11JN40];2a0;B`/@2][Jd0@FWQ00H0Wi^P0P2][Jd00`28EPL0[Jf]0;3PiP0o0;3PiP40
oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]1P2:QGD00`2][Jd00000045Yh@080:BNS`80
@FWQ00<0/J^M0:f][@2][Jd0102aZid00`11JN40/J^M0;6[W@020;6[W@04045Yh@2aZid0[Jf]0;Vb
YP80@FWQ1@2i/ZH2045Yh@D0^K:V0`11JN420;jg[003045Yh@2n]j`0_[N/00/0_[N/102][JdA0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0@FWQ0<>m^`040<>m^`03045Yh@33_K/0`kfk00L0`kfk00<0[Jf]0;ji
^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;401@11JN40];2a0;B`/@2][Jd0
@FWQ00H0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]
08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?045Yh@080:BNS`80@FWQ0`2aZid30:f][@80/J^M00P0@FWQ
0;6[W@2aZid0/J^M045Yh@2aZid0[Jf]0;VbYP80@FWQ1@2i/ZH2045Yh@D0^K:V00<0@FWQ0:f][@2n
]j`00`2n]j`2045Yh@`0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00L0
b<6k1P11JN460<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00P0
a/2l1011JN440<K0_0030:f][@11JN40`kfk00@0`kfk0P11JN480<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00D0];2a0P11JN400`2d/;40[Jf]045Yh@0509nKX080
[Jf]00<0L6ii0:f][@2][Jd0@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f]
[@2TWXl0@FWQ00P0Y9j?0P11JN420;6[W@04045Yh@2aZid0/J^M0;6[W@80[Jf]00P0/J^M045Yh@2a
Zid0/J^M045Yh@2aZid0[Jf]0;VbYP80@FWQ1@2i/ZH2045Yh@D0^K:V00<0@FWQ0:f][@2n]j`0102n
]j`3045Yh@80_[N/0`11JN450;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k00T0b<6k0P11JN480<S1^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0
_0070<K0_003045Yh@36`;`0a/2l0080a/2l00H0@FWQ0<K0_036`;`0a/2l0:f][@11JN450<>m^`80
@FWQ2033_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;42045Y
h@030;B`/@2][Jd0@FWQ00@0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0
/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@040:f][@2TWXl0@FWQ045Y
h@<0Y9j?00<0@FWQ0:BNS`2TWXl00P11JN40102][Jd0@FWQ0;6[W@11JN450;6[W@80[Jf]00H0@FWQ
0;6[W@11JN40/J^M0:f][@2i/ZH2045Yh@D0^K:V0P11JN450;VbYP03045Yh@2n]j`0_[N/00@0_[N/
00<0@FWQ0;jg[02n]j`0102n]j`4045Yh@80_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@D0b<6k1P2][JdA0<O1_0030:f][@36`;`0@FWQ0080@FWQ
1036`;`2045Yh@D0a/2l00D0@FWQ0<K0_036`;`0[Jf]045Yh@040<>m^`80@FWQ1033_K/00`11JN40
`kfk0<>m^`020<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;42045Y
h@030;B`/@11JN40Wi^P00<0Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@040:f][@2TWXl0
@FWQ045Yh@<0Y9j?00P0@FWQ0:BNS`2TWXl0Y9j?045Yh@2][Jd0@FWQ0;6[W@80@FWQ0P2aZid2045Y
h@<0/J^M0P11JN400`2aZid0[Jf]0;VbYP02045Yh@D0^K:V0P11JN450;VbYP03045Yh@2n]j`0_[N/
00@0_[N/00<0@FWQ0;jg[02n]j`0102n]j`2045Yh@@0_[N/00<0[Jf]0<6j/031^[003`31^[080:f]
[A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
00T0b<6k0P11JN450:f][@<0b<6k00<0[Jf]0<O1_037`K`03037`K`3045Yh@80al6l0`11JN450<K0
_080@FWQ2@36`;`00`2][Jd0`kfk0<>m^`030<>m^`80@FWQ1033_K/01011JN40`kfk0<>m^`33_K/3
0:f][@`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;42045Yh@040;B`/@11JN40Wi^P09nKX080[Jf]0`2O
Vj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0
1@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00@0[Jf]0:BNS`11JN40@FWQ0`2TWXl00`11JN40Y9j?
0:BNS`020:BNS`050:f][@2aZid0@FWQ0;6[W@11JN400P2aZid2045Yh@@0/J^M00@0@FWQ0:f][@2]
[Jd0[Jf]0P11JN450;VbYP80@FWQ1@2i/ZH00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/
00@0_[N/0P11JN440;jg[0030:f][@31^[00`KZ`00<0@FWQ3P31^[000`2][Jd0`kfc0<>m/`030<>m
/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1
^`38`K/0b<6k202][Jd2045Yh@P0b<6k00<0[Jf]0<O1_037`K`02@37`K`4045Yh@@0al6l00<0[Jf]
0<K0_011JN401@36`;`2045Yh@T0a/2l00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@D0`kfk00H0@FWQ
0:f][@2][Jd0[Jf]0<>m^`2][Jd=0;ji^0030:f][@2d/;40];2a00D0];2a0`11JN400`2][Jd0Wi^P
0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd00P2TWXl01@11JN40Y9j?0:BN
S`2TWXl0@FWQ00@0Y9j?00@0[Jf]0;6[W@2aZid0@FWQ0`2aZid00`11JN40/J^M0;6[W@030;6[W@04
045Yh@2aZid0[Jf]0;VbYP80@FWQ00<0[Jf]0;VbYP2i/ZH00P2i/ZH2045Yh@D0^K:V00<0@FWQ0;jg
[02n]j`0102n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ102n]j`0102][Jd0@FWQ045Yh@11JN42
0<6j/003045Yh@31^[00`KZ`00/0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/03`38`K/90:f][@P0b<6k0P11JN480<S1^`030:f][@37`K`0al6l00<0al6l1011JN44
0<O1_080@FWQ1037`K`00`2][Jd0a/2l045Yh@050<K0_080@FWQ2@36`;`0102][Jd0`kfk0<>m^`33
_K/2045Yh@@0`kfk0P2][Jd00`11JN40`kfk0<>m^`020<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0
[Jf]0;B`/@2d/;401@2d/;43045Yh@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]0P2TWXl0
0`11JN40Y9j?0:BNS`02045Yh@@0Y9j?00<0[Jf]0;6[W@2aZid01@2aZid00`11JN40/J^M0;6[W@02
0;6[W@04045Yh@2aZid0[Jf]0;VbYP80@FWQ00D0^K:V0:f][@2][Jd0[Jf]0;VbYP02045Yh@D0^K:V
00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ102n]j`2045Yh@D0`KZ`
00<0@FWQ0<6j/031^[001031^[000`11JN40`KZ`0<6j/002045Yh@030<6j/02][Jd0`kfc01@0`kfc
00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k
00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@P0b<6k00@0[Jf]0<O1_037`K`0al6l1011JN460<O1_080
@FWQ1037`K`00`2][Jd0a/2l045Yh@040<K0_080@FWQ2P36`;`00`2][Jd0`kfk0<>m^`02045Yh@<0
`kfk0P2][Jd20<>m^`03045Yh@33_K/0`kfk0080`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0
];2a0;B`/@050;B`/@80@FWQ00<0];2a0:f][@2OVj001P2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]
03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@06
0:f][@2TWXl0Y9j?0:BNS`11JN40Y9j?0P11JN440:BNS`030:f][@2aZid0/J^M00H0/J^M00@0@FWQ
0;6[W@2aZid0@FWQ0P2aZid0102][Jd0^K:V045Yh@11JN440;VbYP040:f][@11JN40@FWQ0:f][@@0
^K:V00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@H0_[N/0P11JN430;jg[0030:f][@11JN40@FWQ00D0
`KZ`00<0@FWQ0<6j/031^[001031^[03045Yh@80`KZ`0P11JN4E0<>m/`030:f][@35_[D0aKje00l0
aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40
b<6k00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@80b<6k0`11JN430<S1^`030:f][@37`K`0al6l00<0
al6l0P11JN460<O1_080@FWQ1037`K`00`2][Jd0a/2l045Yh@040<K0_080@FWQ2P36`;`01@2][Jd0
`kfk045Yh@11JN40`kfk00<0[Jf]00D0@FWQ0<>m^`33_K/0`kfk045Yh@040<>m^`030:f][@2n^KP0
_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;40102d/;400`11JN40];2a0:f][@020:f][@L0Wi^P00D0[Jf]
071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:
QGD30:f][@80Y9j?00<0@FWQ0:BNS`11JN40102TWXl00`2][Jd0/J^M0;6[W@070;6[W@80@FWQ0`2a
Zid0102][Jd0^K:V045Yh@11JN450;VbYP03045Yh@2i/ZH0^K:V00<0[Jf]00<0^K:V045Yh@2n]j`0
102n]j`2045Yh@H0_[N/0P11JN430;jg[0030:f][@11JN40@FWQ00H0`KZ`00<0@FWQ0<6j/031^[00
0`31^[000`11JN40`KZ`0<6j/0030<6j/0030:f][@11JN40`kfc00D0`kfc00<0@FWQ0<>m/`33_K<0
2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng<02][Jd;0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01@38`K/01011JN40b<6k0<S1^`38`K/2045Yh@04
0<S1^`11JN40b<6k0<S1^`<0@FWQ00<0b<6k0:f][@37`K`01037`K`2045Yh@H0al6l0P11JN440<O1
_0030:f][@36`;`0@FWQ00@0a/2l0P11JN4:0<K0_0030:f][@33_K/0@FWQ0080[Jf]0`33_K/01@11
JN40`kfk0<>m^`33_K/0@FWQ00@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@05
0;B`/@040:f][@2d/;40];2a0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo
001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@80Y9j?
00<0@FWQ0:BNS`2TWXl00P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0@FWQ0080@FWQ
102i/ZH00`11JN40^K:V0;VbYP030;VbYP030:f][@11JN40[Jf]00@0_[N/0P11JN460;jg[080@FWQ
0`2n]j`2045Yh@d0`KZ`00<0@FWQ0<6j/031^[000`31^[000`2][Jd0`kfc045Yh@040<>m/`03045Y
h@33_K<0@FWQ00`0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`<0@FWQ
1038`K/00`11JN40b<6k0<S1^`020<S1^`<0@FWQ1038`K/2045Yh@030<S1^`2][Jd0al6l00@0al6l
0P11JN460<O1_080@FWQ1037`K`00`2][Jd0a/2l045Yh@040<K0_080@FWQ1P36`;`00`11JN40a/2l
0:f][@020:f][@80@FWQ1033_K/2045Yh@<0`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0_[Vh
0;ji^00;0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0
RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]045Yh@11JN400P11JN430;VbYP03045Yh@2i/ZH0^K:V00D0^K:V00<0@FWQ0;jg[02]
[Jd00`2][Jd2045Yh@H0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@d0`KZ`00<0@FWQ0<6j/031
^[000`31^[000`2][Jd0`kfc045Yh@050<>m/`03045Yh@33_K<0`kfc00/0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ00<0[Jf]0<S1^`38`K/00P11JN400`38`K/0
@FWQ045Yh@040<S1^`80@FWQ1P38`K/2045Yh@030:f][@37`K`0al6l00<0al6l0P11JN460<O1_080
@FWQ1037`K`00`2][Jd0a/2l045Yh@040<K0_080@FWQ0`36`;`30:f][@80@FWQ0P36`;`00`2][Jd0
@FWQ0<>m^`040<>m^`80@FWQ0`33_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0
];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je0
0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl2
0:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid01`2][Jd0^K:V045Yh@11JN40^K:V045Yh@2i/ZH0
0P11JN460;VbYP80@FWQ1@2n]j`2045Yh@80[Jf]102n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ
4`31^[000`2][Jd0`kfc045Yh@0C0<>m/`030:f][@35_[D0aKje00T0aKje2@11JN420<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P040:f]
[@38`K/0b<6k0<S1^`H0@FWQ2P38`K/2045Yh@030<S1^`2][Jd0b<6k0080b<6k0`11JN450<S1^`80
@FWQ1P38`K/2045Yh@030:f][@37`K`0al6l00<0al6l0P11JN460<O1_080@FWQ1037`K`0102][Jd0
a/2l045Yh@11JN430<K0_080@FWQ0`2][Jd30<K0_080@FWQ0P36`;`00`2][Jd0@FWQ0<>m^`040<>m
^`80@FWQ0`33_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][Jd7
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H0
0`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0
/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH2045Yh@L0^K:V0P11JN450;jg[080@FWQ0P2n]j`4
0:f][@03045Yh@2n]j`0_[N/0080_[N/0P11JN4C0<6j/0030:f][@33_K<0@FWQ01<0`kfc00<0[Jf]
0<Fn]@35_[D02`35_[D2045Yh@@0aKje0P11JN400`35_[D0[Jf]0<Jo]`040<Jo]`L0@FWQ2`36_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0@FWQ00d0al6j0`11JN430<O1^P80@FWQ00<0[Jf]
0<S1^`38`K/00`38`K/2045Yh@`0b<6k00@0@FWQ0<S1^`38`K/0[Jf]1038`K/2045Yh@D0b<6k0P11
JN470<S1^`80@FWQ1@37`K`2045Yh@H0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045Yh@<0[Jf]
00<0@FWQ0<K0_011JN401@36`;`2045Yh@80a/2l00<0[Jf]045Yh@33_K/00`33_K/00`11JN40`kfk
045Yh@030<>m^`80@FWQ0`33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P
09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:
QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0@FWQ102n
]j`2045Yh@H0_[N/00D0@FWQ0:f][@2][Jd0[Jf]00000002045YhA<0`KZ`00<0[Jf]045Yh@11JN40
4`33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1@35_[D2045Yh@030:f][@36_kL0a[ng00D0a[ng
0P11JN4>0<Jo]`030:f][@11JN40@FWQ0080@FWQ1@37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP0
0P37`KP00`2][Jd0al6j045Yh@0;0<O1^P80@FWQ0`37`KX2045Yh@040<O1^P11JN40@FWQ0:f][@D0
b<6k0P11JN4<0<S1^`04045Yh@38`K/0b<6k0:f][@@0b<6k0P11JN450<S1^`80@FWQ1`38`K/2045Y
h@D0al6l0P11JN460<O1_080@FWQ0P37`K`40:f][@80@FWQ1036`;`2045Yh@D0a/2l00H0@FWQ0<K0
_036`;`0a/2l0:f][@33_K/5045Yh@D0`kfk0P11JN430<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2]
[Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H2
0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH3
045Yh@@0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`01@11JN40_[N/0;jg[02n]j`0[Jf]0080@FWQ0P2]
[Jd?0<6j/0@0@FWQ5033_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1P35_[D2045Yh@L0a[ng0P11
JN4=0<Jo]`80@FWQ1037`KP2045Yh@030<O1^011JN40@FWQ00P0al6h00<0@FWQ0<O1^037`KP00P37
`KP00`2][Jd0@FWQ045Yh@0:0<O1^P80@FWQ1P37`KX3045Yh@030:f][@38`K/0b<6k00<0b<6k0P11
JN4<0<S1^`04045Yh@38`K/0b<6k0:f][@@0b<6k0P11JN450<S1^`80@FWQ1`38`K/2045Yh@D0al6l
0P11JN450<O1_0030:f][@11JN40@FWQ0080[Jf]0P37`K`0102][Jd0a/2l045Yh@11JN440<K0_080
@FWQ1@36`;`01@11JN40a/2l0<K0_036`;`0[Jf]00/0`kfk0P11JN430<>m^`030:f][@2n^KP0_[Vh
00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3P
iP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080
[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP80@FWQ00<0_[N/045Yh@11JN400P2n]j`00`11JN40
_[N/0;jg[0050;jg[003045Yh@2n]j`0_[N/0080_[N/00@0[Jf]045Yh@31^[00`KZ`1@2][Jd00`11
JN40[Jf]0<6j/0050<6j/0D0@FWQ5@33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1`35_[D2045Y
h@H0a[ng0P11JN4<0<Jo]`80@FWQ00<0[Jf]0<O1^037`KP00`37`KP3045Yh@T0al6h00<0@FWQ0<O1
^037`KP00P37`KP0102][Jd0@FWQ0<O1^P11JN480<O1^P80@FWQ2037`KX2045Yh@030:f][@38`K/0
b<6k00<0b<6k0P11JN4<0<S1^`04045Yh@38`K/0b<6k0:f][@@0b<6k0P11JN450<S1^`80@FWQ1`38
`K/2045Yh@D0al6l0P11JN450:f][@030<O1_011JN40@FWQ00@0al6l00@0[Jf]0<K0_011JN40@FWQ
1036`;`00`11JN40a/2l045Yh@030<K0_003045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/0
2@33_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5
M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0
[Jf]0;VbYP2i/ZH03@2i/ZH2045Yh@<0_[N/0P11JN480;jg[003045Yh@2n]j`0_[N/0080_[N/00<0
[Jf]045Yh@31^[001@31^[02045Yh@030<6j/02][Jd0[Jf]0080[Jf]1011JN420<6j/0030:f][@33
_K<0`kfc00D0`kfc00<0@FWQ0<>m/`33_K<02`33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1`35
_[D2045Yh@H0a[ng0P11JN4<0<Jo]`80@FWQ00<0[Jf]0<O1^037`KP01037`KP2045Yh@P0al6h0`11
JN440<O1^0<0@FWQ2037`KX2045Yh@P0al6j0P11JN400`2][Jd0b<6k0<S1^`030<S1^`80@FWQ3038
`K/01011JN40b<6k0<S1^`2][Jd40<S1^`80@FWQ1@38`K/2045Yh@L0b<6k0P11JN420<O1_0<0[Jf]
0P11JN460<O1_080@FWQ1037`K`0102][Jd0a/2l045Yh@11JN450<K0_0D0@FWQ1@36`;`00`2][Jd0
`kfk0<>m^`090<>m^`80@FWQ0`33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00
F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH2045Yh@d0_[N/00<0@FWQ0;jg[02n]j`0
0P2n]j`00`2][Jd0@FWQ045Yh@060<6j/003045Yh@31^[00`KZ`0080`KZ`0`11JN400`31^[00[Jf]
0:f][@050:f][@@0`kfc00<0@FWQ0<>m/`33_K<02`33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ
1`35_[D00`2][Jd0@FWQ045Yh@050<Jo]`80@FWQ3036_kL2045Yh@030:f][@37`KP0al6h00@0al6h
0P11JN480<O1^0<0@FWQ1037`KP3045Yh@L0al6j0P11JN490<O1^P80@FWQ00<0[Jf]0<S1^`38`K/0
0`38`K/2045Yh@`0b<6k0P11JN400`38`K/0[Jf]0<S1^`030<S1^`80@FWQ1@38`K/2045Yh@D0b<6k
0P2][Jd2045Yh@80[Jf]0`37`K`2045Yh@H0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045YhA00
a/2l00<0[Jf]0<>m^`33_K/02033_K/2045Yh@<0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji
^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3P
iP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0
/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH03P2i/ZH2045Yh@/0_[N/0`11JN440;jg[003
0:f][@31^[00@FWQ00H0`KZ`00<0@FWQ0<6j/031^[000P31^[000`11JN40`KZ`0<6j/0040<6j/004
0:f][@33_K<0@FWQ0<>m/`@0[Jf]00<0@FWQ0:f][@2][Jd02`33_K<00`2][Jd0aKje0<Fn]@0;0<Fn
]@80@FWQ1`35_[D00`2][Jd0@FWQ045Yh@050<Jo]`80@FWQ3036_kL2045Yh@030:f][@37`KP0al6h
00@0al6h0P11JN480<O1^0<0@FWQ0`37`KP2045Yh@030<O1^P11JN40al6j0080al6j0P0000020<O1
^P80@FWQ2@37`KX2045Yh@030:f][@38`K/0b<6k00<0b<6k0P11JN4<0<S1^`80@FWQ00<0b<6k0:f]
[@38`K/00`38`K/2045Yh@D0b<6k0P11JN450:f][@80b<6k00<0@FWQ0:f][@37`K`01@37`K`2045Y
h@D0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045YhA00a/2l00<0[Jf]0<>m^`33_K/02033_K/2
045Yh@<0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2O
Vj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@02
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@h0^K:V0P11JN4B
0;jg[0040:f][@31^[00`KZ`045Yh@@0`KZ`00<0@FWQ0<6j/031^[000`31^[000`11JN40`KZ`0<6j
/0040<6j/0030:f][@33_K<0@FWQ00D0`kfc00<0@FWQ0<>m/`33_K<0202][Jd30<>m/`030:f][@35
_[D0aKje00/0aKje0P11JN470<Fn]@030:f][@11JN40@FWQ00D0a[ng0P11JN4<0<Jo]`80@FWQ00<0
[Jf]0<O1^037`KP01037`KP2045Yh@P0al6h00<0@FWQ0<O1^011JN400`37`KP2045Yh@030<O1^P11
JN40al6j00H0al6j0P11JN490<O1^P80@FWQ00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@h0b<6k2011
JN450:f][@80@FWQ1`38`K/00`11JN40[Jf]0<O1_0050<O1_080@FWQ1@37`K`2045Yh@@0al6l0P11
JN4B0<K0_0030:f][@33_K/0`kfk00T0`kfk00<0@FWQ0<>m^`33_K/00`2][Jd<0;ji^0030:f][@2d
/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD0
0`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd:
0;VbYP80@FWQ4P2n]j`0102][Jd0`KZ`0<6j/031^[05045Yh@D0`KZ`00<0@FWQ0<6j/031^[001031
^[000`2][Jd0@FWQ045Yh@050<>m/`03045Yh@33_K<0`kfc00P0`kfc2@2][Jd80<Fn]@80@FWQ1`35
_[D00`2][Jd0a[ng045Yh@050<Jo]`80@FWQ3@36_kL2045Yh@H0al6h0P11JN480<O1^003045Yh@37
`KP0@FWQ00<0al6h0P11JN400`37`KX0@FWQ0<O1^P060<O1^P03045Yh@37`KX0al6j00P0al6j1011
JN440<S1^`80@FWQ2P38`K/90:f][@030<S1^`11JN40@FWQ00D0b<6k0P11JN460<S1^`80@FWQ00<0
[Jf]0<O1_037`K`01037`K`3045Yh@80al6l0P11JN460<O1_0030:f][@36`;`0a/2l0140a/2l00<0
[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]
0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]1`2i/ZH2045YhA80_[N/00<0[Jf]
0<6j/031^[003031^[000`11JN40`KZ`0<6j/0030<6j/0030:f][@11JN40`kfc00D0`kfc00<0@FWQ
0<>m/`33_K<02`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@P0[Jf]0P11JN420:f][@D0aKje00<0[Jf]
0<Jo]`11JN401@36_kL2045Yh@h0a[ng00<0@FWQ0<O1^037`KP01037`KP2045Yh@L0al6h0P11JN42
0<O1^003045Yh@37`KP0al6h0080@FWQ0P37`KX00`11JN40al6j0<O1^P040<O1^P03045Yh@37`KX0
al6j00H0al6j1011JN400`2][Jd0b<6k0<S1^`030<S1^`80@FWQ2P2][Jd50<S1^`030:f][@38`K/0
b<6k0080b<6k00<0@FWQ0<S1^`38`K/01038`K/3045Yh@D0b<6k00<0@FWQ0<S1^`2][Jd01P37`K`2
045Yh@030<O1_011JN40@FWQ00T0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`06
0<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je9
0;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V
00H0^K:V0`2][Jd20;VbYP@0@FWQ4P2n]j`00`2][Jd0`KZ`0<6j/00=0<6j/080@FWQ0`31^[02045Y
h@H0`kfc00<0@FWQ0<>m/`33_K<02`33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ0P35_[D70:f]
[@03045Yh@2][Jd0[Jf]00<0[Jf]0P11JN420:f][@`0a[ng00@0[Jf]045Yh@11JN40@FWQ0`37`KP2
045Yh@L0al6h0P11JN420<O1^005045Yh@37`KP0@FWQ045Yh@2][Jd00P37`KX00`11JN40al6j0<O1
^P040<O1^P03045Yh@37`KX0[Jf]0100[Jf]0`11JN4;0<S1^`80@FWQ00<0b<6k0:f][@38`K/00`38
`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<0b<6k045Yh@38`K/00P38`K/2045Yh@030<S1^`2]
[Jd0al6l00D0al6l0P11JN4<0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33
_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`
h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd2045YhA80_[N/00<0[Jf]0<6j/031^[003`31^[03
045Yh@030:f][@11JN40`kfc00@0`kfc0P11JN4=0<>m/`030:f][@35_[D0aKje00/0aKje0P11JN47
0<Fn]@030:f][@36_kL0@FWQ00D0a[ng0`11JN400`36_kL0[Jf]0:f][@0>0:f][@D0@FWQ1`2][Jd2
045Yh@80[Jf]00@0@FWQ0:f][@11JN40@FWQ0`2][Jd00`11JN40[Jf]0:f][@040:f][@03045Yh@2]
[Jd0al6j00X0al6j00<0[Jf]0<S1^`38`K/00`38`K/3045Yh@@0b<6k00<0@FWQ0<S1^`38`K/01@38
`K/00`11JN40b<6k0:f][@040<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN420<S1^`@0@FWQ0P38
`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ3037`K`00`2][Jd0a/2l0<K0_00@0<K0_00300000033
_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00H0];2a0P2]
[Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0
^K:V00d0^K:V0`2][Jd;0;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`040<>m/`80@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1`35_[D0
0`2][Jd0a[ng045Yh@050<Jo]`<0@FWQ3@36_kL00`2][Jd0al6h0<O1^0040<O1^080@FWQ1`37`KP2
045Yh@80al6h00D0@FWQ0<O1^011JN40@FWQ0:f][@020<O1^P03045Yh@37`KX0al6j00@0al6j00<0
@FWQ0<O1^P37`KX02P37`KX00`2][Jd0b<6k0<S1^`030<S1^`<0@FWQ1038`K/2045Yh@H0b<6k00<0
@FWQ0<S1^`2][Jd01038`K/00`11JN40b<6k0<S1^`020<S1^`@0@FWQ2038`K/00`2][Jd0al6l0<O1
_0040<O1_080@FWQ3037`K`00`2][Jd0@FWQ0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H2
0:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
[Jf]00<0[Jf]1`2n]j`2045Yh@@0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`04
0<>m/`80@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1`35_[D00`2][Jd0a[ng045Yh@05
0<Jo]`<0@FWQ1@36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ1P37`KP00`11JN40al6h0<O1^006
0<O1^006045Yh@37`KP0al6h0<O1^011JN40al6h0P11JN40102][Jd0al6j0<O1^P11JN460<O1^P03
045Yh@37`KX0al6j00X0al6j00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@030<S1^`11JN40b<6k0080
b<6k0P11JN470<S1^`H0@FWQ4@38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ3037`K`00`2][Jd0
@FWQ045Yh@090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0
_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]
0`2n]j`00`11JN40_[N/0;jg[0030;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
1033_K<2045Yh@d0`kfc00<0[Jf]0<Fn]@35_[D02`35_[D2045Yh@L0aKje00<0[Jf]0<Jo]`11JN40
1@36_kL2045Yh@030<Jo]`11JN40a[ng0080a[ng0P11JN460<Jo]`80@FWQ1P37`KP00`11JN40al6h
0<O1^0050<O1^080@FWQ1037`KP2045Yh@030<O1^02][Jd0al6j0080al6j00<0@FWQ0<O1^P37`KX0
0`37`KX00`11JN40al6j0<O1^P0:0<O1^P030:f][@38`K/0b<6k00<0b<6k0P11JN420<S1^`@0@FWQ
2@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00@0al6l0P11JN4<0<O1_0030:f]
[@11JN40a/2l00D0a/2l102][Jd70<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0
302n^KP0102][Jd0];2a0;B`/@2d/;420:f][E00/>3V0@3oool006T0/>3V0P2][Jd20:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]
1@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00@0`kfc0P11JN4=0<>m/`030:f]
[@35_[D0aKje00/0aKje0P11JN470<Fn]@030:f][@36_kL0@FWQ00D0a[ng0P11JN400`36_kL0@FWQ
0<Jo]`030<Jo]`03045Yh@36_kL0a[ng00D0a[ng00<0@FWQ0<O1^037`KP00`37`KP00`11JN40al6h
0<O1^0060<O1^080@FWQ1037`KP2045Yh@030<O1^02][Jd0al6j0080al6j00<0@FWQ0<O1^P37`KX0
0`37`KX00`11JN40al6j0<O1^P0:0<O1^P040:f][@38`K/0b<6k0<S1^`@0@FWQ3`38`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00@0al6l0P11JN4<0<O1_0030:f][@11JN40a/2l00D0
[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d
/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`040<>m/`80
@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1`35_[D00`2][Jd0@FWQ045Yh@030<Jo]`@0
@FWQ0P36_kL5045Yh@L0a[ng00<0[Jf]045Yh@11JN400`11JN460<O1^0L0@FWQ0P37`KP2045Yh@03
0<O1^02][Jd0@FWQ00D0@FWQ0`37`KX00`11JN40al6j0<O1^P090<O1^P03045Yh@2][Jd0b<6k01D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ2P37`K`50:f][A00
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00
K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]
4@31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ
1`35_[D00`2][Jd0@FWQ045Yh@0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
1`37`KX2045Yh@X0al6j00<0@FWQ0:f][@38`K/02038`K/00`000000b<6k0<S1^`0:0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037`K`2045Yh@D0al6l1@2][Jd20<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]
E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ
3@33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1`35_[D00`2][Jd0@FWQ045Yh@0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01`37`KX2045Yh@T0al6j0P11JN400`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`00P37`K`2045Yh@030<O1
_02][Jd0[Jf]00@0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31
^[000`2][Jd0`kfc0<>m/`040<>m/`03045Yh@33_K<0`kfc00`0`kfc00<0[Jf]0<Fn]@35_[D02`35
_[D2045Yh@L0aKje0P11JN4F0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01`37
`KX2045Yh@T0al6j0P11JN400`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][Jd3
0<>m/`03045Yh@33_K<0`kfc00`0`kfc00<0[Jf]0<Fn]@35_[D02`35_[D2045Yh@L0aKje0P11JN4F
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02037`KX2045Yh@P0al6j0P11JN40
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdB0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H1
0?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0
aKje00/0aKje0P11JN460<Fn]@80@FWQ5`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j00T0al6j0P11JN460<O1^P<0@FWQ00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`09
0<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2a
Zid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0;0<Fn]@80@FWQ1@35_[D2045Y
h@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1
^P80@FWQ1P37`KX01011JN40al6j045Yh@2][JdF0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33
_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]1P35_[D:045Yh@030<Fn]@2][Jd0
a[ng01H0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0:0<O1^P80@FWQ0`37`KX2
045Yh@80al6j00<0@FWQ0:f][@38`K/04038`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n0;3P
iP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02`37`KX4045Yh@D0al6j00<0[Jf]0<S1
^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880
/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0
al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]
1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V
0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2]
[Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H1
0?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0
/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]
0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool0
0:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB
0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0
[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`
h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50308 .33845 m
.51467 .33859 L
s
.5395 .34075 m
.54281 .33844 L
s
.54281 .33844 m
.54777 .33834 L
s
.53785 .34077 m
.54281 .33844 L
s
0 0 0 r
.58514 .33513 m
.5854 .33561 L
s
.255 .412 .882 r
.54777 .33834 m
.55108 .34052 L
s
.5362 .3453 m
.53785 .34077 L
s
.53786 .34528 m
.5395 .34075 L
s
0 0 0 r
.5854 .33561 m
.58588 .33464 L
s
.255 .412 .882 r
.55108 .34052 m
.5544 .34495 L
s
.55932 .33803 m
.56097 .33798 L
s
.55603 .34039 m
.55932 .33803 L
s
.55768 .34034 m
.55932 .33803 L
s
.48492 .338 m
.48821 .34035 L
s
.46849 .33733 m
.48492 .338 L
s
.48492 .338 m
.48986 .3404 L
s
.5362 .3453 m
.53621 .34981 L
s
.53786 .34528 m
.53787 .34979 L
s
.48986 .3404 m
.49314 .345 L
s
.5544 .34495 m
.55603 .34039 L
s
.48821 .34035 m
.49149 .34496 L
s
.55605 .3449 m
.55768 .34034 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49314 .345 m
.49478 .34956 L
s
.49149 .34496 m
.49313 .34952 L
s
.53621 .34981 m
.53787 .35431 L
s
.53787 .34979 m
.53953 .35429 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49478 .34956 m
.49641 .35638 L
s
.49313 .34952 m
.49476 .35634 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47477 .38526 m
.47505 .33763 L
s
.47312 .38519 m
.47341 .33756 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53787 .35431 m
.54285 .3565 L
s
.53953 .35429 m
.54285 .3565 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50965 .3702 m
.5097 .33854 L
s
.50799 .37018 m
.50805 .33852 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56937 .36936 m
.57576 .33739 L
s
.5544 .34495 m
.55448 .36531 L
s
.55605 .3449 m
.55611 .36073 L
s
.50967 .3566 m
.51132 .36341 L
s
.54285 .3565 m
.5528 .35855 L
s
.49638 .36771 m
.49641 .35638 L
s
.49472 .36767 m
.49476 .35634 L
s
.52128 .36573 m
.52295 .36346 L
s
.52295 .36346 m
.52461 .36573 L
s
.5528 .35855 m
.55446 .36078 L
s
.51132 .36341 m
.51464 .36797 L
s
.53789 .36337 m
.5379 .36563 L
s
.53789 .36337 m
.53955 .36335 L
s
.53955 .36335 m
.53956 .36561 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52128 .36573 m
.52295 .368 L
s
.52461 .36573 m
.52461 .368 L
s
.5379 .36563 m
.53956 .36788 L
s
.55448 .36531 m
.55611 .36073 L
s
.52295 .37027 m
.52461 .368 L
s
.51464 .36797 m
.51796 .37026 L
s
.53956 .36788 m
.54289 .3701 L
s
.51796 .37026 m
.52295 .37027 L
s
.55283 .36762 m
.55448 .36531 L
s
.50301 .37011 m
.50965 .3702 L
s
.4947 .37449 m
.49638 .36771 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49304 .37445 m
.49472 .36767 L
s
.54289 .3701 m
.54952 .36997 L
s
.54952 .36997 m
.55283 .36762 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49302 .379 m
.4947 .37449 L
s
.49136 .37896 m
.49304 .37445 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56442 .36955 m
.57596 .36909 L
s
.58418 .36869 m
.58889 .34348 L
s
.58254 .36878 m
.58884 .3367 L
s
.58884 .3367 m
.59563 .36805 L
s
.57102 .3693 m
.5758 .34416 L
s
.57576 .33739 m
.58254 .36878 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48969 .38347 m
.49302 .379 L
s
.48803 .38342 m
.49136 .37896 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61314 .33726 m
.61793 .3346 L
s
.60998 .34205 m
.61314 .33726 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60841 .34671 m
.60998 .34205 L
s
.61475 .33713 m
.61793 .3346 L
s
.61159 .34192 m
.61475 .33713 L
s
.61793 .3346 m
.62113 .33431 L
s
.61002 .34658 m
.61159 .34192 L
s
.60687 .35364 m
.60841 .34671 L
s
.4847 .3856 m
.48969 .38347 L
s
.4847 .3856 m
.48803 .38342 L
s
.60848 .35352 m
.61002 .34658 L
s
.62113 .33431 m
.62594 .33614 L
s
.46817 .38498 m
.4847 .3856 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60687 .35364 m
.60698 .36501 L
s
.59073 .36834 m
.60051 .36774 L
s
.60848 .35352 m
.6086 .36489 L
s
.62594 .33614 m
.62918 .34038 L
s
0 0 0 r
.58514 .39444 m
.58588 .39723 L
s
.255 .412 .882 r
.62909 .33357 m
.62933 .35175 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58588 .39723 m
.58683 .3933 L
s
.255 .412 .882 r
.63068 .33342 m
.63092 .3516 L
s
.41456 .3334 m
.41612 .33583 L
s
.41295 .33551 m
.41456 .3334 L
s
.4145 .33794 m
.41612 .33583 L
s
.41295 .33551 m
.4145 .33794 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6086 .36489 m
.61029 .37162 L
s
.60698 .36501 m
.60867 .37173 L
s
.62455 .35219 m
.63568 .35113 L
s
.64015 .33243 m
.65109 .33118 L
s
.60867 .37173 m
.61034 .37618 L
s
.61029 .37162 m
.61196 .37606 L
s
.41435 .34931 m
.41558 .37687 L
s
.41239 .37658 m
.41435 .34931 L
s
.61034 .37618 m
.61363 .38052 L
s
.61196 .37606 m
.61524 .38039 L
s
.39727 .33153 m
.40036 .33417 L
s
.40036 .33417 m
.40189 .33662 L
s
.40179 .34345 m
.40189 .33662 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39105 .33079 m
.39727 .33153 L
s
.40022 .34327 m
.40182 .34117 L
s
.61363 .38052 m
.61849 .38243 L
s
.40018 .34555 m
.40179 .34345 L
s
.61524 .38039 m
.61849 .38243 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64721 .34937 m
.64726 .35259 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64485 .33191 m
.64533 .36386 L
s
.64641 .33173 m
.6469 .36368 L
s
.41399 .37673 m
.41417 .36299 L
s
.39706 .3452 m
.40022 .34327 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38792 .33268 m
.39105 .33079 L
s
.39702 .34748 m
.40018 .34555 L
s
.61849 .38243 m
.62171 .38217 L
s
.63113 .36758 m
.63131 .38133 L
s
.62963 .37459 m
.63113 .36758 L
s
.38921 .34885 m
.39706 .3452 L
s
.62171 .38217 m
.62649 .37946 L
s
.64669 .34996 m
.64836 .35664 L
s
.38917 .35114 m
.39702 .34748 L
s
.38634 .33476 m
.38792 .33268 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62649 .37946 m
.62963 .37459 L
s
.62963 .37459 m
.63131 .38133 L
s
.39998 .35926 m
.40162 .35486 L
s
.40148 .36401 m
.40162 .35486 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38488 .33 m
.38634 .33476 L
s
.38472 .33912 m
.38488 .33 L
s
.41392 .38131 m
.41558 .37687 L
s
.38472 .33912 m
.38634 .33476 L
s
.64061 .36435 m
.6469 .36368 L
s
0 0 0 r
.36134 .31888 m
.36436 .31934 L
s
.255 .412 .882 r
.41239 .37658 m
.41392 .38131 L
s
.39838 .36138 m
.39998 .35926 L
s
.39998 .35926 m
.40148 .36401 L
s
.64836 .35664 m
.65156 .36087 L
s
.39521 .36332 m
.39838 .36138 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38607 .35075 m
.38921 .34885 L
s
.38603 .35304 m
.38917 .35114 L
s
.38898 .36259 m
.39521 .36332 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65156 .36087 m
.65471 .3628 L
s
.38449 .35285 m
.38607 .35075 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38445 .35514 m
.38603 .35304 L
s
.65471 .3628 m
.65936 .36224 L
s
.67262 .33062 m
.67711 .32767 L
s
.67119 .33541 m
.67262 .33062 L
s
.65774 .35784 m
.65932 .35994 L
s
.65774 .35784 m
.65925 .35535 L
s
.65925 .35535 m
.66083 .35745 L
s
.38441 .35744 m
.38449 .35285 L
s
.67119 .33541 m
.67127 .33999 L
s
.37112 .33038 m
.37406 .33539 L
s
.38592 .35992 m
.38898 .36259 L
s
.67413 .3304 m
.67711 .32767 L
s
.6727 .3352 m
.67413 .3304 L
s
.36664 .32742 m
.37112 .33038 L
s
.6727 .3352 m
.67279 .33977 L
s
.66083 .35745 m
.66087 .35975 L
s
.38441 .35744 m
.38592 .35992 L
s
.67711 .32767 m
.68161 .32698 L
s
.67127 .33999 m
.67287 .34436 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65936 .36224 m
.66087 .35975 L
s
.36364 .32696 m
.36664 .32742 L
s
.67279 .33977 m
.67439 .34414 L
s
.67287 .34436 m
.67745 .346 L
s
.68161 .32698 m
.68464 .3288 L
s
.36061 .32878 m
.36364 .32696 L
s
.35913 .32854 m
.36364 .32696 L
s
.67439 .34414 m
.67745 .346 L
s
.37373 .35373 m
.37377 .35143 L
s
.37229 .34893 m
.37377 .35143 L
s
.37073 .35101 m
.37229 .34893 L
s
.3706 .35791 m
.37373 .35373 L
s
.68464 .3288 m
.6877 .33291 L
s
.35755 .33289 m
.36061 .32878 L
s
.67304 .35354 m
.67308 .35584 L
s
.67304 .35354 m
.67456 .35333 L
s
.37073 .35101 m
.3722 .35352 L
s
.67745 .346 m
.68649 .34694 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35607 .33265 m
.35913 .32854 L
s
.67308 .35584 m
.67464 .35793 L
s
.67456 .35333 m
.6746 .35563 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69605 .3085 m
.70616 .30662 L
s
.67464 .35793 m
.67772 .3598 L
s
.36753 .35978 m
.3706 .35791 L
s
.68909 .32808 m
.69199 .3253 L
s
.6877 .33291 m
.68909 .32808 L
s
.35593 .33954 m
.35755 .33289 L
s
.69057 .32784 m
.69199 .3253 L
s
.68918 .33267 m
.69057 .32784 L
s
.35445 .3393 m
.35607 .33265 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6877 .33291 m
.68812 .35362 L
s
.68918 .33267 m
.68951 .34877 L
s
.69199 .3253 m
.69346 .32505 L
s
.67772 .3598 m
.68374 .35892 L
s
.36301 .35912 m
.36753 .35978 L
s
.35583 .34414 m
.35593 .33954 L
s
.68649 .34694 m
.68803 .34901 L
s
.33873 .32267 m
.34886 .32452 L
s
.35435 .3439 m
.35445 .3393 L
s
.36006 .35636 m
.36301 .35912 L
s
.35857 .35614 m
.36301 .35912 L
s
.35583 .34414 m
.35717 .35129 L
s
.68374 .35892 m
.68668 .35616 L
s
.35717 .35129 m
.36006 .35636 L
s
.35435 .3439 m
.35569 .35106 L
s
.68812 .35362 m
.68951 .34877 L
s
.68668 .35616 m
.68812 .35362 L
s
.35569 .35106 m
.35857 .35614 L
s
.34379 .35604 m
.3445 .32374 L
s
.34233 .35579 m
.34305 .32348 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70236 .3304 m
.70514 .32527 L
s
.70514 .32527 m
.70796 .32242 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70185 .30744 m
.70292 .35581 L
s
.7004 .30771 m
.70147 .35606 L
s
.70796 .32242 m
.71081 .32187 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71081 .32187 m
.7137 .32362 L
s
.71081 .32187 m
.71512 .32334 L
s
.69708 .35681 m
.70292 .35581 L
s
.32319 .31955 m
.33302 .32157 L
s
0 0 0 r
.32053 .31128 m
.32284 .31177 L
s
.255 .412 .882 r
.70277 .34887 m
.70576 .35298 L
s
.7137 .32362 m
.71664 .32767 L
s
.33799 .35502 m
.34379 .35604 L
s
.71512 .32334 m
.71804 .32739 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32818 .34618 m
.32878 .32072 L
s
.70576 .35298 m
.7087 .35478 L
s
.32677 .3459 m
.32738 .32043 L
s
.71664 .32767 m
.71821 .33433 L
s
0 0 0 r
.72726 .31493 m
.7276 .31399 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34197 .37204 m
.34348 .36996 L
s
.34208 .36739 m
.34348 .36996 L
s
.71804 .32739 m
.71961 .33405 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34057 .36947 m
.34208 .36739 L
s
.7087 .35478 m
.71156 .35426 L
s
.34057 .36947 m
.34197 .37204 L
s
.71821 .33433 m
.71832 .33897 L
s
.71156 .35426 m
.71436 .3514 L
s
.71156 .35426 m
.71578 .35113 L
s
.71961 .33405 m
.71973 .33868 L
s
.71708 .34621 m
.71832 .33897 L
s
.71436 .3514 m
.71708 .34621 L
s
.71849 .34593 m
.71973 .33868 L
s
.32666 .35055 m
.32818 .34618 L
s
.71578 .35113 m
.71849 .34593 L
s
.30817 .31617 m
.31767 .31835 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32525 .35027 m
.32677 .3459 L
s
.32239 .35204 m
.32666 .35055 L
s
.32239 .35204 m
.32525 .35027 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72759 .31838 m
.73709 .3162 L
s
.31961 .35147 m
.32239 .35204 L
s
.31553 .34827 m
.31961 .35147 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31094 .36611 m
.31222 .31712 L
s
.31231 .3664 m
.31357 .31743 L
s
.31291 .34301 m
.31553 .34827 L
s
.74241 .31491 m
.75155 .31256 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73169 .31746 m
.73295 .36642 L
s
.73304 .31715 m
.73432 .36613 L
s
.73371 .34273 m
.73654 .3468 L
s
.72883 .36729 m
.73432 .36613 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73654 .3468 m
.74064 .34822 L
s
.74636 .31391 m
.74707 .33961 L
s
.74766 .31358 m
.74838 .33929 L
s
.30688 .36522 m
.31231 .3664 L
s
.29624 .31554 m
.29871 .32087 L
s
.29871 .32087 m
.29983 .32821 L
s
.2997 .33288 m
.29983 .32821 L
s
.29244 .31218 m
.29624 .31554 L
s
.29494 .3152 m
.29741 .32054 L
s
.29741 .32054 m
.29852 .32788 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74064 .34822 m
.7433 .3476 L
s
.29839 .33256 m
.29852 .32788 L
s
.29244 .31218 m
.29494 .3152 L
s
.2982 .33958 m
.2997 .33288 L
s
.29689 .33926 m
.29839 .33256 L
s
.28988 .31149 m
.29244 .31218 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7433 .3476 m
.74588 .34462 L
s
.7433 .3476 m
.7472 .3443 L
s
0 0 0 r
.76481 .30348 m
.76605 .3042 L
s
.255 .412 .882 r
.74588 .34462 m
.74707 .33961 L
s
.29545 .34362 m
.2982 .33958 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28037 .29225 m
.28909 .29481 L
s
.28728 .31313 m
.28988 .31149 L
s
.7472 .3443 m
.74838 .33929 L
s
.29415 .3433 m
.29689 .33926 L
s
.2915 .34499 m
.29545 .34362 L
s
.28463 .31711 m
.28728 .31313 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75666 .31117 m
.76539 .30867 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2915 .34499 m
.29415 .3433 L
s
.76043 .31011 m
.7614 .34301 L
s
.76168 .30975 m
.76265 .34267 L
s
.28894 .34433 m
.2915 .34499 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28387 .34298 m
.28532 .29373 L
s
.28262 .34264 m
.28407 .29336 L
s
.28646 .3413 m
.28894 .34433 L
s
.7576 .34403 m
.76265 .34267 L
s
.28408 .33591 m
.28646 .3413 L
s
.27622 .30753 m
.27743 .3079 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76801 .32755 m
.76808 .32984 L
s
.7668 .32912 m
.76683 .33025 L
s
.5 Mabswid
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27373 .30913 m
.27622 .30753 L
s
.27494 .3095 m
.27622 .30753 L
s
.27889 .3416 m
.28387 .34298 L
s
.27359 .31384 m
.27494 .3095 L
s
.27239 .31346 m
.27373 .30913 L
s
.76055 .35753 m
.76175 .35482 L
s
.76055 .35753 m
.76188 .35956 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76175 .35482 m
.76307 .35686 L
s
.77169 .31387 m
.77394 .30841 L
s
.7707 .32131 m
.77169 .31387 L
s
.27308 .33036 m
.27359 .31384 L
s
.7707 .32131 m
.77084 .32603 L
s
.76188 .35956 m
.76307 .35686 L
s
.77394 .30841 m
.77741 .30491 L
s
.77289 .3135 m
.77513 .30803 L
s
.77191 .32094 m
.77289 .3135 L
s
.27015 .308 m
.27239 .31346 L
s
.27173 .33472 m
.27239 .31346 L
s
.77191 .32094 m
.77205 .32566 L
s
.77513 .30803 m
.77741 .30491 L
s
.26787 .30488 m
.27015 .308 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77205 .32566 m
.77347 .33239 L
s
.77084 .32603 m
.77227 .33275 L
s
.77741 .30491 m
.77974 .30414 L
s
.26438 .30371 m
.26787 .30488 L
s
.27173 .33472 m
.27308 .33036 L
s
.77227 .33275 m
.77482 .33676 L
s
.27075 .32726 m
.27188 .32999 L
s
.77347 .33239 m
.77601 .3364 L
s
.26377 .32264 m
.27075 .32726 L
s
.77974 .30414 m
.78328 .30532 L
s
.27046 .33673 m
.27173 .33472 L
s
.262 .30529 m
.26438 .30371 L
s
.26086 .30489 m
.26438 .30371 L
s
.77482 .33676 m
.77845 .33804 L
s
.26801 .33837 m
.27046 .33673 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77601 .3364 m
.77845 .33804 L
s
.78328 .30532 m
.78571 .30927 L
s
.26071 .30962 m
.262 .30529 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26332 .33689 m
.26801 .33837 L
s
.25958 .30923 m
.26086 .30489 L
s
.26155 .3195 m
.26377 .32264 L
s
.2604 .31911 m
.26377 .32264 L
s
.77845 .33804 m
.78196 .33692 L
s
.26056 .31436 m
.26071 .30962 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25942 .31397 m
.25958 .30923 L
s
.26056 .31436 m
.26155 .3195 L
s
.25942 .31397 m
.2604 .31911 L
s
.78396 .32665 m
.78503 .32389 L
s
.78396 .32665 m
.78518 .32865 L
s
.78196 .33692 m
.78419 .33379 L
s
.26109 .33375 m
.26332 .33689 L
s
.78503 .32389 m
.78625 .32588 L
s
.2601 .32861 m
.26124 .329 L
s
.26116 .33137 m
.26124 .329 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78419 .33379 m
.78632 .32826 L
s
.26002 .33099 m
.2601 .32861 L
s
.26002 .33099 m
.26109 .33375 L
s
.78625 .32588 m
.78632 .32826 L
s
.79324 .29932 m
.79449 .30366 L
s
.79324 .29932 m
.79356 .30883 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79356 .30883 m
.79449 .30366 L
s
.79449 .30366 m
.79548 .30087 L
s
.79548 .30087 m
.79754 .29766 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79404 .32313 m
.79505 .32034 L
s
.79404 .32313 m
.7942 .32791 L
s
.79412 .32552 m
.79513 .32273 L
s
.79505 .32034 m
.79712 .31714 L
s
.7942 .32791 m
.79537 .3299 L
s
.79513 .32273 m
.7972 .31953 L
s
.25008 .32508 m
.25109 .32787 L
s
.25101 .33026 m
.25109 .32787 L
s
.23846 .29376 m
.24564 .29677 L
s
.24984 .33226 m
.25101 .33026 L
s
.24892 .32707 m
.25008 .32508 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79754 .29766 m
.80174 .29596 L
s
.79712 .31714 m
.80223 .31029 L
s
.79537 .3299 m
.79761 .3315 L
s
.7972 .31953 m
.80231 .31268 L
s
.24892 .32707 m
.24992 .32987 L
s
.24661 .33106 m
.24984 .33226 L
s
.80174 .29596 m
.80388 .29749 L
s
.24136 .32903 m
.24252 .29549 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24033 .32862 m
.2415 .29506 L
s
.80388 .29749 m
.80498 .29945 L
s
.80223 .31029 m
.80421 .30705 L
s
.24457 .32785 m
.24661 .33106 L
s
.80231 .31268 m
.80429 .30945 L
s
.80498 .29945 m
.80523 .30663 L
s
.24265 .32223 m
.24457 .32785 L
s
.80421 .30705 m
.80515 .30423 L
s
.24186 .31462 m
.24265 .32223 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80429 .30945 m
.80523 .30663 L
s
.79761 .3315 m
.80185 .32989 L
s
.80185 .32989 m
.80385 .32666 L
s
.80385 .32666 m
.80479 .32385 L
s
.80479 .32385 m
.80565 .31862 L
s
.80479 .32385 m
.80598 .32824 L
s
.80565 .31862 m
.80598 .32824 L
s
.23728 .32737 m
.24136 .32903 L
s
.81184 .29399 m
.81272 .29115 L
s
.81184 .29399 m
.81289 .29595 L
s
.81272 .29115 m
.81376 .2931 L
s
.23189 .31034 m
.23258 .29111 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2281 .30858 m
.23481 .31165 L
s
.81289 .29595 m
.81376 .2931 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23093 .30991 m
.23163 .29066 L
s
0 0 0 r
.22253 .27886 m
.22257 .27892 L
s
.255 .412 .882 r
.22965 .29216 m
.23137 .29786 L
s
.81332 .30797 m
.81532 .33656 L
s
.81332 .30797 m
.81339 .3374 L
s
0 0 0 r
.22253 .27886 m
.22257 .27894 L
s
.255 .412 .882 r
.22696 .28839 m
.22965 .29216 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22072 .27792 m
.22253 .27886 L
s
.255 .412 .882 r
.81384 .32245 m
.81436 .33698 L
s
.22514 .28747 m
.22696 .28839 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23076 .3418 m
.23129 .32725 L
s
.23006 .3341 m
.23129 .32725 L
s
.81339 .3374 m
.81453 .34184 L
s
.22326 .28895 m
.22514 .28747 L
s
.22238 .28849 m
.22514 .28747 L
s
.22798 .33811 m
.23006 .3341 L
s
.23006 .3341 m
.23076 .3418 L
s
.81453 .34184 m
.81532 .33656 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22132 .29286 m
.22326 .28895 L
s
.22045 .2924 m
.22238 .28849 L
s
.22509 .33926 m
.22798 .33811 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22027 .29724 m
.22132 .29286 L
s
.21941 .29678 m
.22045 .2924 L
s
.21914 .30406 m
.22027 .29724 L
s
.22326 .3384 m
.22509 .33926 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21828 .3036 m
.21941 .29678 L
s
.22155 .33509 m
.22326 .3384 L
s
.22066 .33466 m
.22326 .3384 L
s
.21868 .31624 m
.21914 .30406 L
s
.21782 .31578 m
.21828 .3036 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21996 .32933 m
.22155 .33509 L
s
.21868 .31624 m
.21927 .324 L
s
.21909 .32889 m
.22066 .33466 L
s
.21927 .324 m
.21996 .32933 L
s
.21782 .31578 m
.21841 .32356 L
s
.21841 .32356 m
.21909 .32889 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20959 .31362 m
.21438 .3164 L
s
.21014 .27889 m
.21195 .31502 L
s
.20581 .31126 m
.21014 .27889 L
s
.20655 .31173 m
.20986 .28621 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19855 .26398 m
.20012 .26515 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2043 .27492 m
.20581 .31126 L
s
.20021 .30741 m
.2043 .27492 L
s
.20088 .3079 m
.20401 .28227 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19824 .30595 m
.20294 .30935 L
s
.19776 .26982 m
.19837 .27034 L
s
.19645 .27126 m
.19776 .26982 L
s
.19705 .27177 m
.19776 .26982 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19625 .2762 m
.19705 .27177 L
s
.19566 .27568 m
.19645 .27126 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19555 .29354 m
.19625 .2762 L
s
.1947 .2697 m
.19566 .27568 L
s
.19475 .29801 m
.19566 .27568 L
s
.19369 .26618 m
.1947 .2697 L
s
.19475 .29801 m
.19555 .29354 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19208 .26459 m
.19369 .26618 L
s
.19447 .29004 m
.19496 .29303 L
s
.19126 .28449 m
.19447 .29004 L
s
.19407 .29999 m
.19475 .29801 L
s
.19282 .30148 m
.19407 .29999 L
s
.19095 .26602 m
.19208 .26459 L
s
.19045 .26549 m
.19208 .26459 L
s
.85378 .26411 m
.85847 .25875 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19065 .29947 m
.19282 .30148 L
s
.19024 .27046 m
.19095 .26602 L
s
.19033 .28096 m
.19126 .28449 L
s
.18983 .28043 m
.19126 .28449 L
s
.18975 .26993 m
.19045 .26549 L
s
.85529 .26252 m
.85746 .31508 L
s
.19004 .27545 m
.19024 .27046 L
s
.85577 .26198 m
.85794 .31458 L
s
.19004 .27545 m
.19033 .28096 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18954 .27492 m
.18975 .26993 L
s
0 0 0 r
.18408 .25769 m
.18442 .2548 L
s
.255 .412 .882 r
.18971 .29595 m
.19065 .29947 L
s
.18954 .27492 m
.18983 .28043 L
s
.18942 .29043 m
.18992 .29094 L
s
.18982 .29345 m
.18992 .29094 L
s
.18931 .29293 m
.18971 .29595 L
s
.18931 .29293 m
.18942 .29043 L
s
0 0 0 r
.18408 .25769 m
.18415 .26106 L
s
.18379 .25358 m
.18408 .25769 L
s
.18307 .24891 m
.18379 .25358 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85594 .31657 m
.86067 .31156 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85847 .25875 m
.8594 .26017 L
s
.85847 .25875 m
.8598 .25962 L
s
0 0 0 r
.18303 .28269 m
.18317 .28449 L
s
.18239 .27868 m
.18303 .28269 L
s
.18288 .28627 m
.18302 .28808 L
s
.18214 .28163 m
.18288 .28627 L
s
.18243 .29704 m
.1827 .29569 L
s
.255 .412 .882 r
.8594 .26017 m
.8604 .2641 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8598 .25962 m
.86078 .26356 L
s
.18531 .28575 m
.18562 .28879 L
s
.18552 .29131 m
.18562 .28879 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8604 .2641 m
.86099 .26858 L
s
.18499 .29331 m
.18552 .29131 L
s
.18479 .28775 m
.18531 .28575 L
s
.1822 .25157 m
.18452 .25543 L
s
.86078 .26356 m
.86136 .26804 L
s
.18479 .28775 m
.1851 .29079 L
s
.18379 .29175 m
.18499 .29331 L
s
.86099 .26858 m
.86168 .2756 L
s
.86136 .26804 m
.86204 .27506 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86067 .31156 m
.8614 .30801 L
s
.86067 .31156 m
.86181 .3075 L
s
.18198 .28912 m
.18347 .25378 L
s
.86168 .2756 m
.86221 .28822 L
s
.18314 .28817 m
.18379 .29175 L
s
.18164 .28859 m
.18314 .25323 L
s
.86204 .27506 m
.86257 .28769 L
s
.8614 .30801 m
.86199 .30192 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86254 .25273 m
.86452 .24884 L
s
.86181 .3075 m
.86237 .3014 L
s
.86216 .29633 m
.86221 .28822 L
s
.18264 .28206 m
.18314 .28817 L
s
.86199 .30192 m
.86216 .29633 L
s
.18262 .27394 m
.18264 .28206 L
s
.86253 .29581 m
.86257 .28769 L
s
.86237 .3014 m
.86253 .29581 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86345 .25107 m
.86495 .28652 L
s
.86373 .25051 m
.86524 .28599 L
s
.1807 .28701 m
.18198 .28912 L
s
.86404 .28812 m
.86524 .28599 L
s
.86459 .27075 m
.86519 .27782 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18028 .25582 m
.18031 .26145 L
s
.18023 .26961 m
.18031 .26145 L
s
.18004 .24964 m
.18028 .25582 L
s
.17969 .28233 m
.18023 .26961 L
s
.86519 .27782 m
.86592 .28184 L
s
.18005 .25527 m
.18006 .2609 L
s
.17998 .26906 m
.18006 .2609 L
s
.17983 .24908 m
.18005 .25527 L
s
.17944 .28179 m
.17998 .26906 L
s
.17954 .24542 m
.18004 .24964 L
s
.17954 .24542 m
.17983 .24908 L
s
.17911 .28945 m
.17969 .28233 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86592 .28184 m
.86651 .28332 L
s
.17887 .28891 m
.17944 .28179 L
s
.17819 .23975 m
.17954 .24542 L
s
.17865 .29403 m
.17911 .28945 L
s
.17842 .2935 m
.17887 .28891 L
s
.86651 .28332 m
.86716 .28171 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17797 .2981 m
.17865 .29403 L
s
.86673 .27713 m
.86705 .27915 L
s
.86673 .27713 m
.86683 .27404 L
s
.86683 .27404 m
.86713 .27605 L
s
.17776 .29757 m
.17842 .2935 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86716 .28171 m
.86724 .27861 L
s
.86713 .27605 m
.86724 .27861 L
s
.17725 .29909 m
.17797 .2981 L
s
.1763 .29591 m
.17861 .24202 L
s
.17725 .29909 m
.17776 .29757 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86711 .24349 m
.86722 .24917 L
s
.86722 .24917 m
.86744 .25428 L
s
.86711 .24349 m
.86727 .23923 L
s
0 0 0 r
.87109 .23377 m
.87133 .23684 L
s
.87102 .22955 m
.87109 .23377 L
s
.255 .412 .882 r
.17587 .29378 m
.17725 .29909 L
s
0 0 0 r
.87125 .23261 m
.87102 .22955 L
s
.255 .412 .882 r
.86744 .25428 m
.86777 .25885 L
s
.86721 .24293 m
.86733 .2486 L
s
.86733 .2486 m
.86755 .25372 L
s
.86721 .24293 m
.86727 .23923 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17618 .29538 m
.17849 .24146 L
s
.86755 .25372 m
.86787 .25829 L
s
0 0 0 r
.87133 .23684 m
.87125 .23261 L
s
.255 .412 .882 r
.86821 .26911 m
.86832 .27169 L
s
.86821 .26911 m
.86831 .26856 L
s
.86832 .27169 m
.86853 .27371 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86787 .25829 m
.86815 .25974 L
s
.86727 .23923 m
.86745 .23752 L
s
.86777 .25885 m
.86815 .25974 L
s
.86831 .26856 m
.86842 .27114 L
s
.86745 .23752 m
.86762 .23894 L
s
.86815 .25974 m
.86852 .25898 L
s
.86853 .27371 m
.86881 .2752 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86762 .23894 m
.86786 .24294 L
s
0 0 0 r
.87166 .23219 m
.8715 .22794 L
s
.87214 .24322 m
.87166 .23219 L
s
.8715 .22794 m
.87129 .22309 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87309 .2772 m
.87405 .29939 L
s
.87213 .25514 m
.87413 .29885 L
s
.87213 .25514 m
.87396 .29992 L
s
.5 Mabswid
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86881 .2752 m
.86903 .27301 L
s
.86764 .23722 m
.86786 .24294 L
s
.86786 .24294 m
.86886 .26618 L
s
.86749 .2335 m
.86764 .23722 L
s
0 0 0 r
.87214 .24264 m
.87198 .23954 L
s
.87396 .29992 m
.87437 .30681 L
s
.87129 .22309 m
.87106 .22073 L
s
.8723 .24633 m
.87214 .24322 L
s
.255 .412 .882 r
.86762 .23665 m
.86786 .24237 L
s
.86786 .24237 m
.86864 .26045 L
s
.86749 .2335 m
.86762 .23665 L
s
.86852 .25898 m
.86864 .261 L
s
.86897 .26932 m
.86903 .27301 L
s
.86745 .23292 m
.86749 .2335 L
s
0 0 0 r
.87225 .24518 m
.87214 .24264 L
s
.87437 .30681 m
.87413 .29885 L
s
.87241 .24887 m
.8723 .24633 L
s
.255 .412 .882 r
.86886 .26618 m
.86897 .26932 L
s
.86864 .26045 m
.86886 .26618 L
s
0 0 0 r
.87294 .26166 m
.87326 .26851 L
s
.87359 .27648 m
.87294 .26166 L
s
.87227 .24972 m
.87225 .24518 L
s
.87106 .22073 m
.87105 .22324 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87243 .25343 m
.87241 .24887 L
s
.87326 .26851 m
.87341 .27166 L
s
.87326 .26851 m
.87359 .27648 L
s
.87105 .22324 m
.8711 .22634 L
s
.87341 .27166 m
.8735 .27427 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87067 .21836 m
.8711 .22634 L
s
.87131 .23316 m
.87067 .21836 L
s
.8711 .22634 m
.87131 .23316 L
s
.8735 .27427 m
.87324 .27205 L
s
.255 .412 .882 r
.8682 .26419 m
.8689 .26806 L
s
0 0 0 r
.87223 .2523 m
.87227 .24972 L
s
.87239 .25602 m
.87243 .25343 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86663 .22773 m
.86867 .2664 L
s
.86697 .23552 m
.86856 .26585 L
s
0 0 0 r
.87228 .25545 m
.87223 .2523 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86912 .21303 m
.86992 .2154 L
s
.87244 .25918 m
.87239 .25602 L
s
.87324 .27205 m
.87288 .2672 L
s
.8726 .26291 m
.87228 .25545 L
s
.87288 .2672 m
.8726 .26291 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86698 .24053 m
.86755 .26198 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86598 .2364 m
.86755 .26198 L
s
0 0 0 r
.86882 .21556 m
.86961 .22419 L
s
.255 .412 .882 r
.86578 .23557 m
.86736 .26142 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86912 .21303 m
.87139 .26537 L
s
.86934 .21362 m
.8716 .26593 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86787 .21006 m
.86882 .21556 L
s
.8673 .20887 m
.86787 .21006 L
s
.86683 .21143 m
.8673 .20887 L
s
.86651 .21084 m
.8673 .20887 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86683 .21833 m
.86683 .21143 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87067 .26369 m
.8716 .26593 L
s
.5 Mabswid
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86649 .21774 m
.86651 .21084 L
s
.86683 .21833 m
.86861 .25979 L
s
.86649 .21774 m
.86827 .25923 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86005 .19823 m
.86331 .20236 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86718 .25756 m
.86861 .25979 L
s
.86198 .20058 m
.86424 .25367 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86152 .19999 m
.86377 .25312 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85627 .22732 m
.85636 .22936 L
s
.85682 .22861 m
.85687 .22992 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8623 .25146 m
.86424 .25367 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85623 .19412 m
.85798 .23607 L
s
.8538 .19178 m
.85794 .19588 L
s
.86491 .27994 m
.86521 .27664 L
s
.86458 .27226 m
.86521 .27664 L
s
.255 .412 .882 r
.85772 .26218 m
.85781 .26416 L
s
0 0 0 r
.86427 .27556 m
.86458 .27226 L
s
.255 .412 .882 r
.85781 .26416 m
.85785 .26247 L
s
0 0 0 r
.86427 .27556 m
.86491 .27994 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85771 .2432 m
.85798 .23607 L
s
.85564 .19353 m
.85739 .23552 L
s
.84614 .18542 m
.85117 .18946 L
s
.85711 .24265 m
.85739 .23552 L
s
.85602 .2454 m
.85771 .2432 L
s
.85602 .2454 m
.85711 .24265 L
s
.84909 .18772 m
.85129 .24158 L
s
.84837 .18715 m
.85057 .24104 L
s
.85473 .2443 m
.85602 .2454 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85254 .2388 m
.85473 .2443 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85082 .22998 m
.85254 .2388 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84833 .23942 m
.85129 .24158 L
s
.84184 .19355 m
.84313 .20569 L
s
.83985 .18472 m
.84184 .19355 L
s
.255 .412 .882 r
.83657 .195 m
.837 .19744 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83709 .17918 m
.83985 .18472 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84101 .19299 m
.8423 .20514 L
s
.83899 .18416 m
.84101 .19299 L
s
.84313 .20569 m
.84344 .21343 L
s
.83709 .17918 m
.83899 .18416 L
s
.8423 .20514 m
.84261 .21288 L
s
.255 .412 .882 r
.83561 .21287 m
.83614 .21263 L
s
0 0 0 r
.84308 .22453 m
.84344 .21343 L
s
.8353 .17806 m
.83709 .17918 L
s
.255 .412 .882 r
.20628 .2204 m
.20617 .22311 L
s
.20721 .21715 m
.20628 .2204 L
s
.83561 .21287 m
.83603 .21244 L
s
0 0 0 r
.84224 .22398 m
.84261 .21288 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83763 .2221 m
.83797 .22232 L
s
.83784 .22754 m
.83814 .22664 L
s
.83763 .2221 m
.83774 .22482 L
s
0 0 0 r
.8417 .23124 m
.84308 .22453 L
s
.84084 .2307 m
.84224 .22398 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83267 .18026 m
.8353 .17806 L
s
.83361 .18081 m
.8353 .17806 L
s
.83202 .18746 m
.83361 .18081 L
s
.83106 .18692 m
.83267 .18026 L
s
.83924 .23355 m
.8417 .23124 L
s
.83924 .23355 m
.84084 .2307 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83151 .19859 m
.83202 .18746 L
s
.83054 .19805 m
.83106 .18692 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83743 .23249 m
.83924 .23355 L
s
.83151 .19859 m
.83181 .20639 L
s
.83543 .22753 m
.83743 .23249 L
s
.83449 .227 m
.83743 .23249 L
s
.83054 .19805 m
.83084 .20585 L
s
.83181 .20639 m
.83323 .21864 L
s
.8171 .16822 m
.82461 .17199 L
s
.83323 .21864 m
.83543 .22753 L
s
.83084 .20585 m
.83227 .21812 L
s
.83227 .21812 m
.83449 .227 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82038 .16982 m
.82348 .2525 L
s
.82146 .17036 m
.82456 .25299 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80419 .16246 m
.81256 .1661 L
s
.23887 .16344 m
.25966 .15543 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8085 .20717 m
.80852 .20722 L
s
.80583 .19728 m
.80586 .19789 L
s
.80712 .19891 m
.8085 .20717 L
s
.80733 .20668 m
.80862 .21 L
s
.80586 .19789 m
.80733 .20668 L
s
0 0 0 r
.82016 .25104 m
.82456 .25299 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23962 .24529 m
.24256 .1619 L
s
.24088 .24483 m
.24381 .16139 L
s
.797 .17126 m
.7987 .18362 L
s
.7941 .16237 m
.797 .17126 L
s
.78996 .15694 m
.7941 .16237 L
s
.79569 .17076 m
.7974 .18313 L
s
.79278 .16187 m
.79569 .17076 L
s
.78996 .15694 m
.79278 .16187 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80903 .16453 m
.81203 .24768 L
s
.80784 .16401 m
.81082 .24721 L
s
.7987 .18362 m
.79898 .19155 L
s
.78724 .15596 m
.78996 .15694 L
s
.7974 .18313 m
.79768 .19107 L
s
.24228 .20488 m
.25005 .202 L
s
.79809 .203 m
.79898 .19155 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79678 .20252 m
.79768 .19107 L
s
.7846 .15896 m
.78724 .15596 L
s
.7832 .15848 m
.78724 .15596 L
s
.25828 .15592 m
.25887 .17925 L
s
.80714 .2458 m
.81203 .24768 L
s
.25887 .17925 m
.25966 .15543 L
s
.24951 .21798 m
.2506 .18608 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79573 .21003 m
.79809 .203 L
s
.2359 .24669 m
.25688 .2394 L
s
.78205 .16594 m
.7846 .15896 L
s
.7944 .20956 m
.79678 .20252 L
s
.78063 .16548 m
.7832 .15848 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79183 .21263 m
.79573 .21003 L
s
.78102 .17742 m
.78205 .16594 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79183 .21263 m
.7944 .20956 L
s
.77958 .17696 m
.78063 .16548 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78909 .21172 m
.79183 .21263 L
s
.78102 .17742 m
.78128 .18541 L
s
.77958 .17696 m
.77984 .18495 L
s
.27389 .1547 m
.27852 .14935 L
s
.27216 .16312 m
.27389 .1547 L
s
.78128 .18541 m
.78309 .19787 L
s
.78618 .20679 m
.78909 .21172 L
s
.78477 .20634 m
.78909 .21172 L
s
.27538 .15424 m
.27852 .14935 L
s
.27364 .16266 m
.27538 .15424 L
s
.77984 .18495 m
.78166 .19741 L
s
.78309 .19787 m
.78618 .20679 L
s
.27852 .14935 m
.28157 .14845 L
s
.25549 .23984 m
.25768 .21523 L
s
.25688 .2394 m
.25768 .21523 L
s
.78166 .19741 m
.78477 .20634 L
s
.74242 .11495 m
.75376 .11798 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27077 .20721 m
.27216 .16312 L
s
.27226 .20678 m
.27364 .16266 L
s
.28157 .14845 m
.2861 .15112 L
s
.76408 .15248 m
.76738 .16136 L
s
.76738 .16136 m
.76926 .1738 L
s
.76254 .15204 m
.76586 .16091 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76926 .1738 m
.76951 .18181 L
s
.75931 .14716 m
.76254 .15204 L
s
.76586 .16091 m
.76775 .17336 L
s
.75931 .14716 m
.76408 .15248 L
s
.75617 .14629 m
.75931 .14716 L
s
.76775 .17336 m
.768 .18138 L
s
.2861 .15112 m
.28902 .15825 L
s
.26636 .20853 m
.27226 .20678 L
s
.76837 .19344 m
.76951 .18181 L
s
.7531 .14943 m
.75617 .14629 L
s
.28937 .14625 m
.29578 .14454 L
s
.28771 .20258 m
.28937 .14625 L
s
.76684 .19301 m
.768 .18138 L
s
.28931 .20217 m
.29096 .14582 L
s
.7501 .1566 m
.7531 .14943 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.764 .20023 m
.76684 .19301 L
s
.76555 .20065 m
.76837 .19344 L
s
.74734 .11623 m
.74974 .20061 L
s
.74896 .11666 m
.75137 .201 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76099 .20344 m
.76555 .20065 L
s
.76099 .20344 m
.764 .20023 L
s
.72965 .13971 m
.73987 .14209 L
s
.28297 .20381 m
.28931 .20217 L
s
.30725 .14567 m
.31246 .14046 L
s
.30367 .15451 m
.30725 .14567 L
s
.30167 .167 m
.30367 .15451 L
s
.75782 .20262 m
.76099 .20344 L
s
.72629 .21172 m
.7348 .14089 L
s
.30894 .14527 m
.31246 .14046 L
s
.30535 .15411 m
.30894 .14527 L
s
.30334 .1666 m
.30535 .15411 L
s
.31246 .14046 m
.3159 .13968 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30145 .17507 m
.30167 .167 L
s
.7545 .19775 m
.75782 .20262 L
s
.30312 .17468 m
.30334 .1666 L
s
.75102 .18885 m
.7545 .19775 L
s
.3159 .13968 m
.32102 .14256 L
s
.30145 .17507 m
.30278 .18683 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7266 .22404 m
.7365 .14129 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30312 .17468 m
.30446 .18644 L
s
.74477 .19943 m
.75137 .201 L
s
.32102 .14256 m
.32435 .14989 L
s
.30278 .18683 m
.30593 .19418 L
s
.70831 .13529 m
.71913 .13745 L
s
.30446 .18644 m
.30763 .1938 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30593 .19418 m
.31095 .19713 L
s
.33543 .13561 m
.34836 .13323 L
s
.30763 .1938 m
.31095 .19713 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71614 .161 m
.73201 .1643 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31095 .19713 m
.31616 .19603 L
s
.32196 .17458 m
.32364 .17829 L
s
.32009 .17901 m
.32196 .17458 L
s
.32009 .17901 m
.32176 .18272 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32354 .18236 m
.32364 .17829 L
s
.31616 .19603 m
.31978 .19123 L
s
.31978 .19123 m
.32354 .18236 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33896 .2204 m
.34093 .13457 L
s
.34082 .22009 m
.34277 .13423 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71195 .136 m
.7266 .22404 L
s
.3605 .18824 m
.36166 .13101 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35592 .13194 m
.36941 .12982 L
s
.36244 .18795 m
.36359 .13071 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38516 .13169 m
.39126 .12685 L
s
.38102 .14037 m
.38516 .13169 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38716 .13143 m
.39126 .12685 L
s
.38301 .14011 m
.38716 .13143 L
s
.39126 .12685 m
.39531 .12636 L
s
.37881 .1529 m
.38102 .14037 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3808 .15264 m
.38301 .14011 L
s
.39531 .12636 m
.39932 .12996 L
s
.3334 .22135 m
.34082 .22009 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37866 .1611 m
.37881 .1529 L
s
.35471 .18911 m
.36244 .18795 L
s
.38065 .16084 m
.3808 .15264 L
s
.39932 .12996 m
.40329 .13768 L
s
.40347 .12542 m
.41172 .12454 L
s
.37866 .1611 m
.38043 .17317 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38065 .16084 m
.38243 .17292 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38043 .17317 m
.3843 .18091 L
s
.42634 .12316 m
.4284 .12707 L
s
.42419 .12744 m
.42634 .12316 L
s
.38243 .17292 m
.38632 .18067 L
s
.42419 .12744 m
.42624 .13135 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40217 .21207 m
.40347 .12542 L
s
.40425 .21186 m
.40553 .12519 L
s
.42624 .13135 m
.4284 .12707 L
s
.36008 .20887 m
.36194 .21274 L
s
.35805 .2133 m
.36008 .20887 L
s
.35805 .2133 m
.35991 .21716 L
s
.3843 .18091 m
.3903 .18432 L
s
.35991 .21716 m
.36194 .21274 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38632 .18067 m
.3903 .18432 L
s
.3903 .18432 m
.39438 .18386 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39855 .17927 m
.40279 .17057 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39438 .18386 m
.39855 .17927 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39597 .2127 m
.40425 .21186 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42539 .20165 m
.42569 .1767 L
s
.42326 .20183 m
.42599 .1519 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42599 .1519 m
.42751 .20149 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42326 .20183 m
.42528 .21001 L
s
.42528 .21001 m
.42751 .20149 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`080?JL3`8000002@3fW0l30:f][G<0/>3V0@3oool008L0/>3V
0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l02P3fW0l2000000P0mY`?
00<0[Jf]0>bF3P2][Jd00P2][Je`0;3PiP40oooo00240;3PiP<0[Jf]00<0o:0@0:f][@3oY140503o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00X0mY`?100000060?JL3`030:f][@3/
UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D
0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l02P3fW0l2000000P0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool0
07l0/>3V0`2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@030000002][Jd0ojHA00H0ojHA3`2][Jd70?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA003@3oYA0D0:f][AL0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`090?JL3`800000203fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?oo
o`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA00h0ojHA1@0000030?nV4@80[Jf]0P0000080:f][AH0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l2000000P0mY`?00<0[Jf]0>bF3P3/
UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@080?nV4@<0000000<0ojHA0:f][@2][Jd0
0P0000060:f][@80ojHA00<000000?nV4@0000007@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`090?JL3`800000203fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]
H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA1@2][Jd01@000000[Jf]0:f][@2][Jd000000080ojHA
0P0000080?nV4@80000000<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005@3oXa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0
2@3fW0l2000000P0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][F40/>3V0@3oool007D0/>3V0P2]
[JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ404`3oYQ45000000@0[Jf]103o
YQ400`000000ojHA0?nV4@030?nV4@040000003oYQ400000000000T0ojHA00<000000:f][@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6@3oXa000`2][Jd0o:0@0?bP40060:f][A80o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l2000000P0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40303oYQ4200000080ojHA1@0000020?nV4@030:f][@3o
YQ40ojHA00D0ojHA0P0000050?nV4@040000003oYQ400000000000X0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6@3oXa000`2][Jd0o:0@0?bP40060?bP40D0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`090?JL3`800000
203fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`
h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA00P0ojHA100000040:f][@<0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00
00070?nV4@<000002P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00/0o:0@1@2]
[Jd0103lX10000000000000000040?bP40030:f][@3fW0l0mY`?00T0mY`?0P0000090?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2]
[Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV
4@050?nV4@040:f][@00000000000:f][@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40
103oYQ42000000L0ojHA0`00000:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
403lX1030:f][@@0000000<0o:0@0:f][@3fW0l02P3fW0l2000000T0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH
40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV
4@050:f][@@0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000002@3o
YQ42000000X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400C0?bP40030000003l
X100o:0@00@0[Jf]2P3fW0l2000000T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@060=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0B0?nT4@<000000P2][Jd90?nV4@800000203oYQ4200000080ojHA00<0[Jf]
0?nV4@3oYQ400`3oYQ42000000T0ojHA0P00000:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0?bP403lX1004`3lX1000`000000o:0@0?bP40020?bP40030:f][@3fW0l0[Jf]00D00000103fW0l2
000000T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H1
0?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT
4@80[Jf]00@000000:f][@3oY140[Jf]0P0000090?nV4@800000203oYQ4200000080ojHA00<0[Jf]
0?nV4@3oYQ400`3oYQ42000000T0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0?bP403lX1004`3lX1000`000000o:0@0?bP40020?bP40030:f][@3fW0l0mY`?00<0mY`?0`000000
0`2][Jd0mY`?0?JL3`02000000T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:
0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@080?nT4@80000000<0oj@A0:f][@2][Jd00P2][Jd00`3oY14000000?nT4@020?nT
4@030:f][@3oYQ40000000T0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@030?nV
4@8000002@3oYQ42000000T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400D0?bP
40050000003lX100o:0@0?bP402][Jd01@3fW0l200000080mY`?0P2][Jd2000000T0mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool0
06L0/>3V00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00H0oj@A0P0000030:f][@@0oj@A0P0000030?nT4@040:f][@3oYQ40ojHA000000P0ojHA0P000008
0?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002P3oYQ42000000T0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400D0?bP40050000003lX100o:0@0?bP402][Jd01@3f
W0l2000000@0mY`?0P0000030:f][@800000103fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?
0?bP40040:f][@3oY140oj@A0?nT4@<000000P2][Jd2000000H0oj@A0P0000040?nT4@040:f][@3o
YQ40ojHA000000P0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000
2P3oYQ42000000T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400C0?bP40050000
003lX100o:0@0?bP402][Jd01@3fW0l2000000@0mY`?0P0000001P3fW0l000000000003fW0l0[Jf]
00000080[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP
40040:f][@3oY140[Jf]00000080[Jf]00<0oj@A0000000000000P0000060?nT4@800000103oY140
1@2][Jd0ojHA0?nV4@3oYQ40000000L0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV
4@020?nV4@8000002P3oYQ42000000T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400C0?bP40050000003lX100o:0@0?bP402][Jd0103fW0l2000000D0mY`?0`0000040?JL3`030000
003fW0l0mY`?00<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0
/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400>0?bP40<0
[Jf]0P0000040?nT4@<000001@3oY142000000D0oj@A00<0[Jf]0?nV4@3oYQ402@3oYQ42000000P0
ojHA0P0000020?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000002@3oYQ400`000000
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01<0o:0@00D000000?bP403lX100o:0@0:f][@040?JL
3`8000001@3fW0l3000000D0mY`?00D000000?JL3`3fW0l0[Jf]0>bF3P030:f][@h0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]
0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00P0o:0@0P0000020?bP4080[Jf]00@0
o:0@0:f][@00000000001@3oY143000000D0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA00T0ojHA
0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002P3oYQ42000000T0ojHA
00<000000?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400C0?bP40050000003lX100o:0@0?bP402]
[Jd0103fW0l2000000D0mY`?0P0000060?JL3`040000003fW0l0mY`?0:f][@@0k9H>0P2][Jd<0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool00680
/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00H0
o:0@0P000000103lX10000000:f][@2][Jd30?bP40030:f][@000000000000H0oj@A0P0000050?nT
4@8000001@3oY1400`2][Jd0ojHA0?nV4@090?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV
4@3oYQ400P3oYQ42000000X0ojHA0P0000090?nV4@030000003oYQ40ojHA01D0ojHA;P2][JdG0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100503lX10010000000o:0@0?bP402][Jd4
0?JL3`8000001@3fW0l2000000H0mY`?0P0000000`3fW0l0[Jf]0>bF3P050>bF3P80[Jf]0P000008
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP19
0;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP40030?bP40<0000000@0o:0@0:f][@2][Jd000001@3lX1000`2][Jd000000?nT4@06
0?nT4@8000001@3oY142000000@0oj@A00<0[Jf]0?nV4@3oYQ402P3oYQ42000000P0ojHA0P000002
0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000002@3oYQ400`000000ojHA0?nV4@05
0?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd7
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100503lX10010000000o:0@0?bP402]
[Jd40?JL3`8000001@3fW0l2000000L0mY`?00<000000?JL3`2][Jd01P3/UPh2000000040>bF3P2]
[Jd000000:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f]
[@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH
400;0>nH40040:f][@3lX100o:0@0?bP4080000000@0o:0@0:f][@2][Jd0[Jf]0P3lX1000`000000
o:0@0?bP40030?bP40030:f][@000000oj@A00H0oj@A0P0000040?nT4@8000001@3oY1400`2][Jd0
ojHA0?nV4@0:0?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000X0
ojHA0P0000050?nV4@@0[Jf]00<000000:f][@2][Jd01@2][JdG0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0?bP403lX100503lX10200000003
0?bP402][Jd0mY`?00<0mY`?0P0000060?JL3`8000001P3fW0l2000000030:f][@3/UPh0k9H>00@0
k9H>00H000000>bF3P3/UPh0k9H>0000003/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>7
3P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX1000000008000000P2][Jd50?bP
40030000003lX100o:0@00<0o:0@00<0[Jf]0000003oY1401P3oY142000000@0oj@A0P0000050?nT
4@030:f][@3oYQ40ojHA00X0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV
4@800000203oYQ420:f][@8000001@2][Jd40?nV4@030000003oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS
40030:f][@3lX100o:0@01@0o:0@00<000000?bP400000000`0000020?JL3`8000001P3fW0l20000
00H0mY`?0P0000000`2][Jd0k9H>0>bF3P030>bF3P800000103/UPh00`000000k9H>0>bF3P020:f]
[@80000000<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V
04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH4005
0:f][@3lX100[Jf]0:f][@0000001`3lX1000`000000o:0@0?bP40030?bP40030:f][@000000oj@A
00H0oj@A0P0000040?nT4@8000001@3oY1400`2][Jd0ojHA0?nV4@0:0?nV4@800000203oYQ420000
0080ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000P0[Jf]0P3oYQ42000000T0ojHA00<000000?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100503lX10010000000o:0@0?bP402][Jd2
0?JL3`@000001P3fW0l2000000H0mY`?0P0000000`2][Jd0k9H>0>bF3P030>bF3P030000003/UPh0
k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh00`2][Jd000000000000<0=^:3@030:f][@2iM@/0
^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH
4080[Jf]0P3lX1000`000000o:0@0?bP40050?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0000
003oY1401P3oY142000000@0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA00X0ojHA0P0000080?nV
4@8000001`2][Jd2000000X0ojHA0P0000090?nV4@030000003oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdC0?bP
40040000003lX100o:0@0:f][@@0mY`?00<000000?JL3`3fW0l01@3fW0l2000000H0mY`?0P000000
0`2][Jd0k9H>0>bF3P030>bF3P030000003/UPh0k9H>00<0k9H>0P0000050>bF3P@000002P3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH
403_V1002@3_V1030:f][@<0o:0@00<000000?bP403lX1001@3lX1000`000000o:0@0?bP40030?bP
40030:f][@000000oj@A00H0oj@A0P0000040?nT4@8000001@3oY1400`2][Jd0ojHA0?nV4@0:0?nV
4@800000103oYQ440:f][@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002@3oYQ420000
00X0ojHA00<000000?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX1060:f][@h0o:0@00<00000
0?bP402][Jd00`3fW0l2000000L0mY`?0P0000070?JL3`8000001@3/UPh00`000000k9H>0>bF3P04
0>bF3P030000003/UPh0k9H>00<0k9H>0P000000103KRPd0[Jf]0:f][@0000080=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@08
0=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40050:f][@3lX100o:0@0?bP400000001`3l
X1000`000000o:0@0?bP40030?bP40030:f][@000000oj@A00H0oj@A0P0000040?nT4@8000001@3o
Y1400`2][Jd0ojHA0?nV4@0:0?nV4@800000102][Jd40?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV
4@020?nV4@8000002@3oYQ42000000X0ojHA00<000000?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
40070?bP40L0[Jf]1`3lX1000`000000o:0@0:f][@030?JL3`8000001`3fW0l2000000L0mY`?0P00
00040>bF3P8000001P3/UPh2000000@0k9H>0P0000030=^:3@030:f][@000000000000H0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0
Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@00D0[Jf]0?bP403lX100o:0@
000000070?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0000003oY1401P3oY142000000@0oj@A
0P0000050?nT4@030:f][@3oYQ40ojHA00H0ojHA102][Jd2000000P0ojHA0P0000020?nV4@030:f]
[@3oYQ40ojHA0080ojHA0P0000090?nV4@8000002P3oYQ400`000000ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00h0o:0@1P2][Jd0103lX10000000?bP402][Jd30?JL3`8000001`3fW0l2000000L0
mY`?0P0000040>bF3P8000001P3/UPh2000000@0k9H>0P0000040=^:3@@00000103KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2G
H0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40040>nH40030:f][@3_V100kiP@00@0kiP@00D0[Jf]0?bP
403lX100o:0@000000070?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0000003oY1401@3oY142
000000D0oj@A0P0000050?nT4@040:f][@3oYQ40ojHA000000D0[Jf]103oYQ42000000P0ojHA0P00
00020?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000090?nV4@8000002P3oYQ400`000000ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01@0o:0@00<0[Jf]0000002][Jd00P2][Jd20?JL3`8000001`3f
W0l2000000L0mY`?0P0000040>bF3P8000001P3/UPh2000000@0k9H>0P0000040=^:3@8000000P2]
[Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo
001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]
1`3_V1001@2][Jd0o:0@0?bP403lX100000000L0o:0@00<000000?bP403lX1000`3lX1000`2][Jd0
00000?nT4@050?nT4@8000001@3oY142000000@0oj@A0`2][Jd2000000T0ojHA0P0000080?nV4@80
00000P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ43000000X0ojHA00<000000?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40040000003lX100[Jf]0?JL3`80[Jf]0P0000070?JL
3`8000001`3fW0l2000000@0k9H>0P0000060>bF3P800000103/UPh2000000@0fhX=0P0000020=^:
3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H1
0?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P2][Jd9
0>nH40050:f][@3lX100o:0@0?bP400000001`3lX1000`000000o:0@0?bP40030?bP40030:f][@00
0000oj@A00D0oj@A0P0000050?nT4@800000102][Jd01P3oY140[Jf]0?nV4@000000ojHA000000L0
ojHA0P0000090?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ43000000T0
ojHA0`00000M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@00<000000?bP402][Jd00`3fW0l2000000@0
[Jf]0`3fW0l2000000L0mY`?0P0000040>bF3P8000001`3/UPh2000000<0k9H>0P0000040=^:3@80
0000103KRPd20:f][@800000202iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440
/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P<0[Jf]
2`3_V1001@2][Jd0o:0@0?bP403lX100000000d0o:0@00<0[Jf]0000003oY1401@3oY142000000<0
oj@A0P2][Jd2000000D0oj@A00D0[Jf]0?nV4@000000ojHA000000070?nV4@8000002@3oYQ420000
0080ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000D0ojHA00@000000?nV4@00000000002@3oYQ43
000001d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1000`000000o:0@0:f][@030?JL3`800000103fW0l3
0:f][@8000001`3fW0l2000000@0k9H>0P0000070>bF3P8000000`3/UPh2000000@0fhX=0P000005
0=^:3@030000002][Jd0000000P0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP11
0;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40050:f][@3lX100o:0@0?bP400000003@3lX1000`2][Jd000000?nT4@050?nT4@8000000`2]
[Jd30?nT4@800000103oY1400`2][Jd0ojHA0?nV4@02000000L0ojHA0P0000090?nV4@8000000P3o
YQ400`2][Jd0ojHA0?nV4@050?nV4@8000000`3oYQ400`000000ojHA0?nV4@02000000T0ojHA0`00
000M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01H0o:0@00<000000:f][@3fW0l00P3fW0l00`000000mY`?0?JL
3`060?JL3`8000000`2][Jd40?JL3`800000103/UPh2000000L0k9H>0P0000030>bF3P800000103K
RPd2000000D0fhX=00@000000:f][@2][Jd000001`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]
303_V100102][Jd0o:0@0?bP403lX102000000d0o:0@0P0000040?nT4@80[Jf]0P0000060?nT4@80
0000103oY140102][Jd0ojHA0?nV4@0000080?nV4@8000002@3oYQ4200000080ojHA00<0[Jf]0?nV
4@3oYQ401`3oYQ43000000<0ojHA0P0000090?nV4@<000007@3oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400F0?bP
40040000002][Jd0mY`?0?JL3`800000203fW0l2000000<0mY`?102][Jd2000000@0k9H>0P000007
0>bF3P8000000`3/UPh2000000@0fhX=0P0000040=^:3@080000003KRPd0[Jf]0;Ue2`000000[Jf]
0;Ue2`0000040;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00
F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400;0>nH4004
0:f][@3lX100o:0@0?bP408000000`3lX1000`000000o:0@0?bP40070?bP40800000102][Jd20?nT
4@8000001P3oY142000000@0oj@A00@0[Jf]0?nV4@3oYQ400000203oYQ42000000T0ojHA0P000000
0`3oYQ40[Jf]0?nV4@0?0?nV4@8000002@3oYQ43000001d0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005P3lX100
10000000[Jf]0?JL3`3fW0l2000000P0mY`?0P0000070?JL3`80000000@0[Jf]0>bF3P3/UPh0k9H>
0P0000070>bF3P8000000`3/UPh00`2][Jd000000=^:3@030=^:3@800000103KRPd020000000fhX=
0:f][@2iM@/000000;Ue2`2][Jd0^GD;0P0000020;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]
0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]
0=>73P3CQ`h0dhL>0:f][@0<0>nH40040:f][@3lX100o:0@0?bP408000000`3lX1000`000000o:0@
0?bP40060?bP40030:f][@000000000000H0oj@A0P0000060?nT4@800000103oY1400`2][Jd0ojHA
000000090?nV4@8000001P3oYQ45000000030?nV4@2][Jd0ojHA00l0ojHA0P0000090?nV4@<00000
7@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400F0?bP40040000002][Jd0mY`?0?JL3`800000203fW0l2000000L0
mY`?0P000000103/UPh0[Jf]0:f][@2][Jd2000000L0k9H>0P0000030>bF3P030:f][@000000fhX=
00<0fhX=0P0000040=^:3@050000003KRPd0[Jf]0;Ue2`0000000P2iM@/01P2][Jd0000000000000
0000^GD;0:f][@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0
103CQ`h00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00X0kiP@00@0[Jf]0?bP403lX100
o:0@0P0000030?bP40030000003lX100o:0@00<0o:0@0`2][Jd00`3lX1000000000000060?nT4@80
00001P3oY142000000@0oj@A00<0[Jf]0?nV4@0000002@3oYQ42000000`0ojHA00<0[Jf]0?nV4@3o
YQ403P3oYQ42000000T0ojHA0`00000M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01H0o:0@00@000000:f][@3f
W0l0mY`?0P0000080?JL3`8000001`3fW0l2000000@0k9H>0P0000070>bF3P8000000`3/UPh00`2]
[Jd000000=^:3@030=^:3@800000103KRPd00`000000fhX=0:f][@020;Ue2`030000002iM@/0^GD;
008000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400:0>nH
40040:f][@3lX100o:0@0?bP408000000`3lX10010000000o:0@0?bP403lX1020:f][@@0o:0@0P00
00060?nT4@8000001`3oY142000000<0oj@A00<0[Jf]0000003oYQ402@3oYQ42000000`0ojHA00<0
[Jf]0?nV4@3oYQ403P3oYQ42000000T0ojHA0`00000M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01H0o:0@00@0
00000:f][@3fW0l0mY`?0P0000080?JL3`<000001P3fW0l2000000D0k9H>0P0000020:f][@@0k9H>
0P0000030>bF3P030:f][@000000fhX=00@0fhX=0P0000030=^:3@030000003KRPd0[Jf]0080^GD;
00<000000;Ue2`2iM@/00P0000000`2][Jd000000000000408QF1`80[Jf]@P2`h>H10?ooo`00F@2`
h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1P3CQ`h00`2][Jd0kiP@0>nH400:0>nH4004
0:f][@3lX100o:0@0?bP408000000`3lX10010000000[Jf]0:f][@2][Jd60?bP408000001P3oY142
000000L0oj@A0P0000030?nT4@030:f][@000000ojHA00T0ojHA0P00000<0?nV4@030:f][@3oYQ40
ojHA00h0ojHA0P0000090?nV4@<000005P3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400G0?bP40030000002][Jd0mY`?00800000203fW0l3000000D0mY`?0P000000
0`2][Jd0k9H>0>bF3P030>bF3P8000000P3/UPh30:f][@030>bF3P000000000000<0k9H>00<0[Jf]
0000003KRPd0103KRPd2000000<0fhX=00H000000=^:3@2][Jd0@FWQ0;Ue2`0000020;Ue2`800000
00<0^GD;0:f][@0000001028EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd80=>73P030:f][@3_V100kiP@00X0kiP@00@0[Jf]0?bP403lX100o:0@0P000000103lX100
[Jf]0:f][@0000090?bP408000001P3oY142000000T0oj@A1000000;0?nV4@800000303oYQ400`2]
[Jd0ojHA0?nV4@0>0?nV4@8000002@3oYQ43000000H0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400G0?bP40030000002][Jd0mY`?00800000203fW0l2000000030?JL3`000000mY`?
00<0mY`?0P0000000`2][Jd0k9H>0>bF3P030>bF3P8000001@3/UPh00`2][Jd000000>bF3P020>bF
3P03045Yh@2][Jd0000000D0fhX=0P0000030=^:3@060000003KRPd0[Jf]045Yh@2iM@/000000P2i
M@/200000080^GD;0P00000408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00X0kiP@00@0[Jf]0?bP403lX100o:0@
0P000000102][Jd0o:0@0?bP400000090?bP408000001P3oY142000000`0oj@A00<0[Jf]0?nV4@3o
YQ402@3oYQ42000000`0ojHA00<0[Jf]0?nV4@3oYQ403P3oYQ42000000H0ojHA0`2][Jd00`000000
[Jf]000000060:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0
[Jf]603oXa000`2][Jd0o:0@0?bP400G0?bP40030000002][Jd0mY`?008000001P3fW0l400000003
0?JL3`000000mY`?0080mY`?0P0000000`3fW0l0[Jf]0>bF3P040>bF3P8000001P3/UPh01`000000
[Jf]0:f][@2][Jd0k9H>045Yh@0000001@3KRPd2000000<0fhX=00H000000=^:3@3KRPd0[Jf]0;Ue
2`0000020;Ue2`8000000P2iM@/00`000000[Jf]0000000308QF1`030:f][@2`h>H0/>3V0400/>3V
0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00@0
[Jf]0?bP402][Jd0[Jf]0P0000030?bP40030000003lX100o:0@00L0o:0@0P0000060?nT4@800000
303oY1400`2][Jd0ojHA0?nV4@090?nV4@800000303oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@80[Jf]
0P0000060:f][@<0ojHA0`00000M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400G0?bP40040000
002][Jd0mY`?000000T0mY`?0P0000020?JL3`030000003fW0l0mY`?0080000000<0mY`?0:f][@3/
UPh01@3/UPh00`000000k9H>0>bF3P040>bF3P040000003/UPh0k9H>0>bF3P80[Jf]00<000000=^:
3@3KRPd00`3KRPd2000000<0fhX=00D000000=^:3@3KRPd0[Jf]0;Ue2`0200000080^GD;00L00000
0;Ue2`2iM@/000000:f][@28EPL000000080R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`
h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][@80o:0@00@0
00000?bP403lX100o:0@0P0000090?bP408000001P3oY142000000`0oj@A00<0[Jf]0?nV4@3oYQ40
2@3oYQ42000000`0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@80ojHA0P0000090?nV4@030000
002][Jd0000001d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@00`0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01L0o:0@00@000000:f][@000000
00003@3fW0l400000080mY`?00<0[Jf]0>bF3P3/UPh0103/UPh00`000000k9H>0>bF3P040>bF3P03
0000003/UPh0k9H>0080k9H>00@0[Jf]0000002][Jd0[Jf]0`3KRPd2000000<0fhX=00D000000=^:
3@3KRPd0[Jf]0;Ue2`0200000080^GD;00H000000;Ue2`2iM@/0000008QF1`2][Jd20000000308QF
1`2][Jd0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>73P030:f]
[@3_V100kiP@00T0kiP@0`2][Jd30?bP40D000002P3lX102000000@0oj@A0P00000>0?nT4@030:f]
[@3oYQ40ojHA00T0ojHA0P0000090?nV4@P0[Jf]303oYQ42000000T0ojHA00<000000:f][@000000
7@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
5P3oXa080:f][AH0o:0@00@000000:f][@00000000004`3fW0l00`2][Jd0k9H>0>bF3P050>bF3P03
0000003/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh00P3/UPh0102][Jd000000=^:3@3KRPd20:f]
[@030=^:3@000000000000<0fhX=00D000000=^:3@3KRPd0[Jf]0;Ue2`0200000080^GD;00@00000
0;Ue2`2iM@/000000P28EPL010000000R5H708QF1`2][Je20;3PiP40oooo001I0;3PiP050:f][@2G
H0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1001@2][Jd0o:0@
0?bP403lX100000000<0o:0@00<000000?bP403lX1001`3lX1000`2][Jd000000000000D0?nT4@03
0:f][@3oYQ40ojHA00T0ojHA0P0000030?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0>0?nV4@80
00002@3oYQ42000001h0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40<00000503fW0l00`2]
[Jd0k9H>0>bF3P040>bF3P030000003/UPh0k9H>0080k9H>00<000000>bF3P3/UPh00`3/UPh00`2]
[Jd00000000000030=^:3@030:f][@000000000000<0fhX=00D000000=^:3@3KRPd0[Jf]0;Ue2`02
00000080^GD;00@000000;Ue2`2iM@/000000P28EPL010000000[Jf]08QF1`2][Je20;3PiP40oooo
001I0;3PiP80[Jf]0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00D0kiP@0P2]
[Jd40>nH40050:f][@3lX100o:0@0?bP400000000`3lX1000`000000o:0@0?bP40060?bP40800000
5P3oY1400`2][Jd0ojHA0?nV4@070?nV4@80[Jf]0P0000030:f][@D0ojHA00D000000?nV4@3oYQ40
ojHA0:f][@0@0?nV4@8000002P3oYQ400`000000ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00P0
o:0@1P2][Jd:0?bP40<00000503fW0l00`2][Jd0k9H>0>bF3P050>bF3P050000003/UPh0k9H>0>bF
3P0000001@3/UPh00`2][Jd00000000000040=^:3@80000000@0[Jf]0=^:3@3KRPd000000P3KRPd0
102][Jd0^GD;0000000000020;Ue2`040000002iM@/0^GD;00000080R5H700@000000:f][@28EPL0
0000@P2`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH40030>nH4080[Jf]1P3_V1001@2][Jd0o:0@0?bP403lX100000000<0o:0@00<000000?bP403l
X1001`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]0P3oYQ420000
00L0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00h0ojHA0P00000:0?nV4@030000003oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1003P3lX1070:f][@<0o:0@0`00000D0?JL3`030:f][@3/UPh0k9H>
00H0k9H>00@000000>bF3P00000000001@3/UPh00`2][Jd00000000000040=^:3@80000000@0fhX=
0:f][@2][Jd000000P3KRPd0102][Jd0^GD;0;Ue2`0000020;Ue2`040000002iM@/0^GD;00000080
R5H700@0000008QF1`0000000000@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00P0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd80>nH40050:f][@3lX100o:0@0?bP400000000`3l
X1000`000000o:0@0?bP40070?bP40030:f][@3oY140oj@A01<0oj@A1@2][Jd80?nV4@8000001`3o
YQ400`000000ojHA000000020?nV4@030:f][@3oYQ40ojHA00/0ojHA1@00000:0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1030:f][@030000002][Jd0000001@0mY`?00<0
[Jf]0>bF3P3/UPh01`3/UPh2000000H0k9H>00<0[Jf]000000000000103KRPd2000000<0fhX=00@0
00000:f][@3KRPd0[Jf]0P2iM@/010000000^GD;0;Ue2`0000020;Ue2`0500000028EPL0R5H70000
0028EPL00`0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P04
0:f][@3_V100[Jf]0:f][@X0kiP@00D0[Jf]0?bP403lX100o:0@000000030?bP40050000003lX100
o:0@0?bP400000001@3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ402P3o
YQ42000000L0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030000003fW0l0000000@0[Jf]403fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@000000000000@0fhX=0P0000030=^:3@8000000P2][Jd20;Ue2`040000002i
M@/0^GD;00000080^GD;0P0000000`28EPL0000008QF1`0300000440/>3V0@3oool005P0/>3V0P2]
[Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>0P2][Jd<0>nH40050:f][@3lX100o:0@0?bP40000000
0`3lX1001@000000o:0@0?bP403lX100000000D0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0
oj@A00<0[Jf]0?nV4@3oYQ402@3oYQ42000000P0ojHA00D000000?nV4@3oYQ40ojHA0:f][@0L0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX102000000D0mY`?1@2][Jd;0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]000000000000103KRPd2000000<0fhX=0P0000001@3K
RPd0[Jf]0:f][@2iM@/000000080^GD;0P0000020;Ue2`0400000028EPL0000008QF1`<00000@@2`
h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@d0kiP@00D0[Jf]
0?bP403lX100o:0@000000030?bP40050000003lX100o:0@0?bP400000001@3lX1000`2][Jd0oj@A
0?nT4@070?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@090?nV4@800000303oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd00000
0?JL3`090?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@000000000000@0fhX=
0P0000030=^:3@80000000<0fhX=0:f][@2iM@/00P0000020;Ue2`8000000P2iM@/010000000R5H7
00000028EPL400000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00@0dhL>
00<0[Jf]0=>73P2][Jd03@3_V1001@2][Jd0o:0@0?bP403lX100000000L0o:0@00<000000?bP403l
X1000`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@060?nV4@D0
0000303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd000000?JL3`0>0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P80
0000103KRPd2000000<0fhX=0P0000000`3KRPd0[Jf]0;Ue2`02000000040:f][@2iM@/000000000
0080^GD;00@0000008QF1`000000R5H7100000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P030=>73P040:f][@3CQ`h0dhL>0:f][@d0kiP@00D0[Jf]0?bP403lX100o:0@0000
00070?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0000003fW0l04P3fW0l40:f][A40k9H>0P0000040=^:3@8000000`3K
RPd2000000030=^:3@2][Jd0^GD;0080000000@0^GD;0:f][@00000000000P2iM@/010000000R5H7
00000028EPL400000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`040:f][@3CQ`h0dhL>0=>73P80
[Jf]0`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@008000001`3lX1000`000000
o:0@0?bP40020?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@000000mY`?01@0
mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P800000103KRPd2000000@0fhX=0P000000102][Jd0
^GD;0000000000020;Ue2`8000000P2iM@/010000000R5H700000028EPL400000400/>3V0@3oool0
05P0/>3V0P2][Jd309MP2`040:f][@3CQ`h0dhL>0:f][@D0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP4002000000H0o:0@0P0000020?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh2
0:f][@`0k9H>00<0[Jf]0000003KRPd00`3KRPd2000000@0fhX=0P000000102][Jd0^GD;00000000
00020;Ue2`80000000H0[Jf]0;Ue2`000000R5H700000028EPL400000400/>3V0@3oool005P0/>3V
0P2][Jd309MP2`030:f][@3CQ`h0[Jf]00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP4002000000H0o:0@0P0000020:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>
00<0[Jf]0000003KRPd00`3KRPd2000000D0fhX=00@000000:f][@2iM@/00000102iM@/010000000
^GD;0:f][@00000208QF1`D00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;0P2][Jd70=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P0000050?bP40030:f][@000000000000D0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0000003KRPd00`3KRPd2000000D0
fhX=0P0000000`2iM@/000000;Ue2`030;Ue2`040000002iM@/0^GD;00000080R5H71@0000100;3P
iP40oooo001H0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@008000000P3lX1030:f][@030?bP40000000000000D0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0
k9H>00<0[Jf]0000003KRPd0103KRPd2000000D0fhX=0P0000050;Ue2`060000002iM@/0^GD;0000
002][Jd0R5H71@0000100;3PiP40oooo001H0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h0
0`2][Jd0kiP@0>nH400<0>nH40030:f][@3lX100o:0@008000000P2][Jd40?bP408000001@3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh3
0:f][@030>bF3P2][Jd0000000D0fhX=0P0000060=^:3@030:f][@2iM@/0^GD;00<0^GD;00H00000
0;Ue2`2iM@/000000:f][@28EPL500000400/>3V0@3oool005P0/>3V00@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00<0[Jf]0?bP402][Jd00P0000060?bP40800000
1@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40
5P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]00<000000=^:3@3KRPd00`3KRPd2000000H0fhX=
00<0[Jf]0;Ue2`2iM@/00`2iM@/01P000000^GD;0;Ue2`000000R5H70:f][@D00000@02`h>H10?oo
o`00F02`h>H01P2][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V103
0:f][@030?bP40000000000000H0o:0@0P0000050?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]
0000002][Jd0[Jf]0`3KRPd2000000H0fhX=00L0[Jf]0;Ue2`2iM@/0^GD;0000002iM@/000000080
^GD;00D0000008QF1`2][Jd0000008QF1`0300000400/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2]
[Jd00P2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd0103_V100
[Jf]0?bP403lX102000000@0o:0@0P0000070?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@000000fhX=0=^:3@80[Jf]00<0fhX=
0000000000001P3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`<0000000T0^GD;00000028EPL0R5H70000
0028EPL000000:f][@000000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f]
[@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@00<0[Jf]0?bP403lX100
0P000000103lX10000000000000000090?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405@3oYQ480:f][ID0/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd000000=^:3@030=^:3@030:f][@000000000000H0fhX=00<0[Jf]0;Ue2`2i
M@/0102iM@/00`000000^GD;0000000208QF1`050000002][Jd000000:f][@000000@02`h>H10?oo
o`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080
[Jf]1@3_V1000`2][Jd0o:0@0?bP4003000000`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0
k9H>0>bF3P0>0>bF3P030000002][Jd0000000D0fhX=0P0000000`2][Jd0fhX=0=^:3@030=^:3@03
0:f][@2iM@/0^GD;00D0^GD;00T000000:f][@28EPL0R5H70000002][Jd000000:f][@000000@02`
h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH4003
0>nH4080[Jf]1`3_V100102][Jd0o:0@00000000000>0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh2000000D0fhX=0P0000000`3KRPd0[Jf]0:f][@030=^:3@030:f][@2i
M@/0^GD;00H0^GD;00P0[Jf]08QF1`28EPL0000008QF1`000000[Jf]00000400/>3V0@3oool005L0
/>3V0P2][Jd409MP2`030:f][@3CQ`h0dhL>00D0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd90>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ47
0:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@040=^:3@8000000`3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;00L0[Jf]
08QF1`000000R5H70000002][Jd000000400/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3C
Q`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=0080fhX=100000050=^:3@80[Jf]2@2iM@/01`2][Jd0000000000028EPL000000:f]
[@000000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f][@d0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f][A00
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@8000001P3KRPd30:f][@L0
^GD;00L0[Jf]08QF1`000000R5H70000002][Jd000000400/>3V0@3oool005L0/>3V0P2][Jd309MP
2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2][Jd60;Ue2`070:f][@28EPL0R5H708QF1`000000[Jf]
000000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P030=>73P80[Jf]00<0
dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2]
[JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0
[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`070:f][@28EPL0R5H708QF1`000000@FWQ000000100;3P
iP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0dhL>0=>7
3P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f]
[@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
0080^GD;0P2][Jd30;Ue2`070:f][@28EPL0R5H708QF1`000000@FWQ000000100;3PiP40oooo001G
0;3PiP80[Jf]0`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00@0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`040;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H700@0[Jf]045Yh@000000
0000?`2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]1@3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;0`2][Jd308QF1`040:f][@11JN4000000000
03l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f]
[@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H7
0080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP2`0209MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0
[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@000000000003l0/>3V0@3oool005L0/>3V
00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd0
00000000000o0;3PiP40oooo001G0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]203CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0
^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^0030:f][@03
0>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`03
0:f][@000000000003l0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd80=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V
00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`0000000P28EPL00`2][Jd000000000000o0;3PiP40oooo001G0;3PiP030:f][@2GH0/0[Jf]0080
Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00H0[Jf]08QF1`000000[Jf]08QF1`2][Jd2000003l0/>3V0@3oool005L0/>3V00<0[Jf]09MP
2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/0102][Jd0R5H70000000000020:f][@800000?`2`h>H10?ooo`00E`2`h>H20:f]
[@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;
00L0^GD;00@0[Jf]08QF1`28EPL000000P2][Jd00`2`h>H000000;3PiP0n0;3PiP40oooo001G0;3P
iP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102T
WXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?
0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V102
0:f][@@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]
0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd6
0;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF
1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00T0dhL>00D0[Jf]0>nH402][Jd0[Jf]045Yh@050:BNS`030:f][@2aZid0/J^M00@0/J^M
0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a0;B`/@2d/;420:f]
[@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m
0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@030:BNS`11JN40
@FWQ00D0Y9j?00<0[Jf]045Yh@2aZid01P2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n
^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000
002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f]
[@11JN40@FWQ0:BNS`80@FWQ1@2TWXl00`11JN40/J^M045Yh@080;6[W@80[Jf]00<0/J^M0:f][@2i
/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0
[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/03033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;420:f][@P0^GD;00@0[Jf]08QF1`28
EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd01P3CQ`h20:f][@040:BNS`11JN40@FWQ0:BNS`80@FWQ102TWXl01011JN40[Jf]0;6[W@2a
Zid3045Yh@L0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0
1P2n^KP00`11JN40_[Vh0;ji^0030;ji^0030:f][@2d/;40];2a00L0];2a00<0[Jf]0;Ue2`2iM@/0
1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P<0[Jf]00@0Y9j?045Yh@11JN40Y9j?0P11JN440:BN
S`04045Yh@2aZid0/J^M0;6[W@<0@FWQ0P2aZid00`11JN40/J^M0;6[W@030;6[W@030:f][@2i/ZH0
[Jf]00<0[Jf]2@2i/ZH3045YhA80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`08
0<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00@0_[Vh0P11JN46
0;ji^0030:f][@2d/;40];2a00L0];2a0P2][Jd50;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0
00000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00L0
[Jf]045Yh@2:QGD0[Jf]0:BNS`11JN40Y9j?00<0@FWQ0`2TWXl2045Yh@@0/J^M0P11JN430;6[W@80
@FWQ0`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH3045YhA00_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`03
0:f][@2n^KP0@FWQ00D0_[Vh00<0@FWQ0;ji^02n^KP0102n^KP00`2][Jd0];2a0;B`/@060;B`/@D0
[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P040:f][@2:QGD0@FWQ08Z5M@80[Jf]00<0@FWQ
0:BNS`11JN400P11JN430:BNS`80@FWQ102aZid2045Yh@<0/J^M0`11JN420;6[W@030:f][@2i/ZH0
^K:V00H0^K:V0`2][Jd50;VbYP03045Yh@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0:f][@020:f][@/0`kfk0P11JN400`2n^KP0@FWQ0;ji^00:0;ji^0030:f][@2d/;40
];2a00D0];2a00@0[Jf]0;B`/@2d/;40[Jf]0P2OVj00102][Jd0^GD;0;Ue2`2][Jd308QF1`80[Jf]
00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80
[Jf]00D0@FWQ08Z5M@11JN40RXEe0:f][@02045Yh@050:f][@11JN40@FWQ0:BNS`11JN400P2TWXl2
045Yh@@0/J^M0P11JN430;6[W@80@FWQ0`2aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V
045Yh@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]3033_K/2045Yh@050:f][@2n^KP0
_[Vh0;ji^011JN402P2n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]0`2d/;40102][Jd0Wi^P09nK
X02OVj030:f][@@0R5H700<0[Jf]0000002`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP
2`0209MP2`80[Jf]0`2:QGD01@11JN40RXEe08Z5M@2][Jd0@FWQ0080Y9j?0P11JN401P2TWXl0@FWQ
0:BNS`2TWXl0@FWQ0:f][@@0/J^M0P11JN430;6[W@80@FWQ0`2aZid00`2][Jd0^K:V0;VbYP0=0;Vb
YP030:f][@11JN40[Jf]0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`02`36`;`40:f][@030<K0_02][Jd0`kfk00`0`kfk0P11JN401@2][Jd0_[Vh0;ji^02n^KP0
@FWQ00X0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@070:f][@2OVj00Wi^P09nKX011JN40
Wi^P0:f][@0408QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/0
0P2GH0/00`2][Jd0RXEe08Z5M@0508Z5M@040:f][@11JN40Y9j?0:BNS`80@FWQ00H0[Jf]045Yh@2T
WXl0Y9j?045Yh@2][Jd40;6[W@80@FWQ0`2aZid2045Yh@<0/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH0
0`11JN40^K:V0;VbYP070;VbYP03045Yh@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_007
0<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`040<>m^`03045Yh@33_K/0`kfk00@0`kfk0P11JN40
1@2][Jd0_[Vh0;ji^02n^KP0@FWQ00X0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;40202][Jd0Wi^P
09nKX02OVj00@FWQ09nKX011JN40[Jf]0`28EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001F0;3P
iP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`2:QGD2045Yh@80Y9j?00P0@FWQ0:BNS`2TWXl0@FWQ0:f]
[@2TWXl0@FWQ0:f][@@0/J^M0P11JN430;6[W@80@FWQ0`2aZid00`2][Jd0^K:V0;VbYP020;VbYP80
@FWQ00<0^K:V045Yh@2i/ZH01`2i/ZH00`11JN40_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0
`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0
a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`030<>m^`04045Yh@33_K/0@FWQ045Y
h@@0`kfk0P11JN400`33_K/0[Jf]0;ji^002045Yh@X0_[Vh0`2][Jd80;B`/@080:f][@2OVj00Wi^P
09nKX011JN40Wi^P045Yh@2][Jd308QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00@0
[Jf]09MP2`2GH0/0Uf0;0P2][Jd708Z5M@050:f][@11JN40Y9j?0:BNS`11JN400P2TWXl01@11JN40
Y9j?0:f][@11JN40[Jf]00@0/J^M0P11JN430;6[W@80@FWQ0`2aZid0102][Jd0^K:V0;VbYP2i/ZH2
045Yh@<0^K:V0P11JN420;VbYP05045Yh@2i/ZH0^K:V0;VbYP11JN402@2n]j`40:f][@D0_[N/00<0
[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00@0al6l1011
JN490<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk0<>m^`020<>m^`05045Yh@33
_K/0`kfk0<>m^`11JN401033_K/01@11JN40`kfk0<>m^`2][Jd0_[Vh0080@FWQ0`2n^KP00`11JN40
_[Vh0;ji^0030;ji^080[Jf]2P2d/;402@2][Jd0Wi^P09nKX02OVj00@FWQ09nKX011JN40Wi^P0:f]
[@0208QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd7
08Z5M@050:f][@2TWXl0@FWQ0:BNS`11JN400P2TWXl01011JN40Y9j?0:BNS`11JN420:f][@80/J^M
0`11JN430;6[W@80@FWQ0`2aZid0102][Jd0^K:V0;VbYP2i/ZH2045Yh@@0^K:V0`11JN440;VbYP03
045Yh@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`00P37`K`3045Yh@X0al6l102][Jd?0<K0_0<0@FWQ0`33_K/2045Yh@@0
`kfk00D0@FWQ0<>m^`33_K/0`kfk045Yh@020<>m^`030:f][@11JN40@FWQ00@0_[Vh00@0@FWQ0;ji
^02n^KP0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@080:f][@2OVj00Wi^P09nKX011JN40Wi^P
045Yh@2OVj020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0
Hf1C0P2][Jd608Z5M@030:f][@2TWXl0Y9j?0080Y9j?00@0@FWQ0:BNS`2TWXl0@FWQ0P2TWXl00`11
JN40[Jf]0;6[W@020:f][@80/J^M0P11JN420;6[W@80@FWQ0`2aZid0102][Jd0^K:V0;VbYP2i/ZH2
045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40_[N/045Yh@02045Yh@d0_[N/102][JdA
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037`K`00`11JN40al6l0<O1_003
0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00<0<K0_0<0@FWQ00@0a/2l0:f][@33_K/0`kfk0P11
JN4<0<>m^`030:f][@11JN40_[Vh00@0_[Vh00@0@FWQ0;ji^02][Jd0[Jf]0`2n^KP00`2][Jd0];2a
0;B`/@080;B`/@0:0:f][@2OVj00Wi^P09nKX011JN40Wi^P045Yh@2OVj00[Jf]071^N@80[Jf]@02`
h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`03
0:BNS`03045Yh@2TWXl0@FWQ0080Y9j?00<0@FWQ0:f][@2aZid00P2aZid30:f][@<0/J^M00<0@FWQ
0;6[W@2aZid00P2aZid0102][Jd0^K:V0;VbYP2i/ZH2045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i
/ZH2045Yh@80_[N/0P11JN4=0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00@0al6l00<0@FWQ0:f][@2][Jd00`2][Jd70<O1_0030:f][@36
`;`0a/2l00L0a/2l0`11JN440<K0_003045Yh@36`;`0[Jf]0080`kfk0P11JN4<0<>m^`80@FWQ102n
^KP00`2][Jd0@FWQ0:f][@050;ji^0030:f][@2d/;40];2a00P0];2a00@0[Jf]09nKX02OVj00Wi^P
0P11JN40102OVj00[Jf]0:f][@1`KWT20:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]
1@2:QGD00`2][Jd0Y9j?0:BNS`040:BNS`80@FWQ0P2TWXl00`11JN40[Jf]0;6[W@050;6[W@80[Jf]
00<0/J^M045Yh@11JN400`2aZid0102][Jd0^K:V0;VbYP2i/ZH2045Yh@D0^K:V00<0@FWQ0;VbYP2i
/ZH00`2i/ZH00`11JN40_[N/0;jg[0020;jg[080@FWQ1@2n]j`00`11JN40_[N/0;jg[0040;jg[003
0:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`0102][Jd00`11JN40al6l0<O1_00:0<O1_0040:f][@36`;`0a/2l0<K0_080@FWQ0P36`;`3045Y
h@H0a/2l00<0@FWQ0<K0_02][Jd00P33_K/2045Yh@`0`kfk00@0@FWQ0;ji^02n^KP0_[Vh0P2][Jd0
0`2n^KP0@FWQ0;ji^0050;ji^0030:f][@2d/;40];2a00P0];2a00T0[Jf]09nKX02OVj00Wi^P045Y
h@2OVj00[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<0
0P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00H0Y9j?00@0@FWQ0:BNS`11JN40
[Jf]202aZid00`2][Jd0@FWQ045Yh@030;6[W@030:f][@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i
/ZH00`2i/ZH00`11JN40^K:V0;VbYP020;VbYP030:f][@11JN40_[N/00<0_[N/0P11JN460;jg[080
@FWQ102n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0
[Jf]1037`K`00`11JN40al6l0<O1_00:0<O1_0040:f][@36`;`0@FWQ045Yh@H0a/2l00<0@FWQ0<K0
_036`;`01036`;`00`11JN40a/2l0:f][@020<>m^`03045Yh@33_K/0`kfk00X0`kfk0P11JN400`2n
^KP0[Jf]0:f][@030;ji^003045Yh@2n^KP0_[Vh00@0_[Vh00<0[Jf]0;B`/@2d/;40202d/;401P2]
[Jd0Wi^P09nKX011JN40Wi^P0:f][@80Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F
0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BN
S`080:BNS`03045Yh@2][Jd0/J^M00P0/J^M0P11JN420:f][@030;6[W@2][Jd0^K:V00<0^K:V00<0
@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP020;VbYP03045Yh@2n]j`0_[N/00@0_[N/0P11
JN460;jg[0<0@FWQ0P2n]j`00`2][Jd0@FWQ045Yh@0?0<6j/0P0[Jf]4033_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0
[Jf]0<O1_037`K`01037`K`00`11JN40al6l0<O1_00:0<O1_0@0@FWQ1P36`;`00`11JN40a/2l0<K0
_0040<K0_003045Yh@36`;`0[Jf]0080`kfk00<0@FWQ0<>m^`33_K/02@33_K/2045Yh@80[Jf]00<0
_[Vh045Yh@2n^KP00P2n^KP00`11JN40_[Vh0;ji^0040;ji^0030:f][@2d/;40];2a00P0];2a00<0
[Jf]09nKX02OVj000P2][Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H0
0`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD00`2][Jd0Y9j?0:BN
S`080:BNS`03045Yh@2][Jd0/J^M00P0/J^M0P11JN420;6[W@<0[Jf]0`2i/ZH00`11JN40^K:V0;Vb
YP030;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0@FWQ0;jg[02n]j`0102n]j`2045Yh@H0_[N/00<0
@FWQ0;jg[02n]j`00P2n]j`00`2][Jd0`KZ`045Yh@03045Yh@h0`KZ`00<0[Jf]0<>m/`33_K<00`33
_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38
`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_0040<O1_003045Yh@37`K`0al6l0080al6l
00<0@FWQ0<O1_037`K`01@37`K`0102][Jd0a/2l045Yh@11JN460<K0_003045Yh@36`;`0a/2l00@0
a/2l00<0@FWQ0<K0_02][Jd00P33_K/00`11JN40`kfk0<>m^`070<>m^`80[Jf]00<0@FWQ0<>m^`2]
[Jd00P2n^KP01@11JN40_[Vh0;ji^02n^KP0@FWQ00H0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2]
[Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd02P2TWXl00`11JN40
[Jf]0;6[W@080;6[W@80@FWQ0`2aZid00`2][Jd0^K:V0:f][@020:f][@030;VbYP11JN40^K:V00<0
^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`11JN40_[N/0;jg[0040;jg[080@FWQ1P2n]j`00`11JN40
_[N/0;jg[0020;jg[0040:f][@31^[00@FWQ045Yh@@0`KZ`1011JN480<6j/0030:f][@33_K<0`kfc
00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l
00@0al6l00H0@FWQ0<O1_037`K`0al6l045Yh@37`K`2045Yh@D0al6l00@0[Jf]0<K0_011JN40@FWQ
1P36`;`00`11JN40a/2l0<K0_0040<K0_003045Yh@36`;`0[Jf]0080`kfk00<0@FWQ0<>m^`33_K/0
1033_K/01011JN40[Jf]0:f][@33_K/2045Yh@050<>m^`2][Jd0_[Vh0;ji^011JN400`2n^KP2045Y
h@D0_[Vh00<0[Jf]0;B`/@2d/;40202d/;420:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@X0
Y9j?00<0@FWQ0:f][@2aZid0202aZid00`11JN40/J^M045Yh@020;6[W@03045Yh@2i/ZH0^K:V0080
^K:V0P2][Jd2045Yh@030;VbYP11JN40@FWQ00@0^K:V00<0@FWQ0;jg[02n]j`01@2n]j`00`11JN40
_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/0080_[N/00@0[Jf]0<6j/011JN40@FWQ1P31^[04045Y
h@H0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l
045Yh@<0al6l00@0@FWQ0<O1_011JN40@FWQ0`37`K`2045Yh@@0al6l00@0[Jf]0<K0_011JN40@FWQ
1P36`;`00`11JN40a/2l0<K0_0040<K0_003045Yh@36`;`0[Jf]0080`kfk00<0@FWQ0<>m^`33_K/0
0P33_K/00`2][Jd0@FWQ045Yh@030<>m^`05045Yh@33_K/0`kfk0:f][@2n^KP00P11JN430;ji^080
@FWQ1@2n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`
KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:
QGD0102:QGD00`2][Jd0Y9j?0:BNS`080:BNS`80@FWQ102aZid02@11JN40/J^M0;6[W@11JN40/J^M
045Yh@2aZid0@FWQ0;6[W@02045Yh@L0^K:V00@0[Jf]045Yh@11JN40@FWQ102i/ZH00`11JN40_[N/
0;jg[0050;jg[003045Yh@2n]j`0_[N/00@0_[N/00D0@FWQ0;jg[02n]j`0_[N/0:f][@020<6j/080
@FWQ1P31^[02045Yh@P0`KZ`0`11JN4C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1^`38
`K/03P38`K/3045Yh@80b<6k00<0[Jf]045Yh@11JN401037`K`00`11JN40al6l045Yh@050<O1_080
@FWQ0`37`K`0102][Jd0a/2l045Yh@11JN460<K0_080@FWQ1@36`;`2045Yh@050:f][@000000`kfk
045Yh@33_K/00`2][Jd01033_K/0@FWQ0<>m^`11JN420<>m^`05045Yh@33_K/0`kfk0:f][@2n^KP0
0P11JN430;ji^080@FWQ1@2n^KP00`2][Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii
071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0
[Jf]202TWXl2045Yh@@0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN401@2aZid0@FWQ0;6[W@2aZid0
@FWQ00@0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045Yh@<0[Jf]00<0^K:V045Yh@2n]j`01P2n]j`0
0`11JN40_[N/0;jg[0040;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd00P31^[02045Yh@H0`KZ`0P11
JN460<6j/080@FWQ00@0[Jf]0<>m/`33_K<0@FWQ1`33_K<00`11JN40`kfc0<>m/`080<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0=0<S1^`04045Yh@38`K/0b<6k0<S1^`80@FWQ00<0[Jf]045Yh@11
JN401037`K`2045Yh@H0al6l0P11JN430<O1_0040:f][@36`;`0@FWQ045Yh@H0a/2l0P11JN450<K0
_080@FWQ00D0[Jf]0<>m^`2][Jd0@FWQ0:f][@050<>m^`03045Yh@33_K/0`kfk0080`kfk00@0@FWQ
0<>m^`2][Jd0@FWQ1@2n^KP2045Yh@D0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40102][Jd0];2a0;B`
/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C
06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd60:BNS`80@FWQ102aZid00`11JN40
/J^M0;6[W@050;6[W@80@FWQ00<0[Jf]0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;VbYP020;VbYP80
@FWQ0`2i/ZH00`2][Jd0@FWQ0:f][@060;jg[003045Yh@2n]j`0_[N/00@0_[N/00D0@FWQ0;jg[02n
]j`0_[N/0:f][@020<6j/080@FWQ1P31^[02045Yh@D0`KZ`0P11JN400`31^[00[Jf]0<>m/`020<>m
/`03045Yh@33_K<0`kfc00@0`kfc00<0@FWQ0<>m/`33_K<01011JN440<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0@FWQ045Yh@02045Yh@X0b<6k0P11JN440<S1
^`<0@FWQ1@37`K`2045Yh@L0al6l00H0@FWQ0<O1_037`K`0al6l0:f][@36`;`2045Yh@H0a/2l0P11
JN450<K0_080@FWQ0P2][Jd20<>m^`03045Yh@33_K/0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/00`33
_K/2045Yh@H0_[Vh0P11JN450;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1S
H5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`03045Y
h@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid01`2aZid00`2][Jd0^K:V0;VbYP020;VbYP03045Y
h@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40_[N/0:f][@030:f][@80_[N/
00<0@FWQ0;jg[02n]j`0102n]j`01@11JN40_[N/0;jg[02n]j`0[Jf]0080`KZ`00<0@FWQ0<6j/031
^[001@31^[02045Yh@@0`KZ`0P11JN420<6j/0050:f][@33_K<0`kfc0<>m/`11JN401P33_K<3045Y
h@@0`kfc00D0@FWQ0<>m/`33_K<0`kfc0:f][@020<Fn]@03045Yh@35_[D0aKje0140aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/02@38`K/2045Yh@80b<6k0P11JN440<S1^`@0@FWQ2`38`K/2045Yh@H0b<6k0P11JN45
0<O1_080@FWQ1`37`K`01P11JN40al6l0<O1_037`K`0[Jf]0<K0_080@FWQ1P36`;`2045Yh@D0[Jf]
0P11JN401@2][Jd0`kfk0<>m^`33_K/0@FWQ00@0`kfk00<0@FWQ0<>m^`33_K/01@33_K/00`2][Jd0
_[Vh0;ji^0040;ji^080@FWQ1@2n^KP0102][Jd0];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nK
X02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C
0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00@0@FWQ0;6[W@2aZid0/J^M0P11
JN490;6[W@030:f][@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;Vb
YP030;VbYP80@FWQ102n]j`20:f][@03045Yh@2][Jd0_[N/00@0_[N/00D0@FWQ0;jg[02n]j`0_[N/
0:f][@020<6j/003045Yh@31^[00`KZ`00D0`KZ`0P11JN440<6j/080@FWQ0P31^[000`2][Jd0`kfc
0<>m/`020<>m/`03045Yh@33_K<0`kfc00<0`kfc00<0@FWQ0<>m/`33_K<01033_K<01@11JN40`kfc
0<>m/`33_K<0[Jf]0080aKje0P11JN4B0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0?0<O1^P0300000037`KX0al6j00<0al6j00<0[Jf]0<S1^`38
`K/01`38`K/2045Yh@80b<6k1011JN450<S1^`030:f][@11JN40@FWQ00/0b<6k0P11JN460<S1^`80
@FWQ1@37`K`2045Yh@L0al6l00H0@FWQ0<O1_037`K`0al6l0:f][@36`;`2045Yh@@0a/2l0P2][Jd2
045Yh@D0a/2l0P11JN401@2][Jd0`kfk0<>m^`33_K/0@FWQ00<0`kfk00<0@FWQ0<>m^`33_K/01P33
_K/00`2][Jd0_[Vh0;ji^0040;ji^080@FWQ1@2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C
0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`04045Yh@2aZid0/J^M0;6[W@80
@FWQ202aZid00`2][Jd0^K:V0;VbYP040;VbYPD0@FWQ1@2i/ZH2045Yh@D0_[N/0P11JN400`2n]j`0
[Jf]0:f][@020:f][@030;jg[011JN40_[N/0080_[N/00@0[Jf]0<6j/031^[00@FWQ1`31^[02045Y
h@@0`KZ`00D0@FWQ0<6j/031^[00`KZ`0:f][@0:0<>m/`03045Yh@33_K<0`kfc00D0`kfc00@0@FWQ
0<>m/`33_K<0[Jf]0P35_[D00`11JN40aKje0<Fn]@0A0<Fn]@030:f][@36_kL0a[ng00@0a[ng2P11
JN470<Jo]`030:f][@37`KP0al6h01<0al6h0P11JN450<O1^P03045Yh@37`KX0al6j00D0al6j00<0
@FWQ0<O1^P37`KX00`37`KX01@11JN40al6j0<O1^P37`KX0[Jf]00L0b<6k0`11JN440<S1^`<0@FWQ
1@38`K/00`2][Jd0@FWQ045Yh@0;0<S1^`80@FWQ1P38`K/2045Yh@D0al6l0P11JN470<O1_006045Y
h@37`K`0al6l0<O1_02][Jd0a/2l0P11JN440:f][@80a/2l0P11JN450<K0_080@FWQ00<0[Jf]0<>m
^`33_K/00P33_K/4045Yh@P0`kfk00<0[Jf]0;ji^02n^KP0102n^KP2045Yh@D0_[Vh0`2][Jd80;B`
/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0
Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd3045Yh@030;6[W@11JN40/J^M00L0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`11JN40_[N/045Yh@040;jg[080@FWQ1@2n]j`01P2][Jd0
@FWQ0:f][@2][Jd0_[N/0:f][@80`KZ`00<0@FWQ0<6j/031^[001@31^[000`11JN40`KZ`0<6j/003
0<6j/005045Yh@31^[00`KZ`0<6j/02][Jd02P33_K<00`11JN40`kfc0<>m/`050<>m/`04045Yh@33
_K<0`kfc0:f][AH0aKje00<0[Jf]0<Jo]`36_kL01`36_kL2045Yh@@0a[ng0`11JN450<Jo]`030:f]
[@11JN40@FWQ00@0@FWQ3@37`KP2045Yh@030<O1^011JN40al6j0080al6j0P11JN480<O1^P03045Y
h@37`KX0al6j00<0al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@060<S1^`80@FWQ1`38`K/2045Yh@D0
b<6k00<0[Jf]045Yh@11JN402`38`K/2045Yh@H0b<6k0P11JN450<O1_080@FWQ1`37`K`00`11JN40
al6l0:f][@030:f][@80@FWQ1P36`;`2045Yh@D0a/2l0P11JN400`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00@0_[Vh0P11JN440;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX003
0:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
0P2][Jd30;6[W@03045Yh@2aZid0/J^M00H0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH01@11JN40^K:V
045Yh@2n]j`0@FWQ00<0_[N/0P11JN460;jg[080@FWQ0P2n]j`40:f][@03045Yh@31^[00`KZ`00D0
`KZ`00<0@FWQ0<6j/031^[000`31^[001@11JN40`KZ`0<6j/031^[00[Jf]0180`kfc00@0@FWQ0<>m
/`33_K<0[Jf]5P35_[D00`2][Jd0a[ng0<Jo]`070<Jo]`80@FWQ1P36_kL2045Yh@@0a[ng00<0[Jf]
0<O1^037`KP00P11JN4=0<O1^080@FWQ0`37`KP0102][Jd0@FWQ0<O1^P37`KX2045Yh@P0al6j00<0
@FWQ0<O1^P37`KX00`37`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11
JN450<S1^`030:f][@11JN40@FWQ00/0b<6k0P11JN460<S1^`80@FWQ1@37`K`2045Yh@@0al6l0`2]
[Jd01P11JN40[Jf]0<O1_037`K`0[Jf]0<K0_080@FWQ1P36`;`00`11JN40a/2l0<K0_0040<K0_080
@FWQ00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^003045Yh@2n^KP0_[Vh0080
[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00
F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M
00<0[Jf]0;VbYP2i/ZH03@2i/ZH2045Yh@80_[N/00@0@FWQ0;jg[02n]j`0@FWQ1`2n]j`2045Yh@<0
_[N/00@0[Jf]0<6j/031^[00@FWQ1`2][Jd00`11JN40`KZ`0<6j/0030<6j/005045Yh@31^[00`KZ`
0<6j/02][Jd04@33_K<2045Yh@80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`07
0<Jo]`80@FWQ1P36_kL2045Yh@@0a[ng00<0[Jf]0<O1^037`KP00P11JN4<0<O1^080@FWQ1037`KP0
0`2][Jd0al6j045Yh@02045Yh@P0al6j0`11JN430<O1^P<0@FWQ0P37`KX00`2][Jd0b<6k0<S1^`04
0<S1^`80@FWQ1`38`K/2045Yh@D0b<6k00<0[Jf]045Yh@11JN403038`K/2045Yh@D0b<6k0P11JN45
0<O1_080@FWQ102][Jd20<O1_080@FWQ0`37`K`00`2][Jd0a/2l0<K0_002045Yh@@0a/2l0P11JN44
0<K0_0@0@FWQ00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0060;ji^080[Jf]0`2n^KP0
0`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3P
iP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[
W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP040:f][@2n]j`0_[N/0;jg[080@FWQ202n]j`2
045Yh@<0_[N/00@0[Jf]0<6j/031^[00@FWQ1`31^[000`11JN40[Jf]0:f][@030:f][@05045Yh@31
^[00`KZ`0<6j/02][Jd04033_K<2045Yh@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`070<Jo]`80@FWQ1`36_kL2045Yh@<0a[ng00<0[Jf]0<O1^037`KP00P11JN4<0<O1^080@FWQ
1@37`KP0102][Jd0al6j045Yh@11JN480<O1^P<0@FWQ0`37`KX3045Yh@80al6j00<0[Jf]0<S1^`38
`K/00`38`K/2045Yh@P0b<6k0P11JN450<S1^`030:f][@11JN40@FWQ00d0b<6k1011JN420<S1^`03
0:f][@11JN40al6l00@0[Jf]0P11JN460<O1_080@FWQ0`37`K`00`2][Jd0a/2l0<K0_002045Yh@@0
a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0
/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/00/0_[N/0`11JN420;jg[0040:f][@31^[00@FWQ045Yh@L0`KZ`00<0@FWQ0<6j/031
^[000`31^[000`11JN40[Jf]0:f][@050:f][@/0`kfc0`11JN440<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL01`36_kL2045Yh@L0a[ng0P11JN430<Jo]`030:f][@37`KP0al6h0080
@FWQ3037`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40@FWQ2037`KX3045Yh@<0al6j0`11JN420<O1
^P030:f][@38`K/0b<6k00<0b<6k0P11JN480<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@0@0<S1
^`030:f][@11JN40@FWQ0080@FWQ00<0[Jf]0<O1_037`K`00P37`K`2045Yh@H0al6l00<0@FWQ0<O1
_037`K`00P37`K`00`2][Jd0a/2l0<K0_006045Yh@/0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102]
[Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX003
09nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2]
[Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0?0;Vb
YP030:f][@2n]j`0_[N/00/0_[N/0P11JN401@2n]j`0@FWQ0;jg[02][Jd0`KZ`0080@FWQ1`31^[00
0`11JN40`KZ`0<6j/0030<6j/080@FWQ0P31^[001@2][Jd0`kfc0<>m/`33_K<0@FWQ00H0[Jf]0P33
_K<4045Yh@D0`kfc00@0[Jf]0<Fn]@35_[D0@FWQ4`35_[D00`2][Jd0a[ng0<Jo]`070<Jo]`80@FWQ
2036_kL01@11JN40a[ng0<Jo]`36_kL0[Jf]0080al6h0P11JN4<0<O1^080@FWQ1@37`KP0102][Jd0
al6j045Yh@11JN480<O1^P03045Yh@37`KX0@FWQ00<0al6j0P11JN401037`KX0@FWQ0<O1^P2][Jd5
0<S1^`80@FWQ2038`K/2045Yh@D0b<6k00<0[Jf]045Yh@11JN402@38`K/70:f][@<0b<6k00<0[Jf]
045Yh@37`K`01037`K`2045Yh@D0al6l0P11JN440<O1_0030:f][@36`;`0a/2l0080@FWQ3`36`;`0
0`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]
08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd?
0;VbYP030:f][@2n]j`0_[N/00/0_[N/0P11JN420;jg[0D0@FWQ1`31^[000`11JN40`KZ`0<6j/003
0<6j/080@FWQ0P31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@D0`kfc1011JN440:f][@<0`kfc00@0
[Jf]0<Fn]@35_[D0@FWQ4`35_[D00`2][Jd0a[ng0<Jo]`070<Jo]`80@FWQ2036_kL01@11JN40a[ng
0<Jo]`36_kL0[Jf]0080al6h0P11JN4<0<O1^080@FWQ1@37`KP0102][Jd0al6j045Yh@11JN480<O1
^P03045Yh@37`KX0@FWQ00<0al6j00H0@FWQ0<O1^P37`KX0@FWQ0<O1^P2][Jd40<S1^`80@FWQ1`38
`K/7045Yh@80b<6k00@0[Jf]045Yh@11JN40b<6k202][Jd:0<S1^`030:f][@11JN40al6l00@0al6l
0P11JN450<O1_003045Yh@37`K`0al6l00<0al6l00<0[Jf]0<K0_036`;`00P11JN4?0<K0_0030:f]
[@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00
0P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2a
Zid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/00/0_[N/0P11
JN430;jg[0030:f][@31^[00`KZ`00P0`KZ`00<0@FWQ0<6j/031^[001031^[001011JN40`KZ`0<6j
/02][Jd30<>m/`80@FWQ1@33_K<2045Yh@H0`kfc1P2][Jd00`11JN40[Jf]0:f][@0A0<Fn]@030:f]
[@36_kL0a[ng00L0a[ng0P11JN480<Jo]`80@FWQ0P36_kL00`2][Jd0al6h0<O1^002045Yh@d0al6h
0P11JN440<O1^0040:f][@37`KX0@FWQ045Yh@L0al6j0P11JN401037`KX0@FWQ0<O1^P37`KX2045Y
h@80al6j00<0@FWQ0<O1^P2][Jd01038`K/2045Yh@/0b<6k1P2][Jd2045Yh@030:f][@38`K/0b<6k
00T0b<6k0P11JN450<S1^`030:f][@11JN40al6l00@0al6l0`11JN420<O1_080@FWQ1P37`K`00`2]
[Jd0a/2l0<K0_002045Yh@l0a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh
00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP03
0:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0
[Jf]202i/ZH00`2][Jd0_[N/0;jg[00;0;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0@0
@FWQ1`31^[000`11JN40`KZ`0:f][@030<>m/`03045Yh@33_K<0`kfc00<0`kfc00<0@FWQ0<>m/`33
_K<01P33_K<01011JN40`kfc0<>m/`2][Jd20<Fn]@03045Yh@35_[D0aKje00`0[Jf]1@35_[D00`2]
[Jd0a[ng0<Jo]`070<Jo]`80@FWQ2036_kL2045Yh@80a[ng00<0[Jf]0<O1^037`KP00P11JN4>0<O1
^003045Yh@37`KP0al6h0080al6h00@0[Jf]0<O1^P11JN40@FWQ1`37`KX2045Yh@80al6j00@0@FWQ
0<O1^P11JN40@FWQ0P37`KX00`11JN40al6j0:f][@040<S1^`80@FWQ2`2][Jd50<S1^`040:f][@11
JN40@FWQ045Yh@@0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@D0b<6k00<0@FWQ0<O1_037`K`0
1037`K`2045Yh@030<O1_011JN40@FWQ00T0al6l00@0[Jf]0<K0_011JN40@FWQ3036`;`01011JN40
a/2l0<K0_02][Jd80<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a
00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@03
0:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/00/0_[N/0P11JN430;jg[003
0:f][@31^[00`KZ`0140`KZ`00<0@FWQ0:f][@33_K<00P33_K<00`11JN40`kfc0<>m/`030<>m/`03
045Yh@33_K<0`kfc00D0`kfc0P11JN420<>m/`040:f][@35_[D0aKje045Yh@h0aKje3`2][Jd2045Y
h@P0a[ng0P11JN420<Jo]`030:f][@37`KP0al6h0080@FWQ3`37`KP3045Yh@030<O1^02][Jd0al6j
0080@FWQ1`37`KX01P11JN40[Jf]0:f][@2][Jd0@FWQ0:f][@80@FWQ0`2][Jd00`11JN40[Jf]0:f]
[@030:f][@80@FWQ4038`K/0102][Jd0@FWQ045Yh@11JN440<S1^`80@FWQ1P38`K/00`11JN40b<6k
0<S1^`020<S1^`03045Yh@2][Jd0al6l00<0al6l0P11JN4>0<O1_0040:f][@36`;`0@FWQ045Yh@`0
a/2l0P11JN400`36`;`0[Jf]0<>m^`030<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^003
0:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?
0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;Vb
YP2][Jd0_[N/00`0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`0180`KZ`1011JN470<>m/`03045Y
h@33_K<0`kfc00@0`kfc0P11JN420<>m/`040:f][@35_[D0aKje045YhA<0aKje00<0[Jf]0<Jo]`36
_kL01`36_kL2045Yh@P0[Jf]0P11JN450:f][@80@FWQ4P2][Jd5045Yh@L0[Jf]00H0@FWQ0<O1^P37
`KX0al6j045Yh@37`KX2045Yh@<0al6j00<0@FWQ0:f][@38`K/00`38`K/2045YhA00b<6k00@0[Jf]
045Yh@11JN40@FWQ1038`K/2045Yh@L0b<6k1011JN400`38`K/0[Jf]0<O1_00C0<O1_0040:f][@36
`;`0@FWQ045Yh@`0a/2l00D0@FWQ0<K0_036`;`0[Jf]0<>m^`030:f][@/0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]302n]j`2045Yh@<0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`090<>m/`03045Yh@33_K<0`kfc0080`kfc
0`11JN420<>m/`040:f][@35_[D0aKje045YhA<0aKje00<0[Jf]0<Jo]`36_kL01`36_kL00`11JN40
a[ng0<Jo]`070<Jo]`80@FWQ0P36_kL00`2][Jd0al6h0<O1^003045YhA80al6h00@0[Jf]0<O1^P11
JN40@FWQ1`37`KX01P11JN40al6j0<O1^P37`KX0@FWQ0<O1^P80@FWQ0`37`KX00`11JN40[Jf]0<S1
^`030<S1^`80@FWQ4038`K/01@2][Jd0@FWQ045Yh@38`K/0@FWQ00<0b<6k00<0@FWQ0<S1^`38`K/0
2`38`K/00`2][Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0@FWQ045Yh@d0a/2l102][Jd>0<>m^`03
0:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40
oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02][Jd00`2][Jd80;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc00X0`kfc1011JN420<>m/`05045Yh@33_K<0`kfc0:f][@35_[D00P11JN4C0<Fn]@03
0:f][@36_kL0a[ng00L0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL2045Yh@80a[ng00<0[Jf]0<O1^037
`KP00`11JN440<O1^003045Yh@37`KP0al6h00D0al6h0P11JN440<O1^0030:f][@37`KX0@FWQ00P0
al6j00L0@FWQ0<O1^P37`KX0al6j045Yh@37`KX0@FWQ00@0al6j00<0@FWQ0:f][@38`K/00`38`K/2
045Yh@l0b<6k1011JN420<S1^`<0@FWQ3P38`K/00`2][Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0
@FWQ045Yh@P0a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n
^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd2
0;jg[0@0@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@11JN400P11JN4B0<Fn]@030:f][@36_kL0a[ng00L0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL2
045Yh@80a[ng00<0[Jf]0<O1^037`KP00`11JN440<O1^080@FWQ1P37`KP2045Yh@@0al6h00<0[Jf]
0<O1^P11JN401`37`KX00`11JN40al6j0<O1^P030<O1^P80@FWQ1@37`KX00`2][Jd0b<6k0<S1^`02
0<S1^`80@FWQ4038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00@0[Jf]
0<K0_011JN40@FWQ1036`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0
[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102]
[Jd50;jg[0030:f][@31^[00`KZ`00L0`KZ`00<0@FWQ0<6j/031^[002031^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0@FWQ0080@FWQ4P35_[D00`2][Jd0a[ng0<Jo]`070<Jo]`03045Yh@36
_kL0a[ng00L0a[ng0P11JN420<Jo]`030:f][@37`KP0al6h0080@FWQ00<0al6h045Yh@37`KP00P37
`KP2045Yh@L0al6h00<0@FWQ0<O1^037`KP00P37`KP00`2][Jd0@FWQ0<O1^P070<O1^P03045Yh@37
`KX0al6j00<0al6j0P11JN420<O1^PH0@FWQ0P38`K/2045Yh@X0b<6k00<0@FWQ0<S1^`38`K/00`38
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l0P11JN400`36`;`0[Jf]0:f]
[@030:f][@/0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d
/;40];2a0:f][E80/>3V0@3oool006/0/>3V0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`00P0`KZ`0P11JN490<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@11JN400P11JN4B0<Fn]@030:f][@36_kL0a[ng00L0a[ng00<0
@FWQ0<Jo]`36_kL01`36_kL2045Yh@80a[ng00<0[Jf]045Yh@11JN400P11JN420<O1^0@0@FWQ2@37
`KP5045Yh@H0al6j1`11JN420<O1^P80@FWQ1@37`KX00`2][Jd0b<6k0<S1^`030<S1^`80@FWQ2@38
`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04037
`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`
h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?
0;jg[0D0[Jf]1P31^[000`11JN40`KZ`0<6j/0080<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@11JN400P11JN4B0<Fn]@030:f][@36_kL0a[ng00L0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL0
1@11JN40a[ng0<Jo]`36_kL0[Jf]01L0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`030<S1^`80@FWQ2@38`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2]
[Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@11JN400P11JN4B0<Fn]@030:f][@36
_kL0a[ng00L0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL01@11JN40a[ng0<Jo]`36_kL0[Jf]01L0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`030<S1^`80@FWQ2@38`K/00`11JN40b<6k
0<S1^`030<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`60:f][@L0al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh
0`2][JeG0;3PiP40oooo001a0;3PiP<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002031^[070:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje045Yh@02045YhA80aKje00<0[Jf]0<Jo]`36_kL01`36_kL00`11JN40a[ng0<Jo
]`070<Jo]`05045Yh@36_kL0a[ng0<Jo]`2][Jd05`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k00@0b<6k0P11JN480<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31
^[070:f][A80`kfc00<0[Jf]0<Fn]@11JN400P11JN4B0<Fn]@030:f][@36_kL0a[ng00L0a[ng00<0
@FWQ0<Jo]`36_kL01P36_kL2045Yh@<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k00D0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@D0b<6k00<0
[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00
102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00@0[Jf]0<Fn]@11JN40@FWQ4`35_[D00`2][Jd0a[ng
0<Jo]`070<Jo]`03045Yh@36_kL0a[ng00H0a[ng0P11JN430<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k00<0b<6k
00<0@FWQ0<S1^`11JN401@38`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33
_K<0102][Jd0aKje0<Fn]@11JN4C0<Fn]@030:f][@36_kL0a[ng00L0a[ng00<0@FWQ0<Jo]`36_kL0
1@36_kL2045Yh@@0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k00L0b<6k1@11JN420<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`38`K/0
b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JdA0<Fn]@030:f]
[@36_kL0a[ng00L0a[ng00<0@FWQ0<Jo]`36_kL01036_kL2045Yh@D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]
I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0
[Jf]0<Jo]`36_kL01036_kL:045Yh@L0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2]
[JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL0
0`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H1
0?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo
]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00h0al6j0P0000040<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`4
0:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`h>H10?oo
o`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0
[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0[Jf]V@2`
h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][JfW
0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`h>H10?oo
o`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52269 .33862 m
.52601 .34087 L
s
.50614 .3385 m
.52269 .33862 L
s
.52269 .33862 m
.52766 .34086 L
s
.5409 .33847 m
.55247 .33823 L
s
.52601 .34087 m
.52932 .34536 L
s
.52766 .34086 m
.53098 .34535 L
s
.52932 .34536 m
.53098 .34986 L
s
.53098 .34535 m
.53264 .34985 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53098 .34986 m
.53265 .35663 L
s
.53264 .34985 m
.53431 .35662 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57552 .33965 m
.58042 .33716 L
s
.57391 .34424 m
.57552 .33965 L
s
.57716 .33958 m
.58042 .33716 L
s
.58042 .33716 m
.58532 .3369 L
s
.57555 .34417 m
.57716 .33958 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5127 .38614 m
.51276 .33858 L
s
.51104 .38613 m
.5111 .33856 L
s
.54586 .33838 m
.54595 .37004 L
s
.54751 .33835 m
.54761 .37001 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53265 .35663 m
.53266 .36796 L
s
.53431 .35662 m
.53433 .36794 L
s
.57391 .34424 m
.57394 .34877 L
s
.58532 .3369 m
.58861 .33897 L
s
.54757 .35641 m
.54925 .36317 L
s
.57555 .34417 m
.57558 .34869 L
s
.57394 .34877 m
.57561 .35322 L
s
.58861 .33897 m
.5919 .3433 L
s
.57558 .34869 m
.57725 .35314 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45127 .33638 m
.45288 .33874 L
s
.44962 .33853 m
.45127 .33638 L
s
.45123 .3409 m
.45288 .33874 L
s
.54925 .36317 m
.55258 .36763 L
s
.59349 .33868 m
.59672 .33621 L
s
.5919 .3433 m
.59349 .33868 L
s
.59672 .33621 m
.59834 .3361 L
s
.59512 .33857 m
.59672 .33621 L
s
.53101 .37478 m
.53266 .36796 L
s
.53267 .37477 m
.53433 .36794 L
s
.59353 .3432 m
.59512 .33857 L
s
.57561 .35322 m
.58055 .35525 L
s
.44962 .33853 m
.45123 .3409 L
s
.57725 .35314 m
.58055 .35525 L
s
.55919 .36518 m
.56083 .36286 L
s
.56083 .36286 m
.56249 .36507 L
s
.54097 .37013 m
.54761 .37001 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55258 .36763 m
.5559 .36981 L
s
.55919 .36518 m
.56085 .36739 L
s
.56249 .36507 m
.56251 .36734 L
s
.58055 .35525 m
.59039 .35699 L
s
.52935 .37934 m
.53101 .37478 L
s
.53101 .37933 m
.53267 .37477 L
s
.5559 .36981 m
.56086 .36966 L
s
.56086 .36966 m
.56251 .36734 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57567 .36229 m
.57568 .36456 L
s
.57567 .36229 m
.57731 .36221 L
s
.57731 .36221 m
.57733 .36448 L
s
.52602 .3839 m
.52935 .37934 L
s
.52769 .3839 m
.53101 .37933 L
s
.43348 .3351 m
.43668 .33761 L
s
.43668 .33761 m
.43827 .34 L
s
.4382 .3468 m
.43827 .34 L
s
.42706 .33456 m
.43348 .3351 L
s
.45113 .35222 m
.45253 .37962 L
s
.44926 .37942 m
.45113 .35222 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57568 .36456 m
.57734 .36675 L
s
.59353 .3432 m
.59367 .35907 L
s
.5919 .3433 m
.59208 .36371 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60676 .36731 m
.61288 .33502 L
s
.59039 .35699 m
.59204 .35916 L
s
.52269 .38618 m
.52602 .3839 L
s
.57734 .36675 m
.58065 .36887 L
s
.52269 .38618 m
.52769 .3839 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50604 .38607 m
.52269 .38618 L
s
.43658 .34668 m
.43822 .34453 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58065 .36887 m
.58721 .36853 L
s
.42384 .33655 m
.42706 .33456 L
s
.59208 .36371 m
.59367 .35907 L
s
.43656 .34895 m
.4382 .3468 L
s
.60838 .36719 m
.61295 .34181 L
s
.43333 .3487 m
.43658 .34668 L
s
.59046 .36608 m
.59208 .36371 L
s
.43331 .35097 m
.43656 .34895 L
s
.58721 .36853 m
.59046 .36608 L
s
.42221 .33867 m
.42384 .33655 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42068 .33399 m
.42221 .33867 L
s
.42056 .34306 m
.42068 .33399 L
s
.42525 .35258 m
.43333 .3487 L
s
.45089 .37952 m
.45101 .36585 L
s
.42522 .35486 m
.43331 .35097 L
s
.42056 .34306 m
.42221 .33867 L
s
.43641 .36259 m
.43808 .35815 L
s
.43798 .36726 m
.43808 .35815 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43477 .36474 m
.43641 .36259 L
s
.43641 .36259 m
.43798 .36726 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45085 .38409 m
.45253 .37962 L
s
.42202 .35458 m
.42525 .35258 L
s
.43152 .36678 m
.43477 .36474 L
s
.42199 .35686 m
.42522 .35486 L
s
.44926 .37942 m
.45085 .38409 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60189 .36764 m
.61323 .36683 L
s
.62127 .36617 m
.62576 .3407 L
s
.61967 .36631 m
.62567 .3339 L
s
.62567 .3339 m
.63245 .36517 L
s
.61288 .33502 m
.61967 .36631 L
s
0 0 0 r
.64756 .34908 m
.64856 .34979 L
s
.255 .412 .882 r
.42039 .35671 m
.42202 .35458 L
s
.40639 .33483 m
.40948 .33971 L
s
.40172 .33205 m
.40639 .33483 L
s
.42508 .36626 m
.43152 .36678 L
s
.42036 .35899 m
.42199 .35686 L
s
.42033 .36128 m
.42039 .35671 L
s
.39859 .33169 m
.40172 .33205 L
s
.4219 .3637 m
.42508 .36626 L
s
.42033 .36128 m
.4219 .3637 L
s
.39544 .3336 m
.39859 .33169 L
s
.39388 .33341 m
.39859 .33169 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40562 .35344 m
.40584 .355 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64628 .33859 m
.64933 .33367 L
s
.39226 .33778 m
.39544 .3336 L
s
.62767 .36561 m
.63721 .3647 L
s
.40771 .35321 m
.40926 .35566 L
s
.4061 .35533 m
.40771 .35321 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64478 .34332 m
.64628 .33859 L
s
.64933 .33367 m
.65396 .33083 L
s
.65089 .33349 m
.65396 .33083 L
s
.64784 .33841 m
.65089 .33349 L
s
.40923 .35794 m
.40926 .35566 L
s
.64635 .34314 m
.64784 .33841 L
s
.64332 .35033 m
.64478 .34332 L
s
.39071 .33759 m
.39388 .33341 L
s
.406 .36219 m
.40923 .35794 L
s
.65396 .33083 m
.65705 .33045 L
s
.64489 .35016 m
.64635 .34314 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4061 .35533 m
.40765 .35778 L
s
.64332 .35033 m
.64349 .36176 L
s
.65705 .33045 m
.66171 .33213 L
s
.64489 .35016 m
.64506 .36159 L
s
.39059 .34444 m
.39226 .33778 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38904 .34425 m
.39071 .33759 L
s
.40282 .36415 m
.406 .36219 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37244 .32828 m
.38311 .32977 L
s
.64349 .36176 m
.64516 .36846 L
s
.66171 .33213 m
.66485 .33628 L
s
.39052 .34901 m
.39059 .34444 L
s
.3981 .36364 m
.40282 .36415 L
s
.64506 .36159 m
.64673 .3683 L
s
.38897 .34882 m
.38904 .34425 L
s
.39052 .34901 m
.39196 .35606 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37795 .36121 m
.37852 .32915 L
s
.38897 .34882 m
.39041 .35587 L
s
.39501 .361 m
.3981 .36364 L
s
.39345 .36082 m
.3981 .36364 L
s
.37642 .36101 m
.377 .32893 L
s
.39196 .35606 m
.39501 .361 L
s
.39041 .35587 m
.39345 .36082 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64673 .3683 m
.64837 .37271 L
s
.64516 .36846 m
.6468 .37289 L
s
.66626 .32923 m
.66659 .34752 L
s
.66473 .32944 m
.66505 .34772 L
s
.66044 .34832 m
.67116 .3469 L
s
.6468 .37289 m
.65001 .37714 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64837 .37271 m
.65157 .37697 L
s
.67537 .32793 m
.68585 .32631 L
s
.65001 .37714 m
.65473 .37891 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65157 .37697 m
.65473 .37891 L
s
.35598 .32573 m
.36641 .32739 L
s
.67988 .32725 m
.6805 .3594 L
s
.68138 .32702 m
.68201 .35918 L
s
.65473 .37891 m
.65784 .37855 L
s
.37185 .36039 m
.37795 .36121 L
s
.66687 .36359 m
.66711 .37742 L
s
.66546 .37069 m
.66687 .36359 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65784 .37855 m
.66245 .37569 L
s
.66245 .37569 m
.66546 .37069 L
s
.66546 .37069 m
.66711 .37742 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36306 .34863 m
.36315 .34811 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36142 .35195 m
.36192 .32669 L
s
.35993 .35172 m
.36043 .32645 L
s
.68174 .34536 m
.68337 .35204 L
s
.37613 .37714 m
.3777 .37503 L
s
.37621 .37252 m
.3777 .37503 L
s
.37464 .37463 m
.37621 .37252 L
s
.67597 .36005 m
.68201 .35918 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37464 .37463 m
.37613 .37714 L
s
.33995 .3229 m
.3501 .32473 L
s
.68337 .35204 m
.68645 .35619 L
s
.35983 .35633 m
.36142 .35195 L
s
.35834 .3561 m
.35993 .35172 L
s
.35532 .35794 m
.35983 .35633 L
s
.68645 .35619 m
.68948 .35804 L
s
.35532 .35794 m
.35834 .3561 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34321 .37225 m
.34428 .3237 L
s
.34467 .3725 m
.34573 .32396 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35236 .35747 m
.35532 .35794 L
s
.69234 .35295 m
.69377 .3504 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69377 .3504 m
.69529 .35246 L
s
.69234 .35295 m
.69387 .35502 L
s
.68948 .35804 m
.69392 .35733 L
s
.348 .35443 m
.35236 .35747 L
s
.70636 .32504 m
.7106 .32192 L
s
.70503 .32992 m
.70636 .32504 L
s
.69529 .35246 m
.69534 .35477 L
s
.70503 .32992 m
.70513 .33453 L
s
.69392 .35733 m
.69534 .35477 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70779 .32477 m
.7106 .32192 L
s
.70646 .32965 m
.70779 .32477 L
s
.70646 .32965 m
.70657 .33426 L
s
.70513 .33453 m
.70667 .33888 L
s
.34517 .34931 m
.348 .35443 L
s
.7106 .32192 m
.71485 .32107 L
s
.70657 .33426 m
.70811 .33861 L
s
.70667 .33888 m
.71102 .34039 L
s
.70811 .33861 m
.71102 .34039 L
s
.71485 .32107 m
.71772 .32281 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70688 .34813 m
.70694 .35045 L
s
.70688 .34813 m
.70832 .34787 L
s
.70694 .35045 m
.70843 .3525 L
s
.32711 .3227 m
.32981 .32789 L
s
.32981 .32789 m
.33106 .3351 L
s
.71102 .34039 m
.71957 .34105 L
s
.70832 .34787 m
.70837 .35019 L
s
.71772 .32281 m
.72063 .32686 L
s
.32298 .31951 m
.32711 .3227 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32571 .32241 m
.32841 .3276 L
s
.32841 .3276 m
.32965 .33483 L
s
.33095 .33973 m
.33106 .3351 L
s
.30974 .30023 m
.31924 .30244 L
s
.70843 .3525 m
.71135 .3543 L
s
.33885 .37151 m
.34467 .3725 L
s
.32298 .31951 m
.32571 .32241 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32954 .33946 m
.32965 .33483 L
s
.32937 .34641 m
.33095 .33973 L
s
.32021 .31891 m
.32298 .31951 L
s
.72834 .30195 m
.73779 .29971 L
s
.72191 .32194 m
.72463 .31903 L
s
.72063 .32686 m
.72191 .32194 L
s
.32796 .34614 m
.32954 .33946 L
s
.72063 .32686 m
.72114 .34774 L
s
.71135 .3543 m
.71703 .35322 L
s
.7233 .32164 m
.72463 .31903 L
s
.72202 .32656 m
.7233 .32164 L
s
.72202 .32656 m
.72242 .3428 L
s
.72463 .31903 m
.72601 .31873 L
s
.3174 .32062 m
.32021 .31891 L
s
.32644 .35051 m
.32937 .34641 L
s
.32504 .35023 m
.32796 .34614 L
s
0 0 0 r
.72805 .34607 m
.72823 .34714 L
s
.255 .412 .882 r
.71957 .34105 m
.72103 .34309 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31389 .35026 m
.31514 .30151 L
s
.31253 .34996 m
.31378 .30119 L
s
.31455 .32465 m
.3174 .32062 L
s
.71703 .35322 m
.71979 .35034 L
s
.32218 .352 m
.32644 .35051 L
s
.71979 .35034 m
.72114 .34774 L
s
.72114 .34774 m
.72242 .3428 L
s
.32218 .352 m
.32504 .35023 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3194 .35143 m
.32218 .352 L
s
.73437 .32385 m
.73695 .31857 L
s
.3167 .34851 m
.3194 .35143 L
s
.73695 .31857 m
.73956 .31561 L
s
.3053 .31548 m
.30663 .3158 L
s
.31407 .34326 m
.3167 .34851 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73956 .31561 m
.74221 .31496 L
s
.30259 .31715 m
.3053 .31548 L
s
.30391 .31748 m
.3053 .31548 L
s
.74221 .31496 m
.74491 .31663 L
s
.74221 .31496 m
.74622 .31629 L
s
.30246 .32181 m
.30391 .31748 L
s
.30845 .34906 m
.31389 .35026 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72958 .35067 m
.73504 .34949 L
s
.73377 .30068 m
.73504 .34949 L
s
.73242 .301 m
.73368 .34978 L
s
.73486 .34248 m
.73768 .34654 L
s
.30114 .32148 m
.30259 .31715 L
s
.30202 .33815 m
.30246 .32181 L
s
0 0 0 r
.28291 .30187 m
.2848 .3024 L
s
.255 .412 .882 r
.74491 .31663 m
.74766 .32062 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29864 .31616 m
.30114 .32148 L
s
.30057 .34252 m
.30114 .32148 L
s
.74622 .31629 m
.74896 .32029 L
s
.73768 .34654 m
.74043 .34827 L
s
.29611 .31316 m
.29864 .31616 L
s
.29224 .31213 m
.29611 .31316 L
s
.74766 .32062 m
.74916 .3273 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30057 .34252 m
.30202 .33815 L
s
.74043 .34827 m
.7431 .34764 L
s
.74896 .32029 m
.75045 .32697 L
s
.29944 .33517 m
.30069 .33783 L
s
.29171 .33085 m
.29944 .33517 L
s
.7431 .34764 m
.74568 .34467 L
s
.7431 .34764 m
.747 .34435 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28962 .31377 m
.29224 .31213 L
s
.28835 .31343 m
.29224 .31213 L
s
.29918 .34454 m
.30057 .34252 L
s
.74916 .3273 m
.74929 .33198 L
s
.75045 .32697 m
.75059 .33165 L
s
.74568 .34467 m
.74818 .33934 L
s
.74818 .33934 m
.74929 .33198 L
s
.2965 .34625 m
.29918 .34454 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7648 .3032 m
.76586 .30425 L
s
.255 .412 .882 r
.747 .34435 m
.74948 .33901 L
s
.74948 .33901 m
.75059 .33165 L
s
.28822 .31811 m
.28962 .31377 L
s
.28695 .31776 m
.28835 .31343 L
s
.29131 .34494 m
.2965 .34625 L
s
.28922 .32782 m
.29171 .33085 L
s
.28795 .32748 m
.29171 .33085 L
s
.28808 .32279 m
.28822 .31811 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75773 .31088 m
.76643 .30836 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28682 .32244 m
.28695 .31776 L
s
.28808 .32279 m
.28922 .32782 L
s
.76149 .30981 m
.76295 .35928 L
s
.28682 .32244 m
.28795 .32748 L
s
.76274 .30945 m
.7642 .35894 L
s
.28881 .34192 m
.29131 .34494 L
s
.28768 .33688 m
.28895 .33722 L
s
.28888 .33957 m
.28895 .33722 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28761 .33923 m
.28768 .33688 L
s
.28761 .33923 m
.28881 .34192 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7635 .3353 m
.76612 .33932 L
s
.77129 .30687 m
.77957 .3042 L
s
.75916 .36027 m
.7642 .35894 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26305 .30326 m
.27123 .30597 L
s
.27646 .33375 m
.27761 .33646 L
s
.27754 .33883 m
.27761 .33646 L
s
.27517 .33575 m
.27646 .33375 L
s
.27625 .34084 m
.27754 .33883 L
s
.27517 .33575 m
.27632 .33847 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77605 .30536 m
.77687 .33134 L
s
.77487 .30574 m
.77568 .33171 L
s
.76612 .33932 m
.76988 .34063 L
s
.2726 .33977 m
.27625 .34084 L
s
.26665 .33795 m
.26769 .30482 L
s
.76988 .34063 m
.7723 .33991 L
s
.26547 .33758 m
.26652 .30443 L
s
.7723 .33991 m
.77464 .33682 L
s
.7723 .33991 m
.77583 .33645 L
s
.27028 .33667 m
.2726 .33977 L
s
.77464 .33682 m
.77568 .33171 L
s
.26805 .3312 m
.27028 .33667 L
s
.2671 .32372 m
.26805 .3312 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77583 .33645 m
.77687 .33134 L
s
.78417 .30262 m
.79198 .2998 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26199 .33646 m
.26665 .33795 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78756 .30142 m
.78864 .3347 L
s
.78867 .30102 m
.78977 .33432 L
s
.25565 .31986 m
.25627 .30086 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25454 .31946 m
.25517 .30045 L
s
.25124 .31826 m
.25902 .32103 L
s
.25289 .30201 m
.25493 .30757 L
s
.78524 .33585 m
.78977 .33432 L
s
.24972 .29839 m
.25289 .30201 L
s
0 0 0 r
.24954 .32861 m
.24992 .32603 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24759 .29755 m
.24972 .29839 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24942 .32152 m
.24952 .32084 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25463 .35092 m
.2551 .33655 L
s
.25375 .34334 m
.2551 .33655 L
s
.78798 .34942 m
.78904 .34665 L
s
.78798 .34942 m
.78919 .35144 L
s
.2454 .29909 m
.24759 .29755 L
s
.24435 .29867 m
.24759 .29755 L
s
.78904 .34665 m
.79024 .34867 L
s
.79762 .30486 m
.79957 .29926 L
s
.7968 .31243 m
.79762 .30486 L
s
.78919 .35144 m
.79024 .34867 L
s
.7968 .31243 m
.79696 .3172 L
s
.25138 .34737 m
.25375 .34334 L
s
.25375 .34334 m
.25463 .35092 L
s
.79787 .31202 m
.79868 .30445 L
s
.24315 .30302 m
.2454 .29909 L
s
.79696 .3172 m
.79827 .32397 L
s
.79787 .31202 m
.79803 .3168 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79957 .29926 m
.80261 .2956 L
s
.79868 .30445 m
.80062 .29884 L
s
.80062 .29884 m
.80261 .2956 L
s
.24212 .30259 m
.24435 .29867 L
s
.79803 .3168 m
.79933 .32357 L
s
.80261 .2956 m
.80466 .29474 L
s
.79827 .32397 m
.80056 .32795 L
s
.24195 .30737 m
.24315 .30302 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24802 .34861 m
.25138 .34737 L
s
.79933 .32357 m
.80161 .32755 L
s
.24093 .30695 m
.24212 .30259 L
s
.80466 .29474 m
.80776 .29582 L
s
.24068 .31414 m
.24195 .30737 L
s
.24588 .34783 m
.24802 .34861 L
s
.23966 .31372 m
.24093 .30695 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80161 .32755 m
.80377 .32913 L
s
.80056 .32795 m
.80377 .32913 L
s
.24026 .32615 m
.24068 .31414 L
s
.80776 .29582 m
.80991 .29974 L
s
.24384 .34463 m
.24588 .34783 L
s
.24279 .34423 m
.24588 .34783 L
s
.23924 .32573 m
.23966 .31372 L
s
.80377 .32913 m
.80685 .32789 L
s
.24191 .339 m
.24384 .34463 L
s
.24026 .32615 m
.24104 .33378 L
s
.24087 .3386 m
.24279 .34423 L
s
.24104 .33378 m
.24191 .339 L
s
.23924 .32573 m
.24001 .33337 L
s
.24001 .33337 m
.24087 .3386 L
s
.80685 .32789 m
.80878 .32464 L
s
.80852 .31742 m
.80943 .31459 L
s
.80852 .31742 m
.8096 .3194 L
s
.80943 .31459 m
.81051 .31657 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80878 .32464 m
.81059 .31898 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81051 .31657 m
.81059 .31898 L
s
.22931 .32391 m
.23513 .32647 L
s
.22959 .28969 m
.23219 .32519 L
s
.22466 .32173 m
.22959 .28969 L
s
.81636 .28941 m
.81746 .29377 L
s
.81636 .28941 m
.81671 .29904 L
s
0 0 0 r
.22136 .28175 m
.22252 .28028 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22558 .32217 m
.22933 .2969 L
s
.81671 .29904 m
.81746 .29377 L
s
.81746 .29377 m
.81829 .29091 L
s
.81829 .29091 m
.82003 .28758 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82003 .28758 m
.82358 .28572 L
s
.81723 .31353 m
.81808 .31067 L
s
.81723 .31353 m
.81741 .31837 L
s
.81732 .31595 m
.81816 .31308 L
s
.81808 .31067 m
.81983 .30735 L
s
.81741 .31837 m
.81843 .32035 L
s
.81816 .31308 m
.81992 .30978 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81983 .30735 m
.82412 .30024 L
s
.81843 .32035 m
.82036 .3219 L
s
.81992 .30978 m
.82421 .30267 L
s
.22233 .286 m
.22466 .32173 L
s
.82358 .28572 m
.8254 .2872 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2176 .31815 m
.22233 .286 L
s
.21846 .31861 m
.22206 .29325 L
s
.82036 .3219 m
.82397 .32013 L
s
.8254 .2872 m
.82635 .28915 L
s
.82412 .30024 m
.82577 .29689 L
s
.82421 .30267 m
.82586 .29932 L
s
.82635 .28915 m
.82662 .29643 L
s
.82577 .29689 m
.82653 .294 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82586 .29932 m
.82662 .29643 L
s
.82397 .32013 m
.82563 .3168 L
s
.21508 .31679 m
.22107 .31995 L
s
.82563 .3168 m
.8264 .31391 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8264 .31391 m
.82708 .30858 L
s
.8264 .31391 m
.82745 .31833 L
s
.82708 .30858 m
.82745 .31833 L
s
.21393 .28125 m
.21474 .28174 L
s
.21225 .28272 m
.21393 .28125 L
s
.21304 .2832 m
.21393 .28125 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83203 .28339 m
.83273 .28048 L
s
.83203 .28339 m
.83291 .28534 L
s
.21207 .28759 m
.21304 .2832 L
s
.83273 .28048 m
.83361 .28242 L
s
.21129 .2871 m
.21225 .28272 L
s
.83291 .28534 m
.83361 .28242 L
s
.21141 .30468 m
.21207 .28759 L
s
.20993 .28126 m
.21129 .2871 L
s
.21044 .30911 m
.21129 .2871 L
s
.20852 .27783 m
.20993 .28126 L
s
.21044 .30911 m
.21141 .30468 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83338 .29753 m
.83371 .3274 L
s
.83338 .29753 m
.8353 .32649 L
s
.20632 .27634 m
.20852 .27783 L
s
.83395 .31221 m
.83451 .32695 L
s
.20994 .30129 m
.21063 .30421 L
s
.20555 .29595 m
.20994 .30129 L
s
.20956 .31109 m
.21044 .30911 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83371 .3274 m
.8347 .33187 L
s
.20794 .31261 m
.20956 .31109 L
s
.2048 .27779 m
.20632 .27634 L
s
.2041 .27729 m
.20632 .27634 L
s
.8347 .33187 m
.8353 .32649 L
s
.20497 .31071 m
.20794 .31261 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20391 .2822 m
.2048 .27779 L
s
.20321 .2817 m
.2041 .27729 L
s
.20422 .29251 m
.20555 .29595 L
s
.20352 .29202 m
.20555 .29595 L
s
.20371 .28711 m
.20391 .2822 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20371 .28711 m
.20422 .29251 L
s
.20302 .28661 m
.20321 .2817 L
s
.20302 .28661 m
.20352 .29202 L
s
.20364 .30729 m
.20497 .31071 L
s
.20313 .30187 m
.20383 .30236 L
s
.20374 .30482 m
.20383 .30236 L
s
.20303 .30434 m
.20364 .30729 L
s
.20303 .30434 m
.20313 .30187 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19718 .29745 m
.19771 .30042 L
s
.19761 .3029 m
.19771 .30042 L
s
.19688 .30489 m
.19761 .3029 L
s
.19647 .29943 m
.19718 .29745 L
s
.19148 .26398 m
.19529 .26767 L
s
.19647 .29943 m
.19698 .30241 L
s
.19505 .30341 m
.19688 .30489 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19218 .30091 m
.1936 .2661 L
s
.19163 .3004 m
.19306 .26557 L
s
.19398 .29992 m
.19505 .30341 L
s
.19304 .29393 m
.19398 .29992 L
s
.19279 .28595 m
.19304 .29393 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19005 .29888 m
.19218 .30091 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18826 .26826 m
.18851 .27379 L
s
.18851 .27379 m
.18868 .28181 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18757 .2622 m
.18826 .26826 L
s
.18816 .29433 m
.18868 .28181 L
s
.1878 .26773 m
.18805 .27326 L
s
.18805 .27326 m
.1882 .28129 L
s
.18713 .26166 m
.1878 .26773 L
s
.18768 .29382 m
.1882 .28129 L
s
.1864 .25808 m
.18757 .2622 L
s
.1864 .25808 m
.18713 .26166 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18737 .30136 m
.18816 .29433 L
s
.18691 .30085 m
.18768 .29382 L
s
.18277 .25259 m
.1864 .25808 L
s
.1867 .30588 m
.18737 .30136 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18624 .30538 m
.18691 .30085 L
s
.18558 .30992 m
.1867 .30588 L
s
.18514 .30941 m
.18624 .30538 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18419 .31093 m
.18558 .30992 L
s
.18419 .31093 m
.18514 .30941 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18052 .3058 m
.18419 .31093 L
s
.18152 .30735 m
.18376 .25425 L
s
.18187 .30786 m
.1841 .2548 L
s
.86311 .25171 m
.8656 .24612 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86423 .24948 m
.8665 .30289 L
s
.86396 .25004 m
.86623 .30341 L
s
.86537 .30497 m
.86789 .29974 L
s
.8656 .24612 m
.86609 .24753 L
s
.8656 .24612 m
.86627 .24697 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86609 .24753 m
.86665 .2515 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86627 .24697 m
.8668 .25094 L
s
.86665 .2515 m
.86702 .25604 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8668 .25094 m
.86716 .25548 L
s
.86789 .29974 m
.86817 .29612 L
s
.86789 .29974 m
.86834 .29559 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86716 .25548 m
.86763 .2626 L
s
.86702 .25604 m
.86749 .26316 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86749 .26316 m
.86804 .27598 L
s
.86763 .2626 m
.86818 .27543 L
s
.86817 .29612 m
.86829 .28991 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86834 .29559 m
.86845 .28937 L
s
.86804 .27598 m
.86823 .28423 L
s
.86823 .28423 m
.86829 .28991 L
s
.86818 .27543 m
.86837 .28369 L
s
.86837 .28369 m
.86845 .28937 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86739 .23818 m
.86894 .27419 L
s
.86718 .23989 m
.86753 .23588 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86832 .25816 m
.86869 .26534 L
s
.86872 .27583 m
.86899 .27364 L
s
.86744 .2376 m
.86899 .27364 L
s
.86869 .26534 m
.86897 .2694 L
s
.86897 .2694 m
.86908 .2709 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86901 .26924 m
.86908 .2709 L
s
.86882 .2646 m
.8689 .26665 L
s
.86868 .26145 m
.86882 .2646 L
s
.86868 .26145 m
.86874 .26349 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86886 .26609 m
.86901 .26924 L
s
.86874 .26349 m
.86886 .26609 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86676 .23041 m
.86712 .23618 L
s
.86712 .23618 m
.86734 .24137 L
s
.86619 .22608 m
.86676 .23041 L
s
0 0 0 r
.87043 .22038 m
.87044 .22349 L
s
.87012 .21608 m
.87043 .22038 L
s
.255 .412 .882 r
.86734 .24137 m
.86743 .24601 L
s
.86662 .22984 m
.86699 .2356 L
s
.86699 .2356 m
.86721 .2408 L
s
0 0 0 r
.87011 .2192 m
.87012 .21608 L
s
.255 .412 .882 r
.86619 .22608 m
.86662 .22984 L
s
.86721 .2408 m
.86729 .24544 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87011 .2192 m
.87044 .22349 L
s
.255 .412 .882 r
.86788 .25643 m
.86799 .25905 L
s
.86774 .25588 m
.86788 .25643 L
s
.86796 .2611 m
.86799 .25905 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86708 .24692 m
.86729 .24544 L
s
.86708 .24692 m
.86743 .24601 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87124 .24208 m
.87335 .28758 L
s
.87124 .24208 m
.87303 .28649 L
s
.255 .412 .882 r
.86774 .25588 m
.86785 .25849 L
s
.86776 .26261 m
.86796 .2611 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87222 .26449 m
.87319 .28703 L
s
.86835 .21447 m
.86877 .21879 L
s
.86877 .21879 m
.86925 .22999 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86764 .20956 m
.86835 .21447 L
s
.86899 .22941 m
.86909 .22625 L
s
.87335 .28758 m
.87352 .29457 L
s
.8664 .20718 m
.86764 .20956 L
s
.86915 .23315 m
.86925 .22999 L
s
.8686 .23199 m
.86899 .22941 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86876 .23575 m
.86915 .23315 L
s
.87303 .28649 m
.87352 .29457 L
s
.87006 .24873 m
.87013 .25568 L
s
.87006 .24873 m
.87071 .26378 L
s
.86587 .20974 m
.8664 .20718 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86751 .24041 m
.86876 .23575 L
s
.86735 .23664 m
.8686 .23199 L
s
.87002 .25889 m
.87013 .25568 L
s
.87013 .25568 m
.87071 .26378 L
s
.86567 .21291 m
.86587 .20974 L
s
.86961 .26155 m
.87002 .25889 L
s
.86498 .20481 m
.86567 .21291 L
s
.86498 .20481 m
.86562 .21984 L
s
.86562 .21984 m
.86567 .21291 L
s
.86832 .25932 m
.86961 .26155 L
s
.8668 .23927 m
.86735 .23664 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86696 .24305 m
.86751 .24041 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86659 .24248 m
.8668 .23927 L
s
.86111 .19949 m
.86294 .20186 L
s
.86675 .24627 m
.86696 .24305 L
s
.255 .412 .882 r
.18668 .21342 m
.187 .21404 L
s
0 0 0 r
.86745 .25441 m
.86832 .25932 L
s
.86659 .24248 m
.86691 .25006 L
s
.86691 .25006 m
.86745 .25441 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86159 .20008 m
.86384 .2532 L
s
.255 .412 .882 r
.187 .21404 m
.18735 .21611 L
s
0 0 0 r
.86111 .19949 m
.86336 .25265 L
s
.255 .412 .882 r
.18804 .21024 m
.18735 .21611 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18585 .23328 m
.18657 .23468 L
s
.18574 .23594 m
.18646 .23734 L
s
0 0 0 r
.86029 .20209 m
.86159 .21082 L
s
.85857 .19655 m
.86029 .20209 L
s
.255 .412 .882 r
.18693 .23678 m
.18657 .23468 L
s
.1852 .24877 m
.18613 .24533 L
s
.18682 .23945 m
.18646 .23734 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85747 .19538 m
.85857 .19655 L
s
.255 .412 .882 r
.18671 .24211 m
.18693 .23678 L
s
.18613 .24533 m
.18671 .24211 L
s
0 0 0 r
.85648 .198 m
.85747 .19538 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86187 .25099 m
.86384 .2532 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85678 .23013 m
.8568 .22857 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85621 .20503 m
.85648 .198 L
s
.85589 .19742 m
.85747 .19538 L
s
.8556 .20445 m
.85589 .19742 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8556 .20445 m
.85736 .24658 L
s
.85621 .20503 m
.85796 .24713 L
s
.84549 .18494 m
.85059 .18897 L
s
.85548 .24493 m
.85796 .24713 L
s
.84848 .18724 m
.85068 .24112 L
s
.84775 .18666 m
.84995 .24058 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20436 .23225 m
.20497 .21693 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84768 .23896 m
.85068 .24112 L
s
.83983 .18095 m
.84152 .22353 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83634 .1787 m
.84233 .18266 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85106 .26782 m
.85163 .26444 L
s
.85074 .26002 m
.85163 .26444 L
s
.85015 .26339 m
.85074 .26002 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85015 .26339 m
.85106 .26782 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83897 .18039 m
.84066 .22299 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84097 .23078 m
.84152 .22353 L
s
.82579 .17262 m
.83266 .17647 L
s
.8401 .23025 m
.84066 .22299 L
s
.21405 .1757 m
.23082 .16703 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21382 .25634 m
.21698 .17404 L
s
.21482 .25584 m
.21797 .17349 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82881 .17426 m
.83091 .22892 L
s
.83848 .2331 m
.8401 .23025 L
s
.82979 .17481 m
.83189 .22944 L
s
.83848 .2331 m
.84097 .23078 L
s
.83665 .23205 m
.83848 .2331 L
s
.83368 .22656 m
.83665 .23205 L
s
.83144 .21767 m
.83368 .22656 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82788 .22738 m
.83189 .22944 L
s
.21633 .21641 m
.22258 .2133 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8199 .18108 m
.82142 .19335 L
s
.81741 .1722 m
.8199 .18108 L
s
.81388 .16671 m
.81741 .1722 L
s
.81881 .18055 m
.82034 .19283 L
s
.81629 .17167 m
.81881 .18055 L
s
.22969 .16756 m
.22996 .19054 L
s
.82142 .19335 m
.82172 .2012 L
s
.22199 .22908 m
.22317 .19759 L
s
.81388 .16671 m
.81629 .17167 L
s
.21087 .25784 m
.22778 .24995 L
s
.22996 .19054 m
.23082 .16703 L
s
.82034 .19283 m
.82063 .20068 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81157 .16565 m
.81388 .16671 L
s
.82107 .21248 m
.82172 .2012 L
s
.81997 .21197 m
.82063 .20068 L
s
.80936 .16853 m
.81157 .16565 L
s
.255 .412 .882 r
.80613 .20073 m
.80829 .2008 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80816 .16801 m
.81157 .16565 L
s
.5 Mabswid
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81915 .21936 m
.82107 .21248 L
s
.81803 .21886 m
.81997 .21197 L
s
.80724 .17536 m
.80936 .16853 L
s
.80602 .17485 m
.80816 .16801 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23532 .20126 m
.23557 .20351 L
s
.5 Mabswid
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8159 .22182 m
.81915 .21936 L
s
.8159 .22182 m
.81803 .21886 L
s
.24261 .16576 m
.24654 .1603 L
s
.24109 .17414 m
.24261 .16576 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80521 .18617 m
.80602 .17485 L
s
.80644 .18667 m
.80724 .17536 L
s
.23955 .21771 m
.24109 .17414 L
s
.81357 .22083 m
.8159 .22182 L
s
.24386 .16525 m
.24654 .1603 L
s
.24233 .17363 m
.24386 .16525 L
s
.22663 .25043 m
.22865 .22608 L
s
.22778 .24995 m
.22865 .22608 L
s
.2408 .21723 m
.24233 .17363 L
s
.80644 .18667 m
.80672 .19458 L
s
.24654 .1603 m
.24912 .1593 L
s
.80521 .18617 m
.80549 .19408 L
s
.78881 .15653 m
.79808 .16 L
s
.81106 .21588 m
.81357 .22083 L
s
.80986 .21538 m
.81357 .22083 L
s
.80672 .19458 m
.80837 .20696 L
s
.24912 .1593 m
.25294 .16175 L
s
.80837 .20696 m
.81106 .21588 L
s
.80549 .19408 m
.80714 .20646 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80714 .20646 m
.80986 .21538 L
s
.23586 .21916 m
.2408 .21723 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25294 .16175 m
.25536 .16869 L
s
.25576 .15682 m
.26126 .15488 L
s
.25389 .21252 m
.25576 .15682 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25526 .21206 m
.25712 .15633 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77322 .15129 m
.78328 .15459 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79285 .158 m
.79569 .24174 L
s
.79417 .1585 m
.79703 .24219 L
s
.77903 .15316 m
.78175 .23733 L
s
.77759 .15269 m
.7803 .23691 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24985 .21391 m
.25526 .21206 L
s
.26799 .16443 m
.27116 .15555 L
s
.26616 .17685 m
.26799 .16443 L
s
.27116 .15555 m
.27573 .15019 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26944 .16397 m
.27263 .15509 L
s
.2676 .17639 m
.26944 .16397 L
s
.27263 .15509 m
.27573 .15019 L
s
.2659 .18484 m
.26616 .17685 L
s
.27573 .15019 m
.27875 .14928 L
s
.26735 .18438 m
.2676 .17639 L
s
.79162 .2404 m
.79703 .24219 L
s
.2659 .18484 m
.26696 .1964 L
s
.27875 .14928 m
.28323 .15193 L
s
.26735 .18438 m
.26842 .19596 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26696 .1964 m
.26964 .20356 L
s
.28323 .15193 m
.2861 .15905 L
s
.26842 .19596 m
.27112 .20312 L
s
.76123 .15166 m
.76456 .16054 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75641 .14636 m
.76123 .15166 L
s
.76456 .16054 m
.76646 .17298 L
s
.76302 .16009 m
.76492 .17255 L
s
.75967 .15122 m
.76302 .16009 L
s
.75641 .14636 m
.75967 .15122 L
s
.76646 .17298 m
.7667 .18101 L
s
.75322 .14549 m
.75641 .14636 L
s
.26964 .20356 m
.27399 .20628 L
s
.76492 .17255 m
.76517 .18057 L
s
.76554 .19264 m
.7667 .18101 L
s
.27112 .20312 m
.27399 .20628 L
s
.75012 .14865 m
.75322 .14549 L
s
.74849 .14823 m
.75322 .14549 L
s
.76399 .19222 m
.76517 .18057 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29603 .14447 m
.30761 .14159 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74709 .15584 m
.75012 .14865 L
s
.27399 .20628 m
.27856 .20501 L
s
.77588 .23563 m
.78175 .23733 L
s
.74544 .15543 m
.74849 .14823 L
s
.28214 .18802 m
.28382 .18357 L
s
.28214 .18802 m
.28358 .19163 L
s
.28382 .18357 m
.28527 .18717 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76111 .19945 m
.76399 .19222 L
s
.76268 .19987 m
.76554 .19264 L
s
.29856 .22828 m
.30094 .14322 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30023 .22791 m
.30259 .14281 L
s
.27856 .20501 m
.28177 .20012 L
s
.28514 .19121 m
.28527 .18717 L
s
.74578 .1675 m
.74709 .15584 L
s
.28177 .20012 m
.28514 .19121 L
s
.74412 .1671 m
.74544 .15543 L
s
.75806 .20268 m
.76268 .19987 L
s
.75806 .20268 m
.76111 .19945 L
s
.74578 .1675 m
.74601 .17557 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74412 .1671 m
.74435 .17517 L
s
.75486 .20187 m
.75806 .20268 L
s
.31443 .14001 m
.3267 .13736 L
s
.74601 .17557 m
.748 .18811 L
s
.74435 .17517 m
.74635 .18771 L
s
.7515 .19701 m
.75486 .20187 L
s
.74987 .19661 m
.75486 .20187 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70243 .1061 m
.71514 .10863 L
s
.748 .18811 m
.7515 .19701 L
s
.74635 .18771 m
.74987 .19661 L
s
.72117 .13787 m
.72655 .14303 L
s
.72655 .14303 m
.73023 .15186 L
s
.73023 .15186 m
.73228 .16436 L
s
.72117 .13787 m
.7248 .14265 L
s
.7248 .14265 m
.7285 .15148 L
s
.7285 .15148 m
.73055 .16398 L
s
.71762 .13713 m
.72117 .13787 L
s
.73228 .16436 m
.73249 .17246 L
s
.73055 .16398 m
.73076 .17208 L
s
.71412 .14045 m
.71762 .13713 L
s
.73108 .18426 m
.73249 .17246 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31818 .19562 m
.31964 .13885 L
s
.31995 .19526 m
.32139 .13847 L
s
.72934 .18389 m
.73076 .17208 L
s
.2936 .22942 m
.30023 .22791 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71069 .14783 m
.71412 .14045 L
s
.7278 .19168 m
.73108 .18426 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72604 .19132 m
.72934 .18389 L
s
.34111 .13856 m
.34678 .13351 L
s
.33725 .14735 m
.34111 .13856 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33513 .15987 m
.33725 .14735 L
s
.31294 .1967 m
.31995 .19526 L
s
.34296 .13822 m
.34678 .13351 L
s
.33908 .14701 m
.34296 .13822 L
s
.68803 .1317 m
.69935 .13364 L
s
.33696 .15953 m
.33908 .14701 L
s
.34678 .13351 m
.35053 .13285 L
s
.72259 .19469 m
.7278 .19168 L
s
.33494 .168 m
.33513 .15987 L
s
.72259 .19469 m
.72604 .19132 L
s
.35053 .13285 m
.35422 .13626 L
s
.33677 .16767 m
.33696 .15953 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33494 .168 m
.33649 .17991 L
s
.35422 .13626 m
.35786 .14376 L
s
.33677 .16767 m
.33833 .17958 L
s
.35811 .13158 m
.36582 .13036 L
s
.35633 .21768 m
.35811 .13158 L
s
.35826 .2174 m
.36003 .13127 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71901 .194 m
.72259 .19469 L
s
.70792 .10716 m
.70992 .19232 L
s
.70974 .10753 m
.71175 .19265 L
s
.7153 .18923 m
.71901 .194 L
s
.71146 .18037 m
.7153 .18923 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31766 .21609 m
.31932 .21985 L
s
.31579 .22054 m
.31766 .21609 L
s
.31579 .22054 m
.31745 .2243 L
s
.33649 .17991 m
.33999 .18744 L
s
.33833 .17958 m
.34185 .18711 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66464 .12821 m
.67646 .12989 L
s
.31745 .2243 m
.31932 .21985 L
s
.70437 .19134 m
.71175 .19265 L
s
.67301 .15378 m
.69045 .15642 L
s
.33999 .18744 m
.34551 .19059 L
s
.34185 .18711 m
.34551 .19059 L
s
.37955 .12837 m
.38147 .13217 L
s
.37749 .13272 m
.37955 .12837 L
s
.37749 .13272 m
.3794 .13652 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3794 .13652 m
.38147 .13217 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34551 .19059 m
.34928 .18997 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68376 .20453 m
.69373 .13265 L
s
.68401 .21695 m
.69561 .13298 L
s
.255 .412 .882 r
.67021 .16738 m
.67035 .16751 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37123 .16715 m
.37156 .16906 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35318 .18525 m
.35718 .17645 L
s
.255 .412 .882 r
.66029 .16035 m
.67021 .16738 L
s
0 0 0 r
.34928 .18997 m
.35318 .18525 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35056 .21854 m
.35826 .2174 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37903 .15696 m
.38015 .2062 L
s
.37614 .2067 m
.37903 .15696 L
s
.37814 .20645 m
.37859 .18163 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6686 .12876 m
.68401 .21695 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37614 .2067 m
.37799 .21476 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37799 .21476 m
.38015 .2062 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1003P3lX103000000H0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][H80/>3V
0@3oool009D0/>3V102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@1@0000020?bP40030:f][@3f
W0l0mY`?00L0mY`?102][Jen0;3PiP40oooo002B0;3PiP<0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400@
0?bP408000001@3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f]
[@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01T0oj<@00<0[Jf]0?bP403lX100403lX102000000D0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f]
[GH0/>3V0@3oool008X0/>3V102][Jd@0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@0P0000050?bP4003
0:f][@3fW0l0mY`?01<0mY`?0`2][Jec0;3PiP40oooo00270;3PiP<0[Jf]503oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400@0?bP408000001@3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100403l
X102000000D0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40503oYQ4f0:f][@l0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400@0?bP408000001@3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@050?nV4@l0[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00d0ojD@502][JdG0?nS40030:f][@3lX100o:0@0100o:0@0P0000060?bP40030:f][@3fW0l0mY`?
01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0
[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa000P3oXa090:f][@h0oj<@00<0[Jf]0?bP403lX100403lX102000000H0o:0@00<0[Jf]0?JL3`3f
W0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA
2P2][Jd40?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@0100o:0@
0P0000060?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V
0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@030000002][Jd0[Jf]00L0[Jf]3P3oYQ400`2][Jd0ojHA0?nV
4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400E0?nS4080[Jf]0`0000020:f][A00o:0@0P0000060?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh20:f][F40/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ404P3oYQ4010000000ojHA0000000000050:f][@8000005`3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400I0?nS40D00000102][Jd:0?bP408000001P3lX1000`2][Jd0mY`?0?JL
3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA00<000000?nV4@2][Jd00`000000
102][Jd0ojHA0?nV4@2][Jd30?nV4@030000003oYQ40000001H0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`000000o:0@0?bP40060?bP40030:f][@0000000000008000001@3lX102000000H0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`
h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D
0?nT4@030:f][@3oYQ40ojHA00/0ojHA00H0[Jf]00000000000000000:f][@3oYQ42000000@0ojHA
00@0[Jf]0?nV4@3oYQ40ojHA0P00000G0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0000003l
X1002@3lX104000000<0[Jf]0P0000060?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@3oYQ40ojHA0?nV4@80
00000P3oYQ450:f][@8000000`3oYQ4010000000ojHA0000000000040?nV4@030:f][@3oYQ40ojHA
0080ojHA00<000000?nV4@3oYQ405@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@000000o:0@
00T0o:0@0P0000050?bP408000000`2][Jd010000000o:0@0?bP402][JdF0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH
403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]0000
000000000000102][Jd40?nV4@800000103oYQ4010000000ojHA0000000000040?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd000000?bP40090?bP408000001@3l
X10200000080o:0@00@000000?bP4000000000000P2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY144000000P0ojHA0P0000060?nV4@<00000103o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0000003lX100203l
X1000`000000o:0@000000050?bP408000000P3lX10010000000o:0@0?bP403lX102000000@0[Jf]
4@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo
001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00`0oj@A1000
00030:f][@040?nT4@2][Jd00000000000P0ojHA0P0000060?nV4@<00000103oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0000003lX100203lX102000000H0o:0@
0P0000000`3lX10000000?bP40030?bP40030:f][@000000000000<0mY`?102][Jd=0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2]
[Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY145000000030:f][@3o
Y140oj@A00<0oj@A00<0[Jf]0000000000001`3oYQ42000000P0ojHA0P0000040?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd000000?bP40080?bP408000001P3l
X102000000030?bP40000000o:0@00<0o:0@00<0[Jf]0000000000001`3fW0l40:f][@030?JL3`00
0000mY`?00H0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`
h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd00`3oY1400000000000060?nT4@030:f][@000000
000000L0ojHA0P0000080?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP40000000203lX102000000H0o:0@0`0000050?bP40040:f][@3fW0l0
0000000000X0mY`?00@000000:f][@00000000001@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP
400?0?bP40060:f][@3oY140oj@A0?nT4@000000oj@A102][Jd50?nT4@8000001P3oY1400`2][Jd0
0000000000070?nV4@800000203oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@000000o:0@00L0o:0@0P0000060?bP40<000001@3lX100102][Jd0
mY`?0000000000090?JL3`8000000P3fW0l2000000<0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2]
[Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40060:f][@3oY14000000000002][Jd000002@3oY142
000000H0oj@A00<0[Jf]0000000000001`3oYQ42000000P0ojHA0P0000040?nV4@030:f][@3oYQ40
ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd000000?bP40070?bP408000001`3lX100
0`000000o:0@0?bP40040?bP40030:f][@3fW0l0mY`?008000001`3fW0l2000000@0mY`?00@00000
0?JL3`3fW0l0mY`?0`2][Jd2000000l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue
2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100
3P3lX1020:f][@030000003oY140oj@A0080oj@A00<000000?nT4@3oY1401P3oY142000000H0oj@A
00<0[Jf]0000000000001`3oYQ400`000000ojHA0?nV4@070?nV4@800000103oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0000003lX1001`3lX102000000L0o:0@
0P0000050?bP40030:f][@3fW0l0mY`?008000001`3fW0l2000000@0mY`?0P0000030?JL3`040:f]
[@3/UPh0[Jf]0:f][@8000003@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue
2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP
403lX1002@3lX102000000040?bP402][Jd0[Jf]0?bP408000001@3oY1400`000000oj@A0?nT4@05
0?nT4@8000001P3oY1400`2][Jd00000000000060?nV4@8000002@3oYQ42000000@0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@000000000000<000000`3lX100
0`000000o:0@000000070?bP408000001@3lX1000`2][Jd0mY`?0?JL3`02000000H0mY`?0P000006
0?JL3`050000003fW0l0mY`?0?JL3`2][Jd00`3/UPh4000000/0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P02
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX102000000<0[Jf]0`3lX102
000000D0oj@A00<000000?nT4@3oY1401@3oY142000000H0oj@A00<0[Jf]0000000000001P3oYQ42
000000T0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@3oYQ40503oYQ40
0`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
000000<0o:0@1P0000070?bP408000001@3lX1000`2][Jd0mY`?0?JL3`02000000H0mY`?0P000006
0?JL3`8000000P3fW0l0102][Jd0k9H>0>bF3P3/UPh2000000050>bF3P2][Jd0[Jf]0:f][@000000
203/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0
B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX100103lX1000`000000o:0@0?bP4002000000H0o:0@00<000000?nT4@3oY1401@3o
Y1400`000000oj@A0?nT4@040?nT4@8000001@3oY140102][Jd0ojHA0000000000060?nV4@800000
2@3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@0D0?nV4@030:f]
[@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
1@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@000000060?bP40800000
203lX102000000D0o:0@00D0[Jf]0?JL3`3fW0l0mY`?000000060?JL3`8000001`3fW0l010000000
mY`?0?JL3`2][Jd30>bF3P800000103/UPh00`2][Jd00000000000060>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3PiP40oooo001P0;3PiP03
0:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40030?bP4004
0000002][Jd000000:f][@8000001@3lX102000000h0oj@A0P0000050?nT4@040:f][@3oYQ400000
000000H0ojHA0P0000090?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40
ojHA0100ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA005@3oYA0<
0:f][AP0oj<@00<0[Jf]0?bP400000001P3lX102000000P0o:0@0P0000050?bP40040:f][@3fW0l0
mY`?0?JL3`8000001@3fW0l2000000L0mY`?0P0000000`3fW0l0[Jf]0>bF3P020>bF3P8000001P3/
UPh3000000@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`
h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40070:f][@3lX100o:0@0?bP402][Jd000000:f][@020?bP40<000001@3lX1000`000000[Jf]
0?nT4@0=0?nT4@8000001@3oY140102][Jd0ojHA0000000000060?nV4@8000002@3oYQ42000000@0
ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@070?nV4@T0[Jf]103oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0o:0@000000060?bP40800000203lX102000000D0
o:0@00@0[Jf]0?JL3`3fW0l0mY`?0P0000050?JL3`030000003fW0l0mY`?00H0mY`?0P0000000`3f
W0l0[Jf]0>bF3P020>bF3P8000001P3/UPh00`000000k9H>0>bF3P030:f][@030>bF3P2][Jd0fhX=
00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1001P2][Jd0o:0@0:f][@2][Jd0o:0@
000000<0o:0@0`0000050?bP40030000002][Jd0oj@A00d0oj@A0P0000050?nT4@040:f][@3oYQ40
0000000000H0ojHA0P0000090?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000002]
[Jd0[Jf]00L0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]0`3oXa001011JN40[Jf]0?bP
400000060?bP40800000203lX102000000D0o:0@00@0[Jf]0?JL3`3fW0l0mY`?0P0000050?JL3`03
0000003fW0l0mY`?00H0mY`?0P0000000`3fW0l0[Jf]0>bF3P020>bF3P8000001P3/UPh00`000000
k9H>0>bF3P030>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00
G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V100203_V102000000030>nH402][Jd0[Jf]0080o:0@
0P0000040?bP408000001@3lX1000`000000[Jf]0?nT4@0=0?nT4@8000001@3oY1400`2][Jd00000
000000070?nV4@8000002@3oYQ4200000080ojHA1`2][Jd00`000000ojHA0?nV4@0D0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01H0oj<@1P2][Jd00`000000[Jf]0?bP40040?bP40800000203lX102000000D0o:0@
00@0[Jf]0?JL3`3fW0l0mY`?0P0000050?JL3`030000003fW0l0mY`?00H0mY`?0P0000000`3fW0l0
[Jf]0>bF3P020>bF3P8000001P3/UPh00`000000k9H>0>bF3P040>bF3P80[Jf]0P00000:0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@
0>nH40070>nH40<000000P2][Jd30?bP40030000003lX100o:0@00<0o:0@0P0000050?bP40030000
002][Jd0oj@A00d0oj@A0P0000050?nT4@030:f][@000000000000L0ojHA0P0000070?nV4@80[Jf]
0P0000020:f][@80ojHA00<0[Jf]045Yh@3oYQ400P3oYQ400`000000ojHA0?nV4@0D0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX1000000102][Jd00`000000[Jf]000000080?bP4080
00001@3lX100102][Jd0mY`?0?JL3`3fW0l2000000D0mY`?00<000000?JL3`3fW0l01`3fW0l20000
00040:f][@3/UPh0k9H>0>bF3P8000001P3/UPh00`000000k9H>0>bF3P040>bF3P80000000<0fhX=
0000000000002@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool0
05`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40060>nH40060000002][Jd00000
0000003_V100[Jf]0P3lX102000000D0o:0@0P0000040?bP40030000003lX100[Jf]00h0oj@A0P00
00050?nT4@030:f][@000000000000L0ojHA0P0000020?nV4@D0[Jf]0P3oYQ42000000@0ojHA00@0
[Jf]0?nV4@3oYQ40ojHA0P00000F0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100
0000103lX1000`000000o:0@000000060:f][@80o:0@0P0000050?bP40040:f][@3fW0l0mY`?0?JL
3`8000001@3fW0l00`000000mY`?0?JL3`070?JL3`80000000@0[Jf]0>bF3P3/UPh0k9H>0P000006
0>bF3P030000003/UPh0k9H>00@0k9H>0P0000020=^:3@030000002][Jd0[Jf]00L0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;
0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V103000000060:f][@3_V10000000000003_V100[Jf]
0P3lX102000000D0o:0@0P0000040?bP40030000003lX100[Jf]00h0oj@A0P0000050?nT4@030:f]
[@000000000000H0ojHA00<0[Jf]0000000000000P2][Jd70?nV4@800000103oYQ40102][Jd0ojHA
0?nV4@3oYQ42000001H0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP400000040?bP
40030000003lX100000000H0o:0@0P2][Jd200000080[Jf]0`3lX100102][Jd0mY`?0?JL3`3fW0l2
000000D0mY`?00<000000?JL3`3fW0l01`3fW0l2000000040:f][@3/UPh0k9H>0>bF3P8000001P3/
UPh00`000000k9H>0>bF3P030>bF3P8000000`3KRPd2000000040=^:3@2][Jd0fhX=000000@0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f]
[@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000P3_V102000000040:f][@3_V100kiP@0>nH
4080000000@0kiP@0:f][@3lX100o:0@0P0000050?bP40800000103lX1000`000000o:0@0:f][@0>
0?nT4@8000001@3oY1400`2][Jd00000000000060:f][@040?nV4@000000ojHA000000L0ojHA0P00
00050?nV4@040:f][@3oYQ40ojHA0?nV4@8000005P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40040:f]
[@3lX100o:0@000000@0o:0@0P0000090?bP408000000P3lX1050:f][@80mY`?0P0000050?JL3`03
0000003fW0l0mY`?00L0mY`?0P0000000`2][Jd0k9H>0>bF3P020>bF3P030000003/UPh0k9H>00@0
k9H>00<000000>bF3P3/UPh00`3/UPh2000000<0fhX=0P0000020=^:3@80[Jf]0P0000020=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0102][Jd0kiP@0>nH403_V103000000@0kiP@0P000000
103_V100[Jf]0?bP403lX102000000D0o:0@0P0000040?bP40030000003lX100[Jf]00h0oj@A0P00
00040?nT4@80[Jf]0P0000080?nV4@8000001`3oYQ42000000D0ojHA00@0[Jf]0?nV4@3oYQ40ojHA
0P00000F0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX1000000103lX102000000T0
o:0@0P0000050?bP40040:f][@3fW0l0[Jf]0:f][@8000001@3fW0l00`000000mY`?0?JL3`070?JL
3`80000000<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P040>bF3P030000003/UPh0k9H>
00<0k9H>0P0000040=^:3@030000003KRPd0fhX=0080fhX=00D0[Jf]00000000000000000:f][@09
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P2][Jd2000000@0kiP@0P000000103_V100[Jf]0?bP
403lX102000000D0o:0@0P0000040?bP40030000003lX100[Jf]00h0oj@A0P0000040:f][@040?nT
4@2][Jd00000000000P0ojHA0P0000070?nV4@8000001@3oYQ40102][Jd0ojHA0?nV4@3oYQ420000
01H0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa001@2][Jd0o:0@0?bP403lX100000000<0o:0@0P000009
0?bP408000001@3lX1000`2][Jd0mY`?0?JL3`02000000030?JL3`2][Jd0[Jf]0080[Jf]00<0mY`?
0000003fW0l0203fW0l2000000030:f][@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh0103/UPh0
0`000000k9H>0>bF3P030>bF3P800000103KRPd2000000@0fhX=00@000000:f][@2][Jd000002@2i
M@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00<0[Jf]
09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P<0[Jf]0P3_V102000000D0kiP@00<00000
0>nH402][Jd00P3lX102000000D0o:0@0P0000030?bP4080000000<0o:0@0:f][@3oY1402`3oY142
0:f][@8000001@3oY1400`2][Jd00000000000080?nV4@8000001`3oYQ42000000D0ojHA00@0[Jf]
0?nV4@3oYQ40ojHA0P00000F0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00D0[Jf]0?bP403lX100o:0@
000000030?bP408000002@3lX102000000D0o:0@00<0[Jf]0?JL3`3fW0l00P0000050?JL3`040:f]
[@000000[Jf]0:f][@L0mY`?0P0000000`2][Jd0k9H>0>bF3P020>bF3P030000003/UPh0k9H>00@0
k9H>0P0000040>bF3P8000001@3KRPd00`000000fhX=0=^:3@020=^:3@040000003KRPd0fhX=0:f]
[@8000001`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@0080kiP@0P0000050>nH
40030000003_V100[Jf]0080o:0@0P0000050?bP408000000`3lX102000000030?bP402][Jd0oj@A
00@0oj@A00@000000?nT4@3oY140oj@A0`2][Jd20?nT4@8000001@3oY1400`2][Jd0000000000008
0?nV4@8000001P3oYQ43000000D0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P00000F0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00D0[Jf]0?bP403lX100o:0@000000030?bP408000002@3lX102000000D0o:0@
00<0[Jf]0?JL3`3fW0l00P0000070?JL3`030000003fW0l0[Jf]00<0[Jf]0`3fW0l2000000030:f]
[@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh0103/UPh2000000@0k9H>0P0000050=^:3@030000
003KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00P2][Jd2000000H0^GD;00<0[Jf]08QF1`28EPL0
0P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0
203CQ`h20:f][@@0kiP@0P0000050>nH40030000002][Jd0o:0@0080o:0@0P0000040?bP40800000
103lX102000000030?bP402][Jd0oj@A00@0oj@A00@000000:f][@2][Jd0[Jf]1@3oY142000000D0
oj@A00<0[Jf]0000000000002@3oYQ42000000D0ojHA0`0000050?nV4@040:f][@3oYQ40ojHA0?nV
4@8000005P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40050:f][@3lX100o:0@0?bP400000000P3lX100
0`000000o:0@000000090?bP40<00000103lX1000`2][Jd0mY`?0?JL3`02000000L0mY`?00<00000
0?JL3`3fW0l00`3fW0l30:f][@80000000<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P04
0>bF3P800000103/UPh2000000D0fhX=00<000000=^:3@3KRPd00P3KRPd02@000000fhX=0=^:3@2]
[Jd0^GD;0000002][Jd0^GD;000000040;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd00`3CQ`h0
[Jf]0>nH40030>nH408000001@3_V1000`000000[Jf]0?bP40020?bP40800000103lX102000000@0
o:0@0P0000000`3lX100[Jf]0?nT4@040:f][@8000001P3oY142000000H0oj@A00<0[Jf]00000000
00002@3oYQ42000000@0ojHA00@000000?nV4@0000000000103oYQ400`2][Jd0ojHA0?nV4@020?nV
4@8000005P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40050:f][@3lX100o:0@0?bP400000000P3lX100
0`000000o:0@000000090?bP40<00000103lX100102][Jd0mY`?0?JL3`0000080?JL3`030000003f
W0l0mY`?00D0mY`?0P0000030:f][@<0k9H>00<000000>bF3P3/UPh0103/UPh2000000@0k9H>0P00
00050=^:3@030000003KRPd0fhX=0080fhX=00T000000=^:3@3KRPd0[Jf]0;Ue2`000000^GD;0:f]
[@2iM@/00P0000020;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@04
0>nH408000001@3_V1000`000000[Jf]0?bP40020?bP40800000103lX102000000@0o:0@0P000003
0:f][@@0oj@A0P0000060?nT4@8000001P3oY1400`2][Jd000000000000:0?nV4@8000000`3oYQ40
10000000ojHA0000000000040?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000F0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00D0[Jf]0?bP403lX100o:0@000000020?bP40030000003lX100000000T0o:0@
0P0000000`3lX10000000?bP40020?bP40040:f][@3fW0l00000000000P0mY`?00<000000?JL3`3f
W0l01@3fW0l2000000030?JL3`2][Jd0k9H>00<0[Jf]00<000000>bF3P3/UPh0103/UPh2000000@0
k9H>0P0000050=^:3@8000000`3KRPd01P000000fhX=0=^:3@2][Jd0^GD;00000080^GD;00H0[Jf]
0000002iM@/000000;Ue2`2][Jd408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00@0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH40020>nH40800000
1@3_V1000`000000[Jf]0?bP40020?bP40800000103lX102000000<0o:0@00D0[Jf]000000000000
o:0@0:f][@050?nT4@8000001P3oY142000000H0oj@A00<0[Jf]000000000000303oYQ4300000080
ojHA0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000F0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1000P3lX1001@000000o:0@0000003lX100000000L0o:0@100000020?bP
40060000003lX100o:0@0:f][@3fW0l000002@3fW0l00`000000mY`?0?JL3`050?JL3`80000000<0
mY`?0:f][@3/UPh00`3/UPh00`000000[Jf]0>bF3P040>bF3P800000103/UPh2000000D0fhX=0P00
00030=^:3@060000003KRPd0fhX=0:f][@2iM@/000000`2iM@/01@000000^GD;0;Ue2`2iM@/0[Jf]
00@0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h00`2]
[Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@0080kiP@0P0000060>nH40040:f][@3lX100o:0@
0?bP40800000103lX102000000030?bP402][Jd0[Jf]0080o:0@0P0000000`2][Jd0oj@A0?nT4@04
0?nT4@030000003oY140oj@A00@0oj@A0P0000060?nT4@030:f][@00000000000140ojHA0P000004
0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000F0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1000P3lX10010000000o:0@00000000000:0?bP408000000P3lX1001@000000o:0@0?bP
402][Jd0000000/0mY`?00<000000?JL3`3fW0l0103fW0l2000000030?JL3`2][Jd0k9H>00<0k9H>
00<000000>bF3P2][Jd00P2][Jd20>bF3P800000103/UPh2000000D0fhX=0P0000030=^:3@060000
003KRPd0fhX=0:f][@2iM@/000000`2iM@/01@000000[Jf]0:f][@2iM@/0[Jf]00@0R5H70P2][Je2
0;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd60=>73P030:f][@3_
V100kiP@0080kiP@00<000000>nH403_V1001@3_V1001@2][Jd0o:0@0?bP403lX100000000D0o:0@
0P0000000`2][Jd0o:0@0?bP40020?bP4080000000<0[Jf]0?nT4@3oY1400`3oY1400`000000oj@A
0?nT4@050?nT4@8000001P3oY1400`2][Jd000000000000A0?nV4@800000103oYQ40102][Jd0ojHA
0?nV4@3oYQ43000001H0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP40020?bP40040000003lX1000000000000l0o:0@0`0000000`2]
[Jd0mY`?0?JL3`090?JL3`030000003fW0l0mY`?00@0mY`?0P0000000`3fW0l0[Jf]0>bF3P030>bF
3P030000003/UPh0k9H>0080k9H>0P2][Jd2000000@0k9H>0P0000050=^:3@8000000`3KRPd01P00
0000fhX=0=^:3@2][Jd0^GD;000000<0^GD;00<000000;Ue2`2iM@/00P2][Jd010000000R5H708QF
1`28EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f]
[@3_V100kiP@0080kiP@00@000000>nH403_V1000000103_V1000`2][Jd0o:0@0?bP400200000080
o:0@0`2][Jd2000000D0o:0@0P0000000`2][Jd0oj@A0?nT4@030?nT4@030000003oY140oj@A00D0
oj@A0P0000050?nT4@8000004`3oYQ42000000@0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0`00000F0?nV
4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40020?bP
40040000003lX100000000000180o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l2000000@0mY`?0P000002
0?JL3`030:f][@3/UPh0k9H>0080k9H>0P0000050>bF3P80000000@0[Jf]0>bF3P3/UPh0k9H>0P00
00050=^:3@8000000`3KRPd01P000000fhX=0=^:3@2][Jd0^GD;000000<0^GD;00@000000;Ue2`2i
M@/0^GD;0P00000408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@0080kiP@00@000000>nH403_V1000000103_V100
0`2][Jd0o:0@0?bP400200000080[Jf]0`3lX102000000D0o:0@0P0000000`2][Jd0oj@A0?nT4@02
0?nT4@030000003oY140oj@A00H0oj@A0P0000060?nT4@030:f][@3oYQ40ojHA0140ojHA0P000004
0?nV4@040:f][@3oYQ40ojHA0?nV4@<000004P3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP40020?bP4080000000<0
o:0@0000003lX1004@3lX1000`2][Jd0mY`?0?JL3`0:0?JL3`8000000`3fW0l200000080mY`?00<0
[Jf]0>bF3P3/UPh00P3/UPh2000000D0k9H>0P000000103/UPh0[Jf]0:f][@2][Jd2000000H0fhX=
00D000000=^:3@3KRPd0fhX=000000030=^:3@030:f][@000000^GD;0080^GD;00@000000;Ue2`2i
M@/0^GD;0P0000001@28EPL0000008QF1`28EPL0[Jf]0480/>3V0@3oool005T0/>3V00<0[Jf]09MP
2`2GH0/00P2][Jd80=>73P030:f][@3_V100kiP@00<0kiP@00@000000>nH403_V1000000103_V100
0`2][Jd0@FWQ0:f][@02000000D0o:0@0P0000060?bP40800000103oY1400`000000oj@A0?nT4@06
0?nT4@8000001P3oY1400`2][Jd0ojHA0?nV4@0A0?nV4@800000103oYQ40102][Jd0ojHA0?nV4@3o
YQ43000000P0ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3l
X100o:0@00<0o:0@00<000000?bP400000004P3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`030000003f
W0l0mY`?00<000000P3fW0l00`2][Jd0k9H>0>bF3P020>bF3P8000001P3/UPh00`000000k9H>0>bF
3P020>bF3P80000000<0[Jf]0=^:3@3KRPd00`3KRPd01@000000fhX=0=^:3@3KRPd0000000<0fhX=
00<0[Jf]0000002iM@/00P2iM@/200000080^GD;00@000000:f][@00000000000P28EPL00`2][Jd0
/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080[Jf]203CQ`h00`2][Jd0kiP@
0>nH40030>nH40040000003_V100kiP@000000@0kiP@0P2][Jd00`3lX1000000000000050?bP4080
00001P3lX102000000<0oj@A00<000000?nT4@3oY1401`3oY142000000H0oj@A00<0[Jf]0?nV4@3o
YQ404@3oYQ42000000@0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0`0000080:f][@h0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX1000`3lX1000`000000o:0@0000000B0?bP
40030:f][@3fW0l0mY`?00`0mY`?0`0000040?JL3`030:f][@3/UPh0k9H>0080k9H>0P0000060>bF
3P030000003/UPh0k9H>00<0k9H>00@000000=^:3@2][Jd0[Jf]0`3KRPd00`000000fhX=0=^:3@02
0=^:3@060000003KRPd0fhX=0:f][@2iM@/000000P2iM@/200000080^GD;00<0000008QF1`000000
0P0000000`28EPL0[Jf]0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40030>nH40040000003_V100kiP@00000080kiP@0`2][Jd20?bP4080
00001@3lX102000000L0o:0@0P0000020?nT4@030000003oY140oj@A00L0oj@A0P0000060?nT4@03
0:f][@3oYQ40ojHA0140ojHA0P0000000`3oYQ40[Jf]0:f][@050:f][@<000005P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400F0?nS40P0[Jf]0P3lX1000`000000o:0@0000000B0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh2000000H0k9H>00<000000>bF3P3/UPh00`3/UPh010000000
fhX=0=^:3@3KRPd20:f][@030=^:3@000000fhX=00<0fhX=00H000000=^:3@3KRPd0[Jf]0;Ue2`00
00020;Ue2`8000000P2iM@/01`000000R5H7000000000000R5H70000002][Jd0@P2`h>H10?ooo`00
F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000`3_V10010000000
kiP@0>nH400000020:f][@80kiP@00<0[Jf]0?bP403lX1000P0000050?bP408000001P3lX1000`2]
[Jd0oj@A0?nT4@02000000X0oj@A0P0000060?nT4@030:f][@3oYQ40ojHA00h0ojHA0`2][Jd20000
00050:f][@3oYQ40ojHA0?nV4@2][Jd00`3oYQ43000001H0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
102][Jd0o:0@0?bP403lX1020:f][@030000002][Jd000000080[Jf]403lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`040:f][@3/UPh0k9H>0>bF3P8000001P3/UPh00`000000k9H>0>bF3P030>bF3P030000
003KRPd0fhX=00<0fhX=0P0000040=^:3@060000003KRPd0fhX=0:f][@2iM@/000000P2iM@/20000
0080^GD;00L0000008QF1`00000000000:f][@000000[Jf]0480/>3V0@3oool005T0/>3V0P2][Jd2
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V10010000000kiP@0:f][@00
00040>nH40030:f][@3lX100o:0@008000001@3lX102000000H0o:0@00<0[Jf]0?nT4@3oY140303o
Y142000000H0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@<0ojHA0P0000040?nV4@070:f][@3o
YQ40ojHA0?nV4@000000ojHA0000000F0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X1000`3lX102000000<0o:0@1P2][Jd:0?bP40030:f][@3fW0l0mY`?01@0mY`?00@0[Jf]0>bF3P3/
UPh0k9H>0P0000060>bF3P030000003/UPh0k9H>00<0k9H>00<000000=^:3@3KRPd00`3KRPd20000
0080[Jf]0P3KRPd01P000000fhX=0=^:3@2][Jd0^GD;00000080^GD;0P0000020;Ue2`0500000028
EPL0R5H70000002][Jd00P0000120;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00<0kiP@00@000000:f][@3_V1000000103_V1000`2][Jd0o:0@
0?bP4002000000D0o:0@0P0000060?bP40030:f][@3oY140oj@A00`0oj@A0P0000060?nT4@040:f]
[@3oYQ40ojHA0?nV4@H0[Jf]2P3oYQ42000000@0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P00000G0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1000`3lX102000000T0o:0@1`2][Jd30?bP
40030:f][@3fW0l0mY`?01@0mY`?00@0[Jf]0>bF3P3/UPh0k9H>0P0000060>bF3P030000003/UPh0
k9H>00<0k9H>0P0000040=^:3@8000000P3KRPd20:f][@060000003KRPd0fhX=0:f][@2iM@/00000
0P2iM@/200000080^GD;00D0000008QF1`28EPL0000008QF1`0200000480/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f][@3_V100kiP@0>nH4080[Jf]00@000000>nH
403_V1000000103_V1000`2][Jd0o:0@0?bP4002000000D0o:0@0P0000060?bP40030:f][@3oY140
oj@A00`0oj@A0P0000050?nT4@D0[Jf]403oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ40
0`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100103lX100
0`000000o:0@0?bP400>0?bP40H0[Jf]503fW0l0102][Jd0k9H>0>bF3P3/UPh2000000H0k9H>00<0
00000>bF3P3/UPh00`3/UPh00`2][Jd000000=^:3@030=^:3@800000103KRPd01P000000[Jf]0=^:
3@2][Jd0^GD;00000080^GD;0P0000020;Ue2`0500000028EPL0R5H700000028EPL00P0000120;3P
iP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f]
[@80kiP@100000040>nH40030:f][@3lX100o:0@008000000`3lX102000000P0o:0@00<0[Jf]0?nT
4@3oY140303oY142000000030?nT4@2][Jd0[Jf]0080[Jf]00<0oj@A0:f][@3oYQ404P3oYQ420000
00@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100103lX1000`000000o:0@0?bP400A0?bP40030:f][@3fW0l0mY`?
00@0[Jf]403fW0l0102][Jd0k9H>0>bF3P3/UPh2000000H0k9H>00<000000>bF3P3/UPh00`3/UPh0
0`2][Jd00000000000030=^:3@800000103KRPd01P000000fhX=0:f][@2][Jd0^GD;000000<0^GD;
00P000000;Ue2`2iM@/000000:f][@28EPL0000008QF1`80000000<0[Jf]0;3PiP2`h>H0?`2`h>H1
0?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f][@<0kiP@0P0000020>nH
40030000003_V100kiP@0080kiP@00<0[Jf]0?bP403lX1000P00000=0?bP40030:f][@3oY140oj@A
00/0oj@A00@0[Jf]000000000000[Jf]1@3oY1400`2][Jd000000?nV4@0A0?nV4@800000103oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100103lX100
0`000000o:0@0?bP400A0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0
k9H>0080k9H>00<000000>bF3P3/UPh0103/UPh00`000000k9H>0>bF3P030>bF3P030:f][@3KRPd0
00000080fhX=0P0000050=^:3@030000003KRPd0fhX=0080[Jf]00D000000;Ue2`2iM@/0^GD;0000
00020;Ue2`050000002][Jd0R5H700000028EPL00`0000110;3PiP40oooo001H0;3PiP80[Jf]0`2G
H0/00`2][Jd0dhL>0=>73P050=>73P80[Jf]103_V10200000080kiP@00<000000>nH403_V1000P3_
V100102][Jd0o:0@00000000000>0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd00`3oY1400000
000000060?nT4@030000003oYQ40000000l0ojHA0P0000060?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?
1@2][Jd60?JL3`030:f][@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh0103/UPh00`000000k9H>
0>bF3P030>bF3P030:f][@3KRPd000000080fhX=0P0000050=^:3@070000003KRPd0fhX=0:f][@2i
M@/000000:f][@020;Ue2`0;0000002iM@/0^GD;0000002][Jd0R5H700000028EPL000000:f][@00
0000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0dhL>
0:f][@040>nH408000000P3_V1000`000000kiP@0>nH40020>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1400`3oY1440:f][@D0oj@A0P0000060?nT4@030000003oYQ40000001L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l03P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>
0>bF3P040>bF3P030000003/UPh0k9H>00@0k9H>00<0[Jf]0=^:3@0000000P0000060=^:3@0:0000
003KRPd0fhX=0:f][@2iM@/000000;Ue2`2][Jd0^GD;00000080^GD;00@000000:f][@28EPL00000
0P28EPL00`2][Jd000000;3PiP100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>7
3P030=>73P040:f][@3CQ`h0dhL>0:f][@@0kiP@0P0000020>nH40030000003_V100kiP@0080kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][@T0oj@A0P0000060?nT4@800000
603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`@0[Jf]0`3/UPh00`000000k9H>0>bF3P040>bF3P800000
1@3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80000000@0fhX=0:f][@2iM@/000000P2iM@/0202][Jd0
00000;Ue2`2iM@/000000:f][@28EPL000000P28EPL00`2][Jd000000;3PiP100;3PiP40oooo001H
0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>73P3CQ`h20:f][@<0dhL>00<0[Jf]0>nH403_V1000P3_
V10200000080kiP@00<000000>nH403_V1000P3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]3@3o
Y142000000H0oj@A00<0[Jf]0000003oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0[Jf]0080[Jf]00<000000>bF3P3/UPh0103/UPh2000000D0k9H>00<0[Jf]0=^:3@3KRPd0203K
RPd2000000040=^:3@2][Jd0^GD;000000<0^GD;00L000000;Ue2`2iM@/000000:f][@28EPL00000
0080R5H700<0[Jf]0000002`h>H0@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3C
Q`h0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH40020>nH408000000P3_V1001P000000kiP@0>nH40000000
kiP@0:f][@h0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0=0?nT4@8000001P3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh00`000000[Jf]0>bF
3P040>bF3P8000001@3/UPh00`2][Jd0fhX=0=^:3@060=^:3@060000003KRPd000000000003KRPd0
[Jf]0P0000030;Ue2`060000002][Jd0[Jf]0;Ue2`000000R5H70P0000000`28EPL0[Jf]00000011
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0:f][@060=>73P030:f][@3_V100kiP@
0080kiP@0P0000020>nH40060000003_V100kiP@0000003_V100[Jf]2`3lX1030:f][@<0o:0@00<0
[Jf]0?nT4@3oY1402@3oY145000000H0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>00<000000>bF3P2][Jd00P2][Jd20>bF3P8000001@3/
UPh00`2][Jd0fhX=0=^:3@070=^:3@80000000<0fhX=0000002][Jd00P0000030;Ue2`80000000<0
^GD;0:f][@0000000P28EPL010000000R5H70:f][@0000110;3PiP40oooo001H0;3PiP80[Jf]0`2G
H0/20:f][@L0dhL>00<0[Jf]0>nH403_V1000P3_V102000000D0kiP@00<000000>nH402][Jd02@3l
X1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P020>bF3P80[Jf]0P00
00050>bF3P030:f][@3KRPd0fhX=00X0fhX=00@000000:f][@00000000000`2iM@/200000080^GD;
00D0000008QF1`28EPL0000008QF1`0200000440/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2GH0/0
0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@0080kiP@0P0000050>nH40030000
003_V100[Jf]00H0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh0103/UPh2000000030:f][@3/UPh0k9H>0080k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd2000000@0^GD;0P0000020;Ue2`050000002][Jd0R5H700000028
EPL00P0000110;3PiP40oooo001H0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h00`2][Jd0
kiP@0>nH40030>nH40030000003_V100kiP@00@0kiP@00<000000>nH402][Jd00`3lX1030:f][@/0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`060:f][@3/UPh000000000
003/UPh000001P3/UPh2000000060>bF3P2][Jd0[Jf]0:f][@3/UPh0[Jf]3P3KRPd00`2][Jd0^GD;
0;Ue2`020;Ue2`8000000P2iM@/01@000000[Jf]08QF1`000000R5H700800000@@2`h>H10?ooo`00
F02`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1000`3_V1000`000000
kiP@0>nH40040>nH40040000003_V100[Jf]0?bP4080[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0102][Jd0k9H>0>bF3P3/UPh2
000000H0k9H>0P0000040>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`8000000P2iM@/0
1@000000R5H70:f][@000000R5H700800000@@2`h>H10?ooo`00F02`h>H01P2][Jd0Uf0;09MP2`2]
[Jd0Uf0;0:f][@L0dhL>00<0[Jf]0>nH403_V1000`3_V1000`000000kiP@0>nH40030>nH40800000
0`2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00T0k9H>0P0000050>bF3P040:f][@3KRPd0[Jf]0:f][@/0
fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0`0000020;Ue2`0700000028EPL0[Jf]00000028EPL000000:f]
[@110;3PiP40oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h0
0`2][Jd0kiP@0>nH40030>nH40030000003_V100kiP@00<0kiP@0P0000000`3_V100[Jf]0?bP400@
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@02
0?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P07
0>bF3P@000001@3/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/00P2i
M@/200000080^GD;00<0000008QF1`28EPL00`0000000`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001H
0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH4003
0>nH40040000003_V100kiP@0>nH4080[Jf]0P0000000`3_V100[Jf]0?bP400@0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB0?bP40030:f][@3f
W0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh2000000D0k9H>00<0[Jf]0=^:3@3KRPd00`3K
RPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`000000R5H708QF1`03000000030:f][@00
0000/>3V03l0/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]
0>nH403_V1000`3_V10010000000kiP@0:f][@2][Jd20>nH4080000000<0kiP@0:f][@3lX100403l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3l
X1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3K
RPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/200000080R5H70`0000000`2][Jd000000;3P
iP0o0;3PiP40oooo001H0;3PiP80[Jf]0P2GH0/00`11JN40[Jf]0=>73P060=>73P030:f][@3_V100
kiP@00<0kiP@00<000000:f][@3_V1000`3_V102000000030>nH402][Jd0o:0@0100o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]
0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd3
0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0000008QF1`28EPL00`0000000`2][Jd000000;3PiP0o
0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`11JN40[Jf]0=>73P060=>73P040:f][@3_V100kiP@
0>nH4080[Jf]00<000000>nH403_V1000`3_V102000000030>nH402][Jd0o:0@0100o:0@00<0[Jf]
0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3f
W0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0
fhX=0:f][@2iM@/0202iM@/0102][Jd0R5H700000028EPL300000400/>3V0@3oool005L0/>3V0P2]
[Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]0P3_V10010000000kiP@
0>nH403_V10300000080kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0
[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80
[Jf]2@2iM@/0102][Jd0000000000028EPL300000400/>3V0@3oool005L0/>3V0P2][Jd309MP2`03
0:f][@3CQ`h0dhL>00H0dhL>0P2][Jd40>nH40040000003_V1000000000000D0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f][A00mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@<0[Jf]1`2iM@/0102][Jd0R5H700000028EPL3
00000400/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd50>nH
408000001`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3P
iP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue
2`2iM@/0[Jf]1P2iM@/0102][Jd0R5H708QF1`28EPL300000400/>3V0@3oool005L0/>3V0P2][Jd3
09MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH40020>nH40<000001`3_V100
0`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f]
[@050;Ue2`040:f][@28EPL0R5H708QF1`<00000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0
[Jf]0=>73P3CQ`h00P3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100
403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@000000^GD;0080^GD;
00@0[Jf]08QF1`28EPL0R5H70`0000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/01@2][Jd0dhL>
0=>73P3CQ`h0[Jf]00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0
[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80
000000@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL00`2][Jd00000000000100;3PiP40oooo001G0;3PiP80
[Jf]0`2GH0/0102][Jd0dhL>0:f][@2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/00P2iM@/2000000040;Ue2`2][Jd0[Jf]0:f][@<0R5H700<0[Jf]045Yh@000000@02`h>H1
0?ooo`00E`2`h>H20:f][@<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P0000030;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0000002`h>H0?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP2`0209MP
2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP
40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00<0^GD;00@000000;Ue2`2iM@/0^GD;0P2][Jd308QF1`030:f][@000000
000003l0/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^
0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`80[Jf]0`28EPL00`2][Jd000000000000o0;3PiP40oooo001G0;3PiP040:f][@2GH0/0Uf0;
09MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd4
0;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/0
0`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
0`2][Jd0R5H70:f][@0208QF1`030:f][@000000000003l0/>3V0@3oool005L0/>3V00H0[Jf]09MP
2`2GH0/0[Jf]09MP2`2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2]
[Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd000000000000o0;3PiP40oooo001G
0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:
0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH
0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2][Jd2000003l0/>3V
0@3oool005L0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_
V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n
]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n
^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030;3P
iP000000/>3V03h0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]
00<0/>3V0000002`h>H0?P2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f]
[@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]
102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3C
Q`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080/J^M
0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f][@2][Jd30=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`h>H0/>3V03d0
/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P040:f][@3_V100[Jf]0:f]
[@80@FWQ102TWXl00`11JN40/J^M0;6[W@040;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP2
0:f][@L0_[Vh00<0@FWQ0:f][@2d/;400P2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd02@3CQ`h20:f][@80Y9j?0P11JN440:BNS`03045Yh@2aZid0/J^M00H0/J^M0P2]
[Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@L0_[Vh0P11JN400`2n^KP0@FWQ0;B`/@040;B`/@80[Jf]
2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@11JN40@FWQ0080Y9j?0P11JN440:BNS`04
045Yh@2aZid0/J^M045Yh@L0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]1`2n^KP2045Y
h@<0_[Vh00<0@FWQ0;B`/@2d/;401@2d/;420:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd0
0`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@030:BNS`11JN40@FWQ0080Y9j?0P11JN430:BNS`80@FWQ0P2aZid00`11JN40/J^M0;6[W@07
0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]
0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00L0_[Vh0P11
JN430;ji^003045Yh@2d/;40];2a00L0];2a00<0[Jf]0;Ue2`2iM@/01@2iM@/0102][Jd0R5H708QF
1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@050=>73P<0[Jf]00<0Y9j?045Yh@11JN400P2TWXl2045Yh@<0Y9j?0P11JN420;6[W@03045Y
h@2aZid0/J^M00P0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk
0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P11JN430;ji^080@FWQ2@2d/;420:f][@D0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0RXEe08Z5M@2][Jd20:BNS`03045Yh@2TWXl0Y9j?
0080@FWQ0`2TWXl2045Yh@80/J^M00<0@FWQ0;6[W@2aZid0202aZid00`2][Jd0^K:V0;VbYP030;Vb
YP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^003045Y
h@@0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN480;B`/@D0[Jf]0`2iM@/0102][Jd0R5H708QF1`28
EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@030=>73P040:f][@11JN40@FWQ045Yh@<0[Jf]00@0Y9j?045Yh@2TWXl0@FWQ102TWXl2045Yh@03
0;6[W@11JN40@FWQ00P0/J^M00<0@FWQ0;6[W@2][Jd0202i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0
_[Vh045Yh@020;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN420;B`
/@03045Yh@2d/;40];2a0080];2a00@0[Jf]0;B`/@2d/;40[Jf]0P2OVj00102][Jd0^GD;0;Ue2`2]
[Jd308QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]
1011JN401@2][Jd0Y9j?0:BNS`2][Jd0Y9j?0080@FWQ102TWXl2045Yh@040;6[W@11JN40@FWQ045Y
h@H0/J^M00@0@FWQ0;6[W@11JN40[Jf]2`2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_
0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00@0[Jf]
0<K0_036`;`0a/2l0P11JN4<0<K0_0<0[Jf]2`33_K/01011JN40`kfk0<>m^`2][Jd2045Yh@<0_[Vh
00D0@FWQ0;ji^02n^KP0_[Vh045Yh@020;ji^080@FWQ00@0[Jf]0;B`/@2d/;40@FWQ0P2d/;420:f]
[@<0];2a00@0[Jf]09nKX02OVj00Wi^P0`2][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool0
05H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/20:f][@03045Yh@2:QGD0RXEe00@0@FWQ00<0Y9j?045Y
h@2TWXl00P2][Jd01011JN40Y9j?0:BNS`2TWXl3045Yh@040;6[W@11JN40@FWQ045Yh@D0/J^M00@0
@FWQ0;6[W@2aZid0/J^M1011JN4<0;VbYP<0[Jf]2P2n]j`4045Yh@<0_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
2@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f]
[@37`K`0al6l0180al6l00@0[Jf]045Yh@11JN40@FWQ2P36`;`40:f][@030<K0_02][Jd0`kfk00T0
`kfk0P11JN430<>m^`030:f][@11JN40@FWQ00X0_[Vh00<0@FWQ0;ji^02][Jd00P2d/;400`11JN40
[Jf]0:f][@050;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0
/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@11JN40
0`2:QGD2045Yh@040:f][@2TWXl0@FWQ045Yh@80Y9j?00@0@FWQ0:f][@2TWXl0Y9j?0`11JN40102a
Zid0@FWQ0;6[W@11JN450;6[W@05045Yh@2aZid0/J^M0;6[W@2][Jd00`11JN420;VbYP80@FWQ2@2i
/ZH00`2][Jd0_[N/0:f][@030:f][@P0_[N/1011JN400`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`0102][Jd0a/2l0<K0_011JN460<K0_0@0[Jf]
1@36`;`00`2][Jd0`kfk0<>m^`040<>m^`03045Yh@33_K/0@FWQ00<0@FWQ0`33_K/2045Yh@X0_[Vh
0P11JN401@2n^KP0[Jf]0;B`/@2d/;40@FWQ00L0];2a00<0[Jf]09nKX02OVj00102OVj001@2][Jd0
R5H708QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@11JN40
RXEe045Yh@@0RXEe00<0@FWQ0:f][@2TWXl00P11JN420:BNS`04045Yh@2TWXl0[Jf]0:BNS`80@FWQ
00D0/J^M045Yh@11JN40/J^M045Yh@040;6[W@80@FWQ0`2aZid0102][Jd0^K:V045Yh@11JN440;Vb
YP<0@FWQ1P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]102n]j`2045Yh@<0_[N/00<0[Jf]0<6j
/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00@0[Jf]0<K0
_036`;`0@FWQ0P36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@@0`kfk0P11JN43
0<>m^`80@FWQ2P2n^KP00`11JN40_[Vh0;ji^0030:f][@03045Yh@2d/;40];2a00D0];2a00<0[Jf]
09nKX02OVj00102OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@02045Yh@H0RXEe00<0[Jf]0:BNS`11JN400`2TWXl01011JN40Y9j?0:BN
S`2][Jd2045Yh@050;6[W@11JN40@FWQ0;6[W@11JN40102aZid2045Yh@<0/J^M00@0[Jf]0;VbYP11
JN40@FWQ102i/ZH00`11JN40^K:V0;VbYP060;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd2045Y
h@<0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0140al6l00@0[Jf]0<K0_02][Jd0@FWQ0P2][Jd=0<K0_0030:f][@33_K/0`kfk00<0@FWQ1@33_K/2
045Yh@<0`kfk0P11JN490;ji^080@FWQ00<0_[Vh0:f][@2][Jd00P2d/;400`11JN40];2a0;B`/@05
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]08QF1`28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H0
0`2][Jd0Uf0;09MP2`020:f][@80@FWQ1P2:QGD00`2][Jd0Y9j?045Yh@030:BNS`04045Yh@2TWXl0
Y9j?0:BNS`80@FWQ00D0[Jf]045Yh@11JN40/J^M045Yh@040;6[W@80@FWQ0`2aZid0102][Jd0^K:V
045Yh@11JN440;VbYP03045Yh@2i/ZH0^K:V00H0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`2045Yh@80
[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0
aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0
al6l102][Jd00`36`;`0@FWQ0<K0_00<0<K0_0@0@FWQ0`33_K/00`11JN40`kfk0<>m^`030<>m^`80
@FWQ0`33_K/00`11JN40[Jf]0;ji^0070;ji^080@FWQ0P2][Jd01@2n^KP0@FWQ0;B`/@2d/;40@FWQ
00L0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0
/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd00`11JN40RXEe08Z5M@0308Z5M@070:f][@2TWXl0Y9j?
0:BNS`11JN40Y9j?045Yh@040:BNS`80@FWQ00D0/J^M045Yh@11JN40/J^M045Yh@030;6[W@80@FWQ
102aZid00`2][Jd0^K:V045Yh@050;VbYP03045Yh@2i/ZH0^K:V00H0^K:V00D0[Jf]0;jg[02n]j`0
_[N/045Yh@090;jg[080@FWQ0P2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00:0<O1_0D0[Jf]0P37`K`0102][Jd0a/2l0<K0_011JN4;0<K0_0@0@FWQ00<0[Jf]0<>m
^`33_K/00P33_K/00`11JN40`kfk0<>m^`030<>m^`80@FWQ0`33_K/00`11JN40[Jf]0;ji^0070;ji
^004045Yh@2][Jd0_[Vh0;ji^080@FWQ0P2d/;400`11JN40];2a0;B`/@050;B`/@030:f][@2OVj00
Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]
08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`020:BNS`80@FWQ0`2TWXl2045Yh@070:f][@2aZid0
@FWQ045Yh@2][Jd0@FWQ0:f][@020;6[W@80@FWQ102aZid00`2][Jd0^K:V045Yh@050;VbYP03045Y
h@2i/ZH0^K:V00H0^K:V00D0[Jf]0;jg[011JN40@FWQ0;jg[002045Yh@L0_[N/0P11JN430;jg[003
0:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0
al6l1@2][Jd70<O1_0040:f][@36`;`0a/2l045Yh@d0a/2l0P11JN400`2][Jd0`kfk0<>m^`020<>m
^`03045Yh@33_K/0`kfk00<0`kfk0P11JN430<>m^`03045Yh@2][Jd0_[Vh00@0_[Vh0`2][Jd01011
JN40_[Vh0;ji^02n^KP2045Yh@80];2a0P11JN460;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Jd0
0`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00<0[Jf]0:BN
S`2TWXl01`2TWXl2045Yh@030:f][@2aZid0@FWQ0080/J^M00@0@FWQ0;6[W@2][Jd0[Jf]0P11JN44
0;6[W@030:f][@2i/ZH0@FWQ00D0^K:V00<0@FWQ0;VbYP2i/ZH01P2i/ZH00`2][Jd0@FWQ045Yh@04
0;jg[003045Yh@2n]j`0_[N/0080@FWQ0P2n]j`2045Yh@<0_[N/00<0[Jf]0<6j/031^[001@31^[05
0:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00@0[Jf]
0<K0_036`;`0@FWQ0P36`;`5045Yh@H0a/2l0P11JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33
_K/0`kfk00<0`kfk0P11JN430<>m^`03045Yh@2][Jd0_[Vh0080_[Vh00<0[Jf]045Yh@2n^KP00P2n
^KP01011JN40_[Vh0;ji^02n^KP2045Yh@80];2a0P11JN460;B`/@030:f][@2OVj00Wi^P00<0Wi^P
00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1S
H5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0`11JN400`2][Jd0/J^M045Y
h@030;6[W@03045Yh@2aZid0/J^M0080@FWQ00L0[Jf]0;6[W@2aZid0/J^M045Yh@2i/ZH0@FWQ00D0
^K:V00<0@FWQ0;VbYP2i/ZH01@2i/ZH0102][Jd0_[N/045Yh@11JN440;jg[003045Yh@2n]j`0@FWQ
00@0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
0100b<6k1P2][JdA0<O1_0060:f][@36`;`0a/2l045Yh@36`;`0@FWQ0`36`;`2045Yh@H0a/2l0P11
JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33_K/0`kfk00<0`kfk0P11JN430<>m^`03045Yh@2]
[Jd0_[Vh0080[Jf]00<0_[Vh045Yh@11JN400P2n^KP01011JN40_[Vh0;ji^02n^KP2045Yh@80];2a
0P11JN460;B`/@030:f][@2OVj00Wi^P0080Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@03
0:f][@2TWXl0Y9j?00P0Y9j?0P11JN400`2aZid0@FWQ0;6[W@020;6[W@03045Yh@2aZid0/J^M0080
@FWQ00D0/J^M0:f][@2][Jd0/J^M0:f][@02045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH01@2i/ZH0102]
[Jd0_[N/045Yh@11JN450;jg[080@FWQ102n]j`2045Yh@80_[N/0P11JN4A0<6j/0P0[Jf]4033_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/7
0:f][@<0b<6k00<0[Jf]0<O1_037`K`04037`K`01`11JN40[Jf]0<K0_036`;`0@FWQ0<K0_011JN40
0`36`;`00`11JN40a/2l045Yh@050<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@D0`kfk
00D0@FWQ0<>m^`33_K/0`kfk045Yh@020:f][@<0_[Vh0P11JN420;ji^006045Yh@2n^KP0_[Vh045Y
h@2n^KP0@FWQ0P2d/;42045Yh@H0];2a00<0[Jf]09nKX02OVj000P2][Jd309nKX0030:f][@1`KWT0
L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe
08Z5M@2][Jd00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0@FWQ00<0/J^M00<0@FWQ
0;6[W@2aZid00P11JN430;6[W@<0[Jf]00<0^K:V045Yh@11JN400P2i/ZH2045Yh@L0^K:V00@0[Jf]
0;jg[011JN40@FWQ1@2n]j`2045Yh@@0_[N/1011JN400`2n]j`0@FWQ045Yh@0B0<6j/0030:f][@33
_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038
`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`02@37`K`3045Yh@80al6l
0P11JN401037`K`0[Jf]0<K0_036`;`2045Yh@D0a/2l0P11JN450<K0_080@FWQ00<0[Jf]0<>m^`33
_K/00P33_K/2045Yh@D0`kfk00@0@FWQ0:f][@2][Jd0[Jf]0P11JN450;ji^004045Yh@2n^KP0_[Vh
0;ji^080@FWQ0P2n^KP00`2][Jd0];2a0;B`/@02045Yh@H0];2a00<0[Jf]09nKX02][Jd01@2OVj00
0`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2]
[Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00L0[Jf]0;6[W@2aZid0/J^M045Yh@2a
Zid0@FWQ0080/J^M0P11JN440;6[W@030:f][@2i/ZH0[Jf]0080[Jf]0P2i/ZH2045Yh@L0^K:V00@0
[Jf]0;jg[011JN40@FWQ1@2n]j`2045Yh@@0_[N/0P11JN430;jg[0030:f][@11JN40@FWQ00D0`KZ`
1011JN480<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k
2@2][JdB0<S1^`030:f][@37`K`0al6l00P0al6l00H0@FWQ0<O1_037`K`0al6l045Yh@37`K`2045Y
h@040<O1_02][Jd0a/2l0<K0_080@FWQ1@36`;`2045Yh@D0a/2l0P11JN400`2][Jd0`kfk0<>m^`02
0<>m^`80@FWQ0`33_K/20:f][@04045Yh@33_K/0`kfk0<>m^`80@FWQ102n^KP00`11JN40_[Vh0;ji
^0060;ji^0030:f][@2d/;40];2a0080@FWQ1P2d/;420:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD2
0:f][@/0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2045Yh@80/J^M0P11JN440;6[W@030:f][@2i/ZH0
^K:V0080^K:V0P2][Jd2045Yh@L0^K:V00@0[Jf]0;jg[011JN40@FWQ1@2n]j`2045Yh@@0_[N/0P11
JN430;jg[0030:f][@31^[00@FWQ00L0`KZ`1011JN420<6j/0<0@FWQ00<0`KZ`0:f][@33_K<05033
_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0A0<S1^`80@FWQ00<0[Jf]0<O1_037`K`01`37`K`00`11JN40al6l0<O1
_0030<O1_0<0@FWQ00D0al6l0:f][@36`;`0a/2l045Yh@070<K0_080@FWQ1036`;`2045Yh@030:f]
[@33_K/0`kfk0080`kfk0P11JN400`33_K/0[Jf]0:f][@020<>m^`03045Yh@33_K/0`kfk0080`kfk
00<0@FWQ0;ji^02n^KP00P2n^KP00`11JN40_[Vh0;ji^0060;ji^0030:f][@2d/;40];2a0080@FWQ
1P2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00
EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@04045Yh@2aZid0@FWQ045Yh@@0/J^M00<0[Jf]0;VbYP2i
/ZH0102i/ZH2045Yh@<0[Jf]102i/ZH0102][Jd0_[N/045Yh@11JN450;jg[080@FWQ102n]j`01@11
JN40_[N/0;jg[02n]j`0[Jf]00<0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@L0`KZ`1011JN42
0<>m/`<0@FWQ3P33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00d0b<6k1011JN42
0<S1^`030:f][@37`K`0al6l00H0al6l0P11JN460<O1_080@FWQ00@0al6l0:f][@36`;`0a/2l0P11
JN460<K0_080@FWQ1036`;`2045Yh@030:f][@33_K/0`kfk0080`kfk0P11JN400`2][Jd0`kfk0<>m
^`020<>m^`03045Yh@33_K/0`kfk0080`kfk00D0[Jf]045Yh@2n^KP0_[Vh045Yh@090;ji^0030:f]
[@2d/;40];2a0080@FWQ102d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40
oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2a
Zid01P2aZid2045Yh@@0/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH3045Yh@80^K:V0`2][Jd01@2i/ZH0
[Jf]0;jg[02n]j`0@FWQ00D0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`01@11JN40_[N/0;jg[02n]j`0
[Jf]00<0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@L0`KZ`00<0@FWQ0:f][@33_K<01@33_K<4
045Yh@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00P0b<6k0P11JN460<S1^`04045Yh@38`K/0
b<6k0:f][@P0al6l0P11JN460<O1_080@FWQ00@0al6l0:f][@36`;`0a/2l0P11JN460<K0_080@FWQ
1036`;`2045Yh@030:f][@33_K/0[Jf]0080[Jf]0P11JN450<>m^`03045Yh@33_K/0`kfk0080`kfk
00@0[Jf]0;ji^011JN40@FWQ2P2n^KP00`2][Jd0];2a0;B`/@02045Yh@<0];2a00@0[Jf]0;B`/@2d
/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=P
D`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@07
0;6[W@03045Yh@2aZid0/J^M0080/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH3045Yh@D0^K:V0`2][Jd2
0;jg[003045Yh@2n]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`00`2n]j`01@11JN40_[N/0;jg[02n
]j`0[Jf]00<0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@L0`KZ`00<0@FWQ0:f][@33_K<01@33
_K<2045Yh@P0`kfc0`11JN420<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`020<S1^`D0@FWQ00<0b<6k045Yh@11JN401P38`K/01011JN40b<6k0<S1
^`2][Jd80<O1_080@FWQ1P37`K`2045Yh@040<O1_02][Jd0a/2l0<K0_080@FWQ1P36`;`2045Yh@@0
a/2l0P11JN420:f][@<0`kfk0P11JN450<>m^`03045Yh@33_K/0`kfk0080`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP01P2][Jd0];2a0;B`/@2d/;40@FWQ0;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX005
09nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2]
[Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[
W@070;6[W@03045Yh@2aZid0/J^M0080/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH3045Yh@<0^K:V00D0
@FWQ0;VbYP2i/ZH0[Jf]0;jg[0030:f][@80@FWQ0P2n]j`00`11JN40_[N/0;jg[0030;jg[005045Y
h@2n]j`0_[N/0;jg[02][Jd00`31^[02045Yh@D0`KZ`0P11JN470<6j/003045Yh@2][Jd0`kfc00D0
`kfc0P11JN460<>m/`<0@FWQ0P33_K<00`11JN40`kfc0:f][@060<Fn]@03045Yh@35_[D0aKje00d0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/03038`K/00`11JN40b<6k0<S1^`050<S1^`030:f][@38`K/0b<6k00<0
@FWQ1038`K/3045Yh@H0b<6k00@0@FWQ0<S1^`38`K/0[Jf]2037`K`2045Yh@H0al6l0P11JN401037
`K`0[Jf]0<K0_036`;`2045Yh@H0a/2l0P11JN440:f][@80@FWQ00<0[Jf]0<>m^`33_K/00P33_K/2
045Yh@D0`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40
];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V
0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]
102TWXl00`2][Jd0/J^M0;6[W@070;6[W@03045Yh@2aZid0/J^M0080/J^M00<0[Jf]0;VbYP2i/ZH0
102i/ZH2045Yh@030;VbYP11JN40^K:V0080@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0040:f]
[@11JN40@FWQ045Yh@D0_[N/00D0@FWQ0;jg[02n]j`0_[N/0:f][@030<6j/080@FWQ1@31^[02045Y
h@L0`KZ`00<0@FWQ0:f][@33_K<01@33_K<2045Yh@D0`kfc0P11JN450<>m/`03045Yh@2][Jd0aKje
00D0aKje00<0@FWQ0<Fn]@35_[D01011JN480<Fn]@03045Yh@2][Jd0a[ng01H0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P80@FWQ1P38`K/00`11JN40b<6k0<S1^`040<S1
^`03045Yh@38`K/0b<6k00D0b<6k00<0[Jf]0<S1^`38`K/00P11JN460<S1^`80@FWQ1P38`K/01011
JN40b<6k0<S1^`2][Jd80<O1_080@FWQ1P37`K`2045Yh@040<O1_02][Jd0a/2l0<K0_080@FWQ0`36
`;`30:f][@03045Yh@36`;`0a/2l00@0a/2l00<0@FWQ0:f][@33_K/00`33_K/00`11JN40`kfk0<>m
^`020<>m^`<0@FWQ1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][@L0];2a
00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f]
[@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0
1`2aZid2045Yh@80/J^M00@0[Jf]0;VbYP2i/ZH0@FWQ0`2i/ZH3045Yh@030;VbYP11JN40^K:V0080
@FWQ0P2i/ZH0102][Jd0_[N/045Yh@11JN450;jg[003045Yh@2][Jd0[Jf]0080[Jf]00<0_[N/045Y
h@2n]j`00P2n]j`0102][Jd0`KZ`0<6j/031^[02045Yh@D0`KZ`0P11JN470<6j/003045Yh@2][Jd0
`kfc00D0`kfc0P11JN450<>m/`03045Yh@33_K<0`kfc00D0`kfc00<0@FWQ0<Fn]@35_[D01035_[D3
045Yh@@0aKje00<0@FWQ0<Fn]@35_[D01035_[D2045Yh@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP04`37`KP4045Yh@d0al6j0`11JN440<O1^P03045Yh@2][Jd0b<6k00H0b<6k00<0@FWQ
0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`050<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k0P11
JN460<S1^`04045Yh@38`K/0b<6k0:f][@P0al6l00<0@FWQ0<O1_011JN401@37`K`2045Yh@040<O1
_02][Jd0a/2l0<K0_080@FWQ0`2][Jd30<K0_003045Yh@36`;`0a/2l00@0a/2l00<0@FWQ0:f][@33
_K/00`33_K/00`11JN40`kfk0<>m^`090<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][Jd80;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C
0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd90;6[W@80@FWQ0P2aZid0102][Jd0^K:V
0;VbYP11JN480;VbYP03045Yh@2i/ZH0@FWQ0080^K:V00@0[Jf]0;jg[011JN40@FWQ1@2n]j`00`11
JN40_[N/0;jg[0020;jg[0060:f][@11JN40[Jf]0:f][@2n]j`0[Jf]0`31^[02045Yh@D0`KZ`0P11
JN460<6j/080@FWQ00<0[Jf]0<>m/`33_K<01033_K<2045Yh@D0`kfc00<0@FWQ0<>m/`33_K<01@33
_K<00`2][Jd0@FWQ0<Fn]@030<Fn]@80@FWQ1`35_[D00`11JN40aKje0<Fn]@030<Fn]@03045Yh@35
_[D0@FWQ01L0a[ng00<0[Jf]0<O1^011JN402@11JN470<O1^0D0@FWQ3@37`KX2045Yh@<0al6j0P11
JN420<O1^P03045Yh@2][Jd0b<6k00H0b<6k0P11JN440<S1^`03045Yh@38`K/0@FWQ00H0b<6k00@0
[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@H0b<6k00@0@FWQ0<S1^`38`K/0[Jf]2@37`K`4045Yh@<0
al6l0P11JN440:f][@80@FWQ1P36`;`00`11JN40a/2l0<K0_0040<K0_080@FWQ0`33_K/00`11JN40
`kfk0<>m^`0:0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl20:f][@P0/J^M0P11JN420;6[W@040:f][@2i/ZH0@FWQ045Yh@T0^K:V0P11JN420;VbYP04
0:f][@2n]j`0_[N/045Yh@D0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[0050:f]
[@80@FWQ1@31^[02045Yh@H0`KZ`0P11JN400`2][Jd0`kfc0<>m/`040<>m/`80@FWQ1033_K<2045Y
h@L0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@060<Fn]@03045Yh@35_[D0aKje
00@0aKje00<0@FWQ0:f][@36_kL05P36_kL00`2][Jd0al6h0<O1^0020<O1^003045Yh@37`KP0al6h
00<0al6h0`11JN480<O1^080@FWQ3037`KX2045Yh@H0al6j0`11JN400`2][Jd0b<6k0<S1^`040<S1
^`<0@FWQ1038`K/3045Yh@H0b<6k00<0[Jf]045Yh@11JN402038`K/2045Yh@H0b<6k00@0@FWQ0<S1
^`38`K/0[Jf]3037`K`00`2][Jd0@FWQ045Yh@03045Yh@040<O1_02][Jd0a/2l0<K0_080@FWQ1@36
`;`00`11JN40a/2l0<K0_0050<K0_003045Yh@2][Jd0@FWQ0080@FWQ3@33_K/00`2][Jd0_[Vh0;ji
^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`
h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@02
0:f][@H0/J^M00D0@FWQ0;6[W@2aZid0[Jf]0;VbYP02045Yh@d0^K:V00@0[Jf]0;jg[02n]j`0@FWQ
1@2n]j`00`11JN40_[N/0;jg[0030;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd00P31^[02045Yh@H0
[Jf]0P11JN460<6j/080@FWQ00<0[Jf]0<>m/`33_K<01033_K<2045Yh@@0`kfc0P11JN470<>m/`03
0:f][@35_[D0aKje00<0aKje00<0@FWQ0<Fn]@35_[D01P35_[D00`11JN40aKje0<Fn]@050<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP00P37`KP00`11JN40al6h0<O1^0050<O1^003
045Yh@37`KP0al6h00H0al6h0P11JN4<0<O1^P80@FWQ1`37`KX2045Yh@030:f][@38`K/0b<6k00@0
b<6k0`11JN440<S1^`<0@FWQ1P38`K/00`2][Jd0@FWQ045Yh@080<S1^`80@FWQ1P38`K/01011JN40
b<6k0<S1^`2][Jd70<O1_0D0[Jf]1037`K`2045Yh@040<O1_02][Jd0a/2l0<K0_080@FWQ1@36`;`0
0`11JN40a/2l0<K0_0050<K0_003045Yh@2][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP2
0:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H1
0?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[
W@2aZid00P2aZid20:f][@@0/J^M0P11JN400`2aZid0[Jf]045Yh@02045Yh@d0^K:V00@0[Jf]0;jg
[02n]j`0_[N/1@11JN460;jg[080@FWQ0P2n]j`00`2][Jd0`KZ`0<6j/002045Yh@H0`KZ`0P11JN45
0:f][@040<6j/011JN40@FWQ0:f][@D0`kfc0P11JN450<>m/`80@FWQ1`33_K<00`2][Jd0aKje0<Fn
]@0<0<Fn]@03045Yh@35_[D0aKje00D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^0020<O1^003045Yh@37`KP0al6h00H0al6h00<0@FWQ0<O1^037`KP01@37`KP2045Yh@030:f][@37
`KX0al6j00T0al6j0P11JN470<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/3045Yh@@0b<6k00<0
@FWQ0<S1^`11JN401P38`K/00`2][Jd0@FWQ045Yh@080<S1^`80@FWQ1P38`K/2045Yh@040<S1^`2]
[Jd0al6l0<O1_0D0[Jf]2@37`K`01011JN40al6l0<O1_02][Jd20<K0_080@FWQ1036`;`00`11JN40
a/2l0<K0_0060<K0_003045Yh@2][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP30:f][@D0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440
/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M00@0/J^M0`2][Jd20;6[W@80@FWQ00@0[Jf]045Yh@11JN40@FWQ3@2i/ZH00`2][Jd0
_[N/0;jg[00<0;jg[080@FWQ0P2n]j`01@2][Jd0`KZ`045Yh@31^[00@FWQ00H0`KZ`0P11JN450<6j
/0030:f][@11JN40@FWQ00@0[Jf]0P33_K<2045Yh@D0`kfc0P11JN470<>m/`030:f][@35_[D0aKje
00/0aKje0P11JN470<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP00P37`KP00`11
JN40al6h0<O1^0060<O1^003045Yh@37`KP0al6h00D0al6h0P11JN400`2][Jd0al6j0<O1^P090<O1
^P80@FWQ1`37`KX2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN400`38`K/0@FWQ0<S1^`020<S1
^`03045Yh@38`K/0@FWQ00H0b<6k0P11JN470<S1^`H0@FWQ1038`K/2045Yh@@0[Jf]1`37`K`2045Y
h@D0al6l00@0@FWQ0<O1_037`K`0[Jf]0P36`;`6045Yh@T0a/2l0P11JN400`2][Jd0`kfk0<>m^`08
0<>m^`03045Yh@33_K/0`kfk0080`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d
/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L
0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@07
0;6[W@<0[Jf]00D0/J^M045Yh@2i/ZH0^K:V045Yh@0=0;VbYP030:f][@2n]j`0_[N/00X0_[N/0`11
JN401@2n]j`0@FWQ0;jg[02][Jd0`KZ`0080@FWQ1`31^[02045Yh@H0`KZ`0P11JN4010000000`kfc
0<>m/`33_K<20:f][@80@FWQ0`2][Jd20<>m/`80@FWQ1`33_K<00`2][Jd0aKje0<Fn]@0:0<Fn]@80
@FWQ2035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h0080al6h00<0@FWQ0<O1^037
`KP01P37`KP2045Yh@H0al6h0P11JN400`2][Jd0al6j0<O1^P090<O1^P80@FWQ1`37`KX2045Yh@03
0:f][@38`K/0b<6k00@0b<6k00@0@FWQ0<S1^`38`K/0@FWQ0P38`K/2045Yh@030<S1^`11JN40b<6k
00D0b<6k0P11JN400`000000b<6k0<S1^`070<S1^`L0[Jf]0P11JN401@38`K/0[Jf]0<O1_037`K`0
@FWQ00H0al6l0P11JN440<O1_005045Yh@37`K`0al6l0<O1_02][Jd00P36`;`2045Yh@d0a/2l0P11
JN400`2][Jd0`kfk0<>m^`070<>m^`80@FWQ1033_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo
001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@0:0;6[W@<0[Jf]00<0^K:V045Yh@2i/ZH0302i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0@FWQ1`31
^[02045Yh@H0`KZ`0P11JN400`2][Jd0`kfc0<>m/`030<>m/`80@FWQ0`33_K<20:f][@80@FWQ102]
[Jd30<>m/`030:f][@35_[D0aKje00P0aKje0`11JN480<Fn]@03045Yh@2][Jd0a[ng01H0a[ng00<0
[Jf]0<O1^037`KP00P37`KP00`11JN40al6h0<O1^0060<O1^080@FWQ1P37`KP2045Yh@030:f][@37
`KX0al6j00T0al6j0P11JN470<O1^P80@FWQ00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@80b<6k00<0
@FWQ0<S1^`38`K/00P11JN420<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN420<S1^`P0[Jf]1`38
`K/2045Yh@050<S1^`2][Jd0al6l0<O1_011JN401P37`K`00`11JN40al6l0<O1_0020<O1_003045Y
h@37`K`0al6l0080al6l00<0[Jf]045Yh@11JN403`36`;`2045Yh@030:f][@33_K/0`kfk00P0`kfk
00@0@FWQ0<>m^`33_K/0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02O
Vj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[002031^[03045Yh@@0`KZ`0P11JN400`31^[00[Jf]0<>m/`040<>m/`80@FWQ
1@33_K<2045Yh@@0`kfc0`2][Jd00`11JN40[Jf]0:f][@030:f][@<0aKje1011JN490<Fn]@03045Y
h@2][Jd0a[ng01H0a[ng00<0[Jf]0<O1^037`KP00P37`KP00`11JN40al6h0<O1^0060<O1^080@FWQ
1P37`KP2045Yh@030:f][@37`KX0al6j00X0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@030:f]
[@38`K/0b<6k00<0b<6k0P11JN420<S1^`04045Yh@38`K/0b<6k045Yh@<0b<6k00<0@FWQ0:f][@2]
[Jd00`2][Jd2045Yh@80[Jf]3`38`K/3045Yh@030:f][@37`K`0al6l0080@FWQ1P37`K`5045Yh@@0
al6l00<0[Jf]0<K0_036`;`03`36`;`2045Yh@030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0
[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00
H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH0
0`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/080@FWQ
00<0`KZ`045Yh@11JN400P31^[02045Yh@030<6j/02][Jd0`kfc00@0`kfc0P11JN450<>m/`80@FWQ
1P33_K<00`11JN40[Jf]045Yh@040<Fn]@030:f][@11JN40@FWQ0080@FWQ1`2][Jd40<Fn]@03045Y
h@2][Jd0a[ng01H0a[ng00<0[Jf]0<O1^037`KP00P37`KP00`11JN40al6h0<O1^0070<O1^080@FWQ
1@37`KP2045Yh@030:f][@37`KX0al6j00/0al6j1011JN430<O1^P80@FWQ00<0[Jf]0<S1^`38`K/0
0`38`K/2045Yh@<0[Jf]00<0@FWQ0:f][@11JN400`2][Jd00`11JN40b<6k0<S1^`030<S1^`80@FWQ
4@38`K/2045Yh@030<S1^`11JN40al6l0080al6l00<0@FWQ0<O1_037`K`03P37`K`00`2][Jd0a/2l
0<K0_00>0<K0_080@FWQ00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP0
2`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0
[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN430<6j/0<0@FWQ0P31^[000`2][Jd0`kfc0<>m
/`030<>m/`80@FWQ1P33_K<2045Yh@H0`kfc0P11JN440<Fn]@<0@FWQ1P35_[D00`11JN40aKje0<Fn
]@040:f][@03045Yh@2][Jd0[Jf]00X0[Jf]3036_kL00`2][Jd0al6h0<O1^0020<O1^003045Yh@37
`KP0al6h00L0al6h0P11JN450<O1^080@FWQ00<0[Jf]0<O1^P37`KX02@37`KX60:f][@D0@FWQ1P2]
[Jd2045Yh@<0b<6k00<0@FWQ0<S1^`11JN400`38`K/00`11JN40b<6k0<S1^`030<S1^`80@FWQ4@38
`K/2045Yh@030<S1^`2][Jd0@FWQ00<0@FWQ4037`K`00`2][Jd0a/2l0<K0_00>0<K0_080@FWQ00<0
[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`
/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A
0;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN480<6j/0040:f][@33_K<0`kfc0<>m/`@0@FWQ1P33
_K<2045Yh@H0`kfc00<0@FWQ0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@060<Fn]@03045Yh@35
_[D0aKje00@0aKje00<0@FWQ0:f][@36_kL02P36_kLA0:f][@03045Yh@2][Jd0[Jf]00L0[Jf]0P11
JN450:f][@80@FWQ302][Jd90<O1^P80@FWQ00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@<0b<6k00<0
@FWQ0<S1^`11JN400`38`K/00`11JN40b<6k0<S1^`030<S1^`80@FWQ3`38`K/4045Yh@030<S1^`2]
[Jd0al6l01<0al6l00<0[Jf]0<K0_036`;`03036`;`4045Yh@030:f][@33_K/0[Jf]0080[Jf]2`33
_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S
0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA
0;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN480<6j/0030:f][@33_K<0`kfc00<0`kfc0P11JN47
0<>m/`80@FWQ1033_K<00`11JN40[Jf]0<Fn]@040<Fn]@03045Yh@35_[D0aKje00D0aKje0P11JN46
0<Fn]@03045Yh@2][Jd0a[ng01H0a[ng00<0[Jf]0<O1^037`KP00P37`KP00`11JN40al6h0<O1^007
0<O1^080@FWQ1@37`KP3045Yh@`0al6j00<0@FWQ0<O1^P37`KX01@37`KX00`11JN40al6j0:f][@05
0<S1^`03045Yh@38`K/0b<6k0080b<6k0P11JN450<S1^`03045Yh@38`K/0b<6k0080b<6k0P11JN4D
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03P36`;`40:f][@h0`kfk00<0[Jf]
0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0/>3V0@3oool0
06D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[002031^[02045Yh@P0`KZ`00<0[Jf]0<>m
/`33_K<03@33_K<5045Yh@030<>m/`2][Jd0aKje00D0aKje00<0@FWQ0<Fn]@35_[D01035_[D2045Y
h@H0aKje00<0@FWQ0:f][@36_kL05P36_kL0102][Jd0al6h0<O1^037`KP2045Yh@T0al6h0P11JN45
0<O1^0<0@FWQ1037`KX00`11JN40al6j0<O1^P050<O1^P03045Yh@37`KX0al6j00D0al6j00<0@FWQ
0<O1^P2][Jd01038`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`02
0<S1^`80@FWQ2P38`K/00`11JN40b<6k0<S1^`070<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[@T0_[N/00<0[Jf]0<6j/031^[002031^[02045Yh@P0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@050<Fn]@<0@FWQ0`35_[D2045Yh@D0aKje0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo
]`040:f][@37`KP0al6h0<O1^080@FWQ2@37`KP2045Yh@D0al6h0`11JN430<O1^P03045Yh@37`KX0
@FWQ00H0al6j00<0@FWQ0<O1^P37`KX01037`KX01011JN40al6j0<O1^P2][Jd40<S1^`80@FWQ1@38
`K/01011JN40b<6k0<S1^`38`K/5045Yh@80b<6k00<0[Jf]045Yh@11JN402@38`K/00`11JN40b<6k
0<S1^`070<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l
00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80
[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`00P0`KZ`
0P11JN480<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D02035_[D3045Yh@030<Fn
]@11JN40aKje00@0aKje0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`040:f][@37`KP0al6h0<O1^080
@FWQ2@37`KP2045Yh@D0al6h0P11JN400`2][Jd0@FWQ0<O1^P020<O1^P80@FWQ1P37`KX01011JN40
al6j0<O1^P37`KX3045Yh@<0al6j00<0[Jf]0<S1^`38`K/01P11JN4>0<S1^`030:f][@11JN40@FWQ
00P0b<6k0P11JN490<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB
0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/0090<6j/080@FWQ2031^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje0180aKje0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`040:f][@37`KP0al6h
0<O1^080@FWQ2@37`KP2045Yh@80al6h1@11JN400`2][Jd0al6j045Yh@03045Yh@P0al6j0`11JN46
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]045Yh@11JN402038`K/2045Yh@T0b<6k00<0[Jf]
0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00?0;jg[0D0[Jf]1@31^[04045Yh@P0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<00`11
JN40`kfc0<>m/`0=0<>m/`030:f][@35_[D0aKje0180aKje0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo
]`040:f][@37`KP0al6h0<O1^080@FWQ2037`KP2045Yh@P0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN490<S1^`030:f][@37
`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31
^[000`2][Jd0`kfc0<>m/`030<>m/`03045Yh@33_K<0`kfc00d0`kfc00<0[Jf]0<Fn]@35_[D04P35
_[D2045Yh@030:f][@36_kL0a[ng01D0a[ng00@0[Jf]0<O1^037`KP0al6h0P11JN480<O1^080@FWQ
2037`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`11JN40
@FWQ1P38`K/3045Yh@T0b<6k00<0[Jf]0<O1_037`K`01@37`K`60:f][@L0al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40
oooo001a0;3PiP<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[002031^[070:f][@<0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<2045Yh@h0`kfc
00<0[Jf]0<Fn]@35_[D04P35_[D2045Yh@030:f][@36_kL0a[ng01D0a[ng00@0[Jf]0<O1^037`KP0
al6h0P11JN480<O1^080@FWQ2037`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00@0[Jf]0<S1^`38`K/0@FWQ1P38`K/00`11JN40b<6k045Yh@090<S1^`030:f][@37`K`0al6l
00D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]0P33_K<00`11JN40
`kfc0<>m/`0=0<>m/`030:f][@35_[D0aKje0180aKje0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`04
0:f][@37`KP0al6h0<O1^080@FWQ2037`KP00`11JN40al6h0<O1^0070<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/01@2][Jd0b<6k0<S1^`38`K/0@FWQ00<0b<6k0P11JN42
0<S1^`03045Yh@38`K/0b<6k00@0b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f]
[@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje0180aKje0P11JN40
0`2][Jd0a[ng0<Jo]`0E0<Jo]`040:f][@37`KP0al6h0<O1^080@FWQ2037`KP00`11JN40al6h0<O1
^0070<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`020<S1^`<0@FWQ1038`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i
0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D04P35_[D2
045Yh@030:f][@36_kL0a[ng01D0a[ng00@0[Jf]0<O1^037`KP0al6h0P11JN470<O1^003045Yh@37
`KP0al6h00P0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38
`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4035
_[D00`11JN40[Jf]0<Jo]`0F0<Jo]`040:f][@37`KP0al6h0<O1^080@FWQ1P37`KP2045Yh@X0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V
0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^011JN402@11JN4<0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3o
ool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0
al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3P
iP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f]
[Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0
a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]
MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3o
ool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3P
iPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V
1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V
0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l
1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`09
0<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f]
[A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0
[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4528 .32875 m
.45458 .32886 L
s
.255 .412 .882 r
.54396 .33842 m
.56046 .338 L
s
.48871 .33811 m
.49035 .34042 L
s
.48705 .34032 m
.48871 .33811 L
s
.56046 .338 m
.56377 .34014 L
s
.56046 .338 m
.56542 .34008 L
s
.48869 .34262 m
.49035 .34042 L
s
.48705 .34032 m
.48869 .34262 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56542 .34008 m
.56873 .34446 L
s
.56377 .34014 m
.56709 .34453 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46407 .33711 m
.47062 .33743 L
s
.47062 .33743 m
.47389 .33983 L
s
.47389 .33983 m
.47552 .34216 L
s
.47548 .34894 m
.47552 .34216 L
s
.57854 .33725 m
.58997 .33663 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56709 .34453 m
.56876 .34898 L
s
.56873 .34446 m
.5704 .34892 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54892 .33832 m
.54907 .3859 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46078 .3392 m
.46407 .33711 L
s
.47383 .34887 m
.47549 .34668 L
s
.48865 .35392 m
.49019 .3812 L
s
.48687 .38111 m
.48865 .35392 L
s
.56876 .34898 m
.57044 .35571 L
s
.45753 .33676 m
.45913 .34137 L
s
.45746 .3458 m
.45753 .33676 L
s
.45913 .34137 m
.46078 .3392 L
s
.47382 .35113 m
.47548 .34894 L
s
.5704 .34892 m
.57209 .35564 L
s
.47053 .35099 m
.47383 .34887 L
s
.45746 .3458 m
.45913 .34137 L
s
.47052 .35325 m
.47382 .35113 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4623 .35512 m
.47053 .35099 L
s
.57044 .35571 m
.57051 .36705 L
s
.46228 .35739 m
.47052 .35325 L
s
.57209 .35564 m
.57216 .36698 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47374 .36473 m
.47541 .36026 L
s
.47536 .36934 m
.47541 .36026 L
s
.48853 .38116 m
.48859 .36752 L
s
.44289 .33807 m
.44609 .34282 L
s
.43807 .33546 m
.44289 .33807 L
s
.45901 .35722 m
.4623 .35512 L
s
.43485 .33521 m
.43807 .33546 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44729 .38647 m
.44734 .38675 L
s
.45429 .35746 m
.45429 .35742 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45899 .35948 m
.46228 .35739 L
s
.47208 .36693 m
.47374 .36473 L
s
.47374 .36473 m
.47536 .36934 L
s
.4316 .33721 m
.43485 .33521 L
s
.43 .33708 m
.43485 .33521 L
s
.45735 .35939 m
.45901 .35722 L
s
.46877 .36906 m
.47208 .36693 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57055 .37387 m
.57216 .36698 L
s
.5689 .37393 m
.57051 .36705 L
s
.58522 .35501 m
.58691 .36173 L
s
.58508 .33691 m
.58532 .36864 L
s
.58344 .337 m
.58368 .36872 L
s
.55057 .33828 m
.55073 .38587 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45733 .36167 m
.45899 .35948 L
s
.45732 .36394 m
.45735 .35939 L
s
.61266 .3373 m
.61744 .33464 L
s
.6111 .34196 m
.61266 .3373 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58691 .36173 m
.59021 .36609 L
s
.4622 .36875 m
.46877 .36906 L
s
.42834 .34148 m
.4316 .33721 L
s
.56727 .37854 m
.5689 .37393 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61426 .33717 m
.61744 .33464 L
s
.61271 .34183 m
.61426 .33717 L
s
.56892 .37848 m
.57055 .37387 L
s
.57875 .36896 m
.58532 .36864 L
s
.48851 .38571 m
.49019 .3812 L
s
.61744 .33464 m
.62224 .33422 L
s
.42674 .34134 m
.43 .33708 L
s
.6111 .34196 m
.61115 .3465 L
s
.48687 .38111 m
.48851 .38571 L
s
.54408 .386 m
.56069 .3856 L
s
.45732 .36394 m
.45894 .3663 L
s
.61271 .34183 m
.61276 .34637 L
s
.45894 .3663 m
.4622 .36875 L
s
.56399 .38322 m
.56727 .37854 L
s
.56564 .38316 m
.56892 .37848 L
s
.44434 .35632 m
.44594 .3587 L
s
.44269 .35848 m
.44434 .35632 L
s
.61115 .3465 m
.61281 .35091 L
s
.59021 .36609 m
.5935 .36818 L
s
.62224 .33422 m
.62546 .33619 L
s
.44592 .36097 m
.44594 .3587 L
s
.56069 .3856 m
.56399 .38322 L
s
.42666 .34815 m
.42834 .34148 L
s
.56069 .3856 m
.56564 .38316 L
s
.61276 .34637 m
.61442 .35078 L
s
.59672 .36343 m
.59833 .36105 L
s
.59833 .36105 m
.59998 .36322 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44262 .36531 m
.44592 .36097 L
s
.59672 .36343 m
.59837 .3656 L
s
.42506 .34801 m
.42674 .34134 L
s
.44269 .35848 m
.44429 .36087 L
s
.5935 .36818 m
.59839 .36787 L
s
.40776 .3327 m
.41884 .33382 L
s
.59998 .36322 m
.6 .36549 L
s
.61281 .35091 m
.61766 .35279 L
s
.62546 .33619 m
.6287 .34043 L
s
.61442 .35078 m
.61766 .35279 L
s
.59839 .36787 m
.6 .36549 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42661 .3527 m
.42666 .34815 L
s
.43936 .36736 m
.44262 .36531 L
s
.41365 .36523 m
.41408 .33335 L
s
.425 .35256 m
.42506 .34801 L
s
.63023 .33573 m
.63336 .33315 L
s
.6287 .34043 m
.63023 .33573 L
s
.41206 .36508 m
.4125 .3332 L
s
.63336 .33315 m
.63494 .33299 L
s
.63181 .33558 m
.63336 .33315 L
s
.63029 .34027 m
.63181 .33558 L
s
.42661 .3527 m
.42813 .35966 L
s
.61291 .36001 m
.61293 .36229 L
s
.61291 .36001 m
.61452 .35988 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4345 .367 m
.43936 .36736 L
s
.425 .35256 m
.42653 .35953 L
s
.61452 .35988 m
.61454 .36216 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61293 .36229 m
.61457 .36444 L
s
.63029 .34027 m
.6305 .35621 L
s
.6287 .34043 m
.62896 .36092 L
s
.61766 .35279 m
.62728 .35423 L
s
.42813 .35966 m
.4313 .36448 L
s
.4313 .36448 m
.4345 .367 L
s
.42969 .36435 m
.4345 .367 L
s
.42653 .35953 m
.42969 .36435 L
s
.61457 .36444 m
.61782 .36646 L
s
.62728 .35423 m
.62891 .35636 L
s
.61782 .36646 m
.62423 .36592 L
s
.39058 .33073 m
.40148 .33202 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62896 .36092 m
.6305 .35621 L
s
.3964 .35657 m
.39679 .33148 L
s
.62423 .36592 m
.6274 .36335 L
s
.6274 .36335 m
.62896 .36092 L
s
.39484 .35639 m
.39524 .33129 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64328 .36407 m
.64906 .33142 L
s
.64485 .36391 m
.64917 .33825 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40731 .36461 m
.41365 .36523 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63855 .36457 m
.64956 .36339 L
s
.37372 .32847 m
.38441 .32994 L
s
.41191 .37653 m
.41347 .37897 L
s
.41029 .37867 m
.41191 .37653 L
s
.41185 .38112 m
.41347 .37897 L
s
.39477 .36097 m
.3964 .35657 L
s
.37897 .3775 m
.37981 .32932 L
s
.41029 .37867 m
.41185 .38112 L
s
.39321 .36079 m
.39484 .35639 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37743 .37731 m
.37829 .32911 L
s
.39006 .36272 m
.39477 .36097 L
s
.39006 .36272 m
.39321 .36079 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65734 .36248 m
.66155 .33672 L
s
.65579 .36267 m
.66143 .32988 L
s
.66143 .32988 m
.66813 .36112 L
s
.64906 .33142 m
.65579 .36267 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38696 .36235 m
.39006 .36272 L
s
.38236 .35948 m
.38696 .36235 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37937 .35449 m
.38236 .35948 L
s
.66352 .36172 m
.67271 .3605 L
s
.68129 .33392 m
.68418 .32887 L
s
.67987 .33874 m
.68129 .33392 L
s
.68418 .32887 m
.68859 .32586 L
s
0 0 0 r
.68658 .34751 m
.68705 .34794 L
s
.255 .412 .882 r
.6785 .34585 m
.67987 .33874 L
s
.36016 .32871 m
.36305 .33376 L
s
.36305 .33376 m
.36442 .34087 L
s
.34153 .30706 m
.35168 .30892 L
s
.68278 .33369 m
.68567 .32864 L
s
.68138 .33851 m
.68278 .33369 L
s
.35576 .32569 m
.36016 .32871 L
s
.68567 .32864 m
.68859 .32586 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68001 .34562 m
.68138 .33851 L
s
.35867 .32847 m
.36156 .33353 L
s
.36156 .33353 m
.36292 .34064 L
s
0 0 0 r
.68665 .35079 m
.68712 .35122 L
s
.255 .412 .882 r
.6785 .34585 m
.67872 .35735 L
s
.35576 .32569 m
.35867 .32847 L
s
.36433 .34546 m
.36442 .34087 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68859 .32586 m
.69154 .32537 L
s
.68001 .34562 m
.68023 .35713 L
s
.36283 .34524 m
.36292 .34064 L
s
.35281 .3252 m
.35576 .32569 L
s
.36269 .35214 m
.36433 .34546 L
s
.34626 .35646 m
.34731 .30814 L
s
.36119 .35191 m
.36283 .34524 L
s
.37284 .37671 m
.37897 .3775 L
s
.3448 .35622 m
.34586 .30787 L
s
.34983 .32699 m
.35281 .3252 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69154 .32537 m
.696 .32691 L
s
.67872 .35735 m
.68036 .36404 L
s
.68023 .35713 m
.68187 .36382 L
s
.35961 .35629 m
.36269 .35214 L
s
.35812 .35607 m
.36119 .35191 L
s
.34681 .33108 m
.34983 .32699 L
s
.696 .32691 m
.69901 .331 L
s
.68036 .36404 m
.68196 .36844 L
s
.68187 .36382 m
.68346 .36822 L
s
.3551 .35791 m
.35961 .35629 L
s
.3551 .35791 m
.35812 .35607 L
s
.68196 .36844 m
.68505 .37263 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68346 .36822 m
.68655 .37241 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35214 .35744 m
.3551 .35791 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68505 .37263 m
.68958 .37427 L
s
.69487 .34327 m
.70507 .34149 L
s
.70032 .32384 m
.70072 .34227 L
s
.69886 .3241 m
.69926 .34252 L
s
.33686 .32232 m
.33829 .32259 L
s
.68655 .37241 m
.68958 .37427 L
s
.34924 .35464 m
.35214 .35744 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33396 .32407 m
.33686 .32232 L
s
.33538 .32434 m
.33686 .32232 L
s
.70895 .32223 m
.71885 .32026 L
s
.34641 .34952 m
.34924 .35464 L
s
.33385 .32868 m
.33538 .32434 L
s
.68958 .37427 m
.69255 .37381 L
s
.33243 .3284 m
.33396 .32407 L
s
.34044 .35546 m
.34626 .35646 L
s
.71322 .3214 m
.71398 .3538 L
s
.69255 .37381 m
.69693 .37079 L
s
.33347 .34487 m
.33385 .32868 L
s
.71463 .32112 m
.7154 .35353 L
s
.69977 .36566 m
.70107 .35846 L
s
.32971 .32322 m
.33243 .3284 L
s
.33194 .34924 m
.33243 .3284 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69693 .37079 m
.69977 .36566 L
s
.32695 .32034 m
.32971 .32322 L
s
.32277 .31946 m
.32695 .32034 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69977 .36566 m
.70138 .37239 L
s
.70107 .35846 m
.70138 .37239 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33194 .34924 m
.33347 .34487 L
s
.71507 .33961 m
.71665 .34629 L
s
.33068 .34201 m
.33205 .3446 L
s
.7097 .3546 m
.7154 .35353 L
s
.31994 .32118 m
.32277 .31946 L
s
.31857 .32088 m
.32277 .31946 L
s
.32231 .338 m
.33068 .34201 L
s
.33047 .35129 m
.33194 .34924 L
s
.71665 .34629 m
.71958 .35038 L
s
.32758 .35307 m
.33047 .35129 L
s
.31845 .32551 m
.31994 .32118 L
s
.31708 .32521 m
.31857 .32088 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31833 .33015 m
.31845 .32551 L
s
.32197 .35195 m
.32758 .35307 L
s
.3196 .33509 m
.32231 .338 L
s
.31822 .3348 m
.32231 .338 L
s
.71958 .35038 m
.72244 .35215 L
s
.31696 .32985 m
.31708 .32521 L
s
.31833 .33015 m
.3196 .33509 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31696 .32985 m
.31822 .3348 L
s
.72244 .35215 m
.72661 .3513 L
s
.72511 .34692 m
.72655 .34897 L
s
.72511 .34692 m
.72644 .34431 L
s
.31925 .34905 m
.32197 .35195 L
s
.31798 .3441 m
.31936 .34439 L
s
.31931 .34672 m
.31936 .34439 L
s
.72644 .34431 m
.72788 .34634 L
s
.31792 .34643 m
.31798 .3441 L
s
.31792 .34643 m
.31925 .34905 L
s
.72788 .34634 m
.72793 .34868 L
s
.72661 .3513 m
.72793 .34868 L
s
.73808 .3183 m
.74201 .31501 L
s
.73686 .32327 m
.73808 .3183 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73686 .32327 m
.73699 .32792 L
s
.73942 .31798 m
.74201 .31501 L
s
.73821 .32295 m
.73942 .31798 L
s
.73821 .32295 m
.73833 .32761 L
s
.74201 .31501 m
.74596 .31402 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73833 .32761 m
.73979 .33195 L
s
.73699 .32792 m
.73845 .33227 L
s
.73845 .33227 m
.74252 .33365 L
s
0 0 0 r
.28398 .30218 m
.2848 .3024 L
s
.255 .412 .882 r
.73979 .33195 m
.74252 .33365 L
s
.29077 .31173 m
.29982 .31411 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74596 .31402 m
.74863 .31568 L
s
.7387 .3416 m
.73876 .34394 L
s
.7387 .3416 m
.74004 .34129 L
s
.30575 .34139 m
.30703 .34403 L
s
.30696 .34637 m
.30703 .34403 L
s
.73876 .34394 m
.74017 .34597 L
s
.30435 .34341 m
.30575 .34139 L
s
.30556 .3484 m
.30696 .34637 L
s
.74004 .34129 m
.7401 .34363 L
s
.74252 .33365 m
.75045 .33404 L
s
.30435 .34341 m
.30562 .34606 L
s
.74863 .31568 m
.75135 .31967 L
s
.29499 .34587 m
.29591 .31311 L
s
.74017 .34597 m
.7429 .34769 L
s
.30156 .34747 m
.30556 .3484 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29369 .34555 m
.29462 .31277 L
s
.7429 .34769 m
.74817 .34642 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75251 .31466 m
.755 .31163 L
s
.75135 .31967 m
.75251 .31466 L
s
.75135 .31967 m
.75195 .34075 L
s
.29898 .34449 m
.30156 .34747 L
s
.75379 .31431 m
.755 .31163 L
s
.75264 .31933 m
.75379 .31431 L
s
.75264 .31933 m
.75311 .33572 L
s
.755 .31163 m
.75627 .31128 L
s
.29649 .33916 m
.29898 .34449 L
s
.29539 .3318 m
.29649 .33916 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76474 .30121 m
.76557 .30097 L
s
.255 .412 .882 r
.75045 .33404 m
.75182 .33606 L
s
.76206 .29314 m
.76352 .34243 L
s
.74817 .34642 m
.75072 .34343 L
s
.75072 .34343 m
.75195 .34075 L
s
.75195 .34075 m
.75311 .33572 L
s
.28983 .34456 m
.29499 .34587 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75832 .29424 m
.76698 .29165 L
s
.7633 .29277 m
.76477 .34208 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27771 .32697 m
.28642 .32943 L
s
.28141 .32804 m
.28197 .30925 L
s
.28266 .32839 m
.28321 .30961 L
s
.27943 .31087 m
.28176 .31628 L
s
.764 .31618 m
.76632 .31076 L
s
.27585 .30741 m
.27943 .31087 L
s
.75976 .34345 m
.76477 .34208 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76632 .31076 m
.76869 .30767 L
s
.76869 .30767 m
.77111 .30693 L
s
.27344 .30667 m
.27585 .30741 L
s
.76456 .335 m
.76717 .33902 L
s
.77111 .30693 m
.77358 .30853 L
s
.77111 .30693 m
.77476 .30815 L
s
.27098 .30826 m
.27344 .30667 L
s
.26979 .30788 m
.27344 .30667 L
s
.28071 .35165 m
.28217 .34489 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28175 .35909 m
.28217 .34489 L
s
.77358 .30853 m
.7761 .31248 L
s
.26846 .31222 m
.27098 .30826 L
s
.27809 .3557 m
.28071 .35165 L
s
.28071 .35165 m
.28175 .35909 L
s
.77476 .30815 m
.77727 .3121 L
s
.26729 .31184 m
.26979 .30788 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76717 .33902 m
.76969 .34068 L
s
.76969 .34068 m
.77212 .33997 L
s
.7761 .31248 m
.7775 .31919 L
s
.26714 .31656 m
.26846 .31222 L
s
.27434 .35704 m
.27809 .3557 L
s
.77727 .3121 m
.77867 .31881 L
s
.26597 .31618 m
.26729 .31184 L
s
.77212 .33997 m
.77445 .33687 L
s
.77212 .33997 m
.77565 .33651 L
s
.7775 .31919 m
.77765 .32392 L
s
.26575 .32328 m
.26714 .31656 L
s
.77445 .33687 m
.77669 .3314 L
s
.77867 .31881 m
.77882 .32355 L
s
.77669 .3314 m
.77765 .32392 L
s
.26458 .3229 m
.26597 .31618 L
s
.27191 .35634 m
.27434 .35704 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77565 .33651 m
.77787 .33103 L
s
.77787 .33103 m
.77882 .32355 L
s
.26537 .33514 m
.26575 .32328 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26958 .35325 m
.27191 .35634 L
s
.26839 .35289 m
.27191 .35634 L
s
.2642 .33477 m
.26458 .3229 L
s
.78513 .30229 m
.79291 .29945 L
s
.26735 .34777 m
.26958 .35325 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26537 .33514 m
.26632 .34265 L
s
.26632 .34265 m
.26735 .34777 L
s
.26617 .34741 m
.26839 .35289 L
s
.2642 .33477 m
.26514 .34228 L
s
.26514 .34228 m
.26617 .34741 L
s
0 0 0 r
.25051 .29459 m
.25093 .29616 L
s
.255 .412 .882 r
.7885 .30108 m
.79015 .35112 L
s
.78961 .30068 m
.79127 .35075 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2528 .29957 m
.25613 .33449 L
s
.25279 .33332 m
.25952 .33564 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79048 .32683 m
.79285 .33082 L
s
.78675 .35225 m
.79127 .35075 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24735 .33134 m
.2528 .29957 L
s
.24843 .33174 m
.25256 .3067 L
s
.79285 .33082 m
.7962 .33202 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80038 .29652 m
.80128 .32281 L
s
.79722 .29779 m
.8045 .2948 L
s
.24428 .29622 m
.24735 .33134 L
s
.239 .32808 m
.24428 .29622 L
s
.80142 .29609 m
.80233 .3224 L
s
.7962 .33202 m
.79835 .33122 L
s
.24002 .32849 m
.24403 .30338 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79835 .33122 m
.8004 .32801 L
s
.79835 .33122 m
.80145 .32761 L
s
.8004 .32801 m
.80128 .32281 L
s
.80145 .32761 m
.80233 .3224 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23598 .32682 m
.24312 .32972 L
s
.80852 .29306 m
.81528 .28993 L
s
.23422 .29186 m
.23519 .29231 L
s
.23221 .29337 m
.23422 .29186 L
s
.23317 .29381 m
.23422 .29186 L
s
.81146 .29173 m
.81266 .32543 L
s
.81242 .29128 m
.81363 .325 L
s
.23203 .29817 m
.23317 .29381 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23108 .29773 m
.23221 .29337 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23143 .31503 m
.23203 .29817 L
s
.80971 .3267 m
.81363 .325 L
s
.22937 .29202 m
.23108 .29773 L
s
.2303 .31943 m
.23108 .29773 L
s
.2276 .28871 m
.22937 .29202 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2303 .31943 m
.23143 .31503 L
s
.22486 .28733 m
.2276 .28871 L
s
.22961 .31175 m
.23047 .3146 L
s
.22415 .30666 m
.22961 .31175 L
s
.22926 .32142 m
.2303 .31943 L
s
.8122 .34037 m
.81309 .33753 L
s
.8122 .34037 m
.81327 .34238 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81309 .33753 m
.81415 .33954 L
s
.22299 .28881 m
.22486 .28733 L
s
.22211 .28835 m
.22486 .28733 L
s
.22729 .32297 m
.22926 .32142 L
s
.81327 .34238 m
.81415 .33954 L
s
.82016 .29489 m
.82177 .28914 L
s
.81951 .30259 m
.82016 .29489 L
s
.81951 .30259 m
.81969 .30742 L
s
.82106 .29443 m
.82266 .28868 L
s
.82042 .30213 m
.82106 .29443 L
s
.82177 .28914 m
.82432 .28533 L
s
.81969 .30742 m
.82087 .31424 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22084 .31666 m
.22114 .30866 L
s
.255 .412 .882 r
.82042 .30213 m
.8206 .30697 L
s
.22193 .29318 m
.22299 .28881 L
s
.22362 .32122 m
.22729 .32297 L
s
.82266 .28868 m
.82432 .28533 L
s
.8206 .30697 m
.82177 .3138 L
s
0 0 0 r
.22006 .31274 m
.22023 .30811 L
s
.255 .412 .882 r
.22106 .29272 m
.22211 .28835 L
s
.22245 .30333 m
.22415 .30666 L
s
.22157 .30287 m
.22415 .30666 L
s
0 0 0 r
.22084 .31666 m
.22107 .31917 L
s
.255 .412 .882 r
.82432 .28533 m
.82604 .28438 L
s
0 0 0 r
.22071 .32012 m
.22098 .32146 L
s
.22006 .31274 m
.22071 .32012 L
s
.255 .412 .882 r
.82087 .31424 m
.82285 .31821 L
s
.22175 .29803 m
.22193 .29318 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22175 .29803 m
.22245 .30333 L
s
.82177 .3138 m
.82374 .31776 L
s
.22088 .29757 m
.22106 .29272 L
s
.22088 .29757 m
.22157 .30287 L
s
.22191 .3179 m
.22362 .32122 L
s
.22121 .31259 m
.22209 .31304 L
s
.222 .31547 m
.22209 .31304 L
s
.82285 .31821 m
.82559 .3193 L
s
.22112 .31502 m
.22191 .3179 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82604 .28438 m
.82865 .28538 L
s
.22112 .31502 m
.22121 .31259 L
s
.82374 .31776 m
.82559 .3193 L
s
.82865 .28538 m
.83048 .28929 L
s
0 0 0 r
.8284 .33826 m
.82885 .35004 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82559 .3193 m
.82817 .31795 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82875 .3375 m
.82884 .33854 L
s
.5 Mabswid
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82948 .30727 m
.8304 .30925 L
s
.82948 .30727 m
.83022 .30437 L
s
.82817 .31795 m
.82976 .31459 L
s
.83022 .30437 m
.83113 .30634 L
s
.82976 .31459 m
.83122 .30879 L
s
.83113 .30634 m
.83122 .30879 L
s
.21359 .30846 m
.21432 .31137 L
s
.21422 .31381 m
.21432 .31137 L
s
.21331 .3158 m
.21422 .31381 L
s
.21269 .31044 m
.21359 .30846 L
s
.2055 .27577 m
.21068 .27923 L
s
.21269 .31044 m
.21341 .31335 L
s
.21091 .31441 m
.21331 .3158 L
s
.8357 .2786 m
.83665 .28299 L
s
.8357 .2786 m
.83608 .28836 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20707 .31206 m
.20841 .27776 L
s
.83608 .28836 m
.83665 .28299 L
s
.83665 .28299 m
.8373 .28005 L
s
.8373 .28005 m
.83867 .27662 L
s
.20633 .31159 m
.20767 .27726 L
s
.20945 .31102 m
.21091 .31441 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83867 .27662 m
.8415 .27462 L
s
.83665 .30305 m
.83731 .30012 L
s
.83665 .30305 m
.83684 .30795 L
s
.20811 .30516 m
.20945 .31102 L
s
.83675 .3055 m
.83741 .30257 L
s
.83731 .30012 m
.8387 .2967 L
s
.20765 .29733 m
.20811 .30516 L
s
.83684 .30795 m
.83769 .30994 L
s
.83741 .30257 m
.8388 .29915 L
s
0 0 0 r
.19957 .26835 m
.20006 .26659 L
s
.255 .412 .882 r
.8387 .2967 m
.84208 .28934 L
s
.83769 .30994 m
.83928 .31145 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8388 .29915 m
.84218 .2918 L
s
0 0 0 r
.19957 .26835 m
.1999 .27072 L
s
.255 .412 .882 r
.20415 .31016 m
.20707 .31206 L
s
.8415 .27462 m
.84297 .27606 L
s
.83928 .31145 m
.84216 .30954 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84297 .27606 m
.84374 .27801 L
s
.84208 .28934 m
.84336 .28589 L
s
.84218 .2918 m
.84346 .28835 L
s
.84374 .27801 m
.84403 .28539 L
s
.84336 .28589 m
.84393 .28293 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84346 .28835 m
.84403 .28539 L
s
.20109 .28012 m
.20156 .28554 L
s
.20156 .28554 m
.20194 .29342 L
s
.19998 .27418 m
.20109 .28012 L
s
.84216 .30954 m
.84346 .3061 L
s
.20145 .30576 m
.20194 .29342 L
s
.20043 .27961 m
.20089 .28504 L
s
.20089 .28504 m
.20126 .29293 L
s
.19934 .27367 m
.20043 .27961 L
s
.19818 .27018 m
.19998 .27418 L
s
.20077 .30528 m
.20126 .29293 L
s
.84346 .3061 m
.84404 .30315 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19703 .33177 m
.19729 .32713 L
s
.5 Mabswid
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19818 .27018 m
.19934 .27367 L
s
.84404 .30315 m
.84452 .29772 L
s
.84404 .30315 m
.84491 .30761 L
s
.84452 .29772 m
.84491 .30761 L
s
.20048 .3127 m
.20145 .30576 L
s
.19981 .31222 m
.20077 .30528 L
s
.19244 .26496 m
.19818 .27018 L
s
.19961 .31718 m
.20048 .3127 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8481 .27198 m
.8486 .26899 L
s
.8481 .27198 m
.8488 .27393 L
s
.19895 .3167 m
.19981 .31222 L
s
0 0 0 r
.19703 .33177 m
.19727 .33625 L
s
.255 .412 .882 r
.8486 .26899 m
.8493 .27094 L
s
.1981 .3212 m
.19961 .31718 L
s
.8488 .27393 m
.8493 .27094 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19745 .32071 m
.19895 .3167 L
s
.8493 .2863 m
.8499 .31663 L
s
.19609 .32224 m
.1981 .3212 L
s
.19251 .31933 m
.19463 .26707 L
s
.19609 .32224 m
.19745 .32071 L
s
.19194 .31884 m
.19407 .26654 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8493 .2863 m
.85111 .31565 L
s
.8499 .30119 m
.85051 .31614 L
s
.1903 .31736 m
.19609 .32224 L
s
.8499 .31663 m
.85071 .32113 L
s
.85071 .32113 m
.85111 .31565 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86732 .23883 m
.86746 .2331 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17775 .23757 m
.17764 .23957 L
s
.17786 .23442 m
.17775 .23757 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8675 .23655 m
.86983 .29079 L
s
.86747 .23712 m
.8698 .29132 L
s
.17777 .23642 m
.17786 .23442 L
s
.17764 .23957 m
.17777 .23642 L
s
.86964 .29293 m
.8698 .28757 L
s
.86746 .2331 m
.86747 .23453 L
s
.86741 .23395 m
.86746 .2331 L
s
.17574 .28413 m
.17709 .25247 L
s
.17577 .28305 m
.17709 .25247 L
s
.86747 .23453 m
.86755 .23855 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17575 .28359 m
.17642 .268 L
s
.86741 .23395 m
.86747 .23798 L
s
.17574 .28413 m
.17553 .2888 L
s
.86755 .23855 m
.86769 .24316 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86747 .23798 m
.86759 .24259 L
s
.1781 .23499 m
.17832 .23182 L
s
.17777 .24276 m
.1781 .23499 L
s
.17553 .2888 m
.17577 .28305 L
s
.17832 .23182 m
.17867 .22808 L
s
.86769 .24316 m
.86793 .25039 L
s
.17787 .2422 m
.17788 .24017 L
s
.17776 .24479 m
.17777 .24276 L
s
.86759 .24259 m
.86782 .24982 L
s
.178 .24366 m
.17787 .2422 L
s
.86959 .28387 m
.8698 .28757 L
s
.86953 .28333 m
.8698 .28757 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86793 .25039 m
.86848 .26341 L
s
.17721 .25576 m
.17709 .26041 L
s
.17676 .26618 m
.17721 .25576 L
s
.86782 .24982 m
.86838 .26285 L
s
.86923 .27756 m
.86959 .28387 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17788 .24612 m
.17789 .24626 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86848 .26341 m
.86892 .27179 L
s
.86914 .27702 m
.86953 .28333 L
s
.17676 .26618 m
.17709 .26041 L
s
.86892 .27179 m
.86923 .27756 L
s
.17709 .26041 m
.17709 .26246 L
s
.86838 .26285 m
.86882 .27124 L
s
.86882 .27124 m
.86914 .27702 L
s
.17709 .26246 m
.17725 .26397 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86642 .23823 m
.86742 .26159 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86621 .23736 m
.8665 .24399 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86376 .21006 m
.86401 .20689 L
s
.86344 .20254 m
.86401 .20689 L
s
.86317 .20571 m
.86344 .20254 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86317 .20571 m
.86376 .21006 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86456 .22893 m
.86693 .27514 L
s
.86456 .22893 m
.86608 .27405 L
s
.255 .412 .882 r
.85764 .23331 m
.8579 .23338 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85647 .21679 m
.85707 .21355 L
s
0 0 0 r
.86553 .2517 m
.86651 .2746 L
s
.85934 .20101 m
.86002 .20538 L
s
.86002 .20538 m
.8605 .21675 L
s
.85811 .19605 m
.85934 .20101 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85698 .22899 m
.85747 .24076 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85998 .21618 m
.86034 .21296 L
s
.255 .412 .882 r
.85644 .22771 m
.85674 .23486 L
s
0 0 0 r
.85582 .19371 m
.85811 .19605 L
s
.86684 .28226 m
.86693 .27514 L
s
.86014 .21998 m
.8605 .21675 L
s
.255 .412 .882 r
.85725 .23542 m
.85764 .23331 L
s
.85808 .24398 m
.85839 .24504 L
s
0 0 0 r
.85906 .21883 m
.85998 .21618 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85922 .22264 m
.86014 .21998 L
s
.86608 .27405 m
.86684 .28226 L
s
.255 .412 .882 r
.85747 .24076 m
.85808 .24398 L
s
.85674 .23486 m
.85747 .24076 L
s
0 0 0 r
.8611 .24286 m
.8613 .23578 L
s
.8613 .23578 m
.86194 .25107 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85649 .22363 m
.85906 .21883 L
s
.85477 .19635 m
.85582 .19371 L
s
.86073 .24613 m
.8611 .24286 L
s
.8611 .24286 m
.86194 .25107 L
s
.8543 .19957 m
.85477 .19635 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85979 .24886 m
.86073 .24613 L
s
.85335 .19138 m
.8543 .19957 L
s
.85335 .19138 m
.85398 .20663 L
s
.85398 .20663 m
.8543 .19957 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85541 .22634 m
.85649 .22363 L
s
.85745 .24666 m
.85979 .24886 L
s
.85665 .22746 m
.85922 .22264 L
s
.85557 .23018 m
.85665 .22746 L
s
.84712 .18617 m
.85001 .18848 L
s
.85494 .22962 m
.85541 .22634 L
s
.8551 .23346 m
.85557 .23018 L
s
.85605 .24171 m
.85745 .24666 L
s
.85494 .22962 m
.85526 .23731 L
s
.194 .26805 m
.19731 .18692 L
s
.85526 .23731 m
.85605 .24171 L
s
.84786 .18675 m
.85006 .24066 L
s
.19474 .26753 m
.19804 .18634 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84712 .18617 m
.84932 .24012 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19517 .18865 m
.197 .18733 L
s
.5 Mabswid
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84577 .18886 m
.84759 .19767 L
s
.84326 .18331 m
.84577 .18886 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84163 .18217 m
.84326 .18331 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.197 .18733 m
.20776 .17952 L
s
.84011 .18489 m
.84163 .18217 L
s
.83926 .18433 m
.84163 .18217 L
s
.19632 .22866 m
.20099 .22539 L
s
.84702 .23851 m
.85006 .24066 L
s
.83956 .19205 m
.84011 .18489 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20037 .24095 m
.20161 .20989 L
s
.8387 .19149 m
.83926 .18433 L
s
.83956 .19205 m
.84126 .23477 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20685 .20272 m
.20776 .17952 L
s
.20685 .20272 m
.20689 .18008 L
s
.255 .412 .882 r
.83469 .21024 m
.835 .2125 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.835 .2125 m
.83506 .21386 L
s
0 0 0 r
.8387 .19149 m
.84039 .23424 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82492 .17215 m
.83186 .176 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19185 .26963 m
.19369 .26842 L
s
.5 Mabswid
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19369 .26842 m
.20453 .26132 L
s
.21698 .17784 m
.22016 .17232 L
s
.21569 .18615 m
.21698 .17784 L
s
.20365 .26183 m
.20546 .23778 L
s
.20453 .26132 m
.20546 .23778 L
s
.21404 .22915 m
.21569 .18615 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82796 .17379 m
.83006 .22848 L
s
.82896 .17434 m
.83106 .229 L
s
.83771 .23265 m
.84126 .23477 L
s
.21798 .17729 m
.22016 .17232 L
s
.21668 .18561 m
.21798 .17729 L
s
.21503 .22864 m
.21668 .18561 L
s
.22016 .17232 m
.22223 .17123 L
s
.22223 .17123 m
.22529 .17351 L
s
.21113 .23071 m
.21503 .22864 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81291 .16626 m
.82071 .16999 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22529 .17351 m
.22719 .18026 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.827 .22694 m
.83106 .229 L
s
.22762 .16854 m
.23214 .16642 L
s
.22558 .22354 m
.22762 .16854 L
s
.81743 .16838 m
.81903 .21154 L
s
.2267 .22304 m
.22874 .16801 L
s
.81632 .16785 m
.81791 .21103 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83112 .25611 m
.83197 .25266 L
s
.83082 .2482 m
.83197 .25266 L
s
.82996 .25165 m
.83082 .2482 L
s
.255 .412 .882 r
.23379 .21122 m
.23413 .20169 L
s
0 0 0 r
.82996 .25165 m
.83112 .25611 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2223 .22506 m
.2267 .22304 L
s
.255 .412 .882 r
.23304 .20718 m
.23379 .21122 L
s
0 0 0 r
.8182 .21893 m
.81903 .21154 L
s
.255 .412 .882 r
.23399 .2057 m
.23523 .20244 L
s
0 0 0 r
.81707 .21843 m
.81791 .21103 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23761 .17559 m
.24032 .1667 L
s
.23598 .18791 m
.23761 .17559 L
s
.81492 .2214 m
.8182 .21893 L
s
.24032 .1667 m
.24419 .16124 L
s
.23882 .17508 m
.24155 .16619 L
s
.23718 .1874 m
.23882 .17508 L
s
.81492 .2214 m
.81707 .21843 L
s
.24155 .16619 m
.24419 .16124 L
s
.2357 .1958 m
.23598 .18791 L
s
.2369 .1953 m
.23718 .1874 L
s
.24419 .16124 m
.24673 .16023 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79955 .16058 m
.8082 .16417 L
s
.2357 .1958 m
.23647 .20718 L
s
.2369 .1953 m
.23769 .20668 L
s
.81258 .22041 m
.81492 .2214 L
s
.24673 .16023 m
.25049 .16267 L
s
.80883 .21497 m
.81258 .22041 L
s
.23647 .20718 m
.23864 .21414 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23769 .20668 m
.23988 .21365 L
s
.25049 .16267 m
.25287 .16959 L
s
.8061 .20605 m
.80883 .21497 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80332 .16211 m
.80528 .21749 L
s
.80456 .16262 m
.80652 .21797 L
s
.23864 .21414 m
.24225 .21668 L
s
.23988 .21365 m
.24225 .21668 L
s
.80148 .21606 m
.80652 .21797 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79212 .16944 m
.79386 .18182 L
s
.78915 .16055 m
.79212 .16944 L
s
.78489 .15514 m
.78915 .16055 L
s
.79077 .16896 m
.79252 .18134 L
s
.78779 .16007 m
.79077 .16896 L
s
.78489 .15514 m
.78779 .16007 L
s
.79386 .18182 m
.79413 .18977 L
s
.24225 .21668 m
.2461 .21525 L
s
.78209 .15418 m
.78489 .15514 L
s
.79252 .18134 m
.79279 .18929 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79319 .20125 m
.79413 .18977 L
s
.24927 .19835 m
.25073 .19389 L
s
.24927 .19835 m
.25046 .20186 L
s
.25073 .19389 m
.25193 .1974 L
s
.79184 .20078 m
.79279 .18929 L
s
.77938 .1572 m
.78209 .15418 L
s
.77794 .15673 m
.78209 .15418 L
s
.2461 .21525 m
.24886 .21031 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25179 .20139 m
.25193 .1974 L
s
.26299 .23753 m
.26571 .15338 L
s
.24886 .21031 m
.25179 .20139 L
s
.79075 .20831 m
.79319 .20125 L
s
.26444 .2371 m
.26715 .1529 L
s
.77675 .16422 m
.77938 .1572 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26147 .15481 m
.27151 .1515 L
s
.5 Mabswid
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78938 .20785 m
.79184 .20078 L
s
.77529 .16376 m
.77794 .15673 L
s
.78673 .21094 m
.79075 .20831 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77567 .17573 m
.77675 .16422 L
s
.78673 .21094 m
.78938 .20785 L
s
.7742 .17528 m
.77529 .16376 L
s
.27747 .14967 m
.28827 .14655 L
s
.77567 .17573 m
.77592 .18373 L
s
.78392 .21004 m
.78673 .21094 L
s
.7742 .17528 m
.77445 .18328 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77592 .18373 m
.77777 .1962 L
s
.28033 .20452 m
.28204 .14832 L
s
.78092 .20513 m
.78392 .21004 L
s
.77948 .20468 m
.78392 .21004 L
s
.77445 .18328 m
.7763 .19576 L
s
.28189 .2041 m
.28358 .14787 L
s
.77777 .1962 m
.78092 .20513 L
s
.7763 .19576 m
.77948 .20468 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75506 .14599 m
.76595 .14908 L
s
.25871 .23883 m
.26444 .2371 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73701 .14141 m
.74863 .14428 L
s
.27573 .20579 m
.28189 .2041 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30108 .14717 m
.30619 .14193 L
s
.29756 .15602 m
.30108 .14717 L
s
.29559 .1685 m
.29756 .15602 L
s
.30274 .14676 m
.30619 .14193 L
s
.2992 .15561 m
.30274 .14676 L
s
.29722 .16809 m
.2992 .15561 L
s
.30619 .14193 m
.30956 .14113 L
s
.29536 .17656 m
.29559 .1685 L
s
.29699 .17616 m
.29722 .16809 L
s
.30956 .14113 m
.31287 .14436 L
s
.29536 .17656 m
.29665 .18828 L
s
.29699 .17616 m
.2983 .18789 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27805 .22926 m
.27972 .22479 L
s
.27805 .22926 m
.27947 .23292 L
s
.27972 .22479 m
.28115 .22845 L
s
.31287 .14436 m
.31611 .15165 L
s
.31642 .13956 m
.32342 .13804 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74204 .14262 m
.7444 .22774 L
s
.7437 .14304 m
.74607 .22811 L
s
.75979 .1473 m
.76232 .23199 L
s
.76134 .14774 m
.76389 .2324 L
s
.27947 .23292 m
.28115 .22845 L
s
.29665 .18828 m
.29973 .19561 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2983 .18789 m
.30139 .19522 L
s
.75755 .2308 m
.76389 .2324 L
s
.72331 .14233 m
.72702 .15116 L
s
.71789 .13719 m
.72331 .14233 L
s
.72702 .15116 m
.72908 .16366 L
s
.72154 .14196 m
.72527 .15078 L
s
.71789 .13719 m
.72154 .14196 L
s
.29973 .19561 m
.30464 .19851 L
s
.72527 .15078 m
.72733 .16329 L
s
.7143 .13646 m
.71789 .13719 L
s
.30139 .19522 m
.30464 .19851 L
s
.72908 .16366 m
.72929 .17176 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71078 .13979 m
.7143 .13646 L
s
.72733 .16329 m
.72754 .17139 L
s
.72785 .18358 m
.72929 .17176 L
s
.30464 .19851 m
.30804 .19776 L
s
.7261 .18322 m
.72754 .17139 L
s
.33598 .1355 m
.33771 .1392 L
s
.33407 .1399 m
.33598 .1355 L
s
.33407 .1399 m
.33579 .14359 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70731 .14719 m
.71078 .13979 L
s
.70896 .13944 m
.7143 .13646 L
s
.30804 .19776 m
.31159 .19294 L
s
.70547 .14685 m
.70896 .13944 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31159 .19294 m
.31527 .18406 L
s
.33579 .14359 m
.33771 .1392 L
s
.72454 .19102 m
.72785 .18358 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72276 .19066 m
.7261 .18322 L
s
.73931 .22663 m
.74607 .22811 L
s
.70576 .15904 m
.70731 .14719 L
s
.70391 .1587 m
.70547 .14685 L
s
.65846 .09905 m
.6723 .101 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3142 .22495 m
.31642 .13956 L
s
.31596 .2246 m
.31816 .13918 L
s
.33531 .16388 m
.336 .21269 L
s
.33232 .21333 m
.33531 .16388 L
s
.30899 .22602 m
.31596 .2246 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70391 .1587 m
.70409 .16685 L
s
.70576 .15904 m
.70594 .16718 L
s
.71929 .19405 m
.72276 .19066 L
s
.71929 .19405 m
.72454 .19102 L
s
.70594 .16718 m
.70807 .17976 L
s
.71568 .19337 m
.71929 .19405 L
s
.70409 .16685 m
.70622 .17943 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6787 .13023 m
.68458 .13519 L
s
.68458 .13519 m
.68858 .14393 L
s
.68858 .14393 m
.69074 .15646 L
s
.6787 .13023 m
.68265 .13489 L
s
.68265 .13489 m
.68666 .14363 L
s
.71194 .1886 m
.71568 .19337 L
s
.7101 .18827 m
.71568 .19337 L
s
.6748 .12965 m
.6787 .13023 L
s
.70807 .17976 m
.71194 .1886 L
s
.68666 .14363 m
.68883 .15616 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70622 .17943 m
.7101 .18827 L
s
.33416 .21301 m
.33474 .18837 L
s
.67095 .13314 m
.6748 .12965 L
s
.69074 .15646 m
.69092 .16463 L
s
.68883 .15616 m
.689 .16432 L
s
.66715 .14075 m
.67095 .13314 L
s
.68926 .17661 m
.69092 .16463 L
s
.68734 .17631 m
.689 .16432 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36857 .16784 m
.37 .16728 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33232 .21333 m
.33396 .22125 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66866 .1729 m
.67007 .16634 L
s
0 0 0 r
.68558 .18424 m
.68926 .17661 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33396 .22125 m
.336 .21269 L
s
.68364 .18395 m
.68734 .17631 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66807 .1663 m
.66834 .16506 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66641 .10014 m
.66797 .1859 L
s
.66443 .09986 m
.66597 .18564 L
s
.64273 .12551 m
.65493 .12695 L
s
.67983 .1875 m
.68558 .18424 L
s
.67983 .1875 m
.68364 .18395 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61778 .12305 m
.63034 .12421 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6759 .18695 m
.67983 .1875 L
s
.66775 .17353 m
.67187 .18229 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67187 .18229 m
.6759 .18695 L
s
.62649 .14841 m
.64516 .1503 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65994 .18489 m
.66797 .1859 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62198 .12342 m
.6378 .21154 L
s
.63762 .19904 m
.64886 .12621 L
s
.6378 .21154 m
.65089 .12645 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400E0?nS40@0000000<0oj<@0:f][@3lX1002`3lX1060:f][I<0/>3V0@3o
ool00:H0/>3V1P2][Jd<0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa00603oXa05
00000100o:0@1@2][Jf>0;3PiP40oooo002Q0;3PiPD0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU
40030:f][@3oXa00oj<@01P0oj<@0P0000000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400H0?nS4080
000000<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0:f][@030:f][HH0/>3V0@3oool009T0/>3V
102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
5`3oXa02000000030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][H80/>3V
0@3oool009D0/>3V102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400G0?nS4080000000<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL
3`070?JL3`@0[Jf]OP2`h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01L0oj<@0P0000000`2][Jd0o:0@0?bP400G
0?bP40030:f][@3fW0l0mY`?00/0mY`?102][Jej0;3PiP40oooo002>0;3PiP@0[Jf]303oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005`3oXa020000
00030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][GH0/>3V0@3oool008X0
/>3V102][Jd@0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400G0?nS4080000000<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0
[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01L0oj<@0P0000000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Je`0;3PiP40oooo00240;3PiP<0[Jf]00<0
o:0@0:f][@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa005`3oXa02000000030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40503oYQ4f0:f][@l0ojD@00<0[Jf]0?nS403oXa005`3oXa02000000030:f][@3lX100
o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H1
0?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f][@L0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU4180[Jf]0`00000D0?nS4080000000<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][JeX0;3P
iP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@1@0000040:f][@`0oj<@0P0000000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0
/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40020?nS40030000
003oXa00oj<@00H0oj<@00<0[Jf]0000000000001@0000020:f][@80oj<@0P0000000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V
0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS40030000003o
Xa00oj<@00T0oj<@0P0000040?nS4080[Jf]0P0000030:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0K
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS4003
0?nS40030000003oXa00oj<@00T0oj<@0P0000060?nS4080000000<0[Jf]0?bP403lX1000`000003
0:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H1
0?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV
4@D0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@00<000000?nS
403oXa002@3oXa02000000H0oj<@0P0000000`2][Jd00000000000030?bP4080000000<0o:0@0:f]
[@2][Jd00`2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2]
[Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]1`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@00<000000?nS403oXa00203oXa02000000L0
oj<@0`0000060?bP408000001@3lX1050:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]
103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40
1@3oYQ400`2][Jd000000:f][@030:f][@`0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS40030?nS40030000003oXa00oj<@00P0oj<@0P0000070?nS40<000001P3lX102000000X0o:0@
0`2][Jd300000080o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100kiP@00@0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040000003oYQ400000000000@0[Jf]
00<000000?nV4@0000003`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@
00<000000?nS403oXa00203oXa02000000L0oj<@0P0000000`2][Jd0o:0@0?bP40050?bP40800000
2P3lX10300000080o:0@00@000000:f][@2][Jd0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A0100oj@A00@000000?nT4@3oY140[Jf]0P0000000`2][Jd0
ojHA0?nV4@030?nV4@030000003oYQ40000000l0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS40040?nS40030000003oXa00oj<@00L0oj<@0P0000070?nS4080000000<0[Jf]0?bP403l
X1001@3lX102000000T0o:0@00<000000?bP400000000`3lX102000000030:f][@3fW0l0[Jf]00<0
[Jf]00<0mY`?0000000000003P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0
fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00l0oj@A00H000000:f][@000000[Jf]0?nT4@0000070?nV4@800000403oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00@0oj<@00<000000?nS403oXa001`3oXa020000
00L0oj<@0P0000000`2][Jd0o:0@0?bP40060?bP40800000203lX102000000D0o:0@0P0000050?JL
3`<0[Jf]0`00000;0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f]
[E<0/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1402`3oY1420:f][@8000000`3oY1400`000000oj@A000000080?nV4@030000003oYQ40ojHA00h0
ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40040?nS40030000003oXa00oj<@00L0
oj<@0P0000080?nS40800000203lX102000000L0o:0@00<000000?bP400000001@3lX102000000P0
mY`?0P0000000`2][Jd00000000000090?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@050?nT4@800000102][Jd00`3oY1400000
000000040?nT4@030000003oY140000001T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS40040?nS40030000003oXa00oj<@00L0oj<@0P0000080?nS40800000203lX102000000L0o:0@
0P0000070?bP408000001`3fW0l2000000<0mY`?0P2][Jd3000000@0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@020?nT4@<000000P2][Jd50?nT4@800000103o
Y1400`000000oj@A0000000I0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00103o
Xa05000000@0oj<@0P0000090?nS4080000000<0[Jf]0?bP403lX1001@3lX102000000L0o:0@0P00
00070?bP408000001`3fW0l2000000L0mY`?100000000`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@00h0o:0@0P0000001P3oY140[Jf]000000000000[Jf]000000L0oj@A
0P0000060?nT4@8000006@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00D0oj<@
00@000000?nS403oXa00oj<@1P0000090?nS4080000000<0[Jf]0?bP403lX1001@3lX102000000L0
o:0@0P0000070?bP40030:f][@000000000000H0mY`?0P0000070?JL3`8000000P3fW0l30:f][A40
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP04
0:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100303lX102000000<0[Jf]103oY1400`00
0000oj@A0?nT4@050?nT4@8000001P3oY142000001T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS40050?nS40030000003oXa00oj<@00D0oj<@0P0000090?nS4080000000<0[Jf]0?bP
403lX1001P3lX102000000D0o:0@0P0000080?bP40030:f][@000000000000H0mY`?0P0000070?JL
3`8000000`3fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2]
[Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@00X0o:0@100000000`3lX100[Jf]0?nT4@040?nT4@030000003oY140
oj@A00@0oj@A0P0000080?nT4@030000003oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS40050?nS40030000003oXa00oj<@00D0oj<@0P0000090?nS4080000000<0[Jf]
0?bP403lX1001P3lX102000000D0o:0@0P0000080?bP40030:f][@000000000000H0mY`?0P000007
0?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P020>bF3P040:f][@0000000000000000X0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H0
0`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX103
0:f][@80000000<0o:0@0:f][@3oY140103oY1400`000000oj@A0?nT4@040?nT4@800000203oY140
0`000000ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^
0:f][AL0ojD@00<0[Jf]0?nS403oXa001@3oXa000`000000oj<@0?nS40050?nS408000002@3oXa02
000000030:f][@3lX100o:0@00H0o:0@0P0000050?bP40800000203lX1000`2][Jd0000000000006
0?JL3`8000001`3fW0l2000000<0mY`?00@0[Jf]0>bF3P3/UPh0k9H>0P000000103/UPh0[Jf]0000
000000090>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V
0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]0`3lX102000000030?bP402][Jd0oj@A00@0oj@A00<0
00000?nT4@3oY140103oY142000000L0oj@A00<0[Jf]0000003oYQ40603oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa001@3oXa000`000000oj<@0?nS
40050?nS408000002@3oXa02000000030:f][@3lX100o:0@00H0o:0@0P0000050?bP40800000203l
X100102][Jd0mY`?0000000000050?JL3`8000001`3fW0l2000000<0mY`?00@0[Jf]0>bF3P3/UPh0
k9H>0P0000030>bF3P040000002][Jd0[Jf]0:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3C
Q`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P0000030:f][@D0
o:0@0P0000000`3lX100[Jf]0?nT4@040?nT4@030000003oY140oj@A00@0oj@A0P0000070?nT4@03
0:f][@000000ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]0`3oXa000`000000oj<@0?nS40050?nS4080
00002@3oXa02000000030:f][@3lX100o:0@00H0o:0@0P0000050?bP40800000203lX100102][Jd0
mY`?0000000000050?JL3`8000001`3fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh00P0000040>bF
3P8000000P3/UPh20:f][@050000003/UPh0k9H>0>bF3P2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40050:f][@3lX100o:0@0?bP400000000P2][Jd2000000H0o:0@0P000000
0`3lX100[Jf]0?nT4@040?nT4@030000003oY140oj@A00<0oj@A0P0000080?nT4@030:f][@000000
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ490:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa04
0:f][@030000002][Jd0[Jf]00<0[Jf]0P00000:0?nS4080000000<0[Jf]0?bP403lX1001P3lX102
000000D0o:0@0P0000080?bP40040:f][@3fW0l00000000000D0mY`?0P0000070?JL3`8000000`3f
W0l00`2][Jd0k9H>0>bF3P02000000@0k9H>0P0000040>bF3P050:f][@00000000000000002][Jd0
3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40050:f][@3lX100[Jf]0:f][@000000
0`3lX1000`000000o:0@0?bP40040?bP4080000000<0o:0@0:f][@3oY140103oY1400`000000oj@A
0?nT4@030?nT4@800000203oY1400`2][Jd000000?nV4@070?nV4@030000003oYQ40ojHA00h0ojHA
00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001P3oXa000`000000oj<@
0?nS40030?nS40800000202][Jd20?nS4080000000<0[Jf]0?bP403lX1001P3lX102000000H0o:0@
0P0000070?bP40040:f][@3fW0l00000000000H0mY`?00<000000?JL3`3fW0l01@3fW0l2000000<0
mY`?00<0[Jf]0>bF3P3/UPh00P0000050>bF3P030000003/UPh0k9H>00@0k9H>0`00000=0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@
0>nH40090>nH408000000P2][Jd00`3lX10000000?bP40040?bP40030000003lX100o:0@00<0o:0@
0P0000000`3lX100[Jf]0?nT4@040?nT4@030000003oY140oj@A00<0oj@A0P0000080?nT4@030:f]
[@000000ojHA00L0ojHA00<000000?nV4@3oYQ40303oYQ470:f][AL0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
1P3oXa000`000000oj<@0?nS40030?nS40800000203oXa020:f][@800000102][Jd50?bP40800000
1P3lX102000000L0o:0@00@0[Jf]0?JL3`00000000001P3fW0l00`000000mY`?0?JL3`050?JL3`80
00000`3fW0l00`2][Jd0k9H>0>bF3P02000000D0k9H>0P0000050>bF3P8000000`2][Jd00`000000
fhX=0=^:3@080=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]
203CQ`h00`2][Jd0kiP@0>nH40070>nH408000000`2][Jd00`3lX1000000000000050?bP40030000
003lX100o:0@00<0o:0@0P0000000`3lX100[Jf]0?nT4@040?nT4@030000003oY140oj@A00<0oj@A
0P0000080?nT4@030:f][@000000ojHA00L0ojHA00<000000?nV4@3oYQ401P3oYQ460:f][@80ojHA
00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40060?nS40030000003oXa00oj<@00<0oj<@
0P00000:0?nS4080000000@0[Jf]0?bP403lX100o:0@1@2][Jd2000000H0o:0@0P0000070?bP4004
0:f][@3fW0l00000000000H0mY`?00<000000?JL3`3fW0l01P3fW0l01@000000mY`?0?JL3`3fW0l0
[Jf]0080k9H>0P0000060>bF3P030000003/UPh0k9H>00<0k9H>0P000000102][Jd0fhX=0=^:3@2]
[Jd2000000P0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L
0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001@3_V10010000000kiP@00000000
00020>nH40030:f][@3lX100000000`0o:0@0P0000000`3lX100[Jf]0?nT4@040?nT4@030000003o
Y140oj@A00<0oj@A0P0000080?nT4@030:f][@000000ojHA00L0ojHA00@000000?nV4@3oYQ40ojHA
1@2][Jd80?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001P3oXa000`000000oj<@
0?nS40030?nS408000002P3oXa02000000030:f][@3lX100o:0@00D0o:0@0P0000070:f][@800000
1`3lX100102][Jd0mY`?0000000000060?JL3`030000003fW0l0mY`?00H0mY`?00H000000?JL3`3f
W0l0mY`?0:f][@3/UPh2000000L0k9H>00<000000>bF3P3/UPh00`3/UPh2000000040:f][@3KRPd0
fhX=0=^:3@@000001P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3o
ool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40040>nH40030000002]
[Jd00000008000000P3_V1000`2][Jd000000000000<0?bP4080000000<0o:0@0:f][@3oY140103o
Y1400`000000oj@A0?nT4@030?nT4@800000203oY1400`2][Jd000000?nV4@060?nV4@030:f][@00
0000[Jf]0080[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00L0oj<@00<0
00000?nS403oXa000P3oXa02000000X0oj<@0P0000000`2][Jd0o:0@0?bP40050?bP408000001`3l
X102000000@0[Jf]0`3lX100102][Jd0mY`?0000000000060?JL3`030000003fW0l0mY`?00H0mY`?
00H000000?JL3`3fW0l0mY`?0:f][@3/UPh2000000L0k9H>00<000000>bF3P3/UPh00`3/UPh20000
00040:f][@3KRPd0fhX=0=^:3@80000000@0fhX=0:f][@3KRPd00000103KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]
203CQ`h00`2][Jd0kiP@0>nH40030>nH40030000002][Jd0kiP@00<000000P3_V1000`2][Jd00000
0000000<0?bP4080000000<0o:0@0:f][@3oY140103oY1400`000000oj@A0?nT4@030?nT4@800000
203oY1400`2][Jd000000?nV4@060:f][@030?nV4@000000ojHA00l0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS40070?nS40030000003oXa00oj<@0080oj<@0P00000:0?nS40800000
00<0[Jf]0?bP403lX1001@3lX102000000P0o:0@0P0000030?bP40D0[Jf]0P0000060?JL3`030000
003fW0l0mY`?00H0mY`?00H000000?JL3`3fW0l0mY`?0:f][@3/UPh2000000L0k9H>00<000000>bF
3P3/UPh00`3/UPh2000000040:f][@3KRPd0fhX=0=^:3@8000000P3KRPd20:f][@8000000P3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P3_V100102][Jd000000>nH
403_V10300000080kiP@00<0[Jf]000000000000303lX102000000030?bP402][Jd0oj@A00<0oj@A
00<000000?nT4@3oY140103oY142000000L0oj@A0P2][Jd00`000000[Jf]0?nV4@060?nV4@030000
003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40070?nS40030000
003oXa00oj<@0080oj<@00<000000?nS403oXa002@3oXa03000000L0o:0@0P0000080?bP40800000
1P3lX100102][Jd0mY`?0000000000020:f][@@0mY`?00<000000?JL3`3fW0l01P3fW0l01P000000
mY`?0?JL3`3fW0l0[Jf]0>bF3P800000203/UPh00`000000k9H>0>bF3P020>bF3P80000000@0[Jf]
0=^:3@3KRPd0fhX=0P0000040=^:3@<0000000<0fhX=0:f][@2iM@/0202iM@/01@2][Jd0R5H708QF
1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f]
[@000000kiP@0080[Jf]0P0000030>nH408000000P3_V1000`2][Jd000000000000<0?bP40800000
00<0o:0@0:f][@3oY1400`3oY1400`000000oj@A0?nT4@040?nT4@8000000`3oY1440:f][@030?nT
4@2][Jd0000000P0ojHA00<000000?nV4@3oYQ403P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@00L0oj<@00@000000?nS403oXa00oj<@0P00000;0?nS40<000001P3lX102000000T0
o:0@0P0000060?bP40030:f][@3fW0l0000000<0mY`?102][Jd00`000000mY`?0?JL3`060?JL3`06
0000003fW0l0mY`?0?JL3`2][Jd0k9H>0P0000080>bF3P030000003/UPh0k9H>0080k9H>0P000000
102][Jd0fhX=0=^:3@3KRPd2000000@0fhX=0P0000030:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28
EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]
0=>73P3CQ`h01@3CQ`h3000000040:f][@3_V100kiP@000000@0kiP@0P0000020>nH40030:f][@00
0000o:0@00`0o:0@0P0000000`3lX100[Jf]0?nT4@030?nT4@030000003oY140oj@A00@0oj@A0P00
00030:f][@D0oj@A00<0[Jf]0000003oYQ401`3oYQ400`000000ojHA0?nV4@0>0?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001`3oXa0010000000oj<@0?nS403oXa02000000/0oj<@
0P0000000`2][Jd000000?bP40040?bP408000002@3lX102000000H0o:0@00<0[Jf]0?JL3`000000
1`3fW0l010000000[Jf]0:f][@2][Jd50?JL3`050000003fW0l0mY`?0?JL3`2][Jd00P3/UPh00`00
0000k9H>0>bF3P060>bF3P030000003/UPh0k9H>0080k9H>0P000000102][Jd0fhX=0=^:3@3KRPd2
000000@0fhX=0P0000020=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01`3CQ`h0
10000000dhL>0000000000020>nH40800000103_V10200000080kiP@00<0[Jf]0000003lX100303l
X102000000030?bP402][Jd0oj@A00<0oj@A00<000000?nT4@3oY1400P3oY1420:f][@800000203o
Y1400`000000ojHA0?nV4@070?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS40070?nS40040000003oXa00oj<@0?nS408000002`3oXa02000000030:f]
[@000000o:0@00<0o:0@0P00000;0?bP40030000003lX100o:0@00@0o:0@00<0[Jf]0?JL3`000000
1`3fW0l010000000mY`?0?JL3`3fW0l40:f][@030?JL3`000000mY`?0080mY`?00@0[Jf]0>bF3P3/
UPh00000203/UPh00`000000k9H>0>bF3P020>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=0P000004
0=^:3@8000000P3KRPd20:f][@030;Ue2`000000000000D0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h2
000000040=>73P2][Jd0000000000080kiP@0P0000040>nH4080000000@0kiP@0:f][@3lX1000000
3@3lX102000000030?bP402][Jd0oj@A00<0oj@A00<000000:f][@2][Jd00P2][Jd30?nT4@800000
1`3oY1400`000000ojHA0?nV4@070?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS40080?nS40030000003oXa00oj<@00800000203oXa02000000060?nS
4000000000000:f][@3lX10000000`3lX102000000/0o:0@00<000000?bP403lX100103lX1000`2]
[Jd00000000000070?JL3`030000003fW0l0mY`?00D0mY`?00H0[Jf]0000002][Jd0[Jf]0?JL3`2]
[Jd20>bF3P030000003/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh00P3/UPh2000000040:f][@3K
RPd0fhX=0=^:3@800000103KRPd200000080fhX=00D0[Jf]0;Ue2`000000[Jf]000000050;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00@0dhL>0P0000020:f][@030=>73P00000000000080kiP@0P0000040>nH4080
000000@0kiP@0:f][@3lX10000003@3lX102000000030?bP402][Jd0oj@A00<0[Jf]00<000000?nT
4@3oY1401@3oY142000000H0oj@A0P0000090?nV4@030000003oYQ40ojHA00d0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS40080?nS40030000003oXa00oj<@008000002P3oXa030000
00030:f][@3lX100o:0@00@000003@3lX1000`000000o:0@0?bP40030?bP40030:f][@000000mY`?
00L0mY`?0P0000070?JL3`030000003fW0l0mY`?00<0[Jf]00<0k9H>0000003/UPh01`3/UPh00`00
0000k9H>0>bF3P020>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=0P0000040=^:3@8000000P3KRPd0
1@2][Jd0^GD;0000002iM@/0[Jf]008000000`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`
h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P<000000`3C
Q`h200000080kiP@0P0000040>nH4080000000@0kiP@0:f][@3lX10000003@3lX102000000<0[Jf]
0`3oY1400`000000oj@A0?nT4@050?nT4@8000001P3oY142000000P0ojHA0P00000?0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00203oXa000`000000oj<@0?nS4002000000d0oj<@
00<0[Jf]0?bP403lX1004@3lX1000`000000o:0@0?bP40030?bP40800000203fW0l2000000L0mY`?
00T000000?JL3`3fW0l0mY`?0:f][@3/UPh0[Jf]0000002][Jd01`3/UPh00`000000k9H>0>bF3P02
0>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=0P0000040=^:3@8000000P3KRPd00`2][Jd0^GD;0000
00020;Ue2`<000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>0P0000030=>73P040000003_V100kiP@0>nH40800000
103_V102000000040>nH402][Jd0o:0@000000`0o:0@00D0[Jf]000000000000o:0@0:f][@040?nT
4@030000003oY140oj@A00D0oj@A0P0000050?nT4@030000003oY140000000P0ojHA0P00000?0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00203oXa0010000000oj<@0?nS4000000>
0?nS40030:f][@3lX100o:0@0180o:0@00<000000?bP403lX1000P3lX102000000P0mY`?0P000007
0?JL3`050000003fW0l0mY`?0?JL3`2][Jd00P3/UPh200000080[Jf]1@3/UPh00`000000k9H>0>bF
3P030>bF3P030000002][Jd0fhX=00<0fhX=0P0000030=^:3@8000000P3KRPd00`2][Jd0^GD;0000
00020;Ue2`8000000P2iM@/00`000000[Jf]08QF1`0308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0000000000000`3CQ`h010000000kiP@0>nH
403_V102000000@0kiP@0P000000103_V100[Jf]00000000000:0?bP4080[Jf]00D0o:0@00000000
0000o:0@0:f][@040?nT4@030000003oY140oj@A00H0oj@A0P0000040?nT4@030000003oY1400000
00P0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00203oXa001000
0000oj<@00000000000>0?nS40030:f][@3lX100o:0@01<0o:0@00<000000?bP403lX1000P000009
0?JL3`8000001`3fW0l200000080mY`?00D0[Jf]0>bF3P3/UPh0k9H>000000020>bF3P<0[Jf]0P3/
UPh00`000000k9H>0>bF3P030>bF3P800000103KRPd2000000<0fhX=0P0000020=^:3@030:f][@2i
M@/000000080^GD;0P0000020:f][@8000001028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]
09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@030=>73P000000000000<0dhL>00@000000>nH403_V100
kiP@0P0000040>nH4080000000@0kiP@0:f][@00000000001P3lX10010000000[Jf]0:f][@2][Jd2
0?bP408000000P3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00H0oj@A0P000003
0?nT4@040000003oY140oj@A000000P0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa002@3oXa03000000h0oj<@00<0
[Jf]0?bP403lX100503lX10200000080o:0@00<0[Jf]0?JL3`3fW0l01P3fW0l2000000L0mY`?0P00
00020?JL3`050:f][@3/UPh0k9H>0>bF3P0000001@3/UPh00`2][Jd00000000000050>bF3P800000
103KRPd2000000<0fhX=0P0000020=^:3@030:f][@2iM@/0000000<0^GD;00<000000;Ue2`2iM@/0
0P00000408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@<0dhL>
0P0000030=>73P040000003_V100kiP@0>nH408000000`3_V10200000080kiP@00<0[Jf]00000000
0000103lX100102][Jd000000:f][@0000040?bP408000000P3lX1000`2][Jd0oj@A0?nT4@020?nT
4@030000003oY140oj@A00L0oj@A0P0000000`3oY14000000?nT4@020?nT4@030000003oYQ40ojHA
00H0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU4100[Jf]1`3oYA000`2]
[Jd0oj<@0?nS40090?nS40<000003P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00H0mY`?0P0000070?JL3`8000000P3fW0l01@2][Jd0k9H>0>bF3P3/UPh0000000H0k9H>0P000002
0:f][@<0k9H>0P0000040=^:3@8000000`3KRPd200000080fhX=00<0[Jf]0;Ue2`0000000`2iM@/0
0`000000^GD;0;Ue2`03000000@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>0P0000030=>73P040000003_V100kiP@0>nH408000000`3_
V10200000080kiP@00<0[Jf]0000000000000P3lX1020:f][@030?bP40000000000000D0o:0@0P00
00020?bP40030:f][@3oY140oj@A0080oj@A00<000000?nT4@3oY1402@3oY1400`000000oj@A0?nT
4@020?nT4@030000003oYQ40ojHA00H0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01H0ojHA302]
[JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA005@3oYA0<0:f][@L0oj<@0`00
000>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01P3fW0l2000000L0mY`?0P00
00020?JL3`050:f][@3/UPh0k9H>0>bF3P0000001P3/UPh200000080k9H>0`2][Jd2000000@0fhX=
0P0000030=^:3@8000000`3KRPd00`2][Jd000000;Ue2`020;Ue2`060000002iM@/0^GD;0000002]
[Jd000001028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080
[Jf]103CQ`h200000080dhL>00<0[Jf]0000003_V1000P3_V102000000<0kiP@0P0000020>nH4003
0:f][@00000000000080[Jf]0`3lX102000000D0o:0@0P0000020?bP40030:f][@3oY140oj@A0080
oj@A00<000000?nT4@3oY1403P3oY1400`000000ojHA0?nV4@060?nV4@8000003`3oYQ400`2][Jd0
ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40020?nS40L0[Jf]00<000000:f][@00
00003P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00H0mY`?0P0000070?JL3`80
00000P3fW0l0102][Jd0k9H>0>bF3P3/UPh2000000D0k9H>0P0000050>bF3P80000000@0[Jf]0=^:
3@3KRPd0fhX=0P0000030=^:3@8000000`3KRPd00`2][Jd000000;Ue2`020;Ue2`040000002iM@/0
^GD;00000080[Jf]00D0000008QF1`28EPL0R5H70:f][@120;3PiP40oooo001I0;3PiP030:f][@2G
H0/0Uf0;0080[Jf]103CQ`h200000080dhL>00<0[Jf]0000003_V1000P3_V102000000<0kiP@0P00
00020>nH4080[Jf]00<000000?bP403lX100103lX1000`000000o:0@0?bP40030?bP408000000P3l
X1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00h0oj@A00<000000?nV4@3oYQ401P3o
YQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002@3o
Xa000`000000oj<@0000000:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`060?JL3`8000001`3fW0l200000080mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF
3P030>bF3P8000001@3/UPh2000000040=^:3@2][Jd0[Jf]0=^:3@800000103KRPd200000080fhX=
00<0[Jf]0000002iM@/00P2iM@/02`000000^GD;0;Ue2`000000[Jf]08QF1`000000R5H700000028
EPL0[Jf]0480/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@040=>73P8000000P3C
Q`h00`2][Jd0kiP@0>nH40020>nH408000000`3_V102000000<0[Jf]00<0o:0@0000003lX1001@3l
X1000`000000o:0@0?bP40030?bP408000000P3lX1000`2][Jd0oj@A0000000300000100oj@A00<0
00000?nV4@3oYQ401P3oYQ42000000`0ojHA202][JdH0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00T0oj<@0P00
000;0?nS40P0[Jf]5`3lX1000`2][Jd0mY`?0?JL3`060?JL3`8000001`3fW0l200000080mY`?00<0
[Jf]0>bF3P3/UPh00P3/UPh2000000<0k9H>0P0000060>bF3P8000000`3KRPd00`2][Jd000000000
00040=^:3@8000000P3KRPd00`2][Jd000000;Ue2`020;Ue2`0;0000002iM@/0^GD;0000002][Jd0
R5H70000002][Jd0000008QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0
[Jf]00@0dhL>00D000000=>73P3CQ`h0dhL>0:f][@040>nH40030000003_V100kiP@0080kiP@0P00
00020>nH40030:f][@3lX100000000D0o:0@00<000000?bP403lX100103lX102000000030?bP402]
[Jd0oj@A01D0oj@A00<000000?nV4@3oYQ401P3oYQ42000000H0ojHA1P2][Jd30?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002P3oXa000`000000oj<@0?nS400=0?nS40040:f][@3l
X100o:0@0?bP40L0[Jf]403lX1000`2][Jd0mY`?0?JL3`070?JL3`030000003fW0l0mY`?00D0mY`?
0P0000030?JL3`030:f][@3/UPh0k9H>0080k9H>00@000000>bF3P3/UPh0k9H>0P0000060>bF3P80
0000103KRPd2000000040:f][@3KRPd0fhX=0=^:3@8000000P3KRPd00`2][Jd000000;Ue2`020;Ue
2`0;0000002iM@/0^GD;0000002][Jd0R5H700000028EPL0000008QF1`2][Jd0@P2`h>H10?ooo`00
F@2`h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00@0
kiP@00<000000>nH403_V1000P2][Jd200000080kiP@00@0[Jf]0?bP400000000000103lX1000`00
0000o:0@0?bP40040?bP4080000000<0o:0@0:f][@3oY1405@3oY1400`000000ojHA0?nV4@060?nV
4@8000001P2][Jd90?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002P3oXa000`00
0000oj<@0?nS400=0?nS40030:f][@3lX100o:0@00P0o:0@1P2][Jd:0?bP40030:f][@3fW0l0mY`?
00L0mY`?00<000000?JL3`3fW0l01@3fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20000
0080k9H>0P0000060>bF3P800000103KRPd2000000040=^:3@2][Jd0[Jf]0=^:3@8000000P3KRPd0
0`2][Jd000000;Ue2`020;Ue2`0;0000002iM@/0^GD;0;Ue2`2][Jd0R5H700000028EPL0000008QF
1`2][Jd0@P2`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@000000
dhL>0000003CQ`h0[Jf]00@0kiP@00<000000:f][@2][Jd00P3_V10200000080kiP@00@0[Jf]0?bP
400000000000103lX1000`000000o:0@0?bP40040?bP4080000000<0o:0@0:f][@3oY1405@3oY140
10000000ojHA0?nV4@3oYQ450:f][@8000003`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@00X0oj<@00<000000?nS403oXa003@3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3l
X1000`2][Jd0mY`?0?JL3`070?JL3`030000003fW0l0mY`?00D0mY`?0P0000030?JL3`030:f][@3/
UPh0k9H>00<0k9H>100000070>bF3P800000103KRPd2000000<0fhX=00L0[Jf]000000000000fhX=
045Yh@2][Jd0000000<0^GD;00T000000;Ue2`2iM@/0^GD;0:f][@28EPL0000008QF1`0000000P2]
[Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01@000000dhL>0000
003CQ`h0[Jf]00<0kiP@00<0[Jf]0000003_V1000`3_V10200000080kiP@00<0[Jf]0?bP403lX100
0P0000020?bP40030000003lX100o:0@00D0o:0@0P0000000`3lX100[Jf]0?nT4@0D0?nT4@030:f]
[@000000[Jf]0080[Jf]1@3oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][Jd70?JL3`030000003fW0l0mY`?00H0mY`?
00D000000?JL3`3fW0l0mY`?0:f][@0@0>bF3P800000103KRPd2000000@0fhX=0P000000102][Jd0
fhX=0:f][@0000030;Ue2`070000002iM@/0^GD;0;Ue2`2][Jd0@FWQ0000000308QF1`030:f][@2`
h>H0/>3V0400/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00H00000
0=>73P000000dhL>0:f][@3_V1020:f][@030>nH40000000kiP@00<0kiP@0P0000020>nH40030:f]
[@3lX100o:0@008000000P3lX1000`000000o:0@0?bP40050?bP4080000000<0o:0@0:f][@3oY140
403oY1440:f][@030?nT4@000000ojHA00L0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0[Jf]
0`3fW0l00`000000mY`?0?JL3`060?JL3`050000003fW0l0mY`?0?JL3`2][Jd0403/UPh3000000<0
fhX=00<000000=^:3@3KRPd00`3KRPd2000000030=^:3@2][Jd0[Jf]008000000`2iM@/01P000000
^GD;0;Ue2`2iM@/0[Jf]000000<0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P020=>73P040000003CQ`h000000=>73P80[Jf]0`3_V1000`000000kiP@0>nH4002
0>nH408000000P3_V100102][Jd0o:0@0?bP403lX103000000P0o:0@0P0000000`3lX100[Jf]0?nT
4@0<0?nT4@@0[Jf]1@3oY1400`000000ojHA0?nV4@060?nV4@030000003oYQ40ojHA00h0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0103fW0l30:f][@030000002][Jd0mY`?00H0mY`?00D000000?JL3`3fW0l0mY`?
0:f][@0>0>bF3P@0000000D0fhX=0000003KRPd0fhX=000000050=^:3@8000000P3KRPd00`2][Jd0
0000000000030;Ue2`060000002iM@/0^GD;0;Ue2`2][Jd000000`28EPL20:f][D40/>3V0@3oool0
05P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00<000000=>73P0000000P2][Jd40>nH
40030000003_V100kiP@0080kiP@0P0000020>nH40030:f][@3lX100o:0@00`0o:0@0P0000000`3l
X100[Jf]0?nT4@080?nT4@@0[Jf]2@3oY1400`000000ojHA0?nV4@060?nV4@030000003oYQ40ojHA
00h0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l00`000000mY`?0:f][@040:f][@80mY`?00D000000?JL
3`3fW0l0mY`?0:f][@0@0>bF3P80000000D0fhX=0000003KRPd0fhX=000000050=^:3@8000000P3K
RPd0102][Jd000000000002][Jd20;Ue2`060000002iM@/0^GD;0;Ue2`2][Jd000000`28EPL20:f]
[D40/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00D000000=>73P00
0000dhL>0:f][@040>nH40030000003_V100kiP@0080kiP@0P0000020>nH40030:f][@3lX100o:0@
00`0o:0@0P0000000`3lX100[Jf]0?nT4@040?nT4@@0[Jf]3@3oY1400`000000ojHA0?nV4@060?nV
4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l00`000000mY`?0?JL3`040?JL
3`80[Jf]00D000000:f][@3fW0l0mY`?0:f][@0B0>bF3P040:f][@3KRPd00000000000H0fhX=0P00
00020=^:3@070:f][@00000000000;Ue2`2][Jd0^GD;000000030;Ue2`8000000`28EPL20:f][D40
/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00D000000:f][@000000
dhL>0:f][@040>nH40030000003_V100kiP@0080kiP@0P0000020>nH40030:f][@3lX100o:0@00`0
o:0@0P0000000`3lX100[Jf]0?nT4@040:f][A40oj@A00<000000?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`070?JL3`030000003fW0l0mY`?00H0mY`?00<000000?JL3`2][Jd00`2][JdA0>bF3P03
0:f][@3KRPd0fhX=00L0fhX=0P0000020=^:3@030:f][@00000000000080^GD;00L0[Jf]0000002i
M@/0^GD;0000002][Jd0000000<0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/02P2]
[Jd0dhL>0=>73P3CQ`h0[Jf]0000003CQ`h000000=>73P2][Jd40>nH40040000003_V100kiP@0>nH
408000000`3_V1000`2][Jd0o:0@0?bP400<0?bP408000000`2][Jd30?nT4@030000003oY140oj@A
00h0oj@A0P00000I0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00L0mY`?00<000000?JL3`3fW0l01P3fW0l01P00
0000mY`?0?JL3`3fW0l0[Jf]0>bF3P<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@070=^:3@8000000P3K
RPd00`2][Jd00000000000030;Ue2`030000002iM@/0^GD;008000001028EPL20:f][D40/>3V0@3o
ool005P0/>3V0P2][Jd309MP2`040:f][@3CQ`h0dhL>0:f][@@0000000<0dhL>0:f][@3_V1000`3_
V1000`000000kiP@0>nH40060>nH40030:f][@3lX100o:0@00`0o:0@0P0000000`3lX100[Jf]0?nT
4@030?nT4@030000003oY140oj@A00`0oj@A0P0000000`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?00@0mY`?0P0000000`3fW0l000000?JL3`070?JL3`050000003fW0l0mY`?0?JL3`2][Jd0
103/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd300000080fhX=00<0[Jf]000000000000
0`2iM@/00`000000[Jf]0:f][@02000000@0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`2G
H0/0102][Jd0dhL>0:f][@3CQ`h2000000040=>73P000000dhL>0:f][@@0kiP@00<000000>nH403_
V1001P3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0P0000000`3lX100[Jf]0?nT4@030?nT4@80
0000403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00H0mY`?0P0000080?JL3`05
0000003fW0l0mY`?0?JL3`2][Jd01P3/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20000
0080fhX=00<0[Jf]0000000000000`2iM@/01@000000^GD;0;Ue2`000000@FWQ0080R5H700@00000
08QF1`2][Jd0[Jf]@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;0P2][Jd20=>73P80000000@0dhL>
0000003CQ`h0[Jf]0P3_V102000000T0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@<0o:0@0P00
00000`3lX100[Jf]0?nT4@030?nT4@030000003oY140oj@A00l0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0=0?JL3`80000000<0mY`?0000003fW0l00P3fW0l00`2][Jd0k9H>0>bF
3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@000000000000<0^GD;00D0
00000;Ue2`2iM@/000000:f][@0208QF1`0400000028EPL0[Jf]0:f][D40/>3V0@3oool005P0/>3V
00<0[Jf]09MP2`2GH0/00P2GH0/0102][Jd0dhL>0=>73P3CQ`h2000000040=>73P000000dhL>0:f]
[@d0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@D0o:0@0P0000000`3lX100[Jf]0?nT4@030?nT
4@030000003oY140oj@A00h0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0?0?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@<000000`2iM@/010000000^GD;0;Ue2`000002
0:f][@0308QF1`000000R5H70080[Jf]@@2`h>H10?ooo`00F02`h>H0102][Jd0Uf0;09MP2`2GH0/2
0:f][@<0dhL>0P0000000`3CQ`h000000:f][@0>0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]203l
X102000000030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd2000000<0^GD;00@000000;Ue2`2iM@/00000
0P2][Jd20000000308QF1`2][Jd0[Jf]0440/>3V0@3oool005P0/>3V00@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd30=>73P80000000@0dhL>0000002][Jd000003@3_V100102][Jd0o:0@0:f][@2][Jd;0?bP
4080000000<0o:0@0:f][@3oY140503oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA
01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/01P00
0000^GD;0;Ue2`000000[Jf]08QF1`80000000<0@FWQ0:f][@2][Jd0@@2`h>H10?ooo`00F02`h>H0
1P2][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@<0dhL>0P000000103CQ`h000000:f][@00000<0>nH40<0
[Jf]2`3lX102000000<0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@03
0:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:
3@040:f][@2iM@/0^GD;0;Ue2`8000000P2iM@/00`000000[Jf]08QF1`020000000308QF1`2][Jd0
[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/0102][Jd0dhL>0=>73P3CQ`h2
000000040=>73P000000[Jf]000000X0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`
h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3K
RPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`060000002iM@/0^GD;0000002]
[Jd0R5H70`0000020:f][D40/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/0102][Jd0
dhL>0=>73P3CQ`h200000080dhL>00<0[Jf]0000003_V1001`3_V1020:f][@<0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3P
iPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`000000[Jf]08QF1`030000
0080[Jf]@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P0000020=>7
3P030:f][@000000kiP@00D0kiP@0P2][Jd50>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0[Jf]0?JL
3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd50=^:
3@030:f][@2iM@/0^GD;00H0^GD;00<0000008QF1`0000000P0000020:f][D40/>3V0@3oool005P0
/>3V0P2][Jd309MP2`050:f][@3CQ`h0dhL>0=>73P0000000`3CQ`h00`2][Jd000000>nH40030>nH
4080[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`0300000028EPL00000008000000P2][Je10;3PiP40oooo001G0;3PiP80[Jf]102GH0/01@2][Jd0
dhL>0=>73P3CQ`h0000000<0dhL>0P0000020>nH4080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX100
0`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd0
1@000000[Jf]0:f][@3KRPd0[Jf]00T0^GD;100000020:f][D40/>3V0@3oool005L0/>3V0P2][Jd3
09MP2`030:f][@3CQ`h0dhL>0080dhL>00@000000=>73P3CQ`h0dhL>0P0000020:f][@/0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@8000000P3KRPd20:f][@T0^GD;00@0
[Jf]00000000000000000P2][Je10;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>7
3P020=>73P040000003CQ`h0dhL>0=>73P8000003@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00L0fhX=0P0000030=^:3@<0[Jf]1`2iM@/0102][Jd0R5H708QF1`0000020:f][D40
/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00@000000=>73P3CQ`h0
[Jf]0P00000=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0
/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd01@000000
fhX=0=^:3@3KRPd0[Jf]0080^GD;00<0[Jf]0;Ue2`2iM@/0102iM@/0102][Jd0R5H708QF1`000002
0:f][D40/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00@000000:f]
[@2][Jd0dhL>0P00000<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY145
0:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd0
1@000000fhX=0=^:3@3KRPd0[Jf]00<0^GD;00<0[Jf]0;Ue2`2iM@/00`2iM@/0102][Jd0R5H708QF
1`0000020:f][D40/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00@0
00000=>73P3CQ`h0dhL>0P00000<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140
102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00@0[Jf]08QF1`28EPL000000P2][Je10;3PiP40
oooo001G0;3PiP80[Jf]0`2GH0/01P2][Jd0dhL>0=>73P3CQ`h0[Jf]000000<0dhL>0P00000<0>nH
40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0P28EPL00`000000[Jf]0:f][@11
0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/01P2][Jd0dhL>0:f][@2][Jd0dhL>000000<0dhL>00<0
00000>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0[Jf]0P28EPL00`000000[Jf]0:f]
[@110;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/20:f][@<0dhL>00D000000=>73P00000000000:f]
[@0=0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2]
[Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f]
[@28EPL0R5H70080000000<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP
2`0209MP2`030:f][@3CQ`h0dhL>0080dhL>0P0000020=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]00@0R5H7000000000000[Jf]
@@2`h>H10?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@<0dhL>0P0000030=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V
0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`80[Jf]00@0R5H7000000000000[Jf]@@2`h>H10?ooo`00E`2`h>H0102][Jd0Uf0;
09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080
[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0
`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`2][Jd00P0000000`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP060:f]
[@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]
0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f]
[@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080000000<0[Jf]0;3PiP2`h>H0?`2`h>H10?oo
o`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_
V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0
[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080
[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080000000<0[Jf]0;3PiP2`
h>H0?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H700800000
00<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0R5H7
0000002][Je10;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f]
[@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036
`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080
[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`0000000P2][Je00;3P
iP40oooo001G0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0
kiP@0>nH403_V1020:f][@@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f]
[@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
1@2][Jd0R5H708QF1`28EPL000000080[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00T0dhL>00@0[Jf]0>nH402][Jd0[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@040;6[W@80[Jf]
1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
1@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@L0_[Vh1011JN401@2d/;40[Jf]0:f][@3KRPd0[Jf]
00X0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd02@3CQ`h20:f][@80@FWQ1P2TWXl00`2][Jd0@FWQ0;6[W@060;6[W@80[Jf]0`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[05
0:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0
102][Jd0_[Vh0:f][@2][Jd80;ji^080@FWQ00<0[Jf]0;B`/@11JN400P2d/;400`11JN40[Jf]0:f]
[@0:0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00P0dhL>00<0[Jf]0:BNS`2TWXl00P11JN460:BNS`03045Yh@2aZid0@FWQ00P0/J^M
0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]1`2n^KP00`11JN40_[Vh0;ji^002045Yh@060:f]
[@2d/;40];2a045Yh@2d/;40@FWQ0P2d/;420:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je0
0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@80@FWQ00<0Y9j?
045Yh@11JN401@2TWXl2045Yh@80/J^M00@0@FWQ0;6[W@2aZid0@FWQ1P2aZid30:f][@l0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]
Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@11JN40`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0050;ji^080@FWQ0`2n^KP2045Yh@030:f]
[@2d/;40];2a00D0];2a00<0@FWQ0;B`/@2][Jd01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00
/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P<0[Jf]0P11JN400`2TWXl0
@FWQ045Yh@050:BNS`80@FWQ0P2aZid01011JN40/J^M045Yh@11JN470;6[W@030:f][@2i/ZH0[Jf]
00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`03P36`;`3045Yh@P0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`11JN420;ji
^080@FWQ0P2n^KP00`2][Jd0];2a0;B`/@030;B`/@80@FWQ0P2d/;420:f][@D0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0
102][Jd0RXEe08Z5M@2][Jd2045Yh@030:BNS`11JN40Y9j?00D0Y9j?0P11JN430;6[W@80@FWQ202a
Zid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03@36`;`3045Yh@030:f][@33_K/0`kfk0080`kfk102]
[Jd70<>m^`030:f][@2n^KP0@FWQ0080@FWQ0P2n^KP2045Yh@80_[Vh0P11JN420;ji^0030:f][@2d
/;40];2a00<0];2a00<0@FWQ0;B`/@2d/;400P2][Jd00`11JN40[Jf]0:f][@030;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>
00D0[Jf]045Yh@2:QGD0RXEe0:f][@02045Yh@030:BNS`11JN40Y9j?00D0Y9j?0P11JN430;6[W@80
@FWQ1@2aZid01011JN40/J^M0;6[W@2][Jd80;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn
]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l00h0a/2l0P11JN400`2][Jd0`kfk0:f][@020:f][@/0`kfk0`11JN440;ji
^080@FWQ0P2n^KP2045Yh@80_[Vh00<0[Jf]0;B`/@2d/;400`2d/;400`11JN40];2a045Yh@020;B`
/@04045Yh@2OVj00Wi^P0:f][@80^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G
0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd02@2:QGD0@FWQ08Z5M@2:QGD0[Jf]045Y
h@2TWXl0[Jf]045Yh@060:BNS`80@FWQ0`2aZid2045Yh@D0/J^M00D0@FWQ0;6[W@2aZid0[Jf]045Y
h@0:0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38
`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00>0<K0_080@FWQ0P2]
[Jd<0<>m^`05045Yh@33_K/0[Jf]0;ji^011JN40102n^KP2045Yh@80_[Vh00D0@FWQ0;ji^02n^KP0
_[Vh0:f][@040;B`/@80@FWQ00D0[Jf]045Yh@2d/;40];2a045Yh@0309nKX0<0[Jf]1028EPL00`2]
[Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd308Z5M@05
045Yh@2:QGD0RXEe0:f][@11JN400P2TWXl00`11JN40[Jf]0:BNS`040:BNS`80@FWQ0`2aZid2045Y
h@D0/J^M00D0@FWQ0;6[W@2aZid0[Jf]045Yh@0>0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`09
0<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0<0[Jf]0P11JN400`2][Jd0`kfk0<>m^`09
0<>m^`80@FWQ0P33_K/00`2][Jd0_[Vh045Yh@040;ji^080@FWQ0P2n^KP01@11JN40_[Vh0;ji^02n
^KP0[Jf]00<0];2a00D0[Jf]045Yh@2d/;40];2a045Yh@020;B`/@03045Yh@2OVj00Wi^P00<0Wi^P
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2G
H0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD00P2:QGD01@11JN40RXEe08Z5M@2][Jd0@FWQ0080Y9j?
0P11JN420:f][@<0Y9j?0P11JN430;6[W@80@FWQ102aZid2045Yh@80/J^M00<0[Jf]045Yh@2i/ZH0
3P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@<0a/2l
0P11JN400`2][Jd0`kfk0<>m^`070<>m^`<0@FWQ0`33_K/00`2][Jd0_[Vh045Yh@040;ji^080@FWQ
0P2n^KP01@11JN40_[Vh0;ji^02n^KP0[Jf]0080];2a00<0[Jf]0;B`/@11JN400P2d/;42045Yh@03
0;B`/@11JN40@FWQ00D0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP04
0:f][@2GH0/0Uf0;09MP2`80[Jf]102:QGD01@11JN40RXEe08Z5M@2][Jd0@FWQ0080Y9j?0P11JN42
0:BNS`050:f][@2TWXl0Y9j?0:f][@11JN400`2aZid2045Yh@@0/J^M0P11JN420;6[W@80@FWQ3`2i
/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33
_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]1`36
`;`2045Yh@030:f][@33_K/0`kfk00T0`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0@FWQ0;ji
^0030;ji^080@FWQ0P2n^KP2045Yh@80_[Vh00<0[Jf]045Yh@2][Jd00P2d/;400`11JN40];2a0;B`
/@02045Yh@030;B`/@11JN40@FWQ00D0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo
001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]102:QGD01@11JN40RXEe08Z5M@2][Jd0@FWQ0080
Y9j?0P11JN430:BNS`80[Jf]00<000000;6[W@11JN400P2aZid00`11JN40/J^M0;6[W@030;6[W@80
@FWQ0P2aZid2045Yh@L0^K:V1011JN440;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[003
0:f][@31^[00`KZ`00H0`KZ`1011JN470<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04@37`K`00`2][Jd0a/2l0:f][@030:f][@/0a/2l0P11JN400`2][Jd0`kfk045Yh@03045Yh@H0
`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0@FWQ0;ji^0030;ji^080@FWQ0P2n^KP2045Yh@03
0;ji^02][Jd0[Jf]0080@FWQ0P2d/;401P11JN40];2a045Yh@2d/;40@FWQ0;B`/@80@FWQ1P2OVj00
102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]102:QGD0
1P11JN40RXEe08Z5M@2][Jd0@FWQ0:BNS`<0@FWQ00<0Y9j?045Yh@2TWXl00P2TWXl20:f][@040;6[
W@11JN40/J^M045Yh@D0/J^M0P11JN420;6[W@<0@FWQ1@2i/ZH2045Yh@<0^K:V00D0@FWQ0;VbYP11
JN40@FWQ0:f][@0=0;jg[0@0[Jf]00<0_[N/0:f][@31^[002@31^[04045Yh@D0`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]3`36`;`2045Yh@040:f][@11JN40`kfk
0<>m^`80@FWQ1P33_K/00`11JN40`kfk0<>m^`020<>m^`030:f][@11JN40_[Vh00@0_[Vh00<0@FWQ
0;ji^02n^KP00P11JN400`2][Jd0_[Vh0:f][@02045Yh@80];2a00<0@FWQ0;B`/@11JN400`2d/;42
045Yh@H0Wi^P0P2][Jd00`28EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]
06=PD`80[Jf]102:QGD01@11JN40RXEe0:f][@2TWXl0@FWQ0080Y9j?0P11JN400`2TWXl0@FWQ045Y
h@020:BNS`040:f][@2aZid0[Jf]0:f][@80@FWQ1@2aZid2045Yh@80/J^M0`11JN450;VbYP80@FWQ
102i/ZH3045Yh@030:f][@2n]j`0_[N/0080@FWQ3@2n]j`40:f][@P0`KZ`0P11JN470<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`0
2`36`;`2045Yh@050<K0_011JN40@FWQ0:f][@11JN400P33_K/00`11JN40`kfk045Yh@050<>m^`03
045Yh@33_K/0`kfk0080`kfk00<0[Jf]045Yh@2n^KP0102n^KP01@11JN40_[Vh0:f][@2][Jd0@FWQ
0080_[Vh00<0[Jf]0;B`/@11JN400`2d/;400`11JN40];2a0;B`/@020;B`/@80@FWQ1P2OVj00102]
[Jd0L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<00`2][Jd0RXEe08Z5M@0208Z5
M@05045Yh@2:QGD0[Jf]0:BNS`11JN400`2TWXl01011JN40Y9j?045Yh@11JN420:BNS`80@FWQ0P2a
Zid2045Yh@040:f][@2aZid0/J^M0;6[W@<0@FWQ0P2aZid00`11JN40^K:V045Yh@050;VbYP80@FWQ
102i/ZH3045Yh@030:f][@2n]j`0_[N/0080_[N/0`11JN4;0;jg[0030:f][@31^[00`KZ`00D0[Jf]
0`31^[02045Yh@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]
1`37`K`00`2][Jd0a/2l0<K0_0060<K0_005045Yh@36`;`0a/2l0<K0_011JN400`36`;`3045Yh@@0
`kfk0P11JN450<>m^`03045Yh@33_K/0`kfk0080`kfk00<0[Jf]045Yh@2n^KP00`2n^KP00`2][Jd0
@FWQ0:f][@020;ji^005045Yh@2n^KP0_[Vh0:f][@11JN402@2d/;42045Yh@D0Wi^P0P2][Jd00`1`
KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<20:f][@<0RXEe00@0@FWQ08Z5M@2]
[Jd0@FWQ1@2TWXl2045Yh@<0Y9j?0P11JN430;6[W@05045Yh@2aZid0[Jf]0:f][@2aZid00P11JN40
1P2aZid0@FWQ045Yh@11JN40^K:V045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH2045Yh@030:f]
[@2n]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`02`2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0<0[Jf]
0P11JN470<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f]
[@36`;`0a/2l00@0a/2l0P11JN401@36`;`0@FWQ045Yh@36`;`0@FWQ00<0a/2l0P11JN400`2][Jd0
`kfk0<>m^`020<>m^`80@FWQ1@33_K/00`11JN40`kfk0<>m^`020<>m^`040:f][@11JN40_[Vh0;ji
^080[Jf]00<0_[Vh045Yh@2n^KP00P2n^KP01@11JN40_[Vh0;ji^02][Jd0@FWQ00T0];2a0P11JN44
09nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C
0080Hf1C00@0[Jf]08Z5M@2][Jd0RXEe0P11JN400`2:QGD0[Jf]045Yh@0:0:BNS`030:f][@11JN40
/J^M0080/J^M00D0@FWQ0;6[W@2aZid0/J^M0:f][@02045Yh@060;6[W@11JN40@FWQ045Yh@2i/ZH0
@FWQ1@2i/ZH00`11JN40^K:V0;VbYP040;VbYP80@FWQ1@2n]j`00`11JN40_[N/0;jg[00;0;jg[003
0:f][@31^[00`KZ`00P0`KZ`0P11JN450:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40
al6l00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0020<K0_0<0@FWQ0`36`;`2045Yh@03
0:f][@33_K/0`kfk00<0`kfk0P11JN440<>m^`03045Yh@33_K/0`kfk0080`kfk00@0[Jf]045Yh@2]
[Jd0[Jf]0`2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2n^KP0@FWQ00X0];2a0P11JN4309nK
X0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C
0080Hf1C00D0[Jf]08Z5M@2:QGD0[Jf]08Z5M@04045Yh@X0Y9j?00<0[Jf]045Yh@2aZid00P2aZid0
0`11JN40/J^M0;6[W@020;6[W@80@FWQ00H0[Jf]045Yh@11JN40@FWQ0;VbYP11JN440;VbYP80@FWQ
1P2i/ZH2045Yh@D0_[N/00<0@FWQ0;jg[02n]j`02`2n]j`00`11JN40`KZ`0<6j/0080<6j/080@FWQ
1@31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00/0al6l0`11JN430<O1_0030:f]
[@36`;`0a/2l00<0a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@@0a/2l0P11JN450<>m^`80@FWQ
1033_K/01011JN40`kfk0<>m^`33_K/20:f][@03045Yh@2n^KP0_[Vh00<0_[Vh00<0@FWQ0;ji^02n
^KP00`2n^KP00`11JN40[Jf]0;B`/@090;B`/@80@FWQ00<0Wi^P0:f][@2][Jd00`2OVj000`2][Jd0
L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe
08Z5M@2:QGD0[Jf]0080RXEe0P11JN4:0:BNS`050:f][@11JN40/J^M0;6[W@11JN401@2aZid2045Y
h@060;6[W@11JN40@FWQ045Yh@2][Jd0@FWQ102i/ZH00`11JN40^K:V0;VbYP050;VbYP80@FWQ1@2n
]j`00`11JN40_[N/0;jg[0090;jg[080@FWQ00<0[Jf]045Yh@11JN401031^[001011JN40`KZ`0<6j
/031^[02045Yh@L0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0
al6l0<O1_0080<O1_0@0@FWQ1@37`K`00`2][Jd0a/2l0<K0_0020<K0_080@FWQ1@36`;`2045Yh@@0
a/2l0P11JN450<>m^`80@FWQ1033_K/01`11JN40[Jf]0:f][@2][Jd0`kfk0:f][@11JN401@2n^KP0
0`11JN40_[Vh0;ji^0040;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]045Yh@2][Jd01@2OVj00
0`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2]
[Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00@0[Jf]0;6[W@11JN40@FWQ1@2aZid2
045Yh@80/J^M0`11JN40102i/ZH0@FWQ0:f][@2][Jd20;VbYP03045Yh@2i/ZH0^K:V00D0^K:V0P11
JN450;jg[003045Yh@2n]j`0_[N/00P0_[N/0P11JN401P2n]j`0[Jf]0<6j/031^[00@FWQ0<6j/080
@FWQ00@0`KZ`045Yh@31^[00`KZ`0P11JN470<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00<0al6l0P11JN450<O1
_080@FWQ1@37`K`00`2][Jd0a/2l0<K0_0020<K0_080@FWQ1@36`;`2045Yh@@0a/2l0P11JN450<>m
^`80@FWQ0P33_K/20:f][@03045Yh@33_K/0`kfk0080`kfk00<0[Jf]045Yh@2n^KP0102n^KP00`11
JN40_[Vh0;ji^0040;ji^0030:f][@2d/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii
0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0
RXEe0P2][Jd;0:BNS`030:f][@2aZid0/J^M00H0/J^M0P11JN420;6[W@80@FWQ00<0[Jf]0;VbYP11
JN400P2i/ZH20:f][@03045Yh@2i/ZH0^K:V00D0^K:V0P11JN450;jg[003045Yh@2n]j`0_[N/00P0
_[N/0P11JN400`2n]j`0[Jf]0<6j/0020<6j/0<0@FWQ1031^[02045Yh@80`KZ`0P11JN430<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0@FWQ045Yh@11JN420<O1
_080@FWQ1@37`K`2045Yh@D0al6l00<0[Jf]0<K0_036`;`00P36`;`2045Yh@D0a/2l0P11JN440<K0
_080@FWQ1@33_K/2045Yh@80[Jf]0P33_K/00`11JN40`kfk0<>m^`020<>m^`030:f][@11JN40_[Vh
00@0_[Vh00<0@FWQ0;ji^02n^KP0102n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P
00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C
0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M
00D0/J^M0`11JN420;6[W@80@FWQ00@0[Jf]0;VbYP2i/ZH0@FWQ0`2i/ZH00`11JN40[Jf]0:f][@02
0:f][@030;VbYP11JN40@FWQ0080@FWQ1@2n]j`00`11JN40_[N/0;jg[0080;jg[080@FWQ00<0[Jf]
0<6j/031^[000P31^[02045Yh@D0`KZ`1011JN420<6j/004045Yh@31^[00`KZ`0:f][AD0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`04045Yh@37`K`0al6l0<O1_0@0@FWQ
1@37`K`2045Yh@D0al6l00<0[Jf]0<K0_036`;`00P36`;`2045Yh@D0a/2l0P11JN440<K0_080@FWQ
1033_K/00`2][Jd0@FWQ0:f][@040<>m^`80@FWQ0`33_K/00`2][Jd0@FWQ0;ji^0020;ji^080@FWQ
1`2n^KP00`2][Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0
/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]2@2TWXl00`2][Jd0
/J^M0;6[W@070;6[W@80@FWQ00@0/J^M045Yh@11JN40[Jf]0P2i/ZH01@11JN40^K:V0;VbYP2i/ZH0
@FWQ00@0^K:V0`2][Jd0102i/ZH0@FWQ045Yh@11JN420;jg[080@FWQ2P2n]j`2045Yh@030:f][@31
^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[000`31^[02045Yh@D0`KZ`00<0@FWQ0<6j/02][Jd01033
_K<6045Yh@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00H0b<6k00<0@FWQ0<S1^`38`K/02@38
`K/00`11JN40[Jf]0<O1_0030<O1_0<0@FWQ1@37`K`2045Yh@D0al6l00<0[Jf]0<K0_036`;`00P36
`;`2045Yh@D0a/2l0P11JN440<K0_080@FWQ00H0`kfk0:f][@2][Jd0[Jf]0<>m^`11JN450<>m^`80
@FWQ0`33_K/00`11JN40_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d
/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=P
D`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@0:
0;6[W@80@FWQ00@0[Jf]0;VbYP2i/ZH0@FWQ0`2i/ZH00`11JN40^K:V0;VbYP050;VbYP<0[Jf]0`2n
]j`2045Yh@X0_[N/0P11JN400`2][Jd0`KZ`0<6j/0030<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11
JN450<6j/080@FWQ00<0[Jf]0<>m/`33_K<01033_K<2045Yh@D0`kfc1P11JN420<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`11JN450<S1^`03045Y
h@38`K/0b<6k00P0b<6k00<0@FWQ0<S1^`2][Jd01@37`K`2045Yh@D0al6l0P11JN450<O1_0030:f]
[@36`;`0a/2l00<0a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@<0a/2l00@0[Jf]045Yh@2][Jd0
[Jf]1033_K/00`11JN40`kfk0<>m^`030<>m^`H0@FWQ3@2n^KP00`2][Jd0];2a0;B`/@030;B`/@80
[Jf]0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BN
S`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@040:f][@11JN40@FWQ045Yh@<0^K:V00<0@FWQ
0;VbYP2i/ZH01P2i/ZH00`2][Jd0_[N/0:f][@020:f][@80@FWQ2`2n]j`00`11JN40[Jf]0<6j/004
0<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[001@31^[02045Yh@H0`kfc0P11JN47
0<>m/`80@FWQ1033_K<7045YhA00aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@@0b<6k0P11JN43
0<S1^`040:f][@38`K/0b<6k045Yh@D0b<6k00<0@FWQ0<S1^`38`K/01`38`K/2045Yh@030<S1^`2]
[Jd0al6l00@0al6l0P11JN450<O1_080@FWQ1@37`K`00`2][Jd0a/2l0<K0_0040<K0_0L0@FWQ0`2]
[Jd00`36`;`0@FWQ0:f][@050<>m^`03045Yh@33_K/0`kfk00<0`kfk0P11JN430<>m^`030:f][@2n
^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@03
0:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH00P11JN420;VbYP03045Yh@2i/ZH0^K:V00H0^K:V00<0[Jf]0;jg[02n]j`00P2n]j`2045Yh@<0
[Jf]202n]j`00`11JN40[Jf]0<6j/0040<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031
^[001@31^[02045Yh@H0`kfc0P11JN470<>m/`80@FWQ1033_K<0102][Jd0aKje045Yh@11JN490<Fn
]@@0@FWQ1P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`070<S1^`80@FWQ0P38`K/00`11JN40b<6k0<S1^`02045Y
h@@0b<6k00@0[Jf]0<S1^`38`K/0@FWQ1@38`K/2045Yh@P0b<6k0P11JN400`38`K/0[Jf]0<O1_004
0<O1_080@FWQ1@37`K`2045Yh@D0al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@80@FWQ1036`;`2
045Yh@@0`kfk00<0@FWQ0<>m^`33_K/01033_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0
102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]
@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2]
[Jd20:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH00`11JN40^K:V0;Vb
YP060;VbYP030:f][@2n]j`0_[N/0080_[N/0`11JN420;jg[0@0[Jf]1@2n]j`2045Yh@@0`KZ`00<0
@FWQ0<6j/031^[000`31^[000`11JN40`KZ`0<6j/0050<6j/080@FWQ1P33_K<2045Yh@L0`kfc0P11
JN440<>m/`040:f][@35_[D0@FWQ045Yh@L0aKje0`11JN430<Fn]@80@FWQ1035_[D00`2][Jd0a[ng
045Yh@020<Jo]`@0@FWQ2036_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@37`KP0al6h01@0al6h
0P11JN400`37`KX0@FWQ045Yh@03045Yh@L0al6j1`11JN420<O1^P030:f][@38`K/0b<6k00D0b<6k
0P11JN450<S1^`03045Yh@38`K/0@FWQ00D0b<6k00<0[Jf]0<S1^`11JN400P11JN440<S1^`80@FWQ
2038`K/01011JN40b<6k0<S1^`2][Jd50<O1_080@FWQ1@37`K`2045Yh@D0al6l00<0[Jf]0<K0_036
`;`01@2][Jd40<K0_080@FWQ1036`;`2045Yh@@0`kfk00<0@FWQ0<>m^`33_K/01033_K/2045Yh@<0
`kfk00<0[Jf]0;ji^02n^KP0102n^KP00`11JN40_[Vh0;ji^0040;ji^0030000002][Jd0[Jf]00P0
];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f]
[@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH0
1@2i/ZH00`11JN40^K:V0;VbYP060;VbYP030:f][@2n]j`0_[N/0080_[N/0`11JN460;jg[0@0[Jf]
00<0_[N/0:f][@31^[000P11JN400`31^[00@FWQ045Yh@050<6j/003045Yh@31^[00`KZ`00H0`KZ`
0P11JN450<>m/`80@FWQ1`33_K<2045Yh@@0`kfc00@0[Jf]0<Fn]@11JN40@FWQ1P35_[D2045Yh@H0
aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0a[ng045Yh@02045Yh@@0a[ng0P11JN460<Jo]`03
045Yh@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP04P37`KP5045Yh@@0al6j0`11JN480<O1^P03
045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/01038`K/2045Yh@H0b<6k0`11JN450<S1^`03
0:f][@38`K/0@FWQ0080@FWQ0`38`K/3045Yh@P0b<6k00@0@FWQ0<S1^`38`K/0[Jf]1@37`K`2045Y
h@H0al6l00@0@FWQ0<O1_037`K`0al6l1@2][Jd90<K0_003045Yh@36`;`0a/2l00<0a/2l00@0@FWQ
0:f][@11JN40`kfk0P11JN470<>m^`80@FWQ0`33_K/00`2][Jd0_[Vh0;ji^0030;ji^080@FWQ1@2n
^KP20:f][@030000002d/;40];2a00L0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f]
[@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid0
0`2][Jd0^K:V0;VbYP050;VbYP80@FWQ1`2i/ZH00`2][Jd0_[N/0;jg[0020;jg[0<0@FWQ0`2n]j`0
0`11JN40_[N/0;jg[0040;jg[0D0[Jf]0`11JN450<6j/003045Yh@31^[00`KZ`00H0`KZ`0P11JN45
0<>m/`80@FWQ1`33_K<2045Yh@@0`kfc00@0[Jf]0<Fn]@11JN40@FWQ1P35_[D00`11JN40aKje0<Fn
]@060<Fn]@06045Yh@35_[D0aKje0<Fn]@2][Jd0a[ng0P11JN470<Jo]`03045Yh@36_kL0a[ng00<0
a[ng0P11JN450<Jo]`030:f][@37`KP0al6h01@0al6h0P11JN460<O1^P80@FWQ2037`KX00`11JN40
al6j0<O1^P030<O1^P030:f][@38`K/0b<6k00@0b<6k0P11JN470<S1^`80@FWQ1@38`K/00`2][Jd0
b<6k045Yh@02045Yh@<0b<6k0`11JN480<S1^`04045Yh@38`K/0b<6k0:f][@D0al6l1011JN430<O1
_0030:f][@11JN40[Jf]0080[Jf]0P37`K`00`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l
00<0a/2l00<0@FWQ0<K0_036`;`00`36`;`01011JN40[Jf]0<>m^`11JN490<>m^`80@FWQ0`33_K/0
0`2][Jd0_[Vh0;ji^0040;ji^004045Yh@2n^KP0_[Vh0;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d
/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH2
045Yh@L0^K:V00<0[Jf]0;jg[02n]j`00P2n]j`2045Yh@040;jg[011JN40_[N/0;jg[080@FWQ102n
]j`2045Yh@050:f][@31^[00`KZ`0<6j/02][Jd00P11JN440:f][@030<6j/011JN40`KZ`00L0`KZ`
00<0@FWQ0<>m/`33_K<01033_K<2045Yh@L0`kfc0P11JN440<>m/`040:f][@35_[D0@FWQ045Yh@H0
aKje00<0@FWQ0<Fn]@35_[D01P35_[D01`11JN40aKje0<Fn]@35_[D0[Jf]0<Jo]`11JN402036_kL0
0`11JN40a[ng0<Jo]`030<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP05037`KP2
045Yh@L0al6j0P11JN470<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/01038`K/2
045Yh@L0b<6k0P11JN450<S1^`030:f][@38`K/0@FWQ0080@FWQ0`38`K/01011JN40b<6k0<S1^`11
JN460<S1^`80@FWQ0P38`K/0102][Jd0al6l0<O1_037`K`3045Yh@030<O1_02][Jd0[Jf]00<0[Jf]
00<0al6l045Yh@11JN401037`K`00`11JN40a/2l0<K0_0030<K0_080@FWQ1036`;`01011JN40a/2l
0<K0_036`;`3045Yh@030:f][@33_K/0`kfk00T0`kfk0P11JN430<>m^`030:f][@2n^KP0_[Vh00H0
_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80
/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00H0^K:V00<0@FWQ0;VbYP2i/ZH0
1@2i/ZH00`11JN40_[N/0;jg[004045Yh@040;jg[011JN40_[N/0;jg[080@FWQ102n]j`2045Yh@03
0:f][@31^[00`KZ`0080`KZ`0P11JN440<6j/0030:f][@11JN40[Jf]00@0[Jf]0`31^[000`11JN40
`kfc0<>m/`040<>m/`80@FWQ1`33_K<00`11JN40`kfc0<>m/`030<>m/`040:f][@35_[D0@FWQ045Y
h@D0aKje00<0@FWQ0<Fn]@35_[D02`35_[D00`2][Jd0a[ng045Yh@080<Jo]`03045Yh@36_kL0a[ng
00X0a[ng00<0[Jf]0<O1^037`KP05037`KP2045Yh@L0al6j0P11JN470<O1^P03045Yh@37`KX0al6j
00<0al6j00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11JN450<S1^`030:f][@38`K/0@FWQ
0080b<6k00@0@FWQ0<S1^`38`K/0@FWQ0P38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ0P38`K/0
0`2][Jd0al6l0<O1_0050:f][@H0al6l0P11JN430<O1_080@FWQ1P36`;`00`11JN40a/2l0<K0_002
045Yh@L0a/2l00<0[Jf]0<>m^`33_K/02@33_K/2045Yh@<0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP3
0:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0
/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@030:f][@2i/ZH0^K:V00H0^K:V00<0@FWQ0;Vb
YP2i/ZH01@2i/ZH00`11JN40_[N/0;jg[0060;jg[0<0@FWQ1@2n]j`2045Yh@030:f][@31^[00`KZ`
0080`KZ`00<0@FWQ0<6j/031^[001031^[000`11JN40`KZ`0<6j/0030<6j/0<0[Jf]00@0@FWQ0:f]
[@2][Jd0[Jf]0`33_K<2045Yh@L0`kfc00<0@FWQ0<>m/`33_K<00`33_K<0102][Jd0aKje045Yh@11
JN450<Fn]@03045Yh@35_[D0aKje00/0aKje00<0[Jf]0<Jo]`36_kL02036_kL00`11JN40a[ng0<Jo
]`0:0<Jo]`030:f][@37`KP0al6h01@0al6h0P11JN470<O1^P80@FWQ1`37`KX00`11JN40al6j0<O1
^P030<O1^P030:f][@38`K/0b<6k00@0b<6k0P11JN470<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Y
h@020<S1^`04045Yh@38`K/0b<6k045Yh@80b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@D0[Jf]
2`37`K`2045Yh@<0al6l0P11JN470<K0_080@FWQ2P36`;`00`2][Jd0`kfk0<>m^`080<>m^`80@FWQ
0`33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0
Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD0
0`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]
0;VbYP070;VbYP03045Yh@2i/ZH0^K:V00@0^K:V0P11JN4A0;jg[003045Yh@2][Jd0`KZ`00<0`KZ`
00<0@FWQ0<6j/031^[001031^[02045Yh@H0`KZ`0P11JN430<>m/`<0[Jf]0P11JN420:f][@D0`kfc
00<0@FWQ0<>m/`33_K<00`33_K<0102][Jd0aKje045Yh@11JN450<Fn]@03045Yh@35_[D0aKje00/0
aKje00<0[Jf]0<Jo]`36_kL01`36_kL2045Yh@`0a[ng00<0[Jf]0<O1^037`KP05037`KP2045Yh@P0
al6j0P11JN460<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/01038`K/00`11JN40
b<6k045Yh@060<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@020<S1^`04045Yh@38`K/0b<6k045Y
h@80b<6k00<0@FWQ0:f][@2][Jd0102][Jd2045Yh@80b<6k00<0[Jf]0<O1_037`K`02`37`K`00`11
JN40al6l045Yh@030<O1_003045Yh@36`;`0a/2l0140a/2l00<0[Jf]0<>m^`33_K/02033_K/2045Y
h@<0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00
Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@P0^K:V00<0@FWQ0;Vb
YP2i/ZH00`2i/ZH2045YhA80_[N/0P11JN430<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN460<6j
/080@FWQ1P33_K<2045Yh@80`kfc1@2][Jd00`11JN40[Jf]0:f][@030<>m/`040:f][@35_[D0@FWQ
045Yh@D0aKje00<0@FWQ0<Fn]@35_[D02`35_[D00`2][Jd0a[ng0<Jo]`050<Jo]`<0@FWQ3@36_kL0
0`2][Jd0al6h0<O1^00D0<O1^080@FWQ2037`KX2045Yh@H0al6j00<0@FWQ0<O1^P37`KX00`37`KX0
0`2][Jd0b<6k0<S1^`050<S1^`80@FWQ1P38`K/2045Yh@D0b<6k00H0[Jf]045Yh@11JN40b<6k0:f]
[@11JN420:f][@05045Yh@2][Jd0[Jf]0:f][@11JN401@38`K/2045Yh@80b<6k00<0[Jf]0<O1_037
`K`02`37`K`00`11JN40al6l0<O1_004045YhA<0a/2l00<0[Jf]0<>m^`33_K/01`33_K/3045Yh@80
`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40
oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M
00<0[Jf]0;VbYP2][Jd00`2][Jd40;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN400`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00@FWQ0080@FWQ1`31^[000`11JN40`KZ`045Yh@040<6j/080@FWQ
00<0[Jf]0<>m/`33_K<01033_K<2045Yh@L0`kfc00<0@FWQ0<>m/`33_K<01@2][Jd2045Yh@80[Jf]
0`35_[D00`11JN40aKje0<Fn]@0;0<Fn]@030:f][@36_kL0a[ng00<0a[ng1011JN470<Jo]`03045Y
h@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP05037`KP2045Yh@T0al6j0P11JN450<O1^P03045Y
h@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/01`38`K/8045Yh@H0[Jf]0P11JN401P2][Jd0b<6k
0<S1^`11JN40b<6k045Yh@<0b<6k00<0@FWQ0<S1^`38`K/00`38`K/2045Yh@80b<6k00<0[Jf]0<O1
_037`K`02P37`K`2045Yh@D0al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`090<>m
^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]
04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@03
0:f][@2i/ZH0^K:V00<0^K:V0`2][Jd20;VbYP04045Yh@2i/ZH0^K:V0;VbYP80@FWQ00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0070<6j/0<0@FWQ00<0`KZ`045Yh@31^[000P31^[02045Y
h@030<6j/02][Jd0`kfc00D0`kfc0P11JN470<>m/`03045Yh@33_K<0`kfc00<0`kfc00@0[Jf]0<Fn
]@11JN40@FWQ0P35_[D30:f][@03045Yh@2][Jd0[Jf]00H0[Jf]00<0@FWQ0<Fn]@35_[D00P35_[D0
10000000a[ng0<Jo]`36_kL4045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`2][Jd0al6h0<O1
^00D0<O1^080@FWQ2@37`KX2045Yh@D0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k0<S1
^`030<S1^`X0[Jf]0P11JN450<S1^`030:f][@11JN40@FWQ00<0b<6k0P11JN440<S1^`03045Yh@38
`K/0b<6k00<0b<6k0P11JN420<S1^`030:f][@37`K`0al6l00P0al6l0P11JN480<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]0`11JN400`2i/ZH0@FWQ0:f][@0B
0;jg[0030:f][@31^[00`KZ`00`0`KZ`1011JN420<6j/0030:f][@33_K<0`kfc00@0`kfc0P11JN47
0<>m/`03045Yh@33_K<0`kfc00<0`kfc00@0[Jf]0<Fn]@11JN40@FWQ1@35_[D2045Yh@H0aKje0P11
JN470:f][@<0@FWQ1P2][Jd50<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP05037
`KP2045Yh@T0al6j0P11JN450:f][@03045Yh@2][Jd0[Jf]00T0[Jf]2P38`K/2045Yh@D0b<6k00<0
[Jf]045Yh@38`K/00`38`K/2045Yh@@0b<6k00<0@FWQ0<S1^`38`K/00`38`K/2045Yh@80b<6k00<0
[Jf]0<O1_037`K`01037`K`00`11JN40al6l0<O1_00;0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`
/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`11JN40[Jf]0;jg[00A
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01033_K<4045Yh@@0`kfc0P11JN45
0<>m/`040:f][@35_[D0@FWQ045Yh@D0aKje0P11JN460<Fn]@03045Yh@35_[D0@FWQ00<0aKje00@0
[Jf]0<Jo]`11JN40@FWQ1`36_kL00`11JN40[Jf]0:f][@030:f][@03045Yh@2][Jd0[Jf]01/0[Jf]
0P11JN490:f][@80@FWQ1@37`KX2045Yh@@0al6j00<0[Jf]0<S1^`38`K/01@38`K/2045Yh@H0b<6k
00<0@FWQ0<S1^`38`K/01038`K/2045Yh@@0b<6k0P11JN450<S1^`03045Yh@38`K/0b<6k0080b<6k
0P11JN420<S1^`030:f][@37`K`0al6l00@0al6l00<0@FWQ0<O1_037`K`02`37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f]
[@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[
W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<01033_K<2045Yh@80`kfc0P11JN420<>m/`80@FWQ1@33_K<0102][Jd0aKje045Y
h@11JN460<Fn]@80@FWQ1P35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`11JN402036_kL00`11JN40a[ng
0<Jo]`030<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP05037`KP2045Yh@T0al6j
0P11JN450<O1^P80@FWQ1037`KX00`2][Jd0@FWQ0<S1^`050<S1^`80@FWQ1P38`K/00`11JN40b<6k
0<S1^`040<S1^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`06045Yh@<0b<6k0P11JN400`38`K/0[Jf]
0<O1_0040<O1_080@FWQ3@37`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh
0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`
h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00@0`kfc0P11
JN440<>m/`80@FWQ1`33_K<0102][Jd0aKje045Yh@11JN470<Fn]@80@FWQ1@35_[D00`11JN40aKje
0<Fn]@020<Fn]@030:f][@36_kL0@FWQ00L0a[ng0P11JN450<Jo]`03045Yh@36_kL0a[ng00@0a[ng
00<0[Jf]0<O1^037`KP05037`KP2045Yh@T0al6j0P11JN450<O1^P03045Yh@37`KX0@FWQ00<0al6j
00<0@FWQ0<S1^`11JN401P38`K/00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00D0b<6k
1011JN430<S1^`03045Yh@38`K/0b<6k00T0b<6k0P11JN400`38`K/0[Jf]0<O1_0040<O1_080@FWQ
3@37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f]
[@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2]
[Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00@0`kfc0P11
JN4=0<>m/`@0@FWQ2035_[D00`11JN40aKje0<Fn]@020<Fn]@03045Yh@35_[D0aKje00<0aKje00@0
[Jf]0<Jo]`36_kL0@FWQ1P36_kL2045Yh@D0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`2][Jd0al6h
0<O1^00D0<O1^080@FWQ2@37`KX2045Yh@D0al6j00@0@FWQ0<O1^P37`KX0@FWQ0P37`KX00`2][Jd0
@FWQ045Yh@070<S1^`D0@FWQ1P38`K/3045YhA80b<6k0P11JN400`38`K/0[Jf]0<O1_0040<O1_080
@FWQ3@37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`03
0:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80
[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`040<>m/`80
@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0:0<Fn]@@0@FWQ1P35_[D0102][Jd0a[ng0<Jo]`11JN450<Jo
]`<0@FWQ1036_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP05037`KP2045Yh@T0al6j0P11JN450<O1
^P04045Yh@37`KX0al6j0<O1^P@0@FWQ5@38`K/00`2][Jd0b<6k0<S1^`0A0<S1^`03045Yh@38`K/0
[Jf]00D0al6l0P11JN4=0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H3
0:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/
0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@040:f][@36_kL0a[ng0<Jo]`D0@FWQ0P36_kL00`11JN40a[ng0<Jo]`020<Jo]`<0@FWQ1@36
_kL00`2][Jd0al6h0<O1^00D0<O1^080@FWQ2@37`KX2045Yh@80al6j1011JN450<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04@38`K/2045Yh@030:f][@37`K`0al6l0080al6l00<0
@FWQ0<O1_011JN402`37`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ3@33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00d0a[ng0`11JN450<Jo]`030:f][@37`KP0
al6h01@0al6h0P11JN480<O1^P80@FWQ3037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k0180b<6k0P11JN440<O1_003045Yh@37`K`0@FWQ00H0al6l1@2][Jd20<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H1
0?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ3@33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00d0a[ng0`11JN450<Jo]`030:f][@37`KP0
al6h01@0al6h0P11JN480<O1^P80@FWQ3037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k0180b<6k1P11JN430<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j
/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ3@33_K<00`2][Jd0aKje045Yh@0D0<Fn
]@030:f][@36_kL0a[ng00d0a[ng0`11JN450<Jo]`030:f][@37`KP0al6h01@0al6h0P11JN470<O1
^P80@FWQ3@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][Jd00`33_K<0
@FWQ045Yh@02045Yh@d0`kfc00<0[Jf]045Yh@11JN405035_[D00`2][Jd0a[ng0<Jo]`0=0<Jo]`<0
@FWQ1@36_kL00`2][Jd0al6h0<O1^00D0<O1^080@FWQ1`37`KX2045Yh@d0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V
0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<0102][Jd0@FWQ0<Fn]@11JN4C0<Fn
]@030:f][@36_kL0a[ng00d0a[ng0`11JN450<Jo]`030:f][@37`KP0al6h01@0al6h0P11JN470<O1
^P80@FWQ3@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0
`kfc202][Jd30<>m/`030:f][@35_[D0@FWQ01@0aKje00<0[Jf]0<Jo]`36_kL03@36_kL3045Yh@D0
a[ng00<0[Jf]0<O1^037`KP05037`KP2045Yh@H0al6j0P11JN4>0<O1^P030:f][@38`K/0b<6k01@0
b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100
`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng00d0a[ng0P11JN460<Jo]`030:f][@37`KP0al6h01@0
al6h0P11JN460<O1^P80@FWQ3P37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0
/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd20<Fn]@040000
0035_[D0aKje0:f][A00a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`2][Jd0al6h0<O1^00B0<O1^0X0
@FWQ4037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0
[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng
00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00`33_K/30:f][F`0/>3V
0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36
_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102][Jd@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0
[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][Gh0/>3V
0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`h>H10?ooo`00WP2`h>H6
0:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]QP2`h>H1
0?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0080<O1
_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0
al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0[Jf]V@2`h>H10?ooo`00
^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][JfW0;3PiP40oooo
00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`h>H10?ooo`00d@2`h>H<
0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50064 .33069 m
.49063 .33045 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49693 .33271 m
.4973 .33062 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5265 .33861 m
.52816 .34086 L
s
.52484 .34087 m
.5265 .33861 L
s
.50167 .33843 m
.50829 .33853 L
s
.50829 .33853 m
.5116 .34082 L
s
.52484 .34087 m
.5265 .34312 L
s
.49836 .34061 m
.50167 .33843 L
s
.5265 .34312 m
.52816 .34086 L
s
.5116 .34082 m
.51325 .34309 L
s
.49506 .33829 m
.4967 .34283 L
s
.49503 .34731 m
.49506 .33829 L
s
.51324 .34985 m
.51325 .34309 L
s
.4967 .34283 m
.49836 .34061 L
s
.49503 .34731 m
.4967 .34283 L
s
.51158 .34984 m
.51324 .3476 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51158 .3521 m
.51324 .34985 L
s
.48021 .34009 m
.48348 .34472 L
s
.47529 .33764 m
.48021 .34009 L
s
.50826 .35206 m
.51158 .34984 L
s
.47201 .33749 m
.47529 .33764 L
s
.46871 .3396 m
.47201 .33749 L
s
.46708 .33952 m
.47201 .33749 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50826 .35432 m
.51158 .3521 L
s
.49997 .35645 m
.50826 .35206 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48531 .38811 m
.48537 .38847 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49996 .35872 m
.50826 .35432 L
s
.46541 .34396 m
.46871 .3396 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52651 .35441 m
.52818 .38162 L
s
.52486 .38163 m
.52651 .35441 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58156 .3371 m
.59785 .33613 L
s
.46377 .34388 m
.46708 .33952 L
s
.49665 .35865 m
.49997 .35645 L
s
.51156 .36568 m
.51323 .36116 L
s
.51322 .37023 m
.51323 .36116 L
s
.49664 .36091 m
.49996 .35872 L
s
.49499 .36088 m
.49665 .35865 L
s
.44429 .33591 m
.45566 .33665 L
s
.46372 .35066 m
.46541 .34396 L
s
.46208 .35058 m
.46377 .34388 L
s
.49498 .36314 m
.49664 .36091 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49497 .36541 m
.49499 .36088 L
s
.5099 .36793 m
.51156 .36568 L
s
.51156 .36568 m
.51322 .37023 L
s
.48177 .35823 m
.48341 .36055 L
s
.48011 .36044 m
.48177 .35823 L
s
.52651 .36799 m
.52652 .38162 L
s
.50657 .37016 m
.5099 .36793 L
s
.59785 .33613 m
.60111 .33817 L
s
.59785 .33613 m
.60273 .33806 L
s
.4834 .36282 m
.48341 .36055 L
s
.49497 .36541 m
.49662 .36772 L
s
.46369 .35519 m
.46372 .35066 L
s
.48011 .36044 m
.48175 .36276 L
s
.49662 .36772 m
.49993 .37005 L
s
.49993 .37005 m
.50657 .37016 L
s
.48007 .36724 m
.4834 .36282 L
s
.46205 .35511 m
.46208 .35058 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60111 .33817 m
.6044 .34247 L
s
.46369 .35519 m
.46528 .36208 L
s
.46205 .35511 m
.46364 .362 L
s
.42658 .33452 m
.43782 .33544 L
s
.47676 .36939 m
.48007 .36724 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45049 .36809 m
.45078 .33634 L
s
.44886 .36799 m
.44915 .33624 L
s
.46528 .36208 m
.46853 .36678 L
s
.47181 .36919 m
.47676 .36939 L
s
.52486 .38163 m
.52652 .38618 L
s
.52652 .38618 m
.52818 .38162 L
s
.46364 .362 m
.46689 .3667 L
s
.43272 .36003 m
.43299 .33506 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58809 .33674 m
.58848 .38443 L
s
.58646 .33683 m
.58683 .38452 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6044 .34247 m
.60606 .34688 L
s
.60273 .33806 m
.60601 .34235 L
s
.60601 .34235 m
.60767 .34676 L
s
.46853 .36678 m
.47181 .36919 L
s
.4311 .3599 m
.43139 .33493 L
s
.46689 .3667 m
.47181 .36919 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6156 .33479 m
.62678 .33379 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60606 .34688 m
.60775 .35357 L
s
.60767 .34676 m
.60936 .35345 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60775 .35357 m
.60786 .36495 L
s
.4091 .33285 m
.42019 .33394 L
s
.60936 .35345 m
.60948 .36483 L
s
.44398 .36768 m
.45049 .36809 L
s
.41479 .38139 m
.41542 .33349 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4132 .38125 m
.41384 .33333 L
s
.43105 .36446 m
.43272 .36003 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42944 .36433 m
.4311 .3599 L
s
.44876 .37939 m
.45037 .38178 L
s
.44711 .38158 m
.44876 .37939 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58191 .38477 m
.59829 .38386 L
s
.62222 .3524 m
.6239 .35909 L
s
.60794 .37179 m
.60948 .36483 L
s
.60631 .3719 m
.60786 .36495 L
s
.622 .33424 m
.62239 .36608 L
s
.6204 .33438 m
.62078 .36622 L
s
.44872 .38396 m
.45037 .38178 L
s
.60474 .37658 m
.60631 .3719 L
s
.4262 .36635 m
.43105 .36446 L
s
.60636 .37647 m
.60794 .37179 L
s
.44711 .38158 m
.44872 .38396 L
s
.4262 .36635 m
.42944 .36433 L
s
.60153 .38137 m
.60474 .37658 L
s
.59829 .38386 m
.60153 .38137 L
s
.59829 .38386 m
.60316 .38126 L
s
.60316 .38126 m
.60636 .37647 L
s
.61596 .36661 m
.62239 .36608 L
s
.6239 .35909 m
.62716 .36337 L
s
.42299 .36608 m
.4262 .36635 L
s
.41822 .36337 m
.42299 .36608 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41509 .35851 m
.41822 .36337 L
s
.3753 .31271 m
.38598 .31419 L
s
.62716 .36337 m
.63038 .36536 L
s
.64737 .33846 m
.64886 .33373 L
s
.39035 .3307 m
.39496 .33354 L
s
.39496 .33354 m
.39801 .33846 L
s
.39801 .33846 m
.39947 .34547 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64737 .33846 m
.64744 .34302 L
s
.64893 .33828 m
.65041 .33354 L
s
.65041 .33354 m
.65348 .33089 L
s
.64886 .33373 m
.65348 .33089 L
s
.63349 .36049 m
.63505 .35805 L
s
.63505 .35805 m
.63666 .36018 L
s
.63349 .36049 m
.63511 .36262 L
s
.39035 .3307 m
.39341 .33336 L
s
.39341 .33336 m
.39645 .33828 L
s
.65348 .33089 m
.65812 .33031 L
s
.64893 .33828 m
.649 .34284 L
s
.39645 .33828 m
.39791 .3453 L
s
.63038 .36536 m
.63514 .36491 L
s
.38055 .36155 m
.38139 .31357 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38726 .33031 m
.39035 .3307 L
s
.64744 .34302 m
.64907 .3474 L
s
.3994 .35004 m
.39947 .34547 L
s
.37902 .36135 m
.37986 .31336 L
s
.63666 .36018 m
.6367 .36246 L
s
.649 .34284 m
.65063 .34722 L
s
.39784 .34986 m
.39791 .3453 L
s
.63514 .36491 m
.6367 .36246 L
s
.39773 .35672 m
.3994 .35004 L
s
.65812 .33031 m
.66124 .33219 L
s
.38414 .33219 m
.38726 .33031 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64907 .3474 m
.65378 .34914 L
s
0 0 0 r
.36216 .31901 m
.36436 .31934 L
s
.255 .412 .882 r
.39617 .35654 m
.39784 .34986 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65063 .34722 m
.65378 .34914 L
s
.66124 .33219 m
.66439 .33635 L
s
.38099 .33635 m
.38414 .33219 L
s
.39453 .36095 m
.39773 .35672 L
s
.40843 .38079 m
.41479 .38139 L
s
.64921 .35655 m
.64925 .35883 L
s
.64921 .35655 m
.65077 .35637 L
s
.39297 .36077 m
.39617 .35654 L
s
.65077 .35637 m
.65081 .35866 L
s
.64925 .35883 m
.65085 .36095 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66584 .33157 m
.66885 .32887 L
s
.66439 .33635 m
.66584 .33157 L
s
.66736 .33136 m
.66885 .32887 L
s
.66592 .33614 m
.66736 .33136 L
s
.66885 .32887 m
.67037 .32866 L
s
.38982 .36269 m
.39453 .36095 L
s
.38982 .36269 m
.39297 .36077 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66592 .33614 m
.6662 .35217 L
s
.65085 .36095 m
.654 .36288 L
s
.66439 .33635 m
.66475 .35696 L
s
.65378 .34914 m
.66309 .35027 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.654 .36288 m
.6602 .36213 L
s
.37047 .328 m
.37198 .32822 L
s
.38672 .36232 m
.38982 .36269 L
s
.66309 .35027 m
.66467 .35237 L
s
.36741 .32983 m
.37047 .328 L
s
.36892 .33006 m
.37047 .328 L
s
.38367 .35964 m
.38672 .36232 L
s
.36732 .33441 m
.36892 .33006 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6602 .36213 m
.66325 .35945 L
s
.38067 .35466 m
.38367 .35964 L
s
.66475 .35696 m
.6662 .35217 L
s
.36582 .33418 m
.36741 .32983 L
s
.66325 .35945 m
.66475 .35696 L
s
.36702 .35047 m
.36732 .33441 L
s
.37443 .36074 m
.38055 .36155 L
s
.36292 .32914 m
.36582 .33418 L
s
.36542 .35486 m
.36582 .33418 L
s
.35998 .32638 m
.36292 .32914 L
s
.67854 .35968 m
.68391 .32662 L
s
.35553 .32565 m
.35998 .32638 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68005 .35946 m
.68405 .33349 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35254 .32745 m
.35553 .32565 L
s
.35107 .3272 m
.35553 .32565 L
s
.36542 .35486 m
.36702 .35047 L
s
.674 .36032 m
.68455 .3588 L
s
.36405 .34773 m
.36551 .35025 L
s
.35516 .34403 m
.36405 .34773 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68391 .32662 m
.69051 .35787 L
s
.36387 .35694 m
.36542 .35486 L
s
.35097 .3318 m
.35254 .32745 L
s
.34951 .33155 m
.35107 .3272 L
s
.69051 .35787 m
.69572 .32466 L
s
.36083 .35879 m
.36387 .35694 L
s
.35088 .3364 m
.35097 .3318 L
s
.35225 .34125 m
.35516 .34403 L
s
.35078 .341 m
.35516 .34403 L
s
.69199 .35764 m
.69587 .33155 L
s
.34941 .33615 m
.34951 .33155 L
s
.35088 .3364 m
.35225 .34125 L
s
.35487 .35787 m
.36083 .35879 L
s
.34941 .33615 m
.35078 .341 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35058 .35023 m
.35206 .35047 L
s
.35201 .35278 m
.35206 .35047 L
s
.35196 .35509 m
.35487 .35787 L
s
.35054 .35254 m
.35058 .35023 L
s
.35054 .35254 m
.35196 .35509 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69572 .32466 m
.70226 .35593 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69788 .35667 m
.7066 .35516 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32117 .31912 m
.33096 .32116 L
s
.71458 .32808 m
.71729 .3229 L
s
.71328 .33299 m
.71458 .32808 L
s
.3375 .34795 m
.33888 .35053 L
s
.33883 .35284 m
.33888 .35053 L
s
.71202 .3402 m
.71328 .33299 L
s
.33601 .35 m
.3375 .34795 L
s
.71729 .3229 m
.72143 .31972 L
s
.33734 .3549 m
.33883 .35284 L
s
.32596 .35275 m
.32674 .3203 L
s
.71599 .3278 m
.71869 .32261 L
s
.71469 .33271 m
.71599 .3278 L
s
.71344 .33993 m
.71469 .33271 L
s
.71202 .3402 m
.71229 .35179 L
s
.71869 .32261 m
.72143 .31972 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33601 .35 m
.33739 .35258 L
s
.32455 .35247 m
.32534 .32001 L
s
.71344 .33993 m
.71371 .35152 L
s
.33304 .35411 m
.33734 .3549 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72143 .31972 m
.72421 .31912 L
s
.71229 .35179 m
.71387 .3585 L
s
.72421 .31912 m
.72839 .32053 L
s
.33025 .35125 m
.33304 .35411 L
s
.71371 .35152 m
.7153 .35823 L
s
.32629 .33881 m
.32753 .34605 L
s
.32753 .34605 m
.33025 .35125 L
s
.71387 .3585 m
.71541 .36288 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7153 .35823 m
.71682 .36262 L
s
.71541 .36288 m
.71835 .36701 L
s
.32037 .35163 m
.32596 .35275 L
s
.71682 .36262 m
.71976 .36674 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73107 .3176 m
.73155 .33618 L
s
.72839 .32053 m
.73125 .32456 L
s
.73243 .31729 m
.73291 .33588 L
s
.31247 .33588 m
.31295 .31729 L
s
.31111 .33557 m
.3116 .31698 L
s
.72743 .33708 m
.73697 .33496 L
s
.71835 .36701 m
.72263 .36853 L
s
.30707 .33464 m
.31657 .33678 L
s
.71976 .36674 m
.72263 .36853 L
s
.30884 .31867 m
.31142 .32394 L
s
.3049 .31538 m
.30884 .31867 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72263 .36853 m
.72542 .36798 L
s
.74048 .31538 m
.74967 .31306 L
s
.30225 .31473 m
.3049 .31538 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72542 .36798 m
.72952 .36479 L
s
.29956 .31639 m
.30225 .31473 L
s
.29825 .31606 m
.30225 .31473 L
s
.74445 .3144 m
.74534 .34711 L
s
.73333 .35221 m
.73369 .36627 L
s
.73215 .35953 m
.73333 .35221 L
s
.31169 .36626 m
.31205 .35221 L
s
.31051 .35894 m
.31205 .35221 L
s
.72952 .36479 m
.73215 .35953 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74576 .31407 m
.74666 .34679 L
s
.73215 .35953 m
.73369 .36627 L
s
.29682 .32039 m
.29956 .31639 L
s
.29552 .32006 m
.29825 .31606 L
s
.30767 .36303 m
.31051 .35894 L
s
.31051 .35894 m
.31169 .36626 L
s
0 0 0 r
.76474 .30121 m
.76537 .30103 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29539 .32473 m
.29682 .32039 L
s
.74136 .34805 m
.74666 .34679 L
s
.74627 .33273 m
.74778 .33943 L
s
.29409 .32439 m
.29552 .32006 L
s
.30358 .36448 m
.30767 .36303 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29389 .33142 m
.29539 .32473 L
s
.2926 .33108 m
.29409 .32439 L
s
.74778 .33943 m
.75052 .34348 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30091 .36387 m
.30358 .36448 L
s
.29356 .34315 m
.29389 .33142 L
s
.29227 .34282 m
.2926 .33108 L
s
.29833 .3609 m
.30091 .36387 L
s
.29702 .36058 m
.30091 .36387 L
s
.75052 .34348 m
.75318 .34517 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29356 .34315 m
.29466 .35053 L
s
.29584 .35556 m
.29833 .3609 L
s
.29466 .35053 m
.29584 .35556 L
s
.29227 .34282 m
.29336 .3502 L
s
.29453 .35524 m
.29702 .36058 L
s
.75318 .34517 m
.75702 .34418 L
s
.29336 .3502 m
.29453 .35524 L
s
.75561 .33981 m
.75696 .34182 L
s
.75561 .33981 m
.75682 .33712 L
s
.75682 .33712 m
.75816 .33913 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75816 .33913 m
.75823 .34149 L
s
.75702 .34418 m
.75823 .34149 L
s
.27932 .30847 m
.2833 .34282 L
s
.27344 .34002 m
.27932 .30847 L
s
0 0 0 r
.76572 .33409 m
.76715 .32866 L
s
.255 .412 .882 r
.27956 .34179 m
.28708 .34384 L
s
.76627 .31551 m
.76736 .31045 L
s
.27466 .34038 m
.27911 .31551 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76627 .31551 m
.76641 .32021 L
s
.76736 .31045 m
.77092 .30699 L
s
.76858 .31008 m
.77092 .30699 L
s
.7675 .31515 m
.76858 .31008 L
s
.7675 .31515 m
.76764 .31985 L
s
.76641 .32021 m
.76778 .32456 L
s
.76764 .31985 m
.769 .3242 L
s
.77092 .30699 m
.77451 .30585 L
s
.76778 .32456 m
.7715 .32583 L
s
.769 .3242 m
.7715 .32583 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76807 .334 m
.76814 .33636 L
s
.76807 .334 m
.76929 .33364 L
s
.77451 .30585 m
.77695 .30744 L
s
.76814 .33636 m
.76943 .33837 L
s
.76929 .33364 m
.76936 .336 L
s
.26969 .30547 m
.27344 .34002 L
s
.26395 .33709 m
.26969 .30547 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76943 .33837 m
.77194 .34002 L
s
.7715 .32583 m
.77872 .32597 L
s
.77695 .30744 m
.77944 .3114 L
s
.26512 .33746 m
.26946 .31254 L
s
.77194 .34002 m
.77673 .33857 L
s
.78045 .30629 m
.78268 .30314 L
s
.77944 .3114 m
.78045 .30629 L
s
.77944 .3114 m
.78011 .33271 L
s
.78555 .28542 m
.79328 .28251 L
s
.78161 .3059 m
.78268 .30314 L
s
.7806 .31101 m
.78161 .3059 L
s
.7806 .31101 m
.78113 .32759 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78268 .30314 m
.78382 .30275 L
s
.77872 .32597 m
.77996 .32797 L
s
.77673 .33857 m
.77902 .33546 L
s
.26049 .33596 m
.26865 .33857 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7889 .28419 m
.79054 .33405 L
s
.77902 .33546 m
.78011 .33271 L
s
.25817 .30154 m
.25929 .30195 L
s
.78011 .33271 m
.78113 .32759 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79 .28377 m
.79166 .33366 L
s
.25586 .30311 m
.25817 .30154 L
s
.25697 .30351 m
.25817 .30154 L
s
0 0 0 r
.24935 .29073 m
.25109 .29139 L
s
.255 .412 .882 r
.2557 .30785 m
.25697 .30351 L
s
.25459 .30745 m
.25586 .30311 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25515 .3245 m
.2557 .30785 L
s
.79079 .30745 m
.79282 .30189 L
s
.25256 .30188 m
.25459 .30745 L
s
.25388 .32888 m
.25459 .30745 L
s
.79282 .30189 m
.79491 .29868 L
s
.25047 .29868 m
.25256 .30188 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78717 .3352 m
.79166 .33366 L
s
.79491 .29868 m
.79706 .29785 L
s
.24726 .29743 m
.25047 .29868 L
s
.25388 .32888 m
.25515 .3245 L
s
.25302 .32132 m
.25404 .32411 L
s
.79142 .32649 m
.79378 .33048 L
s
.2527 .33087 m
.25388 .32888 L
s
.79706 .29785 m
.79925 .29939 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24661 .31651 m
.25302 .32132 L
s
0 0 0 r
.79892 .32017 m
.79896 .31966 L
s
.255 .412 .882 r
.24508 .29896 m
.24726 .29743 L
s
.24404 .29854 m
.24726 .29743 L
s
.25043 .33248 m
.2527 .33087 L
s
0 0 0 r
.79949 .32729 m
.80016 .3177 L
s
.7992 .3284 m
.79949 .32729 L
s
.255 .412 .882 r
.79378 .33048 m
.79604 .33208 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79925 .29939 m
.80151 .30331 L
s
.79706 .29785 m
.8003 .29897 L
s
.8003 .29897 m
.80255 .30289 L
s
.24387 .30331 m
.24508 .29896 L
s
.24612 .33088 m
.25043 .33248 L
s
.24284 .30289 m
.24404 .29854 L
s
.79604 .33208 m
.79819 .33128 L
s
.24459 .31329 m
.24661 .31651 L
s
.24354 .31287 m
.24661 .31651 L
s
.80151 .30331 m
.80279 .31006 L
s
.24371 .30809 m
.24387 .30331 L
s
.24371 .30809 m
.24459 .31329 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80255 .30289 m
.80382 .30964 L
s
.24267 .30767 m
.24284 .30289 L
s
.79819 .33128 m
.80023 .32808 L
s
.79819 .33128 m
.80129 .32767 L
s
.24267 .30767 m
.24354 .31287 L
s
.24409 .32767 m
.24612 .33088 L
s
.80279 .31006 m
.80296 .31485 L
s
.80023 .32808 m
.80217 .32246 L
s
.24321 .32246 m
.24426 .32287 L
s
.24418 .32527 m
.24426 .32287 L
s
.80217 .32246 m
.80296 .31485 L
s
.24313 .32486 m
.24409 .32767 L
s
.24313 .32486 m
.24321 .32246 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80129 .32767 m
.80321 .32205 L
s
.80382 .30964 m
.80399 .31443 L
s
.80321 .32205 m
.80399 .31443 L
s
.80936 .29268 m
.81607 .28955 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81228 .29135 m
.81409 .34203 L
s
.81324 .2909 m
.81506 .34161 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23411 .31868 m
.235 .32151 L
s
.23492 .32393 m
.235 .32151 L
s
.22383 .28679 m
.23025 .29 L
s
.23385 .32592 m
.23492 .32393 L
s
.23304 .32066 m
.23411 .31868 L
s
.23304 .32066 m
.23393 .3235 L
s
.23093 .32464 m
.23385 .32592 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22622 .32247 m
.22746 .28864 L
s
.81419 .31739 m
.81627 .32136 L
s
.81115 .34328 m
.81506 .34161 L
s
.2253 .32203 m
.22654 .28818 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22911 .32135 m
.23093 .32464 L
s
.81627 .32136 m
.81916 .32247 L
s
.22741 .31564 m
.22911 .32135 L
s
.22675 .30794 m
.22741 .31564 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81975 .28772 m
.82591 .28446 L
s
.5 Mabswid
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82244 .28633 m
.82342 .31297 L
s
.82332 .28586 m
.82431 .31252 L
s
.81916 .32247 m
.821 .32159 L
s
.22258 .32071 m
.22622 .32247 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.821 .32159 m
.82271 .31828 L
s
.821 .32159 m
.82361 .31783 L
s
.82271 .31828 m
.82342 .31297 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82875 .30315 m
.82886 .30608 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82361 .31783 m
.82431 .31252 L
s
.21835 .29125 m
.21902 .29657 L
s
.21902 .29657 m
.2196 .30431 L
s
.21686 .28545 m
.21835 .29125 L
s
.21915 .31648 m
.2196 .30431 L
s
.21751 .29078 m
.21817 .2961 L
s
.21817 .2961 m
.21875 .30385 L
s
.21603 .28498 m
.21751 .29078 L
s
.21449 .28159 m
.21686 .28545 L
s
.21829 .31603 m
.21875 .30385 L
s
.82926 .28255 m
.83482 .27916 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21449 .28159 m
.21603 .28498 L
s
.21801 .32335 m
.21915 .31648 L
s
.21716 .3229 m
.21829 .31603 L
s
.20683 .27669 m
.21449 .28159 L
s
.21697 .32779 m
.21801 .32335 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83169 .28111 m
.833 .31527 L
s
.83249 .28062 m
.8338 .31481 L
s
.21613 .32734 m
.21716 .3229 L
s
.2151 .3318 m
.21697 .32779 L
s
.21427 .33135 m
.21613 .32734 L
s
.83055 .31665 m
.8338 .31481 L
s
.21253 .33291 m
.2151 .3318 L
s
.2078 .33018 m
.2098 .27867 L
s
.21253 .33291 m
.21427 .33135 L
s
.20704 .32972 m
.20904 .27818 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83275 .33045 m
.83347 .32754 L
s
.83275 .33045 m
.83366 .33246 L
s
.2048 .32833 m
.21253 .33291 L
s
.83347 .32754 m
.83436 .32954 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83366 .33246 m
.83436 .32954 L
s
.83885 .28403 m
.84009 .27814 L
s
.8384 .29187 m
.83885 .28403 L
s
.8384 .29187 m
.83859 .29677 L
s
.83957 .28354 m
.8408 .27764 L
s
.83913 .29138 m
.83957 .28354 L
s
.84009 .27814 m
.84209 .27419 L
s
.83859 .29677 m
.83961 .30366 L
s
.83913 .29138 m
.83932 .29629 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8408 .27764 m
.84209 .27419 L
s
.83932 .29629 m
.84034 .30318 L
s
.83961 .30366 m
.84125 .30763 L
s
.84209 .27419 m
.84344 .27318 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84034 .30318 m
.84196 .30714 L
s
.84344 .27318 m
.8455 .27411 L
s
.84125 .30763 m
.84345 .30865 L
s
.84196 .30714 m
.84345 .30865 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8455 .27411 m
.84697 .27801 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84345 .30865 m
.84548 .30719 L
s
.84548 .30719 m
.84669 .30374 L
s
.84639 .29631 m
.84693 .29334 L
s
.84639 .29631 m
.84713 .29829 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84959 .29028 m
.84968 .29257 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84693 .29334 m
.84767 .29532 L
s
.84669 .30374 m
.84777 .29779 L
s
.84767 .29532 m
.84777 .29779 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85084 .26699 m
.8516 .27142 L
s
.85084 .26699 m
.85124 .27689 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85124 .27689 m
.8516 .27142 L
s
.8516 .27142 m
.85205 .26842 L
s
.85205 .26842 m
.85302 .26488 L
s
.85302 .26488 m
.85506 .26276 L
s
.85185 .29179 m
.85231 .2888 L
s
.85185 .29179 m
.85205 .29677 L
s
.85195 .29428 m
.85241 .29129 L
s
.85231 .2888 m
.8533 .28528 L
s
.85205 .29677 m
.85271 .29876 L
s
.85241 .29129 m
.8534 .28777 L
s
.8533 .28528 m
.85568 .2777 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85271 .29876 m
.85392 .30025 L
s
.8534 .28777 m
.85578 .2802 L
s
.85506 .26276 m
.85613 .26418 L
s
.85392 .30025 m
.856 .29822 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85613 .26418 m
.8567 .26614 L
s
.85568 .2777 m
.85654 .27416 L
s
.85578 .2802 m
.85665 .27665 L
s
.8567 .26614 m
.85701 .27363 L
s
.85654 .27416 m
.85691 .27113 L
s
.85665 .27665 m
.85701 .27363 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.856 .29822 m
.85689 .29469 L
s
.85689 .29469 m
.85727 .29167 L
s
.85727 .29167 m
.85753 .28614 L
s
.85727 .29167 m
.85795 .29618 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85753 .28614 m
.85795 .29618 L
s
.85962 .25987 m
.85991 .25682 L
s
.85962 .25987 m
.86012 .26184 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85991 .25682 m
.8604 .25878 L
s
.86012 .26184 m
.8604 .25878 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86065 .27439 m
.8623 .30417 L
s
.86065 .27439 m
.86152 .3052 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86128 .28951 m
.86191 .30468 L
s
.86152 .3052 m
.86213 .30976 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86213 .30976 m
.8623 .30417 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18005 .25248 m
.18039 .2505 L
s
.18027 .24741 m
.18039 .2505 L
s
.17994 .24938 m
.18027 .24741 L
s
.17994 .24938 m
.18005 .25248 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17844 .29635 m
.17951 .26518 L
s
.17798 .29529 m
.17951 .26518 L
s
.1782 .29582 m
.17886 .28047 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17799 .30095 m
.17844 .29635 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17857 .24488 m
.17859 .24799 L
s
.17827 .25565 m
.17859 .24799 L
s
.17798 .29529 m
.17799 .30095 L
s
.17844 .2412 m
.17857 .24488 L
s
.17813 .25509 m
.17838 .2531 L
s
.17802 .25765 m
.17827 .25565 L
s
.17808 .23892 m
.17844 .2412 L
s
.17778 .25653 m
.17813 .25509 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17767 .2591 m
.17802 .25765 L
s
.17736 .27303 m
.17772 .26844 L
s
.17728 .27871 m
.17772 .26844 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17713 .25888 m
.17778 .25653 L
s
.17728 .27871 m
.17736 .27303 L
s
.17702 .26145 m
.17767 .2591 L
s
.17712 .27505 m
.17736 .27303 L
s
.17808 .23892 m
.17785 .24034 L
s
.17679 .27653 m
.17712 .27505 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17785 .24034 m
.1777 .24233 L
s
.17647 .27435 m
.17679 .27653 L
s
.17789 .23663 m
.1777 .24233 L
s
.17745 .2469 m
.1777 .24233 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17745 .2469 m
.17789 .23663 L
s
.17693 .26034 m
.17713 .25888 L
s
.17682 .26292 m
.17702 .26145 L
s
.17678 .26237 m
.17693 .26034 L
s
.17647 .27435 m
.17648 .27067 L
s
.17667 .26495 m
.17682 .26292 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17656 .26753 m
.17678 .26237 L
s
.17648 .27067 m
.17656 .26753 L
s
.17763 .24035 m
.17797 .23404 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17797 .23404 m
.17834 .22972 L
s
.17674 .26106 m
.17685 .25847 L
s
.17685 .25847 m
.17702 .25531 L
s
.17663 .26515 m
.17674 .26106 L
s
.17697 .25735 m
.17702 .25531 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17834 .22972 m
.17856 .22857 L
s
.17679 .26051 m
.17697 .25735 L
s
.17872 .23001 m
.17856 .22857 L
s
.17887 .22943 m
.17856 .22857 L
s
.17663 .26515 m
.17668 .26665 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17668 .26665 m
.177 .26499 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.177 .26499 m
.17738 .26127 L
s
.177 .26499 m
.17753 .26071 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17843 .24652 m
.17849 .2451 L
s
.17738 .26127 m
.17792 .25492 L
s
.17792 .25492 m
.17843 .24652 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86579 .2356 m
.86613 .24343 L
s
.86726 .26986 m
.86762 .27846 L
s
.86603 .23658 m
.86633 .24374 L
s
.86749 .27083 m
.86784 .279 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85671 .2095 m
.85691 .20975 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18027 .28019 m
.18366 .20026 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18231 .20203 m
.19069 .19263 L
s
.255 .412 .882 r
.18519 .24901 m
.18569 .24838 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85816 .24406 m
.85831 .2432 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18236 .24137 m
.18544 .238 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85726 .24563 m
.85816 .24406 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18974 .2155 m
.19008 .19321 L
s
.18974 .2155 m
.19069 .19263 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18074 .27965 m
.18413 .19967 L
s
.5 Mabswid
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17892 .2818 m
.18733 .27325 L
s
.1848 .25333 m
.18609 .22273 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85112 .19678 m
.85164 .19354 L
s
.8508 .18914 m
.85164 .19354 L
s
.85027 .19238 m
.8508 .18914 L
s
.85027 .19238 m
.85112 .19678 L
s
.18672 .27378 m
.1883 .25005 L
s
.18733 .27325 m
.1883 .25005 L
s
.19726 .19066 m
.19966 .18511 L
s
.19623 .19889 m
.19726 .19066 L
s
.19449 .24128 m
.19623 .19889 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85191 .21594 m
.85312 .26177 L
s
.85191 .21594 m
.85449 .26283 L
s
.198 .19009 m
.19966 .18511 L
s
.19695 .19832 m
.198 .19009 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19522 .24074 m
.19695 .19832 L
s
.19966 .18511 m
.20122 .18396 L
s
.85286 .23905 m
.85381 .2623 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20122 .18396 m
.20348 .1861 L
s
.84433 .18781 m
.84527 .19222 L
s
.84527 .19222 m
.84573 .20376 L
s
.19238 .24291 m
.19522 .24074 L
s
.84257 .18283 m
.84433 .18781 L
s
.84495 .2032 m
.84558 .19991 L
s
.83923 .18056 m
.84257 .18283 L
s
.8451 .20706 m
.84573 .20376 L
s
.85413 .27008 m
.85449 .26283 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8435 .20595 m
.84495 .2032 L
s
.20348 .1861 m
.20485 .19269 L
s
.84366 .20981 m
.8451 .20706 L
s
.20531 .18112 m
.20878 .17887 L
s
.85312 .26177 m
.85413 .27008 L
s
.84604 .23028 m
.84651 .22307 L
s
.84651 .22307 m
.84714 .23859 L
s
.8396 .21095 m
.8435 .20595 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83765 .18329 m
.83923 .18056 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83975 .21483 m
.84366 .20981 L
s
.8454 .23362 m
.84604 .23028 L
s
.84604 .23028 m
.84714 .23859 L
s
.83691 .1866 m
.83765 .18329 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20315 .23538 m
.20531 .18112 L
s
.204 .23484 m
.20616 .18056 L
s
.83571 .17831 m
.83691 .1866 L
s
.84392 .23644 m
.8454 .23362 L
s
.20065 .23698 m
.204 .23484 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83798 .21375 m
.8396 .21095 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83632 .19379 m
.83691 .1866 L
s
.83571 .17831 m
.83632 .19379 L
s
.84052 .23432 m
.84392 .23644 L
s
.83814 .21765 m
.83975 .21483 L
s
.82712 .17333 m
.83105 .17553 L
s
.83723 .21711 m
.83798 .21375 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21294 .18771 m
.21516 .17885 L
s
.21154 .19991 m
.21294 .18771 L
s
.83739 .22101 m
.83814 .21765 L
s
.21516 .17885 m
.21828 .17332 L
s
.8386 .22935 m
.84052 .23432 L
s
.21389 .18716 m
.21614 .1783 L
s
.21248 .19937 m
.21389 .18716 L
s
.83723 .21711 m
.83754 .22491 L
s
.21124 .2077 m
.21154 .19991 L
s
.21614 .1783 m
.21828 .17332 L
s
.21218 .20716 m
.21248 .19937 L
s
.83754 .22491 m
.8386 .22935 L
s
.21124 .2077 m
.21173 .21888 L
s
.21828 .17332 m
.22031 .17223 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82712 .17333 m
.82921 .22805 L
s
.82812 .17388 m
.83021 .22856 L
s
.21218 .20716 m
.21269 .21835 L
s
.22031 .17223 m
.2233 .1745 L
s
.82523 .17612 m
.82756 .18499 L
s
.82194 .17061 m
.82523 .17612 L
s
.21173 .21888 m
.21335 .22567 L
s
.21269 .21835 m
.21434 .22515 L
s
.81979 .16953 m
.82194 .17061 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2233 .1745 m
.22516 .18124 L
s
.21335 .22567 m
.21619 .22804 L
s
.81775 .17236 m
.81979 .16953 L
s
.81663 .17183 m
.81979 .16953 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21434 .22515 m
.21619 .22804 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82612 .22651 m
.83021 .22856 L
s
.81692 .17966 m
.81775 .17236 L
s
.21619 .22804 m
.21927 .2265 L
s
.8158 .17913 m
.81663 .17183 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81692 .17966 m
.81852 .22297 L
s
.22198 .20973 m
.2232 .20528 L
s
.22198 .20973 m
.22291 .21315 L
s
.2232 .20528 m
.22414 .2087 L
s
.23231 .16634 m
.24065 .16269 L
s
.8158 .17913 m
.81739 .22247 L
s
.21927 .2265 m
.22154 .22154 L
s
.22399 .21264 m
.22414 .2087 L
s
.22154 .22154 m
.22399 .21264 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81393 .22098 m
.81852 .22297 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79847 .16015 m
.80718 .16373 L
s
.24565 .16065 m
.25482 .15716 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23282 .2479 m
.23582 .16476 L
s
.23402 .24742 m
.23701 .16424 L
s
.24761 .21471 m
.24952 .15914 L
s
.24892 .21424 m
.25083 .15865 L
s
.78371 .15474 m
.79325 .15815 L
s
.22928 .24933 m
.23402 .24742 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80227 .16167 m
.80422 .21708 L
s
.80351 .16218 m
.80547 .21756 L
s
.78922 .15667 m
.79069 .20038 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80039 .21565 m
.80547 .21756 L
s
.78786 .15619 m
.78932 .19991 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24372 .21613 m
.24892 .21424 L
s
.80492 .23706 m
.80632 .24154 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80379 .2406 m
.80492 .23706 L
s
.8052 .24508 m
.80632 .24154 L
s
.2627 .16616 m
.2658 .15727 L
s
.2609 .17856 m
.2627 .16616 L
s
.2658 .15727 m
.27027 .1519 L
s
.80379 .2406 m
.8052 .24508 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26412 .16569 m
.26724 .1568 L
s
.26231 .1781 m
.26412 .16569 L
s
.26724 .1568 m
.27027 .1519 L
s
.26064 .18654 m
.2609 .17856 L
s
.78959 .20792 m
.79069 .20038 L
s
.27027 .1519 m
.27321 .15097 L
s
.26205 .18607 m
.26231 .1781 L
s
.78821 .20746 m
.78932 .19991 L
s
.77366 .15143 m
.77543 .20745 L
s
.26064 .18654 m
.26166 .19807 L
s
.24547 .23922 m
.24692 .23474 L
s
.24547 .23922 m
.24664 .24278 L
s
.24692 .23474 m
.2481 .2383 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7677 .1496 m
.77803 .15283 L
s
.77219 .15097 m
.77395 .20702 L
s
.27321 .15097 m
.27607 .15403 L
s
.26205 .18607 m
.26308 .19762 L
s
.78554 .21056 m
.78959 .20792 L
s
.24664 .24278 m
.2481 .2383 L
s
.78554 .21056 m
.78821 .20746 L
s
.27607 .15403 m
.27884 .16111 L
s
.26166 .19807 m
.26425 .20519 L
s
.27921 .14914 m
.28537 .14736 L
s
.26308 .19762 m
.2657 .20475 L
s
.78271 .20966 m
.78554 .21056 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27177 .18913 m
.2718 .18812 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77825 .20431 m
.78271 .20966 L
s
.26425 .20519 m
.26849 .20789 L
s
.255 .412 .882 r
.76942 .19344 m
.77021 .19508 L
s
0 0 0 r
.2657 .20475 m
.26849 .20789 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77505 .19538 m
.77825 .20431 L
s
.26849 .20789 m
.27145 .20702 L
s
.75882 .15892 m
.76074 .17138 L
s
.75542 .15005 m
.75882 .15892 L
s
.7505 .14477 m
.75542 .15005 L
s
.76943 .20573 m
.77543 .20745 L
s
.75724 .15849 m
.75917 .17095 L
s
.75383 .14962 m
.75724 .15849 L
s
.7505 .14477 m
.75383 .14962 L
s
.27145 .20702 m
.27457 .20212 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27662 .23368 m
.27921 .14914 L
s
.27816 .23327 m
.28074 .1487 L
s
.76074 .17138 m
.76098 .17942 L
s
.74724 .14393 m
.7505 .14477 L
s
.27457 .20212 m
.27786 .1932 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29652 .14435 m
.29804 .14793 L
s
.29479 .14877 m
.29652 .14435 L
s
.75917 .17095 m
.75941 .17899 L
s
.29479 .14877 m
.29629 .15236 L
s
.74407 .14711 m
.74724 .14393 L
s
.74241 .1467 m
.74724 .14393 L
s
.29629 .15236 m
.29804 .14793 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75819 .19067 m
.75941 .17899 L
s
.75977 .19108 m
.76098 .17942 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74096 .15433 m
.74407 .14711 L
s
.73928 .15393 m
.74241 .1467 L
s
.75684 .19834 m
.75977 .19108 L
s
.75523 .19794 m
.75819 .19067 L
s
.27206 .23492 m
.27816 .23327 L
s
.29572 .17247 m
.29598 .22075 L
s
.2927 .22153 m
.29572 .17247 L
s
.73961 .16603 m
.74096 .15433 L
s
.73792 .16563 m
.73928 .15393 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75212 .20119 m
.75684 .19834 L
s
.75212 .20119 m
.75523 .19794 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73961 .16603 m
.73983 .17411 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72158 .13789 m
.7216 .13861 L
s
.5 Mabswid
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71637 .13688 m
.72871 .1395 L
s
.73792 .16563 m
.73814 .17372 L
s
.29433 .22114 m
.29503 .19673 L
s
.74884 .20039 m
.75212 .20119 L
s
.73983 .17411 m
.74185 .18665 L
s
.73814 .17372 m
.74016 .18627 L
s
.74542 .19555 m
.74884 .20039 L
s
.74375 .19516 m
.74884 .20039 L
s
.74185 .18665 m
.74542 .19555 L
s
.74016 .18627 m
.74375 .19516 L
s
.2927 .22153 m
.2941 .22931 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2941 .22931 m
.29598 .22075 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7225 .17464 m
.72252 .17537 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69618 .13308 m
.70914 .13545 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72347 .13836 m
.72564 .22386 L
s
.72171 .13799 m
.72386 .22352 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68101 .13463 m
.68503 .14337 L
s
.6751 .12969 m
.68101 .13463 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68503 .14337 m
.68721 .1559 L
s
.67907 .13434 m
.68311 .14307 L
s
.6751 .12969 m
.67907 .13434 L
s
.67118 .12912 m
.6751 .12969 L
s
.68311 .14307 m
.68528 .1556 L
s
.6673 .13263 m
.67118 .12912 L
s
.66532 .13236 m
.67118 .12912 L
s
.71846 .22251 m
.72564 .22386 L
s
.68721 .1559 m
.68738 .16407 L
s
.68528 .1556 m
.68545 .16377 L
s
.66347 .14025 m
.6673 .13263 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6857 .17606 m
.68738 .16407 L
s
.66147 .13999 m
.66532 .13236 L
s
.68377 .17577 m
.68545 .16377 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70178 .13408 m
.70372 .21995 L
s
.70363 .13441 m
.70559 .22026 L
s
.61144 .094 m
.62611 .09532 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37169 .16914 m
.37219 .16704 L
s
.37261 .16964 m
.37266 .16698 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68199 .18371 m
.6857 .17606 L
s
.68004 .18343 m
.68377 .17577 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65968 .15201 m
.66147 .13999 L
s
.66169 .15226 m
.66347 .14025 L
s
.66169 .15226 m
.66183 .16047 L
s
.69806 .21905 m
.70559 .22026 L
s
.65968 .15201 m
.65982 .16021 L
s
.6762 .18699 m
.68199 .18371 L
s
.63273 .12445 m
.63899 .12918 L
s
.63899 .12918 m
.64323 .13781 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63273 .12445 m
.63693 .12896 L
s
.62857 .12404 m
.63273 .12445 L
s
.6762 .18699 m
.68004 .18343 L
s
.63693 .12896 m
.64117 .13758 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64323 .13781 m
.64547 .15033 L
s
.66183 .16047 m
.66405 .17306 L
s
.62445 .12773 m
.62857 .12404 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64117 .13758 m
.64341 .1501 L
s
.65982 .16021 m
.66205 .1728 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67225 .18646 m
.6762 .18699 L
s
.62035 .13555 m
.62445 .12773 L
s
.64547 .15033 m
.64559 .15855 L
s
.66405 .17306 m
.6682 .18181 L
s
.64341 .1501 m
.64354 .15833 L
s
.6682 .18181 m
.67225 .18646 L
s
.6662 .18155 m
.67225 .18646 L
s
.66205 .1728 m
.6662 .18155 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5947 .12132 m
.60752 .12222 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64166 .17047 m
.64354 .15833 L
s
.64373 .17069 m
.64559 .15855 L
s
.61775 .09454 m
.61879 .18077 L
s
.61985 .09473 m
.62091 .18094 L
s
.255 .412 .882 r
.56494 .13256 m
.56993 .13276 L
s
0 0 0 r
.63972 .17853 m
.64373 .17069 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63764 .17832 m
.64166 .17047 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56874 .11996 m
.58177 .12056 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63353 .18206 m
.63972 .17853 L
s
.63353 .18206 m
.63764 .17832 L
s
.5776 .14504 m
.59708 .14612 L
s
.62076 .16851 m
.62508 .17715 L
s
.62934 .18167 m
.63353 .18206 L
s
.62508 .17715 m
.62934 .18167 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61241 .18027 m
.62091 .18094 L
s
.255 .412 .882 r
.55934 .1632 m
.56079 .16708 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58886 .19542 m
.60112 .12175 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58897 .20797 m
.60326 .1219 L
s
.57309 .12014 m
.58897 .20797 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@1P00000G0?nS40030:f][@3lX100o:0@00D0[Jf]WP2`h>H10?ooo`00/@2`h>H50:f][@80ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA006`3oYA00102][Jd0oj<@0?nS403oXa05000001@0oj<@00<0[Jf]0?bP403l
X1001@3lX1050:f][IT0/>3V0@3oool00:`0/>3V1@2][Jd70?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@
00@0[Jf]0?nS403oXa00oj<@0P00000G0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40
oooo002V0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40040:f][@3oXa00oj<@0?nS4080
00005`3oXa000`2][Jd0o:0@0?bP400@0?bP40D0[Jf]SP2`h>H10?ooo`00X@2`h>H50:f][A80ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA006`3oYA00102][Jd0oj<@0?nS403oXa02000001L0oj<@00<0[Jf]0?bP403l
X1005@3lX1040:f][HX0/>3V0@3oool009d0/>3V102][JdG0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@
00@0[Jf]0?nS403oXa00oj<@0P00000G0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2]
[Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@008000005`3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?00<0mY`?102][Jf20;3PiP40oooo002E0;3PiP@0[Jf]1@3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P00000G0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][Gh0/>3V0@3oool00980/>3V0`2][Jd9
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS4002
000001L0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]NP2`h>H1
0?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@008000005`3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?
00l0mY`?102][Jef0;3PiP40oooo002:0;3PiP@0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P00000G0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][G<0/>3V0@3oool008L0/>3V0`2][JdD0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS4002000001L0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@008000005`3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V0@3o
ool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01@0ojHA;`2][Jd8000000D0ojD@10000005
0?nU40030:f][@3oXa00oj<@008000005`3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00D0ojHA3`2][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00203oYA000`000000ojD@0?nU40020?nU40T0[Jf]1@0000040:f][@8000005`3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@00P0ojD@00<000000?nU403oYA002`3oYA02000000@0ojD@00<0[Jf]0?nS403o
Xa000P0000030:f][@<000000`2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA
2P2][Jd40?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU40090?nU40030000003oYA00ojD@00X0ojD@0P0000040?nU40030:f][@3oXa00oj<@00800000
0P3oXa0010000000oj<@0?nS403oXa02000000030?nS402][Jd0[Jf]00P0[Jf]103oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0
/>3V0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@0?nU40090?nU40030000
003oYA00000000@0ojD@00<0[Jf]0?nS403oXa000P0000000`3oXa0000000?nS40040?nS40800000
2P3oXa050:f][@030000002][Jd0o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@0?nU40090?nU408000001@3o
YA000`2][Jd0oj<@0?nS4003000000H0oj<@0P00000=0?nS4080000000<0o:0@0000000000001@2]
[JdB0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3o
ool007<0/>3V0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ45
0:f][@80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA001`3oYA000`11JN40ojD@0000000;0?nU408000001@3oYA00
0`2][Jd0oj<@0?nS4003000000L0oj<@0P00000;0?nS4080000000@0[Jf]0?bP403lX100o:0@0P00
00030?bP40D0[Jf]0`00000:0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]1`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU40090?nU40030000003oYA00ojD@00T0ojD@0P0000050?nU40030:f][@3oXa00
oj<@00800000203oXa02000000X0oj<@0P0000000`3oXa00[Jf]0?bP40030?bP408000001`3lX102
0:f][@D000001P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@050?nV4@H0[Jf]303oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU40090?nU40030000003oYA00ojD@00T0ojD@0P0000050?nU40030:f][@3oXa00oj<@
008000002@3oXa02000000T0oj<@0P0000000`3oXa00[Jf]0?bP40030?bP408000002@3lX1020000
00030?bP402][Jd0[Jf]00<0[Jf]0`0000000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_
V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3o
YQ401@2][JdB0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00X0ojD@00<000000?nU403oYA00203oYA02000000D0
ojD@00<0[Jf]0?nS403oXa000P0000090?nS40800000203oXa0200000080oj<@00<0[Jf]0?bP403l
X1000`3lX102000000P0o:0@0P0000070?bP40030:f][@000000000000<000004`3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]
1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A102][JdG0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@00X0ojD@00<000000?nU403oYA001`3oYA000`000000ojD@000000050?nU40030:f]
[@3oXa00oj<@008000002@3oXa02000000P0oj<@0P0000020?nS40030:f][@3lX100o:0@00<0o:0@
0P0000080?bP40800000203lX102000000030?JL3`2][Jd0[Jf]0080[Jf]4@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@00X0ojD@00<000000?nU403oYA001`3oYA02000000H0ojD@00<0
[Jf]0?nS403oXa000P0000090?nS40800000203oXa0200000080oj<@00<0[Jf]0?bP403lX100103l
X102000000L0o:0@0P0000080?bP408000001@3fW0l40:f][@d0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@030000002][Jd0[Jf]0080[Jf]1@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00X0ojD@1P0000040?nU408000001P3oYA00
0`2][Jd0oj<@0?nS4002000000T0oj<@0P0000080?nS408000000P3oXa000`2][Jd0o:0@0?bP4004
0?bP408000001`3lX102000000P0o:0@0P0000090?JL3`80[Jf]0`0000080?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3P
iP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT
4@8000000P3oY1420:f][@8000002@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00X0ojD@00<000000?nU403oYA000`3oYA06000000H0ojD@00<0[Jf]0?nS403oXa000P00000:0?nS
408000001P3oXa02000000<0oj<@00<0[Jf]0?bP403lX100103lX102000000L0o:0@0P0000080?bP
408000002@3fW0l200000080mY`?0P0000020:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403l
X1003`3lX100102][Jd0oj@A0?nT4@3oY142000000@0[Jf]0P3oY142000000T0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400;0?nU40030000003oYA00ojD@00H0ojD@0P0000060?nU
40030:f][@3oXa00oj<@008000002P3oXa02000000H0oj<@0P0000040?nS40030:f][@3lX100o:0@
00<0o:0@0P0000070?bP40800000203lX102000000P0mY`?0P0000040?JL3`030000003fW0l0mY`?
00@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]
0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP4004
0:f][@000000[Jf]0:f][@8000001P3oY142000000T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400;0?nU40030000003oYA00ojD@00H0ojD@0P0000060?nU40030:f][@3oXa00oj<@
008000002P3oXa02000000H0oj<@0P0000040?nS40030:f][@3lX100o:0@00@0o:0@0P0000060?bP
40800000203lX102000000P0mY`?00<000000?JL3`3fW0l00`3fW0l2000000D0mY`?1000000@0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102]
[Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00h0o:0@00D0[Jf]0000002][Jd000000?nT
4@02000000L0oj@A00<000000?nT4@3oY1401`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@00/0ojD@00<000000?nU403oYA001@3oYA000`000000ojD@000000060?nU40030:f][@3o
Xa00oj<@008000002P3oXa02000000H0oj<@0P0000040?nS40030:f][@3lX100o:0@00@0o:0@0P00
00060?bP40800000203lX102000000L0mY`?0P0000050?JL3`8000001P3fW0l00`2][Jd000000000
0002000000h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V
0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@
00@0[Jf]000000000000[Jf]0P3oY14300000140oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400;0?nU40030000003oYA00ojD@00D0ojD@0P0000070?nU40030:f][@3oXa00oj<@0080
00002P3oXa02000000H0oj<@0P0000040?nS40030:f][@3lX100o:0@00@0o:0@0P0000060?bP4080
0000203lX102000000L0mY`?0P0000060?JL3`8000001@3fW0l00`2][Jd00000000000020>bF3P80
[Jf]0P00000:0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0
/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00H0o:0@0P000000103lX100[Jf]0:f][@2][Jd2000000040?bP402][Jd0oj@A0?nT
4@<000004@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ405@3oYQ4^0:f][@H0ojD@00<000000?nU403oYA001@3oYA02000000L0ojD@00<0[Jf]0?nS
403oXa000P00000:0?nS408000001P3oXa02000000@0oj<@00<0[Jf]0?bP403lX100103lX1020000
00H0o:0@0P0000080?bP408000001`3fW0l2000000H0mY`?0P0000050?JL3`030:f][@0000000000
00@0k9H>0P2][Jd2000000P0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue
2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0P0000000`3lX100[Jf]0:f][@030?bP4080
000000<0o:0@0:f][@3oY1400P3oY14200000100oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA001@3oYA060:f][@030000002][Jd0[Jf]00D0[Jf]0P0000070?nU4003
0:f][@3oXa00oj<@008000002P3oXa02000000L0oj<@0P0000030?nS40030:f][@3lX100o:0@00@0
o:0@0P0000060?bP40800000203lX102000000L0mY`?0P0000070?JL3`800000103fW0l00`2][Jd0
0000000000060>bF3P@000001P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0
^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>73P040=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX104000000030:f][@3lX100o:0@00<0o:0@
0P0000000`3lX100[Jf]0?nT4@020?nT4@800000403oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
303oYA000`000000ojD@0?nU40040?nU408000002P2][Jd2000000X0oj<@0P0000070?nS40800000
0`3oXa000`2][Jd0o:0@0?bP40040?bP408000001P3lX102000000P0o:0@0P0000060?JL3`800000
203fW0l2000000@0mY`?00<0[Jf]0000000000001P3/UPh200000080k9H>0P2][Jd01@000000k9H>
0>bF3P3/UPh0[Jf]00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40
oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@
0?bP400000030:f][@8000001@3lX10200000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P00000@0?nT
4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ490:f][@@0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@0080ojD@00<0@FWQ0?nU
403oYA001`3oYA000`000000ojD@0?nU40040?nU408000001`3oYA000`2][Jd0oj<@0?nS40020000
00X0[Jf]0P0000070?nS408000000`3oXa000`2][Jd0o:0@0?bP40040?bP408000001P3lX1020000
00P0o:0@0P0000060?JL3`800000203fW0l2000000@0mY`?00<0[Jf]0000000000001P3/UPh20000
00@0k9H>00D0[Jf]000000000000k9H>0:f][@0=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]
0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00/0kiP@00@0[Jf]000000000000[Jf]0`3lX102000000D0o:0@0P0000020?bP40040:f][@3oY140
oj@A0?nT4@800000403oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2]
[Jd=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400<0?nU40030000003oYA00ojD@00<0ojD@00<000000?nU400000001`3oYA000`2][Jd0oj<@0?nS
4002000000X0oj<@0P0000070:f][@8000000`3oXa000`2][Jd0o:0@0?bP40040?bP408000001P3l
X102000000P0o:0@0P0000060?JL3`800000203fW0l2000000@0mY`?00<0[Jf]0000000000001P3/
UPh2000000D0k9H>1000000=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M
0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH400:0>nH40<000001@3lX102000000D0o:0@0P000002
0?bP40040:f][@3oY140oj@A0?nT4@800000403oY1400`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]5`3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00303o
YA000`000000ojD@0?nU40030?nU40800000203oYA000`2][Jd0oj<@0?nS4002000000X0oj<@0P00
00070?nS408000001`2][Jd30?bP408000001P3lX102000000P0o:0@0P0000060?JL3`8000002@3f
W0l2000000<0mY`?00<0[Jf]0000000000001P3/UPh2000000D0k9H>0P000000103/UPh0[Jf]0:f]
[@2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203C
Q`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]00<000000?bP403lX1000`3lX102000000D0o:0@0P00
00020?bP40040:f][@3oY140oj@A0?nT4@800000403oY1400`2][Jd0ojHA0?nV4@0@0?nV4@H0[Jf]
0P3oYQ400`2][Jd0@FWQ0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400<0?nU40030000003oYA00ojD@00<0ojD@0P0000080?nU40030:f]
[@3oXa00oj<@008000002P3oXa02000000P0oj<@0P0000020?nS40040:f][@3lX100o:0@0?bP40<0
[Jf]0P0000000`2][Jd0o:0@0?bP40030?bP40800000203lX102000000H0mY`?0P0000090?JL3`80
00000`3fW0l00`2][Jd00000000000060>bF3P8000001@3/UPh2000000040>bF3P2][Jd0fhX=0=^:
3@80[Jf]00<0fhX=0000003KRPd01P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]
04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080
[Jf]0P3_V1000`2][Jd000000?bP40040?bP408000001@3lX10200000080o:0@00@0[Jf]0?nT4@3o
Y140oj@A0P00000@0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd80?nV4@030:f][@3oYQ40@FWQ
01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00d0ojD@00<000000?nU403oYA000P3oYA02000000P0ojD@00<0[Jf]0?nS403oXa000P00000:0?nS
40800000203oXa0200000080oj<@00<0[Jf]0?bP403lX1000`3lX10200000080o:0@1@2][Jd20000
00P0o:0@0P0000060?JL3`8000002@3fW0l2000000<0mY`?00<0[Jf]0000000000001P3/UPh20000
00D0k9H>0P0000000`3/UPh0[Jf]0=^:3@030=^:3@030000002][Jd0000000H0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f]
[@P0dhL>00<0[Jf]0>nH403_V1000`3_V10200000080[Jf]103_V1000`2][Jd000000?bP40040?bP
40800000103lX102000000<0o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000060?nT4@030000003oY140
oj@A00L0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003@3oYA00
0`000000ojD@0?nU40020?nU40800000203oYA000`2][Jd0oj<@0?nS4003000000P0oj<@0P000009
0?nS408000000P3oXa000`2][Jd0o:0@0?bP40030?bP408000001`3lX102000000H0[Jf]0P3lX102
000000L0mY`?00<000000?JL3`3fW0l01`3fW0l2000000<0mY`?00<0[Jf]0000000000001P3/UPh2
000000D0k9H>0P0000000`3/UPh0[Jf]0=^:3@030=^:3@060000003KRPd0[Jf]0000003KRPd00000
0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V
00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40020>nH4080000000<0[Jf]0000003_
V100103_V1000`2][Jd000000?bP40040?bP40800000103lX102000000<0o:0@00@0[Jf]0?nT4@3o
Y140oj@A0P0000060?nT4@030000003oY140oj@A00L0oj@A00<0[Jf]0?nV4@3oYQ401P2][JdB0?nV
4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@00d0ojD@00<000000?nU403oYA000P3oYA02000000P0ojD@00<0[Jf]0?nS
403oXa000`0000080?nS408000002@3oXa0200000080oj<@00<0[Jf]0?bP403lX1000`3lX1020000
00L0o:0@0P0000060?bP4080[Jf]0P0000000`2][Jd0mY`?0?JL3`040?JL3`030000003fW0l0mY`?
00L0mY`?0P0000030?JL3`030:f][@000000000000H0k9H>0P0000050>bF3P80000000<0k9H>0:f]
[@3KRPd00`3KRPd01@000000fhX=0=^:3@000000[Jf]00<0000000<0fhX=0:f][@2iM@/0202iM@/0
1@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@080=>73P030:f][@3_V100kiP@0080kiP@00@000000:f][@3_V10000001@3_V1000`2][Jd00000
0?bP40040?bP40800000103lX102000000<0o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000060?nT4@03
0000003oY140oj@A00H0oj@A102][JdH0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00d0ojD@00L000000?nU403o
YA00ojD@0000003oYA00000000P0ojD@00<0[Jf]0?nS403oXa000P0000000`3oXa0000000?nS4005
0?nS408000002`3oXa02000000030?nS402][Jd0o:0@00@0o:0@0P0000070?bP40800000203lX102
000000030?JL3`2][Jd0[Jf]0080[Jf]0P3fW0l00`000000mY`?0?JL3`070?JL3`8000000`3fW0l0
0`2][Jd00000000000060>bF3P8000001@3/UPh2000000030>bF3P2][Jd0fhX=0080fhX=0P000003
0=^:3@80000000@0[Jf]0=^:3@3KRPd0[Jf]2@2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V
0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f][@000000kiP@0:f][@80
00000`3_V1000`000000kiP@0>nH40020>nH40030:f][@000000o:0@00@0o:0@0P0000040?bP4080
00000`3lX100102][Jd0oj@A0?nT4@3oY142000000H0oj@A00<000000?nT4@3oY1400P3oY1440:f]
[@030?nT4@2][Jd0ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003@3oYA0010000000ojD@0?nU403oYA02
000000T0ojD@00<0[Jf]0?nS403oXa000P0000020?nS40030000003oXa00oj<@00<0oj<@0P00000;
0?nS4080000000<0oj<@0:f][@3lX100103lX102000000P0o:0@0P0000070?bP408000001@3fW0l2
0:f][@030000002][Jd0mY`?00L0mY`?0P0000030?JL3`030:f][@000000000000H0k9H>0P000005
0>bF3P80000000<0k9H>0:f][@3KRPd00P3KRPd2000000<0fhX=0P000000103KRPd0[Jf]0:f][@00
00090;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H0
0`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00D0dhL>0P0000020:f][@030>nH40000000
000000<0kiP@00<000000>nH403_V1000P3_V1000`2][Jd000000?bP40040?bP40800000103lX102
000000<0o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000060?nT4@030000002][Jd0[Jf]0080[Jf]1@3o
Y1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00d0ojD@00@000000?nU403oYA00ojD@
0P0000090?nU40D000000`3oXa000`000000oj<@0?nS4003000000d0oj<@0P0000000`2][Jd0o:0@
0?bP40020?bP408000002@3lX102000000L0o:0@0P0000070?JL3`030000003fW0l0[Jf]00<0[Jf]
103fW0l2000000<0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2000000@0k9H>0P0000000`3/UPh0
[Jf]0=^:3@020=^:3@8000000`3KRPd2000000<0fhX=00<000000;Ue2`0000001`2iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@080=>73P8000000P3_V102000000T0kiP@00<0[Jf]0000003lX100103lX102000000@0
o:0@0P0000030?bP40040:f][@3oY140oj@A0?nT4@800000103oY1420:f][@030000003oY140oj@A
00L0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400>0?nU40030000003oYA00ojD@
008000002@3oYA000`2][Jd0oj<@0?nS40060?nS40<00000403oXa000`000000[Jf]0?bP40030?bP
408000002@3lX102000000P0o:0@0P0000070?JL3`030000003fW0l0mY`?0080mY`?102][Jd20000
00<0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2000000@0k9H>0P0000000`3/UPh0[Jf]0=^:3@02
0=^:3@800000103KRPd010000000fhX=0=^:3@3KRPd2000000030;Ue2`000000000000D0^GD;00<0
[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd01P3CQ`h010000000dhL>0000000000020>nH40800000203_V1000`2][Jd0o:0@
000000050?bP40800000103lX102000000<0o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000040:f][@80
oj@A00<000000?nT4@3oY1401`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0
ojD@00<000000?nU403oYA000P0000090?nU40030:f][@3oXa00oj<@01X0oj<@00@000000?bP403l
X100o:0@0`0000090?bP40800000203lX102000000L0mY`?00<000000?JL3`3fW0l01P3fW0l01`00
0000[Jf]0:f][@2][Jd0mY`?0:f][@3/UPh00P0000060>bF3P800000103/UPh2000000030>bF3P2]
[Jd0fhX=0080fhX=0P0000040=^:3@040000003KRPd0fhX=0=^:3@8000000P2][Jd00`000000^GD;
0;Ue2`030;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`
h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>1@0000020>nH40800000203_V1000`2][Jd00000
000000040?bP408000001@3lX102000000<0o:0@00@0[Jf]0?nT4@2][Jd0[Jf]0P0000060?nT4@03
0000003oY140oj@A00L0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400>0?nU4003
0000003oYA00ojD@008000002@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@00000000000080
00002`3lX102000000P0o:0@0P0000070?JL3`030000003fW0l0mY`?00H0mY`?00@000000?JL3`3f
W0l0mY`?0`2][Jd2000000H0k9H>0P0000040>bF3P80000000<0k9H>0:f][@3KRPd00P3KRPd20000
00@0fhX=00@000000=^:3@3KRPd0fhX=0P0000020;Ue2`030000002iM@/0^GD;00<0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd01@3CQ`h00`000000dhL>0000000200000080kiP@0P0000080>nH40030:f][@000000
000000@0o:0@0P0000050?bP408000000P3lX1030:f][@80oj@A0P0000060?nT4@030000003oY140
oj@A00L0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400>0?nU40050000003oYA00
00000?nU400000002@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00d0o:0@0P00
00080?bP408000001`3fW0l00`000000mY`?0?JL3`060?JL3`030000003fW0l0mY`?0080mY`?00D0
[Jf]0>bF3P00000000000:f][@050>bF3P800000103/UPh2000000030>bF3P2][Jd0fhX=0080fhX=
0P0000040=^:3@040000003KRPd0fhX=0=^:3@8000000P2iM@/01`000000[Jf]0;Ue2`2iM@/00000
0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@04
0=>73P8000000P3CQ`h200000080kiP@0P0000080>nH40030:f][@000000000000@0o:0@0P000005
0?bP408000000P2][Jd0103lX100[Jf]0?nT4@3oY142000000L0oj@A00<000000?nT4@3oY1401`3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0ojD@00@000000?nU400000000000
2P3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00d0o:0@0P0000080?bP40800000
1`3fW0l2000000L0mY`?00<000000?JL3`3fW0l00P3fW0l01@2][Jd0k9H>000000000000k9H>0080
[Jf]0`3/UPh2000000D0k9H>0P000000102][Jd0fhX=0=^:3@3KRPd2000000@0fhX=00D000000=^:
3@3KRPd0fhX=000000030;Ue2`030000002iM@/0[Jf]0080000000<0^GD;0:f][@28EPL00`28EPL2
0:f][D80/>3V0@3oool005T0/>3V00T0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h000000=>73P2][Jd0
0P0000020=>73P8000000P3_V1000`000000kiP@0>nH40070>nH40030:f][@000000000000@0o:0@
0P0000040?bP40030:f][@000000000000<0o:0@00<0[Jf]0?nT4@3oY1400P0000070?nT4@030000
003oY140oj@A00L0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400?0?nU40<00000
2P3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00d0o:0@0P0000080?bP40800000
203fW0l00`000000mY`?0?JL3`040?JL3`800000103fW0l0102][Jd0k9H>0000000000030>bF3P<0
[Jf]0P0000050>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=0P0000040=^:3@050000003KRPd0fhX=
0=^:3@000000102iM@/01P000000^GD;000000000000^GD;0:f][@@0R5H70P2][Je20;3PiP40oooo
001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P0000000`2][Jd0dhL>000000030=>73P800000
00<0kiP@0000000000002@3_V1000`2][Jd00000000000040?bP4080000000D0o:0@0:f][@2][Jd0
[Jf]0?bP4002000000<0o:0@00<0[Jf]0?nT4@3oY1400P0000070?nT4@030000003oY140oj@A00L0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0
ojHA;P2][Jd:0?nU40<000002P3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00d0
o:0@0P0000080?bP40800000203fW0l2000000D0mY`?00<000000?JL3`3fW0l00`3fW0l0102][Jd0
@FWQ0000000000060>bF3P80000000<0[Jf]0>bF3P3/UPh00P3/UPh2000000040:f][@3KRPd0fhX=
0=^:3@800000103KRPd01@000000fhX=0=^:3@3KRPd0000000@0^GD;00@000000;Ue2`0000000000
0P2][Jd408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`2GH0/000000:f][@00
00000P3CQ`h010000000dhL>0=>73P3CQ`h2000000030>nH40000000000000T0kiP@00<0[Jf]0000
00000000103lX102000000030:f][@3lX100o:0@0080o:0@0P0000030?bP40030:f][@3oY140oj@A
008000001P3oY142000000T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA001@3oYA0:0:f][@030000002][Jd0000000<0[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@00d0o:0@0P0000080?bP408000002@3fW0l2000000<0mY`?0P0000050?JL
3`040:f][@3/UPh00000000000H0k9H>0P0000000`3/UPh0[Jf]0:f][@020>bF3P80000000@0[Jf]
0=^:3@3KRPd0fhX=0P0000040=^:3@050000003KRPd0fhX=0=^:3@2][Jd0102iM@/01P000000^GD;
0;Ue2`000000^GD;0:f][@D0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0
Uf0;09MP2`02000000050=>73P000000dhL>0=>73P0000000`3CQ`h2000000030>nH400000000000
00T0kiP@00<0[Jf]0000000000000P3lX1020:f][@8000001@3lX102000000<0o:0@00<0[Jf]0?nT
4@0000000P0000060?nT4@8000002@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01H0ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003`3oYA000`00
0000ojD@000000030?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP400=0?bP40800000203lX1020000
00X0mY`?00@000000?JL3`3fW0l0mY`?0P0000050?JL3`030:f][@3/UPh00000008000001@3/UPh2
000000<0k9H>0P2][Jd2000000040:f][@3KRPd0fhX=0=^:3@800000103KRPd00`000000fhX=0=^:
3@020=^:3@050:f][@2iM@/0^GD;0;Ue2`000000102iM@/20:f][@@0R5H700<0[Jf]0;3PiP2`h>H0
@02`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`000000[Jf]0=>73P0000000P3CQ`h010000000
dhL>0=>73P3CQ`h2000000030>nH40000000000000T0kiP@00<0[Jf]0000000000000P2][Jd20?bP
408000001P3lX1001P000000o:0@0?bP403lX100[Jf]0?nT4@<000001P3oY142000000T0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003`3oYA000`000000ojD@0000
000:0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@00d0o:0@0P00
00080?bP408000002`3fW0l3000000L0mY`?00<0[Jf]0>bF3P0000000P0000050>bF3P8000001@3/
UPh200000080[Jf]0P3KRPd2000000@0fhX=00<000000=^:3@3KRPd00P3KRPd01@2][Jd0^GD;0;Ue
2`2iM@/0000000@0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00L0
[Jf]09MP2`00000000000:f][@3CQ`h000000080dhL>00@000000=>73P3CQ`h0dhL>0P0000000`3_
V1000000000000090>nH40030:f][@000000000000@0o:0@0P0000060?bP408000000P3lX1000`2]
[Jd0oj@A00000002000000H0oj@A0P0000090?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@00l0ojD@0P00000;0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS
40030:f][@3lX100o:0@00d0o:0@0P0000080?bP408000005@3fW0l01P2][Jd0k9H>000000000000
k9H>000000@0k9H>0P0000050>bF3P80000000D0[Jf]0=^:3@2][Jd0[Jf]0=^:3@02000000@0fhX=
00D000000=^:3@3KRPd0fhX=0:f][@030;Ue2`030000002iM@/0^GD;0080^GD;00<0[Jf]08QF1`2]
[Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP070:f][@2GH0/0[Jf]0000002]
[Jd0dhL>000000020=>73P040000003CQ`h0dhL>0=>73P80000000<0kiP@000000000000103_V100
0`000000kiP@0>nH40030:f][@800000103lX102000000L0o:0@00H000000?bP403lX100[Jf]0000
003oY142000000H0oj@A0P0000090?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdH0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400@0?nU40030000
003oYA00ojD@00T0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][@`0o:0@0P0000080?bP40800000
5@3fW0l4000000030>bF3P000000k9H>0080k9H>0P0000060>bF3P80000000D0[Jf]0=^:3@3KRPd0
fhX=0:f][@02000000@0fhX=00D000000=^:3@3KRPd0fhX=0:f][@020;Ue2`800000102iM@/0102]
[Jd0R5H708QF1`2][Jd208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00L0[Jf]09MP
2`2][Jd000000:f][@3CQ`h000000080dhL>00@000000=>73P3CQ`h0dhL>0P0000000`3_V1000000
000000040>nH40030000002][Jd0[Jf]0080kiP@00<0[Jf]0000003lX100103lX102000000P0o:0@
00<000000:f][@0000000P3oY142000000H0oj@A0P0000090?nT4@030:f][@3oYQ40ojHA00h0ojHA
1P2][Jd30?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@0100ojD@00<000000?nU403oYA002@3oYA000`2][Jd0oj<@
0?nS400J0?nS40040:f][@3lX100o:0@0?bP40L0[Jf]1@3lX102000000P0o:0@0P00000F0?JL3`03
0:f][@00000000000080k9H>00<000000>bF3P3/UPh00P0000060>bF3P80000000<0[Jf]0=^:3@3K
RPd00P3KRPd2000000050:f][@3KRPd0fhX=0=^:3@0000000`3KRPd00`2][Jd0^GD;0;Ue2`020000
00@0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005T0/>3V0P2][Jd0
1@2GH0/000000:f][@3CQ`h000000080dhL>00<000000=>73P3CQ`h00P0000020>nH408000000`3_
V1000`2][Jd00000000000030>nH40030:f][@000000o:0@00@0o:0@0P0000090?bP40040000003o
Y140oj@A0?nT4@8000001P3oY142000000T0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00403oYA000`000000ojD@0?nU40090?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100203lX1050:f][@800000203lX102000001H0mY`?00<0[Jf]0>bF3P3/UPh0
0`3/UPh2000000030>bF3P000000k9H>00D0k9H>0P0000000`2][Jd0fhX=0=^:3@020=^:3@800000
00D0fhX=0:f][@2][Jd0fhX=000000030=^:3@040:f][@2iM@/00000000000D0^GD;00L0[Jf]045Y
h@28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005T0/>3V0P2][Jd01@2GH0/000000:f][@3C
Q`h000000080dhL>00<000000=>73P3CQ`h00P0000020>nH4080000000@0kiP@0:f][@2][Jd0kiP@
0P0000030>nH40030:f][@000000o:0@00@0o:0@0P0000090?bP40040:f][@3oY140oj@A0?nT4@80
00001P3oY142000000T0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400=0?bP408000001P2][Jd20?bP
408000005P3fW0l00`2][Jd0k9H>0>bF3P040>bF3P8000001`3/UPh2000000030:f][@3KRPd0fhX=
0080fhX=0P0000030=^:3@030:f][@000000fhX=0080fhX=00<0[Jf]0000000000001P2iM@/00`2]
[Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`000000[Jf]
0=>73P0000000P3CQ`h00`000000dhL>0=>73P0200000080kiP@0P000000102][Jd0kiP@0>nH403_
V102000000<0kiP@00<0[Jf]0000003lX100103lX102000000T0o:0@00@0[Jf]0?nT4@3oY140oj@A
0P0000060?nT4@800000203oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@00d0o:0@0P0000060?bP4080[Jf]0P0000020:f][A@0mY`?
00<0[Jf]0>bF3P3/UPh03@3/UPh2000000030:f][@3KRPd0fhX=0080fhX=0P0000040=^:3@070000
002][Jd0[Jf]0=^:3@000000^GD;000000060;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3P
iP2`h>H0@02`h>H10?ooo`00F02`h>H20:f][@80Uf0;00@000000:f][@3CQ`h000000P3CQ`h00`00
0000dhL>0=>73P02000000040>nH402][Jd0[Jf]000000@0kiP@00<000000>nH403_V1000P3_V100
0`2][Jd000000?bP40040?bP408000002@3lX100102][Jd0oj@A0?nT4@3oY142000000H0oj@A0P00
00040?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003@3lX102000000P0o:0@0P0000020?JL3`@0[Jf]403f
W0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0000000<0[Jf]0=^:3@3KRPd00P3KRPd2000000@0fhX=00@0
00000=^:3@3KRPd0[Jf]0P0000080;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo
001H0;3PiP80[Jf]0P2GH0/00`000000[Jf]0=>73P030=>73P030000003CQ`h0dhL>0080000000@0
[Jf]0>nH403_V1000000103_V1000`000000kiP@0>nH40020>nH40030:f][@000000o:0@0080o:0@
0P00000;0?bP40040:f][@3oY140oj@A0?nT4@8000001P3oY142000000@0[Jf]1@3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400=0?bP40800000203lX102000000H0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00d0
k9H>0P0000000`2][Jd0fhX=0=^:3@020=^:3@800000103KRPd01P000000fhX=0=^:3@3KRPd00000
0:f][@D0^GD;00@000000;Ue2`2iM@/0[Jf]1028EPL20:f][D40/>3V0@3oool005P0/>3V0P2][Jd0
102GH0/000000000002][Jd40=>73P030000003CQ`h0dhL>008000000`3_V1001@000000kiP@0>nH
403_V100000000D0kiP@00<0[Jf]0000003lX1003`3lX100102][Jd0oj@A0?nT4@3oY142000000@0
oj@A0P2][Jd2000000T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1002`3lX104000000P0o:0@0P00000;0?JL3`D0
[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P0000040=^:3@06
0000003KRPd0fhX=0=^:3@000000^GD;0P2][Jd30;Ue2`040000002iM@/0^GD;0:f][@@0R5H70P2]
[Je10;3PiP40oooo001H0;3PiP80[Jf]00@0Uf0;0000002GH0/0[Jf]0`3CQ`h010000000dhL>0=>7
3P2][Jd2000000<0kiP@00D000000>nH403_V100kiP@000000050>nH40030:f][@000000o:0@00l0
o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000040:f][@80oj@A0P0000090?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
00d0o:0@0P0000080?bP40800000403fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2]
[Jd0fhX=00000003000000@0fhX=00D000000=^:3@3KRPd0fhX=000000030;Ue2`040:f][@2iM@/0
^GD;00000080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005P0/>3V0P2][Jd0
102GH0/0000009MP2`0000030=>73P040000003CQ`h0[Jf]0=>73P8000000`3_V10200000080kiP@
00<000000>nH403_V1000`3_V1000`2][Jd000000?bP400?0?bP40040:f][@3oY140[Jf]0:f][@80
00001P3oY142000000T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX104000001@0mY`?102][JdA0>bF3P04
0:f][@3KRPd0fhX=0=^:3@800000103KRPd01@000000fhX=0=^:3@3KRPd0000000<0^GD;00@00000
0:f][@2iM@/000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00F02`h>H2
0:f][@0409MP2`000000Uf0;000000<0dhL>00@000000:f][@3CQ`h0dhL>0P0000030>nH40800000
00<0kiP@0000003_V1001@3_V1000`2][Jd000000?bP400>0?bP40<0[Jf]0P3oY142000000H0oj@A
0P0000090?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd01@000000fhX=0=^:3@3KRPd0000000<0
^GD;00@000000;Ue2`2][Jd000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?oo
o`00F02`h>H20:f][@0409MP2`000000Uf0;00000080dhL>00<0[Jf]0000003CQ`h00P3CQ`h20000
00@0kiP@00<000000>nH400000001P3_V102000000d0o:0@0P2][Jd00`3lX100[Jf]0?nT4@020?nT
4@8000001`3oY1400`000000oj@A0?nT4@070?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@050=^:
3@030000003KRPd0000000<0fhX=00D000000;Ue2`2iM@/0^GD;000000020;Ue2`040000002][Jd0
^GD;0:f][@@0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]00P0Uf0;0000002GH0/000000=>7
3P2][Jd0dhL>000000<0dhL>0P0000050>nH40030000003_V100kiP@00D0kiP@0P00000:0?bP40<0
[Jf]0`3lX100102][Jd0oj@A0?nT4@3oY142000000L0oj@A00<000000?nT4@3oY1401`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f]
[@T0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd2000000<0fhX=00D0[Jf]0000002iM@/0^GD;00000002
0;Ue2`040000002iM@/0[Jf]0:f][@@0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]00D0Uf0;
0000002GH0/000000:f][@020=>73P040000003CQ`h0dhL>0=>73P8000003@3_V102000000P0o:0@
0P2][Jd60?bP40040:f][@3oY140oj@A0?nT4@8000004@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd01@2][Jd000000;Ue2`2iM@/000000080^GD;00@000000;Ue2`2iM@/0[Jf]1028EPL2
0:f][D40/>3V0@3oool005P0/>3V00H0[Jf]09MP2`2GH0/0000009MP2`0000030=>73P040000003C
Q`h0dhL>0=>73P8000003@3_V102000000D0o:0@0`2][Jd80?bP40040:f][@3oY140oj@A0?nT4@80
0000403oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd0102][Jd000000;Ue2`2iM@/2000000040;Ue2`000000^GD;0;Ue2`80[Jf]0`28EPL2
0:f][D40/>3V0@3oool005P0/>3V00H0[Jf]09MP2`2GH0/000000:f][@0000030=>73P040000003C
Q`h0dhL>0=>73P8000003@3_V10200000080o:0@0`2][Jd00`000000o:0@0?bP40080?bP40040:f]
[@3oY140000000000180oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0
[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`000000^GD;00000002000000040;Ue2`000000^GD;0;Ue
2`80[Jf]0P28EPL00`11JN40[Jf]0:f][@110;3PiP40oooo001H0;3PiP060:f][@2GH0/0Uf0;0000
002][Jd000000`3CQ`h00`000000dhL>0=>73P02000000h0kiP@0P0000020:f][@80o:0@0P00000:
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F
0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00h0k9H>00@000000:f][@2][Jd0[Jf]3@3KRPd01`2][Jd000000000
002iM@/000000;Ue2`0000000P2iM@/01@2][Jd0R5H70:f][@28EPL0@FWQ0080[Jf]@@2`h>H10?oo
o`00F02`h>H00`2][Jd0Uf0;09MP2`02000000050:f][@3CQ`h0dhL>0=>73P0000000`3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@000000000000@0o:0@00<000000?bP400000002@3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f]
[FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0=0>bF3P80000000<0k9H>0:f][@3KRPd00P2][Jd;0=^:3@060:f][@2iM@/0^GD;
0;Ue2`000000^GD;0P000000102iM@/0[Jf]08QF1`2][Jd208QF1`80[Jf]@@2`h>H10?ooo`00F02`
h>H00`2][Jd0Uf0;0:f][@02000000050:f][@3CQ`h0dhL>0=>73P0000000`3CQ`h00`2][Jd0kiP@
0>nH40090>nH4080[Jf]00<0kiP@000000000000103lX102000000X0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00d0k9H>0P0000000`3/UPh0[Jf]
0=^:3@020=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030000002iM@/0[Jf]0080R5H7
00@0[Jf]08QF1`2][Jd0[Jf]@@2`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@02000000040:f]
[@3CQ`h0dhL>000000@0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@0P0000050?bP4003
0000003lX100o:0@00P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0
[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P80
000000<0k9H>0:f][@3KRPd0103KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`000000
^GD;0:f][@0308QF1`<0[Jf]@@2`h>H10?ooo`00F02`h>H20:f][@0409MP2`00000000000:f][@L0
dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@0P00000@0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0
mY`?00<0[Jf]0>bF3P3/UPh03@3/UPh00`000000k9H>0:f][@070=^:3@80[Jf]1@3KRPd00`2][Jd0
^GD;0;Ue2`040;Ue2`030000002iM@/0[Jf]00<0R5H70`2][Je10;3PiP40oooo001H0;3PiP80[Jf]
00@0Uf0;000000000000[Jf]1`3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_V10200000100
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0
o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00L0
fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00@0^GD;00<000000;Ue2`2][Jd01028EPL20:f][D40
/>3V0@3oool005L0/>3V0P2][Jd209MP2`80000000<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@
0>nH403_V1020:f][@L0kiP@0P0000000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0
oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@030=^:3@2][Jd0^GD;
00D0^GD;00@000000;Ue2`2iM@/0[Jf]0`28EPL20:f][D40/>3V0@3oool005L0/>3V0P2][Jd209MP
2`80000000<0dhL>0000003CQ`h01@3CQ`h0102][Jd0kiP@0:f][@2][Jd;0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@H0^GD;00@000000;Ue2`2iM@/0[Jf]0`28
EPL20:f][D40/>3V0@3oool005L0/>3V0P2][Jd209MP2`80000000<0dhL>0000003CQ`h01@3CQ`h2
0:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H5
0:f][A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@<0[Jf]102iM@/0
10000000^GD;0;Ue2`2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H20:f][@80Uf0;00@00000
0:f][@3CQ`h000001@3CQ`h20:f][@h0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@<0^GD;00@000000;Ue2`2iM@/0[Jf]0`28EPL20:f][D40
/>3V0@3oool005L0/>3V0P2][Jd209MP2`040000002][Jd0dhL>000000<0dhL>0P2][Jd00`3CQ`h0
[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0
/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0
^GD;0;Ue2`2iM@/0[Jf]0080^GD;00@000000;Ue2`2iM@/0[Jf]0`28EPL20:f][D40/>3V0@3oool0
05L0/>3V0P2][Jd01P2GH0/000000000002][Jd0dhL>00000080dhL>00D0[Jf]0=>73P3CQ`h0dhL>
0:f][@0=0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]
0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
0P2iM@/20:f][@040000002iM@/0^GD;0:f][@<0R5H70P2][Je10;3PiP40oooo001G0;3PiP80[Jf]
00P0Uf0;0000002GH0/0[Jf]0=>73P000000dhL>0:f][@@0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`040;Ue2`040000002iM@/0^GD;0:f][@<0R5H70P2][Je10;3PiP40oooo001G
0;3PiP80[Jf]00D0Uf0;0000002GH0/0[Jf]000000020:f][@D0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`040;Ue2`040000002][Jd0[Jf]0:f][@<0R5H70P2][Je10;3PiP40oooo
001G0;3PiP80[Jf]00D0Uf0;0000002GH0/0[Jf]000000070=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0
[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00@000000;Ue2`2i
M@/0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP070:f][@2GH0/0Uf0;0000
002GH0/0[Jf]000000070=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX103
0:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`040;Ue2`030000002iM@/0^GD;0080[Jf]0`28EPL00`2][Jd0/>3V0;3PiP0o
0;3PiP40oooo001G0;3PiP040:f][@2GH0/0Uf0;00000080[Jf]00<000000=>73P3CQ`h01@3CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:
0;VbYP<0[Jf]kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/0102iM@/00`000000^GD;0;Ue2`020:f][@80R5H700<0@FWQ0:f][@2`h>H0@02`h>H1
0?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`0000020:f][@030000003CQ`h0dhL>00D0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<
0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd0
0`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`2][Jd0R5H7045Y
h@2][Je10;3PiP40oooo001G0;3PiP070:f][@2GH0/0Uf0;0000002GH0/0[Jf]000000070=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0
^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2]
[Jd00P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP060:f][@2GH0/0[Jf]0000002G
H0/00000203CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF
1`28EPL0[Jf]08QF1`2][Je10;3PiP40oooo001G0;3PiP030:f][@2GH0/0[Jf]0080000000<0[Jf]
0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001G0;3PiP80[Jf]00@0Uf0;0000002GH0/0[Jf]203C
Q`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je10;3PiP40oooo001G0;3PiP80[Jf]0P0000000`2GH0/0[Jf]0=>73P070=>73P030:f][@3_
V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`0
3`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]
1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je00;3PiP40oooo
001G0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH
403_V1020:f][@05045Yh@2TWXl0Y9j?0:BNS`2][Jd0102aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0
al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0:0<>m^`<0@FWQ00<0`kfk0:f][@2n
^KP0102n^KP20:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd02@3CQ`h01@2][Jd0kiP@0:f][@2][Jd0@FWQ0080Y9j?00@0@FWQ0:BNS`2TWXl0[Jf]1P2a
Zid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00L0`kfk0`11JN430<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]1`2n^KP2045Yh@80];2a
00D0@FWQ0:f][@2][Jd0fhX=0:f][@0:0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?oo
o`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd00`2TWXl0@FWQ045Yh@020:BN
S`04045Yh@2TWXl0Y9j?0:f][@80@FWQ1P2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk00H0@FWQ0<>m^`33_K/0`kfk0:f]
[@2n^KP20:f][@L0_[Vh0`11JN400`2][Jd0];2a0;B`/@02045Yh@030;B`/@2][Jd0[Jf]00X0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd0203CQ`h0102][Jd0Y9j?0:BNS`2TWXl2045Yh@80Y9j?0P11JN400`2TWXl0[Jf]0;6[W@03045Y
h@H0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`03045Yh@33_K/0`kfk00<0[Jf]1`2n^KP00`11
JN40_[Vh0;ji^002045Yh@030:f][@2d/;40];2a0080@FWQ00<0];2a045Yh@11JN400P2][Jd80;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00H0dhL>0P2][Jd40:BNS`80@FWQ0P2TWXl2045Yh@040:BNS`2][Jd0/J^M045Yh@X0/J^M0`2]
[Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m
/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`090<>m^`05045Yh@2][Jd0[Jf]0<>m^`2][Jd01P2n^KP2045Yh@<0
_[Vh0P11JN400`2][Jd0];2a0;B`/@02045Yh@030;B`/@11JN40@FWQ0080];2a00<0[Jf]0;Ue2`2i
M@/01@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@050=>73P<0[Jf]102TWXl2045Yh@80Y9j?0P11JN40102][Jd0/J^M0;6[W@11JN4;
0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]00D0@FWQ
0<>m^`33_K/0`kfk0:f][@050;ji^0<0@FWQ0`2n^KP2045Yh@030;ji^02][Jd0];2a0080@FWQ00<0
];2a045Yh@11JN400`2d/;420:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo
001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0RXEe08Z5M@2][Jd40:BNS`80
@FWQ0`2TWXl01@11JN40[Jf]0;6[W@2aZid0@FWQ00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f]
[@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@<0`kfk00D0@FWQ0<>m^`33_K/0`kfk0:f][@06
0;ji^080@FWQ0`2n^KP2045Yh@030;ji^02][Jd0];2a0080@FWQ0P2d/;400`11JN40];2a0;B`/@02
045Yh@<0[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@030=>73P040:f][@2:QGD0RXEe08Z5M@<0[Jf]0P2TWXl2045Yh@<0Y9j?
00D0@FWQ0:f][@2aZid0/J^M045Yh@090;6[W@03045Yh@2aZid0[Jf]00P0^K:V0`2][Jd50;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@L0
`kfk00D0@FWQ0<>m^`33_K/0`kfk045Yh@060;ji^080@FWQ0`2n^KP2045Yh@030;ji^02][Jd0];2a
0080@FWQ0P2d/;400`11JN40];2a0:f][@02045Yh@040:f][@11JN40Wi^P0:f][@80^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>
0P2][Jd408Z5M@050:f][@2TWXl0Y9j?0:f][@2TWXl00P11JN430:BNS`05045Yh@2][Jd0/J^M0;6[
W@11JN40202aZid01011JN40/J^M045Yh@11JN4;0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA
0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]2P33_K/01P11JN40`kfk0<>m^`11JN40[Jf]045Yh@D0_[Vh
0P11JN430;ji^080@FWQ00D0_[Vh0:f][@2d/;40];2a045Yh@020;B`/@07045Yh@2][Jd0];2a0;B`
/@11JN40[Jf]09nKX002045Yh@<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd608Z5M@050:f][@2TWXl0Y9j?0:BNS`2][Jd00P11JN43
0:BNS`05045Yh@2][Jd0/J^M0;6[W@11JN401`2aZid2045Yh@80/J^M00D0[Jf]045Yh@2i/ZH0^K:V
045Yh@0;0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02P33_K/01@11JN40`kfk045Yh@33_K/0[Jf]0080
@FWQ102n^KP2045Yh@@0_[Vh00<0@FWQ0;ji^02][Jd00P2d/;401011JN40[Jf]0:f][@11JN430;B`
/@04045Yh@2][Jd0Wi^P045Yh@<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n
0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD01@2:QGD00`2]
[Jd0Y9j?0:BNS`020:BNS`80@FWQ00D0[Jf]0:BNS`2TWXl0@FWQ0:f][@020;6[W@03045Yh@2aZid0
/J^M00D0/J^M0P11JN420;6[W@040:f][@11JN40@FWQ045Yh@d0^K:V00<0[Jf]0;jg[02][Jd00`2]
[Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00A0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jd50<K0_0030:f][@33_K/0`kfk00H0`kfk00T0
@FWQ0<>m^`33_K/0@FWQ0<>m^`11JN40`kfk0:f][@2n^KP00P11JN430;ji^080@FWQ102n^KP00`11
JN40_[Vh0:f][@020;B`/@04045Yh@2d/;40];2a045Yh@<0];2a00<0@FWQ0:f][@2OVj00102OVj00
0`11JN40[Jf]08QF1`0208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00@0[Jf]09MP
2`2GH0/0Uf0;0P2][Jd708Z5M@040:f][@2TWXl0Y9j?0:BNS`80@FWQ0P2TWXl01@2][Jd0Y9j?045Y
h@2][Jd0/J^M0080@FWQ1`2aZid01`11JN40/J^M0;6[W@2aZid0[Jf]0;VbYP11JN401P2i/ZH00`11
JN40^K:V0;VbYP050;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`
0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l
00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk0080`kfk00@0@FWQ0<>m^`33_K/0@FWQ0`33_K/2
045Yh@<0`kfk00<0[Jf]045Yh@11JN400`2n^KP2045Yh@@0_[Vh00<0@FWQ0;ji^02][Jd00P2][Jd0
1011JN40];2a0;B`/@11JN420;B`/@03045Yh@2d/;40[Jf]00D0Wi^P00<0@FWQ0:f][@28EPL00P28
EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`2:
QGD0102][Jd0Y9j?0:BNS`2TWXl2045Yh@<0Y9j?00@0[Jf]045Yh@2][Jd0/J^M0P11JN470;6[W@07
045Yh@2aZid0/J^M0;6[W@2][Jd0^K:V045Yh@060;VbYP03045Yh@2i/ZH0^K:V00D0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@33_K/0
`kfk0080@FWQ00@0`kfk045Yh@33_K/0@FWQ0`33_K/2045Yh@<0`kfk00<0[Jf]0;ji^011JN400`2n
^KP2045Yh@@0_[Vh00<0@FWQ0:f][@2][Jd00P2d/;402@11JN40];2a0;B`/@2d/;40@FWQ0;B`/@11
JN40];2a0:f][@0509nKX003045Yh@2OVj00[Jf]0080R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?oo
o`00EP2`h>H00`2][Jd0Uf0;09MP2`030:f][@L0RXEe00@0[Jf]0:BNS`2TWXl0Y9j?0P11JN440:BN
S`03045Yh@2][Jd0[Jf]0080@FWQ1`2aZid01`11JN40/J^M0;6[W@2aZid0[Jf]0;VbYP11JN401P2i
/ZH00`11JN40^K:V0;VbYP020;VbYP04045Yh@2i/ZH0^K:V0:f][@d0_[N/102][Jd00`2n]j`0[Jf]
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40a/2l
00<0[Jf]0<>m^`11JN400`33_K/3045Yh@<0`kfk0P11JN430<>m^`030:f][@2n^KP0@FWQ00<0_[Vh
0P11JN430;ji^0040:f][@11JN40_[Vh0:f][@80];2a00<0@FWQ0;B`/@2d/;400P2d/;401011JN40
];2a0;B`/@2][Jd509nKX006045Yh@2OVj00[Jf]0:f][@28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H0
102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl2045Yh@@0Y9j?00<0
@FWQ0:f][@2aZid00P11JN470;6[W@80@FWQ0P2aZid00`2][Jd0^K:V045Yh@060;VbYP03045Yh@2i
/ZH0^K:V0080^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]4@2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@11JN40@FWQ00@0`kfk0P11JN440<>m^`07045Yh@33_K/0`kfk0<>m^`2][Jd0_[Vh045Yh@030;ji
^080@FWQ00L0_[Vh0:f][@2][Jd0_[Vh045Yh@2n^KP0[Jf]0080];2a00<0@FWQ0;B`/@2d/;401@2d
/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V0P2]
[Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl2045Yh@@0Y9j?00<0
@FWQ0:f][@2aZid00P11JN430:f][@@0/J^M0P11JN420;6[W@030:f][@2i/ZH0@FWQ00D0^K:V0P11
JN440;VbYP04045Yh@2i/ZH0^K:V0:f][A80_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f]
[@33_K<0`kfc00<0`kfc1P11JN4:0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f]
[@36`;`0a/2l00H0a/2l0`11JN470<K0_0030:f][@11JN40`kfk00@0`kfk0P11JN440<>m^`07045Y
h@33_K/0`kfk0<>m^`2][Jd0_[Vh045Yh@030;ji^080@FWQ00L0[Jf]0;ji^02n^KP0_[Vh045Yh@2n
^KP0[Jf]0080];2a00<0@FWQ0;B`/@2d/;401@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00<0
L6ii0:f][@2][Jd0@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f][@2TWXl0
Y9j?0080Y9j?0P11JN440:BNS`03045Yh@2][Jd0/J^M0080@FWQ0`2aZid20:f][@<0/J^M00H0@FWQ
0;6[W@2aZid0[Jf]0;VbYP11JN450;VbYP<0@FWQ0P2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`0
102n]j`4045Yh@P0_[N/00<0[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<0
1@33_K<2045Yh@`0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00@0a/2l
0`11JN490<K0_0030:f][@11JN40`kfk00@0`kfk0P11JN440<>m^`08045Yh@33_K/0`kfk0<>m^`2]
[Jd0_[Vh045Yh@2n^KP20:f][@80@FWQ102n^KP00`11JN40_[Vh0:f][@020;B`/@03045Yh@2d/;40
];2a00D0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]?`2`h>H1
0?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0[Jf]00@0RXEe00<0[Jf]0:BN
S`2TWXl00P2TWXl2045Yh@@0Y9j?00<0@FWQ0:f][@2aZid00P11JN450;6[W@<0[Jf]00H0/J^M045Y
h@2aZid0[Jf]0;VbYP11JN450;VbYP<0@FWQ0P2i/ZH2045Yh@030;VbYP2][Jd0_[N/00D0_[N/0`11
JN420;jg[004045Yh@2n]j`0@FWQ045Yh@@0_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`
00<0[Jf]0<>m/`33_K<01@33_K<2045Yh@`0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdA0<O1_0040:f][@36`;`0@FWQ045Yh@D0
a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0@FWQ0<>m^`040<>m^`80@FWQ1033_K/02011JN40
`kfk0<>m^`33_K/000000;ji^011JN40[Jf]0`2n^KP2045Yh@<0_[Vh00D0@FWQ0;ji^02][Jd0];2a
045Yh@080;B`/@030:f][@2OVj00Wi^P0080Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@03
0:f][@2TWXl0Y9j?0080Y9j?0P11JN430:BNS`80@FWQ00<0[Jf]0;6[W@11JN400P11JN420;6[W@03
045Yh@2aZid0/J^M0080/J^M0P2][Jd4045Yh@D0^K:V00<0@FWQ0;VbYP11JN400P2i/ZH3045Yh@03
0:f][@2n]j`0_[N/00<0_[N/0P11JN450;jg[0<0@FWQ0`2n]j`4045Yh@l0`KZ`202][Jd20<>m/`80
@FWQ3033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`03P37`K`3045Yh@040:f][@36`;`0@FWQ045Y
h@D0a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0@FWQ0<>m^`040<>m^`80@FWQ1033_K/00`11
JN40`kfk0<>m^`020:f][@80@FWQ102n^KP2045Yh@80_[Vh00@0@FWQ0;ji^02n^KP0[Jf]2P2d/;40
0`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0
Y9j?0080Y9j?0P11JN430:BNS`80@FWQ00<0[Jf]045Yh@11JN400P11JN400`2aZid0@FWQ045Yh@06
0;6[W@80[Jf]0P11JN450;VbYP03045Yh@2i/ZH0@FWQ0080^K:V00@0@FWQ0;VbYP11JN40[Jf]1@2n
]j`2045Yh@D0_[N/0`11JN440;jg[0030:f][@11JN40@FWQ0080@FWQ3`31^[000`2][Jd0`kfc0<>m
/`030<>m/`80[Jf]0P11JN470:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00=0<O1_004045Y
h@37`K`0al6l0<O1_0@0@FWQ1@36`;`00`11JN40a/2l0<K0_0070<K0_0030:f][@11JN40`kfk00@0
`kfk0P11JN440<>m^`05045Yh@2][Jd0[Jf]0<>m^`2][Jd00P11JN440;ji^080@FWQ0P2n^KP01011
JN40_[Vh0;ji^02][Jd:0;B`/@030:f][@2OVj00[Jf]00D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo
0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2]
[Jd0RXEe0:f][@040:BNS`80@FWQ0`2TWXl2045Yh@030:f][@2aZid0@FWQ0080@FWQ0P2aZid01011
JN40/J^M0;6[W@2aZid2045Yh@80/J^M00<0[Jf]045Yh@11JN400P2][Jd30;VbYP03045Yh@2i/ZH0
@FWQ0080^K:V00@0@FWQ0;VbYP11JN40[Jf]1@2n]j`00`11JN40_[N/0;jg[0050;jg[080@FWQ102n
]j`00`2][Jd0@FWQ045Yh@0A0<6j/0030:f][@33_K<0`kfc00D0`kfc0P11JN470<>m/`/0[Jf]4@35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00<0<O1_080@FWQ0`37
`K`0102][Jd0@FWQ045Yh@11JN450<K0_003045Yh@36`;`0a/2l00L0a/2l00<0[Jf]045Yh@11JN40
1033_K/2045Yh@050<>m^`2][Jd0[Jf]0:f][@11JN400`33_K/00`2][Jd0@FWQ045Yh@040;ji^0@0
@FWQ0`2n^KP00`2][Jd0];2a0;B`/@080;B`/@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]
102TWXl2045Yh@<0Y9j?00<0@FWQ0:BNS`2][Jd0102aZid3045Yh@<0/J^M0P11JN420;6[W@030:f]
[@11JN40@FWQ0080^K:V0`2][Jd01011JN40^K:V045Yh@2i/ZH2045Yh@030;VbYP11JN40[Jf]00D0
_[N/00<0@FWQ0;jg[02n]j`01@2n]j`2045Yh@@0_[N/00<0[Jf]045Yh@11JN403@31^[001@11JN40
`KZ`0<6j/031^[00[Jf]00L0`kfc0P11JN4<0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00D0[Jf]0<O1
_037`K`0al6l045Yh@090<O1_080@FWQ1037`K`0102][Jd0a/2l045Yh@11JN450<K0_003045Yh@36
`;`0a/2l00L0a/2l00<0[Jf]045Yh@11JN401P11JN401@2][Jd0`kfk0<>m^`33_K/0@FWQ00<0`kfk
0P11JN450;ji^080@FWQ1@2n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C
00<0[Jf]08Z5M@2:QGD0102:QGD0102][Jd0Y9j?0:BNS`2TWXl3045Yh@<0Y9j?00<0@FWQ0:BNS`2]
[Jd02`2aZid01@11JN40/J^M0;6[W@2][Jd0@FWQ00H0^K:V00@0@FWQ0:f][@11JN40[Jf]0P11JN40
0`2i/ZH0@FWQ0:f][@050;jg[003045Yh@2n]j`0_[N/00D0_[N/0P11JN430;jg[0040:f][@31^[00
@FWQ045Yh@/0`KZ`0P11JN401@31^[00@FWQ045Yh@31^[00[Jf]00<0`kfc00@0@FWQ0<>m/`33_K<0
`kfc0P11JN4<0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`11JN40
[Jf]0<O1_0020<O1_003045Yh@37`K`0al6l00L0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045Y
h@D0a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0`kfk0<>m^`020<>m^`80[Jf]0P11JN440<>m
^`04045Yh@33_K/0`kfk0<>m^`80@FWQ1@2n^KP2045Yh@D0_[Vh00@0[Jf]0;B`/@2d/;40@FWQ1@2d
/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1S
H5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@80Y9j?0P11JN420:BNS`04045Yh@2TWXl0Y9j?0:f][@/0
/J^M00D0@FWQ0;6[W@2aZid0[Jf]045Yh@050;VbYP80@FWQ00<0^K:V045Yh@2i/ZH00P11JN400`2]
[Jd0@FWQ0:f][@040;jg[003045Yh@2n]j`0_[N/00H0_[N/0P11JN430;jg[0040:f][@31^[00@FWQ
045Yh@X0`KZ`0P11JN440<6j/080@FWQ00<0`kfc045Yh@11JN401033_K<2045Yh@80`kfc00<0@FWQ
0<>m/`33_K<01`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng<02][Jd;
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01038`K/2045Yh@@0b<6k0P11JN46
0<S1^`03045Yh@2][Jd0al6l0080al6l0P11JN480<O1_080@FWQ1037`K`0102][Jd0a/2l045Yh@11
JN450<K0_003045Yh@36`;`0a/2l00L0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd20<>m^`80@FWQ1033
_K/00`11JN40`kfk0<>m^`02045Yh@H0_[Vh0P11JN450;ji^0040:f][@2d/;40];2a045Yh@@0];2a
00@0[Jf]0;B`/@2d/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0
/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]00D0Y9j?045Y
h@11JN40Y9j?045Yh@020:BNS`030:f][@2aZid0/J^M00X0/J^M00@0@FWQ0;6[W@2][Jd0@FWQ1@2i
/ZH01011JN40^K:V0;VbYP2i/ZH3045Yh@040;VbYP11JN40[Jf]0:f][@<0_[N/00<0@FWQ0;jg[02n
]j`01P2n]j`2045Yh@<0_[N/00@0[Jf]0<6j/011JN40@FWQ2P31^[02045Yh@D0`KZ`0P11JN400`33
_K<0@FWQ0<>m/`030<>m/`@0@FWQ00<0`kfc045Yh@11JN401`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@80b<6k00@0@FWQ0<S1
^`38`K/0@FWQ2038`K/00`11JN40[Jf]0<O1_0020<O1_080@FWQ1`37`K`2045Yh@D0al6l00@0[Jf]
0<K0_011JN40@FWQ1@36`;`2045Yh@H0a/2l102][Jd50<>m^`03045Yh@33_K/0`kfk00<0`kfk1011
JN400`2][Jd0_[Vh0;ji^0040;ji^080@FWQ1@2n^KP0102][Jd0];2a0;B`/@11JN420;B`/@80[Jf]
0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00
E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00@0[Jf]0:BNS`2T
WXl0@FWQ0`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@80@FWQ1P2i/ZH01011JN40^K:V0;VbYP2i/ZH2
045Yh@80^K:V00<0@FWQ0:f][@2n]j`00`2][Jd00`11JN40_[N/0;jg[0060;jg[080@FWQ0`2n]j`0
102][Jd0`KZ`045Yh@11JN4:0<6j/080@FWQ1@31^[000`2][Jd0@FWQ045Yh@050<>m/`80@FWQ1033
_K<3045Yh@D0`kfc00<0[Jf]045Yh@11JN401011JN4@0<Fn]@030:f][@36_kL0a[ng0180a[ng00@0
00000<Jo]`36_kL0[Jf]5P37`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00X0b<6k
0`11JN470<S1^`030:f][@38`K/0b<6k0080@FWQ1@38`K/3045Yh@L0b<6k0`11JN420<O1_0<0@FWQ
1`37`K`2045Yh@D0al6l00@0[Jf]0<K0_011JN40@FWQ1@36`;`2045Yh@030<K0_02][Jd0[Jf]00<0
[Jf]0P36`;`00`2][Jd0@FWQ045Yh@040<>m^`03045Yh@33_K/0`kfk00<0`kfk00D0@FWQ0<>m^`33
_K/0`kfk0:f][@060;ji^080@FWQ1@2n^KP0102][Jd0];2a0;B`/@11JN420:f][@D0];2a00<0[Jf]
09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0
Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302a
Zid00`2][Jd0^K:V0;VbYP020;VbYP03045Yh@2i/ZH0@FWQ00<0^K:V0P11JN430;VbYP03045Yh@2n
]j`0_[N/0080_[N/00<0@FWQ0:f][@2][Jd00P2][Jd20;jg[0@0@FWQ0`2n]j`0102][Jd0`KZ`045Y
h@11JN4:0<6j/080@FWQ1@31^[000`2][Jd0@FWQ045Yh@050<>m/`80@FWQ1@33_K<2045Yh@D0`kfc
00<0[Jf]0<Fn]@35_[D00P11JN440<Fn]@L0@FWQ0P35_[D5045Yh@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0C0<O1^P@0@FWQ2038`K/4045Yh@T0b<6k
00@0[Jf]0<S1^`38`K/0@FWQ1`38`K/2045Yh@L0b<6k0`11JN420<O1_0<0@FWQ1`37`K`2045Yh@D0
al6l00<0[Jf]0<K0_011JN400`11JN420<K0_0040:f][@11JN40@FWQ0:f][@L0a/2l00<0[Jf]045Y
h@11JN401033_K/01011JN40`kfk0<>m^`33_K/2045Yh@@0`kfk00<0[Jf]0;ji^02n^KP0102n^KP2
045Yh@D0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`
KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BN
S`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00@0^K:V0P11
JN430;VbYP80@FWQ0`2i/ZH00`11JN40_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/0080_[N/102]
[Jd0202n]j`0@FWQ045Yh@11JN40_[N/0:f][@31^[00@FWQ2`31^[02045Yh@D0`KZ`00<0[Jf]045Y
h@11JN401@33_K<2045Yh@H0`kfc0P11JN440<>m/`030:f][@35_[D0aKje0080@FWQ1`35_[D2045Y
h@L0aKje1011JN470<Jo]`<0@FWQ2@36_kL01011JN40a[ng0<Jo]`2][JdF0<O1^0030:f][@37`KX0
al6j00h0al6j1@11JN420<O1^P040:f][@38`K/0@FWQ045Yh@P0b<6k0P11JN490<S1^`040:f][@38
`K/0@FWQ045Yh@L0b<6k0P11JN470<S1^`<0@FWQ0P37`K`2045Yh@030<O1_011JN40al6l00D0al6l
00<0@FWQ0<O1_037`K`01037`K`3045Yh@D0[Jf]00<0a/2l045Yh@11JN401036`;`01`11JN40a/2l
0<K0_036`;`0[Jf]0<>m^`11JN400`33_K/00`11JN40`kfk0<>m^`080<>m^`030:f][@2n^KP0_[Vh
00@0_[Vh0P11JN450;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]
0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0
[Jf]3@2aZid00`2][Jd0^K:V0;VbYP060;VbYP80@FWQ00<0^K:V045Yh@11JN400`2i/ZH00`11JN40
_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/00H0_[N/102][Jd00`2n]j`0[Jf]0<6j/002045Yh@/0
`KZ`00<0@FWQ0<6j/031^[000`31^[000`2][Jd0@FWQ045Yh@050<>m/`80@FWQ1P33_K<2045Yh@@0
`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80@FWQ1`35_[D2045Yh@030:f][@36_kL0a[ng00@0
a[ng0P11JN430<Jo]`80@FWQ1`36_kL00`11JN40a[ng0<Jo]`04045Yh@P0al6h00<0@FWQ0<O1^037
`KP02037`KP00`2][Jd0al6j0<O1^P0@0<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`02045Yh@L0
b<6k0P11JN490<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN470<S1^`<0@FWQ0P37`K`2045Y
h@030<O1_011JN40al6l00D0al6l00<0@FWQ0<O1_037`K`00P37`K`50:f][@H0a/2l0P11JN430<K0
_003045Yh@36`;`0@FWQ0080a/2l00<0[Jf]0<>m^`33_K/01011JN4:0<>m^`030:f][@2n^KP0_[Vh
00@0_[Vh0P11JN440;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]
0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@03
0:f][@2i/ZH0^K:V00`0^K:V0`11JN440;jg[003045Yh@2n]j`0_[N/00X0_[N/0`2][Jd2045Yh@/0
`KZ`00<0@FWQ0<6j/031^[000`31^[000`2][Jd0@FWQ045Yh@050<>m/`80@FWQ1P33_K<2045Yh@@0
`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80@FWQ1`35_[D2045Yh@030:f][@36_kL0a[ng00<0
a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40a[ng0<Jo]`040<Jo]`<0@FWQ00@0[Jf]0<O1^037
`KP0al6h0P11JN450<O1^003045Yh@37`KP0@FWQ00T0al6h00<0[Jf]0<O1^P37`KX04037`KX2045Y
h@<0al6j00H0[Jf]0<S1^`38`K/0@FWQ0<S1^`11JN460<S1^`80@FWQ2@38`K/0102][Jd0b<6k045Y
h@11JN470<S1^`80@FWQ1`38`K/00`11JN40b<6k045Yh@020<O1_080@FWQ00<0al6l045Yh@37`K`0
1@37`K`00`11JN40[Jf]0:f][@020:f][@80al6l00<0[Jf]0<K0_036`;`01P36`;`3045Yh@<0a/2l
0P11JN420<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0102n^KP2045Yh@80_[Vh
0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo
001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]2@2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP<0@FWQ0P2n]j`00`11JN40_[N/0;jg[00;0;jg[0040:f][@31
^[00@FWQ045Yh@L0[Jf]1@31^[02045Yh@<0`KZ`00<0[Jf]045Yh@11JN401@33_K<2045Yh@L0`kfc
0P11JN430<>m/`030:f][@35_[D0aKje0080@FWQ1`35_[D2045Yh@L0aKje0P11JN400`2][Jd0a[ng
0<Jo]`020<Jo]`80@FWQ1`36_kL00`11JN40a[ng0<Jo]`040<Jo]`04045Yh@36_kL0a[ng0:f][@D0
al6h00<0@FWQ0<O1^037`KP00`37`KP00`11JN40al6h0<O1^0080<O1^0030:f][@37`KX0al6j0100
al6j0P11JN430<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ1P38`K/2045Yh@T0b<6k00@0[Jf]0<S1
^`11JN40@FWQ1`38`K/2045Yh@H0b<6k0P11JN401038`K/0[Jf]045Yh@37`K`2045Yh@030<O1_011
JN40al6l00D0[Jf]00<0@FWQ0<O1_037`K`01037`K`00`2][Jd0a/2l0<K0_0060<K0_080@FWQ00D0
a/2l045Yh@36`;`0a/2l045Yh@030<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
0`2n^KP2045Yh@030;ji^02][Jd0[Jf]00<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P
09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2T
WXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/00/0_[N/00@0[Jf]0<6j/011JN40@FWQ
1`31^[070:f][@80@FWQ00@0`KZ`0:f][@11JN40@FWQ1@33_K<2045Yh@L0`kfc0P11JN430<>m/`03
0:f][@35_[D0aKje0080@FWQ1`35_[D2045Yh@L0aKje0P11JN400`2][Jd0a[ng0<Jo]`020<Jo]`80
@FWQ2036_kL00`11JN40a[ng0<Jo]`030<Jo]`04045Yh@36_kL0a[ng0:f][@D0al6h00<0@FWQ0<O1
^037`KP03`37`KP00`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ0`37`KX01`2][Jd0b<6k0<S1^`38`K/0
@FWQ0<S1^`11JN401@38`K/2045Yh@T0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@H0b<6k
0P11JN401@38`K/0[Jf]045Yh@37`K`0@FWQ00<0[Jf]00<0@FWQ0<O1_037`K`00`37`K`00`11JN40
al6l0<O1_0040<O1_0030:f][@36`;`0a/2l00H0a/2l0P11JN420<K0_080@FWQ1036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0
];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f]
[@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]
102aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`0
2`2n]j`01@2][Jd0`KZ`045Yh@31^[00@FWQ00<0`KZ`00<0@FWQ0<6j/031^[001`31^[020:f][@@0
@FWQ00<0[Jf]0<>m/`33_K<00P33_K<2045Yh@L0`kfc0P11JN430<>m/`030:f][@35_[D0aKje0080
@FWQ1`35_[D2045Yh@L0aKje0P11JN40102][Jd0a[ng0<Jo]`36_kL2045Yh@l0a[ng00@0@FWQ0<Jo
]`36_kL0[Jf]1@37`KP00`11JN40al6h0<O1^00?0<O1^0030:f][@37`KX0al6j00l0al6j0P11JN43
0<O1^P030:f][@38`K/0b<6k0080b<6k0P11JN450<S1^`80@FWQ2@38`K/00`2][Jd0b<6k0<S1^`02
045Yh@H0b<6k0P11JN460<S1^`80@FWQ0P2][Jd00`11JN40[Jf]045Yh@030<O1_003045Yh@37`K`0
al6l00<0al6l00<0@FWQ0<O1_037`K`01037`K`00`2][Jd0a/2l0<K0_0040<K0_0@0@FWQ2@36`;`0
0`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H0
0`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid3
0:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`00P2n]j`2045Yh@`0_[N/00D0[Jf]
0<6j/011JN40`KZ`045Yh@020<6j/080@FWQ1P31^[000`11JN40`KZ`0<6j/0030<6j/0040:f][@11
JN40@FWQ0<>m/`@0[Jf]0P11JN400`2][Jd0`kfc0<>m/`040<>m/`80@FWQ0`33_K<00`2][Jd0aKje
0<Fn]@02045Yh@L0aKje0P11JN470<Fn]@80@FWQ00@0[Jf]0<Jo]`36_kL0a[ng0P11JN4B0<Jo]`03
0:f][@37`KP0al6h0080al6h0P11JN4A0<O1^0030:f][@37`KX0al6j00l0al6j0P11JN430<O1^P03
0:f][@38`K/0b<6k0080b<6k0P11JN450<S1^`80@FWQ2@38`K/00`2][Jd0b<6k0<S1^`020<S1^`P0
@FWQ1P2][Jd2045Yh@030<S1^`2][Jd0@FWQ0080@FWQ0`37`K`00`11JN40al6l0<O1_0030<O1_003
045Yh@37`K`0al6l00@0al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`04
0:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nK
X0030:f][@2`h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0080
_[N/0P11JN470;jg[003045Yh@2n]j`0_[N/0080_[N/00<0@FWQ0<6j/011JN400P31^[001@11JN40
`KZ`045Yh@31^[00@FWQ00D0`KZ`00<0@FWQ0<6j/031^[000`31^[000`2][Jd0@FWQ045Yh@050<>m
/`80@FWQ00<0`kfc0:f][@2][Jd0102][Jd2045Yh@<0`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn
]@80@FWQ1`35_[D00`11JN40aKje0:f][@030<Jo]`80@FWQ4P36_kL00`2][Jd0al6h0<O1^003045Y
hA80al6h00<0[Jf]0<O1^P37`KX03`37`KX2045Yh@<0al6j00<0[Jf]0<S1^`38`K/00`38`K/00`11
JN40b<6k0<S1^`030<S1^`80@FWQ2@38`K/0102][Jd0b<6k0<S1^`38`K/70:f][@80@FWQ1P38`K/2
045Yh@030<S1^`2][Jd0@FWQ0080@FWQ0`37`K`00`11JN40al6l0<O1_0030<O1_003045Yh@37`K`0
al6l00@0al6l00@0[Jf]0<K0_036`;`0@FWQ4036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n
^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H2
0:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0
[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0@FWQ
0;jg[02n]j`00P2n]j`00`2][Jd0@FWQ045Yh@030<6j/004045Yh@31^[00@FWQ045Yh@D0`KZ`00<0
@FWQ0<6j/031^[000`31^[000`2][Jd0@FWQ0<>m/`050<>m/`80@FWQ1P33_K<2045Yh@030<>m/`2]
[Jd0[Jf]00@0[Jf]0P11JN400`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ1`35_[D00`11JN40aKje0:f]
[@030<Jo]`80@FWQ4P36_kL00`2][Jd0@FWQ045Yh@02045Yh@L0al6h00<0@FWQ0<O1^037`KP02@37
`KP00`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`030<S1^`03045Yh@38
`K/0b<6k00<0b<6k0P11JN440<S1^`T0[Jf]1`38`K/2045Yh@H0b<6k00D0@FWQ0<S1^`38`K/0[Jf]
0<O1_002045Yh@@0al6l00<0@FWQ0<O1_037`K`00P37`K`00`11JN40al6l0<O1_0040<O1_0040:f]
[@36`;`0a/2l045YhA00a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f]
[@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]
202i/ZH00`2][Jd0_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0@FWQ0;jg[02n]j`0
0P2n]j`00`2][Jd0`KZ`0<6j/0040<6j/080@FWQ1P31^[000`11JN40`KZ`0<6j/0030<6j/0030:f]
[@11JN40`kfc00D0`kfc0P11JN460<>m/`80@FWQ1033_K<00`2][Jd0aKje0<Fn]@02045Yh@030<Fn
]@2][Jd0[Jf]00@0[Jf]0P11JN440:f][@<0aKje00<0@FWQ0<Fn]@2][Jd00`36_kL2045YhA40a[ng
0P11JN400`37`KP0@FWQ0<O1^0080<O1^003045Yh@37`KP0al6h00T0al6h00<0[Jf]0<O1^P37`KX0
3`37`KX2045Yh@<0al6j00<0[Jf]0<S1^`38`K/00`38`K/00`11JN40[Jf]0:f][@030:f][@80@FWQ
102][Jd50<S1^`050:f][@38`K/0b<6k0<S1^`11JN401P38`K/00`11JN40b<6k0<S1^`040<S1^`80
@FWQ0P38`K/0102][Jd0al6l045Yh@11JN440<O1_0<0@FWQ0P37`K`2045Yh@H0al6l00<0[Jf]0<K0
_011JN404036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji
^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/00<0
_[N/0P11JN460;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]0<6j/031^[003@31^[03045Yh@80
`KZ`00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@H0`kfc0P11JN440<>m/`030:f][@35_[D0aKje0080
@FWQ1`35_[D2045Yh@@0aKje0`2][Jd00`11JN40[Jf]0:f][@030:f][@80@FWQ1P2][Jd20<Jo]`03
045Yh@36_kL0a[ng00D0a[ng00@0@FWQ0<Jo]`11JN40@FWQ2P37`KP00`11JN40al6h0<O1^0090<O1
^0030:f][@37`KX0al6j00T0al6j1P2][Jd2045Yh@T0[Jf]00<0@FWQ0<S1^`38`K/00`38`K/3045Y
h@@0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@020<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`04
0<S1^`80@FWQ0P38`K/01@2][Jd0al6l045Yh@11JN40al6l00<0@FWQ1@37`K`2045Yh@H0al6l00<0
[Jf]0<K0_011JN404036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H0
0`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH4
0:f][@030;VbYP2][Jd0_[N/00D0_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[002
0;jg[0030:f][@31^[00`KZ`0100`KZ`0P11JN400`2][Jd0`kfc0<>m/`050<>m/`<0@FWQ1033_K<2
045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80@FWQ1`35_[D00`11JN40aKje0:f][@04
0<Jo]`80@FWQ1@36_kL00`2][Jd0@FWQ045Yh@060:f][@03045Yh@2][Jd0@FWQ00`0[Jf]00<0@FWQ
0:f][@2][Jd05@2][Jd60<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`030<S1^`03045Yh@38`K/0
b<6k00<0b<6k0`11JN430<S1^`03045Yh@38`K/0@FWQ0080b<6k00<0[Jf]0<S1^`38`K/00P11JN45
0<S1^`03045Yh@38`K/0b<6k00<0b<6k1P11JN400`2][Jd0al6l0<O1_00:0<O1_080@FWQ1P37`K`0
0`2][Jd0a/2l045Yh@0@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][Jd50;jg[080@FWQ102n]j`2045Y
h@@0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`020<>m/`D0@FWQ00<0`kfc045Y
h@11JN400P33_K<2045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D00P11JN460<Fn]@80@FWQ2035_[D00`11
JN40aKje0:f][@040<Jo]`80@FWQ1P36_kL00`11JN40a[ng045Yh@050<Jo]`80@FWQ00<0a[ng0:f]
[@37`KP01037`KP00`11JN40al6h0<O1^0030<O1^003045Yh@37`KP0al6h00T0al6h00<0[Jf]0<O1
^P37`KX03`37`KX2045Yh@<0al6j00<0[Jf]0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`030<S1
^`<0@FWQ0`38`K/00`11JN40b<6k045Yh@020<S1^`050:f][@38`K/0b<6k0<S1^`11JN400`38`K/2
045Yh@`0b<6k00<0[Jf]0<O1_037`K`02P37`K`00`11JN40al6l045Yh@050<O1_0030:f][@11JN40
@FWQ00h0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40
0`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd20;jg[0D0@FWQ00<0_[N/045Y
h@2n]j`00`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00X0`kfc0P11JN470<>m
/`030:f][@35_[D0aKje00@0@FWQ1035_[D2045Yh@P0aKje00<0@FWQ0<Fn]@2][Jd01@36_kL00`11
JN40a[ng0<Jo]`050<Jo]`80@FWQ1036_kL2045Yh@80a[ng00<0[Jf]0<O1^037`KP00P37`KP2045Y
h@D0al6h00<0@FWQ0<O1^037`KP02@37`KP00`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ0`37`KX00`2]
[Jd0b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN400`38`K/0@FWQ0<S1^`020<S1
^`05045Yh@38`K/0b<6k0<S1^`2][Jd01038`K/3045Yh@h0b<6k00<0[Jf]0<O1_037`K`02`37`K`2
045Yh@D0al6l00<0[Jf]045Yh@11JN402@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/0
0`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3P
iP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`00`2n]j`40:f][@@0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00P11JN420<Fn]@@0@FWQ2P35_[D00`11
JN40aKje0:f][@050<Jo]`80@FWQ1P36_kL00`11JN40a[ng0<Jo]`030<Jo]`05045Yh@36_kL0a[ng
0<Jo]`2][Jd01037`KP2045Yh@D0al6h00<0@FWQ0<O1^037`KP02@37`KP00`2][Jd0al6j0<O1^P0?
0<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN42
0<S1^`@0@FWQ0`38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00`0al6l00<0@FWQ
0<O1_037`K`00`37`K`00`11JN40a/2l045Yh@050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=
0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y
0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje0080@FWQ3@35_[D4045Yh@030<Fn]@2][Jd0a[ng00D0a[ng00<0@FWQ
0<Jo]`36_kL00`36_kL00`11JN40a[ng0<Jo]`050<Jo]`04045Yh@36_kL0a[ng0:f][@<0al6h0`11
JN440<O1^080@FWQ2`37`KP00`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1
^`030<S1^`04045Yh@38`K/0b<6k0<S1^`80@FWQ2`38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00d0al6l1@11JN400`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][E80/>3V0@3oool006/0/>3V
0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg
[02][Jd0`KZ`01<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@02045YhA80aKje
00<0[Jf]0<Jo]`36_kL01@36_kL5045Yh@T0a[ng1P11JN420<O1^003045Yh@37`KP0al6h0080al6h
0`11JN4:0<O1^0030:f][@37`KX0al6j00l0al6j0P11JN430<O1^P030:f][@38`K/0b<6k0080b<6k
0P11JN4@0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04037`K`50:f][A00a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`
h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0080@FWQ4P35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00P0al6h0`11JN4:0<O1^0030:f][@37`KX0al6j00l0al6j0P11
JN430<O1^P030:f][@38`K/0b<6k0080b<6k0P11JN4@0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2]
[Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00P11JN4B0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02037`KP3045Yh@X0al6h00<0[Jf]0<O1^P37`KX03`37
`KX2045Yh@<0al6j00<0[Jf]0<S1^`38`K/00P38`K/00`11JN40b<6k0<S1^`0?0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`60:f][@L0al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40oooo001a
0;3PiP<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[002031^[070:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@02
045YhA80aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0080<O1^0<0@FWQ2P37`KP0
0`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ0`37`KX0102][Jd0b<6k0<S1^`38`K/2045YhA40b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d
0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[003`31^[070:f][A80`kfc00<0[Jf]0<Fn]@35_[D00P11JN4B0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP02037`KP3045Yh@X0al6h00<0[Jf]0<O1^P37`KX03`37`KX2
045Yh@<0al6j00D0[Jf]0<S1^`38`K/0b<6k045Yh@0B0<S1^`030:f][@38`K/0b<6k0100b<6k1P2]
[JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2]
[Jd;0<>m/`030:f][@35_[D0aKje0080@FWQ3`35_[D01011JN40aKje0<Fn]@2][JdG0<Jo]`030:f]
[@37`KP0al6h00P0al6h0`11JN4:0<O1^0030:f][@37`KX0al6j00l0al6j0P11JN430<O1^P030:f]
[@38`K/0b<6k0080@FWQ4P38`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33
_K<5045Yh@l0aKje0P11JN400`35_[D0[Jf]0<Jo]`0F0<Jo]`030:f][@37`KP0al6h00P0al6h0`11
JN4:0<O1^0030:f][@37`KX0al6j00l0al6j0P11JN430<O1^P040:f][@38`K/0b<6k045YhA<0b<6k
00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc
2@2][Jd>0<Fn]@04045Yh@35_[D0aKje0:f][AL0a[ng00<0[Jf]0<O1^037`KP02037`KP2045Yh@/0
al6h00<0[Jf]0<O1^P37`KX03`37`KX2045Yh@030<O1^P11JN40@FWQ00<0@FWQ3`38`K/90:f][A80
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0
`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]
1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00T0al6h00<0@FWQ0<O1^037`KP0
2@37`KP00`2][Jd0al6j0<O1^P0=0<O1^PD0@FWQ0P37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]
1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[DA0:f][@@0a[ng00<000000<Jo]`36_kL01@36_kL00`2][Jd0al6h0<O1
^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H3
0:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_
0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0
_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][GH0
/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jej0;3PiP40oooo
002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H10?ooo`00V@2`h>H5
0:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0[Jf]4@31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3PiP40oooo002T0;3PiPL0
[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l1`2][Jf;0;3PiP40
oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l0<O1_0L0
[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo002i0;3PiPL0[Jf]2`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38
`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool00<P0/>3V2@2][JdA
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0[Jf]1@35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37`KXG0:f]
[Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51876 .3309 m
.50873 .33082 L
s
.53882 .33079 m
.52879 .33089 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50539 .33077 m
.49371 .33054 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49871 .33168 m
.49871 .33065 L
s
.50038 .33071 m
.50038 .33069 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.513 .33858 m
.51797 .34086 L
s
.50969 .33854 m
.513 .33858 L
s
.53287 .33857 m
.53453 .34306 L
s
.53287 .33857 m
.53288 .34759 L
s
.50638 .34076 m
.50969 .33854 L
s
.50472 .34073 m
.50969 .33854 L
s
.53618 .34079 m
.53949 .3385 L
s
.53949 .3385 m
.5461 .33838 L
s
.51797 .34086 m
.52128 .34538 L
s
.5461 .33838 m
.54942 .34056 L
s
.53453 .34306 m
.53618 .34079 L
s
.50306 .34521 m
.50638 .34076 L
s
.5014 .34518 m
.50472 .34073 L
s
.48162 .33788 m
.49316 .33824 L
s
.53288 .34759 m
.53453 .34306 L
s
.54942 .34056 m
.55108 .34278 L
s
.50138 .35196 m
.50306 .34521 L
s
.49973 .35193 m
.5014 .34518 L
s
.56425 .33786 m
.56591 .34006 L
s
.56261 .34018 m
.56425 .33786 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56261 .34018 m
.56427 .34238 L
s
.46357 .33709 m
.47504 .33763 L
s
.56427 .34238 m
.56591 .34006 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54945 .34959 m
.55109 .34729 L
s
.55108 .34278 m
.5511 .34955 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54614 .35192 m
.54945 .34959 L
s
.54945 .35185 m
.5511 .34955 L
s
.50137 .35648 m
.50138 .35196 L
s
.49972 .35645 m
.49973 .35193 L
s
.53787 .35658 m
.54614 .35192 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49774 .36149 m
.49816 .35908 L
s
.5003 .35999 m
.5003 .35916 L
s
.49862 .36097 m
.49863 .3591 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48808 .36977 m
.48821 .3381 L
s
.48642 .36972 m
.48656 .33805 L
s
.46996 .3623 m
.47012 .33741 L
s
.46831 .36222 m
.46848 .33733 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54615 .35418 m
.54945 .35185 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52372 .38865 m
.52378 .38902 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53787 .35884 m
.54615 .35418 L
s
.53456 .35888 m
.53787 .35658 L
s
.51962 .35893 m
.52128 .3612 L
s
.51796 .36119 m
.51962 .35893 L
s
.50137 .35648 m
.50301 .3633 L
s
.49972 .35645 m
.50136 .36327 L
s
.5329 .36116 m
.53456 .35888 L
s
.53456 .36114 m
.53787 .35884 L
s
.52128 .36346 m
.52128 .3612 L
s
.51796 .36119 m
.51962 .36346 L
s
.5329 .36116 m
.5329 .36569 L
s
.44566 .336 m
.45704 .33673 L
s
.5329 .36342 m
.53456 .36114 L
s
.51795 .36799 m
.52128 .36346 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5495 .36543 m
.55114 .36086 L
s
.55114 .36086 m
.55117 .36993 L
s
.50301 .3633 m
.50632 .36789 L
s
.50136 .36327 m
.50466 .36786 L
s
.5329 .36569 m
.53457 .36794 L
s
.51463 .37024 m
.51795 .36799 L
s
.53457 .36794 m
.53789 .37017 L
s
.50632 .36789 m
.50964 .3702 L
s
.54785 .36774 m
.5495 .36543 L
s
.5495 .36543 m
.55117 .36993 L
s
.50466 .36786 m
.50964 .3702 L
s
.50964 .3702 m
.51463 .37024 L
s
0 0 0 r
.45367 .3611 m
.45432 .35988 L
s
.255 .412 .882 r
.54454 .37007 m
.54785 .36774 L
s
.53789 .37017 m
.54454 .37007 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48146 .36956 m
.48808 .36977 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46828 .36676 m
.46996 .3623 L
s
.41066 .31713 m
.42174 .31824 L
s
.46664 .36669 m
.46831 .36222 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5644 .36728 m
.56447 .38092 L
s
.56282 .38098 m
.56433 .35367 L
s
.56433 .35367 m
.56612 .38086 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46334 .3688 m
.46828 .36676 L
s
.41635 .36549 m
.41698 .31778 L
s
.46334 .3688 m
.46664 .36669 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41476 .36534 m
.41539 .31762 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42633 .3345 m
.43112 .33717 L
s
.43112 .33717 m
.43428 .34196 L
s
.43428 .34196 m
.43582 .34889 L
s
.42633 .3345 m
.42951 .33704 L
s
.42951 .33704 m
.43267 .34183 L
s
.61856 .33454 m
.63446 .33304 L
s
.48637 .38109 m
.48802 .38342 L
s
.4847 .38332 m
.48637 .38109 L
s
.42314 .33421 m
.42633 .3345 L
s
.46006 .36864 m
.46334 .3688 L
s
.43267 .34183 m
.43421 .34877 L
s
.56282 .38098 m
.56449 .38548 L
s
.48635 .38565 m
.48802 .38342 L
s
.45194 .36135 m
.45517 .36609 L
s
.45517 .36609 m
.46006 .36864 L
s
.4847 .38332 m
.48635 .38565 L
s
.56449 .38548 m
.56612 .38086 L
s
.41992 .33619 m
.42314 .33421 L
s
.43577 .35343 m
.43582 .34889 L
s
.43416 .35331 m
.43421 .34877 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43408 .36013 m
.43577 .35343 L
s
.41668 .34043 m
.41992 .33619 L
s
.43247 .36001 m
.43416 .35331 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43081 .36444 m
.43408 .36013 L
s
.63446 .33304 m
.63765 .33498 L
s
.63446 .33304 m
.63922 .33481 L
s
.4292 .36431 m
.43247 .36001 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4501 .38405 m
.45053 .33633 L
s
.45174 .38414 m
.45215 .33643 L
s
.40571 .33249 m
.40728 .33265 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62494 .33397 m
.62555 .38184 L
s
.62335 .33411 m
.62394 .38198 L
s
.44521 .38374 m
.45174 .38414 L
s
.63765 .33498 m
.64086 .33919 L
s
.40254 .33441 m
.40571 .33249 L
s
.40411 .33459 m
.40571 .33249 L
s
.42596 .36633 m
.43081 .36444 L
s
.63922 .33481 m
.64243 .33902 L
s
.42596 .36633 m
.4292 .36431 L
s
.40247 .33896 m
.40411 .33459 L
s
.4009 .33879 m
.40254 .33441 L
s
.42275 .36606 m
.42596 .36633 L
s
.64086 .33919 m
.6425 .34357 L
s
.64243 .33902 m
.64407 .3434 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41958 .36349 m
.42275 .36606 L
s
.40223 .35492 m
.40247 .33896 L
s
.41644 .35864 m
.41958 .36349 L
s
.39784 .33388 m
.4009 .33879 L
s
.39476 .33124 m
.39784 .33388 L
s
.40059 .35933 m
.4009 .33879 L
s
.39011 .33067 m
.39476 .33124 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6425 .34357 m
.64417 .35024 L
s
.64407 .3434 m
.64574 .35007 L
s
.6517 .33111 m
.6625 .32974 L
s
.41 .36488 m
.41635 .36549 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38698 .33256 m
.39011 .33067 L
s
.38544 .33236 m
.39011 .33067 L
s
.61912 .38238 m
.63512 .38097 L
s
.64417 .35024 m
.64434 .36167 L
s
.64574 .35007 m
.64591 .3615 L
s
0 0 0 r
.36344 .31921 m
.36436 .31934 L
s
.255 .412 .882 r
.40059 .35933 m
.40223 .35492 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38981 .34892 m
.39913 .3523 L
s
.39913 .3523 m
.40066 .35475 L
s
.38537 .33692 m
.38698 .33256 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38383 .33672 m
.38544 .33236 L
s
.39899 .36145 m
.40059 .35933 L
s
.64287 .36871 m
.64434 .36167 L
s
.38529 .34149 m
.38537 .33692 L
s
.64444 .36854 m
.64591 .3615 L
s
.39582 .36339 m
.39899 .36145 L
s
.38375 .34129 m
.38383 .33672 L
s
.64136 .37346 m
.64287 .36871 L
s
.38676 .34625 m
.38981 .34892 L
s
.38521 .34606 m
.38981 .34892 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38529 .34149 m
.38676 .34625 L
s
.63512 .38097 m
.63826 .37837 L
s
.63512 .38097 m
.63985 .37821 L
s
.64294 .37329 m
.64444 .36854 L
s
.63826 .37837 m
.64136 .37346 L
s
.38375 .34129 m
.38521 .34606 L
s
.63985 .37821 m
.64294 .37329 L
s
.38959 .36267 m
.39582 .36339 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65819 .3486 m
.65985 .35528 L
s
.65789 .33034 m
.65842 .36235 L
s
.65634 .33053 m
.65687 .36254 L
s
.6522 .36309 m
.65842 .36235 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38506 .35522 m
.3866 .35541 L
s
.38656 .3577 m
.3866 .35541 L
s
.65985 .35528 m
.66301 .35948 L
s
.38653 .36 m
.38959 .36267 L
s
.38502 .35751 m
.38506 .35522 L
s
.38502 .35751 m
.38653 .36 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66301 .35948 m
.66613 .36138 L
s
.35384 .32537 m
.36423 .32705 L
s
.66613 .36138 m
.67072 .36077 L
s
.66911 .35638 m
.67068 .35847 L
s
.66911 .35638 m
.67059 .35388 L
s
.67059 .35388 m
.67216 .35597 L
s
.68373 .32895 m
.68814 .32594 L
s
.68233 .33376 m
.68373 .32895 L
s
.68233 .33376 m
.68242 .33835 L
s
.68522 .32871 m
.68814 .32594 L
s
.68382 .33353 m
.68522 .32871 L
s
.67216 .35597 m
.6722 .35827 L
s
.37128 .35339 m
.37276 .3559 L
s
.37272 .3582 m
.37276 .3559 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36972 .35548 m
.37128 .35339 L
s
.68382 .33353 m
.68391 .33812 L
s
.67072 .36077 m
.6722 .35827 L
s
.68242 .33835 m
.684 .34271 L
s
.68814 .32594 m
.69257 .3252 L
s
.37115 .36029 m
.37272 .3582 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35911 .35853 m
.35975 .32634 L
s
.35762 .3583 m
.35827 .3261 L
s
.36972 .35548 m
.3712 .35799 L
s
.68391 .33812 m
.6855 .34248 L
s
.36661 .35965 m
.37115 .36029 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.684 .34271 m
.68852 .34431 L
s
.69257 .3252 m
.69555 .32699 L
s
.6855 .34248 m
.68852 .34431 L
s
.36365 .3569 m
.36661 .35965 L
s
.35938 .34471 m
.36074 .35184 L
s
.36074 .35184 m
.36365 .3569 L
s
.68419 .35191 m
.68423 .35422 L
s
.68419 .35191 m
.68568 .35169 L
s
.69555 .32699 m
.69857 .33108 L
s
.68852 .34431 m
.69741 .34516 L
s
.68423 .35422 m
.68577 .3563 L
s
.68568 .35169 m
.68573 .35399 L
s
.68577 .3563 m
.6888 .35814 L
s
.34466 .34227 m
.34506 .32384 L
s
.69992 .32622 m
.70277 .3234 L
s
.69857 .33108 m
.69992 .32622 L
s
.35316 .3576 m
.35911 .35853 L
s
.34321 .34201 m
.34361 .32358 L
s
.70138 .32596 m
.70277 .3234 L
s
.70003 .33082 m
.70138 .32596 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70277 .3234 m
.70421 .32313 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33887 .34123 m
.34904 .34302 L
s
.34068 .32535 m
.34346 .33048 L
s
.33643 .32223 m
.34068 .32535 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69741 .34516 m
.69892 .34722 L
s
.6888 .35814 m
.69472 .3572 L
s
.70003 .33082 m
.70038 .34696 L
s
.69857 .33108 m
.69902 .35184 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69472 .3572 m
.69761 .3544 L
s
.33358 .32168 m
.33643 .32223 L
s
.69902 .35184 m
.70038 .34696 L
s
.69761 .3544 m
.69902 .35184 L
s
.33069 .32342 m
.33358 .32168 L
s
.32928 .32314 m
.33358 .32168 L
s
.344 .37239 m
.34431 .35846 L
s
.3427 .36517 m
.34431 .35846 L
s
.32776 .32747 m
.33069 .32342 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32636 .32719 m
.32928 .32314 L
s
.71702 .32063 m
.72341 .35195 L
s
.71212 .35415 m
.71702 .32063 L
s
0 0 0 r
.72718 .31192 m
.72815 .31387 L
s
.255 .412 .882 r
.33969 .36932 m
.3427 .36517 L
s
.3427 .36517 m
.344 .37239 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71355 .35389 m
.71719 .32756 L
s
0 0 0 r
.72729 .31622 m
.72815 .31387 L
s
.255 .412 .882 r
.32625 .33182 m
.32776 .32747 L
s
.70782 .35494 m
.7178 .35307 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32485 .33153 m
.32636 .32719 L
s
.32468 .33848 m
.32625 .33182 L
s
.33531 .37088 m
.33969 .36932 L
s
0 0 0 r
.32167 .34473 m
.32177 .34081 L
s
.255 .412 .882 r
.32328 .3382 m
.32485 .33153 L
s
0 0 0 r
.32167 .34473 m
.32199 .34647 L
s
.255 .412 .882 r
.3244 .3501 m
.32468 .33848 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33244 .37036 m
.33531 .37088 L
s
.323 .34982 m
.32328 .3382 L
s
.32965 .36751 m
.33244 .37036 L
s
.32823 .36724 m
.33244 .37036 L
s
.3244 .3501 m
.32563 .35737 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72941 .36942 m
.72967 .37366 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72341 .35195 m
.72813 .31826 L
s
.7248 .35167 m
.7283 .32521 L
s
.32693 .3623 m
.32965 .36751 L
s
.32563 .35737 m
.32693 .3623 L
s
.323 .34982 m
.32423 .35709 L
s
.32552 .36203 m
.32823 .36724 L
s
.32423 .35709 m
.32552 .36203 L
s
.3087 .3163 m
.31327 .35013 L
s
.30248 .34769 m
.3087 .3163 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30919 .34923 m
.31739 .35101 L
s
.30382 .348 m
.30852 .32327 L
s
0 0 0 r
.72886 .37822 m
.72967 .37366 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73033 .35051 m
.73848 .34871 L
s
.72813 .31826 m
.73442 .34962 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29811 .31368 m
.30248 .34769 L
s
.29201 .34512 m
.29811 .31368 L
s
.74575 .32111 m
.74824 .31578 L
s
.74457 .3261 m
.74575 .32111 L
s
.74344 .33343 m
.74457 .3261 L
s
.74824 .31578 m
.75205 .31243 L
s
.74344 .33343 m
.74376 .34513 L
s
.74706 .32078 m
.74954 .31544 L
s
.74588 .32577 m
.74706 .32078 L
s
.74476 .33311 m
.74588 .32577 L
s
.2933 .34545 m
.29792 .32067 L
s
.74954 .31544 m
.75205 .31243 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74476 .33311 m
.74508 .34481 L
s
.75205 .31243 m
.75461 .31174 L
s
.74376 .34513 m
.74527 .35185 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74508 .34481 m
.74659 .35154 L
s
.75461 .31174 m
.75848 .31302 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74527 .35185 m
.74672 .35624 L
s
.74659 .35154 m
.74804 .35592 L
s
.28816 .34413 m
.29721 .34642 L
s
.28533 .31022 m
.28658 .31057 L
s
.74672 .35624 m
.74948 .36032 L
s
.75848 .31302 m
.76113 .317 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28276 .31184 m
.28533 .31022 L
s
.28401 .3122 m
.28533 .31022 L
s
.74804 .35592 m
.75078 .36 L
s
.76092 .30997 m
.76147 .32874 L
s
.28263 .31653 m
.28401 .3122 L
s
.76217 .30961 m
.76272 .32839 L
s
.74948 .36032 m
.75345 .36172 L
s
.28139 .31618 m
.28276 .31184 L
s
.75078 .36 m
.75345 .36172 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28363 .33199 m
.28367 .33173 L
s
.5 Mabswid
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28214 .33299 m
.28263 .31653 L
s
.27906 .31076 m
.28139 .31618 L
s
.28075 .33736 m
.28139 .31618 L
s
.75345 .36172 m
.75602 .36108 L
s
.27669 .30767 m
.27906 .31076 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75769 .32978 m
.76644 .32733 L
s
.27307 .30655 m
.27669 .30767 L
s
.75602 .36108 m
.75978 .35773 L
s
.28075 .33736 m
.28214 .33299 L
s
.76953 .30742 m
.77787 .30476 L
s
.27973 .32993 m
.28089 .33264 L
s
.27249 .32541 m
.27973 .32993 L
s
.27945 .33937 m
.28075 .33736 L
s
.75978 .35773 m
.76217 .35233 L
s
.76321 .34489 m
.76363 .35909 L
s
.76217 .35233 m
.76321 .34489 L
s
.27062 .30815 m
.27307 .30655 L
s
.26943 .30777 m
.27307 .30655 L
s
.76217 .35233 m
.76363 .35909 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27691 .34103 m
.27945 .33937 L
s
.26928 .31248 m
.27062 .30815 L
s
.27205 .3396 m
.27691 .34103 L
s
.26811 .3121 m
.26943 .30777 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77433 .30591 m
.77536 .33899 L
s
.77314 .30629 m
.77416 .33936 L
s
.27018 .3223 m
.27249 .32541 L
s
.26899 .32193 m
.27249 .32541 L
s
.26914 .3172 m
.26928 .31248 L
s
.77054 .34043 m
.77536 .33899 L
s
.26796 .31683 m
.26811 .3121 L
s
.26914 .3172 m
.27018 .3223 L
s
.77492 .32478 m
.77633 .33151 L
s
.26796 .31683 m
.26899 .32193 L
s
.26973 .33651 m
.27205 .3396 L
s
.26869 .3314 m
.26988 .33177 L
s
.26981 .33414 m
.26988 .33177 L
s
.77633 .33151 m
.77884 .33552 L
s
.26862 .33377 m
.26869 .3314 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26862 .33377 m
.26973 .33651 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77884 .33552 m
.78125 .33715 L
s
0 0 0 r
.25018 .29447 m
.25101 .29355 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78125 .33715 m
.78472 .33602 L
s
.78342 .33164 m
.78464 .33364 L
s
.78342 .33164 m
.78449 .32888 L
s
.78449 .32888 m
.78571 .33088 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78571 .33088 m
.78579 .33326 L
s
.78472 .33602 m
.78579 .33326 L
s
.24605 .29694 m
.25356 .29986 L
s
.25827 .32799 m
.25933 .33076 L
s
.25925 .33314 m
.25933 .33076 L
s
.25706 .32999 m
.25827 .32799 L
s
.25804 .33514 m
.25925 .33314 L
s
.25706 .32999 m
.25811 .33276 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25467 .33398 m
.25804 .33514 L
s
.79282 .3067 m
.79375 .30154 L
s
.79282 .3067 m
.79298 .31146 L
s
.79375 .30154 m
.79689 .29791 L
s
.79298 .31146 m
.79423 .31582 L
s
.79391 .30629 m
.79483 .30112 L
s
.79391 .30629 m
.79407 .31105 L
s
.79483 .30112 m
.79689 .29791 L
s
.79407 .31105 m
.79531 .31541 L
s
.79689 .29791 m
.80006 .29665 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24918 .33202 m
.2503 .29862 L
s
.2481 .33162 m
.24923 .2982 L
s
.25253 .33081 m
.25467 .33398 L
s
.79423 .31582 m
.79754 .31698 L
s
.79531 .31541 m
.79754 .31698 L
s
.25051 .32524 m
.25253 .33081 L
s
.24966 .31767 m
.25051 .32524 L
s
.79455 .32536 m
.79463 .32775 L
s
.79455 .32536 m
.79563 .32496 L
s
.79463 .32775 m
.79579 .32975 L
s
.79563 .32496 m
.79571 .32735 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80006 .29665 m
.80222 .29818 L
s
.79579 .32975 m
.79803 .33134 L
s
.2449 .33041 m
.24918 .33202 L
s
.80222 .29818 m
.80444 .3021 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80444 .3021 m
.80529 .29689 L
s
.80529 .29689 m
.80722 .29363 L
s
.80546 .30167 m
.8063 .29646 L
s
.8063 .29646 m
.80722 .29363 L
s
.80959 .27558 m
.81625 .27236 L
s
.23961 .30154 m
.24046 .30676 L
s
.24046 .30676 m
.24123 .31437 L
s
.23777 .29589 m
.23961 .30154 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80546 .30167 m
.80605 .31846 L
s
.80444 .3021 m
.80519 .32368 L
s
.79803 .33134 m
.80226 .32973 L
s
.79754 .31698 m
.80392 .3169 L
s
.80722 .29363 m
.80822 .29319 L
s
.24082 .32637 m
.24123 .31437 L
s
.80392 .3169 m
.80503 .31888 L
s
.23861 .30111 m
.23945 .30633 L
s
.23945 .30633 m
.24021 .31395 L
s
.23678 .29545 m
.23861 .30111 L
s
.80226 .32973 m
.80425 .3265 L
s
.2349 .29217 m
.23777 .29589 L
s
.23979 .32596 m
.24021 .31395 L
s
.2349 .29217 m
.23678 .29545 L
s
.80425 .3265 m
.80519 .32368 L
s
.23954 .33318 m
.24082 .32637 L
s
.81249 .27421 m
.8143 .3247 L
s
.80519 .32368 m
.80605 .31846 L
s
.22549 .28765 m
.2349 .29217 L
s
.23852 .33277 m
.23979 .32596 L
s
.81344 .27375 m
.81526 .32427 L
s
.23835 .3376 m
.23954 .33318 L
s
.23734 .33719 m
.23852 .33277 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23616 .34161 m
.23835 .3376 L
s
.23516 .3412 m
.23734 .33719 L
s
.8143 .29773 m
.81602 .29202 L
s
.22732 .34028 m
.22917 .28948 L
s
.81602 .29202 m
.81779 .28871 L
s
.81139 .32598 m
.81526 .32427 L
s
.23309 .3428 m
.23616 .34161 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22639 .33986 m
.22824 .28902 L
s
.23309 .3428 m
.23516 .3412 L
s
.81779 .28871 m
.81961 .28779 L
s
.815 .31702 m
.81707 .32099 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81961 .28779 m
.8215 .28928 L
s
.81961 .28779 m
.82239 .28882 L
s
.22362 .33857 m
.23309 .3428 L
s
.81707 .32099 m
.81902 .32254 L
s
.8215 .28928 m
.82345 .29319 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82239 .28882 m
.82433 .29272 L
s
.81902 .32254 m
.82086 .32166 L
s
.82345 .29319 m
.8246 .29999 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82433 .29272 m
.82546 .29953 L
s
.82086 .32166 m
.82258 .31835 L
s
.82086 .32166 m
.82347 .3179 L
s
.8246 .29999 m
.82478 .30485 L
s
.82258 .31835 m
.82417 .31259 L
s
.82417 .31259 m
.82478 .30485 L
s
.82546 .29953 m
.82565 .30439 L
s
.82347 .3179 m
.82505 .31214 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82505 .31214 m
.82565 .30439 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82995 .28215 m
.83547 .27875 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83315 .28021 m
.83513 .33162 L
s
.83237 .2807 m
.83434 .33207 L
s
.83419 .30706 m
.83594 .31102 L
s
.83191 .33343 m
.83513 .33162 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83845 .27677 m
.84334 .27325 L
s
.83594 .31102 m
.83831 .31207 L
s
.84059 .27527 m
.84166 .30229 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84129 .27477 m
.84236 .3018 L
s
.83831 .31207 m
.83979 .31112 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84764 .26842 m
.84785 .26681 L
s
.255 .412 .882 r
.83979 .31112 m
.84114 .3077 L
s
.83979 .31112 m
.84185 .30722 L
s
.84114 .3077 m
.84166 .30229 L
s
.84185 .30722 m
.84236 .3018 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84781 .26967 m
.84921 .30432 L
s
.84595 .27121 m
.85018 .26759 L
s
.84842 .26915 m
.84982 .30383 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84733 .3058 m
.84982 .30383 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8492 .31975 m
.84971 .31677 L
s
.8492 .31975 m
.84992 .32176 L
s
.84971 .31677 m
.85043 .31878 L
s
.84992 .32176 m
.85043 .31878 L
s
.85325 .27241 m
.85408 .26639 L
s
.85302 .28039 m
.85325 .27241 L
s
.85302 .28039 m
.85322 .28536 L
s
.85377 .27188 m
.85459 .26586 L
s
.85355 .27987 m
.85377 .27188 L
s
.85408 .26639 m
.85548 .26231 L
s
.85322 .28536 m
.85406 .29233 L
s
.85355 .27987 m
.85376 .28485 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85459 .26586 m
.85548 .26231 L
s
.85376 .28485 m
.85459 .29182 L
s
.85406 .29233 m
.85531 .29631 L
s
.85548 .26231 m
.85642 .26124 L
s
.85459 .29182 m
.85582 .2958 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85642 .26124 m
.85788 .26212 L
s
.85531 .29631 m
.85692 .29728 L
s
.85582 .2958 m
.85692 .29728 L
s
.1877 .26499 m
.18826 .26303 L
s
.18791 .25999 m
.18826 .26303 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18737 .26195 m
.18791 .25999 L
s
.18737 .26195 m
.1877 .26499 L
s
.85788 .26212 m
.85895 .26604 L
s
.85692 .29728 m
.85834 .29574 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18638 .30817 m
.18718 .27749 L
s
.18549 .30716 m
.18718 .27749 L
s
.85834 .29574 m
.85914 .29219 L
s
.85882 .28465 m
.85915 .28162 L
s
.85882 .28465 m
.85936 .28664 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85915 .28162 m
.85968 .2836 L
s
.18593 .30767 m
.18656 .29255 L
s
.85914 .29219 m
.85979 .28612 L
s
.85968 .2836 m
.85979 .28612 L
s
.18572 .31272 m
.18638 .30817 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18419 .25761 m
.18445 .26066 L
s
.18413 .2682 m
.18445 .26066 L
s
.18549 .30716 m
.18572 .31272 L
s
.1836 .254 m
.18419 .25761 L
s
.86134 .25472 m
.86189 .2592 L
s
.86134 .25472 m
.86176 .26477 L
s
.18377 .26766 m
.18424 .26569 L
s
.18366 .27018 m
.18413 .2682 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86486 .26543 m
.86524 .27453 L
s
.86456 .26812 m
.86487 .27538 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18232 .25179 m
.1836 .254 L
s
.18296 .2691 m
.18377 .26766 L
s
.86189 .2592 m
.86176 .26477 L
s
.86189 .2592 m
.86213 .25613 L
s
.18286 .27162 m
.18366 .27018 L
s
.86213 .25613 m
.86267 .25251 L
s
.18303 .28532 m
.1836 .2808 L
s
.18318 .29091 m
.1836 .2808 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18117 .27145 m
.18296 .2691 L
s
.86267 .25251 m
.86384 .25029 L
s
.8624 .2799 m
.86264 .27684 L
s
.8624 .2799 m
.86261 .28496 L
s
.18303 .28532 m
.18318 .29091 L
s
.18106 .27399 m
.18286 .27162 L
s
.18256 .28732 m
.18303 .28532 L
s
.8625 .28243 m
.86274 .27937 L
s
.86264 .27684 m
.8632 .27324 L
s
.86261 .28496 m
.86306 .28696 L
s
.86274 .27937 m
.86331 .27577 L
s
.18163 .2532 m
.18232 .25179 L
s
.18177 .2888 m
.18256 .28732 L
s
.8632 .27324 m
.86448 .26546 L
s
.86306 .28696 m
.86384 .28844 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86596 .30106 m
.86627 .30839 L
s
.86626 .2984 m
.86665 .30757 L
s
.5 Mabswid
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86331 .27577 m
.86459 .268 L
s
.18125 .25517 m
.18163 .2532 L
s
.86384 .25029 m
.86448 .25171 L
s
.18052 .28668 m
.18177 .2888 L
s
.86384 .28844 m
.86506 .28632 L
s
.1812 .24956 m
.18125 .25517 L
s
.18077 .25968 m
.18125 .25517 L
s
.18077 .25968 m
.1812 .24956 L
s
.1805 .2729 m
.18117 .27145 L
s
.18039 .27544 m
.18106 .27399 L
s
.86448 .25171 m
.86483 .25368 L
s
.86448 .26546 m
.86491 .26183 L
s
.86459 .268 m
.86501 .26437 L
s
.86483 .25368 m
.86516 .26128 L
s
.86491 .26183 m
.86505 .25875 L
s
.18012 .2749 m
.1805 .2729 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18006 .28307 m
.18052 .28668 L
s
.86501 .26437 m
.86516 .26128 L
s
.18001 .27745 m
.18039 .27544 L
s
.86506 .28632 m
.86551 .2827 L
s
.1799 .27999 m
.18012 .2749 L
s
.1799 .27999 m
.18006 .28307 L
s
.86551 .2827 m
.86566 .27962 L
s
.86566 .27962 m
.8657 .27399 L
s
.86566 .27962 m
.86613 .28418 L
s
.8657 .27399 m
.86613 .28418 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17915 .24705 m
.17929 .25326 L
s
.86619 .24723 m
.86625 .24412 L
s
.86619 .24723 m
.86646 .24921 L
s
.17879 .24281 m
.17915 .24705 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86625 .24412 m
.86651 .2461 L
s
.86646 .24921 m
.86651 .2461 L
s
.17842 .27365 m
.17853 .2711 L
s
.17845 .268 m
.17853 .2711 L
s
.17784 .27769 m
.17842 .27365 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17817 .27001 m
.17845 .268 L
s
.17853 .24168 m
.17879 .24281 L
s
.17817 .27001 m
.17823 .27311 L
s
.17821 .24309 m
.17853 .24168 L
s
.17811 .24253 m
.17853 .24168 L
s
.1774 .27917 m
.17784 .27769 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86701 .26196 m
.86815 .29326 L
s
.86701 .26196 m
.86849 .29219 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86767 .27731 m
.86833 .29272 L
s
.17781 .24708 m
.17821 .24309 L
s
.86815 .29326 m
.86855 .29787 L
s
.177 .27754 m
.1774 .27917 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17774 .24651 m
.17811 .24253 L
s
.86849 .29219 m
.86855 .29787 L
s
.17741 .25421 m
.17781 .24708 L
s
.17689 .27387 m
.177 .27754 L
s
.17679 .27333 m
.177 .27754 L
s
.17735 .25365 m
.17774 .24651 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17689 .27387 m
.17693 .26763 L
s
.17719 .25935 m
.17741 .25421 L
s
.17693 .26763 m
.17719 .25935 L
s
.17679 .27333 m
.17686 .26708 L
s
.17712 .2588 m
.17735 .25365 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17686 .26708 m
.17712 .2588 L
s
.17803 .23194 m
.17786 .23597 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17631 .27043 m
.17787 .23425 L
s
.17634 .26988 m
.17789 .23367 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17647 .26822 m
.17631 .27043 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17564 .28603 m
.17555 .2881 L
s
.17564 .28603 m
.17578 .28289 L
s
.1757 .28495 m
.17578 .28289 L
s
.17555 .2881 m
.1757 .28495 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17763 .25596 m
.17806 .24581 L
s
.17749 .25652 m
.17794 .24602 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17542 .21558 m
.17785 .21009 L
s
.17785 .21009 m
.17963 .20609 L
s
.255 .412 .882 r
.1774 .26119 m
.17749 .25652 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17756 .26063 m
.17763 .25596 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17442 .25426 m
.17593 .25087 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17258 .2925 m
.17599 .2138 L
s
.17279 .29196 m
.1762 .21321 L
s
.17444 .28912 m
.17622 .28548 L
s
.17201 .29411 m
.17444 .28912 L
s
.17528 .26597 m
.17658 .23583 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17866 .22861 m
.17928 .20668 L
s
.17866 .22861 m
.17963 .20609 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18675 .21187 m
.18732 .21113 L
s
0 0 0 r
.17587 .28602 m
.1772 .26264 L
s
.17622 .28548 m
.1772 .26264 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18357 .20394 m
.18519 .1984 L
s
.18279 .21207 m
.18357 .20394 L
s
.18101 .25384 m
.18279 .21207 L
s
.18404 .20335 m
.18519 .1984 L
s
.18325 .21149 m
.18404 .20335 L
s
.18148 .25328 m
.18325 .21149 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18519 .1984 m
.18621 .19723 L
s
.255 .412 .882 r
.18519 .24901 m
.18576 .2483 L
s
0 0 0 r
.17969 .2555 m
.18148 .25328 L
s
.18621 .19723 m
.18768 .19925 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18576 .2483 m
.18682 .24453 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18768 .19925 m
.1885 .20569 L
s
.18898 .19429 m
.1914 .19196 L
s
.18675 .24776 m
.18898 .19429 L
s
.18734 .24721 m
.18957 .19371 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85653 .26288 m
.85926 .26587 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18504 .24941 m
.18734 .24721 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19422 .20052 m
.19593 .19172 L
s
.19307 .21258 m
.19422 .20052 L
s
.19593 .19172 m
.19827 .18617 L
s
.19491 .19994 m
.19665 .19114 L
s
.19375 .21201 m
.19491 .19994 L
s
.19275 .22025 m
.19307 .21258 L
s
.19665 .19114 m
.19827 .18617 L
s
.19343 .21969 m
.19375 .21201 L
s
.19275 .22025 m
.19296 .23125 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19827 .18617 m
.19978 .18502 L
s
.19343 .21969 m
.19365 .2307 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19978 .18502 m
.20198 .18715 L
s
.19296 .23125 m
.19404 .23787 L
s
.19365 .2307 m
.19476 .23733 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20198 .18715 m
.2033 .19372 L
s
.19404 .23787 m
.19608 .24012 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19476 .23733 m
.19608 .24012 L
s
.19608 .24012 m
.19837 .2385 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20058 .22189 m
.20155 .21747 L
s
.20058 .22189 m
.20124 .22523 L
s
.20155 .21747 m
.20222 .2208 L
s
.19837 .2385 m
.20012 .23354 L
s
.20892 .17878 m
.21546 .17489 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20206 .22469 m
.20222 .2208 L
s
.20012 .23354 m
.20206 .22469 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83245 .18392 m
.83324 .18059 L
s
.83215 .17617 m
.83324 .18059 L
s
.83135 .17949 m
.83215 .17617 L
s
.83135 .17949 m
.83245 .18392 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20845 .25913 m
.21165 .17711 L
s
.20939 .25862 m
.21259 .17655 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21945 .1727 m
.22686 .16891 L
s
.22049 .22592 m
.22255 .17106 L
s
.82331 .17512 m
.8245 .17956 L
s
.8245 .17956 m
.82494 .19126 L
s
.82104 .17015 m
.82331 .17512 L
s
.22155 .22541 m
.22361 .17052 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2057 .26065 m
.20939 .25862 L
s
.81666 .16801 m
.82104 .17015 L
s
.8239 .19073 m
.82479 .18736 L
s
.82404 .19464 m
.82494 .19126 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83412 .2268 m
.83503 .25038 L
s
.8332 .20335 m
.83407 .24987 L
s
.8332 .20335 m
.83598 .25089 L
s
.82192 .19359 m
.8239 .19073 L
s
.83534 .25827 m
.83598 .25089 L
s
.82206 .19751 m
.82404 .19464 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81455 .17086 m
.81666 .16801 L
s
.255 .412 .882 r
.23408 .1786 m
.23419 .17855 L
s
0 0 0 r
.83407 .24987 m
.83534 .25827 L
s
.81669 .19885 m
.82192 .19359 L
s
.82493 .21819 m
.82568 .21085 L
s
.82568 .21085 m
.82628 .22659 L
s
.81684 .20279 m
.82206 .19751 L
s
.21736 .22745 m
.22155 .22541 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81354 .17425 m
.81455 .17086 L
s
.82402 .22162 m
.82493 .21819 L
s
.82493 .21819 m
.82628 .22659 L
s
.8121 .16589 m
.81354 .17425 L
s
.8121 .16589 m
.81267 .18158 L
s
.81267 .18158 m
.81354 .17425 L
s
.82201 .22455 m
.82402 .22162 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23322 .17749 m
.23586 .1686 L
s
.23163 .18979 m
.23322 .17749 L
s
.23586 .1686 m
.23961 .16313 L
s
.81455 .20177 m
.81669 .19885 L
s
.23439 .17697 m
.23705 .16809 L
s
.23279 .18928 m
.23439 .17697 L
s
.81756 .22254 m
.82201 .22455 L
s
.23134 .19767 m
.23163 .18979 L
s
.81469 .20572 m
.81684 .20279 L
s
.23705 .16809 m
.23961 .16313 L
s
.21853 .25015 m
.21974 .24569 L
s
.21853 .25015 m
.21944 .25363 L
s
.8012 .16124 m
.80616 .16329 L
s
.21974 .24569 m
.22066 .24916 L
s
.2325 .19716 m
.23279 .18928 L
s
.23961 .16313 m
.24207 .1621 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23134 .19767 m
.23207 .20901 L
s
.81353 .20522 m
.81455 .20177 L
s
.21944 .25363 m
.22066 .24916 L
s
.2325 .19716 m
.23325 .20852 L
s
.81368 .20917 m
.81469 .20572 L
s
.24207 .1621 m
.24444 .16502 L
s
.81353 .20522 m
.81382 .21313 L
s
.81513 .21759 m
.81756 .22254 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23207 .20901 m
.23415 .21595 L
s
.81382 .21313 m
.81513 .21759 L
s
.24444 .16502 m
.24671 .1719 L
s
.23325 .20852 m
.23535 .21546 L
s
.24712 .16007 m
.25235 .15807 L
s
.7988 .16417 m
.80162 .17306 L
s
.79477 .15872 m
.7988 .16417 L
s
.23415 .21595 m
.23764 .21846 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24423 .24362 m
.24712 .16007 L
s
.24553 .24317 m
.24841 .15957 L
s
.23535 .21546 m
.23764 .21846 L
s
.79212 .15773 m
.79477 .15872 L
s
.78956 .1607 m
.79212 .15773 L
s
.7882 .16022 m
.79212 .15773 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8012 .16124 m
.80315 .21668 L
s
.80246 .16175 m
.80441 .21716 L
s
.23764 .21846 m
.24012 .21749 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78847 .16814 m
.78956 .1607 L
s
.24012 .21749 m
.24277 .21254 L
s
.79929 .21525 m
.80441 .21716 L
s
.78709 .16766 m
.7882 .16022 L
s
.24277 .21254 m
.24561 .20362 L
s
.78847 .16814 m
.78993 .21199 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26037 .1591 m
.2619 .15466 L
s
.26037 .1591 m
.26164 .16259 L
s
.2619 .15466 m
.26317 .15815 L
s
.78709 .16766 m
.78855 .21154 L
s
.26164 .16259 m
.26317 .15815 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24039 .24501 m
.24553 .24317 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26082 .23018 m
.26098 .18248 L
s
.258 .23106 m
.26098 .18248 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76642 .14922 m
.77681 .15244 L
s
.77241 .15104 m
.77418 .20708 L
s
.78435 .21018 m
.78993 .21199 L
s
.2594 .23062 m
.2602 .20647 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77093 .15058 m
.77268 .20665 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74912 .14441 m
.76026 .14743 L
s
.258 .23106 m
.25914 .2387 L
s
.25914 .2387 m
.26082 .23018 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76814 .20537 m
.77418 .20708 L
s
.75395 .14569 m
.75524 .18991 L
s
.75554 .14612 m
.75684 .19032 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7307 .13995 m
.74255 .14275 L
s
.77357 .23498 m
.77494 .23135 L
s
.77331 .22687 m
.77494 .23135 L
s
.77193 .23051 m
.77331 .22687 L
s
.73753 .14153 m
.73906 .19814 L
s
.77193 .23051 m
.77357 .23498 L
s
.75548 .198 m
.75684 .19032 L
s
.73583 .14113 m
.73735 .19776 L
s
.75387 .19759 m
.75524 .18991 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75073 .20085 m
.75548 .198 L
s
.75073 .20085 m
.75387 .19759 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74744 .20006 m
.75073 .20085 L
s
.74233 .19483 m
.74744 .20006 L
s
.255 .412 .882 r
.31589 .18368 m
.31607 .18334 L
s
0 0 0 r
.73873 .18594 m
.74233 .19483 L
s
.71674 .14097 m
.72051 .14978 L
s
.71123 .13586 m
.71674 .14097 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72051 .14978 m
.72259 .16229 L
s
.71495 .14061 m
.71873 .14942 L
s
.71123 .13586 m
.71495 .14061 L
s
.73219 .19665 m
.73906 .19814 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72259 .16229 m
.72279 .17041 L
s
.70759 .13516 m
.71123 .13586 L
s
.71873 .14942 m
.72081 .16193 L
s
.704 .13851 m
.70759 .13516 L
s
.70215 .13817 m
.70759 .13516 L
s
.72081 .16193 m
.72101 .17005 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72132 .18226 m
.72279 .17041 L
s
.71953 .18191 m
.72101 .17005 L
s
.70048 .14595 m
.704 .13851 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69861 .14562 m
.70215 .13817 L
s
.71793 .18972 m
.72132 .18226 L
s
.69888 .15782 m
.70048 .14595 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.697 .1575 m
.69861 .14562 L
s
.67344 .12945 m
.68699 .13153 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71259 .1928 m
.71793 .18972 L
s
.71613 .18938 m
.71953 .18191 L
s
.71259 .1928 m
.71613 .18938 L
s
.69888 .15782 m
.69906 .16598 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.697 .1575 m
.69718 .16566 L
s
.69906 .16598 m
.70121 .17856 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70892 .19214 m
.71259 .1928 L
s
.69718 .16566 m
.69933 .17824 L
s
.70512 .18739 m
.70892 .19214 L
s
.70326 .18707 m
.70892 .19214 L
s
.70121 .17856 m
.70512 .18739 L
s
.69933 .17824 m
.70326 .18707 L
s
.6515 .12653 m
.66555 .12833 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67929 .13032 m
.68099 .21653 L
s
.68122 .13062 m
.68295 .2168 L
s
.255 .412 .882 r
.65718 .1571 m
.65724 .15684 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37099 .16876 m
.37102 .16717 L
s
.36909 .16772 m
.36909 .16739 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63518 .12878 m
.63943 .13739 L
s
.62889 .12407 m
.63518 .12878 L
s
.62889 .12407 m
.6331 .12857 L
s
.62471 .12367 m
.62889 .12407 L
s
.6331 .12857 m
.63736 .13718 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63943 .13739 m
.64167 .14992 L
s
.62057 .12738 m
.62471 .12367 L
s
.61847 .1272 m
.62471 .12367 L
s
.56238 .09109 m
.57756 .09175 L
s
.63736 .13718 m
.63961 .1497 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61646 .13522 m
.62057 .12738 L
s
.61434 .13504 m
.61847 .1272 L
s
.64167 .14992 m
.64179 .15814 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63961 .1497 m
.63973 .15792 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65956 .12754 m
.66106 .214 L
s
.65756 .12728 m
.65903 .21376 L
s
.63991 .17029 m
.64179 .15814 L
s
.61448 .14738 m
.61646 .13522 L
s
.63784 .17008 m
.63973 .15792 L
s
.61236 .14721 m
.61434 .13504 L
s
.67508 .21574 m
.68295 .2168 L
s
.58426 .1207 m
.58861 .12504 L
s
.57993 .12047 m
.58426 .1207 L
s
.58426 .1207 m
.59076 .12517 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57562 .12436 m
.57993 .12047 L
s
.58861 .12504 m
.59299 .13352 L
s
.59076 .12517 m
.59514 .13365 L
s
.63588 .17815 m
.63991 .17029 L
s
.61448 .14738 m
.61458 .15562 L
s
.59514 .13365 m
.5974 .14614 L
s
.63379 .17795 m
.63784 .17008 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61236 .14721 m
.61246 .15546 L
s
.59299 .13352 m
.59525 .146 L
s
.57132 .13239 m
.57562 .12436 L
s
.54501 .11925 m
.55816 .11958 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61458 .15562 m
.61685 .16819 L
s
.51864 .11904 m
.53183 .11907 L
s
.61246 .15546 m
.61472 .16802 L
s
.62966 .1817 m
.63588 .17815 L
s
.5974 .14614 m
.59748 .1544 L
s
.59525 .146 m
.59533 .15426 L
s
.62966 .1817 m
.63379 .17795 L
s
.61685 .16819 m
.62118 .17682 L
s
.59544 .16668 m
.59748 .1544 L
s
.61472 .16802 m
.61907 .17665 L
s
.62546 .18133 m
.62966 .1817 L
s
.59328 .16655 m
.59533 .15426 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65291 .21308 m
.66106 .214 L
s
.62118 .17682 m
.62546 .18133 L
s
.61907 .17665 m
.62546 .18133 L
s
.255 .412 .882 r
.52553 .15737 m
.5263 .15778 L
s
.56979 .1703 m
.56991 .17015 L
s
.56763 .17022 m
.56843 .16918 L
s
.54808 .16094 m
.55024 .15809 L
s
.55024 .15809 m
.55242 .16104 L
s
.53 .15736 m
.53066 .1578 L
s
.53284 .16072 m
.53066 .1578 L
s
.53066 .1607 m
.5263 .15778 L
s
0 0 0 r
.52745 .14377 m
.54728 .14401 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4918 .15747 m
.49195 .15998 L
s
.49103 .15944 m
.49116 .15748 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55039 .16373 m
.55242 .16104 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58902 .1746 m
.59328 .16655 L
s
.53857 .19377 m
.55159 .1194 L
s
.59119 .17472 m
.59544 .16668 L
s
.5689 .09135 m
.56941 .17785 L
s
.57107 .09144 m
.5716 .17794 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58471 .17853 m
.59119 .17472 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57153 .16546 m
.57595 .17396 L
s
.58471 .17853 m
.58902 .1746 L
s
.57595 .17396 m
.58035 .17832 L
s
.58035 .17832 m
.58471 .17853 L
s
.56282 .17762 m
.5716 .17794 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52303 .11903 m
.5386 .20635 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5386 .20635 m
.55378 .11945 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU40030?nU40@00000503oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]ZP2`h>H1
0?ooo`00_02`h>H70:f][A80ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@00H0ojD@1P00000?0?nU40030:f][@3oXa00oj<@01H0oj<@1`2][JfS0;3P
iP40oooo002f0;3PiPH0[Jf]6@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA001P3oYA02000001<0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00H0ojD@
0P00000C0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001@3lX1050:f][IT0/>3V
0@3oool00:`0/>3V1@2][Jd70?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00H0ojD@0P00000C0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1002P3lX1060:f][I<0/>3V0@3oool00:H0/>3V1P2][Jd<
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@00H0ojD@0P00000C0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00H0ojD@0P00000C0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1040:f]
[HX0/>3V0@3oool009d0/>3V102][JdG0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00H0ojD@0P00000C0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0:f][@030:f][HH0
/>3V0@3oool009T0/>3V102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00H0ojD@
0P00000D0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU40060?nU40800000503oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][Gh0/>3V0@3oool00980/>3V0`2][Jd9
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001P3oYA02000001@0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00/0mY`?102][Jej
0;3PiP40oooo002>0;3PiP@0[Jf]303oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00H0ojD@0P00000D0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU40060?nU40800000503oYA000`2][Jd0oj<@0?nS400I0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][G<0/>3V0@3oool008L0/>3V
0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001P3oYA02000001@0ojD@
00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P2][Jd00P2][Je`0;3PiP40oooo00240;3PiP<0[Jf]00<0o:0@0:f][@3oY140503o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400<0?nV40P000001@3oYQ05000000L0ojD@0P00000D0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D
0?nV4AP0[Jf]00<000000:f][@2][Jd0302][Jd4000000@0[Jf]0P0000040:f][@<000003@3oYA00
0`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ401@3oYQ4?0:f][@L0ojHA00<0[Jf]0?nV403oYQ003P3oYQ000`000000ojH@0?nV400;0?nV
40030:f][@000000000000H0ojD@0P0000030?nU40040000003oYA00[Jf]0:f][@800000402][JdG
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P07
0>bF3P<0[Jf]J02`h>H10?ooo`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdF0?nV4@030:f][@3oYQ00ojH@
00l0ojH@00<000000?nV403oYQ002P3oYQ000`000000ojD@000000060?nU408000000P3oYA000`00
0000ojD@0?nU40030?nU408000002P3oYA000`2][Jd0oj<@0?nS40020?nS40@000001@2][Jd>0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01/0
ojHA00<0[Jf]0?nV403oYQ003`3oYQ000`000000ojH@0?nV400:0?nV408000001`3oYA0200000003
0?nU40000000ojD@00D0ojD@0P00000:0?nU40030:f][@3oXa00oj<@00<000000`3oXa02000000<0
oj<@1@2][Jd4000000030:f][@3oXa00oj<@0080oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]
3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400?0?nV40030000
003oYQ00ojH@00X0ojH@0P0000070?nU4080000000<0ojD@0000003oYA001P3oYA02000000T0ojD@
00@0[Jf]0?nS4000000000001P3oXa02000000X0oj<@1@0000030:f][@8000005`3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]
4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA1`2][JdH0?nV4@030:f]
[@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ003`3oYQ000`000000ojH@0?nV400:0?nV40800000
1`3oYA03000000P0ojD@0P0000090?nU40040:f][@3oXa000000000000H0oj<@0P00000:0?nS4080
0000103oXa00102][Jd0o:0@0?bP402][Jd4000000030:f][@3lX100o:0@0100o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@D0[Jf]0P3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ003`3oYQ000`000000
ojH@0?nV400:0?nV408000001`3oYA03000000T0ojD@0P0000080?nU40030:f][@000000000000P0
oj<@0P0000090?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP4080000000<0o:0@00000000
0000102][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0
fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]1`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ003`3oYQ000`000000ojH@
0?nV400:0?nV408000001`3oYA02000000X0ojD@0P0000080?nU40030:f][@000000000000P0oj<@
0P0000090?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP408000001`3lX1050:f][@030000
003lX100o:0@00D0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@0100ojH@00<0
00000?nV403oYQ00203oYQ000`000000[Jf]000000080?nU408000002@3oYA02000000P0ojD@00<0
[Jf]0000000000002@3oXa02000000P0oj<@0P0000040?nS40030:f][@3lX100o:0@0080o:0@0P00
000;0?bP40040000002][Jd00000000000<0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0
[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0
[Jf]0?nV4@3oYQ401@2][JdB0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400@0?nV40030000003oYQ00ojH@00P0ojH@0P0000090?nU408000002@3o
YA02000000P0ojD@00<0[Jf]0000000000002@3oXa02000000P0oj<@0P0000040?nS40030:f][@3l
X100o:0@0080o:0@0P00000:0?bP408000000`3lX102000000030?bP402][Jd0[Jf]0080[Jf]5@3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/
0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A102][JdG
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400@
0?nV40030000003oYQ00ojH@00P0ojH@0P0000090?nU408000002@3oYA02000000P0ojD@0P00000:
0?nS40030000003oXa00000000L0oj<@0P0000040?nS40030:f][@3lX100o:0@0080o:0@0P000009
0?bP408000001@3lX10200000080o:0@00@0[Jf]0?JL3`2][Jd0[Jf]0`00000@0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd9
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@0100ojH@00<000000?nV403oYQ00203oYQ02000000T0ojD@0P00000:0?nU408000001`3oYA02
000000X0oj<@00<000000?nS400000001`3oXa02000000@0oj<@00<0[Jf]0?bP403lX1000P3lX102
000000T0o:0@0P0000050?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`D00000303fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3P
iP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@0100ojH@3@0000090?nU408000002P3oYA02000000L0ojD@0P00000;0?nS
408000001`3oXa02000000@0oj<@00<0[Jf]0?bP403lX1000P3lX102000000P0o:0@0P0000070?bP
4080000000<0o:0@0:f][@3fW0l0103fW0l200000080mY`?0`2][Jd3000000L0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0
/>3V00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0
oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0140ojH@00<000000?nV403oYQ001P3oYQ000`000000
ojH@000000090?nU408000002P3oYA02000000L0ojD@0P00000;0?nS408000001`3oXa02000000@0
oj<@00<0[Jf]0?bP403lX1000P3lX102000000P0o:0@0P0000070?bP4080000000<0o:0@0:f][@3f
W0l0103fW0l2000000H0mY`?00<0[Jf]0000000000000`0000030?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
4@3oYQ000`000000ojH@0?nV40060?nV4080000000<0[Jf]0?nU403oYA001`3oYA02000000X0ojD@
0P0000070?nU408000002`3oXa000`000000oj<@000000060?nS408000001@3oXa00102][Jd0o:0@
0?bP403lX102000000P0o:0@0P0000080?bP4080000000<0[Jf]0?JL3`3fW0l00`3fW0l2000000L0
mY`?0P0000000`3fW0l0[Jf]0:f][@020:f][@8000004P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400A0?nV40030000
003oYQ00ojH@00H0ojH@0P0000000`2][Jd0ojD@0?nU40070?nU408000002P3oYA02000000L0ojD@
0P00000;0?nS40030000003oXa00000000H0oj<@0P0000050?nS40040:f][@3lX100o:0@0?bP4080
0000203lX102000000P0o:0@0P0000000`2][Jd0mY`?0?JL3`030?JL3`8000001`3fW0l2000000D0
mY`?0P2][Jd200000100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3P
iP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f]
[AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ004@3oYQ000`000000ojH@0?nV40060?nV4080000000<0[Jf]0?nU
403oYA001`3oYA02000000X0ojD@00<000000?nU400000001P3oYA02000000/0oj<@00<000000?nS
400000001P3oXa02000000D0oj<@00@0[Jf]0?bP403lX100o:0@0P0000070?bP408000002@3lX102
000000030:f][@3fW0l0mY`?00<0mY`?0P0000070?JL3`8000001P3fW0l00`2][Jd0000000000002
000000h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3o
ool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00X0o:0@00H0
00000?bP402][Jd0[Jf]0?bP402][JdF0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0140ojH@00<000000?nV403o
YQ001P3oYQ02000000030:f][@3oYA00ojD@00L0ojD@0P00000:0?nU40030000003oYA00000000H0
ojD@0P00000;0?nS40030000003oXa00000000H0oj<@0P0000050?nS40040:f][@3lX100o:0@0?bP
408000001`3lX102000000T0o:0@0P0000000`2][Jd0mY`?0?JL3`030?JL3`8000001`3fW0l20000
00H0mY`?00<0[Jf]0000000000000P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1000`2][Jd000000:f][@030?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@03
0:f][@3oYQ40ojHA01D0ojHA6`2][Jd00`000000[Jf]0:f][@050:f][@030000002][Jd0000000P0
[Jf]0P3oYA02000000X0ojD@00<000000?nU400000001P3oYA02000000`0oj<@0P0000060?nS4080
00001@3oXa00102][Jd0o:0@0?bP403lX102000000L0o:0@0P00000:0?bP40030000002][Jd0mY`?
00@0mY`?0P0000070?JL3`8000001P3fW0l00`2][Jd00000000000040>bF3P<0[Jf]2@3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?oo
o`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100103lX10300000080[Jf]00<0o:0@0000000000000`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00
[Jf]1`3oYQ400`2][Jd0ojH@0?nV400B0?nV40030000003oYQ00ojH@00@0ojH@0P0000000`3oYQ00
[Jf]0?nU40060?nU4080[Jf]0P00000:0:f][@030000002][Jd0000000H0ojD@0P00000<0?nS4080
00001P3oXa02000000D0oj<@00@0[Jf]0?bP403lX100o:0@0P0000070?bP408000002P3lX1020000
00D0mY`?0P0000070?JL3`8000001P3fW0l00`2][Jd00000000000070>bF3P040:f][@0000000000
000000D0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0
/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00<0o:0@0P0000020:f][@<0o:0@00<000000?bP403lX1000P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4<0:f]
[AL0ojHA00<0[Jf]0?nV4011JN404P3oYQ000`000000ojH@0?nV40040?nV4080000000<0ojH@0:f]
[@3oYA00203oYA02000000T0ojD@00<000000?nU400000001`2][Jd2000000<0[Jf]2@3oXa020000
00H0oj<@0P0000050?nS40040:f][@3lX100o:0@0?bP408000001`3lX102000000X0o:0@0P000005
0?JL3`8000001`3fW0l2000000H0mY`?00<0[Jf]0000000000001P3/UPh200000080k9H>00@0[Jf]
0000003/UPh000000P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0
[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP400000000P0000000`2][Jd00000000000050?bP40030000003lX100
o:0@0080o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40
ojHA00`0ojHA2@2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ004P3oYQ00
0`000000ojH@0?nV40040?nV4080000000<0ojH@0:f][@3oYA00203oYA02000000T0ojD@00<00000
0?nU400000001`3oYA000`2][Jd000000?nS40020?nS40T0[Jf]0P0000060?nS408000001@3oXa00
102][Jd0o:0@0?bP403lX102000000L0o:0@0P00000:0?bP408000001@3fW0l2000000L0mY`?0P00
00060?JL3`030:f][@000000000000H0k9H>0P0000030>bF3P030000002][Jd000000080000000<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3o
ool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40050:f][@3lX100
00000:f][@3lX1000`00000:0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603o
YQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@0180ojH@00<000000?nV403oYQ00103oYQ02000000030?nV402][Jd0ojD@00P0ojD@0P00
00090?nU40030000003oYA00000000L0ojD@00<0[Jf]0000000000002P3oXa02000000L0[Jf]0P00
00000`2][Jd0oj<@0?nS40020?nS40040:f][@3lX100o:0@0?bP408000001`3lX102000000X0o:0@
0P0000050?JL3`8000001`3fW0l2000000H0mY`?00<0[Jf]0000000000001P3/UPh2000000@0k9H>
0`0000020:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2]
[Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0000003lX1000P3lX103000000X0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]5`3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@0180ojH@00<000000?nV403oYQ00103oYQ02000000030?nV402]
[Jd0ojD@00P0ojD@0P0000090?nU40030000003oYA00000000L0ojD@00<0[Jf]0000000000002P3o
Xa02000000L0oj<@0P0000000`3oXa00[Jf]0:f][@060:f][@8000001`3lX102000000X0o:0@0P00
00050?JL3`8000001`3fW0l2000000H0mY`?00<0[Jf]0000000000001P3/UPh2000000@0k9H>0`00
0000103/UPh0[Jf]0:f][@00000;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo
001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40070>nH40030000003_V100[Jf]0080[Jf]00@0
00000?bP403lX100o:0@0`00000:0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
403oYQ460:f][@80ojHA0P11JN4J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
4`3oYQ000`000000ojH@0?nV40020?nV40050000003oYQ0000000?nV402][Jd0203oYA001011JN40
00000000000000070?nU40030000003oYA00000000P0ojD@00<0[Jf]0000000000002P3oXa020000
00L0oj<@0P0000050?nS40040:f][@3lX100o:0@0?bP40800000102][Jd30?bP408000002P3lX102
000000D0mY`?0P0000070?JL3`8000001P3fW0l00`2][Jd00000000000060>bF3P800000103/UPh3
000000040>bF3P2][Jd0fhX=00000080[Jf]00<000000=^:3@3KRPd01P3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h0
0`2][Jd0kiP@0>nH40050>nH408000000P2][Jd20>nH40800000103lX102000000X0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203oYQ400`2][Jd0ojHA0?nV4@0I
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ004`3oYQ000`000000ojH@0?nV4002
0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40070?nU40<000001`3oYA02000000T0ojD@00<0[Jf]
0000000000002P3oXa02000000P0oj<@00<000000?nS403oXa000`3oXa00102][Jd0o:0@0?bP403l
X102000000@0o:0@0`2][Jd200000080[Jf]203lX102000000H0mY`?00<000000?JL3`3fW0l01P3f
W0l2000000D0mY`?00<0[Jf]0000000000001P3/UPh2000000D0k9H>0P0000001`3/UPh0[Jf]0=^:
3@000000fhX=0000002][Jd00P0000060=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2]
[Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00<0
kiP@0`0000000`2][Jd0kiP@0>nH40020>nH40030000003lX100o:0@00<0o:0@0P00000:0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01<0ojH@00<000000?nV403o
YQ000P3oYQ0200000080ojH@00<0[Jf]0?nU403oYA001`3oYA02000000030?nU40000000ojD@00@0
ojD@00<000000?nU400000002@3oYA00102][Jd0oj<@0000000000080?nS408000002@3oXa020000
00@0oj<@00@0[Jf]0?bP403lX100o:0@0P0000070?bP408000000P3lX1060:f][@80o:0@0P000006
0?JL3`8000001`3fW0l2000000D0mY`?00<0[Jf]0000000000001P3/UPh2000000D0k9H>0P000000
0`3/UPh0[Jf]0=^:3@02000000<0fhX=00<000000=^:3@3KRPd0103KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203C
Q`h01@2][Jd0kiP@0>nH403_V10000000080kiP@00<0[Jf]0000003_V1000`3_V102000000D0o:0@
0P00000:0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401P2][JdB0?nV4@030:f]
[@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400C0?nV40030000
003oYQ00ojH@0080ojH@0P0000020?nV40030:f][@3oYA00ojD@00L0ojD@0P0000000`3oYA000000
0?nU40040?nU408000002P3oYA00102][Jd0oj<@0000000000080?nS408000002@3oXa02000000@0
oj<@00<0[Jf]0?bP403lX1000P3lX102000000L0o:0@0P0000070?bP4080[Jf]0P0000000`2][Jd0
mY`?0?JL3`030?JL3`8000001`3fW0l2000000D0mY`?00<0[Jf]0000000000001P3/UPh2000000D0
k9H>0P0000001@3/UPh0[Jf]0=^:3@3KRPd0000000@0fhX=00<000000:f][@3KRPd00`3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00D0[Jf]0>nH4000000000000>nH40020:f][@030>nH4000
0000kiP@00<0kiP@0P0000050?bP408000002P3lX1000`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]603o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ004`3o
YQ000`000000ojH@0?nV40020?nV408000000P3oYQ000`2][Jd0ojD@0?nU40030?nU40<0000000<0
ojD@0000000000000P3oYA0010000000ojD@0?nU403oYA02000000/0ojD@00<0[Jf]0?nS403oXa00
0P0000060?nS408000002P3oXa02000000@0oj<@00<0[Jf]0?bP403lX1000P3lX102000000L0o:0@
0P0000080?bP4080000000<0[Jf]0?JL3`2][Jd00`2][Jd00`3fW0l00000000000070?JL3`800000
1@3fW0l00`2][Jd00000000000060>bF3P8000001@3/UPh2000000050>bF3P2][Jd0fhX=0=^:3@00
0000103KRPd01`000000fhX=0:f][@2][Jd000000=^:3@2][Jd02@2iM@/01@2][Jd0R5H708QF1`28
EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P050:f][@00
000000000000002][Jd00`3_V1000`000000kiP@0>nH40020>nH408000001@3lX102000000X0o:0@
00<0[Jf]0?nT4@3oY1403P3oY1440:f][@030?nT4@2][Jd0ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01<0ojH@00L000000?nV403oYQ00
ojH@0000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA001P3oYA03000000<0ojD@0`00000=0?nU
40040:f][@3oXa00oj<@0?nS408000001@3oXa02000000X0oj<@0P0000040?nS40030:f][@3lX100
o:0@0080o:0@0P0000070?bP40800000203lX102000000030:f][@3fW0l0mY`?00<0mY`?00@0[Jf]
000000000000[Jf]1P3fW0l2000000D0mY`?00<0[Jf]0000000000001P3/UPh2000000D0k9H>0P00
00001@3/UPh0[Jf]0=^:3@3KRPd0000000D0fhX=00@000000=^:3@3KRPd000000P2][Jd90;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;
09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0P2][Jd2000000@0kiP@00<000000>nH403_V100
0P3_V102000000D0o:0@00<000000?bP403lX1002@3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@@0[Jf]
1@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400D0?nV40030000003oYQ00ojH@008000000`3oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@0P0000020?nS408000002`3oXa02000000@0oj<@
00<0[Jf]0?bP403lX1000P3lX102000000L0o:0@0P0000080?bP4080000000<0[Jf]0?JL3`3fW0l0
103fW0l2000000030?JL3`2][Jd0[Jf]0080[Jf]0P3fW0l2000000D0mY`?00<0[Jf]0>bF3P000000
1P3/UPh2000000D0k9H>0P0000001@3/UPh0[Jf]0=^:3@3KRPd0000000D0fhX=00<000000=^:3@3K
RPd00P0000000`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00@0[Jf]0>nH4000
00000000103_V1000`000000kiP@0>nH40020>nH40030000002][Jd0o:0@00@0o:0@00<000000?bP
403lX100103lX1000`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A00L0oj@A0`2][Jd90?nT
4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01@0ojH@00<000000?nV403oYQ000P0000030?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa001@3oXa02000000d0oj<@0P0000040?nS40030:f][@3lX100o:0@
0080o:0@0P0000080?bP408000001`3lX102000000030:f][@3fW0l0mY`?00@0mY`?0P0000050?JL
3`80[Jf]0P0000050?JL3`030:f][@3/UPh0000000H0k9H>0P0000050>bF3P80000000<0k9H>0:f]
[@3KRPd01`3KRPd01@000000fhX=0=^:3@000000fhX=0080[Jf]202iM@/00`2][Jd0R5H708QF1`02
08QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@06
0=>73P050000003CQ`h0[Jf]0:f][@3_V1000P0000040>nH40040000003_V100kiP@0>nH40800000
1P3lX1000`000000o:0@0?bP40040?bP40030000003lX100o:0@0080o:0@00<0[Jf]0?nT4@3oY140
0`3oY1440:f][@`0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00503oYQ000`000000ojH@0?nV4002000000<0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400D0?nS40800000103oXa000`2][Jd0o:0@
0?bP40020?bP40800000203lX102000000L0o:0@00<000000?bP402][Jd01P3fW0l2000000L0mY`?
0P0000040:f][@040?JL3`2][Jd0k9H>000000H0k9H>0P0000050>bF3P80000000<0k9H>0:f][@3K
RPd01`3KRPd01`000000fhX=0=^:3@000000fhX=0:f][@2iM@/00P2][Jd60;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00D0dhL>00H000000:f][@000000dhL>0:f][@3_V102000000@0kiP@00@000000>nH403_V100
kiP@0P0000060?bP40030000003lX100o:0@00@0o:0@00<000000?bP403lX1000P3lX1000`2][Jd0
oj@A0:f][@030:f][A00oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00503oYQ000`000000ojH@0?nV4002000000<0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400D0?nS40800000103oXa000`2][Jd0
o:0@0?bP40020?bP408000002@3lX102000000D0o:0@0P0000000`3lX100[Jf]0?JL3`050?JL3`80
00001`3fW0l2000000@0mY`?0`2][Jd00`000000k9H>0>bF3P040>bF3P8000001@3/UPh200000003
0>bF3P2][Jd0fhX=00L0fhX=00<000000=^:3@3KRPd00P3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]
00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01`000000[Jf]0=>73P000000dhL>0:f][@3_V1000P00
00040>nH40040000003_V100kiP@0>nH408000001P3lX1000`000000o:0@0?bP40040?bP40040000
003lX100o:0@0?bP40<0[Jf]503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400D0?nV40030000003oYQ00ojH@0080
00000`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01@0oj<@0P0000040?nS4003
0:f][@3lX100o:0@0080o:0@0P00000:0?bP40800000103lX10010000000o:0@0?bP402][Jd60?JL
3`8000001`3fW0l2000000D0mY`?00<0[Jf]0>bF3P0000000P2][Jd40>bF3P8000001@3/UPh20000
00030>bF3P2][Jd0fhX=00H0fhX=0P0000040=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue
2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00@0dhL>00L000000=>73P3CQ`h000000=>73P2][Jd0kiP@00800000103_
V10010000000kiP@0>nH403_V102000000H0o:0@00<000000?bP403lX100103lX1001P000000[Jf]
0:f][@2][Jd0o:0@0:f][AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ005@3oYQ03000000@0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400D0?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP
408000002`3lX1001@000000o:0@0?bP403lX100000000<0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l3
000000H0mY`?0P0000050?JL3`030:f][@3/UPh000000080k9H>0P2][Jd30>bF3P030000003/UPh0
k9H>00@0k9H>0P0000000`2][Jd0fhX=0=^:3@050=^:3@800000103KRPd00`2][Jd0^GD;0;Ue2`03
0;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@02000000030=>73P2][Jd000000080dhL>00@000000=>73P2][Jd0kiP@
0P0000040>nH40040000003_V100kiP@0>nH408000001P3lX1000`000000o:0@0?bP40030?bP4003
0:f][@000000o:0@00<0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400E0?nV40<0
0000103oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01@0oj<@0P0000040?nS4003
0:f][@3lX100o:0@0080o:0@0P00000<0?bP40<00000103lX1000`2][Jd0mY`?0?JL3`040?JL3`<0
00001P3fW0l2000000D0mY`?00<0[Jf]0>bF3P000000103/UPh30:f][@030000003/UPh0k9H>00@0
k9H>0P0000000`2][Jd0fhX=0=^:3@040=^:3@8000001@3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80
[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0
Uf0;0:f][@0000020:f][@030=>73P000000dhL>00<0dhL>00@0[Jf]0>nH400000000000103_V100
10000000kiP@0>nH403_V102000000H0o:0@00<000000?bP403lX1000`2][Jd00`3lX10000000?bP
40030?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA7`2][Jd00`000000[Jf]0000000<0:f][AL0ojD@00<0
[Jf]0?nS403oXa00503oXa02000000@0oj<@00<0[Jf]0?bP403lX1000P3lX102000001@0o:0@00<0
[Jf]0?JL3`3fW0l00`3fW0l2000000030?JL3`000000mY`?00<0mY`?0P0000060?JL3`030:f][@3/
UPh0000000L0k9H>00<000000:f][@2][Jd0103/UPh2000000030:f][@3KRPd0fhX=00<0fhX=00<0
00000=^:3@0000001@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL20:f][D80/>3V0@3o
ool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P0000020=>73P030000003CQ`h0dhL>00<0dhL>00@0
[Jf]0>nH400000000000103_V10010000000kiP@0>nH403_V102000000H0o:0@00<000000:f][@2]
[Jd0103lX1000`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@03
0:f][@3oYQ00ojH@01D0ojH@00<000000?nV40000000103oYQ000`2][Jd0ojD@0?nU40050?nU4100
[Jf]1`3oYA000`2][Jd0oj<@0?nS400D0?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP4080
0000503lX100102][Jd0mY`?0?JL3`3fW0l400000080mY`?00@000000?JL3`3fW0l0mY`?0P000006
0?JL3`030:f][@3/UPh0000000L0k9H>00<000000>bF3P3/UPh00P2][Jd20>bF3P80000000<0[Jf]
0=^:3@3KRPd00`3KRPd2000000H0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`03
08QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/000000:f][@00
00020=>73P030000003CQ`h0dhL>00<0dhL>00<0[Jf]0>nH40000000103_V1000`000000kiP@0>nH
40020>nH40800000103lX1020:f][@030000003lX100o:0@00@0o:0@00<000000?bP403lX1000P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3o
YQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ005@3oYQ000`000000ojH@000000040?nV40030:f][@3o
YA00ojD@01D0ojD@302][JdB0?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP40800000503l
X1000`2][Jd0mY`?0?JL3`030?JL3`8000000P3fW0l01P000000mY`?0?JL3`000000mY`?000000H0
mY`?00<0[Jf]0>bF3P0000001`3/UPh00`000000k9H>0>bF3P020>bF3P80[Jf]0P0000000`2][Jd0
fhX=0=^:3@020=^:3@800000203KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0
/>3V0;3PiP100;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;0000002][Jd000000P3CQ`h00`00
0000dhL>0=>73P020=>73P040:f][@3_V100kiP@000000@0kiP@00<000000>nH403_V1000P3_V102
000000040?bP402][Jd0[Jf]0:f][@80o:0@00<000000?bP403lX100103lX1000`000000o:0@0?bP
40020?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01D0ojH@00<0
00000?nV40000000103oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2]
[Jd80?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP40800000503lX1000`2][Jd0mY`?0?JL
3`080?JL3`@000001`3fW0l00`2][Jd0k9H>000000070>bF3P030000003/UPh0k9H>00@0k9H>0P00
00020:f][@80fhX=00<000000=^:3@000000203KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028
EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP060:f][@2GH0/000000000002][Jd00000
0P3CQ`h00`000000dhL>0=>73P020=>73P040:f][@3_V100kiP@000000@0kiP@00<000000>nH403_
V1000P3_V102000000030:f][@3lX100o:0@0080o:0@0P0000060?bP40030000003lX100o:0@0080
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080
ojHA2P2][Jd>0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ005P3oYQ000`000000
ojH@0?nV40030?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa080:f][@80
0000103oXa000`2][Jd0o:0@0?bP40020?bP40800000503lX1000`2][Jd0mY`?0?JL3`0C0?JL3`03
0:f][@3/UPh0000000L0k9H>00<000000>bF3P3/UPh0103/UPh2000000060:f][@3KRPd0[Jf]0000
003KRPd000001`3KRPd00`000000fhX=0:f][@080;Ue2`030:f][@28EPL0[Jf]00<0R5H700<0[Jf]
0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;000000000000[Jf]00000080dhL>00<0
00000=>73P3CQ`h00P3CQ`h0102][Jd0kiP@0>nH400000040>nH40040000003_V100kiP@0>nH4080
[Jf]00<000000?bP403lX1000`3lX102000000H0o:0@00<000000?bP403lX1000P3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdH0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ005P3oYQ000`000000ojH@0?nV40030?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa00503oXa02000000P0[Jf]00<0o:0@000000000000503lX1000`2][Jd0
mY`?0?JL3`0B0?JL3`80000000<0k9H>0000003/UPh01P3/UPh00`000000k9H>0>bF3P040>bF3P80
000000<0[Jf]0=^:3@3KRPd00P0000000`2][Jd0fhX=0=^:3@050=^:3@030000003KRPd0[Jf]00P0
^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP<0
000000@0Uf0;0:f][@000000dhL>0P0000040=>73P040:f][@3_V100kiP@000000@0kiP@00@00000
0>nH402][Jd0[Jf]0P3_V1000`000000o:0@0?bP40030?bP408000001@3lX102000000<0o:0@00<0
[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ005P3oYQ000`000000ojH@0?nV
40030?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00503oXa02000000@0oj<@00D0
[Jf]0?bP403lX100o:0@0:f][@02000000@0[Jf]403lX1000`2][Jd0mY`?0?JL3`0D0?JL3`800000
1`3/UPh00`000000k9H>0>bF3P040>bF3P80000000@0[Jf]0=^:3@3KRPd000000P3KRPd20:f][@D0
fhX=00<000000=^:3@2][Jd0202iM@/01`2][Jd0R5H708QF1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H1
0?ooo`00F@2`h>H30000000409MP2`2][Jd000000=>73P800000103CQ`h0102][Jd0kiP@0>nH4000
00040>nH40030000002][Jd0kiP@00<0kiP@00<000000?bP403lX1000P3lX103000000D0o:0@0P00
00030?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400D0?nS40800000103oXa000`2][Jd0o:0@0?bP
40020?bP40800000103lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P060>bF3P030000003/UPh0k9H>00@0k9H>0P000000102][Jd0fhX=0=^:3@0000040=^:3@80[Jf]
0`3KRPd00`000000fhX=0:f][@080;Ue2`070:f][@28EPL0R5H708QF1`2][Jd0R5H70:f][@120;3P
iP40oooo001I0;3PiP<0000000@0Uf0;0:f][@000000dhL>0P0000040=>73P040:f][@3_V100kiP@
00000080kiP@0P2][Jd00`000000kiP@0>nH40030>nH40030000003lX100o:0@0080o:0@0`000005
0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]403o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01@0oj<@0P0000040?nS40030:f][@3l
X100o:0@0080o:0@0P00000:0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00@0k9H>00<000000>bF3P0000001P3/UPh2000000040:f][@3KRPd0fhX=000000D0fhX=
00L000000:f][@2][Jd0fhX=0000003KRPd0[Jf]00P0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f]
[D80/>3V0@3oool005P0/>3V10000000102GH0/0[Jf]0000003CQ`h2000000@0dhL>00@0[Jf]0>nH
403_V10000000P2][Jd20>nH40030000003_V100kiP@00<0kiP@0P0000030?bP40<000001@3lX102
000000<0o:0@00<0[Jf]0?nT4@3oY1404`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400A0?nS4080000000<0oj<@000000000000103oXa000`2][Jd0o:0@0?bP4002
0?bP408000004@3lX1060:f][A@0mY`?00<0[Jf]0>bF3P3/UPh01@3/UPh2000000H0k9H>0P000000
102][Jd0fhX=0=^:3@0000050=^:3@070000003KRPd0fhX=0:f][@000000fhX=0:f][@080;Ue2`03
0:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00E`2`h>H50000000409MP
2`2][Jd000000=>73P800000103CQ`h0102][Jd0kiP@0:f][@0000040>nH40030000003_V100kiP@
00<0kiP@00H0[Jf]0000003lX100o:0@0000003lX102000000D0o:0@0P0000030?bP40030:f][@3o
Y140oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa004`3oXa03000000@0oj<@00D0[Jf]0?bP4000000000000?bP4002000001@0o:0@
00<0[Jf]0?JL3`3fW0l0102][Jd@0?JL3`030:f][@3/UPh0k9H>00/0k9H>10000000102][Jd0fhX=
0=^:3@0000050=^:3@050000003KRPd0fhX=0=^:3@0000000P2][Jd90;Ue2`030:f][@28EPL0R5H7
0080R5H70P2][Je10;3PiP40oooo001H0;3PiP@0000000D0Uf0;0:f][@000000dhL>000000030=>7
3P060000003CQ`h0[Jf]0:f][@3_V1000000103_V1000`000000kiP@0>nH40030>nH40060:f][@00
0000o:0@0?bP40000000o:0@0P0000050?bP408000000`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0
[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa00102][Jd0o:0@0?bP403lX103000001@0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l50:f]
[@/0mY`?00<0[Jf]0>bF3P3/UPh03@3/UPh2000000050:f][@3KRPd0fhX=0=^:3@000000103KRPd0
1P000000fhX=0=^:3@3KRPd000000=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@@2`h>H10?ooo`00F02`h>H20000000709MP2`000000Uf0;0:f][@000000dhL>000000030=>73P04
0000002][Jd0[Jf]0>nH40800000103_V1000`000000kiP@0>nH40030>nH40040:f][@3lX1000000
00000080o:0@0P0000050?bP408000000`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/UPh0
k9H>00l0k9H>00D0[Jf]0=^:3@3KRPd0fhX=000000040=^:3@080000003KRPd0fhX=0=^:3@000000
fhX=0:f][@2iM@/20:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005P0
/>3V0P000000102GH0/0000009MP2`0000020=>73P040000003CQ`h0dhL>0=>73P80000000@0[Jf]
0>nH400000000000103_V1000`000000kiP@0>nH40030>nH40030:f][@3lX100o:0@00<0o:0@0P00
00050?bP408000000`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?00h0mY`?102][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>00D0
[Jf]0=^:3@3KRPd0fhX=000000020=^:3@8000000`3KRPd00`000000fhX=0:f][@030;Ue2`030:f]
[@2iM@/0^GD;00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005P0/>3V0P00
0000102GH0/0000009MP2`0000020=>73P040000003CQ`h0dhL>0:f][@80000000@0[Jf]0>nH4000
00000000103_V1000`000000kiP@0>nH40030>nH40030:f][@3lX100o:0@00<0o:0@00<000000?bP
403lX100103lX102000000<0o:0@00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l40:f][A40k9H>00T0[Jf]0=^:3@3KRPd0fhX=0000003K
RPd000000=^:3@0000000`3KRPd00`000000fhX=0:f][@040;Ue2`030:f][@2iM@/0^GD;0080^GD;
00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005P0/>3V0P000000102GH0/0000009MP
2`0000020=>73P040000002][Jd0[Jf]0=>73P80000000@0[Jf]0>nH400000000000103_V1000`00
0000kiP@0>nH40030>nH40030:f][@3lX100o:0@00<0o:0@00<000000?bP403lX100103lX1020000
0080o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd2000000030=^:3@000000fhX=
0080fhX=00<000000=^:3@2][Jd01@2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je1
0;3PiP40oooo001H0;3PiP80000000@0Uf0;0000002GH0/000000P3CQ`h2000000<0dhL>00<00000
0:f][@3_V1000P0000020>nH40<000001@3_V1000`2][Jd0o:0@0?bP40030?bP40030000003lX100
o:0@00@0o:0@0P0000020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@000000k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0
fhX=00D0fhX=00L000000=^:3@3KRPd0fhX=0000003KRPd0[Jf]00H0^GD;0P2][Jd00`2iM@/0[Jf]
08QF1`0308QF1`80[Jf]@@2`h>H10?ooo`00F02`h>H20000000609MP2`000000Uf0;0000003CQ`h0
[Jf]0P0000020=>73P040000003CQ`h0[Jf]0>nH408000002P3_V1000`2][Jd0o:0@0?bP40030?bP
40030000003lX100o:0@00<0o:0@00<0[Jf]0000000000000`3lX1000`2][Jd0oj@A0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l2000000D0k9H>0`2][Jd90>bF
3P030:f][@3KRPd0fhX=00T0fhX=0P0000000`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL20:f]
[D40/>3V0@3oool005P0/>3V00P000000:f][@2GH0/0000009MP2`000000[Jf]0=>73P8000000P3C
Q`h010000000dhL>0:f][@3_V102000000X0kiP@00<0[Jf]0?bP403lX1000`3lX10010000000o:0@
0?bP403lX1020:f][@030?bP40000000000000<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<000000>bF3P0000001`3/UPh30:f][@H0
k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd2000000030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28
EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V00@000000:f][@2GH0/000000P2GH0/00`000000
dhL>0=>73P0200000080dhL>00@000000=>73P2][Jd0kiP@0P00000:0>nH40030:f][@3lX100o:0@
00<0o:0@00@000000:f][@2][Jd0[Jf]0`3lX102000000<0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^
0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01@0mY`?0P00000;0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@090=^:3@80000000<0[Jf]
0;Ue2`2iM@/01`2iM@/20:f][@<0R5H70P2][Je10;3PiP40oooo001G0;3PiP80000000D0Uf0;0000
002GH0/0[Jf]000000030=>73P050000003CQ`h0dhL>0000002][Jd00P3_V102000000X0kiP@00@0
[Jf]0?bP403lX100o:0@0P2][Jd00`000000o:0@0?bP40040?bP40030000003lX100o:0@0080o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@000000k9H>00`0k9H>
0`2][Jd00`3/UPh0[Jf]0=^:3@0:0=^:3@80000000<0fhX=0:f][@2iM@/01`2iM@/20:f][@<0R5H7
0P2][Je10;3PiP40oooo001G0;3PiP80000000D0Uf0;0000002GH0/0[Jf]000000030=>73P050000
003CQ`h000000=>73P2][Jd00P3_V102000000X0kiP@00@0[Jf]0?bP402][Jd0[Jf]0P3lX1000`00
0000o:0@0?bP40040?bP40030000003lX100o:0@0080o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f]
[@X0fhX=0P0000000`3KRPd0[Jf]0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H70P2][Je10;3P
iP40oooo001G0;3PiP80000000D0Uf0;0000002][Jd0Uf0;000000030=>73P050000003CQ`h00000
0=>73P2][Jd00P3_V1000`000000kiP@0>nH40080>nH40<0[Jf]103lX1000`000000o:0@0?bP4004
0?bP40030000003lX100o:0@0080o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H
0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2]
[Jd80=^:3@80000000<0fhX=0:f][@2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`
h>H10?ooo`00E`2`h>H20000000509MP2`000000Uf0;09MP2`000000103CQ`h010000000dhL>0=>7
3P2][Jd20>nH40030000003_V100kiP@00H0kiP@0P2][Jd00`3_V100[Jf]0?bP40040?bP40030000
003lX100o:0@00T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd60=^:3@80000000<0fhX=0:f][@2i
M@/01`2iM@/01@2][Jd0R5H708QF1`2][Jd0R5H70080[Jf]@@2`h>H10?ooo`00E`2`h>H200000005
09MP2`000000Uf0;09MP2`0000001`3CQ`h0102][Jd0kiP@0>nH400000060>nH4080[Jf]0`3_V100
0`2][Jd0o:0@0?bP40030?bP40030000003lX100o:0@00T0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd40=^:3@80000000<0fhX=
0:f][@2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL30:f][D40/>3V0@3oool005L0/>3V0P000000
1@2][Jd0000009MP2`2GH0/0000000L0dhL>00@0[Jf]0>nH403_V1000000103_V1000`2][Jd00000
0>nH40040>nH40040:f][@3lX100o:0@0?bP40800000303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@80fhX=0P0000000`3KRPd0
[Jf]0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`<0[Jf]@@2`h>H10?ooo`00E`2`h>H200000005
0:f][@000000Uf0;09MP2`0000001`3CQ`h0102][Jd0kiP@0>nH400000020>nH4080[Jf]00<0kiP@
0000003_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0P0000000`3KRPd0[Jf]0;Ue2`07
0;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP80000000D0Uf0;0000
002GH0/000000:f][@070=>73P040:f][@3_V100kiP@00000080[Jf]0P3_V102000000D0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]
^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00T0fhX=0P0000000`3KRPd0[Jf]0;Ue2`080;Ue2`040:f][@28EPL0R5H708QF1`80
[Jf]@@2`h>H10?ooo`00E`2`h>H20000000409MP2`000000Uf0;0:f][@P0dhL>00@0[Jf]0>nH402]
[Jd00000103_V1000`000000kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd02@3KRPd200000080[Jf]2@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool0
05L0/>3V00H000000:f][@2GH0/0000009MP2`2][Jd80=>73P80[Jf]00<0kiP@0000003_V1000`3_
V1000`000000kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3o
Y1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3K
RPd2000000040=^:3@2][Jd0[Jf]0:f][@L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40
oooo001G0;3PiP060000002][Jd0Uf0;0000002GH0/0[Jf]1`3CQ`h20:f][@80kiP@00<000000>nH
403_V1002@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3P
iP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=00<000000=^:
3@2][Jd00P2iM@/00`2][Jd0^GD;0;Ue2`040;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H1
0?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd01@3C
Q`h0[Jf]0>nH403_V100000000X0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@04
0?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@09
0=^:3@030000003KRPd0[Jf]00<0^GD;00<0[Jf]0;Ue2`2iM@/00`2iM@/0102][Jd0R5H708QF1`28
EPL20:f][D40/>3V0@3oool005L0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P02
0=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd00P3_V1000`000000kiP@0>nH40080>nH40030:f][@3l
X100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P030:f][@3KRPd0fhX=00T0fhX=00<000000=^:3@2][Jd0102iM@/20:f][@<0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001G0;3PiP030000002][Jd0Uf0;0080Uf0;00D0
[Jf]0=>73P3CQ`h0dhL>0:f][@040=>73P030:f][@3_V100000000/0kiP@00<0[Jf]0?bP403lX100
3`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
102iM@/0102][Jd0^GD;0;Ue2`2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000<0Uf0;
00@0[Jf]0=>73P2][Jd0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0
o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0
^GD;0`2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000<0Uf0;0P2][Jd70=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]
00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP800000
0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
1`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo
001G0;3PiP8000000P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP
40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@2`
h>H0/>3V03l0/>3V0@3oool005L0/>3V0P00000209MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW
0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0
fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@2`h>H0
/>3V03l0/>3V0@3oool005H0/>3V00L000000:f][@000000Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i
/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f]
[@0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00@000000:f][@000000[Jf]0P2G
H0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00X0kiP@0`2][Jd80;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][MP0/>3V102][Jd80<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP2045Yh@80[Jf]2`3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`060:f][@28EPL0R5H70:f][@28EPL0[Jf]@@2`h>H10?ooo`00EP2`h>H010000000[Jf]
0000002][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100203_V1020:f][@/0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^004045Yh@2n^KP0[Jf]0:f]
[@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool0
05H0/>3V00<000000:f][@0000000`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f]
[LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP00`11
JN40_[Vh0:f][@030:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL2
0:f][D40/>3V0@3oool005H0/>3V00<000000:f][@0000000`2GH0/00`2][Jd0dhL>0=>73P060=>7
3P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]
0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh00<0@FWQ
0:f][@2n^KP00`2n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`02
08QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]0000000309MP2`030:f][@3CQ`h0dhL>
00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd7
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/005
0:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0030;ji^080[Jf]00<0@FWQ0;ji^02n^KP00`2n^KP0102][Jd0];2a0:f][@2]
[Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D00/>3V0@3o
ool005H0/>3V00<000000:f][@0000000P2GH0/00`2][Jd0dhL>0=>73P070=>73P040:f][@3_V100
[Jf]0:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0102aZid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh
0P2][Jd20;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00@0[Jf]0;B`/@2d/;40@FWQ0P2][Jd00`3KRPd0
[Jf]0;Ue2`090;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H2000000<0
Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@P0Y9j?00<0[Jf]045Yh@11JN401P2aZid20:f][@<0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0
`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0
`kfk00@0[Jf]0;ji^02][Jd0[Jf]102n^KP01011JN40_[Vh0;ji^011JN420;ji^0030:f][@2d/;40
];2a0080@FWQ00<0];2a0:f][@2][Jd02P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3o
ool005H0/>3V0P00000309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0:BNS`2TWXl0202TWXl0
0`2][Jd0/J^M0;6[W@02045Yh@H0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]1P2n^KP0
1`11JN40_[Vh045Yh@2n^KP0@FWQ0;ji^02][Jd00P2d/;42045Yh@<0];2a0P2][Jd80;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f]
[@3CQ`h0dhL>00@0dhL>0P2][Jd;0:BNS`050:f][@2aZid0/J^M045Yh@2aZid00P11JN460;6[W@<0
[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33
_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00H0_[Vh0P11JN420;ji
^003045Yh@2n^KP0[Jf]0080];2a0P11JN430;B`/@03045Yh@2d/;40[Jf]00L0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>7
3P3CQ`h00`3CQ`h30:f][@X0Y9j?00D0[Jf]0;6[W@2aZid0/J^M045Yh@020;6[W@03045Yh@2aZid0
/J^M00D0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd4
0<>m^`030:f][@2n^KP0_[Vh0080_[Vh00<0@FWQ0;ji^02n^KP00P11JN430;ji^004045Yh@2n^KP0
[Jf]0;B`/@80@FWQ0`2d/;400`11JN40];2a0;B`/@020:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0RXEe
08Z5M@2][Jd:0:BNS`050:f][@2aZid0/J^M0;6[W@11JN400`2aZid00`11JN40/J^M0;6[W@040;6[
W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m
^`050:f][@2n^KP0_[Vh0;ji^011JN400`2n^KP00`11JN40_[Vh0;ji^0020;ji^004045Yh@2n^KP0
[Jf]0;B`/@80@FWQ0`2d/;401@11JN40];2a0:f][@2][Jd0@FWQ0080[Jf]0`2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P04
0:f][@2:QGD0RXEe08Z5M@<0[Jf]202TWXl01@2][Jd0/J^M0;6[W@2aZid0@FWQ00<0/J^M00<0@FWQ
0;6[W@2aZid00P2aZid2045Yh@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk0`11JN40
0`2n^KP0@FWQ0;ji^0020;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00<0@FWQ0:f][@2d/;400P11JN43
0;B`/@05045Yh@2][Jd0];2a0;B`/@11JN400P2OVj00102][Jd0^GD;0;Ue2`2][Jd308QF1`80[Jf]
@02`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]102:QGD0102][Jd0
Y9j?0:BNS`2][Jd70:BNS`050:f][@2aZid0/J^M0;6[W@11JN40102aZid00`11JN40/J^M0;6[W@02
0;6[W@<0@FWQ2P2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`3
0:f][@d0`kfk00@0@FWQ0:f][@2n^KP0_[Vh0P11JN430;ji^080@FWQ102n^KP00`11JN40[Jf]0;B`
/@02045Yh@80];2a00<0[Jf]045Yh@2d/;400P2d/;401011JN40Wi^P09nKX02OVj030:f][@@0R5H7
00<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]00<0
@FWQ08Z5M@2:QGD00`2:QGD0102][Jd0Y9j?0:BNS`2TWXl20:f][@D0Y9j?00D0[Jf]0;6[W@2aZid0
/J^M045Yh@040;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN4?0;VbYP<0[Jf]4@2n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33
_K/03033_K/2045Yh@050:f][@2n^KP0_[Vh0;ji^011JN400`2n^KP2045Yh@@0_[Vh00<0@FWQ0:f]
[@2d/;400P11JN420:f][@030;B`/@11JN40];2a0080];2a00<0@FWQ09nKX02OVj000`2OVj000`2]
[Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2G
H0/00P2GH0/00`2][Jd0@FWQ045Yh@0508Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd30:BNS`05
0:f][@2aZid0/J^M0;6[W@11JN40102aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ402i/ZH00`2]
[Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m
^`33_K/02`33_K/2045Yh@050:f][@2n^KP0_[Vh0;ji^011JN400`2n^KP2045Yh@@0_[Vh00<0@FWQ
0:f][@2d/;400P11JN430;B`/@05045Yh@2d/;40];2a0;B`/@11JN401P2OVj001@2][Jd0R5H708QF
1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd2045Yh@D0RXEe
00<0[Jf]0:BNS`2TWXl01@2TWXl0102][Jd0Y9j?0:BNS`2][Jd30;6[W@03045Yh@2aZid0/J^M0080
/J^M0P11JN430;6[W@80@FWQ402i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0
`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0
a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`020<>m^`80@FWQ1`33_K/01011JN40
`kfk0<>m^`2][Jd20;ji^004045Yh@2n^KP0_[Vh0;ji^080@FWQ102n^KP00`11JN40[Jf]0:f][@02
045Yh@<0];2a00<0@FWQ0;B`/@2d/;400P11JN4609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`
h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@80@FWQ1@2:QGD00`2][Jd0Y9j?0:BN
S`060:BNS`<0[Jf]0`2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ0`2aZid2045Yh@P0^K:V1@11
JN430;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0
[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36
`;`00`2][Jd0`kfk045Yh@03045Yh@P0`kfk00@0@FWQ0<>m^`33_K/0[Jf]0P2n^KP01011JN40_[Vh
0;ji^02n^KP2045Yh@@0_[Vh00@0@FWQ0:f][@2d/;40];2a0P11JN420;B`/@05045Yh@2d/;40];2a
0;B`/@2][Jd01`2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0
Uf0;00<0[Jf]0P11JN4508Z5M@030:f][@2TWXl0Y9j?00P0Y9j?0P2][Jd20;6[W@03045Yh@2aZid0
/J^M0080/J^M0P11JN430;6[W@80@FWQ202i/ZH2045Yh@80^K:V00D0@FWQ0;VbYP2i/ZH0^K:V045Y
h@0=0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l00l0al6l102][Jd?0<K0_003045Yh@36`;`0[Jf]00<0`kfk0P11JN480<>m^`04045Yh@33
_K/0`kfk0:f][@80_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN420;ji^0040:f][@11JN40@FWQ0:f]
[@80];2a0P11JN400`2d/;40@FWQ0;B`/@030;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Jd00`28
EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]00<0RXEe045Y
h@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`050:f][@2aZid0[Jf]0:f][@11JN401@2aZid0
1011JN40/J^M0;6[W@2aZid2045Yh@P0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH01@11JN40^K:V045Y
h@2][Jd0@FWQ0100_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
2P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`02`36`;`01P11JN40a/2l0<K0_011JN40a/2l0:f]
[@<0`kfk0P11JN480<>m^`04045Yh@33_K/0`kfk0:f][@80_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11
JN420:f][@040;ji^011JN40@FWQ0:f][@80];2a1011JN440;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]08Z5M@11JN40
102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`050:f][@2aZid0/J^M0;6[W@11JN400P2][Jd30;6[W@04
045Yh@2aZid0/J^M0;6[W@80@FWQ202i/ZH00`11JN40^K:V0;VbYP020;VbYP<0@FWQ00<0[Jf]0;jg
[02n]j`0102n]j`00`11JN40_[N/0;jg[0090;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l
00T0a/2l0P11JN401P36`;`0@FWQ045Yh@11JN40a/2l0:f][@<0`kfk0P11JN480<>m^`04045Yh@33
_K/0`kfk0:f][@80_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0P11JN430;ji^080@FWQ00<0[Jf]0;B`/@2d
/;400P11JN460;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40
oooo001F0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl0102][Jd0/J^M
0;6[W@11JN430;6[W@80[Jf]00<0/J^M045Yh@2aZid00P2aZid00`11JN40[Jf]0;VbYP070;VbYP03
045Yh@2i/ZH0^K:V00<0^K:V0P11JN400`2][Jd0_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00T0
_[N/00<0[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0_036`;`02036`;`00`11JN40a/2l0<K0_0020<K0_080
@FWQ00<0a/2l0:f][@33_K/00P33_K/2045Yh@P0`kfk0P11JN401@33_K/0[Jf]0;ji^02n^KP0@FWQ
0080[Jf]00<0_[Vh045Yh@11JN400`2n^KP00`11JN40_[Vh0:f][@020;B`/@80@FWQ1P2d/;400`2]
[Jd0Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`04
0:f][@2aZid0/J^M045Yh@D0/J^M00<0[Jf]045Yh@2][Jd00P2aZid00`11JN40[Jf]0;VbYP070;Vb
YP03045Yh@2i/ZH0^K:V00<0^K:V0P11JN460;jg[080@FWQ102n]j`00`11JN40_[N/0;jg[0040;jg
[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@11JN401@11JN4?0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f]
[A40al6l00<0[Jf]045Yh@36`;`01`36`;`2045Yh@D0a/2l00<0@FWQ0<K0_02][Jd00`33_K/2045Y
h@T0`kfk1P11JN430;ji^080@FWQ0`2n^KP00`11JN40_[Vh0:f][@020;B`/@80@FWQ1P2d/;400`11
JN40Wi^P09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`040:f][@2aZid0/J^M045Yh@D0/J^M0P11JN401@2aZid0[Jf]0:f][@11JN40[Jf]00P0^K:V
00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@H0_[N/0P11JN440;jg[003045Yh@2n]j`0_[N/00@0_[N/
00<0[Jf]0<6j/031^[003`31^[080:f][A00`kfc00@0[Jf]0<Fn]@35_[D0aKje0P11JN4A0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037
`K`04@37`K`00`2][Jd0@FWQ0<K0_0070<K0_003045Yh@36`;`0a/2l00@0a/2l00<0@FWQ0<K0_02]
[Jd00`33_K/2045Yh@X0`kfk0`2][Jd00`2n^KP0@FWQ0;ji^0020;ji^080@FWQ0P2n^KP2045Yh@04
0;ji^02][Jd0];2a0;B`/@80@FWQ1P2d/;400`11JN40Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^
N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:
QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00@0[Jf]0;6[W@2aZid0@FWQ1@2aZid2
045Yh@<0/J^M00<0@FWQ0:f][@2][Jd01`2i/ZH2045Yh@@0^K:V0P11JN460;jg[080@FWQ102n]j`0
0`11JN40_[N/0;jg[0040;jg[0030:f][@31^[00`KZ`0080`KZ`0`11JN4<0<6j/0030:f][@33_K<0
`kfc00<0`kfc2`2][Jd50<>m/`040:f][@35_[D0aKje0<Fn]@80@FWQ4@35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00<0<O1_003045Y
h@37`K`0al6l0080al6l00<0[Jf]045Yh@36`;`01P36`;`2045Yh@H0a/2l0P11JN40102][Jd0`kfk
0<>m^`33_K/2045Yh@L0`kfk0`2][Jd01@33_K/0[Jf]0;ji^02n^KP0@FWQ00<0_[Vh0`11JN401@2n
^KP0@FWQ0;ji^02n^KP0[Jf]0080];2a0P11JN460;B`/@03045Yh@2OVj00[Jf]00D0Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5
M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@0;0:BNS`040:f][@2aZid0/J^M045Yh@D0/J^M0P11JN43
0;6[W@80@FWQ00@0^K:V0:f][@2][Jd0[Jf]1@2i/ZH00`11JN40^K:V0;VbYP020;VbYP80@FWQ1P2n
]j`00`11JN40_[N/045Yh@020;jg[080@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/002045Yh@<0`KZ`00@0
@FWQ0<6j/011JN40@FWQ2031^[000`2][Jd0`kfc0<>m/`0>0<>m/`T0[Jf]0P11JN4A0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00D0al6l0P11JN450<O1_003045Y
h@37`K`0al6l0080al6l00<0@FWQ0<K0_011JN401P36`;`00`11JN40a/2l0<K0_0050<K0_080@FWQ
00@0[Jf]0<>m^`33_K/0`kfk0P11JN440<>m^`<0[Jf]1033_K/0102][Jd0_[Vh0;ji^011JN430;ji
^080@FWQ00<0_[Vh045Yh@2n^KP00P2n^KP00`2][Jd0];2a0;B`/@02045Yh@H0];2a0P2][Jd609nK
X0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`03
0:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`040:f][@2aZid0/J^M045Yh@D0/J^M0P11JN430;6[
W@80@FWQ102i/ZH30:f][@<0^K:V00@0@FWQ0;VbYP2i/ZH0^K:V0P11JN450;jg[080@FWQ00@0_[N/
045Yh@2n]j`0_[N/0P11JN460;jg[0040:f][@31^[00@FWQ045Yh@D0`KZ`0`11JN430<6j/0@0@FWQ
00<0`KZ`0:f][@33_K<05033_K<0102][Jd0aKje0<Fn]@35_[D2045Yh@`0[Jf]1@35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@11JN40@FWQ045Y
h@<0al6l00<0@FWQ0<O1_037`K`01@37`K`00`11JN40al6l0<O1_0020<O1_0<0@FWQ1P36`;`00`11
JN40a/2l0<K0_0050<K0_080@FWQ00@0[Jf]0<>m^`33_K/0`kfk0P11JN420<>m^`80[Jf]1@33_K/0
1@11JN40`kfk0:f][@2n^KP0@FWQ00<0_[Vh0P11JN460;ji^0030:f][@2d/;40];2a0080@FWQ1P2d
/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl0102][Jd0/J^M0;6[W@11JN450;6[W@80@FWQ0`2aZid2045Yh@<0^K:V00@0@FWQ0;VbYP2i/ZH0
^K:V102][Jd2045Yh@030;VbYP11JN40@FWQ00D0_[N/00@0@FWQ0;jg[02n]j`0@FWQ0P2n]j`00`11
JN40_[N/045Yh@040;jg[0040:f][@31^[00`KZ`045Yh@H0`KZ`0`11JN450<6j/0@0@FWQ5@33_K<0
102][Jd0aKje0<Fn]@35_[D2045Yh@`0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@<0al6l00@0
@FWQ0<O1_037`K`0@FWQ1`37`K`2045Yh@<0al6l0`11JN460<K0_003045Yh@36`;`0a/2l00D0a/2l
1011JN420<>m^`80@FWQ0P2][Jd70<>m^`05045Yh@33_K/0[Jf]0;ji^011JN402`2n^KP00`2][Jd0
];2a0;B`/@02045Yh@@0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`040:f][@2aZid0/J^M
045Yh@D0/J^M0P11JN430;6[W@04045Yh@2][Jd0@FWQ0;VbYP80@FWQ1`2i/ZH20:f][@<0@FWQ1@2n
]j`01011JN40_[N/0;jg[011JN420;jg[003045Yh@2n]j`0@FWQ00@0_[N/00@0[Jf]0<6j/011JN40
@FWQ1`31^[02045Yh@D0`KZ`0P11JN400`31^[00[Jf]0<>m/`0D0<>m/`040:f][@35_[D0aKje0<Fn
]@80@FWQ4@35_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k00D0b<6k0`11JN490<S1^`80@FWQ00<0[Jf]0<O1_037`K`00P37`K`3045Y
h@H0al6l0`11JN430<O1_0<0@FWQ1@36`;`2045Yh@D0a/2l1011JN40102][Jd0`kfk0:f][@2][Jd3
045Yh@<0`kfk00<0@FWQ0<>m^`33_K/00P33_K/01011JN40`kfk0:f][@11JN4<0;ji^0030:f][@2d
/;40];2a0080@FWQ0`2d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2]
[Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2T
WXl00P2][Jd70:BNS`040:f][@2aZid0/J^M045Yh@D0/J^M00<0@FWQ0;6[W@2aZid00`11JN400`2]
[Jd0@FWQ0;VbYP02045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH3045Yh@030:f][@2n]j`0_[N/
0080_[N/00@0@FWQ0;jg[02n]j`0@FWQ0P2n]j`00`11JN40_[N/045Yh@040;jg[0040:f][@31^[00
@FWQ045Yh@L0`KZ`0P11JN450<6j/080@FWQ00<0`KZ`0:f][@33_K<02@33_K<6045Yh@D0`kfc00@0
[Jf]0<Fn]@35_[D0aKje0P11JN4A0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
0P38`K/4045Yh@/0b<6k00<0@FWQ0<S1^`2][Jd01@37`K`2045Yh@H0al6l0`11JN430<O1_0<0@FWQ
1@36`;`2045Yh@L0a/2l102][Jd20<>m^`<0@FWQ0P33_K/2045Yh@D0`kfk0P11JN4=0;ji^0030:f]
[@2d/;40];2a0080@FWQ00<0];2a0:f][@2][Jd00`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f]
[@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@03
0:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl0102][Jd0/J^M0;6[W@11JN450;6[
W@03045Yh@2aZid0/J^M00<0/J^M00D0[Jf]0;VbYP11JN40^K:V045Yh@040;VbYP03045Yh@2i/ZH0
^K:V00<0^K:V0P11JN40102n]j`0[Jf]0:f][@2][Jd2045Yh@80_[N/00H0@FWQ0;jg[011JN40@FWQ
0;jg[011JN440;jg[0040:f][@31^[00@FWQ045Yh@L0`KZ`0P11JN450<6j/080@FWQ00<0`KZ`0:f]
[@33_K<02@33_K<2045Yh@@0`kfc00@0@FWQ0<>m/`33_K<0`kfc0P11JN430<Fn]@80@FWQ0P35_[D0
0`11JN40aKje0<Fn]@0<0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00X0b<6k0P11JN400`38`K/0@FWQ045Yh@02
045Yh@<0b<6k00<0[Jf]0<S1^`38`K/01038`K/2045Yh@/0b<6k00<0@FWQ0<S1^`2][Jd01@37`K`2
045Yh@H0al6l0`11JN430<O1_003045Yh@36`;`0@FWQ00D0a/2l0P11JN420<K0_0D0[Jf]0P36`;`0
102][Jd0`kfk0<>m^`33_K/3045Yh@<0`kfk00<0@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0040:f][@2d/;40@FWQ045Yh@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f]
[@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0
Y9j?0:BNS`030:BNS`80[Jf]102TWXl0102][Jd0/J^M0;6[W@11JN440;6[W@80@FWQ1@2aZid00`2]
[Jd0^K:V0;VbYP02045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40[Jf]0;jg[0030;jg
[080@FWQ0P2][Jd00`11JN40_[N/045Yh@020;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]045Y
h@11JN402031^[02045Yh@D0`KZ`0P11JN400`31^[00[Jf]0<>m/`080<>m/`80@FWQ1P33_K<3045Y
h@030<>m/`2][Jd0aKje0080aKje1011JN400`35_[D0@FWQ045Yh@080<Fn]@<0@FWQ00<0aKje0:f]
[@36_kL05P36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/02038`K/5045Yh@@0b<6k0P11JN400`38`K/0[Jf]0<S1^`050<S1^`80@FWQ2`38`K/00`11
JN40b<6k0:f][@050<O1_080@FWQ1P37`K`00`11JN40al6l045Yh@020<O1_080@FWQ0P36`;`00`11
JN40a/2l0<K0_0020<K0_080@FWQ0P2][Jd70<K0_0040:f][@33_K/0`kfk0<>m^`80@FWQ00D0`kfk
045Yh@33_K/0`kfk045Yh@060<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]
1`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V
00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl0102][Jd0/J^M
0;6[W@11JN440;6[W@80@FWQ102aZid00`2][Jd0^K:V0;VbYP070;VbYP03045Yh@2i/ZH0^K:V00<0
^K:V00<0@FWQ0:f][@2n]j`00`2n]j`2045Yh@80_[N/00<0@FWQ0:f][@11JN400P2][Jd00`11JN40
_[N/0;jg[0020;jg[0030:f][@11JN40@FWQ00P0`KZ`0P11JN450<6j/080@FWQ00<0`KZ`0:f][@33
_K<02033_K<2045Yh@H0`kfc0P11JN420<>m/`040:f][@35_[D0aKje0<Fn]@<0@FWQ0`35_[D3045Y
h@P0aKje1@11JN420<Jo]`L0@FWQ0P36_kL7045Yh@<0a[ng00<0[Jf]0<O1^037`KP04P37`KP2045Y
h@030:f][@37`KX0al6j00D0al6j00<0@FWQ0<O1^P37`KX03@37`KX00`2][Jd0b<6k0<S1^`0:0<S1
^`80@FWQ1P38`K/2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN4;0<S1^`80@FWQ00<0[Jf]0<O1
_037`K`00`37`K`2045Yh@H0al6l00D0@FWQ0<O1_037`K`0@FWQ0<O1_002045Yh@80a/2l00<0@FWQ
0:f][@2][Jd00P2][Jd2045Yh@T0a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11JN420<>m^`80@FWQ1`33
_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`
KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`07
0:BNS`<0[Jf]0`11JN430;6[W@80@FWQ1@2aZid00`2][Jd0^K:V0;VbYP080;VbYP80@FWQ0P2i/ZH0
0`11JN40^K:V0:f][@040;jg[003045Yh@2n]j`0_[N/0080_[N/0P11JN420;jg[006045Yh@2][Jd0
[Jf]0:f][@2n]j`0[Jf]0P11JN480<6j/080@FWQ1@31^[02045Yh@030<6j/02][Jd0`kfc00P0`kfc
0P11JN470<>m/`04045Yh@33_K<0`kfc0:f][@<0aKje0P11JN450<Fn]@80@FWQ2035_[D2045Yh@03
0:f][@36_kL0a[ng00@0a[ng0P11JN470<Jo]`80@FWQ1P36_kL00`2][Jd0al6h0<O1^004045Yh@P0
al6h00@0@FWQ0<O1^037`KP0al6h0P11JN420<O1^003045Yh@37`KX0al6j00@0al6j00<0@FWQ0<O1
^P11JN403P37`KX00`2][Jd0b<6k0<S1^`0:0<S1^`80@FWQ1`38`K/2045Yh@H0b<6k0P11JN4;0<S1
^`80@FWQ00<0[Jf]0<O1_037`K`00`37`K`2045Yh@H0al6l00D0@FWQ0<O1_037`K`0@FWQ0:f][@02
045Yh@80[Jf]00<0@FWQ0<K0_036`;`00P36`;`2045Yh@T0a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11
JN4;0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0
[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl2
0:f][@030;6[W@11JN40@FWQ0080/J^M0P11JN450;6[W@030:f][@2i/ZH0^K:V00X0^K:V0P11JN42
0;VbYP040:f][@2n]j`0_[N/0;jg[080@FWQ102n]j`2045Yh@80_[N/00@0@FWQ0;jg[02n]j`0_[N/
0P2][Jd2045Yh@030:f][@31^[00`KZ`00<0`KZ`1011JN450<6j/080@FWQ00<0`KZ`0:f][@33_K<0
2033_K<2045Yh@L0`kfc00@0@FWQ0<>m/`33_K<0[Jf]0`35_[D2045Yh@H0aKje0P11JN470<Fn]@80
@FWQ00<0[Jf]0<Jo]`36_kL01036_kL2045Yh@L0a[ng0P11JN460<Jo]`040:f][@11JN40@FWQ045Y
h@<0al6h0P11JN460<O1^004045Yh@37`KP0@FWQ045Yh@@0al6h00<0[Jf]045Yh@37`KX01@37`KX0
0`11JN40al6j0<O1^P0=0<O1^P030:f][@38`K/0b<6k00X0b<6k0P11JN470<S1^`80@FWQ1P38`K/2
045Yh@`0b<6k00<0@FWQ0:f][@37`K`01037`K`2045Yh@D0al6l00H0[Jf]045Yh@2][Jd0[Jf]045Y
h@37`K`2045Yh@80a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@T0a/2l00<0[Jf]0<>m^`33_K/0
0P11JN4<0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BN
S`090:BNS`030:f][@2aZid0[Jf]0080[Jf]0`11JN460;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`00`11JN440;jg[003045Yh@2n]j`0_[N/0080_[N/00D0@FWQ0;jg[02n]j`0_[N/
0:f][@02045Yh@030<6j/02][Jd0[Jf]00D0[Jf]00@0`KZ`045Yh@11JN40@FWQ0`31^[02045Yh@03
0<6j/02][Jd0`kfc00P0`kfc0P11JN470<>m/`04045Yh@33_K<0`kfc0:f][@<0aKje00<0@FWQ0<Fn
]@35_[D01@35_[D2045Yh@L0aKje0P11JN400`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Y
h@H0a[ng0P11JN470<O1^003045Yh@37`KP0al6h00<0al6h0P11JN460<O1^0030:f][@11JN40al6j
01D0al6j00<0[Jf]0<S1^`38`K/02P38`K/2045Yh@P0b<6k0P11JN450<S1^`80@FWQ3038`K/4045Y
h@<0al6l0P11JN450:f][@060<O1_011JN40al6l0<O1_011JN40al6l0P11JN420<K0_003045Yh@36
`;`0a/2l0080a/2l0P11JN490<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01P2n
^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`
h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]
0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0102][Jd0_[N/0;jg[02n
]j`4045Yh@80_[N/00<0@FWQ0;jg[02n]j`00P2n]j`01@11JN40_[N/0;jg[02n]j`0[Jf]0080@FWQ
2031^[070:f][@80@FWQ00<0`KZ`0:f][@33_K<02@33_K<2045Yh@H0`kfc00@0@FWQ0<>m/`33_K<0
[Jf]0`35_[D00`11JN40aKje0<Fn]@050<Fn]@80@FWQ1`35_[D2045Yh@030:f][@36_kL0a[ng00@0
a[ng0P11JN470<Jo]`80@FWQ1P36_kL2045Yh@P0al6h00<0@FWQ0<O1^037`KP00P37`KP00`11JN40
al6h0<O1^0060<O1^003045Yh@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02P38`K/2045Yh@P0
b<6k0P11JN450<S1^`80@FWQ3@38`K/00`2][Jd0al6l0<O1_005045Yh@D0al6l0P11JN420<O1_004
045Yh@37`K`0@FWQ0:f][@<0a/2l00@0@FWQ0<K0_036`;`0a/2l0P11JN480<K0_003045Yh@2][Jd0
`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP30:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;40
0`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5
M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`00`11JN40_[N/0;jg[0020;jg
[005045Yh@2n]j`0_[N/0;jg[02][Jd00P11JN4?0<6j/080@FWQ1@2][Jd80<>m/`03045Yh@33_K<0
`kfc00@0`kfc00@0@FWQ0<>m/`33_K<0[Jf]0`35_[D00`11JN40aKje0<Fn]@060<Fn]@80@FWQ1P35
_[D2045Yh@030:f][@36_kL0a[ng00@0a[ng0P11JN470<Jo]`80@FWQ1P36_kL2045Yh@d0al6h00<0
@FWQ0<O1^037`KP01P37`KP00`11JN40al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00X0b<6k0P11
JN480<S1^`030:f][@11JN40@FWQ00@0b<6k0P11JN4:0<S1^`H0[Jf]0`37`K`2045Yh@D0al6l00<0
@FWQ0<O1_037`K`00P37`K`2045Yh@050:f][@36`;`0a/2l0<K0_011JN400`36`;`2045Yh@P0a/2l
00<0@FWQ0<K0_02][Jd03`33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d
/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V
00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M
0`2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/00X0_[N/0`11JN430;jg[0030:f]
[@11JN40@FWQ00l0`KZ`0`11JN40102][Jd0`kfc0<>m/`33_K<70:f][@80`kfc0`11JN430<>m/`04
045Yh@33_K<0`kfc0:f][@<0aKje00<0@FWQ0<Fn]@35_[D01P35_[D2045Yh@H0aKje0P11JN400`2]
[Jd0a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng0P11JN4G0<O1^003045Yh@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/02P38`K/2045Yh@P0b<6k00<0[Jf]045Yh@11JN401038`K/2045Y
h@<0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01037`K`00`11
JN40al6l0<O1_0020<O1_080@FWQ00@0[Jf]0<K0_036`;`0a/2l0`11JN420<K0_080@FWQ1P36`;`2
045Yh@030<K0_02][Jd0`kfk00h0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H0
0`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid3
0:f][@l0^K:V00<0[Jf]0;jg[02n]j`0302n]j`3045Yh@040;jg[02][Jd0@FWQ045Yh@l0`KZ`0`11
JN400`2][Jd0`kfc0<>m/`080<>m/`D0[Jf]1011JN420<>m/`050:f][@35_[D0aKje0<Fn]@11JN40
2035_[D2045Yh@H0aKje0P11JN400`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng
0P11JN4E0<O1^0<0@FWQ5P37`KX00`2][Jd0b<6k0<S1^`0:0<S1^`80@FWQ2038`K/0102][Jd0@FWQ
045Yh@38`K/30:f][@80@FWQ0`2][Jd90<S1^`03045Yh@2][Jd0al6l00@0al6l00<0@FWQ0<O1_037
`K`01037`K`00`11JN40al6l0<O1_0020<O1_080@FWQ00<0[Jf]0<K0_011JN400P11JN440<K0_080
@FWQ1P36`;`2045Yh@030<K0_02][Jd0`kfk00d0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0
];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?
0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]045Yh@11JN403`31^[03045Yh@050:f][@33_K<0`kfc0<>m/`11
JN403@33_K<2045Yh@H0[Jf]00<0@FWQ0:f][@35_[D01P35_[D2045Yh@H0aKje0P11JN400`2][Jd0
a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng0P11JN4D0<O1^0<0@FWQ00<0[Jf]0<O1^P37
`KX01037`KX00`11JN40al6j0<O1^P0=0<O1^P030:f][@38`K/0b<6k00X0b<6k0P11JN430<S1^`H0
[Jf]0P11JN40102][Jd0b<6k0<S1^`38`K/3045Yh@@0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11
JN40[Jf]0<O1_0030<O1_003045Yh@37`K`0al6l00D0al6l0`11JN440<O1_0030:f][@36`;`0a/2l
00H0a/2l0P11JN460<K0_080@FWQ00<0a/2l0:f][@33_K/02P33_K/30:f][@030<>m^`2][Jd0_[Vh
00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP03
0:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0
[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00@FWQ00l0`KZ`0P11JN401`31^[00
@FWQ0<>m/`33_K<0@FWQ0<>m/`11JN401@33_K<2045Yh@H0`kfc00@0@FWQ0<>m/`33_K<0[Jf]0`35
_[D00`11JN40aKje0:f][@060:f][@80@FWQ0`2][Jd30<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL01036
_kL2045Yh@L0a[ng0P11JN450<Jo]`80@FWQ4P37`KP3045Yh@80al6h00<0[Jf]0<O1^P37`KX01037
`KX00`11JN40al6j0<O1^P0=0<O1^P030:f][@38`K/0b<6k00<0b<6k1`2][Jd2045Yh@<0[Jf]1@38
`K/00`2][Jd0@FWQ045Yh@040<S1^`<0@FWQ0`38`K/00`11JN40b<6k045Yh@050<S1^`03045Yh@2]
[Jd0al6l0080al6l00<0@FWQ0<O1_037`K`00`37`K`3045Yh@P0al6l00<0[Jf]0<K0_036`;`01P36
`;`00`11JN40a/2l0<K0_0030<K0_0<0@FWQ00<0a/2l0:f][@33_K/01`33_K/30:f][@@0`kfk00<0
[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H2
0:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00@FWQ00T0`KZ`00@0@FWQ0<6j/031^[00`KZ`1011
JN400`31^[00@FWQ0<>m/`020<>m/`80@FWQ1@33_K<2045Yh@H0`kfc00@0@FWQ0<>m/`33_K<0[Jf]
0`35_[D00`11JN40aKje0<Fn]@050<Fn]@80@FWQ1035_[D30:f][@80@FWQ1`2][Jd2045Yh@<0[Jf]
1036_kL2045Yh@D0a[ng0P11JN4A0<O1^0<0@FWQ0`37`KP00`2][Jd0al6j0<O1^P040<O1^P03045Y
h@37`KX0al6j0080al6j4@2][Jd70<S1^`80@FWQ2038`K/00`2][Jd0@FWQ045Yh@040<S1^`<0@FWQ
1038`K/2045Yh@H0b<6k1@11JN4@0<O1_0030:f][@36`;`0a/2l00H0a/2l0P11JN440<K0_005045Y
h@36`;`0@FWQ0<K0_02][Jd01033_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0
];2a0;B`/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0
202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]
0;jg[00A0;jg[0030:f][@31^[00@FWQ00T0`KZ`00<0@FWQ0<6j/031^[000`31^[02045Yh@030<6j
/02][Jd0@FWQ00<0@FWQ1`33_K<00`11JN40`kfc0<>m/`040<>m/`04045Yh@33_K<0`kfc0:f][@<0
aKje00<0@FWQ0<Fn]@35_[D01@35_[D2045Yh@L0aKje0P11JN400`2][Jd0a[ng0<Jo]`040<Jo]`80
@FWQ0`36_kL40:f][@80@FWQ1@2][Jd2045Yh@P0[Jf]00<0@FWQ0:f][@2][Jd0102][Jd3045Yh@`0
[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd;0<O1^P030:f][@38`K/0b<6k00/0b<6k00<0@FWQ0<S1^`38
`K/01P38`K/00`2][Jd0@FWQ045Yh@040<S1^`80@FWQ00<0b<6k045Yh@38`K/00P38`K/00`11JN40
b<6k0<S1^`050<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`2045Yh@80
a/2l00L0@FWQ0<K0_036`;`0@FWQ0<K0_02][Jd0`kfk00<0[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[0040:f][@31^[00@FWQ
045Yh@L0`KZ`0P11JN480<6j/0030:f][@33_K<0`kfc00T0`kfc00<0@FWQ0<>m/`33_K<00`33_K<0
1@11JN40`kfc0<>m/`33_K<0[Jf]00<0aKje0P11JN450<Fn]@80@FWQ2035_[D2045Yh@030:f][@36
_kL0a[ng00@0a[ng0P11JN470<Jo]`80@FWQ1P36_kL2045Yh@H0al6h00<0@FWQ0<O1^011JN401037
`KP3045Yh@H0al6h00<0@FWQ0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P0=0<O1^P030:f][@38
`K/0b<6k00/0b<6k00<0@FWQ0<S1^`38`K/01P38`K/00`2][Jd0@FWQ045Yh@040<S1^`80@FWQ0P38
`K/4045Yh@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0080<K0_0<0@FWQ0`36
`;`40:f][@h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`
h>H0/>3V04/0/>3V0@3oool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00@0[Jf]0<6j/031^[00@FWQ1`31
^[02045Yh@P0`KZ`00<0[Jf]0<>m/`33_K<02P33_K<5045Yh@@0`kfc00L0[Jf]0<Fn]@35_[D0aKje
045Yh@35_[D0@FWQ00@0aKje0P11JN480<Fn]@<0@FWQ1P36_kL2045Yh@L0a[ng0P11JN460<Jo]`80
@FWQ1`37`KP2045Yh@@0al6h00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6j0<O1^P040<O1^P03
045Yh@37`KX0al6j00d0al6j00<0[Jf]0<S1^`38`K/02`38`K/00`11JN40b<6k0<S1^`060<S1^`03
0:f][@11JN40@FWQ0080b<6k0`11JN4>0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^003
0:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M
0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/
00<0[Jf]0<6j/031^[000P11JN460<6j/003045Yh@31^[00`KZ`00L0`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0@FWQ045Yh@02045Yh@80aKje1011JN4:0<Fn]@80@FWQ00<0[Jf]045Yh@36_kL0
0`36_kL2045Yh@P0a[ng0P11JN460<Jo]`80@FWQ1`37`KP00`11JN40al6h0<O1^0030<O1^003045Y
h@37`KP0al6h00H0al6h00<0@FWQ0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P0=0<O1^P030:f]
[@38`K/0b<6k00/0b<6k00<0@FWQ0<S1^`38`K/01P38`K/2045YhA@0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f]
[@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]
0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
1`2n]j`40:f][@D0_[N/00D0[Jf]0<6j/031^[00`KZ`045Yh@050<6j/080@FWQ2@31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0180aKje0P11JN400`2][Jd0a[ng045Yh@030<Jo]`80
@FWQ2036_kL2045Yh@H0a[ng00<0[Jf]045Yh@11JN401@37`KP00`11JN40al6h0<O1^0050<O1^003
045Yh@37`KP0al6h00@0al6h0P11JN450<O1^P80@FWQ3`37`KX00`2][Jd0b<6k0<S1^`0;0<S1^`03
045Yh@38`K/0b<6k00H0b<6k0P11JN4D0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0
];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/0030<6j/080@FWQ0P31^[000`11JN40
`KZ`045Yh@090<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D04P35_[D2045Yh@03
0:f][@36_kL0a[ng00@0@FWQ1`36_kL4045Yh@H0a[ng00<0[Jf]0<O1^037`KP01@11JN490<O1^0H0
@FWQ00<0al6h045Yh@37`KX01037`KX3045Yh@h0al6j00<0[Jf]0<S1^`38`K/02`38`K/00`11JN40
b<6k0<S1^`060<S1^`80@FWQ5038`K/00`2][Jd0al6l0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]
3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][Jd30<6j/080@FWQ
0P31^[000`11JN40`KZ`0<6j/0070<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
4P35_[D2045Yh@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P030<O1^P<0@FWQ3P37`KX00`2][Jd0b<6k0<S1^`0;0<S1^`03045Yh@38`K/0b<6k00D0b<6k
0P11JN4E0<S1^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`
h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31
^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0180aKje
0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
0`37`KX3045Yh@h0al6j00<0[Jf]0<S1^`38`K/02`38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ
5@38`K/00`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2]
[Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0180aKje0P11
JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00`37
`KX3045Yh@h0al6j00<0[Jf]0<S1^`38`K/02`38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d
0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[003`31^[070:f][A80`kfc00<0[Jf]0<Fn]@35_[D04P35_[D2045Yh@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P030<O1^P<0@FWQ3P37`KX0
0`2][Jd0b<6k0<S1^`0;0<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN400`2][Jd0b<6k0<S1^`0@
0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc
0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0B0<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00<0al6j0`11JN4>0<O1^P030:f][@38`K/0
b<6k00/0b<6k00<0@FWQ0<S1^`38`K/00`38`K/2045Yh@030<S1^`2][Jd0b<6k00X0b<6k1`2][Jd3
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V
00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
00P0`kfc202][Jd30<>m/`030:f][@35_[D0aKje0180aKje0P11JN400`2][Jd0a[ng0<Jo]`0=0<Jo
]`03045Yh@36_kL0a[ng00D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P030<O1
^P<0@FWQ3P37`KX00`2][Jd0b<6k0<S1^`080<S1^`T0@FWQ0`38`K/0102][Jd0b<6k0<S1^`38`K/8
0:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][@d0aKje1011JN400`2]
[Jd0a[ng0<Jo]`0<0<Jo]`03045Yh@36_kL0@FWQ00H0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P030<O1^P80@FWQ3`37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f]
[FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@03
0:f][@36_kL0a[ng00d0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37`KX03@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0
[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/00`33_K/30:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H4
0:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool0
08`0/>3V102][Jd@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0
[Jf]2`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`00`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0[Jf]00<0[Jf]PP2`h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80
/>3V1`2][JdB0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0@0<S1^`L0[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo
00300;3PiPP0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0
[Jf]0<S1^`38`K/0b<6k202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`090<S1^`l0[Jf][`2`h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3P
iT40[Jf]e@2`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54357 .33071 m
.53188 .33087 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5068 .334 m
.50347 .33074 L
s
.50347 .33074 m
.50013 .33068 L
s
.50847 .33402 m
.50347 .33074 L
s
.50013 .33068 m
.49511 .33378 L
s
.55691 .33039 m
.54691 .33065 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45205 .32871 m
.45458 .32885 L
s
.255 .412 .882 r
.51937 .33861 m
.53096 .33859 L
s
.50117 .33842 m
.51275 .33858 L
s
.54421 .34067 m
.54751 .33835 L
s
.54751 .33835 m
.55081 .33827 L
s
.54255 .3407 m
.54751 .33835 L
s
.55081 .33827 m
.55577 .3404 L
s
.48302 .33793 m
.49456 .33827 L
s
.53925 .34526 m
.54255 .3407 L
s
0 0 0 r
.56372 .34945 m
.57032 .34922 L
s
.255 .412 .882 r
.54091 .34524 m
.54421 .34067 L
s
0 0 0 r
.51177 .36627 m
.51301 .35919 L
s
.51009 .36626 m
.51133 .35919 L
s
.255 .412 .882 r
.44718 .32031 m
.45855 .32103 L
s
0 0 0 r
.53528 .36626 m
.53649 .35913 L
s
.255 .412 .882 r
.55577 .3404 m
.55909 .34481 L
s
.53761 .35206 m
.53925 .34526 L
s
.53927 .35203 m
.54091 .34524 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49502 .36277 m
.49335 .3595 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57058 .33762 m
.57063 .34665 L
s
.57058 .33762 m
.57225 .34206 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53761 .35206 m
.53762 .35658 L
s
.53927 .35203 m
.53928 .35656 L
s
.57387 .33973 m
.57714 .33732 L
s
.57714 .33732 m
.58368 .33699 L
s
.57225 .34206 m
.57387 .33973 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49478 .36322 m
.49502 .36277 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48941 .38574 m
.48961 .33814 L
s
.48776 .38569 m
.48796 .33809 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57063 .34665 m
.57225 .34206 L
s
.46332 .33707 m
.46822 .33958 L
s
.46822 .33958 m
.47147 .34424 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52434 .33862 m
.52435 .37027 L
s
.526 .33861 m
.52601 .37026 L
s
.50774 .36337 m
.50778 .33852 L
s
.50608 .36335 m
.50613 .3385 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46332 .33707 m
.46658 .3395 L
s
.46005 .3369 m
.46332 .33707 L
s
.46658 .3395 m
.46983 .34417 L
s
.53762 .35658 m
.53929 .36335 L
s
.53928 .35656 m
.54095 .36333 L
s
.58368 .33699 m
.58697 .33907 L
s
.47147 .34424 m
.47307 .3511 L
s
.45677 .33897 m
.46005 .3369 L
s
.46983 .34417 m
.47142 .35103 L
s
.58697 .33907 m
.58862 .34123 L
s
.45348 .3433 m
.45677 .33897 L
s
.50607 .36788 m
.50774 .36337 L
s
.53929 .36335 m
.54262 .36783 L
s
.50441 .36786 m
.50608 .36335 L
s
.54095 .36333 m
.54428 .3678 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47304 .35563 m
.47307 .3511 L
s
.5575 .35842 m
.55916 .36064 L
s
.55585 .36074 m
.5575 .35842 L
s
.4714 .35556 m
.47142 .35103 L
s
.58862 .34123 m
.58867 .34802 L
s
.55585 .36074 m
.55752 .36296 L
s
.55916 .36064 m
.55917 .36291 L
s
.48951 .363 m
.4928 .36763 L
s
.50109 .37007 m
.50607 .36788 L
s
.50109 .37007 m
.50441 .36786 L
s
.47135 .36236 m
.47304 .35563 L
s
.54262 .36783 m
.5476 .37001 L
s
.51936 .37026 m
.52601 .37026 L
s
.54428 .3678 m
.5476 .37001 L
s
.55588 .36754 m
.55917 .36291 L
s
.46971 .36229 m
.4714 .35556 L
s
.58704 .34811 m
.58865 .34575 L
s
.57562 .35548 m
.58378 .35055 L
s
.57234 .35789 m
.57562 .35548 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57071 .36023 m
.57234 .35789 L
s
.58378 .35055 m
.58704 .34811 L
s
.60158 .33588 m
.60322 .33802 L
s
.59998 .33825 m
.60158 .33588 L
s
.44218 .33576 m
.44379 .33587 L
s
.49777 .37001 m
.50109 .37007 L
s
.4928 .36763 m
.49777 .37001 L
s
.59998 .33825 m
.60162 .3404 L
s
.58706 .35037 m
.58867 .34802 L
s
.57071 .36023 m
.57074 .36477 L
s
.5476 .37001 m
.55258 .3699 L
s
.43892 .33778 m
.44218 .33576 L
s
.44054 .3379 m
.44218 .33576 L
s
.55258 .3699 m
.55588 .36754 L
s
.57563 .35775 m
.5838 .35282 L
s
.57236 .36016 m
.57563 .35775 L
s
.57072 .3625 m
.57236 .36016 L
s
.5838 .35282 m
.58706 .35037 L
s
.60162 .3404 m
.60322 .33802 L
s
.43888 .34231 m
.44054 .3379 L
s
.46803 .36675 m
.47135 .36236 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45326 .36826 m
.45367 .32074 L
s
.45163 .36816 m
.45204 .32064 L
s
.57074 .36477 m
.5724 .36697 L
s
.46639 .36668 m
.46971 .36229 L
s
.43726 .34219 m
.43892 .33778 L
s
.52435 .38163 m
.52601 .3839 L
s
.52268 .38391 m
.52435 .38163 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5724 .36697 m
.57571 .3691 L
s
0 0 0 r
.56212 .38808 m
.56218 .3884 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43871 .3582 m
.43888 .34231 L
s
.43409 .33741 m
.43726 .34219 L
s
.4309 .33489 m
.43409 .33741 L
s
.52268 .38391 m
.52435 .38618 L
s
.52435 .38618 m
.52601 .3839 L
s
.46309 .36879 m
.46803 .36675 L
s
.42609 .33448 m
.4309 .33489 L
s
.58716 .36399 m
.58876 .35935 L
s
.58876 .35935 m
.58884 .36845 L
s
.43705 .36263 m
.43726 .34219 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46309 .36879 m
.46639 .36668 L
s
.57571 .3691 m
.58228 .36879 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58554 .36635 m
.58716 .36399 L
s
.58716 .36399 m
.58884 .36845 L
s
.58228 .36879 m
.58554 .36635 L
s
.45981 .36862 m
.46309 .36879 L
s
.42287 .33646 m
.42609 .33448 L
s
.42127 .33631 m
.42609 .33448 L
s
.45332 .36144 m
.45655 .36617 L
s
.45655 .36617 m
.45981 .36862 L
s
.48278 .38554 m
.48941 .38574 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40511 .32609 m
.40513 .3247 L
s
.5 Mabswid
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42122 .34085 m
.42287 .33646 L
s
.44674 .36786 m
.45326 .36826 L
s
.41962 .3407 m
.42127 .33631 L
s
.43705 .36263 m
.43871 .3582 L
s
.42587 .35264 m
.4355 .35569 L
s
.4355 .35569 m
.43709 .35808 L
s
.42116 .34539 m
.42122 .34085 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41956 .34525 m
.41962 .3407 L
s
.43541 .36479 m
.43705 .36263 L
s
.42116 .34539 m
.4227 .35008 L
s
.4227 .35008 m
.42587 .35264 L
s
.4211 .34994 m
.42587 .35264 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41956 .34525 m
.4211 .34994 L
s
.43215 .36683 m
.43541 .36479 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60186 .36537 m
.60199 .37905 L
s
.60037 .37916 m
.60173 .35173 L
s
.60173 .35173 m
.60362 .37894 L
s
.60037 .37916 m
.60204 .38362 L
s
.42571 .36631 m
.43215 .36683 L
s
.60204 .38362 m
.60362 .37894 L
s
.42099 .35905 m
.42259 .35919 L
s
.42256 .36147 m
.42259 .35919 L
s
.42096 .36133 m
.42099 .35905 L
s
.42253 .36375 m
.42571 .36631 L
s
.42096 .36133 m
.42253 .36375 L
s
.38833 .33044 m
.3992 .33176 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40469 .35563 m
.40472 .35333 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39402 .36318 m
.39453 .33121 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39246 .363 m
.39297 .33102 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65456 .33076 m
.66991 .32872 L
s
.40508 .3598 m
.40669 .35768 L
s
.40669 .35768 m
.40823 .36013 L
s
.4082 .36241 m
.40823 .36013 L
s
.40659 .36454 m
.4082 .36241 L
s
.40508 .3598 m
.40662 .36225 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40186 .36405 m
.40659 .36454 L
s
.39424 .34945 m
.39569 .35649 L
s
.39875 .36142 m
.40186 .36405 L
s
.39569 .35649 m
.39875 .36142 L
s
.37879 .34752 m
.37912 .32923 L
s
0 0 0 r
.36321 .31917 m
.36436 .31935 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37726 .34731 m
.37759 .32902 L
s
.66991 .32872 m
.67298 .33057 L
s
.66991 .32872 m
.67449 .33035 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65919 .33017 m
.66 .3783 L
s
.3878 .36245 m
.39402 .36318 L
s
.37451 .33087 m
.37747 .33587 L
s
.37001 .32793 m
.37451 .33087 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3727 .34668 m
.3834 .34812 L
s
.67298 .33057 m
.67609 .3347 L
s
.367 .32748 m
.37001 .32793 L
s
.67449 .33035 m
.6776 .33448 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36396 .3293 m
.367 .32748 L
s
.36246 .32907 m
.367 .32748 L
s
.67609 .3347 m
.67768 .33906 L
s
.6776 .33448 m
.67919 .33884 L
s
.36088 .33342 m
.36396 .3293 L
s
.67768 .33906 m
.67932 .34572 L
s
.35939 .33318 m
.36246 .32907 L
s
.67919 .33884 m
.68082 .3455 L
s
.37827 .37742 m
.37851 .36359 L
s
.37685 .3703 m
.37851 .36359 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65534 .37884 m
.67078 .37694 L
s
.66073 .32997 m
.66155 .37811 L
s
.3593 .33778 m
.36088 .33342 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67932 .34572 m
.67954 .35723 L
s
.35781 .33754 m
.35939 .33318 L
s
.68082 .3455 m
.68105 .35701 L
s
.37371 .37451 m
.37685 .3703 L
s
.37685 .3703 m
.37827 .37742 L
s
.35767 .34444 m
.3593 .33778 L
s
.35619 .3442 m
.35781 .33754 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69087 .32548 m
.69154 .35771 L
s
.68643 .32622 m
.69674 .32448 L
s
.67817 .36436 m
.67954 .35723 L
s
.3691 .3762 m
.37371 .37451 L
s
.67078 .37694 m
.67379 .37422 L
s
.67078 .37694 m
.67531 .37402 L
s
.67968 .36414 m
.68105 .35701 L
s
.67674 .36919 m
.67817 .36436 L
s
.35744 .35596 m
.35767 .34444 L
s
.67379 .37422 m
.67674 .36919 L
s
.67825 .36898 m
.67968 .36414 L
s
.35595 .35573 m
.35619 .3442 L
s
.67531 .37402 m
.67825 .36898 L
s
.36607 .37578 m
.3691 .3762 L
s
.69273 .34363 m
.69435 .3503 L
s
.35744 .35596 m
.35879 .36312 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3616 .37282 m
.36607 .37578 L
s
.3631 .37304 m
.36607 .37578 L
s
.35595 .35573 m
.3573 .36289 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35879 .36312 m
.36019 .36797 L
s
.36019 .36797 m
.3631 .37304 L
s
.34051 .32301 m
.34559 .35635 L
s
.33403 .3543 m
.34051 .32301 L
s
.3573 .36289 m
.35869 .36774 L
s
.35869 .36774 m
.3616 .37282 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69435 .3503 m
.69738 .35444 L
s
.68708 .35841 m
.69302 .35747 L
s
.69234 .32524 m
.69302 .35747 L
s
0 0 0 r
.32227 .31165 m
.32284 .31177 L
s
.255 .412 .882 r
.33546 .35456 m
.34035 .32991 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34123 .3556 m
.34999 .35709 L
s
.69738 .35444 m
.70036 .35625 L
s
.70036 .35625 m
.70472 .3555 L
s
.70317 .35112 m
.70467 .35318 L
s
.70317 .35112 m
.70456 .34855 L
s
.70456 .34855 m
.70606 .35061 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32912 .32079 m
.33403 .3543 L
s
.32273 .35211 m
.32912 .32079 L
s
.70606 .35061 m
.70611 .35292 L
s
.71686 .32298 m
.72101 .31981 L
s
.71557 .32789 m
.71686 .32298 L
s
.70472 .3555 m
.70611 .35292 L
s
.71557 .32789 m
.71568 .33251 L
s
.32413 .35239 m
.32896 .32771 L
s
.71827 .3227 m
.72101 .31981 L
s
.71697 .32761 m
.71827 .3227 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71697 .32761 m
.71709 .33223 L
s
.71568 .33251 m
.7172 .33686 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72101 .31981 m
.72517 .31891 L
s
.71709 .33223 m
.7186 .33658 L
s
.7172 .33686 m
.72146 .33833 L
s
.7186 .33658 m
.72146 .33833 L
s
.72517 .31891 m
.72798 .32062 L
s
.71742 .34614 m
.71747 .34846 L
s
.71742 .34614 m
.71883 .34586 L
s
.71747 .34846 m
.71894 .35051 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71883 .34586 m
.71888 .34819 L
s
.31526 .31781 m
.31663 .31812 L
s
.31856 .35125 m
.32835 .35322 L
s
.71894 .35051 m
.7218 .35228 L
s
.31248 .31951 m
.31526 .31781 L
s
.31384 .31982 m
.31526 .31781 L
s
.31236 .32416 m
.31384 .31982 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72146 .33833 m
.72982 .3389 L
s
.72798 .32062 m
.73083 .32465 L
s
.73207 .3197 m
.73472 .31676 L
s
.73083 .32465 m
.73207 .3197 L
s
.73083 .32465 m
.73137 .34559 L
s
.7218 .35228 m
.72736 .35114 L
s
.31101 .32385 m
.31248 .31951 L
s
.73343 .31939 m
.73472 .31676 L
s
.73219 .32435 m
.73343 .31939 L
s
.73219 .32435 m
.73261 .34063 L
s
.73472 .31676 m
.73607 .31644 L
s
.31194 .34045 m
.31236 .32416 L
s
.30843 .31857 m
.31101 .32385 L
s
.31046 .34481 m
.31101 .32385 L
s
.72982 .3389 m
.73125 .34093 L
s
.30582 .31561 m
.30843 .31857 L
s
.72736 .35114 m
.73006 .34822 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30185 .31463 m
.30582 .31561 L
s
.73006 .34822 m
.73137 .34559 L
s
.73137 .34559 m
.73261 .34063 L
s
.31046 .34481 m
.31194 .34045 L
s
.30929 .3375 m
.31058 .34014 L
s
.30134 .33328 m
.30929 .3375 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29916 .31629 m
.30185 .31463 L
s
.29785 .31596 m
.30185 .31463 L
s
.30904 .34684 m
.31046 .34481 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30629 .34857 m
.30904 .34684 L
s
.29772 .32062 m
.29916 .31629 L
s
.74797 .3135 m
.75407 .34494 L
s
.74362 .34752 m
.74797 .3135 L
s
.29642 .32029 m
.29785 .31596 L
s
.30096 .34733 m
.30629 .34857 L
s
.29877 .33029 m
.30134 .33328 L
s
.29746 .32997 m
.30134 .33328 L
s
.73962 .34845 m
.74889 .34625 L
s
.29759 .32529 m
.29772 .32062 L
s
.74494 .34721 m
.74817 .32049 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29629 .32496 m
.29642 .32029 L
s
.29759 .32529 m
.29877 .33029 L
s
0 0 0 r
.28468 .30238 m
.2848 .30257 L
s
.255 .412 .882 r
.29629 .32496 m
.29746 .32997 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29838 .34435 m
.30096 .34733 L
s
.2972 .33933 m
.29851 .33966 L
s
.29845 .342 m
.29851 .33966 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29714 .34168 m
.2972 .33933 L
s
.29714 .34168 m
.29838 .34435 L
s
.75822 .31074 m
.7642 .34224 L
s
.75407 .34494 m
.75822 .31074 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75536 .34461 m
.75843 .31776 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2717 .30612 m
.28017 .30872 L
s
.28564 .33633 m
.28684 .33903 L
s
.28677 .34138 m
.28684 .33903 L
s
.28431 .33834 m
.28564 .33633 L
s
.28543 .3434 m
.28677 .34138 L
s
.28431 .33834 m
.2855 .34104 L
s
.28167 .34237 m
.28543 .3434 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2755 .34062 m
.27651 .30762 L
s
.76044 .34327 m
.76791 .34119 L
s
.27429 .34027 m
.2753 .30724 L
s
.27926 .33932 m
.28167 .34237 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27694 .33389 m
.27926 .33932 L
s
.27594 .32644 m
.27694 .33389 L
s
.77437 .31303 m
.77659 .30756 L
s
.77332 .31813 m
.77437 .31303 L
s
.77234 .32558 m
.77332 .31813 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77234 .32558 m
.7727 .3374 L
s
.77659 .30756 m
.78002 .30404 L
s
.77556 .31266 m
.77776 .30718 L
s
.77452 .31775 m
.77556 .31266 L
s
.77354 .32521 m
.77452 .31775 L
s
.27067 .33919 m
.2755 .34062 L
s
.77354 .32521 m
.77391 .33704 L
s
.77776 .30718 m
.78002 .30404 L
s
.7727 .3374 m
.77413 .34416 L
s
.78002 .30404 m
.78233 .30326 L
s
.77391 .33704 m
.77532 .3438 L
s
.78233 .30326 m
.78582 .30444 L
s
.26228 .30538 m
.26443 .31089 L
s
.26443 .31089 m
.26544 .31601 L
s
.26544 .31601 m
.26638 .32349 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77413 .34416 m
.77547 .34855 L
s
.26601 .33535 m
.26638 .32349 L
s
.25895 .30182 m
.26228 .30538 L
s
.26114 .30499 m
.26327 .3105 L
s
.26327 .3105 m
.26428 .31562 L
s
.26428 .31562 m
.26521 .32311 L
s
.77532 .3438 m
.77667 .34819 L
s
.26484 .33497 m
.26521 .32311 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25895 .30182 m
.26114 .30499 L
s
.77547 .34855 m
.778 .35259 L
s
.26461 .34211 m
.26601 .33535 L
s
.77667 .34819 m
.77918 .35223 L
s
.78582 .30444 m
.78823 .30838 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26345 .34174 m
.26484 .33497 L
s
.78799 .30127 m
.78862 .32025 L
s
.778 .35259 m
.78161 .35389 L
s
.26329 .34651 m
.26461 .34211 L
s
.78911 .30086 m
.78973 .31986 L
s
.78523 .32143 m
.79305 .31866 L
s
.77918 .35223 m
.78161 .35389 L
s
.26213 .34614 m
.26345 .34174 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.248 .29772 m
.25895 .30182 L
s
0 0 0 r
.79789 .29001 m
.79897 .28959 L
s
.255 .412 .882 r
.26083 .35054 m
.26329 .34651 L
s
.78161 .35389 m
.78393 .35316 L
s
.25968 .35017 m
.26213 .34614 L
s
.25063 .34954 m
.2523 .29938 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78393 .35316 m
.78729 .34965 L
s
.25732 .35182 m
.26083 .35054 L
s
.25732 .35182 m
.25968 .35017 L
s
.78729 .34965 m
.7894 .34411 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24954 .34915 m
.25122 .29897 L
s
.79028 .33655 m
.79076 .35092 L
s
.7894 .34411 m
.79028 .33655 L
s
.7894 .34411 m
.79076 .35092 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79885 .29714 m
.8 .3306 L
s
.7999 .29671 m
.80105 .33019 L
s
.79566 .29839 m
.80301 .29543 L
s
.79679 .3318 m
.80105 .33019 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2463 .34798 m
.25732 .35182 L
s
.80056 .31581 m
.80185 .32259 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80185 .32259 m
.80409 .32656 L
s
.80409 .32656 m
.80623 .32814 L
s
.80623 .32814 m
.80925 .32689 L
s
.80808 .32249 m
.80917 .32448 L
s
.80808 .32249 m
.809 .31966 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.809 .31966 m
.81008 .32164 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80925 .32689 m
.81016 .32406 L
s
.81008 .32164 m
.81016 .32406 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81605 .2969 m
.81681 .29164 L
s
.81605 .2969 m
.81622 .30172 L
s
.81681 .29164 m
.81948 .28786 L
s
.81622 .30172 m
.81733 .3061 L
s
.81698 .29645 m
.81773 .29118 L
s
.81698 .29645 m
.81716 .30128 L
s
.81773 .29118 m
.81948 .28786 L
s
.81716 .30128 m
.81826 .30566 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81948 .28786 m
.82217 .28647 L
s
.81733 .3061 m
.82019 .30718 L
s
.81826 .30566 m
.82019 .30718 L
s
.81769 .31577 m
.81777 .31819 L
s
.81769 .31577 m
.81862 .31533 L
s
.81777 .31819 m
.81879 .32018 L
s
.82217 .28647 m
.82401 .28796 L
s
.81862 .31533 m
.8187 .31776 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82019 .30718 m
.82561 .30689 L
s
.81879 .32018 m
.82072 .32173 L
s
.82401 .28796 m
.82592 .29186 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82072 .32173 m
.82431 .31995 L
s
.82592 .29186 m
.82659 .28655 L
s
.82592 .29186 m
.82674 .31373 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82659 .28655 m
.82818 .28318 L
s
.82677 .29139 m
.82744 .28607 L
s
.82677 .29139 m
.82741 .3084 L
s
.82744 .28607 m
.82818 .28318 L
s
.83 .26478 m
.83545 .2613 L
s
.82818 .28318 m
.82901 .2827 L
s
.82561 .30689 m
.82656 .30886 L
s
.82431 .31995 m
.82597 .31662 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82597 .31662 m
.82674 .31373 L
s
.82674 .31373 m
.82741 .3084 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83316 .2628 m
.83514 .31402 L
s
.83238 .2633 m
.83435 .31448 L
s
.8341 .28711 m
.83545 .28126 L
s
.83195 .31587 m
.83514 .31402 L
s
.83545 .28126 m
.83686 .27784 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83686 .27784 m
.83834 .27685 L
s
.83485 .30666 m
.83659 .31062 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83834 .27685 m
.83987 .2783 L
s
.83834 .27685 m
.84058 .2778 L
s
.83659 .31062 m
.8382 .31214 L
s
0 0 0 r
.84744 .26351 m
.84761 .26338 L
s
.255 .412 .882 r
.83987 .2783 m
.84148 .2822 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84058 .2778 m
.84217 .2817 L
s
.8382 .31214 m
.83968 .31119 L
s
.84148 .2822 m
.84246 .28907 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83968 .31119 m
.84103 .30777 L
s
.83968 .31119 m
.84174 .30729 L
s
.84217 .2817 m
.84315 .28858 L
s
.84246 .28907 m
.84266 .29399 L
s
.84103 .30777 m
.84225 .30187 L
s
0 0 0 r
.84803 .2739 m
.84907 .26584 L
s
.255 .412 .882 r
.84225 .30187 m
.84266 .29399 L
s
.84315 .28858 m
.84334 .2935 L
s
.84174 .30729 m
.84295 .30139 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20023 .27692 m
.20098 .27497 L
s
.20043 .272 m
.20098 .27497 L
s
.84295 .30139 m
.84334 .2935 L
s
.19968 .27395 m
.20043 .272 L
s
.19968 .27395 m
.20023 .27692 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19921 .31945 m
.19974 .28924 L
s
.1979 .31849 m
.19974 .28924 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84881 .29306 m
.84882 .29344 L
s
.85011 .32531 m
.8506 .33754 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84648 .27078 m
.85067 .26715 L
s
.19855 .31897 m
.19915 .30408 L
s
.19835 .32394 m
.19921 .31945 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19484 .26982 m
.19532 .27282 L
s
.19501 .28024 m
.19532 .27282 L
s
.1979 .31849 m
.19835 .32394 L
s
.19382 .2663 m
.19484 .26982 L
s
.19444 .27973 m
.19511 .27777 L
s
.19434 .28221 m
.19501 .28024 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84833 .26923 m
.85043 .32135 L
s
.84893 .26871 m
.85104 .32087 L
s
.19168 .26419 m
.19382 .2663 L
s
.85003 .29595 m
.8514 .29992 L
s
.19321 .28118 m
.19444 .27973 L
s
.84857 .3228 m
.85104 .32087 L
s
.19311 .28366 m
.19434 .28221 L
s
.19373 .29712 m
.19451 .29265 L
s
.19411 .30261 m
.19451 .29265 L
s
.85286 .26504 m
.85635 .26132 L
s
.19035 .28357 m
.19321 .28118 L
s
.8514 .29992 m
.8532 .30091 L
s
.19025 .28607 m
.19311 .28366 L
s
.19373 .29712 m
.19411 .30261 L
s
.19306 .29911 m
.19373 .29712 L
s
.19057 .26561 m
.19168 .26419 L
s
.19185 .3006 m
.19306 .29911 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85441 .26345 m
.85554 .29087 L
s
.85491 .26292 m
.85604 .29036 L
s
.8532 .30091 m
.85429 .2999 L
s
.18997 .26757 m
.19057 .26561 L
s
.18973 .29858 m
.19185 .3006 L
s
.18969 .26206 m
.18997 .26757 L
s
.18928 .27203 m
.18997 .26757 L
s
.18928 .27203 m
.18969 .26206 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85429 .2999 m
.85524 .29638 L
s
.85429 .2999 m
.85575 .29587 L
s
.18925 .28504 m
.19035 .28357 L
s
.18914 .28754 m
.19025 .28607 L
s
.85524 .29638 m
.85554 .29087 L
s
.18866 .28702 m
.18925 .28504 L
s
.85575 .29587 m
.85604 .29036 L
s
.18883 .29505 m
.18973 .29858 L
s
.18855 .28952 m
.18914 .28754 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86212 .24916 m
.8628 .24828 L
s
.255 .412 .882 r
.18845 .29203 m
.18866 .28702 L
s
.18845 .29203 m
.18883 .29505 L
s
.85815 .25916 m
.86092 .25535 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8628 .24828 m
.86376 .25073 L
s
.255 .412 .882 r
.18564 .2597 m
.18625 .26579 L
s
.85939 .25753 m
.86087 .29271 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85979 .25699 m
.86127 .29219 L
s
.18461 .25556 m
.18564 .2597 L
s
.18541 .28588 m
.18551 .28336 L
s
.18521 .28032 m
.18551 .28336 L
s
.85961 .29427 m
.86127 .29219 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18438 .28987 m
.18541 .28588 L
s
.1847 .28231 m
.18521 .28032 L
s
.18389 .25446 m
.18461 .25556 L
s
.1847 .28231 m
.18499 .28535 L
s
.18311 .25588 m
.18389 .25446 L
s
.18279 .25533 m
.18389 .25446 L
s
.1835 .29135 m
.18438 .28987 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86651 .29619 m
.86652 .29638 L
s
.86481 .26584 m
.86519 .27466 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86109 .3084 m
.86139 .30535 L
s
.86109 .3084 m
.86161 .31042 L
s
.18226 .25982 m
.18311 .25588 L
s
.86139 .30535 m
.8619 .30737 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1824 .28978 m
.1835 .29135 L
s
.86161 .31042 m
.8619 .30737 L
s
.18195 .25927 m
.18279 .25533 L
s
.86294 .26015 m
.86333 .25401 L
s
.86294 .26827 m
.86294 .26015 L
s
.86294 .26827 m
.86315 .27332 L
s
0 0 0 r
.86907 .23612 m
.87063 .23174 L
s
.255 .412 .882 r
.18163 .26685 m
.18226 .25982 L
s
.86325 .25961 m
.86363 .25346 L
s
.86325 .25961 m
.86326 .26773 L
s
.86315 .27332 m
.86379 .28038 L
s
.86333 .25401 m
.86407 .24982 L
s
.86326 .26773 m
.86347 .27278 L
s
.18183 .28619 m
.1824 .28978 L
s
.1815 .28566 m
.1824 .28978 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18134 .2663 m
.18195 .25927 L
s
.86347 .27278 m
.8641 .27984 L
s
.86363 .25346 m
.86407 .24982 L
s
.1814 .28005 m
.18183 .28619 L
s
.18142 .27191 m
.18163 .26685 L
s
.86379 .28038 m
.86462 .28439 L
s
.86407 .24982 m
.86458 .2487 L
s
.1814 .28005 m
.18142 .27191 L
s
.1811 .27952 m
.1815 .28566 L
s
.18112 .27137 m
.18134 .2663 L
s
.8641 .27984 m
.86491 .28385 L
s
.1811 .27952 m
.18112 .27137 L
s
.1794 .24499 m
.1809 .24892 L
s
.86458 .2487 m
.86538 .24956 L
s
.86462 .28439 m
.86558 .28533 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86491 .28385 m
.86558 .28533 L
s
.17868 .28286 m
.1802 .24724 L
s
.86538 .24956 m
.86601 .25352 L
s
.17847 .28232 m
.17999 .24668 L
s
.86558 .28533 m
.86634 .28373 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86634 .28373 m
.86668 .2801 L
s
.86635 .27244 m
.86646 .26935 L
s
.86635 .27244 m
.86668 .27445 L
s
0 0 0 r
.87238 .31278 m
.87397 .3088 L
s
.87083 .27682 m
.87179 .27413 L
s
.255 .412 .882 r
.86646 .26935 m
.86677 .27135 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86668 .2801 m
.86688 .27391 L
s
.17788 .28071 m
.17868 .28286 L
s
.86677 .27135 m
.86688 .27391 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17806 .23874 m
.17877 .24273 L
s
.1777 .30027 m
.17803 .29823 L
s
.17792 .29513 m
.17803 .29823 L
s
.1776 .29717 m
.17792 .29513 L
s
.1776 .29717 m
.1777 .30027 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8668 .24194 m
.86724 .25215 L
s
.8668 .24194 m
.86714 .24648 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17719 .26919 m
.1784 .24102 L
s
.86714 .24648 m
.86724 .25215 L
s
.86714 .24336 m
.86714 .24648 L
s
.86714 .24336 m
.86721 .23966 L
s
.17709 .26864 m
.1783 .24045 L
s
0 0 0 r
.1743 .22905 m
.17449 .21963 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86789 .26751 m
.8679 .2644 L
s
.86789 .26751 m
.86811 .27265 L
s
.868 .27008 m
.86801 .26696 L
s
.8679 .2644 m
.868 .26072 L
s
.86811 .27265 m
.86835 .27467 L
s
.86801 .26696 m
.86811 .26329 L
s
.17687 .27379 m
.17719 .26919 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86835 .27467 m
.86866 .27616 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87022 .23348 m
.87355 .31038 L
s
.87006 .23406 m
.87338 .31091 L
s
.255 .412 .882 r
.86811 .26329 m
.86823 .25536 L
s
.868 .26072 m
.86812 .25279 L
s
.86721 .23966 m
.86746 .23738 L
s
.17678 .27324 m
.17709 .26864 L
s
.86746 .23738 m
.86763 .2388 L
s
.17651 .27473 m
.17687 .27379 L
s
.17651 .27473 m
.17678 .27324 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17076 .30476 m
.17413 .22729 L
s
.17072 .30423 m
.17409 .22671 L
s
.255 .412 .882 r
.17798 .23243 m
.17788 .23645 L
s
.86763 .2388 m
.86775 .2408 L
s
.86807 .24909 m
.86812 .25279 L
s
.86818 .25166 m
.86823 .25536 L
s
.1764 .27364 m
.17651 .27473 L
s
.86775 .2408 m
.86808 .24852 L
s
.86797 .24595 m
.86807 .24909 L
s
.86808 .24852 m
.86818 .25166 L
s
.17552 .28909 m
.17786 .23473 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86866 .27616 m
.86896 .27397 L
s
.86893 .27029 m
.86896 .27397 L
s
.17642 .2694 m
.1764 .27364 L
s
.17553 .28856 m
.17787 .23416 L
s
0 0 0 r
.17233 .26713 m
.17233 .26376 L
s
.255 .412 .882 r
.86884 .26715 m
.86893 .27029 L
s
.86864 .26143 m
.86884 .26715 L
s
.86884 .26715 m
.86908 .27178 L
s
.86864 .26143 m
.86908 .27178 L
s
.17642 .2694 m
.17664 .26312 L
s
0 0 0 r
.17094 .30635 m
.17109 .2978 L
s
.17168 .27862 m
.17297 .24896 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86726 .23106 m
.86744 .23422 L
s
.86744 .23422 m
.86748 .23623 L
s
0 0 0 r
.17352 .24181 m
.17439 .22023 L
s
.255 .412 .882 r
.86726 .23106 m
.86728 .23307 L
s
.86728 .23307 m
.86748 .23623 L
s
0 0 0 r
.17449 .21963 m
.17352 .24181 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17564 .28694 m
.17552 .28909 L
s
.86803 .24917 m
.8693 .27988 L
s
.86803 .24917 m
.86945 .28097 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8687 .26477 m
.86938 .28042 L
s
.17827 .23617 m
.17877 .22983 L
s
.17781 .24453 m
.17827 .23617 L
s
.17759 .24973 m
.17781 .24453 L
s
.17793 .24397 m
.1784 .2356 L
s
.17738 .25699 m
.17759 .24973 L
s
.86945 .28097 m
.8696 .28566 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17771 .24917 m
.17784 .24619 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17751 .25643 m
.17771 .24917 L
s
.8693 .27988 m
.8696 .28566 L
s
.17743 .2611 m
.17738 .25699 L
s
0 0 0 r
.17207 .27531 m
.171 .29834 L
s
.17109 .2978 m
.17207 .27531 L
s
.255 .412 .882 r
.17758 .26055 m
.17751 .25643 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17586 .21742 m
.1767 .21193 L
s
.17533 .22544 m
.17586 .21742 L
s
.17607 .21683 m
.1767 .21193 L
s
.17554 .22486 m
.17607 .21683 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17375 .26601 m
.17554 .22486 L
s
.17355 .26656 m
.17533 .22544 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1767 .21193 m
.1772 .21074 L
s
.17301 .26824 m
.17375 .26601 L
s
.1772 .21074 m
.17789 .21269 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17789 .21269 m
.17818 .219 L
s
.17867 .20777 m
.18004 .2054 L
s
.1764 .26043 m
.17867 .20777 L
s
.17673 .25987 m
.17899 .20718 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17549 .2621 m
.17673 .25987 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18154 .21374 m
.18273 .20503 L
s
.18063 .22564 m
.18154 .21374 L
s
.255 .412 .882 r
.18671 .21262 m
.18728 .21369 L
s
.18672 .21237 m
.18775 .21311 L
s
0 0 0 r
.18273 .20503 m
.18428 .19949 L
s
.18031 .2332 m
.18063 .22564 L
s
.18196 .21315 m
.18318 .20444 L
s
.18105 .22506 m
.18196 .21315 L
s
.18318 .20444 m
.18428 .19949 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18073 .23263 m
.18105 .22506 L
s
.18024 .24401 m
.18031 .2332 L
s
.18428 .19949 m
.18526 .19831 L
s
.18067 .24344 m
.18073 .23263 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18526 .19831 m
.18667 .20033 L
s
.18024 .24401 m
.18079 .2505 L
s
.18067 .24344 m
.18125 .24994 L
s
.255 .412 .882 r
.18522 .24826 m
.18595 .24555 L
s
.18617 .24022 m
.18664 .23967 L
s
.18606 .24288 m
.18617 .24022 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18653 .24233 m
.18595 .24555 L
s
.18664 .23967 m
.18653 .24233 L
s
0 0 0 r
.18079 .2505 m
.18203 .25264 L
s
.18667 .20033 m
.18745 .20676 L
s
.18125 .24994 m
.18203 .25264 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18203 .25264 m
.18352 .25098 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18523 .23457 m
.18593 .23019 L
s
.18523 .23457 m
.18561 .23783 L
s
.18593 .23019 m
.18633 .23344 L
s
.18352 .25098 m
.18474 .24605 L
s
.1915 .19187 m
.1962 .18781 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18474 .24605 m
.18617 .23727 L
s
.18617 .23727 m
.18633 .23344 L
s
.19011 .27097 m
.19344 .19012 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19078 .27044 m
.19411 .18954 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19913 .18551 m
.20472 .18152 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19928 .23788 m
.20146 .18379 L
s
.18815 .27255 m
.19078 .27044 L
s
.20008 .23735 m
.20226 .18322 L
s
.255 .412 .882 r
.83636 .19486 m
.83689 .19463 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19694 .2395 m
.20008 .23735 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83453 .21221 m
.83467 .21021 L
s
0 0 0 r
.2095 .18974 m
.21164 .18089 L
s
.20814 .20192 m
.2095 .18974 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21164 .18089 m
.21464 .17536 L
s
.19755 .26182 m
.19849 .25738 L
s
.19755 .26182 m
.19818 .26521 L
s
.21042 .18919 m
.21258 .18034 L
s
.20905 .20138 m
.21042 .18919 L
s
.20784 .20969 m
.20814 .20192 L
s
.19849 .25738 m
.19914 .26077 L
s
.21258 .18034 m
.21464 .17536 L
s
.20874 .20915 m
.20905 .20138 L
s
.20784 .20969 m
.20828 .22084 L
s
.19818 .26521 m
.19914 .26077 L
s
.21464 .17536 m
.21659 .17426 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20874 .20915 m
.2092 .22031 L
s
.21659 .17426 m
.21844 .17704 L
s
.20828 .22084 m
.20982 .2276 L
s
.2092 .22031 m
.21076 .22708 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21844 .17704 m
.22018 .18375 L
s
.22063 .17207 m
.22485 .1699 L
s
.2175 .25454 m
.22063 .17207 L
s
.20982 .2276 m
.21252 .22996 L
s
.21854 .25405 m
.22166 .17152 L
s
.21076 .22708 m
.21252 .22996 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21252 .22996 m
.21449 .22892 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21449 .22892 m
.21664 .22395 L
s
.21664 .22395 m
.219 .21506 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23137 .17062 m
.23266 .16618 L
s
.23137 .17062 m
.23238 .17401 L
s
.23266 .16618 m
.23368 .16957 L
s
.23238 .17401 m
.23368 .16957 L
s
.255 .412 .882 r
.23294 .21008 m
.23417 .20168 L
s
0 0 0 r
.21443 .25603 m
.21854 .25405 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80783 .17174 m
.80889 .16833 L
s
.80755 .16389 m
.80889 .16833 L
s
.80648 .16729 m
.80755 .16389 L
s
.80648 .16729 m
.80783 .17174 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80822 .20705 m
.80832 .20982 L
s
.80705 .20656 m
.80822 .20705 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22993 .2412 m
.2308 .21736 L
s
.22877 .24169 m
.23166 .19365 L
s
.2311 .24072 m
.23166 .19365 L
s
.5 Mabswid
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79641 .16324 m
.79784 .16769 L
s
.79784 .16769 m
.79825 .17954 L
s
.79365 .1583 m
.79641 .16324 L
s
.22877 .24169 m
.22964 .24918 L
s
.78828 .15633 m
.79365 .1583 L
s
.79696 .17905 m
.79812 .17559 L
s
.22964 .24918 m
.2311 .24072 L
s
.79709 .18301 m
.79825 .17954 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80854 .19143 m
.81145 .23957 L
s
.80854 .19143 m
.80903 .23862 L
s
.80939 .21519 m
.81024 .2391 L
s
.79446 .18204 m
.79696 .17905 L
s
.7946 .18601 m
.79709 .18301 L
s
.81053 .2471 m
.81145 .23957 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78566 .15932 m
.78828 .15633 L
s
.78796 .18761 m
.79446 .18204 L
s
.79791 .20687 m
.79894 .19938 L
s
.79894 .19938 m
.79949 .21532 L
s
.80903 .23862 m
.81053 .2471 L
s
.7881 .1916 m
.7946 .18601 L
s
.7844 .16281 m
.78566 .15932 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78273 .1544 m
.7844 .16281 L
s
.78273 .1544 m
.78325 .17028 L
s
.79674 .21039 m
.79791 .20687 L
s
.79791 .20687 m
.79949 .21532 L
s
.78325 .17028 m
.7844 .16281 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79421 .21345 m
.79674 .21039 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78531 .19067 m
.78796 .18761 L
s
.78544 .19467 m
.7881 .1916 L
s
.78876 .21161 m
.79421 .21345 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76966 .15019 m
.77557 .15204 L
s
.5 Mabswid
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78404 .19421 m
.78531 .19067 L
s
.77116 .15065 m
.77291 .20672 L
s
.78417 .19821 m
.78544 .19467 L
s
.78404 .19421 m
.7843 .20222 L
s
.78584 .20668 m
.78876 .21161 L
s
.7843 .20222 m
.78584 .20668 L
s
.255 .412 .882 r
.76882 .18582 m
.77017 .1939 L
s
0 0 0 r
.76677 .15327 m
.77003 .16215 L
s
.76205 .14794 m
.76677 .15327 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76966 .15019 m
.77141 .20629 L
s
.75894 .14706 m
.76205 .14794 L
s
.7559 .15018 m
.75894 .14706 L
s
.75431 .14975 m
.75894 .14706 L
s
.75455 .15776 m
.7559 .15018 L
s
.75294 .15734 m
.75431 .14975 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75294 .15734 m
.75423 .20171 L
s
.75455 .15776 m
.75584 .20211 L
s
.76684 .20501 m
.77291 .20672 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72924 .13962 m
.74114 .1424 L
s
.73609 .14119 m
.73761 .19782 L
s
.73439 .1408 m
.7359 .19745 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74934 .20051 m
.75584 .20211 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71951 .17282 m
.72067 .17307 L
s
0 0 0 r
.70969 .13556 m
.72225 .1381 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71692 .13699 m
.71801 .18161 L
s
.71512 .13663 m
.71621 .18126 L
s
.73072 .19634 m
.73761 .19782 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68919 .13189 m
.70234 .13418 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73645 .21787 m
.73827 .22234 L
s
.73483 .22161 m
.73645 .21787 L
s
.73667 .22607 m
.73827 .22234 L
s
.73483 .22161 m
.73667 .22607 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71459 .18909 m
.71621 .18126 L
s
.7164 .18943 m
.71801 .18161 L
s
.69487 .13285 m
.69611 .18997 L
s
.69675 .13318 m
.69801 .19028 L
s
.71104 .19252 m
.7164 .18943 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71104 .19252 m
.71459 .18909 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70735 .19186 m
.71104 .19252 L
s
.67381 .13356 m
.67788 .14227 L
s
.66783 .12865 m
.67381 .13356 L
s
.67185 .13327 m
.67593 .14199 L
s
.66783 .12865 m
.67185 .13327 L
s
.67788 .14227 m
.68007 .1548 L
s
.66386 .1281 m
.66783 .12865 L
s
.70168 .1868 m
.70735 .19186 L
s
.67593 .14199 m
.67812 .15452 L
s
.69774 .17797 m
.70168 .1868 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65994 .13165 m
.66386 .1281 L
s
.65793 .13139 m
.66386 .1281 L
s
.68007 .1548 m
.68023 .16299 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67812 .15452 m
.67828 .1627 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69039 .18907 m
.69801 .19028 L
s
.67852 .17501 m
.68023 .16299 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67656 .17473 m
.67828 .1627 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65404 .13906 m
.65793 .13139 L
s
.65606 .13931 m
.65994 .13165 L
s
.65424 .15134 m
.65606 .13931 L
s
.65221 .1511 m
.65404 .13906 L
s
.62712 .1239 m
.64161 .12538 L
s
.67475 .18268 m
.67852 .17501 L
s
.67277 .18242 m
.67656 .17473 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65424 .15134 m
.65438 .15955 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65221 .1511 m
.65234 .15931 L
s
.66888 .18601 m
.67475 .18268 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66888 .18601 m
.67277 .18242 L
s
.65438 .15955 m
.65661 .17214 L
s
.60391 .12195 m
.61874 .12313 L
s
.65234 .15931 m
.65458 .1719 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66488 .1855 m
.66888 .18601 L
s
.51241 .09043 m
.52775 .09039 L
s
.65661 .17214 m
.66079 .18088 L
s
.66079 .18088 m
.66488 .1855 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65877 .18063 m
.66488 .1855 L
s
.65458 .1719 m
.65877 .18063 L
s
.58026 .12049 m
.58462 .12482 L
s
.58026 .12049 m
.58678 .12494 L
s
.57592 .12027 m
.58026 .12049 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46863 .12031 m
.48168 .11977 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58462 .12482 m
.589 .13328 L
s
.56943 .12409 m
.57592 .12027 L
s
.5716 .12418 m
.57592 .12027 L
s
.255 .412 .882 r
.61104 .16032 m
.61199 .16414 L
s
0 0 0 r
.58678 .12494 m
.59116 .13341 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59116 .13341 m
.59343 .14589 L
s
.56729 .13223 m
.5716 .12418 L
s
.589 .13328 m
.59127 .14576 L
s
.56511 .13215 m
.56943 .12409 L
s
.49481 .11937 m
.50798 .11913 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53436 .11909 m
.53877 .12325 L
s
.53436 .11909 m
.52997 .11906 L
s
.53436 .11909 m
.54097 .12329 L
s
.52557 .12315 m
.52997 .11906 L
s
.54097 .12329 m
.54538 .1316 L
s
.53877 .12325 m
.54318 .13156 L
s
.52117 .13138 m
.52557 .12315 L
s
.56517 .14452 m
.56729 .13223 L
s
.59343 .14589 m
.5935 .15415 L
s
.56299 .14444 m
.56511 .13215 L
s
.59127 .14576 m
.59134 .15402 L
s
.54538 .1316 m
.54762 .14402 L
s
.54318 .13156 m
.54542 .14397 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63336 .12451 m
.63457 .21124 L
s
.63543 .12472 m
.63667 .21143 L
s
.47718 .14463 m
.49692 .14404 L
s
.56517 .14452 m
.56522 .15279 L
s
.56299 .14444 m
.56303 .15271 L
s
.255 .412 .882 r
.57011 .17028 m
.57012 .17032 L
s
.5005 .15798 m
.49831 .16092 L
s
.50266 .16084 m
.5005 .15798 L
s
.56729 .16843 m
.56796 .17023 L
s
0 0 0 r
.54762 .14402 m
.54764 .15229 L
s
.54542 .14397 m
.54544 .15225 L
s
.255 .412 .882 r
.57446 .1734 m
.57488 .17342 L
s
.57012 .17032 m
.57446 .1734 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51894 .17697 m
.51898 .09039 L
s
.52116 .17696 m
.52117 .09038 L
s
.48791 .19415 m
.50139 .11923 L
s
.255 .412 .882 r
.56796 .17023 m
.57446 .1734 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56522 .15279 m
.56748 .16531 L
s
.58928 .16632 m
.59134 .15402 L
s
.59145 .16644 m
.5935 .15415 L
s
.56303 .15271 m
.56529 .16523 L
s
.58718 .1745 m
.59145 .16644 L
s
.58501 .17439 m
.58928 .16632 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54548 .16469 m
.54764 .15229 L
s
.54327 .16465 m
.54544 .15225 L
s
.62827 .21068 m
.63667 .21143 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61029 .12243 m
.61125 .20935 L
s
.61241 .1226 m
.61339 .2095 L
s
.58068 .17833 m
.58718 .1745 L
s
.56748 .16531 m
.57191 .17379 L
s
.56529 .16523 m
.56972 .1737 L
s
.58068 .17833 m
.58501 .17439 L
s
.54108 .17294 m
.54548 .16469 L
s
.53887 .1729 m
.54327 .16465 L
s
.57191 .17379 m
.57631 .17813 L
s
.57631 .17813 m
.58068 .17833 L
s
.56972 .1737 m
.57631 .17813 L
s
.52116 .16448 m
.52559 .1728 L
s
.53445 .17702 m
.54108 .17294 L
s
.53445 .17702 m
.53887 .1729 L
s
.52559 .1728 m
.53002 .17699 L
s
.6048 .2089 m
.61339 .2095 L
s
.53002 .17699 m
.53445 .17702 L
s
.5123 .17701 m
.52116 .17696 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48786 .20672 m
.50358 .11919 L
s
.47297 .12011 m
.48786 .20672 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ002@3oYQ09
000000X0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]ZP2`h>H1
0?ooo`00_02`h>H70:f][A80ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400<0?nV
40030000003oYQ00000000d0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS
40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0
ojH@0?nV400<0?nV40030000003oYQ00000000d0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0[Jf]WP2`h>H10?ooo`00/@2`h>H50:f][@80ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@00`0ojH@
00<000000?nV400000003@3oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1001@3lX1050:f][IT0/>3V0@3oool00:`0/>3V1@2][Jd70?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400<0?nV40030000003o
YQ00000000d0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00303oYQ000`000000ojH@0000000=
0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400@
0?bP40D0[Jf]SP2`h>H10?ooo`00X@2`h>H50:f][A80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@00`0ojH@00<000000?nV400000003@3oYQ000`2]
[Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1040:f]
[HX0/>3V0@3oool009d0/>3V102][JdG0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ406`3oYQ400`2][Jd0ojH@0?nV400<0?nV40030000003oYQ00000000d0ojH@00<0[Jf]0?nU403o
YA006`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2]
[Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00303oYQ000`000000ojH@
0000000=0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jf20;3PiP40oooo002E0;3PiP@0[Jf]1@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400<0?nV40030000003oYQ00000000d0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3f
W0l40:f][Gh0/>3V0@3oool00980/>3V0`2][Jd90?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@00`0ojH@00<00000
0?nV400000003@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f]
[@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01/0ojHA00<0[Jf]0?nV403oYQ00303oYQ000`000000ojH@0000000=0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?
00l0mY`?102][Jef0;3PiP40oooo002:0;3PiP@0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400<0?nV4003
0000003oYQ00000000d0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][G<0/>3V0@3oool008L0/>3V
0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@00`0ojH@00<000000?nV400000003@3oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402]
[Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00200000040?nV40030000003oYQ00000000<0ojH@0`00
00070?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V0@3o
ool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA0140ojHA200000090:f][@8000001P2][Jd0
0`000000[Jf]000000020:f][@040000002][Jd0[Jf]0:f][@8000004P2][Jd3000000l0ojD@00<0
[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA00D0ojHA3`2][Jd00`000000ojHA0?nV4@040?nV4@030:f][@3oYQ00ojH@00@0ojH@0P000006
0?nV40050000003oYQ0000000?nV400000001@3oYQ02000000@0ojH@00<0[Jf]0?nU403oYA00203o
YA02000000<0ojD@0P0000090:f][@P0000000<0[Jf]0?nS403oXa005@3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3o
ool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]3`3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3oYQ00
ojH@00<0ojH@0P0000070?nV40040000003oYQ000000000000H0ojH@00<000000?nV400000000`3o
YQ000`2][Jd0ojD@0?nU40070?nU408000001@3oYA02000000/0ojD@0P0000040?nS4080[Jf]2000
000=0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@030:f][@3oYQ40
ojHA01@0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0ojH@0?nV40030?nV408000001`3oYQ00
10000000ojH@0000000000070?nV408000000`3oYQ000`2][Jd0ojD@0?nU40060?nU408000001P3o
YA02000000/0ojD@0P0000090?nS408000000P3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g
0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ400`000000ojHA0?nV4@03
0?nV4@030:f][@3oYQ00ojH@00<0ojH@0P0000070?nV40030000003oYQ00000000P0ojH@00<00000
0?nV400000000P3oYQ000`2][Jd0ojD@0?nU40050?nU40800000203oYA02000000X0ojD@0P000009
0?nS40800000303oXa000`2][Jd000000000000200000080[Jf]603lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA1`2][JdH0?nV4@030:f][@3oYQ40ojHA
01D0ojHA00<000000?nV4@3oYQ400`3oYQ400`2][Jd0ojH@0?nV40030?nV408000001`3oYQ000`00
0000ojH@000000090?nV408000000P3oYQ000`2][Jd0ojD@0?nU40050?nU40800000203oYA020000
00X0ojD@0P0000090?nS408000002`3oXa0300000080oj<@00<0[Jf]0000003lX1001P2][JdB0?bP
40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0
/>3V0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ450:f][@80
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@030000003oYQ40ojHA00<0
ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000L0ojH@00<000000?nV400000002@3oYQ001@000000
ojH@0000003oYQ00[Jf]00H0ojD@0P00000:0?nU408000002@3oYA02000000T0oj<@0P00000:0?nS
40030000003oXa00000000<0oj<@00<0[Jf]0?bP400000001P3lX1000`2][Jd00000000000030000
00`0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=
0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd70?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ400`000000ojHA0?nV4@030?nV4@030:f][@3oYQ00ojH@00<0
ojH@0P0000070?nV40030000003oYQ00000000T0ojH@00D000000?nV40000000ojH@0:f][@060?nU
408000002P3oYA02000000T0ojD@0P0000090?nS408000002P3oXa02000000@0oj<@00@0[Jf]0?bP
4000000000002@3lX105000000030:f][@3lX100o:0@00H0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3P
iP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV
4@3oYQ401@3oYQ460:f][@`0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV
4@030000003oYQ40ojHA00<0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000P0ojH@00<000000?nV
400000002P3oYQ02000000030?nV402][Jd0ojD@00D0ojD@0P00000:0?nU40030000003oYA000000
00P0ojD@0P0000090?nS408000002@3oXa000`000000oj<@000000040?nS40040:f][@3lX100o:0@
000000T0o:0@0P0000040?bP40030:f][@000000000000<000000P3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool0
06h0/>3V00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ401@2][JdB0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ405@3oYQ400`000000ojHA0?nV4@030?nV4@030:f][@3oYQ00ojH@0080ojH@0P0000080?nV
40030000003oYQ00000000X0ojH@0P0000000`3oYQ00[Jf]0?nU40040?nU408000002`3oYA000`00
0000ojD@000000080?nU408000002@3oXa02000000T0oj<@0P0000050?nS40030:f][@3lX100o:0@
00800000203lX102000000P0o:0@1@0000000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1440:f][AL0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@030000003oYQ40ojHA0080ojHA00<0[Jf]0?nV403o
YQ000P3oYQ02000000P0ojH@00<000000?nV400000002P3oYQ0010000000ojH@0000002][Jd50?nU
40800000303oYA02000000P0ojD@0P0000090?nS408000002@3oXa02000000D0oj<@00D0[Jf]0?bP
403lX100o:0@000000080?bP40800000203lX10200000080o:0@00<0[Jf]0?JL3`2][Jd01@00000?
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool0
06X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f]
[@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0G0?nV
4@030000003oYQ40ojHA0080ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000P0ojH@00<000000?nV
400000002`3oYQ02000000030:f][@3oYA00ojD@00<0ojD@0P00000<0?nU40800000203oYA020000
00T0oj<@0P0000090?nS408000001@3oXa00102][Jd0o:0@0?bP403lX102000000L0o:0@0P000008
0?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`@000003@3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0G0?nV4@`00000203oYQ000`00
0000ojH@0000000;0?nV4080000000<0[Jf]0?nU403oYA000`3oYA02000000`0ojD@00<000000?nU
400000001`3oYA02000000T0oj<@0P0000080?nS408000001P3oXa00102][Jd0o:0@0?bP403lX102
000000L0o:0@0P0000080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`8000000P3fW0l4
0:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0
/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0G0?nV4@030000003oYQ40ojHA0080ojHA00@0[Jf]0?nV
403oYQ00ojH@0P0000090?nV40030000003oYQ00000000/0ojH@0P0000000`2][Jd0ojD@0?nU4003
0?nU40800000303oYA000`000000ojD@000000070?nU408000002@3oXa02000000P0oj<@0P000006
0?nS40040:f][@3lX100o:0@0?bP408000001`3lX102000000P0o:0@0P0000020?bP40030:f][@3f
W0l0mY`?00<0mY`?0P0000060?JL3`@0[Jf]00<000000?JL3`3fW0l00P3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0G0?nV4@030000003oYQ40
ojHA0080ojHA00@0[Jf]0?nV403oYQ00ojH@0P0000090?nV40030000003oYQ00000000/0ojH@0P00
00000`2][Jd0ojD@0?nU40030?nU40800000303oYA000`000000ojD@000000070?nU408000002@3o
Xa02000000P0oj<@0P0000070?nS40030:f][@3lX100o:0@008000001`3lX102000000P0o:0@0P00
00020?bP40030:f][@3fW0l0mY`?00<0mY`?0P0000090?JL3`030000002][Jd000000080[Jf]00<0
mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3o
ool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]
0?nV4@3oYQ405`3oYQ400`000000ojHA0?nV4@020?nV4@040:f][@3oYQ00ojH@0?nV408000002@3o
YQ000`000000ojH@0000000;0?nV4080000000<0[Jf]0?nU403oYA000`3oYA02000000`0ojD@00<0
00000?nU400000001`3oYA02000000T0oj<@0P0000080?nS408000001`3oXa00102][Jd0o:0@0?bP
403lX102000000H0o:0@0P0000080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`800000
203fW0l010000000mY`?0?JL3`3fW0l2000000030:f][@00000000000140k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f]
[@d0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01P0ojHA00D000000?nV4@3oYQ40ojHA0:f][@03
0?nV408000002@3oYQ000`000000ojH@0000000;0?nV4080000000<0[Jf]0?nU403oYA000`3oYA02
000000`0ojD@00<000000?nU400000001`3oYA02000000T0oj<@0P0000080?nS408000001`3oXa00
102][Jd0o:0@0?bP403lX102000000H0o:0@0P0000080?bP408000000P3lX1000`2][Jd0mY`?0?JL
3`030?JL3`800000203fW0l00`000000mY`?0?JL3`030?JL3`D0000000<0[Jf]0>bF3P3/UPh0303/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`
h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@030?bP
402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01P0ojHA00D000000?nV4@3oYQ40ojHA0:f][@030?nV408000002@3oYQ000`000000
ojH@0000000;0?nV4080000000<0[Jf]0?nU403oYA000`3oYA02000000`0ojD@00<000000?nU4000
00001`3oYA02000000T0oj<@0P0000080?nS408000001`3oXa00102][Jd0o:0@0?bP403lX1020000
00H0o:0@0P0000080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`8000001`3fW0l20000
00D0mY`?0`0000030>bF3P80[Jf]00<000000>bF3P3/UPh02@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0
oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0E0?nV4@<0[Jf]00<000000:f][@2][Jd0102][Jd00`000000[Jf]000000090:f][@03
0000002][Jd0000000/0[Jf]0P0000070:f][@8000002`3oYA000`000000ojD@000000070?nU4080
00002@3oXa02000000P0oj<@0P0000070?nS40040:f][@3lX100o:0@0?bP408000001P3lX1020000
00P0o:0@0P0000020?bP40030:f][@3fW0l0mY`?00<0mY`?0P0000070?JL3`8000001@3fW0l30000
00D0k9H>00@000000:f][@0000000000203/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ401@3oYQ4@0:f][@<0ojHA00D000000?nV4@3oYQ40ojHA0:f][@020?nV408000002P3oYQ00
0`000000ojH@0000000:0?nV4080000000<0ojH@0:f][@3oYA001@3oYA02000000/0[Jf]00@00000
0:f][@000000[Jf]1P3oYA02000000T0oj<@0P0000080?nS408000001`3oXa00102][Jd0o:0@0?bP
403lX102000000H0o:0@0P0000080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`800000
1`3fW0l2000000H0mY`?0P0000050>bF3P80000000@0k9H>0:f][@00000000001P3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00
H02`h>H00`2][Jd0dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA302][JdC0?nV4@050000003oYQ40ojHA0?nV4@2][Jd00P3oYQ02000000X0
ojH@00<000000?nV400000002P3oYQ02000000030?nV402][Jd0ojD@00D0ojD@0P00000:0?nU4003
0000003oYA0000000080ojD@1P2][Jd2000000@0[Jf]1@3oXa02000000P0oj<@0P0000070?nS4004
0:f][@3lX100o:0@0?bP408000001P3lX102000000T0o:0@0P0000000`3lX100[Jf]0?JL3`040?JL
3`8000001`3fW0l2000000H0mY`?0P0000050>bF3P800000103/UPh00`000000[Jf]0>bF3P030>bF
3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3P
iP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0
o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030:f][@3oYQ40ojHA00`0ojHA2@2][Jd40?nV4@030:f][@3oYQ40ojHA01P0ojHA00D000000?nV
4@3oYQ40ojHA0:f][@020?nV408000002P3oYQ000`000000ojH@0000000:0?nV4080000000<0ojH@
0:f][@3oYA001P3oYA02000000T0ojD@00<000000?nU40000000203oYA02000000@0oj<@1@2][Jd2
000000<0[Jf]1@3oXa02000000L0oj<@00@0[Jf]0?bP403lX100o:0@0P0000070?bP40800000203l
X102000000030?bP402][Jd0mY`?00@0mY`?0P0000070?JL3`8000001P3fW0l2000000D0k9H>0P00
00050>bF3P060000002][Jd0[Jf]0:f][@3/UPh0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`03
0:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd=0?nV4@030:f][@3oYQ40ojHA01T0
ojHA00@000000?nV4@3oYQ40[Jf]0P3oYQ02000000X0ojH@00<000000?nV400000002P3oYQ020000
00030?nV402][Jd0ojD@00H0ojD@0P0000090?nU40030000003oYA00000000P0ojD@0P0000090?nS
408000000`3oXa050:f][@8000000`2][Jd40?nS40040:f][@3lX100o:0@0?bP408000001`3lX102
000000P0o:0@0P0000000`3lX100[Jf]0?JL3`040?JL3`8000001`3fW0l2000000H0mY`?0P000005
0>bF3P8000001@3/UPh01P000000k9H>0>bF3P3/UPh0[Jf]000000d0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00X0kiP@00<0
00000:f][@2][Jd0403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01H0ojHA1`2]
[JdG0?nV4@030:f][@3oYQ40ojHA01T0ojHA00@000000?nV4@3oYQ40[Jf]0P3oYQ02000000X0ojH@
00<000000?nV400000002@3oYQ0200000080ojH@00<0[Jf]0?nU403oYA001@3oYA02000000T0ojD@
00<000000?nU40000000203oYA02000000T0oj<@0P0000090?nS408000000P3oXa080:f][@800000
1`3lX102000000P0o:0@0P0000000`3lX100[Jf]0?JL3`040?JL3`8000001`3fW0l2000000H0mY`?
0P0000050>bF3P030000003/UPh0k9H>00@0k9H>00<000000>bF3P3/UPh00P3/UPh00`000000[Jf]
0:f][@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203C
Q`h00`2][Jd0kiP@0>nH40090>nH4080000000<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1P2][Jd20?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ401@000000ojHA0?nV4@2][Jd0ojH@008000002`3oYQ0010000000ojH@
0000000000070?nV408000000`3oYQ000`2][Jd0ojD@0?nU40060?nU408000001`3oYA000`000000
ojD@000000090?nU408000002P3oXa02000000P0oj<@0P0000060?nS40030:f][@3lX100o:0@0080
00001@2][Jd30?bP40800000203lX102000000030?bP402][Jd0mY`?00@0mY`?0P0000070?JL3`80
00001P3fW0l2000000D0k9H>00<000000>bF3P3/UPh0103/UPh00`000000k9H>0>bF3P020>bF3P80
000000<0fhX=0:f][@2][Jd02@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0
/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40040>nH40030000
003_V10000000080[Jf]0P0000000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@050000003oYQ40ojHA0:f][@3oYQ000P00000;0?nV40040000003oYQ0000000000
00L0ojH@0P0000030?nV40030:f][@3oYA00ojD@00H0ojD@0P0000070?nU408000002P3oYA020000
00X0oj<@0P0000080?nS408000001P3oXa000`2][Jd0o:0@0?bP4002000000D0o:0@0`2][Jd20000
0080[Jf]1P3lX102000000030?bP402][Jd0mY`?00@0mY`?0P0000070?JL3`8000001P3fW0l20000
00D0k9H>00<000000>bF3P3/UPh0103/UPh00`000000k9H>0>bF3P020>bF3P030000003KRPd0fhX=
0080fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?oo
o`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@0P0000000`2]
[Jd0kiP@0>nH4002000000030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@060?nV4@D0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
01T0ojHA00D000000?nV4@3oYQ40[Jf]0?nV4002000000/0ojH@00D000000?nV40000000ojH@0000
00050?nV40800000103oYQ000`2][Jd0ojD@0?nU40070?nU4080000000<0@FWQ0?nU403oYA000P3o
YA000`000000ojD@0000000:0?nU408000002P3oXa02000000P0oj<@0P0000060?nS40030:f][@3l
X100o:0@00800000203lX10200000080o:0@1P2][Jd200000003045Yh@2][Jd0mY`?00@0mY`?0P00
00070?JL3`8000001P3fW0l2000000`0k9H>00<000000>bF3P3/UPh00P3/UPh00`000000fhX=0=^:
3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF
1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00@0[Jf]0>nH403_V100
kiP@0P0000000`3_V10000000>nH40040>nH40030000002][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@060:f][A80ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@050000003oYQ40ojHA0:f][@3oYQ000P00000;0?nV40030000003oYQ000000
0080ojH@00@000000?nV403oYQ00ojH@0P0000050?nV40030:f][@3oYA00ojD@00L0ojD@0P000005
0?nU408000002`3oYA02000000X0oj<@0P0000080?nS408000001P3oXa000`2][Jd0o:0@0?bP4002
000000P0o:0@0P0000080?bP408000000`2][Jd40?JL3`8000001`3fW0l2000000H0mY`?0P00000<
0>bF3P030000003/UPh0k9H>0080k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@@0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080000000<0[Jf]0000000000001P3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0180oj@A102][JdH0?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ4010000000ojHA0:f][@3oYQ02000000P0ojH@
1P0000030?nV40<000001`3oYQ000`2][Jd0ojD@0?nU40080?nU408000000`3oYA02000000`0ojD@
0P00000:0?nS408000002@3oXa02000000D0oj<@00@0[Jf]0?bP4000000000002@3lX102000000P0
o:0@0P0000000`3lX100[Jf]0?JL3`040:f][@8000001`3fW0l2000000H0mY`?0P00000<0>bF3P03
0000003/UPh0k9H>0080k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@80fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@080=>73P060:f][@3_V100kiP@0000002][Jd0kiP@0P0000060>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403P3oY1440:f][@030?nT4@2][Jd0ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@060000003oYQ40[Jf]0000003oYQ00
00006`3oYQ000`2][Jd0ojD@0?nU400:0?nU40<000003P3oYA02000000X0oj<@0P0000090?nS4080
00001@3oXa00102][Jd0o:0@0000000000090?bP40800000203lX102000000030?bP402][Jd0mY`?
00@0mY`?0P0000020:f][@D0mY`?0P0000060?JL3`800000303/UPh00`000000k9H>0>bF3P020>bF
3P030:f][@3KRPd0fhX=00T0fhX=0`2][Jd90;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3P
iP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00D0
dhL>00<000000:f][@2][Jd00P0000020>nH408000001P3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00X0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030000003oYQ40[Jf]00800000703oYQ000`2][Jd0
ojD@0?nU400K0?nU408000002P3oXa02000000X0oj<@0P0000040?nS40030:f][@000000000000X0
o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l0103fW0l200000080mY`?102][Jd20?JL3`03
0000003fW0l0mY`?00@0mY`?00<0[Jf]0000000000002P3/UPh2000000@0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P0000000`3CQ`h0
[Jf]0>nH4002000000<0kiP@00<000000>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00L0oj@A0`2][Jd90?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030000003oYQ40[Jf]00800000703oYQ000`2][Jd0
ojD@0?nU400K0?nU408000002P3oXa02000000/0oj<@0P0000030?nS40030:f][@000000000000X0
o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l0103fW0l2000000H0mY`?0P2][Jd00`000000
[Jf]0?JL3`040?JL3`030:f][@000000000000X0k9H>0P0000040>bF3P030:f][@3KRPd0fhX=00/0
fhX=0P2][Jd80;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00
F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>0`0000020:f][@030>nH40000000kiP@00<0
kiP@00<000000>nH403_V1000`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0
oj@A102][Jd<0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030000003oYQ40[Jf]00800000703oYQ000`2][Jd0ojD@0?nU400K0?nU4080
00002P3oXa02000000d0oj<@00<000000?nS403oXa000P00000;0?bP408000001`3lX10200000080
o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000P0mY`?00<000000?JL3`2][Jd00`2][Jd0103fW0l0
[Jf]0000000000080>bF3P<000001@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0[Jf]
0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2000000040=>73P2][Jd00000000000@0kiP@00<0
00000>nH403_V1000`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140[Jf]00<0[Jf]403o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`000000ojHA0:f][@02000001`0ojH@00<0[Jf]0?nU403oYA006`3oYA02000000X0oj<@0P00
000>0?nS4080000000<0[Jf]0?bP403lX1002P3lX103000000H0o:0@0P0000020?bP40030:f][@3f
W0l0mY`?00<0mY`?0P0000080?JL3`030000003fW0l0mY`?00<0mY`?0P2][Jd2000000H0k9H>0P00
00020>bF3P030000003/UPh0k9H>00<0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue
2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo
001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h2000000050:f][@00000000000=>73P2]
[Jd00P0000040>nH40030000003_V100kiP@00<0kiP@00<0[Jf]0?bP403lX1003`3lX1030:f][A@0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0
ojHA00@000000:f][@0000000000703oYQ000`2][Jd0ojD@0?nU400K0?nU408000002P3oXa020000
0100oj<@00<0[Jf]0?bP403lX1001`3lX102000000050?bP4000000000000?bP400000001@3lX102
00000080o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000P0mY`?00<000000?JL3`3fW0l0103fW0l0
0`2][Jd00000000000020:f][@<0k9H>00<000000>bF3P3/UPh00P0000060>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h2
000000060:f][@3CQ`h000000000003CQ`h0[Jf]0P0000040>nH40030000003_V100kiP@00<0kiP@
00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA0`00000M0?nV40030:f]
[@3oYA00ojD@01/0ojD@0P00000:0?nS40800000403oXa000`2][Jd0o:0@0?bP40090?bP40<00000
0P3lX10010000000o:0@0?bP403lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000P0
mY`?00<000000?JL3`3fW0l0103fW0l00`2][Jd00000000000020>bF3P80[Jf]00@0k9H>00000000
00000000203/UPh00`2][Jd000000=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0[Jf]0;Ue
2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;09MP2`2GH0/0
[Jf]0=>73P<000000P3CQ`h2000000040=>73P2][Jd00000000000@0kiP@00<000000>nH403_V100
0P3_V1000`000000[Jf]0?bP400;0?bP4080[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@<00000
7@3oYQ000`2][Jd0ojD@0?nU400K0?nU408000002P3oXa0200000100oj<@00<0[Jf]0?bP403lX100
3`3lX103000000D0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000P0mY`?00<000000?JL3`3fW0l0
103fW0l00`2][Jd00000000000040>bF3P80000000<0[Jf]0>bF3P3/UPh01`3/UPh00`2][Jd00000
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80[Jf]
@P2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P2][Jd00P0000020=>73P80
000000<0dhL>0:f][@000000103_V102000000@0kiP@00<000000:f][@3lX100203lX1030:f][@H0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ460:f][@030000002][Jd0000002D0[Jf]5P3oYA02000000X0
oj<@0P00000@0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l2000000P0
mY`?00<000000?JL3`3fW0l0103fW0l00`2][Jd00000000000040>bF3P80000000@0k9H>0:f][@2]
[Jd0[Jf]1P3/UPh00`2][Jd000000=^:3@0;0=^:3@030:f][@11JN40^GD;00H0^GD;0P2][Jd408QF
1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@030=>73P0000000000
0080dhL>0P0000000`3CQ`h0[Jf]000000040>nH40800000103_V1000`000000[Jf]0?bP40050?bP
40<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1P3oYQ400`000000[Jf]0000000M0?nV
40030:f][@3oYA00ojD@00D0ojD@402][Jd60?nU408000002P3oXa0200000100oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`04000000P0mY`?00<000000?JL3`3fW0l0103fW0l00`2]
[Jd00000000000040>bF3P030000003/UPh0k9H>00<0k9H>0P2][Jd40>bF3P030:f][@000000fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V
0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/000000:f][@020=>73P8000000P3CQ`h20000
00030=>73P2][Jd0000000@0kiP@0P0000040>nH40030000002][Jd0o:0@00<0o:0@0P2][Jd<0?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV
4@`0[Jf]5P3oYQ400`000000[Jf]0000000M0?nV40030:f][@3oYA00ojD@01D0ojD@1P2][Jd20000
00@0[Jf]1P3oXa0200000100oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`020?JL
3`800000203fW0l00`000000mY`?0?JL3`040?JL3`030:f][@000000000000@0k9H>00<000000>bF
3P3/UPh01@3/UPh01P000000[Jf]0:f][@3/UPh0[Jf]000000d0fhX=00<0[Jf]0;Ue2`2iM@/01P2i
M@/20:f][@@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`02
00000080dhL>0P0000020=>73P80000000<0[Jf]0>nH40000000103_V102000000@0kiP@00<00000
0:f][@11JN400`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@8000007@3oYQ00
0`2][Jd0ojD@0?nU400K0?nU40800000103oXa060:f][@8000000P2][Jd>0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l2000000030?JL3`000000mY`?00D0mY`?00<0[Jf]
0000000000001@3/UPh00`000000k9H>0>bF3P040>bF3P030000003/UPh0k9H>0080[Jf]00<00000
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP10
0;3PiP40oooo001I0;3PiP050:f][@2GH0/000000:f][@0000000P3CQ`h200000080dhL>0P000000
0`2][Jd0kiP@000000040>nH40800000103_V1000`000000[Jf]0:f][@0A0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030000003oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA02
000000X0oj<@0P0000020?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?00/0mY`?0P0000060?JL3`030:f][@000000000000D0k9H>00<000000>bF3P3/UPh00`3/UPh2
000000<0k9H>00@0[Jf]0000002][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28
EPL0[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd000000000002G
H0/000000080dhL>0P0000020=>73P80000000<0[Jf]0>nH40000000103_V102000000<0kiP@00<0
[Jf]0000002][Jd04P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01@0ojHA202]
[JdH0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<000000?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400K0?nU408000002P3oXa02000000`0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?0180mY`?1000
00050>bF3P030000003/UPh0k9H>00<0k9H>0P0000030>bF3P040:f][@000000fhX=0=^:3@80[Jf]
2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H70:f][@80R5H700<0[Jf]0;3PiP2`
h>H0@02`h>H10?ooo`00F@2`h>H01@000000Uf0;0000002GH0/000000080dhL>0P0000020=>73P80
000000<0[Jf]0>nH40000000103_V102000000060>nH402][Jd0[Jf]0>nH40000000[Jf]4@3lX100
0`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`000000ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01/0ojD@0P00000:0?nS40800000403oXa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l2000000D0k9H>00<000000>bF3P3/UPh00`3/UPh2000000<0k9H>00<0
[Jf]0000003KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0R5H708QF
1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H30000000409MP2`2][Jd0dhL>0=>73P80
00000P3CQ`h2000000030:f][@3_V100000000@0kiP@0P0000001P2][Jd0kiP@0>nH403_V1000000
0:f][A40o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400H0?nU40D000002P3oXa0200000100oj<@00<0[Jf]0?bP403lX100203lX106
0:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P050>bF3P030000003/UPh0
k9H>0080k9H>0P0000030>bF3P030:f][@000000fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0
^GD;00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005P0/>3V1000
00001@2GH0/0[Jf]0=>73P3CQ`h000000080dhL>0P000000103CQ`h0[Jf]0>nH400000030>nH4003
0:f][@000000000000@0kiP@00<000000:f][@3lX100403lX1000`2][Jd0oj@A0?nT4@0D0?nT4@04
0:f][@3oYQ40ojHA0?nV4@H0[Jf]403oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
00D0oj<@1@00000@0?nS40030:f][@3lX100o:0@00h0o:0@1`2][Jd30?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh010000000k9H>0>bF3P3/UPh2000000<0k9H>00<0[Jf]
0000003KRPd01`3KRPd20:f][@80fhX=00<0@FWQ0:f][@2iM@/01`2iM@/00`2][Jd0R5H708QF1`02
08QF1`80[Jf]@P2`h>H10?ooo`00F02`h>H40000000509MP2`2][Jd0dhL>0=>73P0000000P3CQ`h2
000000050=>73P2][Jd0kiP@0000003_V1000P2][Jd00`3_V10000000>nH40040>nH40030000002]
[Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1404`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][JdD0?JL3`030:f][@3/
UPh0k9H>00L0k9H>0`0000000`3/UPh000000>bF3P020>bF3P030:f][@000000fhX=00T0fhX=0P2]
[Jd00`3KRPd0[Jf]0;Ue2`070;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`
h>H10?ooo`00F02`h>H40000000509MP2`2][Jd0dhL>0=>73P0000000P3CQ`h2000000050=>73P2]
[Jd0kiP@0000002][Jd00`3_V1000`000000kiP@0>nH40030>nH40030000002][Jd0o:0@0100o:0@
00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
102][Jd@0?JL3`030:f][@3/UPh0k9H>00/0k9H>00H000000>bF3P3/UPh0k9H>0:f][@00000<0=^:
3@80[Jf]2@2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00F02`h>H400000005
09MP2`2][Jd0dhL>0=>73P0000000P3CQ`h2000000040=>73P2][Jd0[Jf]000000@0kiP@00<00000
0>nH403_V1000P3_V102000000030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY144
0:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@000000000000`0fhX=0P2][Jd80;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP@000000P2GH0/0102][Jd0dhL>0=>73P000002
0=>73P8000000P2][Jd00`3_V10000000>nH40030>nH40030000003_V100kiP@0080kiP@0P000000
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l00`000000mY`?0?JL3`030?JL3`D0[Jf]1P3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@000000000000`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H400000080Uf0;00@0[Jf]
0=>73P3CQ`h000000P3CQ`h2000000040=>73P2][Jd0kiP@000000<0kiP@0P0000040>nH40800000
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?0080mY`?0P00000:0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>
0>bF3P0@0>bF3P800000303KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28
EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V1000000209MP2`040:f][@3CQ`h0dhL>00000080
dhL>0P000000103CQ`h0[Jf]0>nH400000030>nH40800000103_V102000000030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l00P3fW0l00`000000mY`?0000000=0?JL3`@0[Jf]4@3/UPh2000000`0fhX=00<0[Jf]0;Ue
2`2iM@/00P2iM@/00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3P
iP40oooo001G0;3PiP@000000P2GH0/0102][Jd0dhL>0=>73P0000020:f][@80000000D0dhL>0:f]
[@3_V100kiP@000000020>nH40800000103_V102000000030:f][@3lX100o:0@00h0o:0@0`2][JdE
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l00`000000mY`?0?JL3`0>
0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh2000000`0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/0
1@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je10;3PiP40oooo001G0;3PiP@000000P2GH0/0
102][Jd0dhL>0=>73P0000020=>73P80000000T0dhL>0:f][@3_V100kiP@0000003_V10000000>nH
40000000103_V102000000030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l00`000000mY`?0?JL3`0>0?JL
3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P800000303KRPd00`2][Jd0^GD;0;Ue2`040;Ue
2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f][D40/>3V0@3oool005L0/>3V1000000209MP2`04
0:f][@3CQ`h0[Jf]00000080dhL>0P0000002@3CQ`h0[Jf]0>nH403_V10000000>nH40000000kiP@
000000040>nH4080000000<0[Jf]0?bP403lX1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140
503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
103/UPh30:f][@T0k9H>0P00000<0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80[Jf]
@@2`h>H10?ooo`00EP2`h>H500000080Uf0;00@000000:f][@00000000000P3CQ`h2000000030=>7
3P2][Jd0kiP@0080kiP@00@000000>nH403_V1000000103_V102000000030:f][@3lX100o:0@00L0
o:0@0P2][Jd60?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P800000303KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001F0;3PiPD00000
00@0Uf0;000000000000dhL>0P0000020=>73P80000000<0dhL>0:f][@3_V1001@3_V1000`000000
kiP@0>nH40020>nH4080000000<0[Jf]0?bP403lX100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>0P00000<0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@000000/>3V0400/>3V0@3oool005H0/>3V
0`0000000`2GH0/0000009MP2`02000000030=>73P00000000000080dhL>0P0000000`2][Jd0kiP@
0>nH40040>nH40800000103_V102000000040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@03
0>bF3P000000000000d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@<0R5H700<0[Jf]0000002`
h>H0@02`h>H10?ooo`00EP2`h>H30000000609MP2`000000Uf0;0:f][@000000dhL>0P0000020=>7
3P80000000<0[Jf]0>nH403_V100103_V102000000@0kiP@0P000000102][Jd0o:0@0:f][@2][Jd>
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F
0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0000000000003@3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`030:f][@28EPL0[Jf]0080R5H700<0[Jf]0000002`h>H0@02`h>H10?ooo`00EP2`h>H30000
000609MP2`000000[Jf]09MP2`000000dhL>0P0000001@3CQ`h000000000003CQ`h0[Jf]00H0kiP@
0P0000040>nH408000000P2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>0P0000020:f][@/0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@000000/>3V0400/>3V
0@3oool005H0/>3V0`0000001P2GH0/0000009MP2`2GH0/000000=>73P800000103CQ`h00`2][Jd0
kiP@0>nH40040>nH408000000`3_V100102][Jd000000000002][JdA0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f]
[AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P8000000P3KRPd20:f]
[@T0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0R5H708QF1`2][Jd0R5H70:f][@000000@@2`
h>H10?ooo`00E`2`h>H20000000609MP2`000000Uf0;0000002][Jd0dhL>0P0000040=>73P030:f]
[@3_V100kiP@00@0kiP@0P000000103_V100[Jf]0:f][@3_V102000000030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80
o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P800000103KRPd20:f][@L0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V
03l0/>3V0@3oool005L0/>3V0P0000001P2][Jd0000009MP2`000000[Jf]0=>73P800000103CQ`h0
0`2][Jd0kiP@0>nH40040>nH4080000000L0[Jf]0>nH403_V100kiP@0000003_V100[Jf]0140o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@
00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@000000fhX=00D0fhX=
0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000
/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP<0000000H0[Jf]0000002GH0/000000:f][@3CQ`h20000
00@0dhL>00<0[Jf]0>nH403_V1000`3_V1000`2][Jd00000000000040>nH40030000003_V100[Jf]
0140o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f]
[@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@000000fhX=
00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2]
[Jd000000;3PiP100;3PiP40oooo001F0;3PiP<0000000H0Uf0;000000000000@FWQ0:f][@3CQ`h2
000000@0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd00`3_V1000000000000040>nH40030000003_
V100[Jf]0140o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V
1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/0202iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]0000
0440/>3V0@3oool005H0/>3V0`000000102GH0/000000000002][Jd20=>73P030000003CQ`h0dhL>
00<0dhL>00@0[Jf]0>nH402][Jd0[Jf]0`3_V102000000H0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000440/>3V
0@3oool005H0/>3V0`00000209MP2`050000002][Jd0dhL>0=>73P0000001@3CQ`h20:f][@D0kiP@
0P0000060>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V
1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@L0^GD;
00D0[Jf]08QF1`28EPL0R5H70:f][@0200000400/>3V0@3oool005H0/>3V0`00000309MP2`040:f]
[@3CQ`h0dhL>000000@0dhL>0P2][Jd60>nH408000001P3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2iM@/0102][Jd0R5H708QF1`28EPL2
0:f][@030000002`h>H0/>3V03h0/>3V0@3oool005H0/>3V0`00000309MP2`040:f][@3CQ`h0dhL>
00000080dhL>00@0[Jf]0000003CQ`h0[Jf]1@3_V102000000H0kiP@00<0[Jf]0?bP403lX100403l
X1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005H0/>3V0`00000309MP2`060:f]
[@3CQ`h0dhL>0000003CQ`h0[Jf]0P0000000`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@
0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP<000000`2GH0/01P2]
[Jd0dhL>0=>73P000000[Jf]0=>73P80000000<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP
400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`040;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo
001F0;3PiP80000000P0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h0[Jf]00000080dhL>0P0000000`3C
Q`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;0`2][Jd308QF1`80[Jf]00<000000;3P
iP2`h>H0?P2`h>H10?ooo`00EP2`h>H2000000040:f][@2GH0/0Uf0;09MP2`80[Jf]00<0dhL>0000
003CQ`h00P3CQ`h00`000000dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;Vb
YP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0000002`h>H0?`2`h>H1
0?ooo`00EP2`h>H2000000@0Uf0;00@0[Jf]0=>73P3CQ`h000001@3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd7
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0[Jf]
0000002`h>H0?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]0P3CQ`h00`00
0000dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f]
[@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd000000;3PiP0o0;3P
iP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd20=>73P030000003CQ`h0dhL>00<0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0
^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n
^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2]
[Jd00P28EPL00`2][Jd000000;3PiP0o0;3PiP40oooo001F0;3PiP090000002][Jd0Uf0;09MP2`2]
[Jd0Uf0;0:f][@3CQ`h0000000H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@02
0:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd5
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@000000/>3V03l0/>3V0@3oool0
05H0/>3V00@000000:f][@2GH0/0[Jf]0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100
kiP@00X0kiP@0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`4
0:f][MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP2
0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01`2][Jd0R5H708QF1`2][Jd0R5H70:f][@000000
@02`h>H10?ooo`00EP2`h>H010000000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80
[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]
0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BN
S`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0
_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000;3PiP0o0;3PiP40oooo001F0;3PiP030000
002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@@0
Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036
`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^004
0:f][@11JN40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF
1`030:f][@000000/>3V03l0/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00T0dhL>00@0[Jf]0>nH402][Jd0[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@040;6[W@80[Jf]1@2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[06
0:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0
102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00@0[Jf]045Yh@2d/;40@FWQ0P2][Jd00`3KRPd0[Jf]
0;Ue2`090;Ue2`060:f][@28EPL0R5H708QF1`2][Jd00000@02`h>H10?ooo`00E@2`h>H00`000000
/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00L0dhL>0P2][Jd80:BNS`030:f][@2aZid0/J^M00H0
/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@L0_[Vh0`11JN400`2][Jd0@FWQ0;B`/@02045Y
h@030;B`/@2][Jd0[Jf]00X0^GD;00H0[Jf]08QF1`28EPL0R5H70:f][@0000100;3PiP40oooo001E
0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0Y9j?0:BNS`08
0:BNS`030:f][@2aZid0/J^M00P0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]202n^KP0
0`11JN40_[Vh0;ji^003045Yh@040;B`/@11JN40];2a045Yh@80];2a0P2][Jd80;Ue2`060:f][@28
EPL0R5H708QF1`2][Jd00000@02`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f]
[@3CQ`h0dhL>00@0dhL>0P2][Jd00`11JN40Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00X0/J^M
0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc
0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0202n^KP01011JN40
_[Vh0;ji^02n^KP2045Yh@80];2a0P11JN420;B`/@80@FWQ00<0[Jf]0;Ue2`2iM@/01@2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2]
[Jd0dhL>0=>73P030=>73P<0[Jf]00<0@FWQ0:BNS`2TWXl01`2TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2]
[Jd0_[Vh0;ji^0070;ji^004045Yh@2n^KP0_[Vh0;ji^080@FWQ0P2d/;42045Yh@<0];2a00@0@FWQ
0;B`/@2][Jd0[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V
0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@11
JN40RXEe0:f][@11JN402@2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00<0^K:V
0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`040:f][@2n^KP0_[Vh045Yh@D0
_[Vh0P11JN430;ji^080@FWQ0P2d/;42045Yh@<0];2a00@0@FWQ0:f][@11JN40@FWQ0P2][Jd30;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`0;0:f][@3CQ`h0dhL>0=>73P2][Jd0RXEe045Yh@2:QGD0[Jf]045Yh@2]
[Jd0202TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@80@FWQ202i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0
@FWQ045Yh@060;ji^080@FWQ0`2n^KP2045Yh@80];2a0P11JN420;B`/@80@FWQ0P2d/;43045Yh@04
0:f][@2iM@/0^GD;0:f][@<0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001E0;3PiP03
0000002`h>H0[Jf]00<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]0`11JN401@2:QGD0[Jf]045Yh@2TWXl0
[Jf]00L0Y9j?00<0[Jf]0;6[W@2aZid0302aZid3045Yh@T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?
0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd=0<>m^`<0@FWQ1`2n^KP2045Yh@<0_[Vh0P11JN42
0;B`/@80@FWQ00@0];2a0:f][@11JN40@FWQ0P2d/;43045Yh@0409nKX02][Jd0[Jf]0:f][@@0R5H7
00<0[Jf]0000002`h>H0?P2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`80[Jf]0`2:
QGD2045Yh@0308Z5M@2][Jd0@FWQ0080Y9j?0P2][Jd50:BNS`030:f][@2aZid0/J^M00`0/J^M0P11
JN400`2i/ZH0@FWQ045Yh@0;0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02@33_K/2045Yh@<0`kfk00<0
[Jf]045Yh@2n^KP01P2n^KP2045Yh@<0_[Vh0P11JN420;B`/@80@FWQ00@0[Jf]0;B`/@11JN40@FWQ
0P2d/;43045Yh@<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000;3PiP0n0;3PiP40oooo
001E0;3PiP030000002][Jd0Uf0;00<0Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD01011JN40RXEe045Y
h@11JN440:BNS`80[Jf]0`2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@80@FWQ0P2i/ZH2045Yh@/0^K:V
00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jd50<K0_0030:f]
[@33_K/0`kfk00@0`kfk0`11JN400`33_K/0@FWQ045Yh@030<>m^`030:f][@11JN40_[Vh00H0_[Vh
0P11JN440;ji^003045Yh@2d/;40];2a0080@FWQ0P2d/;42045Yh@80];2a0P11JN4509nKX0060:f]
[@28EPL0R5H708QF1`2][Jd00000?`2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`80
[Jf]1`2:QGD00`11JN40Y9j?0:BNS`050:BNS`040:f][@2TWXl0Y9j?0:f][@h0/J^M0P11JN430;Vb
YP80@FWQ0`2i/ZH2045Yh@D0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j
/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/00`33_K/01011JN40`kfk0<>m^`33_K/3
045Yh@@0`kfk00<0@FWQ0;ji^02n^KP01P2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2][Jd0
[Jf]0080@FWQ0P2d/;401011JN40];2a0;B`/@2d/;42045Yh@@0Wi^P00<0@FWQ0:f][@28EPL00P28
EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd7
08Z5M@03045Yh@2TWXl0Y9j?00H0Y9j?0`2][Jd>0;6[W@80@FWQ0`2i/ZH2045Yh@D0^K:V0P11JN43
0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]
0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`0
0`2][Jd0`kfk0<>m^`030<>m^`04045Yh@33_K/0`kfk0<>m^`<0@FWQ1033_K/00`11JN40_[Vh0;ji
^0070;ji^0D0@FWQ0P2d/;42045Yh@80];2a00@0@FWQ0;B`/@2d/;40];2a0P11JN4409nKX003045Y
h@2OVj00[Jf]0080R5H700<0[Jf]0000002`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP
2`030:f][@L0RXEe00<0@FWQ0:BNS`2TWXl0202TWXl20:f][@d0/J^M0P11JN440;VbYP80@FWQ102i
/ZH4045Yh@030;VbYP2][Jd0_[N/00`0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40a/2l00<0[Jf]0<>m^`33_K/00`33
_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ1033_K/00`11JN40_[Vh0;ji^0080;ji^080[Jf]00@0
_[Vh045Yh@2d/;40];2a0P11JN400`2d/;40@FWQ0;B`/@030;B`/@80@FWQ102OVj001`11JN40Wi^P
0:f][@2][Jd0R5H70:f][@000000?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f]
[@H0RXEe00<0[Jf]045Yh@2TWXl02@2TWXl0102][Jd0/J^M0:f][@2][Jd;0;6[W@80@FWQ102i/ZH2
045Yh@@0^K:V0P11JN430;VbYP030:f][@2n]j`0_[N/00l0_[N/102][JdA0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`03@36`;`0
1011JN40a/2l0<K0_02][Jd40<>m^`03045Yh@33_K/0`kfk00@0`kfk00<0@FWQ0<>m^`33_K/00P33
_K/00`11JN40_[Vh0;ji^0060;ji^080[Jf]0`2n^KP00`11JN40];2a0;B`/@04045Yh@@0];2a0P11
JN4409nKX004045Yh@2OVj00[Jf]071^N@80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`
h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0@FWQ0:BNS`090:BNS`040:f][@2a
Zid0/J^M0;6[W@<0[Jf]202aZid2045Yh@@0^K:V0P11JN440;VbYP80@FWQ0`2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_036`;`0
0`36`;`01011JN40a/2l0<K0_02][Jd40<>m^`03045Yh@33_K/0`kfk00@0`kfk00<0@FWQ0<>m^`33
_K/00P33_K/00`11JN40_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`11JN40];2a0;B`/@02045Yh@H0
];2a0P11JN4509nKX080[Jf]00<0L6ii0:f][@2][Jd0@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C
0P2][Jd508Z5M@030:f][@11JN40Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid20:f][@H0/J^M
0P11JN450;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN430;VbYP030:f][@2n]j`0_[N/00<0_[N/
1@11JN480;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_036`;`0
0`36`;`01011JN40a/2l0<K0_02][Jd30<>m^`80@FWQ1P33_K/00`11JN40`kfk0<>m^`020<>m^`80
@FWQ0P2n^KP20:f][@<0_[Vh0P11JN420;ji^003045Yh@2][Jd0];2a0080@FWQ1`2d/;42045Yh@@0
Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<0
0P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@11JN40Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
1P2aZid30:f][@<0/J^M0P11JN450;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN420;VbYP030:f]
[@2n]j`0_[N/00@0_[N/0P11JN430;jg[004045Yh@2n]j`0_[N/0;jg[080@FWQ0P2n]j`00`2][Jd0
`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`0102][Jd0
a/2l0<K0_036`;`2045Yh@@0a/2l00<0@FWQ0<K0_036`;`00P36`;`3045Yh@030<K0_02][Jd0`kfk
0080`kfk0P11JN460<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN420:f][@D0_[Vh0P11JN420;ji
^003045Yh@2][Jd0];2a00T0];2a0P11JN4309nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo
0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD0
0`2][Jd0@FWQ0:BNS`090:BNS`030:f][@2aZid0/J^M00T0/J^M0P2][Jd00`2aZid0@FWQ045Yh@05
0;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN420;VbYP030:f][@2n]j`0_[N/00@0_[N/00<0@FWQ
0;jg[02n]j`00`2n]j`00`11JN40_[N/045Yh@040;jg[0030:f][@31^[00`KZ`00l0`KZ`202][Jd@
0<>m/`030:f][@35_[D0aKje0140aKje0`11JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00h0al6l0`11JN40102][Jd0a/2l0<K0_011
JN460<K0_080@FWQ0`36`;`3045Yh@030<K0_02][Jd0`kfk0080`kfk0P11JN460<>m^`<0@FWQ00@0
`kfk0:f][@11JN40@FWQ0`2n^KP00`11JN40_[Vh0;ji^0020;ji^005045Yh@2n^KP0@FWQ0;ji^02]
[Jd02P2d/;42045Yh@0309nKX02][Jd0[Jf]00<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40
oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@03
0:f][@11JN40Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0@FWQ045Yh@050;VbYP80
@FWQ0`2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0030;jg[0<0
@FWQ102n]j`0102][Jd0`KZ`0<6j/011JN4@0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m
/`030:f][@35_[D0aKje01<0aKje1011JN4E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/0
0`2][Jd0al6l0<O1_00=0<O1_005045Yh@37`K`0al6l0<O1_011JN400P36`;`00`11JN40a/2l0<K0
_0040<K0_080@FWQ0`36`;`3045Yh@030<K0_02][Jd0`kfk0080`kfk00<0@FWQ0<>m^`33_K/00`33
_K/3045Yh@<0[Jf]00<0`kfk045Yh@11JN400P2n^KP2045Yh@D0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]
2P2d/;42045Yh@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo
001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD0102][Jd0RXEe0:f]
[@11JN4:0:BNS`030:f][@2aZid0/J^M00`0/J^M0P11JN430:f][@80^K:V0P11JN430;VbYP80@FWQ
0P2i/ZH00`2][Jd0_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN440;jg[0040:f]
[@31^[00`KZ`045Yh@D0`KZ`00<0@FWQ0<6j/031^[002031^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0
[Jf]4035_[D2045YhAL0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00`0al6l0P11JN430<O1_004
0:f][@11JN40@FWQ045Yh@D0a/2l00<0@FWQ0<K0_011JN400`36`;`3045Yh@030<K0_02][Jd0`kfk
0080`kfk00<0@FWQ0<>m^`33_K/00`33_K/30:f][@@0`kfk0P11JN420;ji^080@FWQ202n^KP00`2]
[Jd0];2a0;B`/@080;B`/@03045Yh@2][Jd0Wi^P00D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@/0
Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`11JN40[Jf]0;VbYP030;VbYP80[Jf]0P11JN430;VbYP05
045Yh@2i/ZH0^K:V0;VbYP2][Jd01P2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ102n]j`0102]
[Jd0`KZ`0<6j/011JN450<6j/003045Yh@31^[00`KZ`00P0`KZ`00<0[Jf]0<>m/`33_K<04P33_K<0
0`000000[Jf]0<Fn]@040<Fn]@`0[Jf]1035_[D2045YhAL0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0
b<6k01<0b<6k1P11JN480<O1_080@FWQ1037`K`0102][Jd0a/2l045Yh@11JN450<K0_003045Yh@36
`;`0@FWQ00<0a/2l00D0@FWQ0<K0_011JN40a/2l0:f][@030<>m^`04045Yh@33_K/0`kfk0<>m^`80
[Jf]1`33_K/2045Yh@<0_[Vh00<0@FWQ0;ji^02n^KP01P2n^KP00`2][Jd0];2a0;B`/@080;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03
0:f][@2aZid0/J^M00/0/J^M00<0@FWQ0:f][@2i/ZH01@2i/ZH2045Yh@<0[Jf]00D0@FWQ0;VbYP2i
/ZH0^K:V0:f][@060;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`
0080@FWQ1031^[02045Yh@X0`KZ`00@0[Jf]0<>m/`11JN40@FWQ4P33_K<00`2][Jd0aKje0<Fn]@0?
0<Fn]@@0[Jf]0P11JN4;0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:
0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0@FWQ045Yh@X0al6l0P11
JN440<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l00<0@FWQ0<K0_011JN400`36`;`01@11JN40a/2l
0<K0_011JN40[Jf]00<0`kfk00@0@FWQ0:f][@2][Jd0[Jf]2@33_K/6045Yh@P0_[Vh00<0[Jf]0;B`
/@2d/;401P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3P
iP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid0
0`11JN40[Jf]0;VbYP050;VbYP80@FWQ0`2i/ZH01@11JN40[Jf]0:f][@2i/ZH0[Jf]00H0_[N/0P11
JN450;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/002045Yh@@0`KZ`0P11JN4:0<6j/080@FWQ0P33
_K<2045Yh@030<>m/`11JN40@FWQ00d0`kfc00<0[Jf]0<Fn]@35_[D04`35_[D2045Yh@/0a[ng<02]
[Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01@38`K/2045Yh@030<S1^`11
JN40@FWQ00@0@FWQ1@38`K/0102][Jd0al6l045Yh@11JN4:0<O1_080@FWQ1037`K`0102][Jd0a/2l
045Yh@11JN450<K0_0<0@FWQ0P36`;`2045Yh@80a/2l00<0@FWQ0:f][@33_K/00P2][Jd00`11JN40
`kfk0<>m^`0:0<>m^`80@FWQ302n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f]
[@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid0
0`11JN40[Jf]0;VbYP050;VbYP80@FWQ0`2i/ZH2045Yh@040;VbYP2][Jd0[Jf]0:f][@H0_[N/00<0
@FWQ0;jg[02n]j`00`2n]j`2045Yh@<0_[N/00H0[Jf]0<6j/031^[00@FWQ0<6j/011JN430<6j/080
@FWQ2@31^[000`11JN40[Jf]0<>m/`040<>m/`<0@FWQ0`33_K<7045Yh@<0`kfc00<0[Jf]0<Fn]@35
_[D04`35_[D2045YhAL0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/00`38`K/5045Yh@@0b<6k0P11JN450<S1^`04
0:f][@37`K`0@FWQ045Yh@X0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN40
0`36`;`0@FWQ0<K0_002045Yh@030<K0_02][Jd0@FWQ0080[Jf]0P33_K/00`11JN40`kfk0<>m^`09
0<>m^`80@FWQ3@2n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX005
09nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2]
[Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[
W@0;0;6[W@03045Yh@2][Jd0^K:V00D0^K:V0P11JN430;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/0:f]
[@030:f][@<0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0020;jg[0060:f][@31
^[00`KZ`045Yh@31^[00@FWQ0`31^[03045Yh@L0`KZ`0P11JN400`2][Jd0`kfc0<>m/`030<>m/`<0
@FWQ1P33_K<2045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D04`35_[D2045YhAL0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/01@38`K/2045Yh@H0b<6k0P11JN440<S1^`040:f][@37`K`0@FWQ045Yh@X0al6l0P11JN440<O1
_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN400`36`;`0@FWQ0:f][@02045Yh@040:f][@36`;`0
@FWQ0:f][@<0`kfk00<0@FWQ0<>m^`33_K/02P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d
/;40];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00
/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80
[Jf]102TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@03045Yh@2][Jd0^K:V00D0^K:V0P11JN430;VbYP80
@FWQ0P2i/ZH00`2][Jd0@FWQ0;jg[0030;jg[0@0[Jf]0P11JN420;jg[003045Yh@2n]j`0_[N/0080
_[N/00H0[Jf]0<6j/031^[00@FWQ0<6j/011JN420<6j/080@FWQ00<0`KZ`045Yh@31^[001@31^[02
045Yh@030<6j/02][Jd0`kfc00D0`kfc0P11JN460<>m/`80@FWQ1@33_K<00`2][Jd0aKje0<Fn]@04
0<Fn]@H0@FWQ1035_[D2045Yh@<0aKje0P11JN4G0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX0102][Jd0b<6k0<S1^`11JN4C0<S1^`030:f][@38`K/0b<6k00D0b<6k0P11
JN470<S1^`03045Yh@38`K/0b<6k0080b<6k00@0[Jf]0<O1_011JN40@FWQ2P37`K`00`11JN40al6l
045Yh@030<O1_0040:f][@36`;`0@FWQ045Yh@@0a/2l00H0[Jf]045Yh@11JN40[Jf]045Yh@36`;`2
045Yh@80a/2l00<0@FWQ0:f][@33_K/00P33_K/00`11JN40`kfk0<>m^`0:0<>m^`030:f][@2n^KP0
_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`
KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BN
S`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@80@FWQ1P2i/ZH2045Yh@<0^K:V00H0
@FWQ0;VbYP11JN40^K:V0:f][@11JN480;jg[080[Jf]0`11JN440;jg[0060:f][@31^[00@FWQ045Y
h@31^[00@FWQ0P31^[02045Yh@030<6j/011JN40`KZ`00D0`KZ`0P11JN400`31^[00[Jf]0<>m/`05
0<>m/`80@FWQ1P33_K<2045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D01035_[D2045Yh@@0aKje00@0@FWQ
0<Fn]@35_[D0@FWQ1@35_[D2045Yh@80a[ng0`11JN490<Jo]`H0@FWQ0`36_kL00`2][Jd0al6h0<O1
^00D0<O1^0<0@FWQ2037`KX00`11JN40al6j0<O1^P05045Yh@D0al6j00@0[Jf]0<S1^`11JN40@FWQ
4`38`K/00`2][Jd0b<6k0<S1^`050<S1^`80@FWQ1`38`K/00`11JN40b<6k0<S1^`020<S1^`040:f]
[@37`K`0@FWQ045Yh@/0al6l1011JN400`37`K`0[Jf]0<K0_002045Yh@@0[Jf]00H0a/2l045Yh@11
JN40a/2l045Yh@36`;`2045Yh@<0a/2l00D0[Jf]0<>m^`33_K/0`kfk045Yh@070<>m^`03045Yh@33
_K/0`kfk0080`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2O
Vj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]
0:BNS`2TWXl01`2TWXl30:f][@d0/J^M0P11JN450;VbYP80@FWQ0P2i/ZH01`11JN40^K:V045Yh@2i
/ZH0@FWQ0;VbYP2][Jd00P11JN440;jg[080@FWQ1@2n]j`02011JN40[Jf]0:f][@2][Jd0_[N/0:f]
[@31^[00@FWQ0P31^[000`11JN40`KZ`0<6j/002045Yh@030<6j/011JN40`KZ`00D0`KZ`0P11JN40
0`31^[00[Jf]0<>m/`050<>m/`80@FWQ1P33_K<2045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D2
045Yh@H0aKje0`11JN450<Fn]@@0@FWQ0`36_kL2045Yh@T0a[ng0P11JN450<Jo]`H0@FWQ0`37`KP6
045Yh@H0al6h0P11JN400`2][Jd0al6j0<O1^P02045Yh@H0al6j00<0@FWQ0<O1^P11JN401@37`KX0
0`11JN40al6j0<O1^P020<O1^P040:f][@38`K/0b<6k045YhA<0b<6k00<0[Jf]0<S1^`38`K/01@38
`K/2045Yh@L0b<6k0P11JN430<S1^`040:f][@37`K`0@FWQ045Yh@h0al6l00<0[Jf]045Yh@11JN40
0`11JN440<K0_007045Yh@36`;`0@FWQ0<K0_011JN40a/2l045Yh@040<K0_0050:f][@33_K/0`kfk
0<>m^`11JN401`33_K/00`11JN40`kfk0<>m^`020<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f]
[@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@`0/J^M0P11JN450;VbYP80@FWQ0`2i/ZH2045Y
h@80^K:V00@0@FWQ0:f][@11JN40@FWQ102n]j`2045Yh@D0_[N/00@0@FWQ0;jg[02n]j`0_[N/0`2]
[Jd01011JN40[Jf]0<6j/011JN420<6j/080@FWQ00<0`KZ`045Yh@31^[001031^[02045Yh@80`KZ`
00<0[Jf]0<>m/`33_K<01033_K<2045Yh@H0`kfc0P11JN450<>m/`030:f][@35_[D0aKje00<0aKje
0P11JN470<Fn]@80@FWQ1@35_[D2045Yh@H0a[ng0P11JN480<Jo]`80@FWQ1@36_kL0102][Jd0al6h
045Yh@11JN470<O1^080@FWQ1`37`KP2045Yh@030<O1^02][Jd0al6j0080al6j00<0@FWQ0<O1^P37
`KX01037`KX2045Yh@L0al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@0F0<S1^`030:f][@38`K/0b<6k
00D0b<6k0P11JN470<S1^`80@FWQ0`38`K/0102][Jd0al6l045Yh@11JN490<O1_0D0[Jf]0P37`K`0
102][Jd0a/2l045Yh@11JN440<K0_080@FWQ0`36`;`2045Yh@@0a/2l0P11JN420<>m^`80@FWQ1P33
_K/00`11JN40`kfk0<>m^`020<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`
/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD0
0`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]2@2aZid2045Yh@D0^K:V0P11JN48
0;VbYP80@FWQ1P2n]j`00`11JN40_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/0080_[N/00L0[Jf]
0<6j/011JN40`KZ`0:f][@11JN40[Jf]0080@FWQ0P2][Jd00`11JN40`KZ`0<6j/0030<6j/080@FWQ
0P31^[000`2][Jd0`kfc0<>m/`040<>m/`80@FWQ1P33_K<2045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D0
0`35_[D2045Yh@L0aKje0P11JN450<Fn]@80@FWQ1`36_kL2045Yh@L0a[ng0P11JN450<Jo]`040:f]
[@37`KP0@FWQ045Yh@L0al6h0P11JN460<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P020<O1^P03
045Yh@37`KX0al6j00<0al6j0P11JN470<O1^P05045Yh@37`KX0al6j0<O1^P2][Jd05P38`K/00`2]
[Jd0b<6k0<S1^`050<S1^`80@FWQ2038`K/2045Yh@80b<6k00@0[Jf]0<O1_011JN40@FWQ1037`K`5
0:f][@L0al6l00<0[Jf]0<K0_011JN401@36`;`2045Yh@<0a/2l0P11JN420<K0_080@FWQ00@0[Jf]
0<>m^`33_K/0`kfk0P11JN460<>m^`03045Yh@33_K/0`kfk0080`kfk00<0[Jf]0;ji^02n^KP01P2n
^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`
h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]
0;6[W@2aZid00P2aZid20:f][@L0/J^M0P11JN450;VbYP03045Yh@2i/ZH0^K:V00L0^K:V00<0[Jf]
0;jg[02n]j`01@2n]j`00`11JN40_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]
0<6j/011JN400P31^[001011JN40`KZ`045Yh@11JN420<6j/003045Yh@2][Jd0[Jf]00<0[Jf]0P11
JN420<6j/0030:f][@33_K<0`kfc00@0`kfc0P11JN460<>m/`80@FWQ1@33_K<00`2][Jd0aKje0<Fn
]@030<Fn]@80@FWQ1`35_[D2045Yh@D0aKje0P11JN470<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng00@0
[Jf]0<O1^011JN40@FWQ1`37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP00P37`KP01@2][Jd0al6j
0<O1^P37`KX0@FWQ00D0al6j00<0@FWQ0<O1^P37`KX01P37`KX01@11JN40al6j0<O1^P37`KX0[Jf]
01H0b<6k00<0[Jf]0<S1^`38`K/01@38`K/2045Yh@P0b<6k0P11JN420<S1^`040:f][@37`K`0@FWQ
045Yh@@0[Jf]1`37`K`2045Yh@<0al6l00<0[Jf]0<K0_011JN401@36`;`4045Yh@030<K0_011JN40
@FWQ00@0a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11JN460<>m^`80@FWQ0`33_K/00`2][Jd0_[Vh0;ji
^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0
[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@<0/J^M0`11JN440;VbYP80@FWQ2@2i/ZH0
0`2][Jd0_[N/0;jg[0060;jg[080@FWQ0P2n]j`00`11JN40_[N/0;jg[0030;jg[0030:f][@11JN40
`KZ`00<0`KZ`0`11JN420<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11JN460:f][@030<>m/`11JN40
@FWQ00@0@FWQ0`33_K<2045Yh@H0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D2045Yh@L0aKje0P11JN45
0<Fn]@80@FWQ1`36_kL2045Yh@L0a[ng0P11JN450<Jo]`040:f][@37`KP0@FWQ045Yh@L0al6h0P11
JN460<O1^003045Yh@37`KP0al6h0080al6h00<0[Jf]0<O1^P37`KX01`37`KX00`11JN40al6j0<O1
^P050<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00D0b<6k0P11
JN480<S1^`80@FWQ102][Jd3045Yh@X0al6l0P11JN430<O1_0030:f][@36`;`0@FWQ00D0a/2l0P11
JN4:0<K0_0040:f][@33_K/0`kfk0<>m^`80@FWQ1033_K/3045Yh@<0`kfk00@0[Jf]0;ji^02n^KP0
_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0
/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00@0/J^M045Yh@11JN40@FWQ0P2i/ZH2045Yh@X0
^K:V00<0[Jf]0;jg[02n]j`0202n]j`2045Yh@H0_[N/00<0[Jf]045Yh@31^[000`31^[03045Yh@<0
`KZ`00<0@FWQ0<6j/031^[000P31^[02045Yh@80`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd30<>m
/`80@FWQ1P33_K<00`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ1P35_[D00`11JN40aKje0<Fn]@040<Fn
]@80@FWQ2036_kL2045Yh@H0a[ng0P11JN450<Jo]`040:f][@37`KP0@FWQ045Yh@L0al6h0P11JN45
0<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P040<O1^P0300000037`KX0al6j00L0al6j0P11JN44
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01@38`K/2045Yh@80b<6k1P2][Jd2
045Yh@80b<6k00<0[Jf]0<O1_011JN400P11JN440<O1_003045Yh@37`K`0al6l00<0al6l00<0@FWQ
0<O1_037`K`00P37`K`00`2][Jd0@FWQ0<K0_0030<K0_080@FWQ3036`;`0102][Jd0`kfk0<>m^`33
_K/2045Yh@@0`kfk00<0@FWQ0<>m^`11JN400`33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo
001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@0:0;6[W@<0[Jf]00<0^K:V045Yh@11JN400P11JN4:0;VbYP030:f][@2n]j`0_[N/00l0_[N/0`11
JN440<6j/080@FWQ1031^[000`11JN40`KZ`0<6j/0020<6j/080@FWQ0P31^[000`2][Jd0`kfc0<>m
/`080<>m/`<0[Jf]0P11JN430:f][@<0`kfc00<0[Jf]0<Fn]@35_[D01@35_[D00`11JN40aKje0<Fn
]@040<Fn]@03045Yh@35_[D0aKje00@0aKje0P11JN480<Jo]`80@FWQ1P36_kL2045Yh@D0a[ng00@0
[Jf]0<O1^011JN40@FWQ1`37`KP2045Yh@D0al6h0P11JN440<O1^0030:f][@37`KX0al6j00h0al6j
00<0@FWQ0<O1^P37`KX00`37`KX0102][Jd0b<6k0<S1^`11JN4C0<S1^`040:f][@38`K/0b<6k0<S1
^`@0[Jf]0P11JN420:f][@H0b<6k0P11JN420<S1^`030:f][@37`K`0@FWQ0080@FWQ0`37`K`00`11
JN40al6l045Yh@050<O1_0D0@FWQ4`36`;`01`2][Jd0`kfk0<>m^`33_K/0@FWQ0<>m^`11JN400P33
_K/01011JN40`kfk0<>m^`11JN420<>m^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00@FWQ0080@FWQ00<0`KZ`045Yh@11JN401031^[000`11JN40`KZ`0<6j
/0020<6j/080@FWQ0P31^[000`2][Jd0`kfc0<>m/`0;0<>m/`80@FWQ0`33_K<90:f][@<0aKje0`11
JN430<Fn]@03045Yh@35_[D0aKje00@0aKje0P11JN480<Jo]`80@FWQ1P36_kL2045Yh@D0a[ng00@0
[Jf]0<O1^011JN40@FWQ1`37`KP2045Yh@D0al6h0P11JN440<O1^0030:f][@37`KX0al6j00`0al6j
0`11JN450<O1^P040:f][@38`K/0b<6k045Yh@h0b<6k2@2][Jd40<S1^`80@FWQ2038`K/2045Yh@80
b<6k00H0[Jf]0<O1_011JN40@FWQ0<O1_011JN430<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_00A
0<K0_0030:f][@33_K/0`kfk0080`kfk1011JN430<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP0
0`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5
M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001031^[000`11JN40`KZ`0<6j/003045Y
h@@0`KZ`0P11JN420<6j/0030:f][@33_K<0`kfc00/0`kfc0`11JN440<>m/`030000002][Jd0aKje
00@0aKje1P2][Jd4045Yh@80[Jf]1035_[D2045Yh@P0a[ng0P11JN460<Jo]`80@FWQ1@36_kL0102]
[Jd0al6h045Yh@11JN470<O1^080@FWQ1@37`KP2045Yh@@0al6h00<0[Jf]0<O1^P37`KX02P37`KX4
045Yh@H0al6j00@0[Jf]0<S1^`38`K/0@FWQ0P38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/01P38
`K/00`11JN40b<6k0<S1^`060<S1^`80@FWQ0P38`K/0102][Jd0al6l045Yh@11JN420<O1_0@0@FWQ
2`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f]
[@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3oool00640/>3V0P2]
[Jd:0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0090<6j/0<0@FWQ0P31^[02045Yh@80`KZ`00<0
[Jf]0<>m/`33_K<02`33_K<3045Yh@D0`kfc00<0@FWQ0<Fn]@35_[D03035_[D00`11JN40aKje0<Fn
]@040:f][@80@FWQ202][Jd2045Yh@030:f][@36_kL0a[ng00<0a[ng0P11JN450<Jo]`040:f][@37
`KP0@FWQ045Yh@L0al6h0P11JN450<O1^080@FWQ1037`KP01@2][Jd0al6j0<O1^P37`KX0@FWQ00H0
al6j1011JN4;0:f][@03045Yh@2][Jd0[Jf]0140b<6k00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40
b<6k0<S1^`060<S1^`80@FWQ0P38`K/4045YhA40al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0
];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/
00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<02`33_K<2045Yh@030<>m
/`11JN40`kfc0080`kfc0P11JN460<Fn]@03045Yh@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D0
1035_[D2045Yh@L0a[ng0P11JN420<Jo]`D0[Jf]0P11JN470:f][@80@FWQ1`2][Jd2045Yh@D0[Jf]
0P11JN470:f][@80@FWQ1@2][Jd3045Yh@H0al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@020<S1^`03
045Yh@38`K/0b<6k0140b<6k00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`060<S1^`80
@FWQ0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2]
[Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0
/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[003`31^[02045Yh@030<6j/02][Jd0`kfc00X0`kfc
1011JN420<>m/`05045Yh@33_K<0`kfc0<>m/`11JN401P35_[D00`11JN40aKje0<Fn]@050<Fn]@03
045Yh@35_[D0aKje00@0aKje0P11JN470<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng00@0[Jf]0<O1^011
JN40@FWQ1`37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP00P37`KP00`2][Jd0al6j0<O1^P02045Y
h@D0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@<0al6j00@0[Jf]0<S1^`38`K/0@FWQ4`38`K/0
0`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k00H0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f]
[@0D0<O1_0030:f][@36`;`0a/2l00h0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0
[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=
0;jg[0030:f][@31^[00`KZ`00l0`KZ`0P11JN400`31^[00[Jf]0<>m/`060<>m/`03045Yh@33_K<0
`kfc00<0`kfc0P11JN430<>m/`80@FWQ00<0`kfc045Yh@35_[D01@35_[D00`11JN40aKje0<Fn]@05
0<Fn]@03045Yh@35_[D0aKje00@0aKje0P11JN460<Jo]`80@FWQ2036_kL2045Yh@80a[ng00D00000
0<Jo]`36_kL0[Jf]0<O1^002045Yh@L0al6h0P11JN460<O1^003045Yh@37`KP0al6h0080al6h00D0
[Jf]0<O1^P37`KX0al6j045Yh@050<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN430<O1^P040:f]
[@38`K/0b<6k045YhA<0b<6k00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`060<S1^`05
045Yh@38`K/0b<6k0<S1^`2][Jd05037`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2]
[Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f]
[Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00?0<6j/080
@FWQ00<0`KZ`0:f][@33_K<01P33_K<00`11JN40`kfc0<>m/`0:0<>m/`80@FWQ1`35_[D3045Yh@<0
aKje00<0@FWQ0<Fn]@35_[D01@35_[D3045Yh@D0a[ng0P11JN480<Jo]`80@FWQ1@36_kL00`2][Jd0
@FWQ045Yh@080<O1^080@FWQ1P37`KP2045Yh@<0al6h00@0[Jf]0<O1^P37`KX0@FWQ1P37`KX00`11
JN40al6j0<O1^P050<O1^P80@FWQ0`37`KX0102][Jd0b<6k045Yh@11JN4C0<S1^`030:f][@38`K/0
b<6k00H0b<6k00<0@FWQ0<S1^`38`K/01P38`K/01@11JN40b<6k0<S1^`38`K/0[Jf]01@0al6l00<0
[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0
[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102]
[Jd50;jg[0030:f][@31^[00`KZ`0100`KZ`00<0@FWQ0<6j/02][Jd01P33_K<2045Yh@d0`kfc00<0
[Jf]0<Fn]@35_[D02035_[D3045Yh@D0aKje1@11JN400`36_kL0@FWQ0<Jo]`020<Jo]`80@FWQ2@36
_kL4045Yh@<0a[ng00<0[Jf]045Yh@11JN402037`KP2045Yh@L0al6h0P11JN420<O1^0040:f][@37
`KX0al6j045Yh@L0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`11JN40al6j045Yh@030<O1^P030:f]
[@38`K/0@FWQ0080@FWQ4P38`K/00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k00D0b<6k
0P11JN430<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40
oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/
102][Jd00`2n]j`0[Jf]0<6j/00A0<6j/080@FWQ00<0[Jf]0<>m/`33_K<01033_K<2045Yh@d0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`04045Yh@X0a[ng0P11JN420<Jo]`D0@FWQ
1`37`KP4045Yh@T0al6h1@11JN490<O1^PD0@FWQ1P37`KX00`2][Jd0b<6k045Yh@02045YhA80b<6k
00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ0`38`K/00`2][Jd0al6l
0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00l0_[N/1@2][Jd@0<6j/003045Yh@2][Jd0`kfc00@0`kfc0P11JN4>0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL03P36_kL2045Yh@D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0@FWQ0080@FWQ4P38`K/00`2][Jd0b<6k0<S1
^`060<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN440<S1^`030:f][@37`K`0al6l00/0al6l1@2]
[Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2@31^[02045Yh@@0`kfc00<0
@FWQ0<>m/`11JN403P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00h0a[ng0P11
JN450<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k045Y
h@02045YhA80b<6k00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`040<S1^`03045Yh@38
`K/0b<6k00<0b<6k00<0[Jf]0<O1_037`K`01@37`K`60:f][@L0al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40oooo001a
0;3PiP<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[002031^[070:f][@<0`KZ`1@11JN420<>m/`03045Yh@33_K<0`kfc00`0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0>0<Jo]`80@FWQ1@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`11JN400P11JN4B0<S1^`030:f][@38`K/0
b<6k00H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`040<S1^`030:f][@37`K`0
al6l00D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]0`33_K<00`11
JN40`kfc0<>m/`0<0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL03P36_kL2045Y
h@D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0@FWQ
0080@FWQ4P38`K/00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0@FWQ00<0@FWQ1038`K/60:f]
[A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f]
[@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0>0<Jo]`80@FWQ1@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`11JN400P11JN4B0<S1
^`030:f][@38`K/0b<6k00<0b<6k1@11JN400`38`K/0[Jf]0:f][@050:f][@<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0>0<Jo]`80@FWQ1@36_kL00`2][Jd0
al6h0<O1^0080<O1^003045Yh@37`KP0al6h00X0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0
b<6k045Yh@11JN4C0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool0
07/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0>0<Jo]`80@FWQ1@36_kL00`2]
[Jd0al6h0<O1^0070<O1^003045Yh@37`KP0@FWQ00/0al6h00<0[Jf]0<O1^P37`KX05037`KX0102]
[Jd0b<6k0<S1^`11JN4>0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng00/0a[ng1@11JN450<Jo
]`030:f][@37`KP0al6h00P0al6h00<0@FWQ0<O1^037`KP02P37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][JeY0;3P
iP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0
al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00
Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]
2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd0
0`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`4
0:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jej0;3P
iP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H10?ooo`00
V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0[Jf]4@31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3PiP40oooo002T
0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l1`2][Jf;
0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l
0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo002i0;3PiPL0
[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool00<P0/>3V
2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0[Jf]1@35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37
`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51992 .3309 m
.50822 .33081 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53831 .3308 m
.5333 .33406 L
s
.54165 .33075 m
.53831 .3308 L
s
.545 .33389 m
.54165 .33075 L
s
.54666 .33386 m
.54165 .33075 L
s
.50154 .33071 m
.48987 .33043 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49486 .33392 m
.49487 .33057 L
s
.49653 .33295 m
.49654 .3306 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48449 .32223 m
.49601 .32257 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45344 .32879 m
.45458 .32886 L
s
.255 .412 .882 r
.52078 .33862 m
.53237 .33858 L
s
.53899 .3385 m
.55056 .33828 L
s
.50092 .33841 m
.50422 .34072 L
s
.49761 .33834 m
.50092 .33841 L
s
.50092 .33841 m
.50587 .34075 L
s
.4943 .34052 m
.49761 .33834 L
s
.50587 .34075 m
.50918 .3453 L
s
.50422 .34072 m
.50752 .34528 L
s
.55716 .3381 m
.56868 .33769 L
s
.49098 .34495 m
.4943 .34052 L
s
.50918 .3453 m
.51082 .35209 L
s
.50752 .34528 m
.50917 .35207 L
s
0 0 0 r
.53166 .35983 m
.52998 .36307 L
s
.53334 .36304 m
.53166 .35983 L
s
.255 .412 .882 r
.47947 .3378 m
.48112 .33786 L
s
.47617 .33993 m
.47947 .3378 L
s
.47782 .33999 m
.47947 .3378 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52998 .36307 m
.52998 .3663 L
s
.53166 .36629 m
.53334 .36304 L
s
.255 .412 .882 r
.47615 .34444 m
.47782 .33999 L
s
.4745 .34438 m
.47617 .33993 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51082 .35661 m
.51082 .35209 L
s
.50916 .3566 m
.50917 .35207 L
s
.46798 .33731 m
.47125 .33972 L
s
.46307 .33706 m
.46798 .33731 L
s
.47125 .33972 m
.4745 .34438 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49644 .36225 m
.49645 .35902 L
s
.49476 .36323 m
.49477 .35895 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49088 .36985 m
.49107 .32244 L
s
.48923 .3698 m
.48942 .32239 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52574 .33861 m
.52576 .38618 L
s
.5274 .33861 m
.52743 .38617 L
s
.54395 .33842 m
.54401 .36327 L
s
.5456 .33839 m
.54567 .36324 L
s
0 0 0 r
.54928 .36106 m
.54961 .35909 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57519 .37133 m
.57522 .37491 L
s
.57685 .37022 m
.57688 .37484 L
s
.255 .412 .882 r
.5621 .33794 m
.56226 .36962 L
s
.56375 .33788 m
.56391 .36956 L
s
.47606 .36028 m
.47615 .34444 L
s
.50915 .36339 m
.51082 .35661 L
s
.50749 .36337 m
.50916 .3566 L
s
.45979 .33914 m
.46307 .33706 L
s
.45816 .33905 m
.46307 .33706 L
s
.47438 .36476 m
.4745 .34438 L
s
.58018 .33943 m
.58507 .33691 L
s
.57693 .34411 m
.58018 .33943 L
s
.58182 .33934 m
.58507 .33691 L
s
.58507 .33691 m
.58833 .33673 L
s
.57857 .34403 m
.58182 .33934 L
s
.57534 .35097 m
.57693 .34411 L
s
.58833 .33673 m
.59324 .33869 L
s
.57698 .35089 m
.57857 .34403 L
s
.45812 .34357 m
.45979 .33914 L
s
.45649 .34348 m
.45816 .33905 L
s
.52741 .36345 m
.53074 .36797 L
s
.50582 .36788 m
.50915 .36339 L
s
.50416 .36786 m
.50749 .36337 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54237 .36784 m
.54401 .36327 L
s
.54403 .36781 m
.54567 .36324 L
s
.57534 .35097 m
.57537 .3555 L
s
.59324 .33869 m
.59653 .34301 L
s
.45808 .3481 m
.45812 .34357 L
s
.57698 .35089 m
.57701 .35542 L
s
.53074 .36797 m
.53573 .3702 L
s
.49091 .36304 m
.49421 .36766 L
s
.45645 .348 m
.45649 .34348 L
s
.50083 .37007 m
.50582 .36788 L
s
.50083 .37007 m
.50416 .36786 L
s
.53905 .37016 m
.54237 .36784 L
s
.53905 .37016 m
.54403 .36781 L
s
.53573 .3702 m
.53905 .37016 L
s
.57537 .3555 m
.57705 .36222 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46294 .35515 m
.47278 .35788 L
s
.47278 .35788 m
.47441 .36022 L
s
.49421 .36766 m
.49751 .37001 L
s
.45808 .3481 m
.45968 .35272 L
s
.57701 .35542 m
.5787 .36215 L
s
.49751 .37001 m
.50083 .37007 L
s
.47438 .36476 m
.47606 .36028 L
s
.45645 .348 m
.45805 .35263 L
s
.48426 .36966 m
.49088 .36985 L
s
.45968 .35272 m
.46294 .35515 L
s
.45805 .35263 m
.46294 .35515 L
s
.55729 .36977 m
.56391 .36956 L
s
0 0 0 r
.57522 .37491 m
.58187 .37461 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47272 .36696 m
.47438 .36476 L
s
.42425 .33431 m
.43548 .33526 L
s
.46941 .36909 m
.47272 .36696 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5787 .36215 m
.58201 .36653 L
s
.57705 .36222 m
.58037 .36661 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59979 .38445 m
.60018 .38662 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60779 .33542 m
.60789 .34448 L
s
.60779 .33542 m
.60945 .33982 L
s
.60945 .33982 m
.61104 .33743 L
s
.61104 .33743 m
.61423 .33491 L
s
.60789 .34448 m
.60945 .33982 L
s
.61423 .33491 m
.62064 .33436 L
s
.43029 .36668 m
.43065 .33487 L
s
.45798 .3617 m
.45961 .36179 L
s
.4596 .36406 m
.45961 .36179 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46284 .36878 m
.46941 .36909 L
s
.58037 .36661 m
.58531 .36864 L
s
.45796 .36397 m
.45798 .3617 L
s
.52077 .38618 m
.52743 .38617 L
s
.42868 .36655 m
.42905 .33473 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58201 .36653 m
.58531 .36864 L
s
.59502 .35671 m
.59667 .35888 L
s
.59341 .35908 m
.59502 .35671 L
s
.59341 .35908 m
.59506 .36125 L
s
.45796 .36397 m
.45958 .36633 L
s
.45958 .36633 m
.46284 .36878 L
s
.56231 .38099 m
.56398 .38322 L
s
.56067 .38332 m
.56231 .38099 L
s
.59667 .35888 m
.59669 .36115 L
s
.62064 .33436 m
.62386 .33634 L
s
.58531 .36864 m
.59022 .36837 L
s
.56067 .38332 m
.56233 .38555 L
s
.59347 .3659 m
.59669 .36115 L
s
.56233 .38555 m
.56398 .38322 L
s
.59022 .36837 m
.59347 .3659 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62386 .33634 m
.62548 .33846 L
s
.44166 .36296 m
.44331 .3608 L
s
.44331 .3608 m
.44491 .36318 L
s
.44489 .36546 m
.44491 .36318 L
s
.60962 .35571 m
.61282 .35318 L
s
.60803 .3581 m
.60962 .35571 L
s
.60803 .3581 m
.60808 .36265 L
s
.44324 .36763 m
.44489 .36546 L
s
.61282 .35318 m
.6208 .34797 L
s
.62548 .33846 m
.62556 .34527 L
s
.44166 .36296 m
.44326 .36535 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60965 .35798 m
.61285 .35546 L
s
.60805 .36038 m
.60965 .35798 L
s
.41446 .3516 m
.4147 .33342 L
s
.43045 .35302 m
.43198 .35997 L
s
.61285 .35546 m
.62083 .35025 L
s
.41287 .35145 m
.41312 .33326 L
s
.43837 .36729 m
.44324 .36763 L
s
.6208 .34797 m
.62397 .34542 L
s
.60808 .36265 m
.60972 .36481 L
s
.62397 .34542 m
.62554 .343 L
s
.62083 .35025 m
.624 .34769 L
s
.624 .34769 m
.62556 .34527 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43198 .35997 m
.43516 .36477 L
s
.43516 .36477 m
.43837 .36729 L
s
.40992 .33521 m
.41303 .34007 L
s
.40523 .33243 m
.40992 .33521 L
s
.63809 .33266 m
.63969 .33476 L
s
.63654 .33509 m
.63809 .33266 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60186 .38626 m
.60245 .3825 L
s
.59831 .38553 m
.59849 .38653 L
s
.5 Mabswid
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60972 .36481 m
.61297 .36685 L
s
.63654 .33509 m
.63815 .3372 L
s
.40209 .33209 m
.40523 .33243 L
s
.61297 .36685 m
.61941 .36633 L
s
.63815 .3372 m
.63969 .33476 L
s
.42386 .36615 m
.43029 .36668 L
s
.39893 .33401 m
.40209 .33209 L
s
.39737 .33383 m
.40209 .33209 L
s
.62417 .36135 m
.62571 .35665 L
s
.62571 .35665 m
.62582 .36578 L
s
.61941 .36633 m
.62259 .36378 L
s
.62259 .36378 m
.62417 .36135 L
s
.62417 .36135 m
.62582 .36578 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40812 .35097 m
.41923 .35205 L
s
.39574 .3382 m
.39893 .33401 L
s
.39418 .33801 m
.39737 .33383 L
s
.63831 .34858 m
.64029 .37587 L
s
.63712 .37618 m
.63831 .34858 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39411 .34257 m
.39574 .3382 L
s
.39256 .34239 m
.39418 .33801 L
s
.41406 .38133 m
.41425 .36758 L
s
.41256 .3743 m
.41425 .36758 L
s
.39245 .34924 m
.39411 .34257 L
s
.63851 .36228 m
.6387 .37602 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39089 .34905 m
.39256 .34239 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40932 .37858 m
.41256 .3743 L
s
.41256 .3743 m
.41406 .38133 L
s
.39226 .36068 m
.39245 .34924 L
s
.39071 .3605 m
.39089 .34905 L
s
.63712 .37618 m
.63877 .38062 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40454 .38041 m
.40932 .37858 L
s
.63877 .38062 m
.64029 .37587 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37432 .32856 m
.37985 .36146 L
s
.36766 .3598 m
.37432 .32856 L
s
.39226 .36068 m
.39371 .36775 L
s
.40138 .38009 m
.40454 .38041 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39071 .3605 m
.39215 .36757 L
s
.39371 .36775 m
.3952 .37251 L
s
.39827 .37745 m
.40138 .38009 L
s
.3967 .37728 m
.40138 .38009 L
s
.36918 .36001 m
.37419 .33541 L
s
.39215 .36757 m
.39364 .37234 L
s
.3952 .37251 m
.39827 .37745 L
s
.39364 .37234 m
.3967 .37728 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37526 .36085 m
.38447 .36204 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36228 .32675 m
.36766 .3598 L
s
.35568 .358 m
.36228 .32675 L
s
.35716 .35823 m
.36214 .33362 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68917 .32577 m
.70378 .32321 L
s
.34753 .32428 m
.34899 .32454 L
s
.34457 .32606 m
.34753 .32428 L
s
.34602 .32632 m
.34753 .32428 L
s
.35124 .35729 m
.36164 .35892 L
s
.34447 .33066 m
.34602 .32632 L
s
.34302 .3304 m
.34457 .32606 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70378 .32321 m
.7067 .32498 L
s
.70378 .32321 m
.70814 .3247 L
s
.34412 .34681 m
.34447 .33066 L
s
.34024 .32527 m
.34302 .3304 L
s
.34256 .35118 m
.34302 .3304 L
s
.33742 .32242 m
.34024 .32527 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69359 .32502 m
.69461 .37349 L
s
.69506 .32477 m
.69609 .37325 L
s
.7067 .32498 m
.70967 .32904 L
s
.33315 .32159 m
.33742 .32242 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70814 .3247 m
.7111 .32877 L
s
.34256 .35118 m
.34412 .34681 L
s
.33026 .32334 m
.33315 .32159 L
s
.32885 .32305 m
.33315 .32159 L
s
.34127 .34398 m
.34266 .34655 L
s
.70967 .32904 m
.71121 .33339 L
s
.33271 .34007 m
.34127 .34398 L
s
.7111 .32877 m
.71263 .33311 L
s
.34106 .35324 m
.34256 .35118 L
s
.71121 .33339 m
.71279 .34005 L
s
.32874 .32767 m
.33026 .32334 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32064 .31205 m
.32065 .3113 L
s
.32044 .31216 m
.32065 .3113 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33812 .35504 m
.34106 .35324 L
s
.71263 .33311 m
.71421 .33978 L
s
.32734 .32739 m
.32885 .32305 L
s
.32863 .3323 m
.32874 .32767 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69016 .37418 m
.70486 .3718 L
s
.32993 .33721 m
.33271 .34007 L
s
.32852 .33693 m
.33271 .34007 L
s
.71279 .34005 m
.71306 .35165 L
s
.33239 .35399 m
.33812 .35504 L
s
.32723 .33201 m
.32734 .32739 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7194 .32014 m
.72908 .31805 L
s
.5 Mabswid
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32863 .3323 m
.32993 .33721 L
s
.71421 .33978 m
.71448 .35138 L
s
.32723 .33201 m
.32852 .33693 L
s
.72357 .31926 m
.72438 .35176 L
s
.70486 .3718 m
.7077 .36897 L
s
.70486 .3718 m
.70914 .36871 L
s
.7118 .35888 m
.71306 .35165 L
s
.72496 .31896 m
.72577 .35147 L
s
.3283 .34621 m
.32971 .34648 L
s
.32966 .3488 m
.32971 .34648 L
s
.3296 .35113 m
.33239 .35399 L
s
.7077 .36897 m
.71047 .3638 L
s
.71322 .35862 m
.71448 .35138 L
s
.71047 .3638 m
.7118 .35888 L
s
.32824 .34853 m
.3283 .34621 L
s
.70914 .36871 m
.7119 .36353 L
s
.32824 .34853 m
.3296 .35113 L
s
.7119 .36353 m
.71322 .35862 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72019 .3526 m
.72577 .35147 L
s
.72542 .33751 m
.72698 .34419 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30033 .31425 m
.30964 .31652 L
s
.72698 .34419 m
.72985 .34827 L
s
.31577 .34363 m
.31709 .34625 L
s
.31703 .34858 m
.31709 .34625 L
s
.31434 .34566 m
.31577 .34363 L
s
.31559 .35063 m
.31703 .34858 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30475 .34822 m
.30562 .31556 L
s
.31434 .34566 m
.31565 .34829 L
s
.31149 .34974 m
.31559 .35063 L
s
.30341 .34791 m
.30429 .31523 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72985 .34827 m
.73265 .35001 L
s
.73265 .35001 m
.73672 .34911 L
s
.73525 .34474 m
.73666 .34677 L
s
.73525 .34474 m
.73654 .3421 L
s
.30884 .3468 m
.31149 .34974 L
s
.73654 .3421 m
.73795 .34413 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30512 .33419 m
.30627 .34151 L
s
.30627 .34151 m
.30884 .3468 L
s
.73795 .34413 m
.73801 .34647 L
s
.73672 .34911 m
.73801 .34647 L
s
.74784 .31588 m
.75166 .31253 L
s
.74667 .32088 m
.74784 .31588 L
s
.74667 .32088 m
.74679 .32554 L
s
.74914 .31554 m
.75166 .31253 L
s
.74797 .32054 m
.74914 .31554 L
s
.74797 .32054 m
.7481 .32521 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74679 .32554 m
.74823 .32989 L
s
.29943 .34696 m
.30475 .34822 L
s
.7481 .32521 m
.74953 .32956 L
s
.75166 .31253 m
.7555 .31149 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74823 .32989 m
.75219 .33124 L
s
.74953 .32956 m
.75219 .33124 L
s
.28993 .31386 m
.29235 .31922 L
s
.29235 .31922 m
.2935 .32424 L
s
.2935 .32424 m
.2946 .3316 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7555 .31149 m
.7581 .31313 L
s
.74849 .33926 m
.74856 .3416 L
s
.74849 .33926 m
.74979 .33893 L
s
.2862 .31047 m
.28993 .31386 L
s
.29427 .34333 m
.2946 .3316 L
s
.28866 .31351 m
.29107 .31888 L
s
.29107 .31888 m
.29222 .3239 L
s
.29222 .3239 m
.2933 .33126 L
s
.74856 .3416 m
.74993 .34363 L
s
.74979 .33893 m
.74986 .34128 L
s
.2862 .31047 m
.28866 .31351 L
s
.29297 .343 m
.2933 .33126 L
s
.75219 .33124 m
.75991 .33155 L
s
.74993 .34363 m
.75259 .34532 L
s
.7581 .31313 m
.76075 .31711 L
s
.27391 .30681 m
.2862 .31047 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29277 .35006 m
.29427 .34333 L
s
.29148 .34973 m
.29297 .343 L
s
.75259 .34532 m
.75772 .344 L
s
.76186 .31206 m
.76427 .309 L
s
.76075 .31711 m
.76186 .31206 L
s
.76075 .31711 m
.76137 .33826 L
s
.29135 .35444 m
.29277 .35006 L
s
.7631 .31171 m
.76427 .309 L
s
.762 .31675 m
.7631 .31171 L
s
.762 .31675 m
.76248 .33321 L
s
.29006 .35412 m
.29148 .34973 L
s
.76427 .309 m
.7655 .30863 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75991 .33155 m
.76123 .33355 L
s
.28864 .35851 m
.29135 .35444 L
s
.75772 .344 m
.76018 .34096 L
s
.28737 .35819 m
.29006 .35412 L
s
.76018 .34096 m
.76137 .33826 L
s
.76137 .33826 m
.76248 .33321 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28476 .35989 m
.28864 .35851 L
s
.28476 .35989 m
.28737 .35819 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27604 .35752 m
.27754 .30793 L
s
.27727 .35787 m
.27876 .3083 L
s
.27238 .35648 m
.28476 .35989 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77259 .33983 m
.77634 .30526 L
s
.77634 .30526 m
.78206 .33689 L
s
.76895 .34089 m
.77737 .33837 L
s
.7738 .33947 m
.77656 .31234 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78557 .30213 m
.79115 .33383 L
s
.78206 .33689 m
.78557 .30213 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78322 .33652 m
.78581 .30923 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78779 .33499 m
.79445 .33266 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7991 .30912 m
.79999 .30393 L
s
.79828 .3167 m
.7991 .30912 L
s
.79999 .30393 m
.80191 .29831 L
s
.79828 .3167 m
.79869 .32867 L
s
.80015 .3087 m
.80103 .30351 L
s
.79934 .31629 m
.80015 .3087 L
s
.80103 .30351 m
.80294 .29788 L
s
.80191 .29831 m
.8049 .29463 L
s
.79934 .31629 m
.79975 .32826 L
s
.80294 .29788 m
.8049 .29463 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79869 .32867 m
.8 .33546 L
s
.8049 .29463 m
.80692 .29376 L
s
.80692 .29376 m
.80997 .29484 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8 .33546 m
.80122 .33987 L
s
.79975 .32826 m
.80106 .33506 L
s
.80106 .33506 m
.80227 .33947 L
s
.80122 .33987 m
.80348 .34389 L
s
.80227 .33947 m
.80452 .34349 L
s
.80997 .29484 m
.81209 .29875 L
s
.81184 .29155 m
.81252 .31078 L
s
.80959 .31208 m
.81634 .30903 L
s
.8128 .29111 m
.81349 .31035 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80452 .34349 m
.80666 .3451 L
s
.80348 .34389 m
.80666 .3451 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80666 .3451 m
.80869 .34428 L
s
.80869 .34428 m
.8116 .34063 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81843 .28839 m
.82466 .28514 L
s
.8116 .34063 m
.81339 .33494 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8141 .32725 m
.81462 .3418 L
s
.81339 .33494 m
.8141 .32725 L
s
.81339 .33494 m
.81462 .3418 L
s
.82114 .28701 m
.82239 .32091 L
s
.82203 .28654 m
.82329 .32047 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81967 .32223 m
.82329 .32047 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82275 .30589 m
.82391 .31272 L
s
.82391 .31272 m
.82584 .31669 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21722 .28814 m
.21815 .28619 L
s
.2174 .28329 m
.21815 .28619 L
s
.21648 .28524 m
.2174 .28329 L
s
.21648 .28524 m
.21722 .28814 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82584 .31669 m
.82765 .31822 L
s
.2165 .33004 m
.21676 .30028 L
s
.21481 .32914 m
.21676 .30028 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82765 .31822 m
.83018 .31686 L
s
.82916 .31243 m
.83008 .31442 L
s
.82916 .31243 m
.8299 .30953 L
s
.21565 .32959 m
.21621 .31491 L
s
.8299 .30953 m
.83082 .31151 L
s
.83018 .31686 m
.83091 .31396 L
s
.83082 .31151 m
.83091 .31396 L
s
.21547 .33449 m
.2165 .33004 L
s
.21012 .28137 m
.21079 .2843 L
s
.21051 .29162 m
.21079 .2843 L
s
.21481 .32914 m
.21547 .33449 L
s
.2087 .27795 m
.21012 .28137 L
s
.20974 .29114 m
.2106 .28918 L
s
.20964 .29358 m
.21051 .29162 L
s
.83552 .28621 m
.83609 .28084 L
s
.83552 .28621 m
.83571 .2911 L
s
.83609 .28084 m
.83823 .27692 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20578 .27597 m
.2087 .27795 L
s
.20813 .29262 m
.20974 .29114 L
s
.83571 .2911 m
.83666 .29551 L
s
.83628 .28573 m
.83684 .28035 L
s
.83628 .28573 m
.83647 .29061 L
s
.83684 .28035 m
.83823 .27692 L
s
.20803 .29506 m
.20964 .29358 L
s
.83647 .29061 m
.83741 .29502 L
s
.20907 .30828 m
.21003 .30385 L
s
.20966 .31366 m
.21003 .30385 L
s
.83823 .27692 m
.84038 .27542 L
s
.83666 .29551 m
.83899 .29651 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20429 .29509 m
.20813 .29262 L
s
.2042 .29755 m
.20803 .29506 L
s
.83741 .29502 m
.83899 .29651 L
s
.20907 .30828 m
.20966 .31366 L
s
.20822 .31026 m
.20907 .30828 L
s
.83704 .30531 m
.83714 .30777 L
s
.83704 .30531 m
.8378 .30484 L
s
.20427 .27741 m
.20578 .27597 L
s
.83714 .30777 m
.83799 .30975 L
s
.20662 .31178 m
.20822 .31026 L
s
.8378 .30484 m
.83789 .30729 L
s
.84038 .27542 m
.84187 .27687 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83899 .29651 m
.84334 .29604 L
s
.83799 .30975 m
.83957 .31126 L
s
.20348 .27936 m
.20427 .27741 L
s
.20371 .30987 m
.20662 .31178 L
s
.84187 .27687 m
.84343 .28078 L
s
.20299 .27396 m
.20348 .27936 L
s
.2026 .28377 m
.20348 .27936 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2026 .28377 m
.20299 .27396 L
s
.83957 .31126 m
.84244 .30935 L
s
.2028 .29657 m
.20429 .29509 L
s
.2027 .29904 m
.2042 .29755 L
s
.84343 .28078 m
.8439 .27536 L
s
.84343 .28078 m
.84431 .30296 L
s
.8439 .27536 m
.84511 .27188 L
s
.20201 .29855 m
.2028 .29657 L
s
.20241 .30644 m
.20371 .30987 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20191 .30101 m
.2027 .29904 L
s
.8441 .28027 m
.84456 .27485 L
s
.8441 .28027 m
.84478 .29752 L
s
.84456 .27485 m
.84511 .27188 L
s
.84334 .29604 m
.84411 .29802 L
s
.84511 .27188 m
.84575 .27137 L
s
.84244 .30935 m
.84373 .30591 L
s
.20182 .30348 m
.20201 .29855 L
s
.20182 .30348 m
.20241 .30644 L
s
0 0 0 r
.84881 .29307 m
.84974 .30164 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84373 .30591 m
.84431 .30296 L
s
.84431 .30296 m
.84478 .29752 L
s
.1971 .27182 m
.19813 .27778 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84933 .29122 m
.84949 .29276 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84632 .25314 m
.85044 .24942 L
s
.19543 .26779 m
.1971 .27182 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19733 .29756 m
.19743 .29509 L
s
.19691 .29211 m
.19743 .29509 L
s
.1959 .30153 m
.19733 .29756 L
s
.1962 .29409 m
.19691 .29211 L
s
.19429 .26675 m
.19543 .26779 L
s
.84973 .27568 m
.85068 .2697 L
s
.1962 .29409 m
.19671 .29707 L
s
.85068 .2697 m
.8517 .26618 L
s
.19309 .26817 m
.19429 .26675 L
s
.19255 .26765 m
.19429 .26675 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84841 .30497 m
.85083 .30299 L
s
.84873 .25102 m
.85083 .30299 L
s
.84814 .25156 m
.85024 .30348 L
s
.1946 .30303 m
.1959 .30153 L
s
.8517 .26618 m
.85278 .26513 L
s
.85053 .29552 m
.85189 .2995 L
s
.19182 .27209 m
.19309 .26817 L
s
.19287 .30153 m
.1946 .30303 L
s
.85278 .26513 m
.85393 .26655 L
s
.85278 .26513 m
.85444 .26602 L
s
.1913 .27156 m
.19255 .26765 L
s
.85189 .2995 m
.85312 .30099 L
s
.19099 .27903 m
.19182 .27209 L
s
.85393 .26655 m
.85514 .27047 L
s
.19187 .29803 m
.19287 .30153 L
s
.19133 .29752 m
.19287 .30153 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19048 .27851 m
.1913 .27156 L
s
.85444 .26602 m
.85564 .26994 L
s
.85312 .30099 m
.85421 .29998 L
s
.19079 .28401 m
.19099 .27903 L
s
.191 .29201 m
.19187 .29803 L
s
.85514 .27047 m
.85595 .27742 L
s
.19079 .28401 m
.191 .29201 L
s
.19027 .2835 m
.19048 .27851 L
s
.19048 .2915 m
.19133 .29752 L
s
.85421 .29998 m
.85516 .29646 L
s
.85421 .29998 m
.85567 .29595 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85564 .26994 m
.85643 .27689 L
s
.19027 .2835 m
.19048 .2915 L
s
.18609 .25766 m
.18914 .26144 L
s
.85516 .29646 m
.85597 .29043 L
s
.85595 .27742 m
.85615 .28241 L
s
.85597 .29043 m
.85615 .28241 L
s
.85567 .29595 m
.85646 .28992 L
s
.85643 .27689 m
.85664 .28189 L
s
0 0 0 r
.86216 .24996 m
.86232 .24892 L
s
.255 .412 .882 r
.85646 .28992 m
.85664 .28189 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18632 .29491 m
.18778 .25983 L
s
0 0 0 r
.86232 .24892 m
.86315 .2478 L
s
.255 .412 .882 r
.18588 .29439 m
.18734 .25929 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85851 .2587 m
.86123 .25488 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85973 .25707 m
.86195 .30999 L
s
.18462 .29284 m
.18632 .29491 L
s
.86012 .25653 m
.86234 .30948 L
s
0 0 0 r
.86421 .29851 m
.86444 .29908 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18223 .25162 m
.18455 .25548 L
s
.18514 .31206 m
.18569 .31004 L
s
.18535 .307 m
.18569 .31004 L
s
.18482 .30902 m
.18535 .307 L
s
.18482 .30902 m
.18514 .31206 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86128 .28418 m
.86224 .28817 L
s
.18233 .28157 m
.1835 .25383 L
s
.86071 .31151 m
.86234 .30948 L
s
.18199 .28104 m
.18317 .25328 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17506 .23304 m
.17672 .23723 L
s
.255 .412 .882 r
.86257 .25268 m
.86454 .24879 L
s
.86224 .28817 m
.86341 .28913 L
s
.18178 .28611 m
.18233 .28157 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86347 .25102 m
.86465 .27885 L
s
.18146 .28557 m
.18199 .28104 L
s
.86341 .28913 m
.86407 .28807 L
s
.86376 .25046 m
.86494 .27832 L
s
.18073 .28705 m
.18178 .28611 L
s
.18073 .28705 m
.18146 .28557 L
s
.17956 .24547 m
.18112 .24939 L
s
.86407 .28807 m
.86458 .28447 L
s
.86407 .28807 m
.86487 .28393 L
s
0 0 0 r
.86915 .23791 m
.86929 .23646 L
s
.255 .412 .882 r
.86458 .28447 m
.86465 .27885 L
s
.18015 .28599 m
.18073 .28705 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86487 .28393 m
.86494 .27832 L
s
.17811 .30124 m
.18039 .24772 L
s
.17946 .28184 m
.18015 .28599 L
s
.17788 .30071 m
.18017 .24715 L
s
0 0 0 r
.86929 .23646 m
.86968 .23531 L
s
.17439 .27646 m
.17497 .27777 L
s
.255 .412 .882 r
.86545 .24655 m
.86665 .24259 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86968 .23531 m
.87019 .23778 L
s
.86968 .23531 m
.87035 .2372 L
s
.255 .412 .882 r
.1792 .27566 m
.17946 .28184 L
s
.86603 .24486 m
.86755 .28058 L
s
0 0 0 r
.17376 .29109 m
.17502 .26189 L
s
.87019 .23778 m
.87066 .24447 L
s
.17411 .25487 m
.17521 .23362 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87081 .24389 m
.87035 .2372 L
s
.17506 .23304 m
.17411 .25487 L
s
.87066 .24447 m
.87241 .28467 L
s
.255 .412 .882 r
.86697 .2822 m
.86773 .28004 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87081 .24389 m
.87256 .28412 L
s
.255 .412 .882 r
.17727 .29913 m
.17811 .30124 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8662 .24429 m
.86773 .28004 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17817 .24916 m
.17818 .24292 L
s
.17796 .2574 m
.17817 .24916 L
s
.17774 .26252 m
.17796 .2574 L
s
.86803 .29652 m
.8681 .29342 L
s
.86803 .29652 m
.86832 .29856 L
s
.8681 .29342 m
.86838 .29546 L
s
.17806 .2486 m
.17809 .24235 L
s
.17784 .25684 m
.17806 .2486 L
s
.17729 .26966 m
.17774 .26252 L
s
.17805 .23866 m
.17818 .24292 L
s
.17762 .26196 m
.17784 .25684 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86832 .29856 m
.86838 .29546 L
s
.17718 .26911 m
.17762 .26196 L
s
.17809 .24235 m
.17805 .23866 L
s
0 0 0 r
.87295 .28249 m
.87241 .28467 L
s
.255 .412 .882 r
.86746 .24117 m
.86753 .24743 L
s
.86753 .24743 m
.86777 .25568 L
s
.86777 .25568 m
.86799 .26081 L
s
.17686 .27371 m
.17729 .26966 L
s
.17805 .23866 m
.17794 .23751 L
s
.17867 .21903 m
.17871 .21492 L
s
0 0 0 r
.17188 .31051 m
.17268 .28785 L
s
.87065 .21831 m
.87122 .22774 L
s
.255 .412 .882 r
.86761 .24686 m
.86786 .25512 L
s
.17676 .27316 m
.17718 .26911 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87127 .22715 m
.87218 .24971 L
s
.87122 .22774 m
.87218 .24971 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86786 .25512 m
.86808 .26025 L
s
.86746 .24117 m
.86749 .23689 L
s
.86799 .26081 m
.86841 .26797 L
s
.86751 .2406 m
.86761 .24686 L
s
.86808 .26025 m
.86849 .26741 L
s
.86749 .23689 m
.86751 .2406 L
s
0 0 0 r
.17396 .23086 m
.17405 .22544 L
s
.17369 .23876 m
.17396 .23086 L
s
.17193 .27924 m
.17369 .23876 L
s
.255 .412 .882 r
.17794 .23751 m
.17777 .23893 L
s
.1765 .27465 m
.17686 .27371 L
s
0 0 0 r
.17393 .23027 m
.17405 .22544 L
s
.17364 .23818 m
.17393 .23027 L
s
.255 .412 .882 r
.86841 .26797 m
.86878 .27202 L
s
0 0 0 r
.17188 .27869 m
.17364 .23818 L
s
.255 .412 .882 r
.1763 .27136 m
.17863 .21727 L
s
.86749 .23689 m
.86753 .23575 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17172 .30998 m
.17268 .28785 L
s
.5 Mabswid
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17172 .30998 m
.17339 .31373 L
s
.255 .412 .882 r
.1765 .27465 m
.17676 .27316 L
s
.86849 .26741 m
.86884 .27147 L
s
.17631 .27081 m
.17863 .21669 L
s
0 0 0 r
.17405 .22544 m
.17405 .22427 L
s
.255 .412 .882 r
.17752 .24294 m
.17777 .23893 L
s
.86753 .23575 m
.86762 .2366 L
s
0 0 0 r
.17214 .28089 m
.17188 .27869 L
s
.255 .412 .882 r
.17639 .27355 m
.1765 .27465 L
s
0 0 0 r
.17405 .22427 m
.17398 .22617 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86884 .27147 m
.86904 .27296 L
s
.86878 .27202 m
.86904 .27296 L
s
.17644 .26987 m
.17639 .27355 L
s
.86762 .2366 m
.86778 .24061 L
s
.86904 .27296 m
.86909 .27131 L
s
0 0 0 r
.87362 .28289 m
.87464 .30463 L
s
.87459 .30517 m
.87362 .28289 L
s
.255 .412 .882 r
.17644 .26987 m
.17664 .26359 L
s
0 0 0 r
.17398 .22617 m
.17377 .23237 L
s
.87374 .2796 m
.87245 .24997 L
s
.17425 .22132 m
.17461 .21895 L
s
.172 .27316 m
.17425 .22132 L
s
.255 .412 .882 r
.17804 .23177 m
.17811 .23119 L
s
.17638 .26916 m
.1763 .27136 L
s
.86895 .26762 m
.86909 .27131 L
s
0 0 0 r
.17207 .2726 m
.17432 .22073 L
s
.255 .412 .882 r
.86848 .25669 m
.86862 .25984 L
s
.86862 .25984 m
.8687 .26188 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87106 .22068 m
.87445 .29875 L
s
.255 .412 .882 r
.86848 .25669 m
.86856 .25873 L
s
0 0 0 r
.87283 .26138 m
.8731 .26475 L
s
.255 .412 .882 r
.17811 .23119 m
.17817 .23263 L
s
.17808 .2332 m
.17811 .23119 L
s
0 0 0 r
.87406 .2966 m
.87459 .30517 L
s
.87097 .22009 m
.87437 .29821 L
s
.255 .412 .882 r
.86867 .26132 m
.86895 .26762 L
s
.86856 .25873 m
.86867 .26132 L
s
.17795 .2378 m
.17808 .2332 L
s
.17805 .23723 m
.17817 .23263 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17717 .25598 m
.17795 .2378 L
s
0 0 0 r
.17185 .27482 m
.17207 .2726 L
s
.255 .412 .882 r
.86688 .22884 m
.86698 .23344 L
s
.86688 .22884 m
.86732 .23921 L
s
.17805 .23723 m
.17851 .2309 L
s
.1789 .22715 m
.17851 .2309 L
s
.86698 .23344 m
.86732 .23921 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86673 .23027 m
.86698 .23344 L
s
.17705 .26063 m
.17717 .25598 L
s
.86632 .22652 m
.86673 .23027 L
s
.17727 .25542 m
.1775 .25225 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1775 .25225 m
.17851 .24626 L
s
.17705 .26063 m
.17765 .24649 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17705 .26268 m
.17705 .26063 L
s
.86776 .25164 m
.86799 .25481 L
s
.86799 .25481 m
.86822 .26003 L
s
.86787 .25425 m
.86811 .25742 L
s
.86737 .24791 m
.86776 .25164 L
s
0 0 0 r
.17482 .22711 m
.17549 .21851 L
s
.17417 .23884 m
.17482 .22711 L
s
.255 .412 .882 r
.86821 .26208 m
.86822 .26003 L
s
.86748 .25052 m
.86787 .25425 L
s
.17719 .26419 m
.17705 .26268 L
s
0 0 0 r
.17549 .21851 m
.17627 .21303 L
s
.17385 .24629 m
.17417 .23884 L
s
.17499 .22653 m
.17569 .21792 L
s
.17433 .23826 m
.17499 .22653 L
s
.255 .412 .882 r
.86804 .26359 m
.86821 .26208 L
s
0 0 0 r
.17569 .21792 m
.17627 .21303 L
s
.17401 .24571 m
.17433 .23826 L
s
.17352 .25692 m
.17385 .24629 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86636 .24247 m
.86748 .25052 L
s
.86625 .23986 m
.86737 .24791 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17369 .25635 m
.17401 .24571 L
s
.17627 .21303 m
.17673 .21184 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17355 .26328 m
.17352 .25692 L
s
.17673 .21184 m
.17735 .21379 L
s
.255 .412 .882 r
.8657 .2361 m
.86625 .23986 L
s
.86582 .23872 m
.86636 .24247 L
s
0 0 0 r
.17374 .26272 m
.17369 .25635 L
s
.255 .412 .882 r
.86553 .23453 m
.8657 .2361 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.174 .26536 m
.17355 .26328 L
s
.17735 .21379 m
.17761 .22008 L
s
.174 .26536 m
.17374 .26272 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.174 .26536 m
.17472 .26369 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1759 .2475 m
.17634 .24317 L
s
.1759 .2475 m
.17602 .2507 L
s
.17634 .24317 m
.17648 .24636 L
s
.17472 .26369 m
.17541 .2588 L
s
.1801 .20531 m
.18295 .20117 L
s
.17541 .2588 m
.17631 .25013 L
s
.17631 .25013 m
.17648 .24636 L
s
.255 .412 .882 r
.18674 .2119 m
.187 .21153 L
s
0 0 0 r
.17785 .28317 m
.18125 .20354 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17826 .28263 m
.18166 .20294 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18519 .24902 m
.18545 .24868 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18484 .19881 m
.18858 .1947 L
s
.17669 .28478 m
.17826 .28263 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18413 .25035 m
.18637 .19705 L
s
.18466 .24979 m
.18691 .19646 L
s
.18259 .25201 m
.18466 .24979 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19176 .20263 m
.19339 .19385 L
s
.19065 .21467 m
.19176 .20263 L
s
.18263 .27394 m
.18332 .26955 L
s
.18263 .27394 m
.18299 .27726 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18332 .26955 m
.18369 .27287 L
s
.19339 .19385 m
.1956 .1883 L
s
.19033 .22233 m
.19065 .21467 L
s
.19241 .20206 m
.19406 .19327 L
s
.19129 .2141 m
.19241 .20206 L
s
.19406 .19327 m
.1956 .1883 L
s
.18299 .27726 m
.18369 .27287 L
s
.19097 .22177 m
.19129 .2141 L
s
.19033 .22233 m
.19049 .23329 L
s
.1956 .1883 m
.19702 .18714 L
s
.19097 .22177 m
.19114 .23274 L
s
.19702 .18714 m
.19834 .18982 L
s
.19049 .23329 m
.19149 .23989 L
s
.19114 .23274 m
.19216 .23935 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19834 .18982 m
.19955 .19636 L
s
.19149 .23989 m
.19339 .24212 L
s
.20002 .18485 m
.20319 .18257 L
s
.19672 .26617 m
.20002 .18485 L
s
.19216 .23935 m
.19339 .24212 L
s
.19751 .26565 m
.20079 .18428 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19339 .24212 m
.19482 .24104 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19482 .24104 m
.19646 .23608 L
s
.19646 .23608 m
.1983 .22724 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20815 .18303 m
.20919 .17861 L
s
.20815 .18303 m
.20889 .18634 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20919 .17861 m
.20994 .18192 L
s
.19445 .26773 m
.19751 .26565 L
s
.20889 .18634 m
.20994 .18192 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20538 .25314 m
.20813 .20572 L
s
.20719 .25211 m
.20813 .20572 L
s
.20628 .25263 m
.20721 .22911 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20538 .25314 m
.20597 .2605 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20597 .2605 m
.20719 .25211 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23408 .17861 m
.23454 .17839 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7775 .16052 m
.77882 .15702 L
s
.77725 .15258 m
.77882 .15702 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77592 .15608 m
.77725 .15258 L
s
.77592 .15608 m
.7775 .16052 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77814 .18046 m
.78114 .22914 L
s
.77814 .18046 m
.77822 .22827 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27101 .1887 m
.27102 .18832 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76395 .15244 m
.7656 .15688 L
s
.76074 .14757 m
.76395 .15244 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76866 .18666 m
.76963 .18664 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75444 .14582 m
.76074 .14757 L
s
.7656 .15688 m
.76597 .16887 L
s
.76443 .16843 m
.76585 .16487 L
s
.77891 .20451 m
.77969 .2287 L
s
.76456 .17244 m
.76597 .16887 L
s
.76146 .17158 m
.76443 .16843 L
s
.76158 .17559 m
.76456 .17244 L
s
.75135 .14897 m
.75444 .14582 L
s
.77995 .2368 m
.78114 .22914 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76529 .19657 m
.76658 .18894 L
s
.74984 .15255 m
.75135 .14897 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74799 .14412 m
.74984 .15255 L
s
.74799 .14412 m
.74844 .16017 L
s
.77822 .22827 m
.77995 .2368 L
s
.74844 .16017 m
.74984 .15255 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76529 .19657 m
.76707 .20507 L
s
.76386 .20019 m
.76529 .19657 L
s
.75389 .18154 m
.76158 .17559 L
s
.76658 .18894 m
.76707 .20507 L
s
.75377 .17751 m
.76146 .17158 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76085 .2034 m
.76386 .20019 L
s
.73294 .14046 m
.73972 .14206 L
s
.75065 .18072 m
.75377 .17751 L
s
.75077 .18477 m
.75389 .18154 L
s
.75447 .20177 m
.76085 .2034 L
s
.73465 .14086 m
.73616 .1975 L
s
.74913 .18436 m
.75065 .18072 L
s
.73294 .14046 m
.73444 .19713 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74925 .18841 m
.75077 .18477 L
s
.74913 .18436 m
.74936 .19246 L
s
.75111 .19691 m
.75447 .20177 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72961 .14371 m
.73326 .15254 L
s
.72427 .13853 m
.72961 .14371 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74936 .19246 m
.75111 .19691 L
s
.72075 .13778 m
.72427 .13853 L
s
.71729 .14108 m
.72075 .13778 L
s
.71549 .14072 m
.72075 .13778 L
s
.71569 .14881 m
.71729 .14108 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71389 .14845 m
.71549 .14072 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72923 .19603 m
.73616 .1975 L
s
.68757 .13163 m
.70077 .13389 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69327 .13258 m
.6945 .18971 L
s
.69516 .1329 m
.6964 .19002 L
s
.71389 .14845 m
.71497 .19324 L
s
.71569 .14881 m
.71678 .19358 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70948 .19224 m
.71678 .19358 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66615 .12842 m
.67988 .13041 L
s
.67403 .12953 m
.67489 .1745 L
s
.67207 .12925 m
.67292 .17422 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68876 .18882 m
.6964 .19002 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66335 .1658 m
.66381 .16367 L
s
.66378 .16169 m
.66385 .16585 L
s
.66577 .16316 m
.66582 .16606 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64398 .12565 m
.65817 .12736 L
s
.67308 .18246 m
.67489 .1745 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6711 .18219 m
.67292 .17422 L
s
.69495 .21032 m
.69694 .21475 L
s
.69312 .21416 m
.69495 .21032 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69513 .21859 m
.69694 .21475 L
s
.46267 .09202 m
.47782 .09129 L
s
.41987 .12374 m
.43249 .12264 L
s
.62749 .12802 m
.63177 .13661 L
s
.62116 .12334 m
.62749 .12802 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66719 .18579 m
.67308 .18246 L
s
.62116 .12334 m
.6254 .12782 L
s
.61695 .12298 m
.62116 .12334 L
s
.6254 .12782 m
.62969 .13641 L
s
.69312 .21416 m
.69513 .21859 L
s
.66719 .18579 m
.6711 .18219 L
s
.61277 .12672 m
.61695 .12298 L
s
.61066 .12655 m
.61695 .12298 L
s
.63177 .13661 m
.63402 .14913 L
s
.62969 .13641 m
.63194 .14893 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4266 .16092 m
.42808 .16161 L
s
0 0 0 r
.60862 .13459 m
.61277 .12672 L
s
.60649 .13443 m
.61066 .12655 L
s
.63402 .14913 m
.63414 .15736 L
s
.44525 .12168 m
.45814 .12086 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66318 .18529 m
.66719 .18579 L
s
.65009 .12636 m
.65102 .18386 L
s
.65212 .1266 m
.65306 .18409 L
s
.65286 .1717 m
.65706 .18043 L
s
.63194 .14893 m
.63205 .15716 L
s
.65706 .18043 m
.66318 .18529 L
s
.255 .412 .882 r
.61086 .1611 m
.61195 .16094 L
s
0 0 0 r
.57842 .12039 m
.59353 .12124 L
s
.255 .412 .882 r
.43125 .16065 m
.43226 .16127 L
s
0 0 0 r
.63222 .16954 m
.63414 .15736 L
s
.63013 .16934 m
.63205 .15716 L
s
.255 .412 .882 r
.43223 .16416 m
.42808 .16161 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42797 .14762 m
.44716 .14619 L
s
.64486 .18319 m
.65306 .18409 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60449 .14662 m
.60649 .13443 L
s
.60662 .14677 m
.60862 .13459 L
s
.255 .412 .882 r
.60664 .1601 m
.60668 .16367 L
s
.60879 .16383 m
.61086 .1611 L
s
0 0 0 r
.55445 .11947 m
.56973 .12 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43223 .16416 m
.43223 .16417 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46856 .17816 m
.46915 .09168 L
s
.47075 .17806 m
.47131 .09158 L
s
.47545 .12411 m
.47983 .11984 L
s
.4842 .11968 m
.47983 .11984 L
s
.4842 .11968 m
.48855 .12365 L
s
.4842 .11968 m
.49074 .12359 L
s
.47105 .13253 m
.47545 .12411 L
s
.60662 .14677 m
.60671 .15502 L
s
.62815 .17742 m
.63222 .16954 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60449 .14662 m
.60457 .15487 L
s
.62605 .17724 m
.63013 .16934 L
s
.48855 .12365 m
.4929 .13176 L
s
.5303 .11906 m
.5347 .1232 L
s
.5303 .11906 m
.5369 .12323 L
s
.5259 .11904 m
.5303 .11906 L
s
.5215 .12314 m
.5259 .11904 L
s
.5193 .12315 m
.5259 .11904 L
s
.49074 .12359 m
.4951 .1317 L
s
.5369 .12323 m
.54132 .13152 L
s
.5347 .1232 m
.53912 .13149 L
s
.51489 .1314 m
.5193 .12315 L
s
.5171 .13139 m
.5215 .12314 L
s
.60671 .15502 m
.60898 .16759 L
s
.60457 .15487 m
.60684 .16743 L
s
.4929 .13176 m
.49506 .14408 L
s
.62188 .18102 m
.62815 .17742 L
s
.4951 .1317 m
.49725 .14403 L
s
.54132 .13152 m
.54355 .14394 L
s
.62188 .18102 m
.62605 .17724 L
s
.53912 .13149 m
.54135 .1439 L
s
.51268 .1438 m
.51489 .1314 L
s
.51488 .14378 m
.5171 .13139 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60898 .16759 m
.61334 .17619 L
s
.60684 .16743 m
.61121 .17603 L
s
.61764 .18068 m
.62188 .18102 L
s
.61334 .17619 m
.61764 .18068 L
s
.255 .412 .882 r
.56665 .16801 m
.56829 .17025 L
s
0 0 0 r
.49503 .15235 m
.49506 .14408 L
s
.61121 .17603 m
.61764 .18068 L
s
.49723 .1523 m
.49725 .14403 L
s
.54355 .14394 m
.54357 .15221 L
s
.54135 .1439 m
.54137 .15218 L
s
.255 .412 .882 r
.57478 .17341 m
.57488 .17342 L
s
0 0 0 r
.51267 .15207 m
.51268 .1438 L
s
.51487 .15206 m
.51488 .14378 L
s
.255 .412 .882 r
.57368 .17263 m
.57478 .17341 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4943 .1614 m
.49431 .15747 L
s
.49213 .1601 m
.49214 .15747 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56829 .17025 m
.57478 .17341 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42406 .12336 m
.43793 .20908 L
s
.43793 .20908 m
.45383 .12112 L
s
.43806 .19654 m
.45168 .12125 L
s
.49278 .16485 m
.49503 .15235 L
s
.49498 .16479 m
.49723 .1523 L
s
.5414 .16462 m
.54357 .15221 L
s
.53919 .16459 m
.54137 .15218 L
s
.51267 .15207 m
.51486 .1645 L
s
.51487 .15206 m
.51707 .16449 L
s
.47083 .16559 m
.47516 .17372 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48834 .17328 m
.49278 .16485 L
s
.49054 .17322 m
.49498 .16479 L
s
.46202 .17846 m
.47075 .17806 L
s
.53699 .17288 m
.5414 .16462 L
s
.53478 .17286 m
.53919 .16459 L
s
.47516 .17372 m
.47952 .17772 L
s
.51486 .1645 m
.51928 .1728 L
s
.51707 .16449 m
.5215 .1728 L
s
.48392 .17757 m
.48834 .17328 L
s
.48392 .17757 m
.49054 .17322 L
s
.47952 .17772 m
.48392 .17757 L
s
.53036 .17699 m
.53699 .17288 L
s
.53036 .17699 m
.53478 .17286 L
s
.51928 .1728 m
.52593 .17697 L
s
.5215 .1728 m
.52593 .17697 L
s
.52593 .17697 m
.53036 .17699 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58491 .12073 m
.5856 .2078 L
s
.58707 .12085 m
.58778 .20791 L
s
.56319 .11975 m
.56364 .2069 L
s
.56101 .11967 m
.56143 .20683 L
s
.57904 .20749 m
.58778 .20791 L
s
.5548 .20665 m
.56364 .2069 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0>0?nV4@T00000103oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa005P3oXa070:f][J<0/>3V0@3oool00;H0
/>3V1P2][JdI0?nV4@030:f][@3oYQ40ojHA0180ojHA0P0000070?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0
[Jf]WP2`h>H10?ooo`00/@2`h>H50:f][@80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0B0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`
h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@8000001`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400:0?bP40H0[Jf]T`2`h>H10?ooo`00YP2`h>H60:f][@`0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400@
0?bP40D0[Jf]SP2`h>H10?ooo`00X@2`h>H50:f][A80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0B0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@80
00001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]00<0[Jf]QP2`h>H10?ooo`00
V@2`h>H40:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0B0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00<0mY`?
102][Jf20;3PiP40oooo002E0;3PiP@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA0180ojHA0P000007
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][GX0/>3V0@3oool0
08h0/>3V102][Jd<0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0B0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?
00l0mY`?102][Jef0;3PiP40oooo002:0;3PiP@0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ42000000L0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA0180ojHA
0P0000070?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0:f][@020:f][G00/>3V0@3oool008@0/>3V0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@8000001`3o
YQ400`2][Jd0ojH@0?nV400@0?nV40<000002@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@09
0?nV4@@000001@3oYQ42000000<0[Jf]0`00000B0:f][@8000000`2][Jd2000000T0[Jf]2@000003
0:f][@T00000203oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f]
[@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01P0ojHA00<000000?nV4@0000000P0000050?nV4@030:f][@000000000000<000001`2][Jd20000
0080ojHA00@000000?nV4@3oYQ40ojHA0P00000?0?nV408000001@3oYQ02000000H0ojH@00<0[Jf]
0?nU403oYA000P3oYA02000000T0ojD@00<0[Jf]0000000000003P2][Jd3000001L0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][JeX
0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ44000000P0[Jf]103oYQ42000000L0ojHA0P0000000`3o
YQ4000000?nV4@040?nV4@8000003@3oYQ02000000H0ojH@00<000000?nV400000001@3oYQ000`2]
[Jd0ojD@0?nU40020?nU408000002P3oYA02000000`0ojD@0P0000030?nS40030000002][Jd0[Jf]
00H0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF
3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]0P3oYQ400`000000
ojHA0:f][@0:0?nV4@800000203oYQ43000000H0ojHA00<000000?nV400000002`3oYQ000`000000
ojH@000000070?nV408000001@3oYQ000`2][Jd0ojD@0?nU40020?nU408000002P3oYA02000000/0
ojD@0P0000040?nS408000001`3oXa020:f][@P00000103oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3oool007L0/>3V
0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@020?nV4@X0[Jf]303oYQ400`000000ojHA0:f][@0:0?nV4@800000203oYQ43000000H0ojHA
00<0[Jf]0000000000002`3oYQ02000000P0ojH@00<000000?nV40000000103oYQ000`2][Jd0ojD@
0?nU40020?nU408000002P3oYA02000000X0ojD@0P0000000`2][Jd0oj<@0?nS40030?nS40800000
2`3oXa02000000<0oj<@0`2][Jd4000001P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]5`3oYQ400`000000[Jf]0?nV4@090?nV4@800000203o
YQ42000000L0ojHA00@0[Jf]0000003oYQ0000002@3oYQ000`000000ojH@000000090?nV40800000
103oYQ000`2][Jd0ojD@0?nU40020?nU408000002P3oYA02000000X0ojD@0P0000000`2][Jd0oj<@
0?nS40040?nS408000002P3oXa02000000L0oj<@00<0[Jf]0?bP40000000100000020:f][A80o:0@
00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`
h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@D0[Jf]0P3o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030000002][Jd0ojHA00T0ojHA0P0000080?nV4@8000001`3o
YQ401@2][Jd0ojH@0000003oYQ00000000P0ojH@00<000000?nV400000002@3oYQ000`000000ojH@
000000030?nV40030:f][@3oYA00ojD@0080ojD@0P00000:0?nU408000002@3oYA02000000030?nU
402][Jd0oj<@00D0oj<@0P00000:0?nS408000001`3oXa00102][Jd0o:0@0000000000050?bP40D0
00003@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3K
RPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`000000[Jf]0?nV4@090?nV4@800000203oYQ42000000L0ojHA00D0[Jf]0?nV40000000
ojH@000000080?nV408000002P3oYQ000`000000ojH@000000030?nV40030:f][@3oYA00ojD@0080
ojD@0P00000:0?nU408000002@3oYA02000000030?nU402][Jd0oj<@00H0oj<@0P0000090?nS4080
00001`3oXa00102][Jd0o:0@0000000000080?bP40D000000P2][Jd80?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?oo
o`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@03
0:f][@3oYQ40ojHA00D0ojHA1P2][Jd<0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<000000:f][@3o
YQ402@3oYQ42000000L0ojHA0P0000080?nV4@030:f][@3oYQ00ojH@00800000203oYQ02000000/0
ojH@0P0000030?nV40030:f][@3oYA00ojD@0080ojD@0P00000:0?nU408000002@3oYA0200000003
0?nU402][Jd0oj<@00L0oj<@0P0000080?nS408000001`3oXa00102][Jd0o:0@0000000000080?bP
408000001@3lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100kiP@00@0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0
[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030000002][Jd0ojHA00P0ojHA0P0000080?nV4@80
0000203oYQ400`2][Jd0ojH@0?nV4002000000L0ojH@00<000000?nV400000002`3oYQ02000000<0
ojH@00<0[Jf]0?nU403oYA000P3oYA02000000X0ojD@0P0000090?nU4080000000<0ojD@0:f][@3o
Xa001`3oXa02000000P0oj<@0P0000070?nS40040:f][@3lX1000000000000P0o:0@0P00000;0?bP
40@000005@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3P
iP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0
oj@A102][JdG0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<000000:f][@3oYQ40203oYQ42000000P0
ojHA0P0000080?nV4@060:f][@3oYQ00ojH@0000003oYQ0000001P3oYQ000`000000ojH@0000000;
0?nV40030000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA000P3oYA02000000X0ojD@0P000008
0?nU408000000P3oYA000`2][Jd0oj<@0?nS40060?nS40800000203oXa02000000L0oj<@00@0[Jf]
0?bP400000000000203lX102000000T0o:0@0`000000103lX100[Jf]0?JL3`0000020:f][@800000
403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo
001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A102]
[Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0000003oYQ40203o
YQ42000000P0ojHA0P0000080?nV4@040:f][@3oYQ00ojH@0?nV408000001P3oYQ02000000d0ojH@
0P0000020?nV40030:f][@3oYA00ojD@0080ojD@0P00000:0?nU40800000203oYA0200000080ojD@
00<0[Jf]0?nS403oXa001P3oXa02000000P0oj<@0P0000070?nS40040:f][@3lX1000000000000P0
o:0@0P0000090?bP408000000P3lX1000`2][Jd0mY`?000000020?JL3`@0000000<0[Jf]0?JL3`3f
W0l02`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40
oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A
102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd00000
0?nV4@080?nV4@800000203oYQ42000000P0ojHA00@0[Jf]0?nV403oYQ00ojH@0P0000060?nV4080
00003@3oYQ0200000080ojH@00<0[Jf]0?nU403oYA000P3oYA02000000X0ojD@0P0000080?nU4080
00000P3oYA000`2][Jd0oj<@0?nS40070?nS408000001`3oXa02000000L0oj<@00@0[Jf]0?bP4000
00000000203lX102000000P0o:0@0P0000030?bP40050:f][@3fW0l0mY`?0000003fW0l00P000003
0?JL3`80[Jf]00<000000:f][@3fW0l0203fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@000000ojHA00@0ojHA1P0000080?nV
4@800000203oYQ40102][Jd0ojH@0?nV403oYQ02000000H0ojH@0P00000=0?nV408000000P3oYQ00
0`2][Jd0ojD@0?nU40020?nU408000002P3oYA02000000P0ojD@0P0000020?nU40030:f][@3oXa00
oj<@00L0oj<@0P0000070?nS408000001`3oXa00102][Jd0o:0@0000000000080?bP40800000203l
X102000000<0o:0@00D0[Jf]0?JL3`3fW0l000000?JL3`02000000D0mY`?00@000000?JL3`2][Jd0
[Jf]0P0000050?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40
/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
0`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@000000000000@000000`3oYQ42000000T0ojHA0P0000080?nV4@040:f][@3oYQ00ojH@0?nV4080
00001P3oYQ02000000d0ojH@0P0000020?nV40030:f][@3oYA00ojD@0080ojD@0P00000:0?nU4080
0000203oYA0200000080ojD@00<0[Jf]0?nS403oXa001`3oXa02000000L0oj<@0P0000080?nS4003
0:f][@000000000000P0o:0@0P0000080?bP408000000`3lX100102][Jd0mY`?0?JL3`3fW0l30000
00D0mY`?00@000000?JL3`00000000000P3fW0l200000080[Jf]00<0mY`?0:f][@3/UPh04@3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>7
3P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0000003oYQ401`3oYQ420000
00T0ojHA0P0000080?nV4@040:f][@3oYQ00ojH@0?nV408000001P3oYQ02000000d0ojH@0P000002
0?nV40030:f][@3oYA00ojD@0080ojD@0P00000:0?nU40800000203oYA0200000080ojD@00<0[Jf]
0?nS403oXa001`3oXa02000000L0oj<@0P0000080?nS40030:f][@000000000000P0o:0@0P000008
0?bP408000000`3lX100102][Jd0mY`?0?JL3`3fW0l3000000D0mY`?0P0000050?JL3`030000003f
W0l0mY`?00<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V
0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]
5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0000003oYQ40
1`3oYQ42000000T0ojHA0P0000080?nV4@040:f][@3oYQ00ojH@0?nV408000001P3oYQ02000000d0
ojH@0P0000020?nV40030:f][@3oYA00ojD@0080ojD@0P00000:0?nU40800000203oYA0200000080
ojD@00<0[Jf]0?nS403oXa001`3oXa02000000L0oj<@0P0000080?nS40030:f][@000000000000P0
o:0@0P0000080?bP408000000`3lX1000`2][Jd0mY`?0?JL3`020?JL3`8000001@3fW0l2000000H0
mY`?00D000000?JL3`3fW0l0[Jf]0>bF3P020:f][@030000003/UPh0k9H>00`0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>7
3P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA00000007
0?nV4@8000002@3oYQ42000000P0ojHA00@0[Jf]0?nV403oYQ00ojH@0P0000060?nV408000003@3o
YQ0200000080ojH@00<0[Jf]0?nU403oYA000P3oYA02000000X0ojD@0P0000080?nU408000000P3o
YA000`2][Jd0oj<@0?nS40070?nS408000001`3oXa02000000P0oj<@00<0[Jf]000000000000203l
X102000000P0o:0@0P0000030?bP40030:f][@3fW0l0mY`?0080mY`?0P0000060?JL3`030000003f
W0l0mY`?00@0mY`?00@000000?JL3`3fW0l0[Jf]0P3/UPh200000080[Jf]303/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3C
Q`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3l
X1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA000000070?nV4@8000002@3oYQ42000000030?nV4@2][Jd0[Jf]00P0[Jf]00<0
00000:f][@0000001P2][Jd2000000d0[Jf]0P0000070:f][@80000000<0[Jf]0?nU403oYA001`3o
YA02000000P0ojD@0P0000020?nU40030:f][@3oXa00oj<@00L0oj<@0P0000070?nS40800000203o
Xa000`2][Jd00000000000080?bP40800000203lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l00P3f
W0l2000000H0mY`?00<000000?JL3`3fW0l01@3fW0l00`000000mY`?0:f][@020>bF3P040000003/
UPh000000>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;
00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@0000001@3o
YQ40102][Jd000000:f][@0000090:f][@80000000<0[Jf]0?nV4@3oYQ401@3oYQ400`2][Jd0ojH@
0?nV4002000000L0ojH@0P00000<0?nV408000000`3oYQ000`2][Jd0ojD@0?nU40020?nU40800000
00<0ojD@0:f][@2][Jd01`2][Jd2000000D0[Jf]0`3oYA0200000080ojD@00<0[Jf]0?nS403oXa00
1`3oXa02000000L0oj<@0P0000080?nS40030:f][@000000000000P0o:0@0P0000080?bP40800000
0`3lX1000`2][Jd0mY`?0?JL3`020?JL3`8000001P3fW0l00`000000mY`?0?JL3`050?JL3`030000
003fW0l0[Jf]0080k9H>0P0000050>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>7
3P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@P0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01D0ojHA1P2]
[Jd00`000000[Jf]0:f][@030:f][@030?nV4@000000000000X0ojHA0P0000080?nV4@030:f][@3o
YQ00@FWQ00800000203oYQ02000000/0ojH@0P0000030?nV40030:f][@3oYA00ojD@0080ojD@0P00
000:0?nU408000001@3oYA030:f][@8000001`2][Jd50?nS408000001`3oXa02000000P0oj<@00<0
[Jf]000000000000203lX102000000P0o:0@0P0000030?bP40030:f][@3fW0l0mY`?0080mY`?0P00
00060?JL3`030000003fW0l0mY`?00D0mY`?00<000000?JL3`2][Jd00`3/UPh00`000000k9H>0>bF
3P060>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0
[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100
kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ400`2][Jd0ojHA0000
00060?nV4@8000002P3oYQ42000000P0ojHA00D0[Jf]0?nV40000000ojH@000000080?nV40800000
2`3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA000P3oYA02000000X0ojD@0P0000090?nU40800000
00<0ojD@0:f][@3oXa000`3oXa040:f][@800000102][Jd40?nS408000001P3oXa000`11JN40oj<@
0:f][@02000000T0o:0@0P0000070?bP408000000`3lX1000`2][Jd0mY`?0?JL3`020?JL3`800000
3P3fW0l00`000000mY`?0:f][@0>0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd=0?nV4@030:f]
[@3oYQ40000000H0ojHA0P00000:0?nV4@800000203oYQ401@2][Jd0ojH@0000003oYQ00000000P0
ojH@0P00000;0?nV408000000`3oYQ000`2][Jd0ojD@0?nU40030?nU408000002P3oYA000`000000
ojD@0?nU40070?nU4080000000<0ojD@0:f][@3oXa001`3oXa02000000@0oj<@102][Jd2000000@0
[Jf]103oXa000`2][Jd00000000000090?bP408000001`3lX102000000<0o:0@00<0[Jf]0?JL3`3f
W0l00P3fW0l2000000h0mY`?00<000000?JL3`2][Jd04@3/UPh20:f][@d0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@
0P2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405P3oYQ470:f][AL0ojHA
00@0[Jf]0?nV4@3oYQ4000001@3oYQ42000000X0ojHA0`0000070?nV4@040:f][@000000ojH@0000
00X0ojH@0P0000090?nV40800000103oYQ000`2][Jd0ojD@0?nU40030?nU408000002P3oYA020000
00P0ojD@0P0000000`3oYA00[Jf]0?nS40070?nS40800000203oXa02000000@0oj<@1@2][Jd20000
00030:f][@3lX100o:0@00H0o:0@0P0000070?bP408000000`3lX1000`2][Jd0mY`?0?JL3`020?JL
3`8000003P3fW0l00`000000mY`?0:f][@0B0>bF3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A40
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@H0[Jf]0P3oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@040:f][@3oYQ40ojHA000000D0ojHA0P00000:0?nV4@<000001`3oYQ400`2]
[Jd000000000000;0?nV40800000203oYQ02000000D0ojH@00<0[Jf]0?nU403oYA000`3oYA020000
00X0ojD@0P0000080?nU4080000000<0ojD@0:f][@3oXa001`3oXa02000000P0oj<@0P0000080?nS
40040:f][@00000000000?bP40H0[Jf]0P3lX102000000L0o:0@0P0000030?bP40030:f][@3fW0l0
mY`?0080mY`?0P00000>0?JL3`030000003fW0l0[Jf]0180k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd9
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2]
[Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@040:f][@3oYQ40ojHA000000@0ojHA0P00000;0?nV4@80000000<0ojHA
0000003oYQ401@3oYQ400`000000ojH@0000000<0?nV408000001`3oYQ02000000D0ojH@00<0[Jf]
0?nU403oYA000`3oYA02000000X0ojD@0P0000090?nU4080000000<0[Jf]0?nS403oXa001@3oXa02
000000T0oj<@0P0000080?nS40030:f][@000000000000L0o:0@0P2][Jd2000000<0[Jf]103lX102
000000<0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000/0mY`?0`0000000`3fW0l0[Jf]0>bF3P0A
0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]
08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100
kiP@00D0kiP@0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@060?nV4@D0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@040:f][@3oYQ40
ojHA000000@0ojHA0P00000;0?nV4@80000000<0ojHA0000003oYQ401@3oYQ42000000h0ojH@0P00
00050?nV408000001P3oYQ000`2][Jd0ojD@0?nU40030?nU40800000103oYA000`11JN40ojD@0?nU
40030?nU408000002@3oYA02000000030:f][@3oXa00oj<@00D0oj<@0P0000090?nS40800000203o
Xa000`2][Jd00000000000090?bP408000000`3lX1050:f][@8000000P3lX1000`2][Jd0mY`?0?JL
3`030?JL3`8000002P3fW0l01P000000mY`?0?JL3`000000mY`?0:f][A80k9H>00<0[Jf]0=^:3@3K
RPd0103KRPd00`2][Jd0fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28
EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@
00@0kiP@00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ401P2][JdB0?nV4@030:f][@3oYQ40ojHA01T0ojHA00@0[Jf]0?nV
4@3oYQ400000103oYQ42000000/0ojHA0P0000020?nV4@030000003oYQ40ojHA0080ojHA0P00000@
0?nV408000000`3oYQ02000000L0ojH@00<0[Jf]0?nU403oYA000`3oYA02000000X0ojD@0P00000:
0?nU408000001P3oXa02000000X0oj<@0P0000080?nS40030:f][@000000000000T0o:0@0P000008
0?bP40800000102][Jd40?JL3`800000203fW0l2000000030?JL3`00000000000080mY`?00<0[Jf]
0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]103KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@040:f][@3o
YQ40ojHA000000@0ojHA0P00000;0?nV4@8000000`3oYQ401P000000ojHA0?nV4@000000ojHA0:f]
[A80ojH@0`0000090?nV40030:f][@3oYA00ojD@00<0ojD@0P00000:0?nU408000002P3oYA020000
00H0oj<@0P00000:0?nS40<000001`3oXa000`2][Jd00000000000090?bP40800000203lX1020000
0080o:0@00<0[Jf]0?JL3`2][Jd00`2][Jd2000000L0mY`?00@000000?JL3`3fW0l00000103fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd20=^:3@030:f][@2iM@/0
^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd0203CQ`h00`2][Jd000000>nH40020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0>0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ406@3oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@050:f][@3oYQ40ojHA0?nV4@0000000`3oYQ42000000P0ojHA1@0000040?nV4@800000
0P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00<0ojD@0P00000:0?nU40800000
2`3oYA03000000<0oj<@0P00000;0?nS40<000001`3oXa02000000X0o:0@0P0000080?bP40800000
0P3lX1000`2][Jd0mY`?0?JL3`030?JL3`8000000P2][Jd40?JL3`040000003fW0l00000000000D0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@090=^:3@<0[Jf]2@2iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/0
0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@000000[Jf]00/0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01T0ojHA00D0[Jf]0?nV4@3oYQ40ojHA000000020?nV4@030000003oYQ40000001D0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40030?nU408000002P3oYA02000000/0
ojD@00<0[Jf]0?nS400000000`00000=0?nS4080000000<0oj<@0000003oXa001@3oXa02000000X0
o:0@0P0000080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`030?JL3`8000000P3fW0l40:f][@80
00001`3fW0l01@2][Jd0k9H>0>bF3P3/UPh0000000h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00L0dhL>00<000000=>73P2][Jd00P00000;0>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@050:f][@3oYQ40ojHA0?nV4@0000000P3oYQ42
000001H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40030?nU408000002P3oYA02
000000/0ojD@00<0[Jf]0?nS403oXa003@3oXa02000000030?nS4000000000000080oj<@0P000004
0?nS408000002P3lX102000000P0o:0@0P0000020?bP40030:f][@3fW0l0mY`?00<0mY`?0P000005
0?JL3`8000000`2][Jd50?JL3`050:f][@3/UPh0k9H>0>bF3P0000003P3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3o
ool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P050000003CQ`h0[Jf]0:f][@000000
2`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd<0?nT4@030:f]
[@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ401@2][Jd0ojHA0?nV4@3oYQ4000000080
ojHA0P00000F0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA000`3oYA02000000X0
ojD@0P00000;0?nU40030:f][@3oXa00oj<@00l0oj<@0`0000040?nS40030000003oXa00oj<@0080
00002`3lX102000000P0o:0@0P0000020?bP40030:f][@3fW0l0mY`?00<0mY`?0P0000050?JL3`80
00000`3fW0l40:f][@030?JL3`2][Jd0k9H>0080k9H>00<000000>bF3P3/UPh0303/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2]
[Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01`00
0000dhL>0000002][Jd0dhL>0:f][@0000002`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3o
Y140[Jf]00<0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00D0
[Jf]0?nV4@3oYQ40ojHA000000020?nV4@8000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@00<0ojD@0P00000:0?nU408000002`3oYA000`2][Jd0oj<@0?nS400G0?nS40800000
00<0oj<@0:f][@3lX1002P3lX102000000P0o:0@0P0000020?bP40030:f][@3fW0l0mY`?00<0mY`?
0P0000050?JL3`030000003fW0l0mY`?00H0mY`?0`2][Jd20>bF3P030000003/UPh0k9H>00`0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28
EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00`3CQ`h2000000050:f][@000000dhL>0=>73P2][Jd0303_V1000`2][Jd0o:0@0?bP400?0?bP
40<0[Jf]503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00D0[Jf]0?nV
4@3oYQ40ojHA000000020?nV4@8000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@00<0ojD@0P00000:0?nU408000002`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@00H0o:0@0P0000000`3lX1000000000000080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`03
0?JL3`8000001@3fW0l00`000000mY`?0?JL3`060?JL3`030000002][Jd0k9H>0080[Jf]00<00000
0>bF3P3/UPh0303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]
0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00@000000:f][@00000000000P3CQ`h00`2][Jd0kiP@0>nH
400:0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@040000003o
YQ400000000001H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40030?nU40800000
2P3oYA02000000/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40080?bP40<00000
203lX10200000080o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000D0mY`?00<000000?JL3`3fW0l0
1P3fW0l00`000000[Jf]0>bF3P020>bF3P030000002][Jd0[Jf]00`0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P80000000<0dhL>00000000
00000P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd40?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA0080ojHA0`00000G0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA000`3oYA02000000X0ojD@0P00000;0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100403lX10500000080o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000D0mY`?00<000000?JL3`3f
W0l01@3fW0l2000000050:f][@3/UPh0k9H>0>bF3P0000000P3/UPh30:f][@T0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f]
[D80/>3V0@3oool005T0/>3V00L0[Jf]09MP2`2GH0/0Uf0;0:f][@000000[Jf]0080000000<0dhL>
0000000000000P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd6
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA0080ojHA0`00000@0?nV4B`0[Jf]0P00000:0?nU408000002`3oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l2
000000D0mY`?00<000000?JL3`3fW0l01@3fW0l2000000040:f][@3/UPh0k9H>0>bF3P800000103/
UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028
EPL20:f][D80/>3V0@3oool005T0/>3V00L0[Jf]09MP2`2GH0/0Uf0;0000002][Jd0dhL>00800000
00<0dhL>0000000000000P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00@0o:0@
0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA0080ojHA0`00000@0:f][@L0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU40030?nU408000002P2][Jd2000000@0[Jf]1`3oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`000000100000060?JL3`030000
003fW0l0mY`?00@0mY`?0P000000102][Jd0k9H>0>bF3P3/UPh2000000L0k9H>0P2][Jd40>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`03
0:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P0000020=>73P050000
003CQ`h0dhL>0=>73P0000000P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@0080
o:0@0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0F0?nV4@T0[Jf]00<000000:f][@0000005`3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@00<0ojD@0P00000:0?nU40800000103oYA0<0:f][AP0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0;0?JL3`030000003fW0l0mY`?0080mY`?0`000000102][Jd0
k9H>0>bF3P3/UPh2000000T0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/0^GD;
00H0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`00
0000[Jf]000000020=>73P070000003CQ`h0dhL>0=>73P000000dhL>0:f][@0=0>nH40030:f][@3l
X100[Jf]0080[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0000
000G0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA000`3oYA02000000X0ojD@0P00
000;0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0303fW0l200000080mY`?0`000000102][Jd0k9H>0>bF3P3/UPh2000000`0k9H>
0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V
0@3oool005T0/>3V00D0[Jf]000000000000[Jf]000000020=>73P070000003CQ`h0dhL>0=>73P00
0000dhL>0:f][@0=0>nH4080[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ420000
01L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40030?nU408000002P3oYA020000
00/0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`0>0?JL3`8000000P3fW0l00`000000[Jf]0>bF3P020>bF3P8000003@3/UPh0102]
[Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00`28EPL0
0`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@000000000009MP2`0000000P3CQ`h0
0`000000dhL>0=>73P02000000040=>73P2][Jd0kiP@000000T0kiP@0`2][JdB0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ480:f][AP0ojHA00<0[Jf]0?nV4@3oYQ400`3o
YQ400`000000ojHA0?nV4@0F0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA000`3o
YA02000000X0ojD@0P00000;0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdG0?bP40030:f][@3f
W0l0mY`?0180mY`?00<000000:f][@3/UPh00P3/UPh2000000d0k9H>00@0[Jf]0=^:3@3KRPd0fhX=
0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2][Jd0
/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@000000000009MP2`0000000P3CQ`h010000000
dhL>0=>73P0000020=>73P030:f][@3_V100000000L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ405P3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00000000D000001P3oYA03000000030?nU400000000000
00/0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P02000000d0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2
0:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0R5H708QF1`28EPL0[Jf]08QF1`2][Jd0
@P2`h>H10?ooo`00F@2`h>H01`2][Jd000000000002GH0/000000=>73P0000000`3CQ`h01P000000
dhL>0=>73P2][Jd0kiP@000000D0kiP@0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ405P3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@00h0ojD@0`00000;0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P02
000000d0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0
1`2][Jd0R5H708QF1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H01`2][Jd000000000
002GH0/000000=>73P0000000`3CQ`h01P000000dhL>0=>73P2][Jd0kiP@000000<0kiP@0P2][Jd6
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3o
YQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@00T0o:0@00<000000?bP403lX1000P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P02000000d0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00<0
[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F02`h>H0
20000000[Jf]000000000000Uf0;0000003CQ`h000000`3CQ`h01`000000dhL>0=>73P2][Jd0kiP@
0000003_V1000P2][Jd80>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY145
0:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@00P0o:0@0P00000;0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P02000000d0k9H>00<0[Jf]
0=^:3@3KRPd02@3KRPd20:f][@030=^:3@2][Jd0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00`28EPL0
0`2][Jd0/>3V0;3PiP100;3PiP40oooo001H0;3PiP080000002][Jd000000000002GH0/000000=>7
3P0000030=>73P070000003CQ`h0dhL>0:f][@3_V10000000:f][@0:0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00P0o:0@00<000000?bP
400000003@3lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0[Jf]0>bF3P3/UPh00P00000=0>bF
3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3P
iP40oooo001G0;3PiP80000000L0[Jf]000000000000Uf0;0000003CQ`h0000000<0dhL>00@00000
0=>73P3CQ`h0[Jf]0P00000;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3o
Y1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100203lX102000000h0o:0@00<0[Jf]0?JL3`3fW0l0103f
W0l50:f][@/0mY`?00<0[Jf]0>bF3P3/UPh00P00000=0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2]
[Jd80;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiPD0000000@0Uf0;
0000003CQ`h000000`3CQ`h010000000dhL>0:f][@2][Jd2000000/0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40090?bP40030000
003lX100o:0@00`0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]0>bF3P3/UPh0
0`00000<0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@000000/>3V0400/>3V0@3oool005L0/>3V1@000000102GH0/00000
0=>73P0000030=>73P040000002][Jd0dhL>0:f][@8000002`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l03P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh00`00000=0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]
000000000000@02`h>H10?ooo`00E`2`h>H01@000000[Jf]0:f][@000000Uf0;0080000000<0dhL>
0000003CQ`h00P3CQ`h010000000dhL>0=>73P2][Jd2000000/0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0B0?JL3`@0[Jf]00@0k9H>00000000000000003@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@00000000000400/>3V0@3oool005L0/>3V00X000000:f][@2][Jd0000009MP2`000000[Jf]0=>7
3P000000dhL>0P2][Jd010000000dhL>0=>73P2][Jd2000000/0kiP@00<0[Jf]0?bP403lX1003P3l
X1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0[Jf]00<000003@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0
[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`
h>H02P000000[Jf]0:f][@000000Uf0;0000002][Jd0dhL>0000002][Jd20=>73P040000003CQ`h0
dhL>0:f][@8000002`3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00`00
00000`2][Jd0k9H>0>bF3P0:0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102i
M@/20:f][@030;Ue2`2][Jd0R5H700<0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001G
0;3PiP090000002][Jd0[Jf]0000002GH0/000000:f][@3CQ`h0000000<0dhL>00D000000=>73P3C
Q`h0[Jf]0000000<0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00<0000000@0k9H>0:f][@2][Jd0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00H0^GD;0P2][Jd408QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H01P00
0000[Jf]0:f][@000000Uf0;00000080[Jf]00D000000=>73P3CQ`h0dhL>000000020=>73P030:f]
[@000000kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140
503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00H0[Jf]0>bF3P3/UPh0
00000>bF3P0000040>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005L0
/>3V00T000000:f][@2GH0/0000009MP2`000000[Jf]0=>73P0000000P3CQ`h200000080dhL>00<0
[Jf]0000003_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P02000000P0k9H>0P2][Jd40>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H70P2][Jd00`000000/>3V0;3P
iP0n0;3PiP40oooo001G0;3PiP090000002][Jd0Uf0;0000002GH0/000000:f][@3CQ`h000000080
dhL>0P000000103CQ`h0[Jf]0>nH4000000<0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00D0[Jf]0>bF3P3/UPh0k9H>0000
000:0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]0P28
EPL01011JN40[Jf]0:f][@0000100;3PiP40oooo001G0;3PiP080000002][Jd0Uf0;0000002GH0/0
00000:f][@3CQ`h2000000070=>73P00000000000=>73P2][Jd0kiP@0000000<0>nH40040:f][@3l
X100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00D0[Jf]0>bF3P3/UPh0k9H>0000000=0>bF3P<0[Jf]3@3KRPd00`2][Jd0
^GD;0;Ue2`060;Ue2`050:f][@28EPL0[Jf]08QF1`11JN400P2][Jd00`000000/>3V0;3PiP0n0;3P
iP40oooo001G0;3PiP080000002][Jd0Uf0;0000002][Jd000000:f][@3CQ`h3000000060=>73P00
0000dhL>0:f][@3_V10000002`3_V1030:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0
fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P28EPL20:f]
[@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V00P000000:f][@2GH0/0000009MP2`000000
[Jf]0=>73P<0000000@0dhL>0000003CQ`h0[Jf]0P0000090>nH4080[Jf]00<0kiP@0:f][@3lX100
403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ4:0:f][H40/>3V2P2][JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0
R5H708QF1`2][Jd0R5H70080[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H400000003
09MP2`000000[Jf]0080dhL>00H000000=>73P3CQ`h000000=>73P2][Jd2000000L0kiP@0P2][Jd3
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E
0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]
08QF1`28EPL0R5H70`2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001G0;3PiP@0000000<0Uf0;
0000002][Jd0103CQ`h2000000040=>73P2][Jd00000000000D0kiP@0P2][Jd50>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`
h>H50:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00P0[Jf]08QF1`28EPL0R5H7
0:f][@11JN40[Jf]00000400/>3V0@3oool005H0/>3V1@0000000`2GH0/000000:f][@040=>73P04
0000003CQ`h0dhL>0:f][@8000000`3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2]
[Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f]
[@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3P
iP2`h>H0?P2`h>H10?ooo`00EP2`h>H50000000309MP2`000000[Jf]00@0dhL>00@000000=>73P3C
Q`h0[Jf]0P0000000`3_V100[Jf]0:f][@090>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0
mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=
0:f][@2iM@/0202iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3o
ool005H0/>3V1`0000050=>73P040000003CQ`h0dhL>0:f][@80000000<0[Jf]0>nH403_V1002@3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H6000000030:f][@3C
Q`h0dhL>00<0dhL>00@000000=>73P3CQ`h0[Jf]0P00000<0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000
/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP80000000D0[Jf]000000000000Uf0;0:f][@050=>73P04
0000003CQ`h0[Jf]0:f][@800000303_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`
h>H0/>3V03h0/>3V0@3oool005H0/>3V0P0000001@2][Jd000000000002GH0/0[Jf]00D0dhL>00@0
00000:f][@3CQ`h0[Jf]0P00000;0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140
103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`00
0000/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP80000000D0[Jf]000000000000Uf0;0:f][@040=>7
3P070:f][@000000dhL>0=>73P2][Jd0kiP@0000000;0>nH40030:f][@3lX100o:0@0100o:0@00<0
[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP80000000D0[Jf]000000000000Uf0;
0:f][@030=>73P030:f][@3CQ`h000000080dhL>00<0[Jf]0>nH400000002`3_V1000`2][Jd0o:0@
0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`040;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H700@0[Jf]045Yh@0000000000?`2`h>H10?oo
o`00EP2`h>H2000000060:f][@000000Uf0;09MP2`2][Jd0dhL>0P2][Jd20=>73P040000003CQ`h0
dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0R5H700@0[Jf]045Yh@0000000000
?`2`h>H10?ooo`00EP2`h>H2000000040:f][@000000Uf0;09MP2`80[Jf]103CQ`h010000000dhL>
0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@04
0<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0R5H70080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H010000000
[Jf]09MP2`00000209MP2`030:f][@3CQ`h0dhL>0080dhL>0P0000020=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f]
[@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2]
[Jd000000000000o0;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;0000002GH0/000000:f][@08
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0
^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3P
iP070000002][Jd0Uf0;0000002GH0/000000:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102]
[Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H700<0[Jf]000000000000?`2`
h>H10?ooo`00EP2`h>H01@000000[Jf]09MP2`000000[Jf]00800000203CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n
]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H700<0
[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`000000Uf0;0000002][Jd0
203CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0
[Jf]08QF1`2][Jd2000003l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0000009MP2`000000
[Jf]00P0dhL>00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001F0;3PiP040000002][Jd0[Jf]00000080Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V00@000000:f][@2][Jd00000
0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]
0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0
[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`03
0:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP030:f]
[@2GH0/000000080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@05
0:BNS`11JN40Y9j?0:BNS`2][Jd0102aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0
_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji
^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`02
08QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0000009MP2`2GH0/0
[Jf]00T0dhL>00D0[Jf]0>nH402][Jd0[Jf]045Yh@020:BNS`04045Yh@2TWXl0Y9j?0:f][@H0/J^M
0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a0;B`/@2d/;420:f]
[@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m
0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f]
[@80Y9j?00<0@FWQ0:BNS`2TWXl00P11JN400`2TWXl0[Jf]0;6[W@070;6[W@80[Jf]0`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f]
[Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102]
[Jd0_[Vh0:f][@2][Jd80;ji^080@FWQ00<0[Jf]0;B`/@2d/;400P2d/;400`11JN40[Jf]0:f][@0:
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`h>H0
0`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0:BNS`2TWXl00P2TWXl0
0`11JN40Y9j?0:BNS`030:BNS`030:f][@2aZid0/J^M00P0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd2
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<
0<>m^`<0[Jf]2@2n^KP2045Yh@030;ji^02][Jd0];2a00<0];2a00<0@FWQ0;B`/@2d/;400P2][Jd8
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`h>H0
0`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd50:BNS`03045Yh@2TWXl0
Y9j?00<0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2]
[Jd00`33_K/0[Jf]0;ji^0050;ji^080@FWQ0`2n^KP00`11JN40_[Vh0:f][@040;B`/@06045Yh@2d
/;40];2a0;B`/@11JN40[Jf]1`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V
03d0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P030=>73P03
0:f][@11JN40[Jf]00@0Y9j?00<0@FWQ0:BNS`2TWXl00`2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@03
0:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0
_[Vh0;ji^0020;ji^004045Yh@2n^KP0@FWQ045Yh@<0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0`2d/;40
1011JN40];2a0;B`/@2d/;42045Yh@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000
002`h>H0/>3V03d0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>7
3P020=>73P040:f][@2:QGD0@FWQ0:f][@80Y9j?0`11JN450:BNS`030:f][@2aZid0/J^M00`0/J^M
00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk
00H0[Jf]0;ji^02n^KP0_[Vh045Yh@2n^KP3045Yh@<0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]102d/;40
0`11JN40];2a0;B`/@02045Yh@040:f][@11JN40[Jf]0:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00P0
[Jf]0=>73P3CQ`h0dhL>0:f][@11JN40RXEe045Yh@80[Jf]0`11JN460:BNS`030:f][@2aZid0/J^M
00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f]
[E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/0102][Jd0_[Vh0;ji^011JN42
0;ji^0<0@FWQ0`2n^KP01011JN40_[Vh0;ji^02][Jd50;B`/@@0@FWQ00D0];2a045Yh@11JN40@FWQ
0:f][@020;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00
EP2`h>H00`000000[Jf]09MP2`0209MP2`040:f][@3CQ`h0[Jf]0:f][@80@FWQ00H0RXEe045Yh@2]
[Jd0Y9j?045Yh@2][Jd70:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH4
0:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@h0`kfk00@0[Jf]
0;ji^011JN40@FWQ0`2n^KP2045Yh@<0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]1@2d/;420:f][@80@FWQ
00D0];2a045Yh@11JN40@FWQ09nKX0030:f][@@0R5H700<0[Jf]0000002`h>H0?P2`h>H10?ooo`00
EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]0`2:QGD01`11JN40RXEe045Yh@2][Jd0Y9j?045Y
h@2TWXl00P2][Jd30:BNS`03045Yh@2TWXl0[Jf]00h0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f]
[A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f]
[@030<K0_02][Jd0`kfk00P0`kfk00<0@FWQ0<>m^`33_K/00`33_K/00`2][Jd0@FWQ045Yh@040;ji
^080@FWQ0`2n^KP01011JN40_[Vh0;ji^02][Jd30;B`/@80[Jf]0P2d/;400`11JN40];2a0;B`/@03
045Yh@<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001F0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD01@11JN40RXEe0:f][@2TWXl0
@FWQ00<0Y9j?00H0@FWQ0:f][@2TWXl0@FWQ0:BNS`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jd50<K0_0030:f]
[@33_K/0`kfk00L0`kfk00<0@FWQ0<>m^`33_K/00`33_K/00`2][Jd0@FWQ045Yh@050;ji^005045Y
h@2n^KP0_[Vh0;ji^011JN400P2n^KP0102][Jd0];2a0;B`/@2][Jd40;B`/@03045Yh@2d/;40];2a
0080@FWQ102OVj000`11JN40[Jf]08QF1`0208QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0
/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd708Z5M@030:f][@2TWXl0@FWQ00<0Y9j?00H0@FWQ0:BN
S`2][Jd0@FWQ0:BNS`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n
]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/00`33
_K/01@11JN40`kfk0<>m^`33_K/0@FWQ00H0`kfk0P11JN450;ji^004045Yh@2n^KP0_[Vh0;ji^080
@FWQ00@0_[Vh0:f][@2][Jd0[Jf]0P2d/;401@11JN40];2a0;B`/@11JN40];2a0080@FWQ1@2OVj00
0`11JN40[Jf]08QF1`0208QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00@0[Jf]09MP
2`2GH0/0Uf0;0P2][Jd00`11JN40RXEe08Z5M@0408Z5M@030:f][@2TWXl0@FWQ0080Y9j?0P11JN42
0:BNS`03045Yh@2][Jd0[Jf]00h0/J^M00<0[Jf]0;VbYP2i/ZH0202i/ZH3045Yh@<0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@33_K/0
`kfk00<0`kfk00@0@FWQ0<>m^`33_K/0`kfk0P11JN450<>m^`03045Yh@2n^KP0_[Vh00@0_[Vh00@0
@FWQ0;ji^02n^KP0_[Vh0P11JN420:f][@@0];2a00<0@FWQ0;B`/@11JN400`2d/;400`2][Jd0Wi^P
09nKX00309nKX003045Yh@2OVj00[Jf]0080R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`
h>H00`2][Jd0Uf0;09MP2`030:f][@80@FWQ1@2:QGD01P2][Jd0Y9j?0:BNS`11JN40Y9j?045Yh@<0
Y9j?00@0@FWQ0:BNS`2][Jd0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP@0@FWQ00<0[Jf]0;jg
[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00?0<O1_0@0[Jf]4@36`;`00`11JN40`kfk0<>m^`030<>m^`04045Yh@33_K/0`kfk
0<>m^`80@FWQ1@33_K/00`11JN40_[Vh0;ji^0040;ji^080@FWQ0P2n^KP2045Yh@030;ji^02][Jd0
@FWQ00<0];2a00<0@FWQ0;B`/@11JN400`2d/;400`2][Jd0Wi^P09nKX00309nKX006045Yh@2OVj00
[Jf]0:f][@28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@03045Y
h@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl2045Yh@<0Y9j?00@0@FWQ0:BNS`2][Jd0
/J^M0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00X0^K:V0P11JN420;VbYP80@FWQ402n]j`40:f][A40
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0
a/2l0<K0_00;0<K0_003045Yh@36`;`0a/2l0080@FWQ00<0[Jf]0<>m^`33_K/00`33_K/00`11JN40
`kfk0<>m^`03045Yh@D0`kfk00<0@FWQ0;ji^02n^KP00P2n^KP3045Yh@030;ji^02][Jd0[Jf]0080
@FWQ00@0_[Vh0:f][@11JN40@FWQ0`2d/;400`11JN40];2a0;B`/@020;B`/@030:f][@2OVj00Wi^P
00<0Wi^P00@0@FWQ09nKX02][Jd0L6ii0P2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<00`2]
[Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00<0Y9j?00L0@FWQ0:BNS`2TWXl0Y9j?045Yh@2T
WXl0[Jf]00<0/J^M0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00X0^K:V0P11JN420;VbYP030:f][@2n
]j`0@FWQ00D0_[N/00<0@FWQ0;jg[02n]j`0202n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0
_0090<K0_080@FWQ00<0a/2l045Yh@36`;`00P11JN400`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33
_K/0`kfk00<0@FWQ1033_K/2045Yh@D0_[Vh0`2][Jd20;ji^080@FWQ00@0_[Vh0:f][@11JN40@FWQ
202d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00<0L6ii0:f][@2][Jd0@02`h>H10?ooo`00EP2`
h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0P11JN400`2TWXl0[Jf]0;6[
W@050;6[W@80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP80@FWQ0P2i/ZH0102][Jd0_[N/045Y
h@11JN450;jg[080@FWQ202n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0_0070<K0_080@FWQ
1036`;`2045Yh@030<K0_02][Jd0`kfk00<0`kfk0`11JN401033_K/0@FWQ045Yh@11JN440<>m^`80
@FWQ0`2n^KP20:f][@D0_[Vh0P11JN400`2n^KP0[Jf]045Yh@090;B`/@030:f][@2OVj00Wi^P00<0
Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<0
0P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0P11JN400`2TWXl0[Jf]
0;6[W@070;6[W@<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP80@FWQ00<0^K:V0:f][@2n]j`0
0P2n]j`00`11JN40_[N/0;jg[0040;jg[0<0@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]
0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4037`K`3045Yh@P0a/2l0P11JN450<K0_003045Y
h@36`;`0[Jf]00@0`kfk0`11JN401033_K/0@FWQ045Yh@11JN440<>m^`80@FWQ00<0_[Vh0:f][@2]
[Jd01`2n^KP5045Yh@T0];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^
N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe0:f]
[@<0RXEe00<0[Jf]0:BNS`2TWXl01P2TWXl2045Yh@030:BNS`2][Jd0/J^M00X0/J^M0P2][Jd00`2a
Zid0[Jf]0;VbYP0;0;VbYP80@FWQ00<0^K:V0:f][@2n]j`00P2n]j`2045Yh@D0_[N/00<0@FWQ0;jg
[02n]j`01P2n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0P0[Jf]4033_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1
_037`K`03@37`K`4045Yh@030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_036`;`01036`;`00`11
JN40a/2l0:f][@040<>m^`<0@FWQ00D0`kfk045Yh@11JN40`kfk045Yh@030<>m^`80@FWQ00<0[Jf]
0;ji^02n^KP01`2n^KP2045Yh@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Jd3
09nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=P
D`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD00`2][Jd0Y9j?0:BNS`060:BNS`80@FWQ00<0Y9j?
0:f][@2aZid0302aZid30:f][@/0^K:V0P11JN400`2i/ZH0[Jf]0;jg[0020;jg[080@FWQ1@2n]j`0
0`11JN40_[N/0;jg[0060;jg[0030:f][@31^[00`KZ`0080`KZ`00<0@FWQ0<6j/031^[003031^[00
0`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng00`0a[ng0`11JN460<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1
_00?0<O1_080@FWQ00<0[Jf]0<K0_036`;`01`36`;`00`11JN40a/2l0<K0_0040<K0_003045Yh@36
`;`0[Jf]00@0`kfk00@0@FWQ0<>m^`11JN40`kfk0P11JN400`33_K/0@FWQ0:f][@020:f][@80@FWQ
2@2n^KP3045Yh@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii
071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5
M@0208Z5M@030:f][@2:QGD0[Jf]00P0Y9j?0P11JN400`2TWXl0[Jf]0;6[W@0=0;6[W@030:f][@2i
/ZH0[Jf]0080[Jf]202i/ZH2045Yh@030;VbYP2][Jd0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`00`2n
]j`00`11JN40_[N/0;jg[0060;jg[0030:f][@31^[00`KZ`0080@FWQ00<0`KZ`045Yh@11JN401031
^[000`11JN40`KZ`0<6j/0050<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36
_kL0a[ng00l0a[ng1011JN420<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0020<O1_0D0@FWQ2037
`K`2045Yh@030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_036`;`01036`;`00`11JN40a/2l0:f]
[@040<>m^`05045Yh@33_K/0@FWQ0<>m^`11JN400P2][Jd01011JN40`kfk0<>m^`33_K/2045Yh@d0
_[Vh00<0[Jf]0;B`/@2d/;40202d/;420:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40
oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@P0Y9j?
0P11JN400`2TWXl0[Jf]0;6[W@0=0;6[W@030:f][@2i/ZH0^K:V0080^K:V0`2][Jd50;VbYP80@FWQ
00<0^K:V0:f][@2n]j`00`2n]j`00`11JN40_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/00H0_[N/
00@0[Jf]0<6j/011JN40@FWQ1031^[001P11JN40`KZ`0<6j/011JN40`KZ`045Yh@H0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0?
0<Jo]`80@FWQ1036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0@FWQ045Yh@02
045Yh@@0al6l0`11JN460<O1_080@FWQ00<0[Jf]0<K0_036`;`01`36`;`00`11JN40a/2l0<K0_004
0<K0_003045Yh@36`;`0[Jf]00@0`kfk00D0@FWQ0<>m^`11JN40[Jf]045Yh@020<>m^`03045Yh@33
_K/0`kfk0080`kfk00<0@FWQ0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1S
H5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`060:BNS`80@FWQ00<0
Y9j?0:f][@2aZid03@2aZid00`2][Jd0^K:V0;VbYP050;VbYP@0[Jf]00D0^K:V045Yh@11JN40^K:V
0:f][@040;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`00`2][Jd0`KZ`
0<6j/002045Yh@D0`KZ`00<0@FWQ0<6j/011JN401`31^[000`11JN40[Jf]0<>m/`0D0<>m/`030:f]
[@35_[D0aKje00l0aKje4@2][Jd60<Jo]`80@FWQ1036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
0P11JN450<O1_080@FWQ1P37`K`2045Yh@030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_036`;`0
1036`;`2045Yh@030:f][@33_K/0`kfk0080`kfk00D0@FWQ0:f][@11JN40`kfk045Yh@020<>m^`03
045Yh@33_K/0`kfk0080`kfk00<0@FWQ0;ji^02n^KP0102n^KP00`11JN40_[Vh0;ji^0040;ji^003
0:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd60:BNS`80@FWQ00<0Y9j?0:f]
[@2aZid03@2aZid00`2][Jd0^K:V0;VbYP090;VbYP050:f][@11JN40@FWQ0;VbYP2][Jd0102n]j`2
045Yh@@0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`00`2][Jd0`KZ`0<6j/002045Yh@D0`KZ`0`11JN47
0<6j/003045Yh@2][Jd0`kfc00<0`kfc00<0@FWQ0<>m/`33_K<03P33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng00T0a[ng1P2][Jd2045YhBP0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`00P11JN460<O1_080@FWQ1@37`K`2
045Yh@030:f][@36`;`0a/2l00P0a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@030:f][@33_K/0
[Jf]0080[Jf]00<0@FWQ0<>m^`11JN400P11JN430<>m^`05045Yh@33_K/0`kfk0<>m^`11JN401P2n
^KP00`11JN40_[Vh0;ji^0040;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d/;40[Jf]
1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0
Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]102TWXl2045Yh@030:BNS`2][Jd0/J^M00d0
/J^M00<0[Jf]0;VbYP2i/ZH02P2i/ZH2045Yh@<0[Jf]0`2n]j`2045Yh@<0_[N/0P11JN470;jg[003
0:f][@31^[00`KZ`0080@FWQ1P31^[02045Yh@L0`KZ`00<0@FWQ0:f][@33_K<00`33_K<00`11JN40
`kfc0<>m/`0;0<>m/`04045Yh@33_K<0`kfc0:f][AH0aKje00<0[Jf]0<Jo]`36_kL03`36_kL2045Y
h@@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_002045Yh@H0al6l0P11JN450<O1
_080@FWQ00<0[Jf]0<K0_036`;`02@36`;`7045Yh@80[Jf]0P33_K/2045Yh@80`kfk0P11JN430<>m
^`05045Yh@33_K/0`kfk0<>m^`11JN401P2n^KP00`11JN40_[Vh0;ji^0040;ji^0030:f][@2d/;40
];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f]
[@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2T
WXl01@2][Jd0Y9j?0:BNS`2TWXl0@FWQ0080Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V
0;VbYP0:0;VbYP05045Yh@2i/ZH0^K:V0:f][@2n]j`00`2][Jd2045Yh@<0_[N/0P11JN470;jg[003
0:f][@31^[00`KZ`0080@FWQ1P31^[02045Yh@H0`KZ`0`11JN440<>m/`03045Yh@33_K<0`kfc00T0
`kfc0P11JN401033_K<0@FWQ045Yh@2][Jd20<Fn]@80@FWQ0`35_[D3045Yh@`0aKje00<0[Jf]0<Jo
]`36_kL03`36_kL2045Yh@050<Jo]`000000a[ng0<Jo]`2][Jd05P37`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k00P0b<6k0P11JN480<S1^`03045Yh@38`K/0[Jf]01D0b<6k00<0[Jf]
0<O1_037`K`00P11JN470<O1_080@FWQ1037`K`2045Yh@030:f][@36`;`0a/2l00T0a/2l1@2][Jd2
045Yh@050:f][@33_K/0`kfk0<>m^`11JN400`33_K/2045Yh@<0`kfk0`11JN400`33_K/0@FWQ045Y
h@050;ji^003045Yh@2n^KP0_[Vh00@0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C
06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd01@2TWXl0@FWQ0:BNS`2TWXl0[Jf]
00h0/J^M00<0[Jf]0;VbYP2i/ZH02P2i/ZH01011JN40^K:V0;VbYP2][Jd40;jg[080@FWQ0`2][Jd2
045Yh@L0_[N/00D0[Jf]0<6j/031^[00`KZ`045Yh@060<6j/080@FWQ1P31^[03045Yh@<0`kfc0`11
JN490<>m/`80@FWQ1033_K<2045Yh@030<Fn]@11JN40@FWQ00H0aKje1011JN480<Fn]@030:f][@36
_kL0a[ng00l0a[ng0P11JN440<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k0080@FWQ0P38`K/2045Yh@D0b<6k00@0
@FWQ0<S1^`11JN40[Jf]5@38`K/00`2][Jd0al6l0<O1_002045Yh@L0al6l0P11JN440<O1_080@FWQ
00<0[Jf]0<K0_036`;`01@36`;`40:f][@D0a/2l00<0@FWQ0<K0_02][Jd00`33_K/01011JN40`kfk
0<>m^`33_K/2045Yh@040<>m^`11JN40@FWQ045Yh@<0`kfk0P11JN450;ji^080@FWQ1@2n^KP0102]
[Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`
h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd2
0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH02`2i/ZH01011JN40^K:V0;VbYP2]
[Jd40;jg[080@FWQ0`2n]j`2045Yh@80[Jf]1@2n]j`01@2][Jd0`KZ`0<6j/031^[00@FWQ00H0`KZ`
0P11JN460<6j/0<0@FWQ0`33_K<3045Yh@P0`kfc0P11JN450<>m/`030:f][@35_[D0@FWQ0080@FWQ
1P35_[D00`11JN40aKje0<Fn]@090<Fn]@040:f][@36_kL0a[ng0<Jo]`@0@FWQ1@36_kL2045Yh@<0
a[ng0P11JN420<Jo]`03045Yh@36_kL0[Jf]01D0al6h0`11JN420<O1^PL0@FWQ1`37`KX3045Yh@<0
al6j00<0[Jf]0<S1^`38`K/00`38`K/3045Yh@D0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11JN40
b<6k0:f][@0E0<S1^`030:f][@37`K`0al6l0080@FWQ2037`K`2045Yh@@0al6l00@0@FWQ0:f][@36
`;`0a/2l1@2][Jd90<K0_003045Yh@36`;`0[Jf]00<0`kfk00@0@FWQ0<>m^`11JN40`kfk0P11JN47
0<>m^`80@FWQ1@2n^KP2045Yh@D0_[Vh0`2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]
071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?
00L0Y9j?0`2][Jd=0;6[W@030:f][@2i/ZH0^K:V00/0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]102n]j`2
045Yh@<0_[N/0`11JN400`2n]j`0[Jf]0:f][@020:f][@030;jg[02][Jd0`KZ`00<0`KZ`0P11JN44
0<6j/003045Yh@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j/011JN400`33_K<3045Yh@P0`kfc0P11JN45
0<>m/`030:f][@35_[D0aKje0080@FWQ1P35_[D00`11JN40aKje0<Fn]@090<Fn]@030:f][@36_kL0
@FWQ0080@FWQ0`36_kL2045Yh@030<Jo]`11JN40@FWQ00D0a[ng0P11JN400`36_kL0@FWQ0<Jo]`02
045Yh@P0al6h1`11JN420<O1^0D0@FWQ00<0[Jf]0<O1^P37`KX01037`KX2045Yh@L0al6j0P11JN43
0<O1^P80@FWQ00<0al6j0:f][@38`K/01038`K/00`11JN40b<6k0<S1^`050<S1^`03045Yh@38`K/0
b<6k00H0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_002045Yh@P0al6l0P11JN43
0<O1_0030:f][@11JN40[Jf]0080[Jf]2036`;`00`11JN40a/2l0<K0_0030<K0_003045Yh@36`;`0
[Jf]00<0`kfk0P11JN4;0<>m^`030:f][@11JN40_[Vh00<0_[Vh00<0@FWQ0;ji^011JN40102n^KP2
0:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3P
iP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP0;0;Vb
YP04045Yh@2i/ZH0^K:V0:f][@@0_[N/0P11JN430;jg[0<0@FWQ1@2n]j`50:f][@<0`KZ`0P11JN42
0<6j/003045Yh@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j/011JN400`33_K<00`11JN40`kfc045Yh@08
0<>m/`03045Yh@33_K<0`kfc00@0`kfc00<0[Jf]0<Fn]@35_[D00P11JN460<Fn]@03045Yh@35_[D0
aKje00T0aKje00<0[Jf]045Yh@11JN401P36_kL2045Yh@030<Jo]`11JN40a[ng00@0a[ng0`11JN43
0<Jo]`<0@FWQ2@37`KP2045Yh@L0al6h0P11JN400`2][Jd0al6j0<O1^P040<O1^P80@FWQ1P37`KX2
045Yh@H0al6j00<0@FWQ0:f][@38`K/01038`K/00`11JN40b<6k0<S1^`050<S1^`03045Yh@38`K/0
b<6k00H0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_002045Yh@P0al6l0P11JN43
0:f][@030<O1_011JN40[Jf]00@0a/2l00<0@FWQ0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_003
0<K0_004045Yh@36`;`0[Jf]0<>m^`80@FWQ3@33_K/00`2][Jd0@FWQ045Yh@030;ji^003045Yh@2n
^KP0@FWQ0080_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2]
[Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
[Jf]0080[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0;0;VbYP04045Yh@2i/ZH0^K:V0:f][@@0_[N/0P11
JN430;jg[0<0@FWQ0`2n]j`01011JN40_[N/0;jg[02][Jd30<6j/0D0[Jf]0`11JN460<6j/080@FWQ
00<0`KZ`045Yh@33_K<00P33_K<00`11JN40`kfc045Yh@080<>m/`03045Yh@33_K<0`kfc00@0`kfc
00@0[Jf]0<Fn]@35_[D0@FWQ1`35_[D00`11JN40aKje0<Fn]@090<Fn]@030:f][@11JN40@FWQ00L0
a[ng0P11JN460<Jo]`80@FWQ1036_kL0102][Jd0al6h045Yh@11JN480<O1^080@FWQ1`37`KP2045Y
h@030:f][@37`KX0al6j00@0al6j0P11JN450<O1^P80@FWQ2037`KX00`11JN40b<6k0<S1^`030<S1
^`03045Yh@38`K/0b<6k00D0b<6k0P11JN470<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`00P11JN430<O1_0D0[Jf]0P11JN440<O1_080@FWQ0`36`;`2045Yh@D0a/2l00@0@FWQ0<K0
_036`;`0a/2l0P11JN420<K0_0030:f][@33_K/0`kfk00h0`kfk00H0[Jf]0;ji^011JN40@FWQ0;ji
^011JN430;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P
0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0;0;VbYP04045Yh@2i
/ZH0^K:V0:f][@@0_[N/0P11JN430;jg[080@FWQ00@0_[N/045Yh@2n]j`0_[N/0P11JN400`2n]j`0
[Jf]0<6j/0020<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11JN460:f][@80@FWQ00@0`KZ`0:f][@11
JN40`kfc0P11JN400`33_K<0@FWQ0<>m/`060<>m/`80@FWQ1P33_K<0102][Jd0aKje0<Fn]@11JN47
0<Fn]@03045Yh@35_[D0aKje00T0aKje00<0[Jf]045Yh@11JN401`36_kL2045Yh@H0a[ng0P11JN44
0<Jo]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@L0al6h0P11JN400`37`KP0[Jf]0<O1^P04
0<O1^P80@FWQ1@37`KX2045Yh@P0al6j00<0[Jf]0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`05
0<S1^`80@FWQ1`38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0080@FWQ0`2][Jd5
0<O1_080@FWQ1037`K`2045Yh@<0a/2l0P11JN460<K0_0<0@FWQ1036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh0080@FWQ00@0_[Vh0:f][@2][Jd0[Jf]1@2n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H0
0`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid3
0:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH02`2i/ZH01011JN40^K:V0;VbYP2][Jd30;jg[080@FWQ0P2n
]j`4045Yh@040;jg[011JN40_[N/0;jg[080@FWQ00<0_[N/0:f][@31^[000P31^[000`11JN40`KZ`
0<6j/0040<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN420:f][@04045Yh@2][Jd0@FWQ045Yh@80
`kfc00<0@FWQ0<>m/`33_K<01033_K<00`11JN40`kfc0<>m/`050<>m/`040:f][@35_[D0aKje045Y
h@L0aKje00<0@FWQ0<Fn]@35_[D02@35_[D00`2][Jd0@FWQ045Yh@070<Jo]`80@FWQ1P36_kL00`11
JN40a[ng0<Jo]`030<Jo]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@L0al6h0P11JN400`37
`KP0[Jf]0<O1^P040<O1^P80@FWQ1@37`KX00`11JN40al6j0<O1^P070<O1^P030:f][@38`K/0b<6k
00T0b<6k0`11JN480<S1^`030:f][@38`K/0b<6k0100b<6k1P2][Jd2045Yh@P0al6l0P11JN440<O1
_003045Yh@2][Jd0@FWQ00<0a/2l00<0@FWQ0<K0_036`;`03036`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00
Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H00`2][Jd0RXEe08Z5M@0308Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid30:f][@030;6[W@2][Jd0^K:V
00`0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]0`2n]j`2045Yh@P0_[N/00H0@FWQ0;jg[02n]j`0@FWQ0;jg
[02][Jd30<6j/003045Yh@31^[00`KZ`00@0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@040<6j
/02][Jd0@FWQ0<>m/`80@FWQ0P2][Jd01011JN40[Jf]0:f][@2][Jd30<>m/`03045Yh@33_K<0`kfc
00D0`kfc00@0[Jf]0<Fn]@35_[D0@FWQ1`35_[D00`11JN40aKje0<Fn]@090<Fn]@030:f][@11JN40
@FWQ00L0a[ng0P11JN460<Jo]`03045Yh@36_kL0a[ng00<0a[ng00D0[Jf]0<O1^037`KP0al6h045Y
h@070<O1^080@FWQ1`37`KP2045Yh@030<O1^02][Jd0al6j00@0al6j0P11JN450<O1^P03045Yh@37
`KX0al6j00L0al6j00<0[Jf]0<S1^`38`K/02038`K/3045Yh@L0b<6k00<0@FWQ0<S1^`2][Jd02`38
`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`00P11JN480<O1_080@FWQ1037`K`00`11JN40[Jf]0<K0
_004045Yh@h0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo
001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@0:0;6[W@<0[Jf]302i/ZH01011JN40^K:V0;VbYP2][Jd30;jg[003045Yh@2n]j`0_[N/00P0_[N/
0P11JN420;jg[0050:f][@31^[00`KZ`0<6j/011JN401P31^[000`11JN40`KZ`0<6j/0040<6j/006
045Yh@31^[00`KZ`0:f][@11JN40`kfc0P11JN420<>m/`04045Yh@33_K<0`kfc0<>m/`<0[Jf]00<0
@FWQ0:f][@2][Jd00P2][Jd30<>m/`L0@FWQ1035_[D00`11JN40aKje0<Fn]@090<Fn]@040:f][@36
_kL0@FWQ045Yh@H0a[ng0P11JN460<Jo]`03045Yh@36_kL0a[ng00<0a[ng00D0[Jf]0<O1^037`KP0
al6h045Yh@070<O1^080@FWQ1`37`KP2045Yh@030<O1^02][Jd0al6j00@0al6j0P11JN450<O1^P03
045Yh@37`KX0al6j00L0al6j00<0[Jf]0<S1^`38`K/01P38`K/3045Yh@T0b<6k00<0@FWQ0<S1^`2]
[Jd00`38`K/80:f][@X0b<6k00@0[Jf]0<O1_037`K`0al6l0P11JN470<O1_080@FWQ1037`K`00`11
JN40[Jf]0<K0_00B0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a
00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd80;VbYP04
045Yh@2i/ZH0^K:V0:f][@<0_[N/00<0@FWQ0;jg[02n]j`0302n]j`00`2][Jd0`KZ`0<6j/0020<6j
/080@FWQ0`31^[000`11JN40`KZ`0<6j/0040<6j/080@FWQ0P31^[00102][Jd0@FWQ0<>m/`11JN43
0<>m/`03045Yh@33_K<0`kfc00@0`kfc00<0@FWQ0<>m/`33_K<00P33_K<90:f][@D0aKje00<0@FWQ
0<Fn]@35_[D02@35_[D0102][Jd0a[ng045Yh@11JN460<Jo]`80@FWQ1P36_kL00`11JN40a[ng0<Jo
]`030<Jo]`050:f][@37`KP0al6h0<O1^011JN401`37`KP2045Yh@L0al6h0P11JN400`37`KP0[Jf]
0<O1^P040<O1^P80@FWQ1@37`KX00`11JN40al6j0<O1^P070<O1^P030:f][@38`K/0b<6k00D0b<6k
0`11JN470<S1^`<0[Jf]00<0@FWQ0:f][@2][Jd00`2][JdB0<S1^`040:f][@37`K`0al6l0<O1_080
@FWQ1`37`K`2045Yh@80al6l0P11JN400`37`K`0[Jf]0<K0_00B0<K0_0030:f][@33_K/0`kfk00T0
`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02]
[Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M
00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@D0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]0P2n]j`2045Yh@h0
_[N/00<0[Jf]0<6j/031^[001031^[03045Yh@L0`KZ`0P11JN420<6j/0040:f][@33_K<0@FWQ045Y
h@<0`kfc00<0@FWQ0<>m/`33_K<01033_K<00`11JN40`kfc0<>m/`050<>m/`030:f][@35_[D0aKje
00<0aKje1@2][Jd00`11JN40[Jf]0:f][@040:f][@D0aKje00@0[Jf]0<Jo]`36_kL0a[ng0`11JN43
0<Jo]`80@FWQ1P36_kL00`11JN40a[ng0<Jo]`030<Jo]`050:f][@37`KP0al6h0<O1^011JN401`37
`KP2045Yh@L0al6h0P11JN400`37`KP0[Jf]0<O1^P040<O1^P80@FWQ1@37`KX00`11JN40al6j0<O1
^P070<O1^P030:f][@38`K/0b<6k00<0b<6k00<0[Jf]045Yh@11JN402@2][Jd30<S1^`03045Yh@38
`K/0[Jf]01D0b<6k00@0[Jf]0<O1_037`K`0al6l0P11JN460<O1_080@FWQ1`37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3oool00640/>3V0P2][Jd:0:BNS`030:f][@2a
Zid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@<0@FWQ0P2i/ZH0102][Jd0_[N/045Y
h@11JN4?0;jg[0030:f][@31^[00`KZ`00`0`KZ`1011JN420<6j/0040:f][@33_K<0@FWQ045Yh@@0
`kfc00<0@FWQ0<>m/`33_K<00`33_K<00`11JN40`kfc0<>m/`050<>m/`030:f][@35_[D0aKje00P0
aKje0P11JN450<Fn]@`0[Jf]1@11JN460<Jo]`03045Yh@36_kL0a[ng00<0a[ng00D0[Jf]0<O1^037
`KP0al6h045Yh@070<O1^080@FWQ1`37`KP2045Yh@030<O1^02][Jd0al6j00@0al6j0P11JN440<O1
^P030:f][@11JN40[Jf]00L0[Jf]00<0@FWQ0:f][@2][Jd0102][Jd2045Yh@L0b<6k00<0@FWQ0<S1
^`38`K/00`38`K/00`11JN40b<6k0:f][@0E0<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1P37`K`2
045Yh@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/0
0`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H1
0?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;Vb
YP2i/ZH02@2i/ZH30:f][@H0@FWQ3`2n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0<0@FWQ00@0[Jf]0<>m
/`11JN40@FWQ1033_K<00`11JN40`kfc0<>m/`030<>m/`03045Yh@33_K<0`kfc00D0`kfc00<0[Jf]
0<Fn]@35_[D02035_[D2045Yh@X0aKje00<0[Jf]0<Jo]`36_kL01`36_kL2045Yh@H0[Jf]00<0@FWQ
0:f][@2][Jd01`2][Jd00`11JN40[Jf]0:f][@050:f][@80@FWQ1`2][Jd2045Yh@L0[Jf]0P11JN44
0:f][@030<O1^P11JN40@FWQ00H0al6j00<0@FWQ0<O1^P11JN401@38`K/00`11JN40b<6k0<S1^`05
0<S1^`80@FWQ1@38`K/00`11JN40b<6k0:f][@0E0<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1P37
`K`2045Yh@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0
[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H2
0:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00<0`kfc1@11JN430<>m/`03045Yh@33_K<0
`kfc00D0`kfc00<0[Jf]0<Fn]@35_[D02035_[D00`11JN40aKje045Yh@040<Fn]@03045Yh@35_[D0
aKje0080aKje00@0[Jf]0<Jo]`11JN40@FWQ1P36_kL2045Yh@H0a[ng00<0@FWQ0<Jo]`36_kL00`36
_kL00`2][Jd0al6h0<O1^002045Yh@L0al6h0P11JN470<O1^080@FWQ00<0al6h0:f][@37`KX01037
`KX2045Yh@D0al6j0P11JN470<O1^P80@FWQ1@38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ1@38
`K/00`11JN40b<6k0:f][@0E0<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1P37`K`00`11JN40al6l
0<O1_0060<O1_0030:f][@36`;`0a/2l00h0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh
00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2T
WXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2]
[Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02`33_K<00`11JN40`kfc0<>m
/`050<>m/`030:f][@35_[D0aKje00P0aKje00<0@FWQ0<Fn]@11JN400`35_[D00`11JN40aKje045Y
h@030<Fn]@040:f][@36_kL0@FWQ045Yh@H0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40a[ng
0<Jo]`030<Jo]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@L0al6h0P11JN400`37`KP0[Jf]
0<O1^P040<O1^P80@FWQ1P37`KX2045Yh@H0al6j00<0@FWQ0:f][@38`K/01038`K/00`11JN40b<6k
0<S1^`040<S1^`<0@FWQ1038`K/3045Yh@030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0
al6l0P11JN460<O1_003045Yh@37`K`0al6l00H0al6l00<0[Jf]0<K0_036`;`02@36`;`50:f][@80
a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0
];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0;0<>m/`80@FWQ1P33_K<00`2][Jd0aKje0<Fn]@050<Fn]@80@FWQ
00D0aKje045Yh@35_[D0aKje045Yh@030<Fn]@80@FWQ0`35_[D0102][Jd0a[ng0<Jo]`11JN460<Jo
]`03045Yh@36_kL0a[ng00D0a[ng0P11JN440<Jo]`040:f][@37`KP0@FWQ045Yh@P0al6h0P11JN46
0<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P030<O1^P80@FWQ1P37`KX2045Yh@H0al6j00<0@FWQ
0:f][@38`K/01@38`K/00`11JN40b<6k0<S1^`03045Yh@80b<6k00<0@FWQ0<S1^`38`K/00P38`K/3
045Yh@030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l0P11JN450<O1_080@FWQ2037
`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2T
WXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n
]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0;0<>m/`80@FWQ1P33
_K<0102][Jd0aKje0<Fn]@11JN460<Fn]@80@FWQ0`35_[D4045Yh@@0aKje00D0[Jf]0<Jo]`36_kL0
a[ng045Yh@040<Jo]`03045Yh@36_kL0a[ng00H0a[ng00<0@FWQ0<Jo]`11JN400`36_kL00`2][Jd0
@FWQ045Yh@090<O1^0@0@FWQ1037`KP2045Yh@80al6h00<0[Jf]0<O1^P37`KX00`37`KX2045Yh@L0
al6j0P11JN420<O1^P<0@FWQ00<0al6j0:f][@38`K/01P38`K/2045Yh@X0b<6k0`11JN400`2][Jd0
b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1@37`K`00`11JN40al6l0<O1_0070<O1
_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2]
[Jd0`kfc0<>m/`0;0<>m/`80@FWQ1P33_K<0102][Jd0aKje0<Fn]@11JN4C0<Fn]@030:f][@36_kL0
a[ng0080a[ng1011JN460<Jo]`@0@FWQ0P36_kL4045Yh@/0al6h0P11JN420<O1^0@0@FWQ1037`KP0
102][Jd0al6j0<O1^P37`KX4045Yh@D0al6j00<000000<O1^P37`KX00`11JN440<O1^P030:f][@38
`K/0b<6k0140b<6k0`11JN400`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l0<O1_080@FWQ
1037`K`2045Yh@L0al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
2`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`03`2n]j`50:f][A40`KZ`00<0[Jf]0<>m/`33_K<03033_K<2045Yh@D0`kfc00@0
[Jf]0<Fn]@11JN40@FWQ4`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00T0al6h
0P11JN4:0<O1^0030:f][@37`KX0al6j00T0al6j00<000000<O1^P37`KX02037`KX00`2][Jd0b<6k
0<S1^`0A0<S1^`<0@FWQ00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`7045Yh@<0
al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0
`kfc0<>m/`0=0<>m/`03045Yh@33_K<0`kfc00<0`kfc00@0[Jf]0<Fn]@11JN40@FWQ4`35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00T0al6h0P11JN4:0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/04@38`K/3045Yh@030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_011JN400`11JN420<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0
[Jf]0`31^[000`2][Jd0`kfc0<>m/`0=0<>m/`80@FWQ1033_K<0102][Jd0aKje045Yh@11JN4C0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02@37`KP2045Yh@X0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0A0<S1^`<0@FWQ00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f][@d0
`kfc00<0@FWQ0<>m/`33_K<00P33_K<0102][Jd0@FWQ045Yh@11JN4C0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP02@37`KP2045Yh@X0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0A0<S1^`04045Yh@38`K/0@FWQ0:f][A80b<6k1P2][JdB0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H1
0?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd70<>m/`H0@FWQ00<0aKje
045Yh@35_[D04P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00T0al6h0P11JN4:
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/04P38`K/00`11JN40b<6k0:f][@0;
0<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2a
Zid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<0102][Jd0aKje0<Fn]@11JN4C0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP02@37`KP2045Yh@X0al6h00<0[Jf]0<O1^P37`KX00`37`KX0
0`11JN40al6j0<O1^P0>0<O1^P040:f][@38`K/0b<6k00000140b<6k00<0@FWQ0<S1^`2][Jd00`38
`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0090<O1^080@FWQ2P37`KP00`2][Jd0al6j0<O1^P02
0<O1^P03045Yh@37`KX0@FWQ00l0al6j00<0[Jf]0<S1^`0000003`38`K/90:f][A80b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU
0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00H0al6h1@11JN4:0<O1^0030:f][@37`KX0al6j
00<0al6j00<0@FWQ0<O1^P37`KX03P37`KX00`2][Jd000000<S1^`030<S1^``0[Jf]1@38`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/00`33_K/30:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;VbYP2]
[Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102][Jd@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`00`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]
PP2`h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00?0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1
^`L0[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]
0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0
b<6k202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf]
[`2`h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52134 .3309 m
.50964 .33083 L
s
.53972 .33078 m
.52803 .33089 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50296 .33073 m
.49128 .33047 L
s
.55807 .33036 m
.5464 .33066 L
s
.255 .412 .882 r
.52218 .32289 m
.53375 .32283 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49628 .33309 m
.49629 .3306 L
s
.49795 .33212 m
.49795 .33064 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53308 .35914 m
.53309 .36628 L
s
.53475 .35914 m
.53476 .36626 L
s
.5 Mabswid
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51721 .3386 m
.51887 .33861 L
s
.5139 .34084 m
.51721 .3386 L
s
.51556 .34085 m
.51721 .3386 L
s
.53212 .34083 m
.53543 .33855 L
s
.53543 .33855 m
.53874 .33851 L
s
.53874 .33851 m
.54205 .34071 L
s
.53874 .33851 m
.5437 .34068 L
s
.50563 .33849 m
.50893 .34079 L
s
.50067 .33841 m
.50563 .33849 L
s
0 0 0 r
.58457 .33552 m
.58631 .33878 L
s
.255 .412 .882 r
.51389 .34535 m
.51556 .34085 L
s
.49735 .34059 m
.50067 .33841 L
s
.4957 .34055 m
.50067 .33841 L
s
.51224 .34533 m
.5139 .34084 L
s
.52881 .34536 m
.53212 .34083 L
s
0 0 0 r
.58582 .33468 m
.58796 .33869 L
s
.255 .412 .882 r
.50893 .34079 m
.51224 .34533 L
s
.54205 .34071 m
.54537 .34516 L
s
.5437 .34068 m
.54702 .34512 L
s
.49569 .34507 m
.49735 .34059 L
s
.49403 .34503 m
.4957 .34055 L
s
.55856 .33806 m
.57008 .33764 L
s
.54537 .34516 m
.54704 .3519 L
s
.54702 .34512 m
.5487 .35186 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49567 .34958 m
.49569 .34507 L
s
.49402 .34954 m
.49403 .34503 L
s
.46119 .33696 m
.47265 .33752 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49567 .34958 m
.49731 .35414 L
s
.57664 .33734 m
.58808 .33674 L
s
.49402 .34954 m
.49566 .3541 L
s
.54704 .3519 m
.54706 .35642 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49786 .36142 m
.49787 .35907 L
s
.49618 .3624 m
.49619 .35901 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46752 .369 m
.46773 .3373 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5487 .35186 m
.54871 .35639 L
s
.46587 .36893 m
.4661 .33722 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52714 .32288 m
.52717 .37026 L
s
.52879 .32287 m
.52883 .37025 L
s
.51388 .36117 m
.51389 .34535 L
s
.51221 .36568 m
.51224 .34533 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58155 .3371 m
.58173 .362 L
s
.49731 .35414 m
.50062 .35647 L
s
.49566 .3541 m
.50062 .35647 L
s
.50062 .35647 m
.51056 .35887 L
s
.51056 .35887 m
.51222 .36115 L
s
.54542 .36325 m
.54706 .35642 L
s
.54708 .36322 m
.54871 .35639 L
s
.51221 .36568 m
.51388 .36117 L
s
.52882 .36345 m
.53215 .36796 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54211 .36784 m
.54542 .36325 L
s
.51055 .36794 m
.51221 .36568 L
s
.59459 .33635 m
.60593 .33556 L
s
.54377 .36781 m
.54708 .36322 L
s
0 0 0 r
.58652 .36463 m
.58667 .36365 L
s
.255 .412 .882 r
.49563 .36316 m
.49728 .36319 L
s
.49728 .36546 m
.49728 .36319 L
s
.49562 .36543 m
.49563 .36316 L
s
0 0 0 r
.58817 .36454 m
.58851 .36242 L
s
.255 .412 .882 r
.53215 .36796 m
.53548 .3702 L
s
.50722 .37017 m
.51055 .36794 L
s
.49562 .36543 m
.49727 .36773 L
s
.5388 .37016 m
.54211 .36784 L
s
.52218 .37027 m
.52883 .37025 L
s
.5388 .37016 m
.54377 .36781 L
s
.53548 .3702 m
.5388 .37016 L
s
.49727 .36773 m
.50058 .37006 L
s
.50058 .37006 m
.50722 .37017 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44652 .33833 m
.44973 .34306 L
s
.44168 .33572 m
.44652 .33833 L
s
0 0 0 r
.5728 .37292 m
.57496 .37492 L
s
.255 .412 .882 r
.47908 .36494 m
.48074 .36273 L
s
.48074 .36273 m
.48238 .36505 L
s
.46761 .35538 m
.46921 .36226 L
s
.56527 .3627 m
.5686 .36712 L
s
.43845 .33548 m
.44168 .33572 L
s
.48237 .36732 m
.48238 .36505 L
s
0 0 0 r
.58325 .37129 m
.58652 .36463 L
s
.255 .412 .882 r
.47908 .36494 m
.48072 .36727 L
s
0 0 0 r
.58491 .37121 m
.58817 .36454 L
s
.255 .412 .882 r
.48071 .36954 m
.48237 .36732 L
s
.43521 .3375 m
.43845 .33548 L
s
.4336 .33737 m
.43845 .33548 L
s
0 0 0 r
.57496 .37492 m
.57995 .3747 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44962 .35439 m
.44979 .33628 L
s
.45125 .3545 m
.45141 .33638 L
s
.46921 .36226 m
.47247 .36695 L
s
0 0 0 r
.57995 .3747 m
.58325 .37129 L
s
.255 .412 .882 r
.47575 .36935 m
.48071 .36954 L
s
0 0 0 r
.51628 .39226 m
.51459 .39551 L
s
.51796 .39552 m
.51628 .39226 L
s
.255 .412 .882 r
.44475 .35408 m
.45615 .35479 L
s
0 0 0 r
.57995 .3747 m
.58491 .37121 L
s
.255 .412 .882 r
.47247 .36695 m
.47575 .36935 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58012 .36662 m
.58173 .362 L
s
.5686 .36712 m
.57356 .36919 L
s
.58319 .33701 m
.58337 .36192 L
s
.56514 .33783 m
.56539 .38545 L
s
.5635 .33789 m
.56374 .38551 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59946 .33602 m
.59976 .36779 L
s
.60108 .33591 m
.60139 .36768 L
s
.43194 .34177 m
.43521 .3375 L
s
.58176 .36654 m
.58337 .36192 L
s
.43033 .34164 m
.4336 .33737 L
s
.57356 .36919 m
.57685 .36905 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57685 .36905 m
.58012 .36662 L
s
.57685 .36905 m
.58176 .36654 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46095 .36868 m
.46752 .369 L
s
0 0 0 r
.40624 .32482 m
.40852 .32661 L
s
.255 .412 .882 r
.61722 .33692 m
.62199 .33424 L
s
.61406 .34172 m
.61722 .33692 L
s
.43028 .34618 m
.43194 .34177 L
s
.61253 .34866 m
.61406 .34172 L
s
0 0 0 r
.40624 .32482 m
.40851 .3274 L
s
.255 .412 .882 r
.61882 .33679 m
.62199 .33424 L
s
.61567 .34159 m
.61882 .33679 L
s
.42867 .34605 m
.43033 .34164 L
s
.62199 .33424 m
.62518 .33395 L
s
.61414 .34853 m
.61567 .34159 L
s
.55877 .38566 m
.56539 .38545 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62518 .33395 m
.62998 .33576 L
s
.61253 .34866 m
.61258 .3532 L
s
.4286 .35286 m
.43028 .34618 L
s
.61414 .34853 m
.61419 .35308 L
s
.42699 .35273 m
.42867 .34605 L
s
.59488 .36809 m
.60139 .36768 L
s
.44942 .37715 m
.45111 .37041 L
s
.61258 .3532 m
.61426 .3599 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61419 .35308 m
.61587 .35977 L
s
.62998 .33576 m
.63321 .33999 L
s
.42846 .36425 m
.4286 .35286 L
s
.42686 .36412 m
.42699 .35273 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45099 .3841 m
.45111 .37041 L
s
.44612 .38151 m
.44942 .37715 L
s
.44942 .37715 m
.45099 .3841 L
s
.40972 .33291 m
.41563 .36542 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64259 .35875 m
.64352 .35238 L
s
.255 .412 .882 r
.61587 .35977 m
.61914 .36407 L
s
.61426 .3599 m
.61754 .3642 L
s
.59987 .37919 m
.60152 .38137 L
s
.59826 .38158 m
.59987 .37919 L
s
.59826 .38158 m
.59991 .38376 L
s
.44121 .38348 m
.44612 .38151 L
s
.42846 .36425 m
.43 .37123 L
s
.61754 .3642 m
.62238 .36608 L
s
.59991 .38376 m
.60152 .38137 L
s
.42686 .36412 m
.42839 .3711 L
s
.61914 .36407 m
.62238 .36608 L
s
.64413 .33199 m
.64576 .33636 L
s
.64413 .33199 m
.64426 .34109 L
s
.43 .37123 m
.43156 .37592 L
s
.43796 .38326 m
.44121 .38348 L
s
.42839 .3711 m
.42994 .3758 L
s
.6318 .3538 m
.63342 .35592 L
s
.63025 .35623 m
.6318 .3538 L
s
.62238 .36608 m
.62718 .36566 L
s
.63025 .35623 m
.63187 .35836 L
s
.43156 .37592 m
.43474 .38074 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40295 .36416 m
.40972 .33291 L
s
.40453 .36433 m
.40962 .33972 L
s
.43474 .38074 m
.43796 .38326 L
s
.43312 .38062 m
.43796 .38326 L
s
.39717 .33152 m
.40295 .36416 L
s
.39043 .36277 m
.39717 .33152 L
s
.42994 .3758 m
.43312 .38062 L
s
.64576 .33636 m
.64729 .33391 L
s
.64729 .33391 m
.65037 .33127 L
s
.64426 .34109 m
.64576 .33636 L
s
.41086 .36497 m
.42042 .36585 L
s
.63342 .35592 m
.63345 .35821 L
s
.62718 .36566 m
.63034 .36308 L
s
.63034 .36308 m
.63345 .35821 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65037 .33127 m
.65657 .33051 L
s
.39199 .36295 m
.39706 .33835 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65657 .33051 m
.65969 .33239 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.646 .35232 m
.6491 .34969 L
s
.64447 .35478 m
.646 .35232 L
s
.64447 .35478 m
.64454 .35936 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6491 .34969 m
.6568 .34419 L
s
.64604 .35461 m
.64913 .35197 L
s
.6445 .35707 m
.64604 .35461 L
s
.65969 .33239 m
.66127 .33447 L
s
.38171 .32958 m
.38324 .32978 L
s
.64913 .35197 m
.65683 .34648 L
s
.64454 .35936 m
.64614 .36147 L
s
.37861 .33145 m
.38171 .32958 L
s
.38014 .33165 m
.38171 .32958 L
s
.66127 .33447 m
.66139 .34132 L
s
.6568 .34419 m
.65985 .34152 L
s
.64614 .36147 m
.64931 .36342 L
s
.65683 .34648 m
.65989 .3438 L
s
.37853 .33601 m
.38014 .33165 L
s
.65985 .34152 m
.66135 .33904 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65989 .3438 m
.66139 .34132 L
s
.37701 .3358 m
.37861 .33145 L
s
.38578 .36221 m
.39667 .36348 L
s
.37825 .35204 m
.37853 .33601 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64931 .36342 m
.65555 .3627 L
s
.37405 .33081 m
.37701 .3358 L
s
.37664 .35643 m
.37701 .3358 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37106 .32808 m
.37405 .33081 L
s
.67192 .33072 m
.67339 .32822 L
s
.67192 .33072 m
.67348 .33279 L
s
.67339 .32822 m
.67494 .33028 L
s
.36654 .32741 m
.37106 .32808 L
s
.65555 .3627 m
.65861 .36003 L
s
.66012 .35754 m
.66158 .35276 L
s
.66158 .35276 m
.66174 .36194 L
s
.65861 .36003 m
.66012 .35754 L
s
.66012 .35754 m
.66174 .36194 L
s
.67348 .33279 m
.67494 .33028 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3635 .32923 m
.36654 .32741 L
s
.36201 .329 m
.36654 .32741 L
s
.37664 .35643 m
.37825 .35204 L
s
.37523 .34933 m
.37672 .35184 L
s
.36619 .34574 m
.37523 .34933 L
s
.67369 .34424 m
.67572 .37165 L
s
.67268 .37206 m
.67369 .34424 L
s
.36192 .33358 m
.3635 .32923 L
s
0 0 0 r
.36363 .35203 m
.3637 .34821 L
s
.255 .412 .882 r
.37507 .35852 m
.37664 .35643 L
s
.36043 .33335 m
.36201 .329 L
s
.37198 .36041 m
.37507 .35852 L
s
0 0 0 r
.36363 .35203 m
.36372 .35245 L
s
.255 .412 .882 r
.36183 .33817 m
.36192 .33358 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36033 .33794 m
.36043 .33335 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36323 .34299 m
.36619 .34574 L
s
.36173 .34277 m
.36619 .34574 L
s
.36183 .33817 m
.36323 .34299 L
s
.67394 .35802 m
.6742 .37185 L
s
.36592 .35955 m
.37198 .36041 L
s
.36033 .33794 m
.36173 .34277 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36155 .35197 m
.36305 .35219 L
s
.36301 .3545 m
.36305 .35219 L
s
.67268 .37206 m
.67429 .37647 L
s
.36296 .3568 m
.36592 .35955 L
s
.36151 .35427 m
.36155 .35197 L
s
.36151 .35427 m
.36296 .3568 L
s
.67429 .37647 m
.67572 .37165 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33151 .32127 m
.34151 .32319 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34822 .34983 m
.34964 .35239 L
s
.34959 .3547 m
.34964 .35239 L
s
.34671 .3519 m
.34822 .34983 L
s
.33646 .35474 m
.3372 .32238 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34808 .35677 m
.34959 .3547 L
s
.33503 .35448 m
.33578 .32211 L
s
.34671 .3519 m
.34812 .35446 L
s
.34369 .35603 m
.34808 .35677 L
s
.34084 .3532 m
.34369 .35603 L
s
.33678 .34084 m
.33806 .34805 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33806 .34805 m
.34084 .3532 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33075 .35368 m
.33646 .35474 L
s
.32028 .32125 m
.32293 .32647 L
s
.32293 .32647 m
.32421 .3314 L
s
.32421 .3314 m
.32544 .33864 L
s
.31621 .31803 m
.32028 .32125 L
s
.72613 .3187 m
.72735 .36759 L
s
.3189 .32095 m
.32154 .32618 L
s
.32154 .32618 m
.32282 .33111 L
s
.32516 .35026 m
.32544 .33864 L
s
.32282 .33111 m
.32404 .33835 L
s
.31621 .31803 m
.3189 .32095 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32376 .34997 m
.32404 .33835 L
s
.30277 .31485 m
.31621 .31803 L
s
.32359 .35696 m
.32516 .35026 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72198 .3196 m
.73566 .31654 L
s
.32219 .35668 m
.32376 .34997 L
s
.32207 .36135 m
.32359 .35696 L
s
.73566 .31654 m
.7384 .31822 L
s
.73566 .31654 m
.73974 .3179 L
s
.32068 .36107 m
.32219 .35668 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30544 .3649 m
.30675 .31583 L
s
.31917 .36547 m
.32207 .36135 L
s
.30679 .3652 m
.30809 .31615 L
s
.31779 .36518 m
.32068 .36107 L
s
.7384 .31822 m
.74119 .32223 L
s
.73974 .3179 m
.74252 .32191 L
s
.31497 .36696 m
.31917 .36547 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7275 .3184 m
.72874 .3673 L
s
.72318 .36842 m
.73695 .36556 L
s
.31497 .36696 m
.31779 .36518 L
s
.74119 .32223 m
.74264 .32657 L
s
.74252 .32191 m
.74397 .32625 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74264 .32657 m
.74416 .33325 L
s
.30143 .36399 m
.31497 .36696 L
s
.74397 .32625 m
.74548 .33293 L
s
.74416 .33325 m
.74448 .34496 L
s
.75017 .31292 m
.7591 .31049 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74548 .33293 m
.7458 .34464 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73695 .36556 m
.74093 .36232 L
s
.73695 .36556 m
.73958 .36262 L
s
.74334 .35231 m
.74448 .34496 L
s
.73958 .36262 m
.74214 .35731 L
s
.75403 .31189 m
.75497 .34471 L
s
.74214 .35731 m
.74334 .35231 L
s
.74467 .35199 m
.7458 .34464 L
s
.74093 .36232 m
.74347 .357 L
s
.7553 .31155 m
.75625 .34438 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74347 .357 m
.74467 .35199 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75109 .3457 m
.75625 .34438 L
s
.75584 .33028 m
.75732 .33699 L
s
.75732 .33699 m
.75999 .34102 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75999 .34102 m
.76257 .34269 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76257 .34269 m
.7663 .34165 L
s
.76492 .33728 m
.76623 .33929 L
s
.76492 .33728 m
.76609 .33457 L
s
.76609 .33457 m
.76739 .33657 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76739 .33657 m
.76746 .33894 L
s
.7663 .34165 m
.76746 .33894 L
s
.77623 .30768 m
.77967 .30416 L
s
.7752 .31277 m
.77623 .30768 L
s
.7752 .31277 m
.77534 .31749 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77741 .30729 m
.77967 .30416 L
s
.77638 .31239 m
.77741 .30729 L
s
.77638 .31239 m
.77653 .31711 L
s
.77534 .31749 m
.77668 .32184 L
s
.77653 .31711 m
.77785 .32147 L
s
.77967 .30416 m
.78313 .30299 L
s
.77668 .32184 m
.78027 .32308 L
s
.77785 .32147 m
.78027 .32308 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77697 .33131 m
.77705 .33368 L
s
.77697 .33131 m
.77815 .33094 L
s
.78313 .30299 m
.78548 .30456 L
s
.77705 .33368 m
.7783 .33569 L
s
.77815 .33094 m
.77823 .33331 L
s
.78027 .32308 m
.78723 .32314 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7783 .33569 m
.78072 .33732 L
s
.78548 .30456 m
.78789 .3085 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78072 .33732 m
.78534 .33582 L
s
.78885 .30335 m
.79098 .30017 L
s
.78789 .3085 m
.78885 .30335 L
s
.78789 .3085 m
.78859 .3299 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78996 .30295 m
.79098 .30017 L
s
.789 .3081 m
.78996 .30295 L
s
.789 .3081 m
.78955 .32474 L
s
.79098 .30017 m
.79208 .29976 L
s
.78723 .32314 m
.78843 .32513 L
s
.78534 .33582 m
.78754 .33267 L
s
.78754 .33267 m
.78859 .3299 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78859 .3299 m
.78955 .32474 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79861 .33113 m
.80167 .29599 L
s
.79967 .33072 m
.80192 .30315 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23823 .29852 m
.23932 .29656 L
s
.2384 .29373 m
.23932 .29656 L
s
.23732 .29569 m
.2384 .29373 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80167 .29599 m
.80694 .32785 L
s
.79538 .33232 m
.80283 .3295 L
s
.23732 .29569 m
.23823 .29852 L
s
.80974 .29251 m
.81482 .32447 L
s
.80694 .32785 m
.80974 .29251 L
s
.2378 .33983 m
.23781 .3105 L
s
.23579 .339 m
.23781 .3105 L
s
.80795 .32744 m
.81 .2997 L
s
.23679 .33942 m
.2373 .32493 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23662 .34426 m
.2378 .33983 L
s
.22959 .29213 m
.23044 .29498 L
s
.23018 .3022 m
.23044 .29498 L
s
.22782 .28882 m
.22959 .29213 L
s
.22924 .30176 m
.23027 .2998 L
s
.23579 .339 m
.23662 .34426 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22915 .30417 m
.23018 .3022 L
s
.81192 .32575 m
.81767 .32317 L
s
.22418 .28698 m
.22782 .28882 L
s
.22729 .30328 m
.22924 .30176 L
s
.2272 .30569 m
.22915 .30417 L
s
0 0 0 r
.82584 .27969 m
.82645 .28048 L
s
.255 .412 .882 r
.22863 .31867 m
.22975 .31427 L
s
.2294 .32394 m
.22975 .31427 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22258 .30586 m
.22729 .30328 L
s
.22249 .30829 m
.2272 .30569 L
s
.22863 .31867 m
.2294 .32394 L
s
.2276 .32065 m
.22863 .31867 L
s
.22232 .28846 m
.22418 .28698 L
s
.22566 .3222 m
.2276 .32065 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82145 .29915 m
.82217 .29386 L
s
.82082 .30687 m
.82145 .29915 L
s
.82217 .29386 m
.82375 .2881 L
s
.22136 .29041 m
.22232 .28846 L
s
.82082 .30687 m
.82127 .31899 L
s
.82235 .2987 m
.82305 .2934 L
s
.82172 .30642 m
.82235 .2987 L
s
.82305 .2934 m
.82462 .28763 L
s
.82375 .2881 m
.82624 .28427 L
s
.22204 .32044 m
.22566 .3222 L
s
.82172 .30642 m
.82217 .31855 L
s
0 0 0 r
.82735 .30629 m
.82838 .30766 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22067 .28511 m
.22136 .29041 L
s
.22031 .29479 m
.22136 .29041 L
s
.22031 .29479 m
.22067 .28511 L
s
.82462 .28763 m
.82624 .28427 L
s
0 0 0 r
.82694 .30904 m
.82851 .31113 L
s
.255 .412 .882 r
.22072 .30738 m
.22258 .30586 L
s
.82127 .31899 m
.82244 .32585 L
s
.22063 .30981 m
.22249 .30829 L
s
.82217 .31855 m
.82333 .32541 L
s
.82244 .32585 m
.82352 .33028 L
s
.21976 .30936 m
.22072 .30738 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82624 .28427 m
.82793 .28332 L
s
.22036 .31711 m
.22204 .32044 L
s
.21967 .31179 m
.22063 .30981 L
s
.82793 .28332 m
.83049 .28431 L
s
.82333 .32541 m
.8244 .32984 L
s
.21958 .31422 m
.21976 .30936 L
s
.21958 .31422 m
.22036 .31711 L
s
.82352 .33028 m
.82547 .33429 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8244 .32984 m
.82634 .33385 L
s
.83049 .28431 m
.83228 .28822 L
s
.21311 .28324 m
.21453 .28907 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82547 .33429 m
.82817 .33541 L
s
.82634 .33385 m
.82817 .33541 L
s
.832 .28092 m
.83275 .30041 L
s
.83032 .30182 m
.83588 .29851 L
s
.21086 .27935 m
.21311 .28324 L
s
.8328 .28043 m
.83355 .29994 L
s
.82817 .33541 m
.82986 .33453 L
s
.21379 .30857 m
.21388 .30613 L
s
.21317 .30322 m
.21388 .30613 L
s
.21199 .31253 m
.21379 .30857 L
s
.20934 .27837 m
.21086 .27935 L
s
.21227 .30519 m
.21317 .30322 L
s
.21227 .30519 m
.21298 .30811 L
s
.20775 .27982 m
.20934 .27837 L
s
.20702 .27933 m
.20934 .27837 L
s
.21032 .31406 m
.21199 .31253 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82986 .33453 m
.83226 .33073 L
s
.83226 .33073 m
.83369 .3249 L
s
.83738 .27749 m
.84235 .27399 L
s
.2061 .28373 m
.20775 .27982 L
s
.8342 .31708 m
.83477 .33183 L
s
.83369 .3249 m
.8342 .31708 L
s
.83369 .3249 m
.83477 .33183 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20801 .31265 m
.21032 .31406 L
s
.20538 .28323 m
.20702 .27933 L
s
.83956 .276 m
.84091 .31038 L
s
.20509 .29059 m
.2061 .28373 L
s
.84027 .2755 m
.84163 .3099 L
s
.2066 .30924 m
.20801 .31265 L
s
.20586 .30877 m
.20801 .31265 L
s
.20438 .2901 m
.20538 .28323 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2049 .2955 m
.20509 .29059 L
s
.20533 .30337 m
.2066 .30924 L
s
.83872 .31181 m
.84163 .3099 L
s
.2049 .2955 m
.20533 .30337 L
s
.20419 .29502 m
.20438 .2901 L
s
.20461 .30288 m
.20586 .30877 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84104 .29512 m
.84204 .30202 L
s
.20419 .29502 m
.20461 .30288 L
s
.19772 .26979 m
.20221 .27337 L
s
.84204 .30202 m
.84362 .30599 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19885 .30641 m
.20023 .27185 L
s
.1982 .30592 m
.19959 .27133 L
s
.84362 .30599 m
.84507 .30749 L
s
.84507 .30749 m
.84704 .30603 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8462 .30156 m
.84694 .30355 L
s
.8462 .30156 m
.84674 .29859 L
s
.84674 .29859 m
.84748 .30057 L
s
.19632 .30444 m
.19885 .30641 L
s
.84704 .30603 m
.84758 .30305 L
s
.84748 .30057 m
.84758 .30305 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19153 .26403 m
.19534 .26771 L
s
.19751 .32332 m
.19825 .32131 L
s
.19771 .31834 m
.19825 .32131 L
s
.19697 .32035 m
.19771 .31834 L
s
.85079 .27473 m
.85116 .26926 L
s
.19697 .32035 m
.19751 .32332 L
s
.85116 .26926 m
.8527 .26521 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85079 .27473 m
.851 .27969 L
s
.851 .27969 m
.85176 .28414 L
s
.19254 .29347 m
.19365 .26614 L
s
.85136 .27421 m
.85171 .26873 L
s
.85136 .27421 m
.85156 .27917 L
s
.85171 .26873 m
.8527 .26521 L
s
.85156 .27917 m
.85232 .28362 L
s
.19199 .29296 m
.19311 .26562 L
s
.8527 .26521 m
.85426 .26362 L
s
.85176 .28414 m
.85351 .28508 L
s
.85232 .28362 m
.85351 .28508 L
s
.85217 .29409 m
.85227 .29658 L
s
.85217 .29409 m
.85273 .29358 L
s
.85227 .29658 m
.85293 .29857 L
s
.85273 .29358 m
.85283 .29607 L
s
.19178 .29795 m
.19254 .29347 L
s
.85426 .26362 m
.85536 .26504 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85351 .28508 m
.85667 .28447 L
s
.85293 .29857 m
.85413 .30005 L
s
.19124 .29744 m
.19199 .29296 L
s
.19009 .29893 m
.19178 .29795 L
s
.85536 .26504 m
.85652 .26896 L
s
.19009 .29893 m
.19124 .29744 L
s
.85413 .30005 m
.8562 .29802 L
s
.18643 .25812 m
.18954 .2619 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18908 .29791 m
.19009 .29893 L
s
.85652 .26896 m
.85678 .26344 L
s
.85652 .26896 m
.85745 .29147 L
s
.85678 .26344 m
.85758 .25987 L
s
.18596 .31299 m
.18816 .26029 L
s
.85699 .26843 m
.85724 .2629 L
s
.85699 .26843 m
.85771 .28594 L
s
.85724 .2629 m
.85758 .25987 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85667 .28447 m
.85725 .28646 L
s
.8562 .29802 m
.85708 .29449 L
s
.85758 .25987 m
.85802 .25933 L
s
.85813 .24078 m
.86079 .23688 L
s
.18773 .29387 m
.18908 .29791 L
s
.18552 .31249 m
.18771 .25975 L
s
0 0 0 r
.86224 .25187 m
.86308 .24789 L
s
.86232 .25378 m
.8624 .25256 L
s
.18181 .28877 m
.18293 .29004 L
s
.8624 .25256 m
.86308 .24789 L
s
.255 .412 .882 r
.85708 .29449 m
.85745 .29147 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85745 .29147 m
.85771 .28594 L
s
0 0 0 r
.86308 .24789 m
.86388 .24677 L
s
.255 .412 .882 r
.18701 .28781 m
.18773 .29387 L
s
.85933 .23912 m
.86154 .29183 L
s
.85971 .23856 m
.86192 .29131 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86404 .29465 m
.86422 .29556 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18205 .28303 m
.18225 .27839 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18423 .31097 m
.18596 .31299 L
s
.86076 .26359 m
.86128 .25748 L
s
.86033 .29339 m
.86192 .29131 L
s
.86128 .25748 m
.86187 .25387 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86187 .25387 m
.86252 .25276 L
s
.18301 .25571 m
.18347 .26184 L
s
.18347 .26184 m
.1835 .26994 L
s
.8616 .28373 m
.86255 .28773 L
s
.18329 .27498 m
.1835 .26994 L
s
.18269 .25516 m
.18313 .26129 L
s
.18313 .26129 m
.18315 .2694 L
s
.18262 .28202 m
.18329 .27498 L
s
.18218 .25153 m
.18301 .25571 L
s
.18294 .27444 m
.18315 .2694 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86252 .25276 m
.86324 .25418 L
s
.86252 .25276 m
.86354 .25362 L
s
.18228 .28149 m
.18294 .27444 L
s
.18218 .25153 m
.18269 .25516 L
s
.86255 .28773 m
.86336 .28921 L
s
.18173 .28602 m
.18262 .28202 L
s
.18161 .25042 m
.18218 .25153 L
s
.18048 .22822 m
.18209 .23223 L
s
.86324 .25418 m
.86404 .25812 L
s
.18141 .28549 m
.18228 .28149 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86354 .25362 m
.86431 .25757 L
s
.86336 .28921 m
.86402 .28815 L
s
.18097 .25184 m
.18161 .25042 L
s
.18068 .28697 m
.18173 .28602 L
s
.17907 .28377 m
.18134 .23052 L
s
.86404 .25812 m
.86463 .26517 L
s
.18068 .28697 m
.18141 .28549 L
s
.86402 .28815 m
.86453 .28455 L
s
.86402 .28815 m
.86483 .28402 L
s
0 0 0 r
.17652 .23757 m
.17669 .23797 L
s
.255 .412 .882 r
.17884 .28324 m
.18111 .22994 L
s
.86431 .25757 m
.8649 .26462 L
s
.18026 .25579 m
.18097 .25184 L
s
.86453 .28455 m
.8649 .2784 L
s
.86463 .26517 m
.86485 .27024 L
s
0 0 0 r
.17573 .23946 m
.17652 .23757 L
s
.255 .412 .882 r
.18011 .28591 m
.18068 .28697 L
s
.86485 .27024 m
.8649 .2784 L
s
.86483 .28402 m
.86517 .27786 L
s
.8649 .26462 m
.86511 .2697 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86511 .2697 m
.86517 .27786 L
s
0 0 0 r
.86924 .24 m
.86946 .23597 L
s
.255 .412 .882 r
.17968 .28229 m
.18011 .28591 L
s
0 0 0 r
.86946 .23597 m
.86983 .23482 L
s
.255 .412 .882 r
.1794 .27612 m
.17968 .28229 L
s
0 0 0 r
.17504 .24557 m
.17573 .23946 L
s
.255 .412 .882 r
.86562 .24607 m
.86676 .24211 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86983 .23482 m
.87033 .23729 L
s
.86983 .23482 m
.87048 .23671 L
s
.17551 .23469 m
.1749 .23237 L
s
.17331 .28572 m
.17551 .23469 L
s
.255 .412 .882 r
.1782 .28162 m
.17907 .28377 L
s
0 0 0 r
.17313 .28517 m
.17534 .23411 L
s
.255 .412 .882 r
.17918 .24425 m
.17935 .24482 L
s
.17876 .24567 m
.17918 .24425 L
s
.17891 .24623 m
.17918 .24425 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87093 .24341 m
.87033 .23729 L
s
.87107 .24283 m
.87048 .23671 L
s
.255 .412 .882 r
.17854 .25077 m
.17891 .24623 L
s
0 0 0 r
.87117 .28475 m
.87166 .28692 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1784 .2502 m
.17876 .24567 L
s
.17778 .26866 m
.17854 .25077 L
s
0 0 0 r
.87241 .31351 m
.87256 .31317 L
s
.17389 .28735 m
.17313 .28517 L
s
.87154 .25378 m
.87093 .24341 L
s
.87166 .28692 m
.87204 .28584 L
s
.255 .412 .882 r
.17837 .24397 m
.1784 .2502 L
s
.17741 .27324 m
.1784 .2502 L
s
0 0 0 r
.87166 .25321 m
.87107 .24283 L
s
.255 .412 .882 r
.17827 .24028 m
.17837 .24397 L
s
.86754 .27189 m
.86805 .27593 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86633 .24381 m
.86863 .29759 L
s
.86617 .24438 m
.86847 .29812 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86791 .2997 m
.86863 .29759 L
s
0 0 0 r
.87204 .28584 m
.87222 .28108 L
s
.87204 .28584 m
.87238 .28053 L
s
.255 .412 .882 r
.17741 .27324 m
.17778 .26866 L
s
0 0 0 r
.87186 .26109 m
.87154 .25378 L
s
.255 .412 .882 r
.17804 .23857 m
.17827 .24028 L
s
.17761 .265 m
.17763 .26811 L
s
0 0 0 r
.87198 .26053 m
.87166 .25321 L
s
.87222 .28108 m
.8722 .27264 L
s
.8722 .27264 m
.87186 .26109 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17761 .265 m
.17716 .2591 L
s
.17717 .27526 m
.17741 .27324 L
s
.86805 .27593 m
.86853 .27687 L
s
0 0 0 r
.87238 .28053 m
.87233 .27209 L
s
.87233 .27209 m
.87198 .26053 L
s
.87132 .22607 m
.87116 .22842 L
s
.17388 .2404 m
.17406 .23194 L
s
.17349 .25195 m
.17388 .2404 L
s
.255 .412 .882 r
.17683 .27675 m
.17717 .27526 L
s
0 0 0 r
.17406 .23194 m
.17408 .22653 L
s
.17317 .25928 m
.17349 .25195 L
s
.1738 .23983 m
.174 .23135 L
s
.1734 .25138 m
.1738 .23983 L
s
.255 .412 .882 r
.17782 .23999 m
.17804 .23857 L
s
.17779 .23942 m
.17804 .23857 L
s
0 0 0 r
.174 .23135 m
.17408 .22653 L
s
.17309 .25872 m
.1734 .25138 L
s
.17261 .26974 m
.17317 .25928 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86739 .23812 m
.86861 .26639 L
s
.86719 .23984 m
.86753 .23583 L
s
.86853 .27687 m
.86873 .27578 L
s
.86744 .23755 m
.86866 .26584 L
s
0 0 0 r
.17253 .26919 m
.17309 .25872 L
s
.255 .412 .882 r
.17649 .27456 m
.17683 .27675 L
s
0 0 0 r
.17408 .22653 m
.17405 .22535 L
s
.255 .412 .882 r
.17757 .24456 m
.17782 .23999 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17716 .2591 m
.17716 .25541 L
s
.17716 .2591 m
.17713 .25485 L
s
.17754 .24399 m
.17779 .23942 L
s
.86873 .27578 m
.86877 .2721 L
s
.86873 .27578 m
.86883 .27156 L
s
0 0 0 r
.17214 .27601 m
.17261 .26974 L
s
.17405 .22535 m
.17391 .22726 L
s
.255 .412 .882 r
.17735 .2497 m
.17757 .24456 L
s
0 0 0 r
.8715 .22856 m
.8718 .23706 L
s
.17208 .27546 m
.17253 .26919 L
s
.255 .412 .882 r
.17716 .25541 m
.17735 .2497 L
s
.17732 .24913 m
.17754 .24399 L
s
.86861 .26639 m
.86877 .2721 L
s
0 0 0 r
.87129 .22313 m
.8715 .22856 L
s
.255 .412 .882 r
.1765 .27088 m
.17649 .27456 L
s
.17713 .25485 m
.17732 .24913 L
s
.86866 .26584 m
.86883 .27156 L
s
.17672 .26572 m
.17668 .26517 L
s
.17661 .2683 m
.17672 .26572 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87132 .22607 m
.87357 .27762 L
s
.8713 .22666 m
.87354 .27817 L
s
.17184 .27805 m
.17214 .27601 L
s
.255 .412 .882 r
.17657 .26775 m
.1765 .27088 L
s
.17668 .26517 m
.17657 .26775 L
s
0 0 0 r
.17391 .22726 m
.17367 .23345 L
s
.8712 .22195 m
.87129 .22313 L
s
.17184 .27805 m
.17208 .27546 L
s
.255 .412 .882 r
.86701 .2295 m
.86749 .23354 L
s
0 0 0 r
.87123 .22445 m
.8712 .22195 L
s
.87115 .22386 m
.8712 .22195 L
s
.87358 .27597 m
.87354 .27817 L
s
.1718 .2764 m
.17184 .27805 L
s
.255 .412 .882 r
.86735 .23181 m
.86891 .26809 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87147 .23124 m
.87123 .22445 L
s
.255 .412 .882 r
.86728 .23123 m
.86884 .26754 L
s
0 0 0 r
.17247 .26045 m
.17266 .25618 L
s
.17234 .26359 m
.17247 .26045 L
s
.87137 .23066 m
.87115 .22386 L
s
.17266 .25618 m
.17254 .25932 L
s
.17199 .27157 m
.1718 .2764 L
s
.255 .412 .882 r
.86884 .26754 m
.86904 .26975 L
s
0 0 0 r
.87147 .23124 m
.87324 .27209 L
s
.17238 .26303 m
.17199 .27157 L
s
.17462 .21886 m
.17568 .21471 L
s
.17254 .25932 m
.17238 .26303 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87137 .23066 m
.87315 .27153 L
s
.255 .412 .882 r
.17666 .26332 m
.17683 .26017 L
s
.17655 .26592 m
.17666 .26332 L
s
.1765 .26797 m
.17655 .26592 L
s
.17679 .26221 m
.17683 .26017 L
s
.17661 .26537 m
.17679 .26221 L
s
.17674 .26631 m
.1765 .26797 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86947 .28113 m
.86964 .28429 L
s
.86964 .28429 m
.86969 .28636 L
s
.86947 .28113 m
.86951 .2832 L
s
.86951 .2832 m
.86969 .28636 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17736 .26355 m
.17812 .24571 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17674 .26631 m
.17707 .2626 L
s
0 0 0 r
.87281 .26986 m
.87324 .27209 L
s
.255 .412 .882 r
.86611 .22805 m
.86668 .23441 L
s
.86668 .23441 m
.86717 .24278 L
s
.86717 .24278 m
.86739 .248 L
s
.17755 .25626 m
.17707 .2626 L
s
.86592 .22748 m
.86651 .23383 L
s
.86701 .24222 m
.86651 .23383 L
s
0 0 0 r
.86956 .21425 m
.87052 .23657 L
s
.255 .412 .882 r
.86739 .248 m
.86757 .25527 L
s
.86701 .24222 m
.86723 .24743 L
s
.17755 .25626 m
.17803 .24787 L
s
0 0 0 r
.86935 .21366 m
.87052 .23657 L
s
.255 .412 .882 r
.86723 .24743 m
.8674 .25471 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86745 .25939 m
.86757 .25527 L
s
0 0 0 r
.17653 .21234 m
.17845 .20819 L
s
.255 .412 .882 r
.86726 .25883 m
.8674 .25471 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17795 .25294 m
.17827 .24547 L
s
0 0 0 r
.17161 .29548 m
.17501 .21709 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17122 .2971 m
.17176 .29494 L
s
.17502 .26305 m
.17728 .21056 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86494 .20476 m
.86655 .20807 L
s
.86655 .20807 m
.86956 .21425 L
s
.17529 .26249 m
.17756 .20997 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17176 .29494 m
.17516 .21649 L
s
.87198 .27028 m
.87276 .29237 L
s
.87198 .27028 m
.87296 .29291 L
s
.17426 .26472 m
.17529 .26249 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86929 .23685 m
.87059 .26695 L
s
.86814 .24848 m
.86994 .25187 L
s
.17377 .2863 m
.1742 .28196 L
s
.17377 .2863 m
.17387 .28955 L
s
.18005 .2159 m
.18115 .2072 L
s
.17919 .22777 m
.18005 .2159 L
s
.1742 .28196 m
.17431 .28521 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86835 .28428 m
.86996 .28729 L
s
.86996 .28729 m
.87296 .29291 L
s
.86603 .20654 m
.86944 .2859 L
s
.86637 .20713 m
.86978 .28644 L
s
.18115 .2072 m
.18258 .20167 L
s
.17886 .23531 m
.17919 .22777 L
s
.18043 .21531 m
.18156 .20661 L
s
.17956 .22719 m
.18043 .21531 L
s
.17387 .28955 m
.17431 .28521 L
s
.18156 .20661 m
.18258 .20167 L
s
.17924 .23474 m
.17956 .22719 L
s
.17875 .24609 m
.17886 .23531 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18258 .20167 m
.18348 .20049 L
s
.17914 .24553 m
.17924 .23474 L
s
.17875 .24609 m
.17922 .25256 L
s
.18348 .20049 m
.18426 .20309 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17914 .24553 m
.17963 .252 L
s
.18426 .20309 m
.18494 .20948 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17922 .25256 m
.18032 .25469 L
s
.255 .412 .882 r
.85674 .21457 m
.85704 .21292 L
s
0 0 0 r
.18542 .19813 m
.18754 .19578 L
s
.17963 .252 m
.18032 .25469 L
s
.255 .412 .882 r
.85696 .21988 m
.85744 .22244 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18032 .25469 m
.18122 .25358 L
s
.255 .412 .882 r
.85763 .23584 m
.8582 .24051 L
s
.85808 .24652 m
.85829 .24272 L
s
.85763 .23584 m
.85808 .24652 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18122 .25358 m
.18233 .24865 L
s
.18233 .24865 m
.18365 .2399 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19091 .19608 m
.19169 .19169 L
s
.19091 .19608 m
.19138 .19931 L
s
.18056 .27986 m
.18255 .27772 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18203 .27825 m
.18542 .19813 L
s
.18255 .27772 m
.18593 .19754 L
s
.19169 .19169 m
.19217 .19492 L
s
.19138 .19931 m
.19217 .19492 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18931 .2641 m
.19058 .21841 L
s
.18804 .26517 m
.19058 .21841 L
s
.18867 .26464 m
.18963 .24146 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18804 .26517 m
.18835 .27239 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18835 .27239 m
.18931 .2641 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2045 .22687 m
.2049 .21697 L
s
.20449 .22676 m
.2045 .22687 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20472 .22144 m
.20563 .21819 L
s
.2045 .22687 m
.2052 .22905 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76884 .19327 m
.76982 .18684 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74165 .14253 m
.74342 .14695 L
s
.74008 .14613 m
.74165 .14253 L
s
.74187 .15056 m
.74342 .14695 L
s
.74008 .14613 m
.74187 .15056 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74208 .21909 m
.74242 .1707 L
s
.74242 .1707 m
.74545 .21984 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72278 .13821 m
.72639 .143 L
s
.72639 .143 m
.72824 .14741 L
s
.72824 .14741 m
.72855 .15952 L
s
.71567 .13674 m
.72278 .13821 L
s
.72681 .15915 m
.72845 .15548 L
s
.72691 .1632 m
.72855 .15952 L
s
.74309 .19501 m
.74377 .21947 L
s
.72339 .16246 m
.72681 .15915 L
s
.71216 .14006 m
.71567 .13674 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71465 .1688 m
.72339 .16246 L
s
.70842 .13531 m
.7088 .15151 L
s
.70842 .13531 m
.71044 .14375 L
s
.71044 .14375 m
.71216 .14006 L
s
.7235 .16651 m
.72691 .1632 L
s
.71475 .17287 m
.7235 .16651 L
s
.72754 .18757 m
.72908 .1798 L
s
.72908 .1798 m
.7295 .19609 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7088 .15151 m
.71044 .14375 L
s
.74399 .22765 m
.74545 .21984 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74208 .21909 m
.74399 .22765 L
s
.72588 .19129 m
.72754 .18757 L
s
.72754 .18757 m
.7295 .19609 L
s
.69167 .13231 m
.69919 .13361 L
s
.72244 .19466 m
.72588 .19129 L
s
.71111 .17218 m
.71465 .1688 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71121 .17626 m
.71475 .17287 L
s
.68795 .13573 m
.69193 .14448 L
s
.68211 .13075 m
.68795 .13573 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70947 .18001 m
.71121 .17626 L
s
.71524 .19329 m
.72244 .19466 L
s
.70937 .17593 m
.71111 .17218 L
s
.69167 .13231 m
.69289 .18946 L
s
.69356 .13263 m
.69479 .18976 L
s
.70937 .17593 m
.70957 .1841 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67823 .13016 m
.68211 .13075 L
s
.7115 .18852 m
.71524 .19329 L
s
.67441 .13364 m
.67823 .13016 L
s
.67245 .13336 m
.67823 .13016 L
s
.70957 .1841 m
.7115 .18852 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37345 .12923 m
.38536 .1276 L
s
.6726 .14151 m
.67441 .13364 L
s
.67063 .14123 m
.67245 .13336 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6726 .14151 m
.67345 .18662 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41432 .09582 m
.42892 .09443 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66591 .16326 m
.66608 .16396 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41944 .18137 m
.42055 .0952 L
s
.42154 .18119 m
.42264 .095 L
s
.68713 .18857 m
.69479 .18976 L
s
.39747 .1261 m
.40979 .12474 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66608 .16396 m
.66612 .16609 L
s
.66805 .16485 m
.66807 .1663 L
s
0 0 0 r
.67063 .14123 m
.67147 .18635 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64224 .12545 m
.65646 .12714 L
s
.38093 .15262 m
.39913 .15042 L
s
.61938 .12319 m
.63399 .12457 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66549 .18558 m
.67345 .18662 L
s
.255 .412 .882 r
.66077 .19779 m
.66142 .1969 L
s
0 0 0 r
.42643 .12724 m
.43069 .12279 L
s
.43069 .12279 m
.43493 .12244 L
s
.42212 .13581 m
.42643 .12724 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3774 .12867 m
.38995 .21336 L
s
.38995 .21336 m
.40566 .12518 L
s
.39016 .20088 m
.40361 .1254 L
s
.596 .1214 m
.61093 .12248 L
s
.43493 .12244 m
.43913 .12621 L
s
.43493 .12244 m
.44126 .12606 L
s
.43913 .12621 m
.44332 .13411 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62567 .12376 m
.62626 .16899 L
s
.62776 .12396 m
.62836 .16918 L
s
.64837 .12615 m
.64928 .18367 L
s
.6504 .12639 m
.65133 .18389 L
s
.44126 .12606 m
.44546 .13397 L
s
.255 .412 .882 r
.42639 .16693 m
.4279 .16084 L
s
.5684 .13269 m
.56992 .13276 L
s
0 0 0 r
.44332 .13411 m
.44533 .14631 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44546 .13397 m
.44748 .14617 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57224 .12011 m
.57661 .12441 L
s
.57224 .12011 m
.57878 .12451 L
s
.56789 .11993 m
.57224 .12011 L
s
.64311 .18301 m
.65133 .18389 L
s
.47143 .12429 m
.47581 .11999 L
s
.47581 .11999 m
.48017 .11982 L
s
.46926 .12439 m
.47581 .11999 L
s
.57878 .12451 m
.58318 .13296 L
s
.56355 .12387 m
.56789 .11993 L
s
.56136 .12379 m
.56789 .11993 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57661 .12441 m
.58101 .13284 L
s
.46486 .13282 m
.46926 .12439 L
s
.48017 .11982 m
.48451 .12378 L
s
.48017 .11982 m
.4867 .12371 L
s
.46703 .13271 m
.47143 .12429 L
s
.55921 .13195 m
.56355 .12387 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58318 .13296 m
.58544 .14543 L
s
.55702 .13188 m
.56136 .12379 L
s
.52844 .11905 m
.54382 .11923 L
s
.48451 .12378 m
.48885 .13187 L
s
.50425 .11918 m
.51964 .11904 L
s
.58101 .13284 m
.58327 .14532 L
s
.4867 .12371 m
.49104 .13181 L
s
.4626 .14529 m
.46486 .13282 L
s
.255 .412 .882 r
.55993 .16359 m
.55995 .16705 L
s
0 0 0 r
.46477 .14518 m
.46703 .13271 L
s
.62637 .17727 m
.62836 .16918 L
s
.44525 .15457 m
.44533 .14631 L
s
.4474 .15443 m
.44748 .14617 L
s
.62426 .17708 m
.62626 .16899 L
s
.4217 .16876 m
.42583 .17669 L
s
.55708 .14426 m
.55921 .13195 L
s
.55488 .14419 m
.55702 .13188 L
s
.48885 .13187 m
.49099 .14418 L
s
.49104 .13181 m
.49319 .14412 L
s
.58544 .14543 m
.5855 .15369 L
s
.44298 .16712 m
.44525 .15457 L
s
.41314 .18194 m
.42154 .18119 L
s
.58327 .14532 m
.58333 .15358 L
s
.46254 .15356 m
.4626 .14529 L
s
.44513 .16698 m
.4474 .15443 L
s
.62008 .18087 m
.62637 .17727 L
s
.46471 .15345 m
.46477 .14518 L
s
.62008 .18087 m
.62426 .17708 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64762 .20835 m
.64961 .20441 L
s
.64961 .20441 m
.65173 .20879 L
s
.64974 .21274 m
.65173 .20879 L
s
.42583 .17669 m
.43002 .1805 L
s
.60502 .1673 m
.60939 .1759 L
s
.46254 .15356 m
.46462 .16587 L
s
.46471 .15345 m
.4668 .16577 L
s
.64762 .20835 m
.64974 .21274 L
s
.55708 .14426 m
.55711 .15253 L
s
.255 .412 .882 r
.55823 .16247 m
.55995 .16705 L
s
0 0 0 r
.61584 .18053 m
.62008 .18087 L
s
.43861 .17571 m
.44298 .16712 L
s
.55488 .14419 m
.55491 .15247 L
s
.49096 .15245 m
.49099 .14418 L
s
.49316 .1524 m
.49319 .14412 L
s
.44075 .17557 m
.44513 .16698 L
s
.60939 .1759 m
.61584 .18053 L
s
.43002 .1805 m
.43429 .18017 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49246 .16029 m
.49247 .15747 L
s
.4903 .15899 m
.4903 .15748 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43429 .18017 m
.43861 .17571 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58125 .1659 m
.58333 .15358 L
s
.58343 .16601 m
.5855 .15369 L
s
.60242 .12184 m
.60301 .17961 L
s
.60456 .12199 m
.60515 .17975 L
s
.43429 .18017 m
.44075 .17557 L
s
.55711 .15253 m
.55936 .16503 L
s
.55491 .15247 m
.55717 .16497 L
s
.48871 .16495 m
.49096 .15245 L
s
.49091 .16489 m
.49316 .1524 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57913 .1741 m
.58343 .16601 L
s
.59654 .17919 m
.60515 .17975 L
s
.57695 .174 m
.58125 .1659 L
s
.46462 .16587 m
.46892 .17398 L
s
.4668 .16577 m
.47111 .17389 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55936 .16503 m
.5638 .17349 L
s
.55717 .16497 m
.5616 .17341 L
s
.48427 .1734 m
.48871 .16495 L
s
.5726 .17798 m
.57913 .1741 L
s
.48647 .17333 m
.49091 .16489 L
s
.5726 .17798 m
.57695 .174 L
s
.46892 .17398 m
.47546 .17787 L
s
.47111 .17389 m
.47546 .17787 L
s
.5638 .17349 m
.56822 .17781 L
s
.5616 .17341 m
.56822 .17781 L
s
.47986 .17771 m
.48427 .1734 L
s
.56822 .17781 m
.5726 .17798 L
s
.47986 .17771 m
.48647 .17333 L
s
.47546 .17787 m
.47986 .17771 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53723 .11912 m
.53739 .20633 L
s
.53503 .1191 m
.53517 .20631 L
s
.51071 .2063 m
.51084 .11909 L
s
.51294 .20629 m
.51304 .11907 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50405 .20638 m
.51294 .20629 L
s
.5285 .20626 m
.53739 .20633 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AD0
ojHA1P00000L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0[Jf]WP2`h>H10?ooo`00/@2`h>H50:f][@80ojHA
00<0[Jf]0?nV4@3oYQ404`3oYQ4500000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ405P3o
YQ4200000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400:0?bP40H0[Jf]T`2`
h>H10?ooo`00YP2`h>H60:f][@`0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4200000080ojHA00<0[Jf]
0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400@0?bP40D0[Jf]SP2`h>H10?ooo`00X@2`h>H50:f]
[A80ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?ooo`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3o
YQ405P3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0[Jf]00<0[Jf]QP2`h>H10?ooo`00V@2`h>H40:f][@030?nT4@2][Jd0ojHA01P0ojHA
00<0[Jf]0?nV4@3oYQ405P3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jf20;3PiP40oooo002E0;3PiP@0[Jf]1@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA0P0000020?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F
0?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l02`3fW0l40:f][GX0/>3V0@3oool008h0/>3V102][Jd<0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00l0mY`?102][Jef0;3PiP40oooo002:0;3PiP@0
[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA0P0000020?nV4@03
0:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0
[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0F0?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][G00/>3V0@3oool008@0/>3V0`2]
[Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3o
YQ4200000080ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV40050?nV40T000000`3o
YQ0900000080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01H0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA01@0ojHA00@0[Jf]
00000000000000003P2][Jd2000000X0[Jf]00<000000:f][@0000003P2][Jd3000000@0[Jf]1`3o
YA04000000@0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd6
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F
0?nV4@8000000P3oYQ400`2][Jd0ojHA00000002000000<0ojHA3P2][Jd2000000<0ojHA0P000000
0`3oYQ40[Jf]0?nV40090?nV408000002P3oYQ000`000000ojH@000000050?nV40030:f][@3oYA00
ojD@00@0ojD@0P0000030?nU408000000P3oYA0:0:f][@D000000`2][Jd4000001D0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][JeX
0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ403P3oYQ44000000@0ojHA0P0000020:f][@8000000`2][Jd20000
00030:f][@3oYQ40ojHA00/0ojHA0P0000050?nV4@80000000<0[Jf]0?nV403oYQ00203oYQ020000
00X0ojH@00<000000?nV400000001@3oYQ000`2][Jd0ojD@0?nU40030?nU408000001@3oYA020000
00/0ojD@0P0000030?nU40030:f][@3oXa00oj<@0080oj<@0P2][Jd500000080[Jf]3P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f]
[FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@D000001P2][Jd2000000030?nV4@000000[Jf]00D0
ojHA0P00000<0?nV4@8000001P3oYQ400`000000ojHA0000000:0?nV408000002P3oYQ000`000000
ojH@000000050?nV40030:f][@3oYA00ojD@0080ojD@0P0000060?nU408000002`3oYA02000000<0
ojD@00<0[Jf]0?nS403oXa00103oXa02000000D0oj<@00<0[Jf]0000000000001P0000000`2][Jd0
oj<@0?nS40020?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40000000H000001P2][Jd20?nV4@800000
1P3oYQ42000000030?nV4@000000[Jf]00D0ojHA0P00000<0?nV4@8000001`3oYQ42000000X0ojH@
0P00000:0?nV40030000003oYQ00000000D0ojH@00@0[Jf]0?nU403oYA00ojD@0P0000080?nU4080
00002P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00103oXa02000000T0oj<@0P0000040?nS40L0
[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40
oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA
1P2][Jd00`000000ojHA0?nV4@090?nV4@8000001`3oYQ43000000030?nV4@2][Jd0ojHA00D0ojHA
0P00000:0?nV4@800000203oYQ400`000000[Jf]000000090?nV408000002P3oYQ000`000000ojH@
000000050?nV40040:f][@3oYA00ojD@0?nU40800000203oYA02000000X0ojD@0P0000030?nU4003
0:f][@3oXa00oj<@00@0oj<@0P0000090?nS40800000203oXa00102][Jd0o:0@0?bP402][Jd40000
00030:f][@3lX100o:0@0100o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0@0?nV4@D0[Jf]0P3oYQ401@2][Jd0ojHA0?nV4@3oYQ40000000/0ojHA0P0000070?nV
4@<0000000<0ojHA0:f][@3oYQ401@3oYQ42000000X0ojHA0P0000090?nV4@030000003oYQ000000
00P0ojH@0P00000:0?nV40030000003oYQ00000000D0ojH@00<0[Jf]0?nU403oYA000P0000050?nU
4003045Yh@3oYA00ojD@0080ojD@0P0000090?nU408000000`3oYA000`2][Jd0oj<@0?nS40040?nS
408000002@3oXa02000000P0oj<@00<0[Jf]0?bP400000000P0000030?bP40030000002][Jd0[Jf]
0080000000<0[Jf]0?bP403lX1002`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0
ojHA00D0[Jf]0?nV4@3oYQ40ojHA0000000;0?nV4@8000001`3oYQ4200000080ojHA00<0[Jf]0?nV
4@3oYQ401@3oYQ42000000T0ojHA0P0000090?nV4@030000003oYQ00000000P0ojH@0P00000:0?nV
40030000003oYQ00000000D0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU408000002@3oYA020000
00<0ojD@00<0[Jf]0?nS403oXa00103oXa02000000T0oj<@0P0000080?nS40040:f][@3lX1000000
000000D0o:0@00<000000?bP40000000100000030:f][@030?bP40000000o:0@00D0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK
0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`00
0000ojHA0?nV4@080?nV4@8000001`3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ420000
00P0ojHA0P00000:0?nV4@030:f][@000000000000P0ojH@0P00000:0?nV40030000003oYQ000000
00D0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU40030000003oYA00000000P0ojD@0P0000030?nU
40030:f][@3oXa00oj<@00@0oj<@0P0000090?nS40800000203oXa00102][Jd000000?bP40000006
0?bP40<000001P3lX100102][Jd000000:f][@2][Jd200000080o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^
0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D
0?nT4@030:f][@3oYQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40
ojHA00P0ojHA0P0000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42
000000X0ojHA00<0[Jf]000000000000203oYQ02000000X0ojH@00<000000?nV400000001@3oYQ00
102][Jd0ojD@00000000000;0?nU40030000003oYA00000000P0ojD@0P0000030?nU40030:f][@3o
Xa00oj<@00@0oj<@0P0000090?nS40800000203oXa000`2][Jd00000000000070?bP40<000001`3l
X1000`000000o:0@000000020?bP40<0000000<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A102][JdG0?nV4@030:f][@3oYQ40
ojHA0080ojHA00<000000?nV4@3oYQ40203oYQ42000000L0ojHA0P0000020?nV4@030:f][@3oYQ40
ojHA00D0ojHA0P0000080?nV4@8000002P3oYQ40102][Jd000000?nV400000070?nV408000002P3o
YQ000`000000ojH@000000050?nV40040:f][@3oYA000000000000`0ojD@0P0000080?nU40800000
0`3oYA000`2][Jd0oj<@0?nS40040?nS408000002@3oXa02000000P0oj<@00<0[Jf]000000000000
203lX102000000L0o:0@0`0000040?bP40030:f][@000000[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@3oYQ401`3oYQ42000000P0ojHA0P00
00000`3oYQ40[Jf]0?nV4@080?nV4@8000001P3oYQ42000000/0ojHA00@0[Jf]0?nV400000000000
1`3oYQ02000000X0ojH@00<000000?nV400000001@3oYQ00102][Jd0ojD@00000000000<0?nU4003
0000003oYA00000000L0ojD@0P0000030?nU40030:f][@3oXa00oj<@00@0oj<@0P0000090?nS4080
0000203oXa000`2][Jd00000000000080?bP408000001`3lX102000000D0o:0@00<0[Jf]0?JL3`00
00000`3fW0l30:f][@030000003fW0l0mY`?00/0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA0080ojHA00<000000?nV4@3oYQ401`3oYQ42000000P0ojHA0P0000000`3oYQ40[Jf]
0?nV4@080?nV4@8000001P3oYQ42000000/0ojHA00@0[Jf]0?nV4000000000001`3oYQ02000000X0
ojH@00<000000?nV400000001@3oYQ00102][Jd0ojD@00000000000<0?nU40030000003oYA000000
00L0ojD@0P0000030?nU40030:f][@3oXa00oj<@00@0oj<@0P0000090?nS40800000203oXa000`2]
[Jd00000000000080?bP408000001`3lX102000000D0o:0@00<0[Jf]0?JL3`0000001P3fW0l00`00
0000[Jf]0:f][@020:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:
3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@070?nV4@800000203oYQ4200000003
0?nV4@2][Jd0ojHA00P0ojHA0P0000060?nV4@8000002`3oYQ40102][Jd0ojH@0000000000070?nV
408000002P3oYQ000`000000ojH@000000050?nV40040:f][@3oYA000000000000`0ojD@00<00000
0?nU400000001`3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00103oXa02000000T0oj<@0P000008
0?nS40030:f][@000000000000P0o:0@0P0000070?bP408000001@3lX100102][Jd0mY`?0?JL3`00
00050?JL3`8000000`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA0080ojHA00<000000?nV4@3oYQ401`3oYQ42000000P0ojHA0P0000000`3oYQ40[Jf]0?nV4@08
0?nV4@8000001P3oYQ42000000/0ojHA00@0[Jf]0?nV4000000000001`3oYQ02000000X0ojH@00<0
00000?nV400000001@3oYQ00102][Jd0ojD@00000000000<0?nU40030000003oYA00000000L0ojD@
0P0000030?nU40030:f][@3oXa00oj<@00@0oj<@0P0000090?nS408000002@3oXa02000000P0o:0@
0P0000070?bP40030000003lX100o:0@00@0o:0@00@0[Jf]0?JL3`3fW0l000001@3fW0l00`000000
mY`?0?JL3`060?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ400P3oYQ46000000P0ojHA0P0000000`3oYQ40[Jf]
0?nV4@080?nV4@8000001P3oYQ42000000/0ojHA00@0[Jf]0?nV4000000000001`3oYQ02000000X0
ojH@00<000000?nV400000001@3oYQ00102][Jd0ojD@00000000000<0?nU40030000003oYA000000
00L0ojD@0P0000030?nU40030:f][@3oXa00oj<@00@0oj<@0P0000090?nS408000002@3oXa020000
00P0o:0@0P0000070?bP40030000003lX100o:0@00@0o:0@00@0[Jf]0?JL3`3fW0l000001@3fW0l0
0`000000mY`?0?JL3`0:0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0
^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP
400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00<0ojHA1@00
00030?nV4@8000002@3oYQ42000000030?nV4@2][Jd0ojHA00P0ojHA0P0000060?nV4@8000002`3o
YQ40102][Jd0ojH@0000000000070?nV408000002P3oYQ000`000000ojH@000000050?nV40040:f]
[@3oYA000000000000`0ojD@00<000000?nU400000001`3oYA02000000<0ojD@00<0[Jf]0?nS403o
Xa00103oXa02000000T0oj<@0P0000090?nS40800000203lX102000000h0o:0@00@0[Jf]0?JL3`3f
W0l000004`3fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2]
[Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA0?nV4@050?nV4@8000002@3oYQ42
000000030?nV4@2][Jd0ojHA00P0ojHA0P0000060?nV4@8000002`3oYQ40102][Jd0ojH@00000000
00070?nV408000002P3oYQ000`000000ojH@000000050?nV40040:f][@3oYA000000000000`0ojD@
00<000000?nU400000001`3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00103oXa02000000T0oj<@
0P0000090?nS40800000203lX102000000h0o:0@00@0[Jf]0?JL3`3fW0l000004`3fW0l00`2][Jd0
k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080
^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA0?nV4@050?nV4@800000
2@3oYQ42000000030?nV4@2][Jd0ojHA00P0ojHA0P0000060?nV4@800000103oYQ480:f][@800000
202][Jd2000000X0[Jf]00<000000:f][@0000001`2][Jd00`000000[Jf]000000030:f][@P0ojD@
00<000000?nU400000001`3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00103oXa02000000T0oj<@
0P0000090?nS40800000203lX102000000h0o:0@00@0[Jf]0?JL3`00000000004`3fW0l00`2][Jd0
k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0
^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ40
1@3oYQ42000000T0ojHA0P0000000`3oYQ40[Jf]0?nV4@060?nV4@80[Jf]0P0000060:f][@800000
102][Jd70?nV4@030:f][@000000000000P0ojH@0P00000:0?nV40030000003oYQ00000000D0ojH@
00D0[Jf]0?nU40000000ojD@000000030?nU40P0[Jf]00<000000:f][@0000001@2][Jd20?nU4080
00000`3oYA000`2][Jd0oj<@0?nS40040?nS408000002@3oXa02000000T0oj<@0P0000080?bP4080
00003P3lX100102][Jd0mY`?00000000000C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF
3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3P
iP40oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA0?nV4@050?nV4@800000203oYQ400`2][Jd0
0000000000090:f][@030?nV4@000000000000P0ojHA0P00000:0?nV4@030:f][@000000000000P0
ojH@0P00000:0?nV40030000003oYQ00000000D0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU4003
0000003oYA00000000H0ojD@0P2][Jd2000000P0[Jf]0P3oXa02000000T0oj<@0P0000090?nS4080
0000203lX102000000h0o:0@00<0[Jf]000000000000503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80
[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`
h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@
00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@030?nV4@030000003oYQ40ojHA00@0ojHA00<000000?nV4@00
0000202][Jd01@3oYQ4000000000003oYQ40[Jf]00P0ojHA0P0000080?nV4@8000002P3oYQ420000
00T0ojH@0P00000:0?nV40030000003oYQ00000000D0ojH@00H0[Jf]0?nU403oYA0000000?nU4000
00090?nU40030000003oYA00000000P0ojD@0P0000030?nU40030:f][@3oXa00oj<@0080oj<@0P2]
[Jd2000000H0[Jf]0`3oXa02000000L0oj<@00@0@FWQ0?nS4000000000002@3lX102000000d0o:0@
00<000000?JL3`000000503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0
303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA
0P2][Jd00`000000[Jf]0:f][@030:f][@8000002P3oYQ42000000030?nV4@2][Jd0ojHA00L0ojHA
0P0000080?nV4@8000002P3oYQ42000000T0ojH@0P00000;0?nV408000001@3oYQ001P2][Jd0ojD@
0?nU40000000ojD@000000T0ojD@00<000000?nU40000000203oYA02000000<0ojD@00<0[Jf]0?nS
403oXa00103oXa02000000H0oj<@0`2][Jd2000000D0[Jf]0`3oXa000`11JN400000000000090?bP
40800000303lX1000`000000[Jf]0000000E0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][Jd=0=^:
3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0
kiP@0>nH400;0>nH4080[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01H0
ojHA1`2][Jd20?nV4@030000003oYQ40ojHA00<0ojHA0P00000:0?nV4@80000000<0ojHA0:f][@3o
YQ401`3oYQ42000000P0ojHA0P0000090?nV4@8000002P3oYQ02000000/0ojH@0P0000050?nV4004
0:f][@3oYA00ojD@0?nU408000002@3oYA000`000000ojD@000000080?nU408000000`3oYA000`2]
[Jd0oj<@0?nS40040?nS408000002@3oXa02000000D0oj<@1@2][Jd00`000000[Jf]0:f][@070?bP
408000002P3lX102000000030?bP40000000mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f]
[@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P03
0:f][@3_V100kiP@00T0kiP@0`2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40403oYQ460:f][@80ojHA00<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0?nV4@030?nV4@80
00002P3oYQ42000000030?nV4@2][Jd0ojHA00H0ojHA0P00000:0?nV4@800000203oYQ42000000X0
ojH@0P00000;0?nV408000001@3oYQ001`2][Jd0ojD@0?nU403oYA0000000?nU400000001`3oYA00
0`000000ojD@000000090?nU408000000`3oYA000`2][Jd0oj<@0?nS40040?nS408000002@3oXa02
000000T0oj<@0P0000020?bP40H0[Jf]00<0o:0@0000000000002@3lX1001@000000o:0@0?bP4000
0000[Jf]01H0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][@T0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0
[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd80?nV4@030:f][@3oYQ40
ojHA00@0ojHA00<000000?nV4@3oYQ400`3oYQ42000000X0ojHA0P0000000`3oYQ40[Jf]0?nV4@06
0?nV4@8000002P3oYQ42000000L0ojHA0P0000000`2][Jd0ojH@0?nV40080?nV408000002`3oYQ02
000000D0ojH@00<0[Jf]0?nU403oYA000P3oYA02000000L0ojD@0P00000:0?nU40<000000P3oYA00
0`2][Jd0oj<@0?nS40040?nS408000002@3oXa02000000T0oj<@0P0000080?bP40030:f][@000000
000000@0[Jf]103lX1001P000000o:0@000000000000o:0@0:f][@T0mY`?00<000000?JL3`3fW0l0
2P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd70=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP
2`2][Jd80=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060?nV4@D0[Jf]3@3oYQ400`2][Jd0ojHA
0?nV4@040?nV4@030000003oYQ40ojHA00<0ojHA0P00000:0?nV4@<0000000<0[Jf]0?nV4@3oYQ40
103oYQ42000000`0ojHA0P0000060?nV4@80000000<0[Jf]0?nV403oYQ00203oYQ02000000/0ojH@
0P0000050?nV40030:f][@3oYA00ojD@00<0ojD@0P0000050?nU40030000003oYA00000000X0ojD@
0`0000020?nU40030:f][@3oXa00oj<@00<0oj<@0P00000:0?nS408000002@3oXa02000000T0o:0@
0P0000040?bP40<0[Jf]00<000000:f][@0000000`3lX1000`2][Jd0mY`?0?JL3`070?JL3`030000
003fW0l0mY`?00X0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@040=^:3@030:f]
[@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40
oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V1000`2][Jd0
kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@060:f][A80ojHA00<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0?nV4@020?nV4@80
00002`3oYQ43000000030:f][@3oYQ40ojHA00@0ojHA0P00000=0?nV4@800000103oYQ4200000003
0?nV4@2][Jd0ojH@00T0ojH@0P00000;0?nV408000001@3oYQ000`2][Jd0ojD@0?nU40040?nU4080
0000103oYA02000000/0ojD@0P000000103oYA0000000?nU402][Jd50?nS408000002P3oXa020000
00T0oj<@0P0000090?bP408000001P3lX10010000000o:0@0000003lX1050:f][@P0mY`?00<00000
0?JL3`3fW0l02P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd4
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]1`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0180oj@A102][JdH0?nV4@030:f][@3o
YQ40ojHA00@0ojHA00<000000?nV4@3oYQ400P3oYQ42000000/0ojHA0P0000000`3oYQ4000000?nV
4@040?nV4@8000003`3oYQ42000000<0ojHA00@000000?nV4@3oYQ40[Jf]2P3oYQ02000000/0ojH@
0P0000050?nV40030:f][@3oYA00ojD@00D0ojD@00@000000?nU403oYA00ojD@0P00000<0?nU4080
000000@0ojD@0000003oYA00[Jf]1@3oXa02000000X0oj<@0P0000090?nS408000002@3lX1020000
00H0o:0@0P0000050?bP40030:f][@3fW0l0[Jf]00<0[Jf]103fW0l00`000000mY`?0?JL3`0:0?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@80fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00h0oj@A102][Jd00`3oY140[Jf]0?nV4@0I0?nV4@030:f][@3oYQ40
ojHA00D0ojHA00@000000?nV4@3oYQ40ojHA0P00000;0?nV4@80000000<0ojHA0:f][@0000000`3o
YQ4200000180ojHA0`0000030?nV4@030:f][@3oYQ00ojH@00P0ojH@0P00000;0?nV408000001@3o
YQ000`2][Jd0ojD@0?nU40060?nU40<000002`3oYA02000000030?nU4000000000000080ojD@0P00
00040?nS408000002`3oXa02000000T0oj<@0P0000090?bP408000001P3lX1000`000000o:0@0?bP
40040?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd00`000000mY`?0?JL3`0:0?JL3`030:f][@3/
UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd30:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28
EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]
0=>73P3CQ`h01P3CQ`h30:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:
0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00D0ojHA00@00000
0?nV4@3oYQ40ojHA0P00000;0?nV4@80000000<0ojHA0:f][@3oYQ400`00000J0?nV4@030:f][@3o
YQ00ojH@00P0ojH@0P00000;0?nV408000001@3oYQ000`2][Jd0ojD@0?nU400F0?nU40<000000`3o
YA000`2][Jd0000000000002000000d0oj<@0P0000090?nS408000002@3lX102000000H0o:0@00<0
00000?bP403lX100103lX100102][Jd0mY`?0?JL3`0000060?JL3`040000002][Jd0[Jf]0:f][@T0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@050?nV4@040000003oYQ40ojHA0?nV4@800000203oYQ43000000<0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV40080?nV408000002`3oYQ02000000D0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS4080000000<0oj<@0000000000002@3oXa020000
00T0o:0@0P0000060?bP40030000003lX100o:0@00@0o:0@00@0[Jf]0?JL3`3fW0l000001P3fW0l0
10000000mY`?0?JL3`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3o
ool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP
400@0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd<0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ401P000000ojHA0?nV4@000000ojHA000000h0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV40080?nV408000002`3oYQ02000000D0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400>0?nS40<000001P3oXa02000000030?nS40000000000000T0
o:0@0P0000060?bP40030000003lX100o:0@00@0o:0@00@0[Jf]0?JL3`00000000001P3fW0l00`00
0000mY`?0?JL3`050?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP11
0;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@030=>73P2][Jd0
kiP@00/0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0:f][@030:f][A00oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@030000003oYQ40ojHA008000003`3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00P0ojH@0P00000;0?nV408000001@3oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@0`0000090?bP408000001P3lX100
0`000000o:0@0?bP40040?bP40040:f][@3fW0l00000000000H0mY`?00<000000?JL3`3fW0l02@3f
W0l30:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd01@3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00`0kiP@00<0[Jf]0?bP403l
X1003`3lX1030:f][A@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@03
0000003oYQ40ojHA008000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00P0
ojH@0P00000;0?nV408000001@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1001@3lX102000000030?bP40000000000000L0o:0@00<000000?bP403l
X1000`3lX100102][Jd000000000000000060?JL3`030000003fW0l0mY`?00X0mY`?00<0[Jf]0>bF
3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2]
[Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h00`000000dhL>0:f][@040=>73P030:f][@3_V100kiP@
00X0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@030000003oYQ40ojHA008000003`3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00P0ojH@0P00000;0?nV408000001@3oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001`3lX1030000
00P0o:0@00<000000?bP403lX1000P3lX100102][Jd000000000000000060?JL3`030000003fW0l0
mY`?00X0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3o
ool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P030000002][Jd0dhL>00@0dhL>00<0
[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]103lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ401`3oYQ4010000000ojHA0000
0000000?0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00203oYQ02000000/0ojH@
0P0000050?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400C0?bP408000000P3lX10010000000mY`?0?JL3`0000060?JL3`030000003fW0l0mY`?00X0
mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f][D80/>3V0@3oool005T0/>3V
00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h2000000H0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2]
[Jd0o:0@0?bP40070?bP40<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ401`3oYQ4010000000ojHA00000000000?0?nV4@030:f][@3oYQ40
ojHA01D0ojHA4P2][Jd2000000/0[Jf]0P00000=0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400E0?bP40<0000000<0[Jf]0?JL3`0000001@3fW0l2000000`0mY`?00<0[Jf]
0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`80[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V00L0[Jf]09MP2`2GH0/0Uf0;0000002]
[Jd0000000L0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]2@3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ401`3o
YQ4300000100ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ00203o
YQ02000000/0ojH@0P0000050?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3o
Xa00oj<@01D0oj<@00<0@FWQ0?nS403oXa000P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0000000D0mY`?0`00000;0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`
h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P0000000`3CQ`h000000=>73P06
0=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@`0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00L0ojHA0`00000<
0?nV4@`0[Jf]5`3oYQ400`2][Jd0ojH@0?nV40080?nV408000002`3oYQ02000000D0ojH@00<0[Jf]
0?nU403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`05
0?JL3`<000002`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3P
iP030:f][@2GH0/0000000800000203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]
0080[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ401`3oYQ4300000080ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00203oYQ02000000/0ojH@0P0000050?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`050?JL
3`<000002`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/000000080
0000203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ450:f][@030000002][Jd000000080
[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00P0ojH@0P00000;0?nV4080
00001@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01@3fW0l3000000/0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF
1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@000000[Jf]0080
0000203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01@0ojHA202][Jd50?nV4@030000003oYQ4000000100ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV40080?nV408000002`3oYQ02000000D0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400?0?nS40030000003oXa00oj<@00@0oj<@202][JdG0?bP4003
0:f][@3fW0l0mY`?00D0mY`?0`00000;0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3K
RPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28EPL0[Jf]08QF1`00
0000[Jf]0480/>3V0@3oool005T0/>3V00<0[Jf]0000002][Jd00P0000080=>73P030:f][@3_V100
kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140
0`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@080?nV4@800000403oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00D0ojH@1@0000070?nV40H000001@3oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00h0oj<@00<000000?nS400000002@3oXa00
102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0[Jf]0?JL3`3fW0l01@3fW0l3000000`0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`070:f][@28EPL0R5H708QF1`2][Jd000000:f][@120;3PiP40oooo001I0;3PiP800000
00<0Uf0;000000000000203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA
00<0[Jf]0?nV4@3oYQ40203oYQ400`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00h0oj<@
00@000000?nS403oXa000000203oXa000`2][Jd0o:0@0?bP40080?bP40H0[Jf]2P3lX1000`2][Jd0
mY`?0?JL3`050?JL3`<00000303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0
fhX=0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@000000
[Jf]0480/>3V0@3oool005P0/>3V0`0000000`2GH0/00000000000080=>73P030:f][@3_V100kiP@
00<0kiP@0P2][Jd60>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102]
[Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ40203oYQ400`000000ojHA0?nV4@0?
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@00l0oj<@0P0000090?nS40030:f][@3lX100o:0@00h0o:0@1`2][Jd3
0?bP40030:f][@3fW0l0mY`?00D0mY`?0`00000<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`02
08QF1`800000@P2`h>H10?ooo`00F02`h>H30000000309MP2`000000000000P0dhL>00@0[Jf]0>nH
403_V100kiP@0P2][Jd80>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY145
0:f][AH0ojHA00<0[Jf]0?nV4@3oYQ40203oYQ400`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@0100oj<@00<000000?nS403oXa001`3oXa000`2][Jd0o:0@0?bP400E0?bP40H0[Jf]1@3fW0l3
000000`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=
0:f][@2iM@/01`2iM@/00`2][Jd0@FWQ08QF1`0208QF1`<00000@@2`h>H10?ooo`00F02`h>H30000
000309MP2`000000000000P0dhL>00@0[Jf]0>nH402][Jd0[Jf]2P3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?00@0[Jf]00@0mY`?0000000000000000303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00/0fhX=0P2][Jd90;Ue2`070:f][@28EPL0R5H708QF1`000000[Jf]000000110;3PiP40
oooo001G0;3PiP@0000000<0Uf0;0000002][Jd0203CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00@0mY`?00D0[Jf]00000000000000000:f][@0;0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][@P0^GD;00L0[Jf]08QF1`28EPL0R5H70000002][Jd0
00000440/>3V0@3oool005L0/>3V100000001@2GH0/000000:f][@3CQ`h0000000D0dhL>0P2][Jd=
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`050?JL3`<0000000<0mY`?0:f][@2][Jd00`2][Jd6
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0:f][@2]
[Jd60;Ue2`070:f][@28EPL0R5H708QF1`000000[Jf]000000110;3PiP40oooo001G0;3PiP@00000
00D0Uf0;0000002][Jd0dhL>000000040=>73P030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00D0mY`?00<000000?JL3`0000001P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/01`2]
[Jd0R5H708QF1`28EPL000000:f][@000000@@2`h>H10?ooo`00E`2`h>H40000000509MP2`000000
[Jf]0=>73P0000000`3CQ`h0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
1@3fW0l2000000/0mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
0P2iM@/00`2][Jd0^GD;0;Ue2`020;Ue2`060:f][@28EPL0R5H708QF1`000000[Jf]0P0000100;3P
iP40oooo001G0;3PiP@0000000H0Uf0;0000002][Jd0dhL>0000003CQ`h20:f][@<0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l02`3fW0l00`2][Jd0k9H>0:f][@02
0:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0
^GD;0;Ue2`2][Jd00`28EPL010000000[Jf]0000000000100;3PiP40oooo001G0;3PiP@0000000H0
Uf0;0000002][Jd0dhL>0000002][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100303lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`060?JL3`030000003fW0l0mY`?00/0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28
EPL00P28EPL400000400/>3V0@3oool005L0/>3V100000001@2GH0/000000:f][@3CQ`h0000000H0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0
oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0
^GD;0P2][Jd408QF1`<00000@02`h>H10?ooo`00E`2`h>H300000080Uf0;00@000000:f][@2][Jd0
00001P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd60?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`<00000@02`h>H10?ooo`00E`2`h>H300000080Uf0;
00@000000:f][@3CQ`h000001P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0
o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0
k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0
R5H70`0000100;3PiP40oooo001G0;3PiP<000000P2GH0/010000000[Jf]0=>73P0000050=>73P03
0:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f]
[@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]0`28EPL300000400/>3V0@3oool005L0
/>3V0`00000209MP2`040000002][Jd0dhL>000000D0dhL>00<0[Jf]0>nH403_V100303_V100102]
[Jd0o:0@0:f][@2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0
^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P28EPL300000400/>3V0@3oool005L0/>3V0`0000001P2G
H0/000000000002][Jd0dhL>000000D0dhL>00<0[Jf]0>nH403_V1002`3_V1030:f][A00o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2]
[JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;
00<0[Jf]08QF1`2][Jd00P28EPL300000400/>3V0@3oool005L0/>3V0`0000001P2][Jd000000000
002][Jd0dhL>000000D0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH402][Jd0o:0@0100
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080
ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100
k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00D0[Jf]08QF
1`28EPL0[Jf]08QF1`0300000400/>3V0@3oool005L0/>3V0`000000102][Jd000000000002][Jd2
000000D0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX100
0`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2
0:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]00<00000@02`
h>H10?ooo`00EP2`h>H40000000409MP2`00000000000:f][@8000001@3CQ`h00`2][Jd0kiP@0>nH
40050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00`0000100;3PiP40oooo001F0;3PiP@0000000@0
Uf0;000000000000[Jf]0P0000050=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd70>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf]
[`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`28EPL0
0P28EPL300000400/>3V0@3oool005H0/>3V1`0000000`2][Jd00000000000050=>73P040:f][@3_
V100kiP@0>nH4080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A
00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@030=^:3@2][Jd0^GD;00P0
^GD;00@0[Jf]08QF1`28EPL0R5H70`0000100;3PiP40oooo001F0;3PiP80000000<0[Jf]00000000
00000P0000000`3CQ`h00000000000050=>73P040:f][@3_V100[Jf]0:f][@/0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/0102][Jd0R5H708QF1`28EPL3
00000400/>3V0@3oool005H0/>3V0P0000000`2][Jd0000000000002000000030=>73P000000dhL>
00D0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f]
[M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f]
[@L0^GD;00@0[Jf]08QF1`28EPL0R5H71000000o0;3PiP40oooo001F0;3PiP80000000<0[Jf]09MP
2`0000000P0000000`3CQ`h000000=>73P040=>73P80[Jf]3P3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2iM@/0102][Jd0R5H708QF1`28
EPL4000003l0/>3V0@3oool005H0/>3V0P0000001`2][Jd0Uf0;09MP2`000000[Jf]0=>73P000000
0`3CQ`h20:f][@030=>73P2][Jd0kiP@00`0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A
0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/0102][Jd0R5H708QF1`28EPL40000
03l0/>3V0@3oool005H0/>3V0P0000001`2][Jd0Uf0;09MP2`000000[Jf]0=>73P0000000P3CQ`h0
1@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT
4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL4000003l0/>3V
0@3oool005H0/>3V0P0000002@2][Jd0Uf0;09MP2`000000[Jf]0=>73P000000dhL>0:f][@040=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/0102][Jd0^GD;0;Ue2`2][Jd3
08QF1`@00000?`2`h>H10?ooo`00EP2`h>H2000000080:f][@2GH0/0Uf0;0000002][Jd0dhL>0000
002][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V
0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0R5H7
1000000o0;3PiP40oooo001F0;3PiP80000000@0[Jf]09MP2`2GH0/000000P2][Jd00`000000dhL>
0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V
0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H71000000o0;3PiP40oooo001F0;3PiP03
0000002][Jd0Uf0;0080Uf0;00@000000:f][@3CQ`h000001P3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF
3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@80R5H71000000o0;3P
iP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00@000000:f][@3CQ`h000001P3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;Vb
YP<0[Jf]kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/20:f][@<0R5H70`00000o0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080
Uf0;00@000000:f][@3CQ`h000001P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f]
[@33_K/03`33_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`<00000?`2`h>H10?ooo`00EP2`h>H02@000000
[Jf]09MP2`2GH0/0[Jf]0000002][Jd0dhL>000000060=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2]
[JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2]
[Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL3000003l0/>3V0@3o
ool005H0/>3V00L000000:f][@2GH0/0[Jf]09MP2`000000[Jf]00P0dhL>00<0[Jf]0>nH403_V100
2P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]
f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]
2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H70:f][@28EPL00`00000o0;3PiP40
oooo001F0;3PiP070000002][Jd0Uf0;0:f][@2GH0/000000:f][@080=>73P030:f][@3_V100kiP@
00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f]
[M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f]
[@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]00<00000?`2`h>H1
0?ooo`00EP2`h>H010000000[Jf]0:f][@2GH0/2000000030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]
0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;
0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^007
0;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00`00
000o0;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_
V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`0
3`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]
1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P0000100;3PiP40oooo
001F0;3PiP800000102GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080[Jf]
102TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l
0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh
00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080
R5H700<000000:f][@000000?`2`h>H10?ooo`00EP2`h>H2000000<0Uf0;00<0[Jf]0=>73P3CQ`h0
1`3CQ`h01P2][Jd0kiP@0:f][@2][Jd0Y9j?045Yh@<0Y9j?00<0@FWQ0:f][@2aZid01@2aZid20:f]
[@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^004045Yh@2d/;40@FWQ045Yh@80[Jf]00<0
fhX=0:f][@2iM@/02@2iM@/00`2][Jd0R5H708QF1`02000000030:f][@000000/>3V03h0/>3V0@3o
ool005H0/>3V0P00000309MP2`030:f][@3CQ`h0dhL>00L0dhL>0P2][Jd40:BNS`06045Yh@2TWXl0
Y9j?045Yh@2][Jd0@FWQ1`2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2@2n^KP2045Yh@80
];2a0P11JN400`2d/;40[Jf]0:f][@0:0;Ue2`070:f][@28EPL0R5H708QF1`000000[Jf]0000000o
0;3PiP40oooo001F0;3PiP8000000`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@2TWXl0@FWQ
00@0Y9j?00<0@FWQ0:BNS`2TWXl00P11JN400`2aZid0@FWQ045Yh@070;6[W@80[Jf]00<0/J^M0:f]
[@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3P
iPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03033_K/30:f][@/0_[Vh0P11JN420;B`/@80@FWQ0P2d/;400`11JN40[Jf]0:f][@080;Ue
2`050:f][@28EPL0R5H708QF1`2][Jd00P00000o0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;
0080Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h20:f][@80Y9j?00<0@FWQ0:BNS`2TWXl01@2TWXl01@11
JN40[Jf]0;6[W@2aZid0@FWQ00T0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0
`kfk0:f][@2n^KP02P2n^KP2045Yh@030:f][@2d/;40];2a0080@FWQ0P2d/;401011JN40];2a0;B`
/@2][Jd70;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P00000o0;3PiP40oooo001F0;3PiP030000
002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h20:f][@04045Yh@2TWXl0Y9j?045Yh@L0
Y9j?00D0@FWQ0;6[W@2aZid0/J^M045Yh@040;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]0;Vb
YP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh
00<0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP2045Yh@050;ji^02][Jd0];2a0;B`/@11JN400P2d/;42
045Yh@80];2a0P2][Jd50;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`
h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>0080dhL>00@0[Jf]
08Z5M@2:QGD0@FWQ0P2TWXl00`11JN40Y9j?0:BNS`050:BNS`03045Yh@2aZid0/J^M0080/J^M00<0
@FWQ0;6[W@2aZid00P11JN450;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`
h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0@FWQ00<0_[Vh00<0@FWQ0;ji^02n^KP00`2n
^KP2045Yh@050;ji^02][Jd0];2a0;B`/@11JN400`2d/;400`11JN40];2a0:f][@040:f][@<0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;
00H0[Jf]0=>73P3CQ`h0dhL>0:f][@11JN4208Z5M@04045Yh@2][Jd0[Jf]045Yh@L0Y9j?00<0[Jf]
0;6[W@2aZid00P2aZid00`11JN40/J^M0;6[W@02045Yh@D0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH3
0:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0
b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh045Yh@030;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00@0@FWQ
0;ji^02n^KP0[Jf]0P2d/;401P11JN40];2a0;B`/@2d/;40@FWQ0:f][@80];2a00@0[Jf]045Yh@2O
Vj00[Jf]0P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00H0[Jf]09MP
2`2GH0/0Uf0;0:f][@3CQ`h20:f][@05045Yh@2:QGD0RXEe08Z5M@11JN400P2TWXl00`11JN40Y9j?
0:BNS`050:BNS`030:f][@2aZid0/J^M0080/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@050;6[W@03
0:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40
b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0
a/2l0`2][Jd;0<>m^`06045Yh@33_K/0`kfk0:f][@2n^KP0@FWQ0`2n^KP2045Yh@@0_[Vh00@0@FWQ
0;ji^02n^KP0[Jf]0P2d/;42045Yh@030;B`/@2][Jd0@FWQ0080];2a00D0@FWQ0:f][@2OVj00@FWQ
09nKX0030:f][@@0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP
2`0209MP2`80[Jf]00<0@FWQ08Z5M@2:QGD00`2:QGD01011JN40Y9j?0:BNS`11JN420:f][@D0Y9j?
00@0[Jf]0;6[W@2aZid0/J^M0P11JN490;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0
[Jf]0<>m^`0:0<>m^`06045Yh@33_K/0`kfk0<>m^`2][Jd0_[Vh0P11JN420;ji^080@FWQ102n^KP0
1011JN40_[Vh0;ji^02][Jd3045Yh@80[Jf]00<0];2a045Yh@2d/;400P11JN400`2][Jd0Wi^P09nK
X00309nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H0
0`2][Jd0Uf0;09MP2`0209MP2`030:f][@11JN40@FWQ00D0RXEe00@0@FWQ0:BNS`2TWXl0@FWQ0P2T
WXl00`2][Jd0@FWQ0:BNS`020:BNS`030:f][@2aZid0/J^M0080@FWQ2P2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36
`;`00`2][Jd0`kfk0<>m^`040<>m^`<0@FWQ0P33_K/01P11JN40`kfk0<>m^`33_K/0[Jf]0;ji^080
@FWQ0P2n^KP2045Yh@@0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0P2d/;401@2][Jd0];2a0;B`/@2d/;40
@FWQ0080];2a00<0@FWQ0:f][@2OVj001@2OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3o
ool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd2045Yh@@0RXEe0P11JN420:BNS`04045Yh@2T
WXl0Y9j?0:BNS`80@FWQ0P2TWXl0102][Jd0@FWQ045Yh@11JN4;0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0
`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0
a/2l00<0[Jf]0<>m^`33_K/00`33_K/01`11JN40`kfk0<>m^`33_K/0@FWQ0<>m^`11JN401033_K/0
0`2][Jd0@FWQ045Yh@020;ji^080@FWQ102n^KP00`11JN40_[Vh0;ji^0030:f][@@0];2a0P11JN40
0`2d/;40@FWQ0:f][@0609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0
102][Jd0Uf0;09MP2`2GH0/20:f][@80@FWQ1@2:QGD01@11JN40Y9j?0:BNS`2TWXl0@FWQ0080Y9j?
0P11JN420:f][@03045Yh@2aZid0@FWQ00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0:f][@030:f][@d0a/2l00<0[Jf]0<>m^`33_K/0
0P33_K/2045Yh@<0`kfk0`11JN440<>m^`030:f][@11JN40@FWQ0080_[Vh0P11JN440;ji^004045Y
h@2n^KP0[Jf]0:f][@H0];2a00D0@FWQ0;B`/@11JN40];2a0:f][@0709nKX0040:f][@28EPL0R5H7
0:f][D00/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd2045Yh@D0RXEe00D0[Jf]0:BN
S`2TWXl0Y9j?045Yh@030:BNS`03045Yh@2TWXl0Y9j?0080@FWQ3@2aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40a/2l00<0[Jf]0<>m^`33_K/00P33_K/2
045Yh@@0`kfk0P11JN440<>m^`030:f][@11JN40@FWQ0080_[Vh0P11JN440;ji^004045Yh@2][Jd0
_[Vh0:f][@H0];2a00D0@FWQ0;B`/@2d/;40];2a0:f][@0709nKX080[Jf]00<0R5H70:f][@2`h>H0
?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@80@FWQ102:QGD00`2][Jd0Y9j?
0:BNS`020:BNS`04045Yh@2TWXl0Y9j?045Yh@80Y9j?00<0@FWQ0:f][@2aZid00P2][Jd40;6[W@03
045Yh@2aZid0/J^M00@0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0
[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36
_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00X0al6l1@2][Jd20<O1_003
0:f][@36`;`0a/2l00X0a/2l1011JN420<K0_0030:f][@33_K/0`kfk0080`kfk0P11JN440<>m^`80
@FWQ1033_K/0102][Jd0@FWQ045Yh@2n^KP2045Yh@030;ji^011JN40_[Vh0080[Jf]00@0@FWQ0;ji
^02n^KP0[Jf]1@2d/;42045Yh@<0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii0:f][@2]
[Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<00`2][Jd0@FWQ045Yh@0408Z5M@030:f][@2TWXl0
Y9j?00<0Y9j?0`11JN420:BNS`03045Yh@2][Jd0/J^M0080/J^M00D0@FWQ0:f][@2][Jd0/J^M045Y
h@060;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/0050:f][@`0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37
`K`00`2][Jd0a/2l0<K0_0090<K0_0<0@FWQ1036`;`00`2][Jd0`kfk0<>m^`020<>m^`80@FWQ1033
_K/2045Yh@@0`kfk0P11JN401`2n^KP0@FWQ045Yh@2n^KP0[Jf]045Yh@2][Jd00P2n^KP01011JN40
_[Vh0;ji^02][Jd:0;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3P
iP40oooo001F0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00<0[Jf]0:BNS`2TWXl0202TWXl00`11JN40
[Jf]0;6[W@020;6[W@05045Yh@2aZid0/J^M0:f][@11JN401P2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00H0_[N/1011JN460;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l
00X0a/2l0P11JN440<K0_0030:f][@33_K/0`kfk0080`kfk0P11JN440<>m^`80@FWQ1033_K/2045Y
h@060;ji^011JN40@FWQ0:f][@2n^KP0@FWQ0`2n^KP01011JN40_[Vh0;ji^02][Jd:0;B`/@030:f]
[@2OVj00Wi^P00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00D0
@FWQ0;6[W@2aZid0/J^M045Yh@030;6[W@04045Yh@2][Jd0[Jf]0:f][@<0/J^M00<0[Jf]0;VbYP2i
/ZH03@2i/ZH00`2][Jd0_[N/0;jg[0090;jg[003045Yh@2n]j`0@FWQ00<0@FWQ0P2n]j`00`2][Jd0
`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`00`2][Jd0
@FWQ045Yh@04045Yh@H0a/2l0P11JN440<K0_0030:f][@33_K/0`kfk0080`kfk0P11JN440<>m^`80
@FWQ1033_K/00`11JN40_[Vh0:f][@02045Yh@80_[Vh00D0@FWQ0;ji^02n^KP0_[Vh045Yh@020;ji
^0040:f][@2d/;40];2a045Yh@L0];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02]
[Jd2071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0
RXEe0:f][@<0RXEe00<0[Jf]045Yh@2TWXl02@2TWXl01@11JN40/J^M0;6[W@2aZid0@FWQ00<0/J^M
00@0@FWQ0;6[W@2aZid0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00T0
_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@030;jg[02][Jd0`KZ`0100`KZ`202][Jd@0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0
[Jf]0`38`K/00`2][Jd0al6l0<O1_00>0<O1_0@0@FWQ1@36`;`2045Yh@D0a/2l0P11JN440<K0_003
0:f][@33_K/0`kfk0080`kfk0P11JN440<>m^`80@FWQ0`33_K/0102][Jd0@FWQ0:f][@2n^KP2045Y
h@80_[Vh00D0@FWQ0;ji^02n^KP0_[Vh045Yh@020;ji^0040:f][@2d/;40];2a045Yh@L0];2a00<0
[Jf]09nKX02OVj000P2][Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H0
0`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD2045Yh@X0Y9j?00<0
[Jf]045Yh@11JN400P11JN430;6[W@03045Yh@2aZid0/J^M00<0/J^M0`2][Jd>0;VbYP030:f][@2n
]j`0_[N/00T0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@040:f][@31^[00`KZ`0<6j/0<0@FWQ
3@31^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0140
al6l00<0@FWQ0<K0_036`;`01036`;`2045Yh@@0a/2l0P11JN440<K0_0030:f][@33_K/0`kfk00<0
`kfk00<0@FWQ0<>m^`33_K/00`33_K/01P11JN40[Jf]0:f][@2][Jd0`kfk045Yh@80_[Vh0P11JN43
0;ji^004045Yh@2n^KP0_[Vh045Yh@80_[Vh00@0[Jf]0;B`/@2d/;40@FWQ1`2d/;400`2][Jd0Wi^P
0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@11JN402`2TWXl01@2][Jd0/J^M0;6[
W@2aZid0@FWQ00<0/J^M00<0@FWQ0;6[W@2aZid0102aZid00`2][Jd0^K:V0:f][@020:f][@/0^K:V
00<0[Jf]0;jg[02n]j`02@2n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ00<0[Jf]0<6j/031^[00
0`31^[04045Yh@X0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^0070<O1^0L0@FWQ1P37`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0140al6l00<0@FWQ0<K0_036`;`0
1036`;`2045Yh@@0a/2l0P11JN440<K0_0030:f][@33_K/0`kfk00@0`kfk1P11JN440<>m^`05045Y
h@2n^KP0_[Vh0;ji^011JN400`2n^KP2045Yh@050;ji^011JN40@FWQ0;ji^02][Jd00P2d/;400`11
JN40];2a0;B`/@050;B`/@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0
/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]2`2TWXl00`2][Jd0
/J^M0;6[W@040;6[W@80@FWQ1P2aZid00`2][Jd0^K:V0;VbYP020;VbYP<0[Jf]202i/ZH00`2][Jd0
_[N/0;jg[0090;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN450<6j/080@FWQ3031^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP02P37`KP00`11JN40al6h0<O1^0070<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00A0<O1_003045Yh@36`;`0a/2l00D0a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@@0
a/2l00<0[Jf]0<>m^`33_K/01@33_K/20:f][@80`kfk00<0@FWQ0<>m^`33_K/00P33_K/01P11JN40
_[Vh0;ji^02n^KP0@FWQ0;ji^0<0@FWQ0P2n^KP2045Yh@040;ji^02][Jd0];2a0;B`/@80@FWQ1P2d
/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl00`2][Jd0/J^M0;6[W@040;6[W@80@FWQ1P2aZid00`2][Jd0^K:V0;VbYP050;VbYP@0[Jf]102i
/ZH00`2][Jd0_[N/0;jg[0090;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN450<6j/080@FWQ3031
^[000`2][Jd0@FWQ045Yh@02045YhA40`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0
[Jf]0<O1^037`KP02P37`KP00`11JN40al6h0<O1^0070<O1^0030:f][@37`KX0al6j00X0al6j4@2]
[JdA0<S1^`030:f][@38`K/0b<6k00`0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`2][Jd0al6l0<O1
_00A0<O1_003045Yh@36`;`0a/2l00D0a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@@0a/2l00<0
[Jf]0<>m^`33_K/00P33_K/30:f][@@0`kfk00<0@FWQ0<>m^`33_K/00P33_K/01@11JN40_[Vh0;ji
^02n^KP0@FWQ00H0_[Vh0P11JN40102n^KP0[Jf]0;B`/@2d/;42045Yh@@0];2a0`2][Jd709nKX005
0:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]
00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0/J^M00@0/J^M0P11JN460;6[W@030:f][@2i/ZH0^K:V
00T0^K:V0`2][Jd00`2i/ZH0[Jf]0;jg[00:0;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0[Jf]045Y
h@31^[001031^[02045Yh@/0`KZ`0`11JN420<>m/`03045Yh@33_K<0`kfc0080`kfc0P11JN4;0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kLI0:f][@03045Yh@2][Jd0[Jf]
01@0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00`0b<6k0P11JN450<S1
^`030:f][@37`K`0al6l0140al6l00<0@FWQ0<K0_036`;`01@36`;`00`11JN40a/2l0<K0_0030<K0
_080@FWQ0`36`;`00`2][Jd0`kfk0:f][@020:f][@L0`kfk00<0@FWQ0<>m^`33_K/00P33_K/3045Y
h@T0_[Vh00L0@FWQ0;ji^02][Jd0];2a045Yh@2d/;40@FWQ00<0];2a00@0[Jf]0;B`/@2d/;40[Jf]
1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0
Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@040;6[W@80
@FWQ1P2aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]2P2n]j`00`11JN40_[N/0;jg[0040;jg[003
0:f][@11JN40@FWQ00@0`KZ`0P11JN4;0<6j/003045Yh@2][Jd0`kfc00<0`kfc00@0@FWQ0<>m/`33
_K<0@FWQ2033_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00:0<O1^003045Yh@37`KP0al6h00L0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@11JN40b<6k0<S1^`@0@FWQ1`38`K/0
0`11JN40b<6k0<S1^`040<S1^`030:f][@37`K`0al6l0140al6l00<0@FWQ0<K0_036`;`01P36`;`0
0`11JN40a/2l0<K0_0020<K0_080@FWQ00<0a/2l0:f][@2][Jd00P2][Jd40<>m^`03045Yh@33_K/0
`kfk0080`kfk00@0@FWQ0<>m^`33_K/0`kfk0`11JN4;0;ji^008045Yh@2n^KP0[Jf]0;B`/@11JN40
];2a045Yh@2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0
[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`02
0:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0102aZid2045Yh@H0/J^M00<0[Jf]
0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][@H0_[N/00<0@FWQ0;jg[02n]j`0102n]j`0
0`2][Jd0@FWQ045Yh@040<6j/080@FWQ2`31^[000`11JN40[Jf]0<>m/`040<>m/`<0@FWQ2033_K<0
0`11JN40`kfc0<>m/`020<>m/`030:f][@11JN40aKje01@0aKje00<0[Jf]0<Jo]`36_kL04P36_kL0
10000000a[ng0<Jo]`2][Jd<0<O1^003045Yh@37`KP0al6h00L0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0:0<S1^`<0@FWQ1`38`K/0102][Jd0@FWQ045Yh@11JN440<S1^`03045Y
h@38`K/0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`2][Jd0al6l0<O1_00A0<O1_003045Y
h@36`;`0a/2l00H0a/2l00<0@FWQ0<K0_036`;`00P2][Jd2045Yh@040:f][@36`;`0a/2l0:f][@D0
`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`11JN40`kfk0<>m^`030<>m^`030:f][@2n^KP0_[Vh00X0
_[Vh00<0@FWQ0:f][@11JN400P2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0
L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BN
S`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0102aZid2045Yh@H0/J^M00<0[Jf]0;Vb
YP2i/ZH03@2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]0P2n]j`00`11JN40_[N/0;jg[0040;jg
[0030:f][@11JN40@FWQ00@0`KZ`0P11JN4:0<6j/080@FWQ00<0[Jf]0<>m/`33_K<01033_K<2045Y
h@L0`kfc0P11JN440<>m/`030:f][@11JN40aKje00`0aKje0`11JN430<Fn]@80@FWQ00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00:0<O1^003045Yh@37`KP0al6h00L0al6h00<0[Jf]0<O1
^P37`KX03`37`KX00`000000al6j0<O1^P020<O1^PL0@FWQ1@38`K/2045Yh@<0b<6k0P11JN450<S1
^`030:f][@11JN40@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/02P38`K/00`2][Jd0al6l0<O1_00A0<O1
_003045Yh@36`;`0a/2l00D0a/2l00@0[Jf]045Yh@2][Jd0[Jf]0P36`;`2045Yh@<0a/2l00<0@FWQ
0<>m^`33_K/01033_K/01011JN40`kfk0<>m^`11JN460<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0P11
JN400`2d/;40[Jf]0;B`/@060;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]
@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2]
[Jd20:BNS`030:f][@2aZid0/J^M00@0/J^M0P11JN450;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`01`2n]j`20:f][@03045Yh@2][Jd0_[N/00@0_[N/00<0[Jf]045Yh@11JN401031
^[02045Yh@X0`KZ`0P11JN400`2][Jd0`kfc0<>m/`040<>m/`80@FWQ1`33_K<3045Yh@<0`kfc00<0
[Jf]045Yh@35_[D02P35_[D2045Yh@<0aKje0P11JN401035_[D0@FWQ045Yh@2][Jd30<Jo]`H0@FWQ
3P36_kL00`2][Jd0al6h0<O1^00:0<O1^003045Yh@37`KP0al6h00L0al6h00<0[Jf]0<O1^P37`KX0
0P37`KX7045Yh@80al6j1`11JN430<O1^P030:f][@38`K/0@FWQ00L0b<6k0P11JN450<S1^`03045Y
h@38`K/0b<6k00<0b<6k00<0[Jf]045Yh@11JN401P38`K/00`11JN40b<6k0<S1^`0:0<S1^`030:f]
[@37`K`0al6l0140al6l00<0@FWQ0<K0_036`;`01@2][Jd00`36`;`0@FWQ0<K0_0030<K0_080@FWQ
0`36`;`2045Yh@H0`kfk0P11JN470<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][Jd80;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f]
[@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd60;6[W@80@FWQ1@2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00T0_[N/00<0@FWQ0;jg[02][Jd00`2][Jd0102n]j`0[Jf]045Y
h@11JN440<6j/080@FWQ2P31^[02045Yh@030:f][@33_K<0`kfc00@0`kfc0P11JN470<>m/`<0@FWQ
0`33_K<3045Yh@T0aKje0P11JN460<Fn]@<0@FWQ00<0[Jf]0<Jo]`36_kL00`36_kL2045Yh@l0a[ng
1011JN450<O1^003045Yh@37`KP0al6h0080al6h00@0@FWQ0<O1^037`KP0al6h0`11JN430<O1^003
0:f][@37`KX0al6j00D0al6j00<0@FWQ0<O1^P37`KX01P37`KX00`11JN40al6j0<O1^P040<O1^P03
0:f][@38`K/0@FWQ00H0b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k0080b<6k00<0[Jf]045Yh@38
`K/01P38`K/00`11JN40b<6k0<S1^`0:0<S1^`030:f][@37`K`0al6l00l0al6l0P2][Jd00`11JN40
[Jf]0:f][@060<K0_003045Yh@36`;`0a/2l0080a/2l0P11JN430<K0_0030:f][@11JN40`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0
L6ii0:f][@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]
1@2aZid2045Yh@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0080;jg[080@FWQ
1@2n]j`20:f][@80@FWQ00@0[Jf]0<6j/031^[00`KZ`0P11JN4;0<6j/080@FWQ1P33_K<2045Yh@L0
`kfc0`11JN430<>m/`<0@FWQ2035_[D2045Yh@L0aKje0`11JN400`2][Jd0a[ng0<Jo]`030<Jo]`80
@FWQ3@36_kL2045Yh@050<Jo]`2][Jd0al6h0<O1^011JN400P37`KP2045Yh@D0al6h00@0@FWQ0<O1
^011JN40@FWQ0P37`KP3045Yh@030<O1^02][Jd0al6j00H0al6j00<0@FWQ0<O1^P37`KX01P37`KX0
0`11JN40al6j0<O1^P040<O1^P030:f][@38`K/0@FWQ00H0b<6k0P11JN4<0<S1^`030:f][@11JN40
b<6k00H0b<6k00<0@FWQ0<S1^`38`K/02P38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`0
0`11JN40a/2l0<K0_0060<K0_003045Yh@36`;`0a/2l0080a/2l0`11JN420<K0_0030:f][@11JN40
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]
09nKX02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?
00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd30;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0080;jg[080@FWQ1P2n]j`0102][Jd0@FWQ045Yh@31^[03
0:f][@80@FWQ0P2][Jd90<6j/080@FWQ1P33_K<00`11JN40`kfc0<>m/`050<>m/`80@FWQ00<0`kfc
045Yh@33_K<00P33_K<00`11JN40aKje045Yh@070<Fn]@80@FWQ2@35_[D2045Yh@030:f][@36_kL0
a[ng00<0a[ng0P11JN4<0<Jo]`80@FWQ0P36_kL0102][Jd0al6h0<O1^037`KP3045Yh@H0al6h0P11
JN460<O1^003045Yh@37`KP0[Jf]00L0al6j00<0@FWQ0<O1^P37`KX01P37`KX00`11JN40al6j0<O1
^P040<O1^P030:f][@38`K/0@FWQ00H0b<6k0P11JN4<0<S1^`030:f][@38`K/0b<6k00@0b<6k0`11
JN450<S1^`03045Yh@38`K/0b<6k00@0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0
@FWQ0<K0_036`;`01P36`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ00@0a/2l045Yh@11JN40@FWQ
4033_K/00`2][Jd0_[Vh0;ji^0060;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00P0_[N/0P11JN460;jg[0030:f][@11JN40@FWQ00@0`KZ`0P11
JN420<6j/0L0[Jf]0`31^[03045Yh@@0`kfc00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@030<>m/`11
JN40`kfc0080`kfc00<0@FWQ0<Fn]@11JN401`35_[D2045Yh@T0aKje0P11JN400`2][Jd0a[ng0<Jo
]`030<Jo]`80@FWQ3036_kL2045Yh@80a[ng00<0[Jf]0<O1^037`KP00P37`KP2045Yh@H0al6h00<0
@FWQ0<O1^037`KP01P37`KP00`11JN40al6h0:f][@060<O1^P03045Yh@37`KX0al6j00H0al6j00<0
@FWQ0<O1^P37`KX01037`KX00`2][Jd0b<6k045Yh@050<S1^`80@FWQ3@38`K/00`2][Jd0b<6k0<S1
^`030<S1^`03045Yh@38`K/0@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`2][Jd0al6l0<O1
_0050:f][@`0al6l00<0[Jf]045Yh@36`;`01P36`;`00`11JN40a/2l0<K0_003045Yh@@0a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H0
0`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid3
0:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0080;jg[080@FWQ1P2n]j`0
0`2][Jd0@FWQ045Yh@040<6j/080@FWQ2@31^[060:f][@80@FWQ0P33_K<00`11JN40`kfc0<>m/`05
0<>m/`80@FWQ00<0`kfc045Yh@33_K<00P33_K<00`11JN40aKje045Yh@070<Fn]@80@FWQ2@35_[D2
045Yh@030:f][@36_kL0a[ng00<0a[ng0P11JN4<0<Jo]`80@FWQ0P36_kL00`2][Jd0al6h0<O1^002
0<O1^080@FWQ1P37`KP00`11JN40al6h0<O1^0060<O1^003045Yh@37`KP0[Jf]00H0al6j00<0@FWQ
0<O1^P37`KX01P37`KX00`11JN40al6j0<O1^P040<O1^P030:f][@38`K/0@FWQ00D0b<6k0P11JN4=
0<S1^`040:f][@38`K/0b<6k0<S1^`80@FWQ00<0b<6k045Yh@38`K/01P38`K/01011JN40b<6k0<S1
^`38`K/60:f][A40al6l00<0[Jf]045Yh@36`;`01P36`;`00`11JN40a/2l0<K0_0080<K0_0030:f]
[@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0
];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f]
[@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]
00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[0080;jg[080@FWQ1P2n]j`00`2][Jd0@FWQ
045Yh@040<6j/0<0@FWQ0`31^[000`11JN40`KZ`0<6j/0050<6j/0050:f][@33_K<0`kfc0<>m/`2]
[Jd00`11JN430:f][@@0`kfc0P11JN420<>m/`06045Yh@33_K<0@FWQ045Yh@35_[D0@FWQ1`35_[D0
0`11JN40aKje0<Fn]@080<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL00`36_kL2045Yh@`0a[ng0P11JN42
0<Jo]`030:f][@37`KP0al6h0080al6h0P11JN460<O1^003045Yh@37`KP0al6h00H0al6h0P11JN40
0`2][Jd0al6j0<O1^P040<O1^P03045Yh@37`KX0al6j00H0al6j00<0@FWQ0<O1^P37`KX01037`KX0
0`2][Jd0b<6k045Yh@050<S1^`80@FWQ3@38`K/01@2][Jd0b<6k0<S1^`11JN40b<6k0080@FWQ1@38
`K/30:f][@04045Yh@2][Jd0[Jf]0:f][@<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0@FWQ
0<K0_0050<K0_080@FWQ2P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0
/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/00P0_[N/0P11JN460;jg[0030:f]
[@11JN40@FWQ00@0`KZ`0`11JN430<6j/080@FWQ1@31^[02045Yh@H0`kfc00@0@FWQ0<>m/`33_K<0
`kfc0`2][Jd2045Yh@<0[Jf]00@0@FWQ0<>m/`11JN40[Jf]0P35_[D00`11JN40aKje0<Fn]@040<Fn
]@03045Yh@35_[D0aKje00P0aKje0P11JN400`2][Jd0a[ng0<Jo]`030<Jo]`80@FWQ3036_kL2045Y
h@80a[ng00<0[Jf]0<O1^037`KP00P37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP01P37`KP2045Y
h@030:f][@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37`KX01P37`KX00`11JN40al6j0<O1^P040<O1
^P030:f][@38`K/0@FWQ00D0b<6k0P11JN4=0<S1^`0300000038`K/0@FWQ0080@FWQ1`2][Jd30<S1
^`03045Yh@38`K/0b<6k00@0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0@FWQ0<K0_0050<K0
_080@FWQ2P36`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`
/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0
_[N/0;jg[0080;jg[080@FWQ1P2n]j`2045Yh@<0`KZ`1011JN401031^[00@FWQ0<6j/031^[02045Y
h@D0`KZ`0P11JN460<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN430<>m/`03045Yh@2][Jd0@FWQ
00<0[Jf]00<0@FWQ0:f][@2][Jd01035_[D00`11JN40aKje0<Fn]@060<Fn]@@0@FWQ00<0[Jf]0<Jo
]`36_kL00`36_kL2045Yh@d0a[ng0P11JN400`36_kL0[Jf]0<O1^0030<O1^080@FWQ1P37`KP00`11
JN40al6h0<O1^0060<O1^080@FWQ00<0[Jf]0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P060<O1
^P03045Yh@37`KX0al6j00@0al6j00<0[Jf]0<S1^`11JN401@38`K/2045Yh@P0b<6k00<0@FWQ0:f]
[@2][Jd00`2][Jd2045Yh@030:f][@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11
JN40b<6k0<S1^`040<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]045Yh@36`;`01@36`;`2045Y
h@X0a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`
/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0
Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0
_[N/0;jg[0080;jg[080@FWQ1P2n]j`2045Yh@D0`KZ`0P11JN420<6j/004045Yh@31^[00`KZ`045Y
h@D0`KZ`0P11JN460<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN430<>m/`04045Yh@33_K<0@FWQ
0:f][@80aKje00<0@FWQ0<Fn]@35_[D0102][Jd00`11JN40[Jf]0:f][@050:f][@@0aKje0`11JN44
0<Jo]`80@FWQ3P36_kL3045Yh@@0al6h0P11JN460<O1^003045Yh@37`KP0al6h00H0al6h0P11JN40
0`2][Jd0al6j0<O1^P040<O1^P03045Yh@37`KX0al6j00H0al6j00<0@FWQ0<O1^P37`KX01037`KX0
0`2][Jd0b<6k045Yh@030<S1^`80[Jf]0P11JN470:f][@80@FWQ1038`K/00`2][Jd0@FWQ045Yh@06
0<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`2][Jd0al6l0<O1_00A
0<O1_080@FWQ1P36`;`00`11JN40a/2l0<K0_0090<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd4
0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3oool0
0640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f]
[@D0^K:V00<0[Jf]0;jg[02n]j`0202n]j`2045Yh@H0_[N/0P11JN4:0<6j/080@FWQ1`31^[000`11
JN40`kfc0<>m/`030<>m/`03045Yh@33_K<0`kfc00D0`kfc0P11JN430<>m/`04045Yh@33_K<0@FWQ
0:f][@80aKje00<0@FWQ0<Fn]@35_[D01035_[D00`11JN40aKje0<Fn]@050<Fn]@/0[Jf]0P11JN44
0:f][@`0a[ng00<0[Jf]045Yh@11JN400P37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP01P37`KP2
045Yh@030:f][@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37`KX00P37`KX40:f][@03045Yh@2][Jd0
[Jf]00H0[Jf]00@0@FWQ0:f][@2][Jd0[Jf]0`38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00P38
`K/00`2][Jd0@FWQ0<S1^`060<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN450<S1^`030:f][@37
`K`0al6l0140al6l0P11JN460<K0_003045Yh@36`;`0a/2l00T0a/2l00<0[Jf]0<>m^`33_K/00P33
_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`
h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[0090;jg[080@FWQ1P2n]j`0
0`11JN40`KZ`0<6j/00B0<6j/0030:f][@11JN40@FWQ00@0@FWQ1P33_K<2045Yh@D0`kfc00<0@FWQ
0<>m/`2][Jd00P35_[D00`11JN40aKje0<Fn]@040<Fn]@03045Yh@35_[D0aKje00X0aKje00<0[Jf]
0<Jo]`36_kL00`36_kL3045Yh@<0a[ng3`2][Jd4045Yh@H0[Jf]00<0@FWQ0:f][@2][Jd01P2][Jd0
0`11JN40[Jf]0:f][@060:f][@03045Yh@2][Jd0[Jf]0080[Jf]1037`KX00`11JN40al6j0<O1^P04
0<O1^P030:f][@38`K/0@FWQ00H0b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k0080b<6k00<0[Jf]
045Yh@38`K/01@38`K/3045Yh@@0b<6k0P11JN450<S1^`030:f][@37`K`0al6l0140al6l0P11JN45
0<K0_003045Yh@36`;`0a/2l00X0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0
_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BN
S`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@T0_[N/0P11JN460;jg
[003045Yh@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<4045Yh@D0`kfc00<0@FWQ0<>m
/`2][Jd00`35_[D00`11JN40aKje0<Fn]@030<Fn]@03045Yh@35_[D0aKje00X0aKje00<0[Jf]0<Jo
]`36_kL00`36_kL3045Yh@l0a[ng00<0[Jf]0<O1^037`KP00P37`KP2045Yh@H0al6h00<0@FWQ0<O1
^037`KP01P37`KP00`11JN40al6h0:f][@060<O1^P03045Yh@37`KX0al6j00H0al6j00@0@FWQ0<O1
^P37`KX000000`37`KX00`2][Jd0b<6k045Yh@070<S1^`03045Yh@38`K/0b<6k00@0b<6k00<0@FWQ
0<S1^`38`K/00`38`K/00`2][Jd0b<6k045Yh@040<S1^`04045Yh@38`K/0b<6k045Yh@@0b<6k0P11
JN450<S1^`030:f][@37`K`0al6l0140al6l0P11JN450<K0_003045Yh@36`;`0a/2l00P0a/2l102]
[Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3P
iP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd30;jg[0@0@FWQ1@2n]j`00`11JN40[Jf]0<6j/00C
0<6j/0030:f][@33_K<0`kfc00X0`kfc1@11JN420<>m/`03045Yh@33_K<0[Jf]00<0aKje00<0@FWQ
0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@0:0<Fn]@030:f][@36_kL0a[ng00<0a[ng0`11JN44
0<Jo]`03045Yh@36_kL0a[ng00D0a[ng0P11JN400`36_kL0[Jf]0<O1^0030<O1^003045Yh@37`KP0
al6h00D0al6h00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6h0:f][@060<O1^P80@FWQ1`37`KX0
0`11JN40al6j000000040<O1^P030:f][@38`K/0@FWQ00P0b<6k00<0@FWQ0<S1^`38`K/00`38`K/0
0`11JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k00@0@FWQ2038`K/2045Yh@D0b<6k00<0[Jf]
0<O1_037`K`04@37`K`2045Yh@@0a/2l00<0@FWQ0<K0_036`;`01036`;`50:f][@80a/2l00<0[Jf]
0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>
0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@030;jg[011JN40@FWQ0080@FWQ0P2n]j`2045Y
h@030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje045Yh@04045Y
h@<0aKje00<0@FWQ0<Fn]@35_[D02P35_[D00`2][Jd0a[ng0<Jo]`030<Jo]`80@FWQ00<0a[ng045Y
h@36_kL00P36_kL2045Yh@H0a[ng0P11JN400`36_kL0[Jf]0<O1^0030<O1^003045Yh@37`KP0al6h
00D0al6h0P11JN460<O1^004045Yh@37`KP0al6h0:f][@H0al6j0P11JN460<O1^P80@FWQ1P37`KX0
0`2][Jd0b<6k045Yh@090<S1^`D0@FWQ1P38`K/00`2][Jd0b<6k0<S1^`0<0<S1^`80@FWQ1@38`K/0
0`2][Jd0al6l0<O1_00A0<O1_0H0@FWQ0`36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0
0`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H2
0:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/00L0_[N/102][Jd01P2n]j`0@FWQ045Yh@11JN40_[N/0:f][A@0`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@070<Fn]@03045Yh@35_[D0aKje00X0aKje00<0[Jf]0<Jo]`36_kL0
0`36_kL2045Yh@030<Jo]`11JN40a[ng0080a[ng0P11JN470<Jo]`03045Yh@36_kL0[Jf]00<0al6h
00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6h045Yh@040<O1^080@FWQ0P37`KP00`2][Jd0al6j
0<O1^P040<O1^P@0@FWQ1037`KX2045Yh@D0al6j1011JN4D0<S1^`030:f][@38`K/0b<6k00`0b<6k
0P11JN450<S1^`030:f][@37`K`0al6l00l0al6l1011JN420<K0_0D0[Jf]2`36`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00
J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]
00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00L0aKje
0P11JN4:0<Fn]@03045Yh@2][Jd0a[ng0080a[ng1011JN420<Jo]`@0@FWQ2@36_kL5045Yh@H0al6h
1011JN420<O1^0@0@FWQ1037`KP00`2][Jd0al6j0<O1^P040<O1^P80@FWQ0P37`KX4045Yh@P0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0<0<S1^`80@FWQ1@38`K/00`2][Jd0al6l
0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01`35
_[D2045Yh@X0aKje00<0@FWQ0:f][@36_kL05P36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j00@0al6j0P11JN4>0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03038
`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_
0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]
0<6j/031^[00`KZ`1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01`35
_[D2045Yh@T0aKje0P11JN400`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX01037`KX2045Yh@h0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0<0<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3o
ool00740/>3V0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00P0aKje0P11JN480<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j00@0al6j0P11JN4>0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/03@38`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@37`K`0al6l00D0[Jf]3@37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP2
0:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@090<Fn
]@80@FWQ1`35_[D2045Yh@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P040<O1^P80@FWQ3P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
0100b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33
_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje00T0aKje0P11JN460<Fn]@<0@FWQ00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00@0al6j0P11JN4>0<O1
^P030:f][@38`K/0@FWQ01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0
`kfc00<0[Jf]0<Fn]@35_[D02P35_[D2045Yh@@0aKje00D0@FWQ0<Fn]@35_[D0@FWQ0:f][@0G0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01037`KX2045Yh@h0al6j00@0[Jf]045Y
h@38`K/0@FWQ4`38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k
0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04033_K<90:f][@P0aKje1@11JN430<Fn]@03045Yh@2][Jd0a[ng01H0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P040<O1^P80@FWQ3P37`KX00`2][Jd0b<6k045Yh@0?
0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0102]
[Jd0al6j0<O1^P37`KX5045Yh@h0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]
0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80
/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
3`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/7
0:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1
^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0
/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52276 .3309 m
.51106 .33084 L
s
.54114 .33076 m
.52944 .33088 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50438 .33076 m
.4927 .33051 L
s
.55948 .33031 m
.54782 .33063 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49769 .33227 m
.4977 .33063 L
s
.49937 .3313 m
.49937 .33067 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51772 .36631 m
.51773 .35917 L
s
.51604 .3663 m
.51605 .35918 L
s
.5 Mabswid
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55988 .32227 m
.57137 .32182 L
s
0 0 0 r
.59492 .3286 m
.59585 .32854 L
s
.255 .412 .882 r
.49876 .33837 m
.51034 .33855 L
s
.53518 .3408 m
.53848 .33851 L
s
.53848 .33851 m
.54345 .33843 L
s
.53352 .34082 m
.53848 .33851 L
s
.54345 .33843 m
.54676 .34062 L
s
.53187 .34534 m
.53352 .34082 L
s
.53353 .34533 m
.53518 .3408 L
s
.54676 .34062 m
.55008 .34506 L
s
.55501 .33816 m
.55666 .33812 L
s
.55172 .3405 m
.55501 .33816 L
s
.55337 .34046 m
.55501 .33816 L
s
.48878 .35619 m
.48886 .33812 L
s
.48713 .35614 m
.48721 .33807 L
s
.55008 .34506 m
.55172 .3405 L
s
.53187 .34534 m
.53188 .34986 L
s
.55173 .34502 m
.55337 .34046 L
s
.53353 .34533 m
.53353 .34984 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47897 .33778 m
.4839 .34022 L
s
.47569 .33765 m
.47897 .33778 L
s
.4839 .34022 m
.48718 .34484 L
s
.53188 .34986 m
.53354 .35436 L
s
.47239 .33977 m
.47569 .33765 L
s
.47075 .33969 m
.47569 .33765 L
s
.53353 .34984 m
.5352 .35435 L
s
.56984 .3399 m
.57311 .33751 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56658 .34455 m
.56984 .3399 L
s
.57311 .33751 m
.57639 .33736 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57639 .33736 m
.57968 .33945 L
s
.57639 .33736 m
.58132 .33937 L
s
.46908 .34414 m
.47239 .33977 L
s
.53354 .35436 m
.53852 .35657 L
s
.5352 .35435 m
.53852 .35657 L
s
.46744 .34406 m
.47075 .33969 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49928 .36059 m
.49929 .35912 L
s
.4976 .36157 m
.49761 .35906 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50531 .37014 m
.50538 .33849 L
s
.50365 .37012 m
.50372 .33846 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56481 .32209 m
.56506 .36952 L
s
.56645 .32203 m
.56671 .36946 L
s
.55008 .34506 m
.55015 .36542 L
s
.55173 .34502 m
.55179 .36084 L
s
.54847 .35866 m
.53852 .35657 L
s
.50534 .35655 m
.50698 .36336 L
s
.57968 .33945 m
.58299 .3438 L
s
.58132 .33937 m
.58462 .34372 L
s
.46741 .34858 m
.46908 .34414 L
s
.48218 .35598 m
.49374 .35632 L
s
.46577 .3485 m
.46744 .34406 L
s
.54847 .35866 m
.55013 .36088 L
s
.51694 .36572 m
.5186 .36346 L
s
.5186 .36346 m
.52027 .36573 L
s
.53355 .36342 m
.53356 .36568 L
s
.53355 .36342 m
.53521 .3634 L
s
.53521 .3634 m
.53522 .36567 L
s
.50698 .36336 m
.5103 .36793 L
s
.58299 .3438 m
.58467 .3505 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55015 .36542 m
.55179 .36084 L
s
.52026 .368 m
.52027 .36573 L
s
.51694 .36572 m
.5186 .36799 L
s
.58462 .34372 m
.58631 .35042 L
s
.46572 .35529 m
.46741 .34858 L
s
.53356 .36568 m
.53522 .36793 L
s
0 0 0 r
.57468 .37167 m
.57469 .37169 L
s
.255 .412 .882 r
.46408 .35521 m
.46577 .3485 L
s
.59597 .33626 m
.6073 .33546 L
s
.5186 .37026 m
.52026 .368 L
s
.5103 .36793 m
.51362 .37023 L
s
.53522 .36793 m
.53855 .37016 L
s
.5485 .36772 m
.55015 .36542 L
s
.51362 .37023 m
.5186 .37026 L
s
.54519 .37006 m
.5485 .36772 L
s
.53855 .37016 m
.54519 .37006 L
s
.49867 .37003 m
.50531 .37014 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58467 .3505 m
.58471 .35504 L
s
0 0 0 r
.57382 .37224 m
.57804 .37479 L
s
.255 .412 .882 r
.56667 .36265 m
.57 .36707 L
s
.58631 .35042 m
.58635 .35495 L
s
.46564 .36664 m
.46572 .35529 L
s
0 0 0 r
.57469 .37169 m
.57804 .37479 L
s
.255 .412 .882 r
.464 .36656 m
.46408 .35521 L
s
0 0 0 r
.58631 .37114 m
.58957 .36447 L
s
.255 .412 .882 r
.5601 .36969 m
.56671 .36946 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45011 .35979 m
.45059 .35713 L
s
.45197 .35875 m
.45224 .35726 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4463 .33605 m
.45252 .36821 L
s
.4395 .36737 m
.4463 .33605 L
s
.44112 .36748 m
.44623 .34283 L
s
.48866 .38572 m
.48871 .37206 L
s
.48703 .37884 m
.48871 .37206 L
s
0 0 0 r
.57804 .37479 m
.58136 .37463 L
s
.58136 .37463 m
.58631 .37114 L
s
.255 .412 .882 r
.43338 .33509 m
.4395 .36737 L
s
.42659 .36638 m
.43338 .33509 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57 .36707 m
.57331 .3692 L
s
.58476 .36184 m
.58635 .35495 L
s
.58312 .36193 m
.58471 .35504 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57987 .36663 m
.58312 .36193 L
s
.61374 .33495 m
.62494 .33397 L
s
.57331 .3692 m
.5766 .36906 L
s
.58151 .36655 m
.58476 .36184 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46564 .36664 m
.46724 .37354 L
s
.5766 .36906 m
.57987 .36663 L
s
.5766 .36906 m
.58151 .36655 L
s
0 0 0 r
.40759 .32496 m
.40854 .32506 L
s
.255 .412 .882 r
.4837 .38329 m
.48703 .37884 L
s
.48703 .37884 m
.48866 .38572 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58979 .39132 m
.58984 .39702 L
s
.59144 .39022 m
.5915 .39693 L
s
.255 .412 .882 r
.464 .36656 m
.46559 .37346 L
s
.42819 .36651 m
.4333 .34188 L
s
.46724 .37354 m
.46885 .37817 L
s
.47872 .3854 m
.4837 .38329 L
s
.46559 .37346 m
.46721 .3781 L
s
.44762 .36791 m
.45742 .36849 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46885 .37817 m
.47212 .38287 L
s
.46721 .3781 m
.47047 .3828 L
s
.47541 .38528 m
.47872 .3854 L
s
.41739 .33368 m
.41898 .33383 L
s
.47212 .38287 m
.47541 .38528 L
s
.6027 .36076 m
.60599 .36508 L
s
.47047 .3828 m
.47541 .38528 L
s
.41419 .33564 m
.41739 .33368 L
s
.41577 .33579 m
.41739 .33368 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63129 .33336 m
.64232 .3322 L
s
.41413 .34018 m
.41577 .33579 L
s
.41254 .34002 m
.41419 .33564 L
s
0 0 0 r
.61622 .37243 m
.61757 .37233 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41392 .35611 m
.41413 .34018 L
s
.40944 .33516 m
.41254 .34002 L
s
.40633 .33255 m
.40944 .33516 L
s
0 0 0 r
.61757 .37233 m
.61999 .36967 L
s
.255 .412 .882 r
.41227 .36053 m
.41254 .34002 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60084 .33593 m
.6013 .38367 L
s
.60246 .33581 m
.60292 .38357 L
s
.63761 .33271 m
.63806 .36462 L
s
.63603 .33287 m
.63648 .36477 L
s
.60599 .36508 m
.61087 .36701 L
s
.62015 .3344 m
.62045 .35939 L
s
.61855 .33454 m
.61884 .35953 L
s
.61087 .36701 m
.6141 .36676 L
s
.40162 .33203 m
.40633 .33255 L
s
.61729 .36422 m
.61884 .35953 L
s
.42177 .36597 m
.43303 .36689 L
s
.6189 .36409 m
.62045 .35939 L
s
.5964 .38398 m
.60292 .38357 L
s
.6141 .36676 m
.61729 .36422 L
s
.6141 .36676 m
.6189 .36409 L
s
.39846 .33395 m
.40162 .33203 L
s
.39689 .33377 m
.40162 .33203 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41227 .36053 m
.41392 .35611 L
s
.39682 .33832 m
.39846 .33395 L
s
.40135 .35025 m
.41077 .35352 L
s
.41077 .35352 m
.41233 .35596 L
s
.39527 .33814 m
.39689 .33377 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41065 .36266 m
.41227 .36053 L
s
.39675 .34288 m
.39682 .33832 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39519 .3427 m
.39527 .33814 L
s
.65328 .3332 m
.65788 .33034 L
s
.65024 .33813 m
.65328 .3332 L
s
.64879 .34515 m
.65024 .33813 L
s
.63172 .36524 m
.63806 .36462 L
s
.40745 .36463 m
.41065 .36266 L
s
.39675 .34288 m
.39825 .34762 L
s
.6518 .33794 m
.65483 .33301 L
s
.65035 .34497 m
.6518 .33794 L
s
.65483 .33301 m
.65788 .33034 L
s
.39825 .34762 m
.40135 .35025 L
s
.39668 .34744 m
.40135 .35025 L
s
.39519 .3427 m
.39668 .34744 L
s
.64879 .34515 m
.64886 .34971 L
s
.65788 .33034 m
.66096 .32994 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65035 .34497 m
.65042 .34953 L
s
.40114 .36397 m
.40745 .36463 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64886 .34971 m
.65053 .3564 L
s
.66096 .32994 m
.6656 .33161 L
s
.65042 .34953 m
.65209 .35621 L
s
.39654 .35659 m
.39811 .35676 L
s
.39807 .35905 m
.39811 .35676 L
s
.39651 .35888 m
.39654 .35659 L
s
.39804 .36134 m
.40114 .36397 L
s
.63664 .37623 m
.63825 .37837 L
s
.63508 .37868 m
.63664 .37623 L
s
.63508 .37868 m
.6367 .38082 L
s
.39651 .35888 m
.39804 .36134 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6656 .33161 m
.66873 .33576 L
s
.6367 .38082 m
.63825 .37837 L
s
.36481 .32714 m
.37538 .32871 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65209 .35621 m
.65527 .36043 L
s
.65053 .3564 m
.65372 .36061 L
s
.65372 .36061 m
.65841 .36235 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65527 .36043 m
.65841 .36235 L
s
.37023 .36016 m
.37083 .32805 L
s
.36872 .35995 m
.36932 .32783 L
s
.65841 .36235 m
.66305 .36178 L
s
.38258 .35491 m
.38408 .35739 L
s
.38404 .35969 m
.38408 .35739 L
s
.381 .357 m
.38258 .35491 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38246 .36179 m
.38404 .35969 L
s
.66596 .3522 m
.66745 .3497 L
s
.66596 .3522 m
.66753 .35429 L
s
.66745 .3497 m
.66902 .35179 L
s
.67919 .32735 m
.68078 .3317 L
s
.67919 .32735 m
.67937 .33651 L
s
.381 .357 m
.3825 .3595 L
s
.37785 .3612 m
.38246 .36179 L
s
.66305 .36178 m
.66608 .35908 L
s
.66902 .35179 m
.66906 .35408 L
s
.66608 .35908 m
.66906 .35408 L
s
.67937 .33651 m
.68078 .3317 L
s
.68078 .3317 m
.68223 .32918 L
s
.68223 .32918 m
.68517 .32642 L
s
.37049 .34637 m
.37188 .35347 L
s
.37484 .35849 m
.37785 .3612 L
s
.68517 .32642 m
.69109 .32545 L
s
.37188 .35347 m
.37484 .35849 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67963 .35029 m
.68109 .34777 L
s
.67963 .35029 m
.67972 .35489 L
s
.68109 .34777 m
.68404 .34501 L
s
.36419 .3593 m
.37023 .36016 L
s
.67968 .35259 m
.68113 .35007 L
s
.68113 .35007 m
.68409 .34731 L
s
.35289 .32751 m
.35575 .3326 L
s
.35575 .3326 m
.35713 .33743 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68404 .34501 m
.69137 .33923 L
s
.69109 .32545 m
.69408 .32724 L
s
.67972 .35489 m
.68127 .35697 L
s
.34854 .32446 m
.35289 .32751 L
s
.35713 .33743 m
.35848 .34456 L
s
.68409 .34731 m
.69142 .34153 L
s
.35142 .32726 m
.35427 .33235 L
s
.35427 .33235 m
.35565 .33719 L
s
.34854 .32446 m
.35142 .32726 L
s
.69408 .32724 m
.69559 .32929 L
s
.35565 .33719 m
.35699 .34433 L
s
.35825 .35609 m
.35848 .34456 L
s
.68127 .35697 m
.68431 .35883 L
s
.33413 .32179 m
.34854 .32446 L
s
.35676 .35585 m
.35699 .34433 L
s
.69559 .32929 m
.69574 .33619 L
s
.69137 .33923 m
.69427 .33644 L
s
.69142 .34153 m
.69432 .33874 L
s
.69427 .33644 m
.69569 .33389 L
s
.68431 .35883 m
.69028 .35791 L
s
.69432 .33874 m
.69574 .33619 L
s
.35662 .36278 m
.35825 .35609 L
s
.35513 .36255 m
.35676 .35585 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69028 .35791 m
.69319 .35513 L
s
.35504 .36718 m
.35662 .36278 L
s
.33876 .37149 m
.33985 .32288 L
s
.69461 .35258 m
.69598 .34771 L
s
.69319 .35513 m
.69461 .35258 L
s
.7057 .32516 m
.70708 .32259 L
s
.7057 .32516 m
.70718 .3272 L
s
.35355 .36695 m
.35513 .36255 L
s
.33731 .37124 m
.33842 .32261 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69461 .35258 m
.69618 .35696 L
s
.69598 .34771 m
.69618 .35696 L
s
.70708 .32259 m
.70856 .32462 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35198 .37135 m
.35504 .36718 L
s
.70718 .3272 m
.70856 .32462 L
s
.3505 .37112 m
.35355 .36695 L
s
.3475 .37296 m
.35198 .37135 L
s
.70745 .33874 m
.70952 .36631 L
s
.70664 .36682 m
.70745 .33874 L
s
.3475 .37296 m
.3505 .37112 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.333 .37047 m
.3475 .37296 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70776 .35263 m
.70808 .36656 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70664 .36682 m
.70819 .37122 L
s
.70819 .37122 m
.70952 .36631 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75638 .31125 m
.75781 .36062 L
s
.75765 .3109 m
.75908 .36029 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75255 .31229 m
.76513 .30875 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76513 .30875 m
.76765 .31036 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76765 .31036 m
.77022 .31432 L
s
.76513 .30875 m
.76887 .30999 L
s
.76887 .30999 m
.77143 .31395 L
s
.77022 .31432 m
.77157 .31866 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77143 .31395 m
.77278 .31829 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75395 .3616 m
.76661 .35828 L
s
.77278 .31829 m
.77419 .32501 L
s
.77157 .31866 m
.77299 .32538 L
s
.77299 .32538 m
.77336 .33721 L
s
.77833 .30461 m
.78636 .30185 L
s
.77419 .32501 m
.77456 .33684 L
s
.76661 .35828 m
.76901 .35522 L
s
.76661 .35828 m
.77023 .35488 L
s
.76901 .35522 m
.7713 .34978 L
s
.77237 .34468 m
.77336 .33721 L
s
.7713 .34978 m
.77237 .34468 L
s
.77023 .35488 m
.77252 .34942 L
s
.77358 .34432 m
.77456 .33684 L
s
.78181 .30344 m
.78287 .33663 L
s
.26283 .30796 m
.26405 .30599 L
s
.26298 .30323 m
.26405 .30599 L
s
.77252 .34942 m
.77358 .34432 L
s
.26176 .3052 m
.26298 .30323 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78295 .30305 m
.78402 .33625 L
s
.26176 .3052 m
.26283 .30796 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26245 .3198 m
.26269 .34872 L
s
.26038 .34798 m
.26245 .3198 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77937 .33775 m
.78402 .33625 L
s
.78356 .32199 m
.78494 .32873 L
s
.26153 .34835 m
.26199 .33405 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78494 .32873 m
.78737 .33273 L
s
.26138 .35313 m
.26269 .34872 L
s
.25282 .30198 m
.25384 .30476 L
s
.2536 .31189 m
.25384 .30476 L
s
.25073 .29878 m
.25282 .30198 L
s
.2525 .31149 m
.25368 .30952 L
s
.78737 .33273 m
.78969 .33434 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25242 .31387 m
.2536 .31189 L
s
.26038 .34798 m
.26138 .35313 L
s
.24646 .29711 m
.25073 .29878 L
s
.25025 .31306 m
.2525 .31149 L
s
.25017 .31544 m
.25242 .31387 L
s
.78969 .33434 m
.79302 .33317 L
s
.25194 .32818 m
.2532 .3238 L
s
.25289 .33336 m
.2532 .3238 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79176 .32879 m
.79294 .33078 L
s
.79176 .32879 m
.79279 .326 L
s
.79279 .326 m
.79396 .32799 L
s
.24476 .31578 m
.25025 .31306 L
s
.24467 .31818 m
.25017 .31544 L
s
.25077 .33018 m
.25194 .32818 L
s
.25194 .32818 m
.25289 .33336 L
s
.24429 .29864 m
.24646 .29711 L
s
.79396 .32799 m
.79404 .33039 L
s
.79302 .33317 m
.79404 .33039 L
s
.24852 .33178 m
.25077 .33018 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24317 .3006 m
.24429 .29864 L
s
.80072 .30363 m
.80159 .29844 L
s
.80072 .30363 m
.80088 .30841 L
s
.80159 .29844 m
.80459 .29476 L
s
.24426 .33017 m
.24852 .33178 L
s
.80088 .30841 m
.80209 .31278 L
s
.80176 .30321 m
.80263 .29801 L
s
.80176 .30321 m
.80192 .30799 L
s
.80263 .29801 m
.80459 .29476 L
s
.2423 .2954 m
.24317 .3006 L
s
.24197 .30495 m
.24317 .3006 L
s
.24197 .30495 m
.2423 .2954 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24259 .31735 m
.24476 .31578 L
s
.80192 .30799 m
.80312 .31236 L
s
.24251 .31974 m
.24467 .31818 L
s
.80459 .29476 m
.80761 .29346 L
s
.24147 .31933 m
.24259 .31735 L
s
.24226 .32695 m
.24426 .33017 L
s
.24139 .32173 m
.24251 .31974 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80242 .32236 m
.80346 .32195 L
s
.80242 .32236 m
.8025 .32476 L
s
.80312 .31236 m
.80526 .31391 L
s
.80209 .31278 m
.80526 .31391 L
s
.8025 .32476 m
.80362 .32675 L
s
.80761 .29346 m
.80968 .29497 L
s
.80346 .32195 m
.80354 .32435 L
s
.2413 .32413 m
.24147 .31933 L
s
.2413 .32413 m
.24226 .32695 L
s
.80526 .31391 m
.81134 .31375 L
s
.80362 .32675 m
.80576 .32833 L
s
.80968 .29497 m
.8118 .29889 L
s
.80576 .32833 m
.8098 .32666 L
s
.23325 .29385 m
.23502 .29954 L
s
.23047 .29011 m
.23325 .29385 L
s
.8118 .29889 m
.81259 .29364 L
s
.8118 .29889 m
.81257 .32056 L
s
.81259 .29364 m
.81442 .29035 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81277 .29845 m
.81355 .2932 L
s
.81277 .29845 m
.81337 .3153 L
s
.81355 .2932 m
.81442 .29035 L
s
.81442 .29035 m
.81536 .28989 L
s
.81134 .31375 m
.8124 .31573 L
s
.23434 .31878 m
.23443 .31637 L
s
.23353 .31353 m
.23443 .31637 L
s
.2286 .2892 m
.23047 .29011 L
s
.8098 .32666 m
.81168 .3234 L
s
.23222 .32275 m
.23434 .31878 L
s
.23248 .31551 m
.23353 .31353 L
s
.23248 .31551 m
.23336 .31835 L
s
.81168 .3234 m
.81257 .32056 L
s
.22667 .2907 m
.2286 .2892 L
s
.22576 .29024 m
.2286 .2892 L
s
.81257 .32056 m
.81337 .3153 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2302 .32431 m
.23222 .32275 L
s
.22468 .29461 m
.22667 .2907 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22378 .29415 m
.22576 .29024 L
s
.22737 .32301 m
.2302 .32431 L
s
.22351 .3014 m
.22468 .29461 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22262 .30095 m
.22378 .29415 L
s
.22561 .31971 m
.22737 .32301 L
s
.22469 .31927 m
.22737 .32301 L
s
.81846 .3228 m
.82479 .31971 L
s
.82122 .32149 m
.82353 .28575 L
s
.22333 .30625 m
.22351 .3014 L
s
.22396 .31397 m
.22561 .31971 L
s
.22333 .30625 m
.22396 .31397 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22244 .30579 m
.22262 .30095 L
s
.82212 .32105 m
.8238 .29301 L
s
.22306 .31352 m
.22469 .31927 L
s
.22244 .30579 m
.22306 .31352 L
s
.21388 .28122 m
.21968 .28457 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82353 .28575 m
.82824 .31791 L
s
.21586 .31721 m
.21715 .28314 L
s
.21503 .31676 m
.21632 .28266 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82824 .31791 m
.83027 .28196 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82909 .31745 m
.83055 .28925 L
s
.83027 .28196 m
.83478 .31423 L
s
.21258 .31538 m
.21586 .31721 L
s
.20556 .27581 m
.21074 .27928 L
s
.21438 .33391 m
.2153 .33191 L
s
.21456 .329 m
.2153 .33191 L
s
.21364 .33101 m
.21456 .329 L
s
.83239 .31562 m
.8371 .31283 L
s
.21364 .33101 m
.21438 .33391 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20742 .30473 m
.20847 .2778 L
s
.20668 .30425 m
.20773 .27731 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20649 .30917 m
.20742 .30473 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83993 .28832 m
.84045 .28292 L
s
.8395 .29617 m
.83993 .28832 L
s
.84045 .28292 m
.84166 .27702 L
s
.20575 .30869 m
.20668 .30425 L
s
.8395 .29617 m
.83998 .30847 L
s
.84065 .28783 m
.84116 .28243 L
s
.84022 .29569 m
.84065 .28783 L
s
.20421 .3102 m
.20649 .30917 L
s
.84116 .28243 m
.84235 .27652 L
s
.84166 .27702 m
.8436 .27306 L
s
.84022 .29569 m
.84071 .30799 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20421 .3102 m
.20575 .30869 L
s
.84235 .27652 m
.8436 .27306 L
s
.19824 .27023 m
.20278 .2738 L
s
.83998 .30847 m
.841 .31539 L
s
.84071 .30799 m
.84171 .31492 L
s
.8436 .27306 m
.84491 .27204 L
s
.20279 .30924 m
.20421 .3102 L
s
.841 .31539 m
.84191 .31986 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84491 .27204 m
.84692 .27296 L
s
.84171 .31492 m
.84262 .31939 L
s
.20083 .30532 m
.20279 .30924 L
s
.84191 .31986 m
.84351 .32387 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1968 .33892 m
.19727 .32712 L
s
.19854 .29566 m
.19857 .29493 L
s
.5 Mabswid
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19871 .3242 m
.20078 .27228 L
s
.19805 .32373 m
.20013 .27177 L
s
.84262 .31939 m
.84421 .32339 L
s
.1997 .29939 m
.20083 .30532 L
s
.84692 .27296 m
.84835 .27687 L
s
.84351 .32387 m
.84566 .32493 L
s
.84421 .32339 m
.84566 .32493 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84805 .26947 m
.84885 .28924 L
s
.84865 .26895 m
.84945 .28873 L
s
.84566 .32493 m
.84699 .32398 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19614 .32229 m
.19871 .3242 L
s
.84699 .32398 m
.84882 .32005 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84699 .29075 m
.85121 .28721 L
s
.84882 .32005 m
.84985 .31409 L
s
.19292 .26801 m
.19382 .27402 L
s
.19382 .27402 m
.19408 .28197 L
s
.85208 .26581 m
.85566 .2621 L
s
.19388 .28694 m
.19408 .28197 L
s
.85016 .30612 m
.85076 .32109 L
s
.84985 .31409 m
.85016 .30612 L
s
.84985 .31409 m
.85076 .32109 L
s
.19239 .26749 m
.19326 .2735 L
s
.19326 .2735 m
.19351 .28146 L
s
.19145 .26395 m
.19292 .26801 L
s
.19301 .2939 m
.19388 .28694 L
s
.19331 .28643 m
.19351 .28146 L
s
.19145 .26395 m
.19239 .26749 L
s
.19245 .29339 m
.19331 .28643 L
s
.85367 .26423 m
.8551 .29912 L
s
.1917 .29787 m
.19301 .2939 L
s
.19044 .26288 m
.19145 .26395 L
s
.18751 .24113 m
.19067 .24498 L
s
.85418 .2637 m
.85562 .29861 L
s
.19116 .29737 m
.19245 .29339 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18937 .26431 m
.19044 .26288 L
s
.8535 .30064 m
.85562 .29861 L
s
.19001 .29885 m
.1917 .29787 L
s
.18709 .29578 m
.18926 .24334 L
s
.19001 .29885 m
.19116 .29737 L
s
0 0 0 r
.18429 .25045 m
.18458 .25081 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.855 .28361 m
.85582 .29059 L
s
.18663 .29527 m
.18881 .24279 L
s
.18823 .26823 m
.18937 .26431 L
s
0 0 0 r
.18283 .25236 m
.18429 .25045 L
s
.255 .412 .882 r
.189 .29783 m
.19001 .29885 L
s
0 0 0 r
.86212 .24912 m
.86382 .24686 L
s
.255 .412 .882 r
.85582 .29059 m
.85701 .29457 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18813 .2943 m
.189 .29783 L
s
.85701 .29457 m
.85806 .29605 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1874 .28825 m
.18813 .2943 L
s
.85806 .29605 m
.85941 .29451 L
s
.18532 .29372 m
.18709 .29578 L
s
.18557 .25695 m
.18597 .2575 L
s
.85876 .29 m
.85931 .29199 L
s
.85876 .29 m
.8591 .28696 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1847 .25837 m
.18557 .25695 L
s
.18508 .25891 m
.18557 .25695 L
s
.8591 .28696 m
.85963 .28895 L
s
.18449 .26339 m
.18508 .25891 L
s
.85941 .29451 m
.85974 .29147 L
s
.85963 .28895 m
.85974 .29147 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18412 .26284 m
.1847 .25837 L
s
.18375 .28101 m
.18449 .26339 L
s
.18363 .25673 m
.18412 .26284 L
s
.18317 .28553 m
.18412 .26284 L
s
.86144 .26259 m
.86158 .25701 L
s
.86144 .26259 m
.86165 .26762 L
s
.86158 .25701 m
.86247 .25285 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18307 .25311 m
.18363 .25673 L
s
.86165 .26762 m
.86221 .27212 L
s
.86179 .26204 m
.86192 .25647 L
s
.86179 .26204 m
.862 .26708 L
s
.86192 .25647 m
.86247 .25285 L
s
.18317 .28553 m
.18375 .28101 L
s
.862 .26708 m
.86256 .27158 L
s
.18214 .25145 m
.18307 .25311 L
s
.18313 .27742 m
.18338 .28048 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86221 .27212 m
.86333 .27303 L
s
.86247 .25285 m
.86339 .25119 L
s
.18128 .27166 m
.18313 .27742 L
s
.1827 .28753 m
.18317 .28553 L
s
.86256 .27158 m
.86333 .27303 L
s
.86264 .28222 m
.86275 .28475 L
s
.86264 .28222 m
.86299 .28169 L
s
.1819 .28901 m
.1827 .28753 L
s
.86275 .28475 m
.8632 .28675 L
s
.18146 .25286 m
.18214 .25145 L
s
.18119 .25231 m
.18214 .25145 L
s
.86299 .28169 m
.86309 .28422 L
s
.86339 .25119 m
.86405 .2526 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86333 .27303 m
.86518 .27232 L
s
.8632 .28675 m
.86397 .28823 L
s
.18064 .28689 m
.1819 .28901 L
s
.18098 .25736 m
.18146 .25286 L
s
.86405 .2526 m
.86479 .25655 L
s
.18082 .26804 m
.18128 .27166 L
s
.18055 .2675 m
.18128 .27166 L
s
.86397 .28823 m
.86518 .28611 L
s
.18072 .25681 m
.18119 .25231 L
s
0 0 0 r
.17611 .24052 m
.17663 .23937 L
s
.255 .412 .882 r
.18076 .26243 m
.18098 .25736 L
s
.18076 .26243 m
.18082 .26804 L
s
.1805 .26188 m
.18072 .25681 L
s
.86479 .25655 m
.86482 .25093 L
s
.86479 .25655 m
.86576 .27941 L
s
.86482 .25093 m
.86517 .24728 L
s
.18017 .28328 m
.18064 .28689 L
s
.1805 .26188 m
.18055 .2675 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18012 .27766 m
.18039 .2782 L
s
.18028 .28074 m
.18039 .2782 L
s
.86504 .256 m
.86505 .25037 L
s
.86504 .256 m
.86579 .27378 L
s
.86505 .25037 m
.86517 .24728 L
s
0 0 0 r
.86934 .24249 m
.86938 .24025 L
s
.255 .412 .882 r
.86518 .27232 m
.86555 .27432 L
s
.86518 .28611 m
.86561 .28249 L
s
.86517 .24728 m
.86539 .24672 L
s
.18001 .2802 m
.18017 .28328 L
s
0 0 0 r
.17539 .24662 m
.17611 .24052 L
s
.255 .412 .882 r
.18001 .2802 m
.18012 .27766 L
s
0 0 0 r
.86938 .24025 m
.86981 .2349 L
s
.8695 .24611 m
.86958 .23968 L
s
.255 .412 .882 r
.86561 .28249 m
.86576 .27941 L
s
0 0 0 r
.86958 .23968 m
.86981 .2349 L
s
.255 .412 .882 r
.86576 .27941 m
.86579 .27378 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86981 .2349 m
.87014 .23375 L
s
.87106 .28223 m
.87126 .28389 L
s
.87014 .23375 m
.8706 .23622 L
s
.87014 .23375 m
.87073 .23564 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86503 .22786 m
.8661 .22382 L
s
0 0 0 r
.17465 .269 m
.1747 .2732 L
s
.17433 .27629 m
.1747 .2732 L
s
.8709 .27857 m
.87147 .28335 L
s
.17423 .28415 m
.17451 .28857 L
s
.17429 .27209 m
.17465 .269 L
s
.17413 .27575 m
.17423 .28415 L
s
.17413 .27575 m
.17429 .27209 L
s
.17488 .23228 m
.17421 .2282 L
s
.87117 .24235 m
.8706 .23622 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87126 .28389 m
.87201 .28592 L
s
.255 .412 .882 r
.86679 .25098 m
.86685 .24475 L
s
.17812 .27278 m
.1782 .27588 L
s
.17809 .27844 m
.1782 .27588 L
s
0 0 0 r
.87128 .24177 m
.87073 .23564 L
s
.87147 .28335 m
.87201 .28592 L
s
.255 .412 .882 r
.86731 .28129 m
.868 .27912 L
s
.1778 .28046 m
.17809 .27844 L
s
.17784 .27479 m
.17812 .27278 L
s
.86685 .24475 m
.86698 .24106 L
s
.17797 .23791 m
.17858 .2419 L
s
.17784 .27479 m
.17791 .2779 L
s
.17731 .27884 m
.1778 .28046 L
s
0 0 0 r
.87176 .25273 m
.87117 .24235 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86698 .24106 m
.86717 .23992 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8657 .22556 m
.868 .27912 L
s
.86555 .22613 m
.86784 .27966 L
s
0 0 0 r
.87201 .28592 m
.87236 .28483 L
s
.255 .412 .882 r
.86767 .27143 m
.86817 .27547 L
s
0 0 0 r
.87186 .25216 m
.87128 .24177 L
s
.255 .412 .882 r
.17672 .27612 m
.17826 .24019 L
s
.86717 .23992 m
.86744 .24134 L
s
.86717 .23992 m
.8675 .24077 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17715 .27518 m
.17731 .27884 L
s
0 0 0 r
.87236 .28483 m
.8725 .28007 L
s
.87236 .28483 m
.87263 .27952 L
s
.255 .412 .882 r
.17663 .27557 m
.17817 .23962 L
s
0 0 0 r
.87208 .26005 m
.87176 .25273 L
s
.255 .412 .882 r
.86817 .27547 m
.86852 .27695 L
s
0 0 0 r
.87218 .25949 m
.87186 .25216 L
s
.8725 .28007 m
.87244 .27162 L
s
.87244 .27162 m
.87208 .26005 L
s
.255 .412 .882 r
.17715 .26894 m
.17715 .27518 L
s
0 0 0 r
.87255 .27106 m
.87218 .25949 L
s
.87263 .27952 m
.87255 .27106 L
s
.255 .412 .882 r
.17715 .26894 m
.17738 .26068 L
s
0 0 0 r
.87134 .22498 m
.87126 .22733 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8675 .24077 m
.86781 .24477 L
s
.86744 .24134 m
.86777 .24533 L
s
.86852 .27695 m
.86871 .27586 L
s
.86777 .24533 m
.86814 .25248 L
s
.17643 .27393 m
.17672 .27612 L
s
0 0 0 r
.17406 .22585 m
.17421 .22173 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17108 .30717 m
.17443 .22995 L
s
.17118 .3077 m
.17453 .23053 L
s
.255 .412 .882 r
.86871 .27586 m
.86876 .27219 L
s
.86871 .27586 m
.86882 .27164 L
s
.86781 .24477 m
.86817 .25192 L
s
0 0 0 r
.17154 .30929 m
.17108 .30717 L
s
.255 .412 .882 r
.86865 .26593 m
.86876 .27219 L
s
.86814 .25248 m
.86836 .25763 L
s
.86836 .25763 m
.86865 .26593 L
s
.86817 .25192 m
.86839 .25707 L
s
0 0 0 r
.17181 .27576 m
.17406 .22409 L
s
.87148 .22748 m
.87182 .23599 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86869 .26537 m
.86882 .27164 L
s
.86839 .25707 m
.86869 .26537 L
s
.17698 .2551 m
.17786 .23447 L
s
0 0 0 r
.17183 .27521 m
.17408 .2235 L
s
.87126 .22263 m
.87148 .22748 L
s
.255 .412 .882 r
.17711 .25286 m
.17699 .25678 L
s
.177 .25454 m
.17788 .2339 L
s
0 0 0 r
.87115 .22145 m
.87126 .22263 L
s
.255 .412 .882 r
.17755 .24163 m
.17784 .23532 L
s
.86692 .22901 m
.86746 .23305 L
s
.17784 .23532 m
.17814 .23102 L
s
0 0 0 r
.87116 .22395 m
.87115 .22145 L
s
.87107 .22336 m
.87115 .22145 L
s
.87311 .26549 m
.87341 .27178 L
s
.17181 .27742 m
.17183 .27521 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87134 .22498 m
.87472 .30266 L
s
.87134 .22557 m
.87471 .3032 L
s
.255 .412 .882 r
.86729 .23132 m
.86963 .2859 L
s
.17814 .23102 m
.17831 .22986 L
s
0 0 0 r
.87129 .23016 m
.87116 .22395 L
s
.255 .412 .882 r
.17553 .28885 m
.1762 .27324 L
s
.17588 .28049 m
.1762 .27324 L
s
.86721 .23074 m
.86956 .28536 L
s
0 0 0 r
.87117 .22958 m
.87107 .22336 L
s
.87341 .27178 m
.87351 .27439 L
s
.255 .412 .882 r
.17831 .22986 m
.17842 .2313 L
s
.17831 .22986 m
.17855 .23072 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17572 .28462 m
.17588 .28049 L
s
.17553 .28885 m
.17588 .28049 L
s
0 0 0 r
.87468 .30106 m
.87471 .3032 L
s
.87166 .2407 m
.87129 .23016 L
s
.87351 .27439 m
.87341 .27328 L
s
.255 .412 .882 r
.17846 .23534 m
.17842 .2313 L
s
0 0 0 r
.17083 .29865 m
.171 .29437 L
s
.17067 .30185 m
.17083 .29865 L
s
.87153 .24012 m
.87117 .22958 L
s
.171 .29437 m
.17086 .29757 L
s
.17428 .22927 m
.17487 .22069 L
s
.17368 .24097 m
.17428 .22927 L
s
.255 .412 .882 r
.86844 .25926 m
.86848 .26336 L
s
.86956 .28536 m
.8698 .28752 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17572 .28462 m
.17579 .28562 L
s
0 0 0 r
.17487 .22069 m
.17552 .21522 L
s
.17335 .2484 m
.17368 .24097 L
s
.17086 .29757 m
.17067 .30185 L
s
.17441 .22869 m
.17502 .2201 L
s
.1738 .2404 m
.17441 .22869 L
s
.87341 .27328 m
.87309 .26844 L
s
.87341 .27328 m
.873 .26788 L
s
.87166 .2407 m
.87198 .24813 L
s
.17502 .2201 m
.17552 .21522 L
s
.17347 .24783 m
.1738 .2404 L
s
.17299 .259 m
.17335 .2484 L
s
.87153 .24012 m
.87186 .24756 L
s
.87258 .25986 m
.87198 .24813 L
s
.87309 .26844 m
.87258 .25986 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86848 .26336 m
.86823 .26431 L
s
0 0 0 r
.17312 .25844 m
.17347 .24783 L
s
.17552 .21522 m
.17591 .21403 L
s
.87246 .2593 m
.87186 .24756 L
s
.873 .26788 m
.87246 .2593 L
s
.86895 .21256 m
.86978 .21494 L
s
.255 .412 .882 r
.17579 .28562 m
.17597 .28454 L
s
.17821 .24722 m
.17826 .24549 L
s
0 0 0 r
.17293 .26535 m
.17299 .259 L
s
.255 .412 .882 r
.17838 .24666 m
.17842 .24522 L
s
0 0 0 r
.17591 .21403 m
.17617 .21656 L
s
.255 .412 .882 r
.17597 .28454 m
.1763 .28083 L
s
0 0 0 r
.17309 .26479 m
.17312 .25844 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8664 .23815 m
.86707 .25367 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86619 .23728 m
.86687 .25312 L
s
.86823 .26431 m
.86793 .2632 L
s
0 0 0 r
.17617 .21656 m
.17632 .22283 L
s
.17326 .26743 m
.17293 .26535 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1763 .28083 m
.17633 .28047 L
s
.17797 .25298 m
.17821 .24722 L
s
.17597 .28454 m
.17642 .28032 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86748 .25947 m
.86793 .2632 L
s
.86729 .25892 m
.86793 .2632 L
s
0 0 0 r
.17681 .21166 m
.17789 .20928 L
s
.17326 .26743 m
.17309 .26479 L
s
.86862 .2151 m
.86943 .22373 L
s
.255 .412 .882 r
.86707 .25367 m
.86748 .25947 L
s
.86687 .25312 m
.86729 .25892 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86895 .21256 m
.87121 .26493 L
s
.86917 .21316 m
.87144 .26549 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86765 .2096 m
.86862 .2151 L
s
.17364 .26631 m
.17326 .26743 L
s
.86706 .20841 m
.86765 .2096 L
s
.17364 .26631 m
.17423 .26143 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1734 .29055 m
.17681 .21166 L
s
.17365 .29001 m
.17706 .21106 L
s
.86658 .21096 m
.86706 .20841 L
s
.86624 .21037 m
.86706 .20841 L
s
.17423 .26143 m
.17503 .25279 L
s
.87047 .26326 m
.87144 .26549 L
s
.86656 .21787 m
.86658 .21096 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86621 .21728 m
.86624 .21037 L
s
.17271 .29217 m
.17365 .29001 L
s
.86656 .21787 m
.86834 .25935 L
s
.17968 .20947 m
.18021 .20513 L
s
.17968 .20947 m
.17989 .21264 L
s
.18021 .20513 m
.18043 .20829 L
s
.86621 .21728 m
.868 .2588 L
s
.17989 .21264 m
.18043 .20829 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17751 .27644 m
.17908 .23145 L
s
.17677 .27752 m
.17908 .23145 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86688 .25713 m
.86834 .25935 L
s
.86208 .20071 m
.86304 .22337 L
s
.17713 .27698 m
.17811 .25415 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86162 .20012 m
.86304 .22337 L
s
.255 .412 .882 r
.18518 .24908 m
.18605 .24796 L
s
.8566 .20936 m
.85691 .20973 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17677 .27752 m
.17681 .28462 L
s
.17681 .28462 m
.17751 .27644 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85765 .24605 m
.85847 .24697 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8645 .25761 m
.86501 .28006 L
s
.8645 .25761 m
.86547 .2806 L
s
.86025 .22373 m
.86154 .2543 L
s
.255 .412 .882 r
.85617 .23426 m
.85552 .23103 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8533 .19133 m
.86208 .20071 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85752 .23564 m
.86089 .23899 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85517 .19308 m
.85852 .27365 L
s
.85577 .19366 m
.85913 .27418 L
s
.85664 .27206 m
.86547 .2806 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20431 .2312 m
.20532 .22897 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83672 .21358 m
.83679 .21474 L
s
.83658 .21335 m
.83659 .21463 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83804 .24898 m
.83804 .24896 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83803 .24895 m
.83804 .24898 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76732 .18429 m
.76739 .18634 L
s
.76845 .22093 m
.76845 .22111 L
s
.76884 .18583 m
.76886 .18671 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33039 .1366 m
.34132 .13449 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70134 .13399 m
.70328 .13838 L
s
.69956 .13771 m
.70134 .13399 L
s
.70152 .14209 m
.70328 .13838 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69956 .13771 m
.70152 .14209 L
s
.36844 .10171 m
.38217 .09969 L
s
.33708 .1595 m
.35391 .15658 L
s
.35253 .13251 m
.364 .13064 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.334 .13589 m
.34499 .21942 L
s
.34526 .20703 m
.35824 .13156 L
s
.34499 .21942 m
.36015 .13125 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68047 .1305 m
.68441 .13516 L
s
.68441 .13516 m
.68641 .13953 L
s
.68641 .13953 m
.68666 .15175 L
s
.67267 .12933 m
.68047 .1305 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68474 .15145 m
.68658 .14767 L
s
.66881 .13284 m
.67267 .12933 L
s
.68482 .15553 m
.68666 .15175 L
s
.68095 .15494 m
.68474 .15145 L
s
.68103 .15902 m
.68482 .15553 L
s
.6669 .13664 m
.66881 .13284 L
s
.66477 .12823 m
.6669 .13664 L
s
.66477 .12823 m
.66506 .14454 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37549 .14112 m
.3796 .13243 L
s
.3796 .13243 m
.38366 .12782 L
s
.38366 .12782 m
.38767 .1273 L
s
.67131 .16172 m
.68095 .15494 L
s
.66506 .14454 m
.6669 .13664 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67139 .16582 m
.68103 .15902 L
s
.38767 .1273 m
.39163 .13087 L
s
.38767 .1273 m
.39365 .13063 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70253 .18694 m
.70309 .21162 L
s
.70121 .21131 m
.70198 .16242 L
s
.70198 .16242 m
.70496 .21193 L
s
.68532 .1801 m
.68709 .17219 L
s
.68709 .17219 m
.68742 .18861 L
s
.64664 .12595 m
.65475 .12693 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37267 .18652 m
.37429 .10083 L
s
.37466 .18626 m
.37625 .10054 L
s
.39163 .13087 m
.39555 .13856 L
s
.39365 .13063 m
.39759 .13832 L
s
.70327 .21988 m
.70496 .21193 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6626 .16081 m
.6636 .16583 L
s
.66465 .16233 m
.66542 .16602 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68347 .18392 m
.68532 .1801 L
s
.68532 .1801 m
.68742 .18861 L
s
.66742 .16529 m
.67131 .16172 L
s
.70121 .21131 m
.70327 .21988 L
s
.64261 .12957 m
.64683 .13821 L
s
.63638 .12482 m
.64261 .12957 L
s
.6675 .1694 m
.67139 .16582 L
s
.67965 .18748 m
.68347 .18392 L
s
.39555 .13856 m
.39739 .15061 L
s
.63223 .1244 m
.63638 .12482 L
s
.39759 .13832 m
.39944 .15038 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6655 .16914 m
.66742 .16529 L
s
.62813 .12808 m
.63223 .1244 L
s
.62604 .12788 m
.63223 .1244 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66558 .17325 m
.6675 .1694 L
s
.37489 .1739 m
.37872 .18161 L
s
.67178 .18639 m
.67965 .18748 L
s
.36676 .18733 m
.37466 .18626 L
s
.6655 .16914 m
.66565 .17737 L
s
.62615 .13607 m
.62813 .12808 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39727 .15883 m
.39739 .15061 L
s
.62405 .13588 m
.62604 .12788 L
s
.42045 .12778 m
.4268 .12312 L
s
.41616 .13636 m
.42045 .12778 L
s
.42254 .12758 m
.4268 .12312 L
s
.4268 .12312 m
.43101 .12276 L
s
.39931 .1586 m
.39944 .15038 L
s
.41825 .13616 m
.42254 .12758 L
s
.66565 .17737 m
.66772 .18175 L
s
.43101 .12276 m
.4352 .12651 L
s
.43101 .12276 m
.43733 .12635 L
s
.66772 .18175 m
.67178 .18639 L
s
.41391 .14888 m
.41616 .13636 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.416 .14868 m
.41825 .13616 L
s
.37872 .18161 m
.38265 .18523 L
s
.39502 .17142 m
.39727 .15883 L
s
.59419 .12128 m
.60913 .12234 L
s
.39707 .17119 m
.39931 .1586 L
s
.4352 .12651 m
.43937 .1344 L
s
.43733 .12635 m
.4415 .13424 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62405 .13588 m
.62463 .18126 L
s
.62615 .13607 m
.62674 .18144 L
s
.64664 .12595 m
.64754 .18348 L
s
.64868 .12619 m
.64959 .1837 L
s
.4138 .15711 m
.41391 .14888 L
s
.38265 .18523 m
.38669 .18474 L
s
.41589 .15691 m
.416 .14868 L
s
.39081 .18014 m
.39502 .17142 L
s
.45448 .12108 m
.46962 .12027 L
s
.39285 .1799 m
.39707 .17119 L
s
.38669 .18474 m
.39081 .18014 L
s
.38669 .18474 m
.39285 .1799 L
s
.43937 .1344 m
.44138 .14659 L
s
.4138 .15711 m
.41572 .1693 L
s
.4415 .13424 m
.44352 .14644 L
s
.41589 .15691 m
.41782 .1691 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49078 .12171 m
.49078 .12001 L
s
.48862 .12042 m
.48862 .12002 L
s
.5 Mabswid
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57039 .12003 m
.58557 .12077 L
s
.47832 .11989 m
.49362 .1194 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64135 .18283 m
.64959 .1837 L
s
.54635 .11928 m
.56167 .1197 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44129 .15484 m
.44138 .14659 L
s
.41572 .1693 m
.41981 .1772 L
s
.51337 .12318 m
.51777 .11904 L
s
.51777 .11904 m
.52217 .11903 L
s
.51117 .1232 m
.51777 .11904 L
s
.44343 .15469 m
.44352 .14644 L
s
.52217 .11903 m
.52657 .12315 L
s
.52217 .11903 m
.52877 .12316 L
s
.41782 .1691 m
.42192 .17701 L
s
.50676 .13148 m
.51117 .1232 L
s
.50896 .13146 m
.51337 .12318 L
s
.52877 .12316 m
.53318 .13142 L
s
.255 .412 .882 r
.50801 .16076 m
.50802 .15743 L
s
0 0 0 r
.52657 .12315 m
.53098 .1314 L
s
.43902 .1674 m
.44129 .15484 L
s
.44116 .16725 m
.44343 .15469 L
s
.50453 .1439 m
.50676 .13148 L
s
.41981 .1772 m
.4261 .18081 L
s
.50673 .14386 m
.50896 .13146 L
s
.53318 .13142 m
.53541 .14382 L
s
.53098 .1314 m
.5332 .1438 L
s
.42192 .17701 m
.4261 .18081 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61829 .18073 m
.62674 .18144 L
s
.43466 .176 m
.43902 .1674 L
s
.43679 .17584 m
.44116 .16725 L
s
.255 .412 .882 r
.51237 .15782 m
.51421 .15741 L
s
0 0 0 r
.4261 .18081 m
.43035 .18047 L
s
.255 .412 .882 r
.51019 .16074 m
.51237 .15782 L
s
0 0 0 r
.43035 .18047 m
.43466 .176 L
s
.255 .412 .882 r
.48775 .165 m
.48844 .16406 L
s
0 0 0 r
.50451 .15217 m
.50453 .1439 L
s
.50672 .15214 m
.50673 .14386 L
s
.43035 .18047 m
.43679 .17584 L
s
.53541 .14382 m
.53542 .1521 L
s
.5332 .1438 m
.53321 .15208 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48846 .15789 m
.48846 .15748 L
s
.49062 .15919 m
.49063 .15748 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55039 .16549 m
.55158 .16392 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57691 .12032 m
.57722 .16571 L
s
.57908 .12043 m
.57941 .16581 L
s
.60061 .12171 m
.60118 .17949 L
s
.60275 .12186 m
.60333 .17963 L
s
.55511 .11949 m
.55535 .1774 L
s
.55292 .11943 m
.55314 .17734 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46027 .20777 m
.46095 .12071 L
s
.46246 .20767 m
.46311 .12059 L
s
.48445 .20682 m
.48486 .11966 L
s
.48666 .20675 m
.48705 .11959 L
s
.50451 .15217 m
.50669 .16458 L
s
.50672 .15214 m
.5089 .16456 L
s
.59471 .17908 m
.60333 .17963 L
s
.53323 .16452 m
.53542 .1521 L
s
.53102 .16451 m
.53321 .15208 L
s
.57728 .17402 m
.57941 .16581 L
s
.5751 .17392 m
.57722 .16571 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5553 .16492 m
.55974 .17336 L
s
.57074 .1779 m
.57728 .17402 L
s
.57074 .1779 m
.5751 .17392 L
s
.50669 .16458 m
.5111 .17285 L
s
.5089 .16456 m
.51331 .17283 L
s
.52881 .17281 m
.53323 .16452 L
s
.5266 .1728 m
.53102 .16451 L
s
.55974 .17336 m
.56635 .17774 L
s
.56635 .17774 m
.57074 .1779 L
s
.5111 .17285 m
.51774 .17697 L
s
.51331 .17283 m
.51774 .17697 L
s
.52217 .17696 m
.52881 .17281 L
s
.52217 .17696 m
.5266 .1728 L
s
.54652 .17719 m
.55535 .1774 L
s
.60139 .20032 m
.60359 .20464 L
s
.59927 .20437 m
.60139 .20032 L
s
.60147 .20869 m
.60359 .20464 L
s
.51774 .17697 m
.52217 .17696 L
s
.59927 .20437 m
.60147 .20869 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45373 .20811 m
.46246 .20767 L
s
.47783 .20703 m
.48666 .20675 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA00000004000001H0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400@0?bP40D0[Jf]SP2`h>H10?ooo`00X@2`h>H50:f][A80ojHA1000000I0?nV
4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1040:f][HX0/>3V0@3oool009d0
/>3V102][JdG0?nV4@040:f][@3oYQ400000000001T0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]00<0[Jf]QP2`h>H10?ooo`00V@2`h>H40:f][@03
0?nT4@2][Jd0ojHA01P0ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS
40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][H80/>3V0@3oool009D0
/>3V102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2]
[Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f]
[Gh0/>3V0@3oool00980/>3V0`2][Jd90?nT4@030:f][@3oYQ40ojHA01L0ojHA00@0[Jf]0?nV4@00
000000006@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL
3`3fW0l02`3fW0l40:f][GX0/>3V0@3oool008h0/>3V102][Jd<0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@
01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][GH0/>3V0@3oool008X0/>3V102][Jd@0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS
40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][G<0/>3V0@3oool008L0
/>3V0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2]
[Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0:f][@020:f][G00/>3V0@3oool008@0/>3V0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV
4@@000002`3oYQ03000000/0ojH@1000000M0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3P
iP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00@0[Jf]0?nV4@00000000006@3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@T0000000<0ojHA0:f]
[@2][Jd01P00000<0:f][@8000000`2][Jd2000000`0[Jf]1P0000030:f][@T000000`3oYA040000
00D0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40102][Jd0ojHA00000000000I0?nV
4@<000001@3oYQ490:f][@800000102][Jd50?nV4@040000003oYQ400000045Yh@X0ojH@0P000005
0?nV408000002P3oYQ000`2][Jd000000000000:0?nU4080000000<0ojD@0:f][@2][Jd01`2][Jd5
000000H0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40102][Jd0ojHA00000000000E0?nV4@<0[Jf]00@00000
0:f][@2][Jd0[Jf]0P0000030:f][@T0ojHA0P0000090?nV4@030000003oYQ40000000X0ojH@0P00
00060?nV40030000003oYQ00000000T0ojH@00<0[Jf]0000000000002P3oYA02000000X0ojD@0P00
00040?nU40030:f][@3oXa00oj<@0080oj<@1@2][Jd3000000030:f][@3oXa00oj<@00`0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2]
[JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00@0[Jf]0?nV4@00000000001@3oYQ400`000000ojHA0?nV4@030?nV4@X0[Jf]00D0
ojHA000000000000ojHA0:f][@030?nV4@8000002`3oYQ42000000T0ojHA00<000000?nV4@000000
2P3oYQ000`000000ojH@0?nV40060?nV408000002@3oYQ000`2][Jd000000000000:0?nU40800000
2P3oYA02000000@0ojD@00<0[Jf]0?nS403oXa001@3oXa02000000<0oj<@00@000000:f][@2][Jd0
[Jf]1@0000020:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`03
0:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00D0[Jf]0?nV4@00000000000?nV4@020:f][@80
000000<0[Jf]0000000000000`2][Jd:0?nV4@8000000P3oYQ40102][Jd0ojHA0?nV4@3oYQ420000
00/0ojHA0P0000090?nV4@030000003oYQ40000000T0ojH@0P0000080?nV40030000003oYQ000000
00P0ojH@00<0[Jf]0000000000002P3oYA02000000X0ojD@0P0000040?nU40030:f][@3oXa00oj<@
00@0oj<@0P0000050?nS40030000003oXa00oj<@008000001@3oXa020:f][@040000002][Jd0[Jf]
0:f][@8000005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ
0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
0180ojHA0`0000040:f][@80000000<0[Jf]0?nV4@000000103oYQ42000000/0ojHA0P0000030?nV
4@030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000002@3oYQ400`000000ojHA000000090?nV
40030000003oYQ00ojH@00P0ojH@00<000000?nV400000001`3oYQ000`2][Jd000000000000:0?nU
408000002P3oYA02000000@0ojD@00<0[Jf]0?nS403oXa00103oXa02000000H0oj<@00@000000?nS
4000000000001`3oXa001P000000oj<@0:f][@000000o:0@0:f][@<000000P2][JdB0?bP40030:f]
[@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2]
[JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403`3oYQ4400000080[Jf]0P3o
YQ401P2][Jd0ojHA000000000000ojHA000000D0ojHA0P00000;0?nV4@8000000`3oYQ400`2][Jd0
ojHA0?nV4@020?nV4@8000002P3oYQ42000000T0ojHA00<000000?nV4@000000203oYQ02000000X0
ojH@00<000000?nV400000001`3oYQ000`2][Jd000000000000:0?nU408000002P3oYA02000000@0
ojD@00<0[Jf]0?nS403oXa000`3oXa02000000L0oj<@00@000000?nS4000000000001`3oXa000`00
0000oj<@000000060?bP40030000003lX100[Jf]00@0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80
[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3o
YQ401`3oYQ43000000030?nV4@2][Jd0[Jf]00<0[Jf]00<0ojHA000000000000103oYQ400`2][Jd0
ojHA00000002000000L0ojHA0P0000090?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@030?nV4@80
00002@3oYQ42000000T0ojHA00<000000?nV4@000000203oYQ02000000/0ojH@0P0000070?nV4003
0:f][@000000000000X0ojD@0P00000:0?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS4080
0000203oXa03000000L0oj<@0P0000000`2][Jd0o:0@0?bP40050?bP40030000003lX100o:0@00<0
o:0@0P2][Jd00`000000[Jf]0:f][@080?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00@0ojHA
0`0000040:f][@H0ojHA0P0000040?nV4@030:f][@3oYQ400000008000001`3oYQ42000000T0ojHA
0P0000040?nV4@030:f][@3oYQ40ojHA00<0ojHA0P0000090?nV4@8000002@3oYQ400`000000ojHA
000000080?nV408000002`3oYQ02000000L0ojH@00<0[Jf]0000000000002P3oYA02000000X0ojD@
0P0000040?nU40030:f][@3oXa00oj<@00<0oj<@0P0000080?nS40<000001`3oXa02000000030:f]
[@3lX100o:0@00D0o:0@00<000000?bP403lX100103lX10200000080o:0@1P2][Jd20?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]
F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@050:f][@030000003oYQ40ojHA00T0ojHA00<0
00000?nV4@3oYQ400`3oYQ40102][Jd0ojHA0000000000090?nV4@800000203oYQ42000000@0ojHA
00<0[Jf]0?nV4@3oYQ400`3oYQ42000000T0ojHA0P0000090?nV4@030000003oYQ40000000L0ojH@
0P00000<0?nV40030000003oYQ00000000H0ojH@00<0[Jf]0000000000002P3oYA02000000X0ojD@
0P0000040?nU40030:f][@3oXa00oj<@00<0oj<@0P0000090?nS408000001`3oXa02000000030:f]
[@3lX100o:0@00H0o:0@00<000000?bP403lX1000`3lX1000`000000o:0@000000070?bP40@0[Jf]
5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo
001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A102]
[Jd50?nV4@030000003oYQ40ojHA00P0ojHA0P0000050?nV4@040:f][@3oYQ400000000000T0ojHA
0P0000080?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000T0ojHA
00<000000?nV4@0000001`3oYQ02000000`0ojH@00<000000?nV400000001P3oYQ000`2][Jd00000
0000000:0?nU408000002P3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000T0oj<@
0P0000070?nS40030000003oXa00[Jf]00P0o:0@00<000000?bP403lX1000`3lX102000000X0o:0@
00<0[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA00H0ojHA00<000000?nV4@3oYQ40203o
YQ42000000D0ojHA00@0[Jf]0?nV4@00000000002@3oYQ42000000L0ojHA0P0000040?nV4@030:f]
[@3oYQ40ojHA00D0ojHA0P0000080?nV4@8000002@3oYQ400`000000ojHA000000070?nV40800000
3@3oYQ02000000H0ojH@00<0[Jf]0000000000002P3oYA02000000X0ojD@0P0000040?nU40030:f]
[@3oXa00oj<@00<0oj<@0P0000090?nS408000001`3oXa000`000000oj<@0:f][@080?bP40030000
003lX100o:0@00@0o:0@00<000000?bP403lX100203lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]
3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo
001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102]
[Jd50?nT4@030:f][@3oYQ40ojHA00H0ojHA00<000000?nV4@3oYQ401`3oYQ42000000D0ojHA00@0
[Jf]0?nV4@00000000002@3oYQ42000000L0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00D0ojHA
0P0000080?nV4@8000002@3oYQ400`000000ojHA000000070?nV408000003@3oYQ02000000H0ojH@
00<0[Jf]0000000000002P3oYA000`000000ojD@000000090?nU40800000103oYA000`2][Jd0oj<@
0?nS40030?nS408000002@3oXa02000000L0oj<@00<000000?nS402][Jd0203lX1000`000000o:0@
0?bP400?0?bP40030:f][@3fW0l0mY`?00L0mY`?102][Jd90?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3o
Y1400`2][Jd0ojHA0?nV4@060?nV4@030000003oYQ40ojHA00L0ojHA0P0000050?nV4@040:f][@3o
YQ400000000000X0ojHA0P0000060?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000
203oYQ42000000T0ojHA00<000000?nV4@0000001`3oYQ02000000d0ojH@0P0000060?nV40030:f]
[@000000000000X0ojD@00<000000?nU400000002@3oYA02000000@0ojD@00<0[Jf]0?nS403oXa00
0`3oXa02000000T0oj<@0P0000090?nS40030:f][@3lX100o:0@00H0o:0@00<000000?bP403lX100
3`3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA00H0ojHA00<0
00000?nV4@3oYQ401`3oYQ42000000D0ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000H0ojHA
0P0000040?nV4@030:f][@3oYQ40ojHA00D0ojHA0P0000080?nV4@8000002@3oYQ400`000000ojHA
000000070?nV408000003@3oYQ02000000H0ojH@00<0[Jf]0000000000002P3oYA000`000000ojD@
000000090?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa02000000X0oj<@
00<0[Jf]0?bP403lX1001@3lX1000`000000o:0@0?bP400?0?bP40030:f][@3fW0l0mY`?00l0mY`?
102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0
D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA00H0ojHA00<000000?nV4@3oYQ401`3o
YQ400`000000ojHA0?nV4@040?nV4@040:f][@3oYQ400000000000X0ojHA0P0000060?nV4@800000
103oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42000000T0ojHA00<000000?nV4@000000
1`3oYQ02000000d0ojH@0P0000060?nV40040:f][@000000ojD@000000T0ojD@00<000000?nU4000
00002@3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000T0oj<@0P00000:0?nS4003
0:f][@3lX100o:0@00@0o:0@0P00000A0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2][JdA0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0
dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA
00H0ojHA00<000000?nV4@3oYQ401P3oYQ42000000H0ojHA00@0[Jf]0?nV4@00000000002P3oYQ42
000000H0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00D0ojHA0P0000080?nV4@8000002@3oYQ40
0`000000ojHA000000070?nV408000003@3oYQ02000000H0ojH@00@0[Jf]0000003oYA0000002@3o
YA000`000000ojD@000000090?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3o
Xa02000000X0oj<@00<0[Jf]0?bP403lX1000`3lX1000`000000o:0@0000000A0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0
[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd0
3@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA
0?nV4@060?nV4@030000003oYQ40ojHA00H0ojHA0P0000060?nV4@040:f][@3oYQ400000000000X0
ojHA0P0000060?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42000000T0
ojHA00<000000?nV4@0000001`3oYQ02000000d0ojH@0P0000060?nV40040:f][@000000ojD@0000
00T0ojD@00<000000?nU400000002@3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000`3oXa020000
00T0oj<@0P00000:0?nS40030:f][@3lX100o:0@0080o:0@00<000000?bP400000004P3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3C
Q`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ400`000000ojHA0?nV4@030?nV4@D0
00001P3oYQ40102][Jd0ojHA00000000000:0?nV4@8000001P3oYQ42000000@0ojHA00<0[Jf]0?nV
4@3oYQ401@3oYQ42000000P0ojHA0P0000040?nV4@D0[Jf]00<000000:f][@0000001`2][Jd20000
00`0[Jf]00<000000:f][@0000001`2][Jd00`000000[Jf]000000040:f][@D0ojD@00<000000?nU
400000002@3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000T0oj<@0P00000:0?nS
40070:f][@3lX100o:0@0?bP40000000o:0@0000000C0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ45000000<0ojHA0P0000060?nV4@040:f][@3oYQ40
0000000000X0ojHA0P0000060?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000202]
[Jd2000000@0[Jf]1@3oYQ4010000000ojHA00000011JN460?nV40800000303oYQ02000000L0ojH@
00@0[Jf]0000003oYA000000103oYA050:f][@030000002][Jd0000000P0[Jf]00<0ojD@00000000
0000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa02000000X0oj<@00H0[Jf]0?bP4000
000000000?bP4000000D0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh3
0:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0
/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40203oYQ400`000000ojHA0?nV4@050?nV4@8000001P3oYQ40102][Jd0ojHA00000000000:
0?nV4@8000001P3oYQ42000000/0[Jf]0P0000090?nV4@8000002@3oYQ400`000000ojHA00000008
0?nV408000002`3oYQ02000000L0ojH@00@0[Jf]0000003oYA0000002@3oYA000`000000ojD@0000
00080?nU40030:f][@000000000000T0[Jf]00<0oj<@0000000000002@3oXa02000000X0oj<@00D0
[Jf]0000003lX100o:0@0000000E0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
2P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f]
[@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH
400;0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA00P0ojHA00<000000?nV4@3oYQ401@3oYQ400`000000ojHA0?nV4@050?nV4@040:f]
[@3oYQ400000000000X0ojHA0P0000060:f][@800000103oYQ400`2][Jd0ojHA0?nV4@040?nV4@80
00002@3oYQ42000000T0ojHA00<000000?nV4@000000203oYQ02000000X0ojH@00<000000?nV4000
00001`3oYQ00102][Jd000000?nU400000090?nU40030000003oYA00000000T0ojD@0P0000040?nU
40030:f][@3oXa00oj<@0080oj<@00<0[Jf]0000000000001`2][Jd20?nS408000002P3oXa001000
0000o:0@00000000000<0?bP40030000003lX100o:0@00L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@080?nV4@030000003oYQ40ojHA00@0ojHA0P0000070?nV4@050:f][@3oYQ40
00000000003oYQ40202][Jd2000000P0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00
00080?nV4@8000002P3oYQ42000000030:f][@3oYQ00ojH@00H0ojH@0P00000:0?nV40030000003o
YQ00000000L0ojH@00@0[Jf]0000003oYA0000002@3oYA000`000000ojD@000000090?nU40800000
103oYA000`2][Jd0oj<@0?nS40030?nS408000001`3oXa020:f][@8000001P2][Jd20?nS40800000
00<0[Jf]0000003lX1003@3lX1000`000000o:0@0?bP40070?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V
0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@0P2][Jd@0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ400`000000ojHA0?nV4@040?nV4@8000001@3o
YQ440:f][@80000000<0[Jf]0?nV4@3oYQ401P3oYQ42000000P0ojHA0P0000030?nV4@030:f][@3o
YQ40ojHA00@0ojHA0P0000080?nV4@8000002P3oYQ42000000030:f][@3oYQ00ojH@00L0ojH@0P00
00080?nV40030000003oYQ00000000P0ojH@00@0[Jf]0000003oYA0000002@3oYA000`000000ojD@
000000090?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa02000000H0oj<@
00D0[Jf]0000002][Jd0[Jf]000000030:f][@`0o:0@00<000000?bP403lX1001`3lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]
4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA00<000000?nV4@3oYQ40
103oYQ42000000D0[Jf]0P3oYQ40102][Jd0ojHA0000000000090?nV4@800000203oYQ42000000<0
ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA000000080?nV4@8000002P3oYQ4200000003
0:f][@3oYQ00ojH@00L0ojH@0P0000080?nV408000002@3oYQ000`2][Jd000000?nU4002000000P0
ojD@0P00000:0?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa02000000L0
oj<@0`000000102][Jd0o:0@0?bP403lX1060:f][@H0o:0@00<000000?bP403lX1001`3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd90=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0
Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@030000003oYQ40ojHA00@0
[Jf]0P0000070?nV4@040:f][@3oYQ400000000000T0ojHA0P0000080?nV4@8000000`3oYQ400`2]
[Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000X0ojHA0P0000000`2][Jd0ojH@0?nV40080?nV
408000001P3oYQ000`000000ojH@000000090?nV40030:f][@000000ojD@008000001`3oYA000`00
0000ojD@0000000:0?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa020000
00L0oj<@00@000000?nS403oXa00[Jf]2@3lX1060:f][@030000003lX100o:0@00L0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd7
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102]
[Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd40>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060?nV4@<0[Jf]00<00000
0:f][@3oYQ400`3oYQ42000000L0ojHA00@0[Jf]0?nV4@00000000002@3oYQ42000000T0ojHA0P00
00020?nV4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@0000002@3oYQ42000000X0ojHA0P00
00000`2][Jd0ojH@0?nV40090?nV408000001@3oYQ02000000X0ojH@00H0[Jf]0000003oYA000000
0?nU400000060?nU408000002`3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000T0
oj<@0P0000070?nS40040000003oXa00oj<@0:f][@L0o:0@00<000000?bP403lX1001@3lX1000`00
0000[Jf]0:f][@040:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0=^:3@3KRPd0103KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h0
0`2][Jd0kiP@0>nH40040>nH40030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0[Jf]0`3oYQ400`000000ojHA0?nV4@03
0?nV4@030000003oYQ40ojHA00H0ojHA00@0[Jf]0?nV4@0000000000203oYQ42000000X0ojHA0P00
00020?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000002P3oYQ42000000030:f][@3o
YQ00ojH@00X0ojH@0P0000030?nV408000002`3oYQ00102][Jd000000?nU400000020?nU40030000
003oYA00ojD@00<0ojD@0P00000;0?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS40800000
2@3oXa02000000L0oj<@00@000000?nS403oXa00[Jf]1`3lX1000`000000o:0@0?bP40050?bP4003
0000003lX100o:0@00@0o:0@1@2][JdE0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3K
RPd01@3KRPd20:f][@@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]
04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@
0080kiP@0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404P3oY1440:f]
[@T0ojHA00<000000?nV4@3oYQ400P3oYQ42000000P0ojHA00<0[Jf]0?nV4@0000000P0000070?nV
4@8000002`3oYQ42000000030?nV4@2][Jd0ojHA0080ojHA00<000000?nV4@0000002P3oYQ420000
00X0ojHA0P0000000`2][Jd0ojH@0?nV400<0?nV40<000002`3oYQ06000000<0ojD@00@000000?nU
403oYA00ojD@0P00000<0?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa02
000000L0oj<@00@000000?nS403oXa00[Jf]1P3lX102000000L0o:0@00<000000?bP403lX1001`3l
X1000`2][Jd0mY`?0:f][@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:
3@070=^:3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0
A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V100
0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403P3oY1440:f][@030?nT
4@2][Jd0ojHA00X0ojHA00<000000?nV4@3oYQ400P3oYQ42000000P0ojHA00<0[Jf]0?nV4@000000
0P0000060?nV4@8000003@3oYQ42000000030:f][@3oYQ40ojHA00<000002`3oYQ42000000X0ojHA
0P0000000`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@0`00000;0?nU40D00000
103oYA000`2][Jd0oj<@0?nS40030?nS408000002@3oXa02000000L0oj<@00@000000?nS403oXa00
[Jf]1P3lX102000000L0o:0@00<000000?bP403lX1001`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0
[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00T0fhX=0`2][Jd90;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;
09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0`2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1402P3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA
0?nV4@020?nV4@800000203oYQ401P2][Jd0ojHA000000000000ojHA000000D0ojHA0P00000?0?nV
4@@000003@3oYQ42000000X0ojHA0P0000000`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa001@0000090?nS40800000203oXa000`000000oj<@0:f][@060?bP
408000001`3lX1000`000000o:0@0?bP40070?bP40030:f][@3fW0l0mY`?00L0mY`?102][Jd90?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A00L0oj@A0`2][Jd90?nT4@030:f][@3oYQ40ojHA00T0ojHA00<000000?nV
4@3oYQ400P3oYQ42000000P0ojHA00@0[Jf]0?nV4@00000000000P3oYQ4010000000ojHA0?nV4@3o
YQ4200000100ojHA00<0[Jf]0?nV4@3oYQ403P3oYQ42000000X0ojHA0P0000000`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa05000000P0oj<@00<0
00000?nS402][Jd01@3lX103000000L0o:0@00<000000?bP403lX1001`3lX1000`2][Jd0mY`?0?JL
3`0;0?JL3`@0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2]
[Jd80;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd<0>nH40030:f][@3lX100o:0@0100o:0@00<0
[Jf]0?nT4@3oY1400`3oY1440:f][@`0oj@A00<0[Jf]0?nV4@3oYQ402P3oYQ4010000000ojHA0?nV
4@3oYQ42000000P0ojHA00@0[Jf]0?nV4@00000000000`3oYQ4300000180ojHA00<0[Jf]0?nV4@3o
YQ403P3oYQ42000000X0ojHA0P0000000`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006@3oXa02000000D0o:0@0`0000070?bP40030000003lX100o:0@00L0
o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL3`2][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd0102][Jd0^GD;0:f][@2][Jd60;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3P
iP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd00`3C
Q`h0[Jf]0>nH400;0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd@0?nT
4@030:f][@3oYQ40ojHA00X0ojHA00@000000?nV4@3oYQ40ojHA0P0000070?nV4@D00000603oYQ40
0`2][Jd0ojHA0?nV4@0>0?nV4@8000002P3oYQ42000000030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@000000000000<000000P3lX100
0`000000o:0@0?bP40040?bP408000002@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@050=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd0303_V1000`2][Jd0o:0@0?bP400?0?bP40<0[Jf]
503oY1400`2][Jd0ojHA0?nV4@0:0?nV4@030000003oYQ40ojHA00800000203oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00h0ojHA0P00000:0?nV4@80000000<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
1@3lX1000`000000o:0@0?bP40040?bP40<00000203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;
00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`
h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@
0>nH400:0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA00X0ojHA00<000000?nV4@3oYQ400P0000080?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ403P3oYQ42000000X0ojHA0P0000000`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400<0?bP40<00000
203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`000000[Jf]00@0
R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h00`2][Jd0
dhL>0=>73P030=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@@0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0:0?nV4@030000003oYQ40ojHA0080
0000203oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00h0ojHA0P00000:0?nV4@80
000000<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100303lX103000000P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0
^GD;0P2][Jd00`2iM@/0000008QF1`0308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;
09MP2`2GH0/0[Jf]0=>73P80[Jf]1P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@
00L0o:0@0`2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402P3oYQ400`00
0000ojHA0?nV4@02000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0>0?nV
4@8000001@3oYQ450:f][@8000009`2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100303lX103000000T0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF
3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0000
000000000`28EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>7
3P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@T0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0:0?nV4@030000003oYQ40ojHA00800000203oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA2@2][Jd2000000D0[Jf]1@3oYQ420000
00030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400<0?bP40<000002@3lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/2000000@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40020?bP
4080[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00/0ojHA00@000000?nV
4@0000000000203oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]2@3oYQ42000000X0ojHA0P000000
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01D0ojD@302][JdH0?nS40030:f][@3lX100
o:0@00`0o:0@0`0000090?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh3
0:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`000000[Jf]00000003
08QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd>0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ43000000T0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f]
[@@0ojHA00<0[Jf]0?nV4@3oYQ403P3oYQ42000000X0ojHA0P0000000`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01H0ojD@00<000000?nU403oYA000`3oYA000`2][Jd0oj<@0?nS40020?nS
40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400<0?bP40<000002@3lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;00@000000:f]
[@28EPL000000P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;
0080[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA00/0ojHA0`0000090?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV
4@030:f][@3oYQ40ojHA00h0ojHA0P00000:0?nV4@80000000<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400E0?nU40030000003oYA00000000@0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f]
[@@0oj<@00<0[Jf]0?bP403lX100303lX103000000T0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0
10000000R5H70:f][@00000208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]
0000002][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00T0kiP@0`2][JdB0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ43000000H0ojHA202][JdH0?nV4@030:f][@3o
YQ40ojHA00h0ojHA0P00000:0?nV4@80000000<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400E0?nU40040000003oYA00ojD@000000<0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][@/0o:0@
0`0000090?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=
0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/010000000R5H708QF1`00000208QF
1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]0000002][Jd0Uf0;0:f][@080=>7
3P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@<000001P2][Jd30?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ403P3oYQ42000000L0ojHA1@0000000`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01H0ojD@0P0000040?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP
403lX100o:0@1`2][Jd40?bP40<000002@3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0
1`000000R5H708QF1`000000[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H200000080Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ440:f][@030000002]
[Jd0000000T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@<000003P3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01L0ojD@00<000000?nU403oYA000P3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00P0o:0@102][Jd3000000T0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2]
[Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00L00000045Yh@28EPL000000:f][@28EPL000000480
/>3V0@3oool005P0/>3V00<000000:f][@0000000P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f]
[@3_V100kiP@00<0kiP@0P2][Jd60>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
503oY140102][Jd0ojHA0?nV4@3oYQ460:f][@@0ojHA00<000000?nV4@0000002@3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100303lX103000000H0
[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd01`3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@000000R5H708QF1`000000R5H7
00800000@P2`h>H10?ooo`00F02`h>H00`000000[Jf]0000000209MP2`030:f][@3CQ`h0dhL>00H0
dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd80>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1450:f][@/0ojHA00<000000?nV4@3oYQ40203oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100303lX1000`000000o:0@000000060?bP
40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3K
RPd0@FWQ0;Ue2`070;Ue2`0400000028EPL0R5H708QF1`@00000@@2`h>H10?ooo`00E`2`h>H20000
00050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0102][Jd0kiP@0:f][@2][Jd:0>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA00d0ojHA00<0
00000?nV4@3oYQ40203oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100303lX1000`000000o:0@000000090?bP40030:f][@3fW0l0mY`?00@0[Jf]403f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd80;Ue2`8000000P28
EPL400000440/>3V0@3oool005L0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2]
[Jd<0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0
[Jf]0?nV4@3oYQ40303oYQ400`000000ojHA0?nV4@080?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400=0?bP40030000003lX100o:0@00P0o:0@00<0
[Jf]0?JL3`3fW0l0103fW0l50:f][@/0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0<0=^:3@80[Jf]1`2iM@/200000080R5H7100000110;3PiP40oooo001G0;3PiP80000000D0[Jf]
09MP2`2GH0/0Uf0;0:f][@070=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA00`0ojHA00<000000?nV4@3oYQ40203o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003@3l
X1000`000000o:0@0?bP40080?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0:f][@2][Jd50;Ue2`800000
0P28EPL400000440/>3V0@3oool005L0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>
00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00<0oj@A
102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@00d0o:0@00<000000?bP403lX100203lX1000`2][Jd0mY`?
0?JL3`0>0?JL3`@0[Jf]00<0mY`?045Yh@2][Jd04P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f]
[@2iM@/0^GD;0;Ue2`2][Jd0102iM@/200000080R5H70P0000000`2][Jd00000000000100;3PiP40
oooo001G0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P040:f][@3CQ`h0dhL>0:f]
[@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;0080^GD;00@0[Jf]0;Ue2`2iM@/0^GD;0`0000001028EPL000000000002]
[Jd200000400/>3V0@3oool005L0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>0P2]
[Jd30=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00<0[Jf]0;Ue2`2iM@/00`00
000208QF1`040000002][Jd0000000000400/>3V0@3oool005L0/>3V0P0000001@2][Jd0Uf0;09MP
2`2GH0/0[Jf]0080dhL>00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd300000080R5H700@000000:f][@000000
0000@02`h>H10?ooo`00E`2`h>H2000000070:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0:f][@060=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT
4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`<000000P28EPL010000000[Jf]0000000000100;3PiP40oooo001G0;3PiP<000000`2GH0/20:f]
[@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2]
[Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
00H0^GD;0`00000208QF1`040000002][Jd0000000000400/>3V0@3oool005L0/>3V0`00000309MP
2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP
40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0`00000208QF
1`040000002][Jd0000000000400/>3V0@3oool005L0/>3V0`00000209MP2`80[Jf]1`3CQ`h00`2]
[Jd0kiP@0>nH400<0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@05
0?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0
fhX=00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/200000080R5H700@000000:f][@0000000000@02`
h>H10?ooo`00E`2`h>H300000080Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]
0?bP402][Jd0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`80000000@0[Jf]08QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3PiP<0000000@0
Uf0;0:f][@2GH0/0[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40<0[Jf]403lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V
3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/300000003
08QF1`000000000000800000@02`h>H10?ooo`00E`2`h>H3000000040:f][@2GH0/0Uf0;0:f][@L0
dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH402][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0
[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3K
RPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00P0000008QF1`000000[Jf]08QF1`00
0000[Jf]00000400/>3V0@3oool005L0/>3V0`000000102][Jd0Uf0;09MP2`2][Jd70=>73P030:f]
[@3_V100kiP@00L0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l0
5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00P0000008QF1`000000R5H70:f][@000000[Jf]00000400/>3V0@3oool0
05H0/>3V1000000309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f]
[@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`00
0000R5H700000028EPL0[Jf]0000002][Jd00P00000o0;3PiP40oooo001F0;3PiP@000000`2GH0/0
0`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd70>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H5
0:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00L0fhX=0P2][Jd20=^:3@03045Yh@2][Jd0^GD;00L0^GD;00<0000008QF1`0000000P28EPL0
10000000[Jf]00000000000o0;3PiP40oooo001F0;3PiP@000000P2GH0/00`11JN40[Jf]0=>73P06
0=>73P040:f][@3_V100kiP@0>nH4080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?
0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@030=^:
3@2][Jd0^GD;00L0^GD;00<000000:f][@0000000P28EPL010000000[Jf]00000000000o0;3PiP40
oooo001F0;3PiP80000000D0[Jf]0000002GH0/0Uf0;0:f][@080=>73P040:f][@3_V100[Jf]0:f]
[@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f]
[AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/00`00
0000[Jf]0000000208QF1`040000002][Jd00000000003l0/>3V0@3oool005H0/>3V0P0000001@2]
[Jd0000009MP2`2GH0/0[Jf]00P0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0303KRPd30:f][@H0^GD;00<000000:f][@0000000P28EPL010000000[Jf]00000000
000o0;3PiP40oooo001F0;3PiP@000000P2GH0/00`2][Jd0dhL>0=>73P050=>73P80[Jf]3P3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1@2i
M@/300000080R5H700@000000:f][@0000000000?`2`h>H10?ooo`00EP2`h>H400000080Uf0;00<0
[Jf]0=>73P3CQ`h00`3CQ`h20:f][@030=>73P2][Jd0kiP@00`0kiP@00<0[Jf]0?bP403lX100403l
X1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0102iM@/20000000508QF
1`000000R5H70000002][Jd00P00000o0;3PiP40oooo001F0;3PiP@000000P2GH0/00`2][Jd0dhL>
0=>73P020=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP4003
0:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Jd20;Ue2`80000000D0R5H700000028
EPL00000045Yh@02000003l0/>3V0@3oool005H0/>3V1000000209MP2`050:f][@3CQ`h0dhL>0=>7
3P2][Jd0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3P
iP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00T0[Jf]0;Ue
2`000000000008QF1`000000R5H70:f][@11JN400P00000o0;3PiP40oooo001F0;3PiP@000000P2G
H0/0102][Jd0dhL>0:f][@2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1@2iM@/01`2][Jd0000000000028EPL0000008QF1`2][Jd00`00000o0;3PiP40oooo001F0;3PiP@0
00000P2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080
[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20000000508QF1`000000R5H708QF1`2][Jd00P00000o
0;3PiP40oooo001F0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f]
[@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80000000D0[Jf]0000
0028EPL0R5H70:f][@02000003l0/>3V0@3oool005H0/>3V0`00000209MP2`80[Jf]203CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;Vb
YP<0[Jf]kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/2000000050:f][@000000000008QF1`2][Jd00P00000o0;3PiP40oooo001F0;3P
iP<000000P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP
4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk
00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;
00H0^GD;0P0000001@28EPL0[Jf]00000028EPL0[Jf]00800000?`2`h>H10?ooo`00EP2`h>H30000
000409MP2`2][Jd0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@02
0:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd5
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]
0;Ue2`2iM@/01P2iM@/20000000508QF1`2][Jd0000008QF1`2][Jd00P00000o0;3PiP40oooo001F
0;3PiP<0000000@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2i
M@/0^GD;00L0^GD;0P0000001028EPL0000008QF1`2][Jd2000003l0/>3V0@3oool005H0/>3V0`00
0000102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/0102][Jd0000008QF1`0000020:f][@800000?`2`h>H10?ooo`00EP2`h>H3000000<0Uf0;
00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;
00@0[Jf]08QF1`00000000000P2][Jd2000003l0/>3V0@3oool005H0/>3V0`00000309MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80
[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0
[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28
EPL0000008QF1`020:f][@030000002`h>H0/>3V03d0/>3V0@3oool005H0/>3V0`00000309MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd01@2TWXl0@FWQ0:BNS`2TWXl0
[Jf]00@0/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f][@2]
[Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`
h>H0/>3V03d0/>3V0@3oool005H0/>3V0`00000209MP2`030:f][@3CQ`h0dhL>00L0dhL>00@0[Jf]
0>nH402][Jd0[Jf]0`2TWXl2045Yh@030:BNS`2][Jd0/J^M00D0/J^M0P2][Jd50;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/0H0[Jf]Z@2`
h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n
^KP0_[Vh0;ji^080[Jf]1`2n^KP01@11JN40[Jf]0;B`/@11JN40];2a0080[Jf]00<0fhX=0:f][@2i
M@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030;3PiP000000/>3V03d0/>3V0@3oool005H0
/>3V0P00000309MP2`030:f][@3CQ`h0dhL>00L0dhL>0P2][Jd00`2TWXl0@FWQ0:BNS`020:BNS`04
045Yh@2TWXl0Y9j?0:f][@P0/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@T0_[Vh00<0@FWQ
0:f][@2d/;400P11JN420;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030;3PiP00
0000/>3V03d0/>3V0@3oool005D0/>3V0`00000309MP2`030:f][@3CQ`h0dhL>00H0dhL>00D0[Jf]
0:BNS`2TWXl0Y9j?045Yh@030:BNS`04045Yh@2TWXl0Y9j?0:f][@80/J^M0P11JN460;6[W@80[Jf]
00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`
1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03033_K/30:f][@L0_[Vh00L0@FWQ0;ji^02n^KP0_[Vh045Yh@2][Jd0];2a
0080@FWQ0`2d/;400`11JN40[Jf]0:f][@080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0/>3V
0000002`h>H0?@2`h>H10?ooo`00E@2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@04045Yh@2TWXl0Y9j?045Yh@@0Y9j?00@0@FWQ0:BNS`2TWXl0[Jf]0P11JN400`2aZid0@FWQ
0;6[W@070;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00L0
_[Vh00L0@FWQ0;ji^02n^KP0_[Vh045Yh@2][Jd0];2a0080@FWQ0`2d/;401011JN40];2a0;B`/@2]
[Jd70;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0/>3V0000002`h>H0?@2`h>H10?ooo`00E@2`
h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00<0dhL>0`2][Jd01011JN40Y9j?0:BN
S`11JN440:BNS`05045Yh@2TWXl0[Jf]0;6[W@11JN400`2aZid00`11JN40/J^M0;6[W@060;6[W@03
0:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0
_[Vh0;ji^0020;ji^004045Yh@2n^KP0_[Vh045Yh@@0_[Vh00<0@FWQ0;ji^02][Jd00P11JN430;B`
/@04045Yh@2d/;40];2a0;B`/@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030;3PiP00
0000/>3V03d0/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P02
0=>73P050:f][@2:QGD0RXEe0:f][@11JN400P2TWXl00`11JN40Y9j?0:BNS`020:BNS`05045Yh@2T
WXl0[Jf]0;6[W@11JN400`2aZid00`11JN40/J^M0;6[W@020;6[W@05045Yh@2aZid0/J^M0;6[W@2]
[Jd01@2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00T0[Jf]0;ji^02n
^KP0_[Vh045Yh@2n^KP0@FWQ0;ji^011JN40102n^KP2045Yh@030:f][@11JN40@FWQ00<0];2a00<0
@FWQ0;B`/@2d/;401@2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0/>3V0000002`h>H0
?@2`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`060:f][@3CQ`h0dhL>0=>73P2][Jd0
@FWQ0P2:QGD2045Yh@030:f][@2TWXl0@FWQ00@0Y9j?00<0@FWQ0:BNS`2][Jd00P11JN440;6[W@09
045Yh@2aZid0/J^M0;6[W@11JN40/J^M045Yh@2aZid0[Jf]00P0^K:V0`2][Jd50;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00@0
[Jf]0;ji^02n^KP0@FWQ0P2n^KP3045Yh@@0_[Vh0P11JN400`2][Jd0@FWQ045Yh@030;B`/@03045Y
h@2d/;40[Jf]0080];2a00@0[Jf]09nKX02OVj00[Jf]0P2iM@/0102][Jd0R5H708QF1`28EPL20:f]
[@030;3PiP000000/>3V03d0/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/01@2][Jd0
dhL>0:f][@2][Jd0@FWQ00<0RXEe0P11JN400`2TWXl0[Jf]045Yh@040:BNS`04045Yh@2TWXl0[Jf]
045Yh@D0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN400`2aZid0@FWQ045Yh@0;0;VbYP@0[Jf]00<0
^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]3P33_K/0102][Jd0_[Vh045Y
h@11JN430;ji^080@FWQ102n^KP3045Yh@030;B`/@11JN40@FWQ0080];2a00<0@FWQ0:f][@2d/;40
0P2d/;40102][Jd0Wi^P09nKX011JN430:f][@@0R5H700<0[Jf]0;3PiP000000?P2`h>H10?ooo`00
E@2`h>H00`000000[Jf]09MP2`0309MP2`80[Jf]1P2:QGD2045Yh@80Y9j?00@0@FWQ0:f][@2TWXl0
Y9j?0P11JN400`2TWXl0[Jf]045Yh@090;6[W@06045Yh@2aZid0/J^M0;6[W@2][Jd0@FWQ3P2i/ZH3
0:f][A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`4
0:f][@030<K0_02][Jd0`kfk00T0`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0_[Vh045Yh@04
0;ji^080@FWQ102n^KP3045Yh@030;B`/@11JN40@FWQ0080[Jf]00<0@FWQ0;B`/@2d/;400P2d/;40
0`2][Jd0Wi^P045Yh@0309nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP000000?P2`h>H1
0?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@2:QGD0RXEe00D0RXEe0P11JN420:BN
S`04045Yh@2TWXl0[Jf]0:f][@80@FWQ00<0Y9j?0:f][@11JN402@2aZid01P11JN40/J^M0;6[W@2a
Zid0[Jf]045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH0202i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l
00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/01@33_K/3045Yh@D0`kfk
00<0[Jf]0;ji^011JN40102n^KP2045Yh@<0_[Vh1@11JN40102d/;40@FWQ0;B`/@2d/;42045Yh@<0
];2a00<0[Jf]09nKX02OVj00102OVj001`2][Jd0R5H708QF1`28EPL0[Jf]0;3PiP000000?P2`h>H1
0?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1`2:QGD2045Yh@80Y9j?00@0@FWQ0:BN
S`2TWXl0Y9j?0P11JN400`2TWXl0[Jf]045Yh@090;6[W@06045Yh@2aZid0/J^M0;6[W@2][Jd0@FWQ
0`2i/ZH00`11JN40^K:V045Yh@090;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f]
[@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f]
[@36`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk00@0`kfk0`11JN470<>m^`030:f]
[@11JN40_[Vh00<0_[Vh0P11JN430;ji^0D0@FWQ00@0[Jf]045Yh@2d/;40];2a0P11JN430;B`/@03
045Yh@2OVj00Wi^P00@0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001E0;3PiP03
0000002][Jd0Uf0;0080Uf0;0P2][Jd708Z5M@80@FWQ0P2TWXl01011JN40Y9j?0:BNS`2TWXl2045Y
h@80[Jf]00<0@FWQ0;6[W@2aZid02`2aZid00`2][Jd0@FWQ0;VbYP030;VbYP03045Yh@2i/ZH0^K:V
00P0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2]
[Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0
_0030:f][@33_K/0`kfk00D0`kfk0P11JN470<>m^`030:f][@11JN40_[Vh00<0_[Vh0P11JN430;ji
^003045Yh@2n^KP0@FWQ0080@FWQ00@0];2a045Yh@2d/;40];2a0P11JN430;B`/@03045Yh@2OVj00
Wi^P00D0Wi^P00@0[Jf]08QF1`28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`03
0:f][@L0RXEe00<0@FWQ0:BNS`11JN400P11JN430:BNS`80@FWQ00<0Y9j?0:f][@11JN403@2aZid0
0`2][Jd0@FWQ0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A00a/2l1011JN45
0<>m^`80@FWQ1`33_K/00`2][Jd0@FWQ0;ji^0030;ji^080@FWQ0`2n^KP00`11JN40[Jf]045Yh@02
045Yh@80];2a00@0@FWQ0;B`/@11JN40@FWQ0`2d/;400`11JN40Wi^P09nKX00509nKX080[Jf]00<0
R5H70:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0
[Jf]045Yh@2TWXl01P2TWXl2045Yh@050:BNS`2][Jd0@FWQ045Yh@2][Jd02`2aZid00`2][Jd0@FWQ
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`03036`;`3045Yh@040<K0
_02][Jd0@FWQ045Yh@D0`kfk0P11JN470<>m^`030:f][@11JN40@FWQ00@0_[Vh00D0@FWQ0;ji^02]
[Jd0[Jf]045Yh@020;ji^080@FWQ0P2d/;401011JN40];2a045Yh@11JN430;B`/@03045Yh@2OVj00
Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]
08Z5M@2:QGD0102:QGD00`2][Jd0@FWQ0:BNS`060:BNS`80@FWQ00D0Y9j?0:f][@11JN40@FWQ0;6[
W@020:f][@03045Yh@2aZid0/J^M00D0/J^M0`11JN4?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37
`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`02P36`;`3045Yh@<0a/2l00@0[Jf]0<>m^`11JN40@FWQ
1033_K/2045Yh@L0`kfk00<0[Jf]045Yh@11JN401@11JN40102][Jd0_[Vh0;ji^011JN420;ji^080
@FWQ0P2d/;42045Yh@030;B`/@11JN40];2a0080];2a00<0@FWQ09nKX02OVj00102OVj020:f][@03
071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]1@2:QGD00`2][Jd0@FWQ
0:BNS`050:BNS`<0@FWQ00@0Y9j?0:f][@11JN40@FWQ0`2aZid00`11JN40[Jf]0:f][@030;6[W@@0
@FWQ402i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00`0
a/2l00D0@FWQ0<K0_036`;`0a/2l0:f][@020<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN470<>m
^`040:f][@2n^KP0_[Vh0;ji^080[Jf]00<0_[Vh045Yh@2n^KP00P2n^KP00`11JN40_[Vh0;ji^004
045Yh@<0];2a00@0@FWQ0;B`/@2d/;40];2a0P11JN4409nKX0030:f][@2OVj00[Jf]0080L6ii0P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD0
0`2][Jd0@FWQ0:BNS`060:BNS`80@FWQ00@0Y9j?0:f][@2aZid0@FWQ0`2aZid2045Yh@030;6[W@2]
[Jd0[Jf]00<0@FWQ00<0/J^M0:f][@2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00A0;jg[0030:f][@31
^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdA0<O1_0030:f][@36
`;`0a/2l00`0a/2l00D0@FWQ0<K0_036`;`0a/2l0:f][@020<>m^`80@FWQ0`33_K/2045Yh@L0`kfk
00@0[Jf]0;ji^02][Jd0[Jf]0`2n^KP01@11JN40_[Vh0;ji^02n^KP0@FWQ0080_[Vh0P11JN450;B`
/@04045Yh@2d/;40];2a0;B`/@80@FWQ0`2OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`
h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe0:f][@<0RXEe00<0
[Jf]045Yh@2TWXl02@2TWXl00`2][Jd0/J^M045Yh@030;6[W@80@FWQ0P2aZid2045Yh@80[Jf]00<0
/J^M0:f][@2i/ZH0102i/ZH00`11JN40^K:V0;VbYP070;VbYP030:f][@2n]j`0_[N/0140_[N/00<0
[Jf]0<6j/031^[003`31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0140al6l00<0
[Jf]0<K0_036`;`03036`;`01@11JN40a/2l0<K0_036`;`0[Jf]0080`kfk0P11JN430<>m^`80@FWQ
1P33_K/30:f][@D0_[Vh00P0@FWQ0;ji^02n^KP0_[Vh045Yh@2n^KP0@FWQ0:f][@H0];2a0P11JN42
0;B`/@80@FWQ00<0Wi^P0:f][@2][Jd00`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe0P11JN4:
0:BNS`030:f][@2aZid0@FWQ00<0/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@030;6[W@<0[Jf]102i
/ZH00`11JN40^K:V0;VbYP070;VbYP030:f][@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/031^[000P31
^[02045Yh@d0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX00`37
`KX7045Yh@/0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k
00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_00<0<K0_005045Yh@36`;`0a/2l0<K0_02]
[Jd00P33_K/2045Yh@@0`kfk00@0@FWQ0<>m^`33_K/0`kfk0`2][Jd01033_K/0[Jf]0;ji^011JN44
0;ji^004045Yh@2n^KP0_[Vh0;ji^080@FWQ00<0_[Vh0:f][@2d/;401@2d/;42045Yh@050;B`/@11
JN40[Jf]045Yh@2][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@040:f][@2:QGD0[Jf]045Yh@X0Y9j?
00<0[Jf]0;6[W@2aZid01011JN430;6[W@03045Yh@2aZid0/J^M0080/J^M00<0[Jf]045Yh@2][Jd0
0P2][Jd00`2i/ZH0@FWQ0;VbYP080;VbYP030:f][@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/031^[00
1031^[04045Yh@T0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00D0al6j0P11JN4>0<O1^P030:f]
[@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00L0al6l00<0@FWQ0<O1_037`K`0
1`37`K`00`2][Jd0a/2l0<K0_00<0<K0_005045Yh@36`;`0a/2l0<K0_02][Jd00`33_K/00`11JN40
`kfk0<>m^`020<>m^`04045Yh@2][Jd0[Jf]0:f][@@0`kfk00<0[Jf]0;ji^011JN400`2n^KP01@11
JN40_[Vh0;ji^02n^KP0@FWQ00<0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`11JN40];2a045Yh@02
0:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C
0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@/0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid00`11
JN40/J^M0;6[W@020;6[W@030:f][@11JN40^K:V0080^K:V00<0[Jf]045Yh@2][Jd0202i/ZH00`2]
[Jd0_[N/0;jg[00A0;jg[0030:f][@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j/031^[000`11JN460<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00D0al6j0P11JN4>0<O1
^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]045Y
h@11JN401P37`K`00`11JN40al6l045Yh@080<O1_0030:f][@36`;`0a/2l00`0a/2l00D0@FWQ0<K0
_036`;`0a/2l0:f][@030<>m^`06045Yh@33_K/0`kfk0<>m^`2][Jd0@FWQ1033_K/01P11JN40`kfk
0<>m^`2][Jd0_[Vh045Yh@80_[Vh00<0@FWQ0;ji^02n^KP01P2n^KP00`2][Jd0];2a0;B`/@060;B`
/@03045Yh@2d/;40[Jf]00L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00P0/J^M00H0@FWQ0;6[W@2aZid0/J^M0:f][@11JN440;VbYP03045Yh@2i
/ZH0[Jf]00<0[Jf]102i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00H0`KZ`00<0
@FWQ0<6j/031^[000`31^[02045Yh@@0`KZ`00<0[Jf]045Yh@11JN400P11JN4A0<>m/`030:f][@35
_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX01@37
`KX2045Yh@<0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00l0b<6k00<0@FWQ0<S1^`38`K/00P11
JN420<O1_080@FWQ1@37`K`00`11JN40al6l0<O1_0070<O1_0030:f][@36`;`0a/2l00`0a/2l00D0
@FWQ0<K0_036`;`0a/2l0:f][@030<>m^`05045Yh@2][Jd0[Jf]0:f][@33_K/00P11JN420<>m^`80
@FWQ0P33_K/00`2][Jd0_[Vh045Yh@03045Yh@P0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;430:f][@L0
Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=P
D`2][Jd01`2:QGD30:f][@H0Y9j?00@0@FWQ0:BNS`2TWXl0[Jf]2`2aZid00`11JN40/J^M0;6[W@02
045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH30:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]
0<6j/031^[001P31^[000`11JN40`KZ`0<6j/0030<6j/080@FWQ1031^[000`2][Jd0`kfc0<>m/`04
045Yh@l0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]b/0[Jf]0P11JN43
0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`050<S1^`80@FWQ2038`K/0
1@11JN40b<6k045Yh@38`K/0[Jf]00<0al6l00<0@FWQ0<O1_037`K`03@37`K`00`2][Jd0a/2l0<K0
_00<0<K0_006045Yh@36`;`0a/2l0<K0_02][Jd0`kfk0P2][Jd00`11JN40`kfk0<>m^`020<>m^`80
@FWQ0P33_K/2045Yh@80`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@050;B`/@04
0:f][@2d/;40];2a0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3P
iP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@<0Y9j?0P11JN42
0:BNS`030:f][@2aZid0/J^M00X0/J^M0P11JN400`2][Jd0@FWQ0;VbYP030;VbYP03045Yh@2i/ZH0
^K:V00H0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`00H0`KZ`00<0@FWQ0<6j/031^[001031^[02
045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN4>0<>m/`04045Yh@33_K<0`kfc0:f][AH0aKje00<0
[Jf]0<Jo]`36_kL05036_kL00`000000[Jf]0<O1^00E0<O1^0030:f][@37`KX0al6j00D0al6j0P11
JN4>0<O1^P030:f][@38`K/0b<6k0180b<6k0`11JN450<S1^`80@FWQ0P38`K/2045Yh@H0b<6k0P11
JN420<S1^`050:f][@37`K`0al6l0<O1_011JN403`37`K`00`2][Jd0a/2l0<K0_00<0<K0_003045Y
h@36`;`0[Jf]00<0[Jf]0P33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ0`33_K/01011JN40`kfk
0<>m^`2][Jd=0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f]
[@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl01@2][Jd0Y9j?0:BNS`2TWXl0@FWQ0080Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0@FWQ0;VbYP020;VbYP80@FWQ2@2i/ZH00`2][Jd0_[N/0:f][@03
0:f][@d0_[N/00<0[Jf]0<6j/031^[001P31^[000`11JN40`KZ`0<6j/0040<6j/080@FWQ0`31^[00
0`2][Jd0`kfc0<>m/`02045Yh@`0`kfc0P11JN401033_K<0@FWQ045Yh@2][Jd40<Fn]@80@FWQ4035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX01@37
`KX2045Yh@h0al6j00<0[Jf]0<S1^`38`K/02@38`K/3045Yh@80b<6k1011JN420<S1^`030:f][@38
`K/0b<6k0080b<6k0P11JN450<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN420<S1^`050:f][@37
`K`0al6l0<O1_011JN403`37`K`00`2][Jd0a/2l0<K0_0090<K0_0<0[Jf]00D0@FWQ0:f][@36`;`0
a/2l0:f][@030<>m^`80@FWQ0`33_K/00`11JN40`kfk045Yh@03045Yh@80`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP0102][Jd0];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102]
[Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP02
0;VbYP80@FWQ2@2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/006
0<6j/003045Yh@31^[00`KZ`00D0`KZ`00D0@FWQ0<6j/031^[00`KZ`0:f][@020<>m/`80@FWQ2`33
_K<2045Yh@@0`kfc0P11JN400`35_[D0@FWQ045Yh@080<Fn]@03045Yh@35_[D0aKje00<0aKje00D0
@FWQ0<Fn]@35_[D0aKje0:f][@0G0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
1@37`KX2045Yh@h0al6j1P11JN430<S1^`@0@FWQ1`38`K/01011JN40b<6k0<S1^`2][Jd30<S1^`80
@FWQ1`38`K/00`11JN40b<6k0<S1^`020<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd00`37`K`00`11
JN40al6l0<O1_00=0<O1_0030:f][@36`;`0a/2l00D0a/2l102][Jd30<K0_005045Yh@36`;`0a/2l
0<K0_02][Jd00`33_K/2045Yh@<0`kfk00<0@FWQ0<>m^`33_K/01@33_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0040:f][@2d/;40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^
N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2T
WXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP80@FWQ2@2i
/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/0060<6j/003045Yh@31
^[00`KZ`00D0`KZ`0P11JN420<6j/0030:f][@33_K<0`kfc0080@FWQ2`33_K<2045Yh@@0`kfc00@0
[Jf]045Yh@11JN40@FWQ2@35_[D00`11JN40aKje0<Fn]@030<Fn]@05045Yh@35_[D0aKje0<Fn]@2]
[Jd02@36_kL4045Yh@<0a[ng00<0@FWQ0<Jo]`36_kL00P36_kL3045YhAH0al6h00<0[Jf]0<O1^P37
`KX00P11JN430<O1^P80@FWQ0P37`KX3045Yh@T0al6j00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Y
h@L0b<6k00@0@FWQ0<S1^`38`K/0[Jf]0`38`K/2045Yh@`0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f]
[@030<O1_003045Yh@37`K`0al6l00d0al6l00<0[Jf]0<K0_036`;`01@2][Jd70<K0_080@FWQ0P36
`;`0102][Jd0`kfk0<>m^`33_K/2045Yh@040<>m^`11JN40@FWQ045Yh@L0`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40
oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@d0/J^M
00<0[Jf]0;VbYP2i/ZH00`2i/ZH2045Yh@T0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg
[02][Jd0`KZ`00L0`KZ`00<0@FWQ0<6j/031^[001@31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<0
0P11JN4;0<>m/`80@FWQ1033_K<0102][Jd0aKje045Yh@11JN480<Fn]@80@FWQ1@35_[D01@11JN40
aKje0<Fn]@35_[D0[Jf]00L0a[ng0`11JN430<Jo]`80@FWQ00<0a[ng045Yh@36_kL01@36_kL00`2]
[Jd0@FWQ045Yh@02045Yh@d0al6h1011JN400`37`KP0[Jf]0<O1^P02045Yh@@0al6j0P11JN400`37
`KX0@FWQ0<O1^P020<O1^P80@FWQ1`37`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1`38`K/0
1011JN40b<6k0<S1^`2][Jd30<S1^`80@FWQ4038`K/00`2][Jd0al6l045Yh@02045Yh@D0al6l00<0
@FWQ0<O1_037`K`01@37`K`50:f][@`0a/2l0P11JN420<K0_0040:f][@33_K/0`kfk0<>m^`80@FWQ
2`33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f]
[@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2]
[Jd<0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11JN490;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2]
[Jd50<6j/003045Yh@31^[00`KZ`00H0`KZ`00@0@FWQ0<6j/031^[00[Jf]0P33_K<2045Yh@/0`kfc
0P11JN440<>m/`040:f][@35_[D0@FWQ045Yh@P0aKje0`11JN430<Fn]@03045Yh@35_[D0@FWQ0080
aKje00<0[Jf]0<Jo]`36_kL01036_kL2045Yh@L0a[ng0P11JN460<Jo]`030:f][@11JN40@FWQ00d0
al6h0P11JN440<O1^003045Yh@2][Jd0al6j0080@FWQ1037`KX3045Yh@D0al6j0P11JN460<O1^P04
0:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN470<S1^`04045Yh@38`K/0b<6k0:f][@80b<6k0P11JN4A
0<S1^`040:f][@11JN40@FWQ045Yh@H0al6l00<0@FWQ0<O1_037`K`01@2][Jd20<O1_0030:f][@36
`;`0a/2l00`0a/2l0P11JN420<K0_0050:f][@33_K/0`kfk0<>m^`11JN403033_K/00`2][Jd0_[Vh
0;ji^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]
@P2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f]
[@020:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH2045Yh@T0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`0102][Jd0`KZ`0<6j/031^[050:f][@03045Yh@2][Jd0`KZ`00H0`KZ`0P11JN401@31^[00[Jf]
0<>m/`33_K<0@FWQ00`0`kfc0P11JN440<>m/`040:f][@35_[D0@FWQ045Yh@P0aKje0`11JN430<Fn
]@<0@FWQ0P35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Yh@H0a[ng00<0[Jf]045Y
h@11JN403037`KP2045Yh@H0al6h0`11JN450<O1^P<0@FWQ1P37`KX2045Yh@D0al6j00@0[Jf]0<S1
^`11JN40@FWQ1`38`K/2045Yh@L0b<6k00@0@FWQ0<S1^`38`K/0[Jf]0P38`K/2045YhA40b<6k0P11
JN460<O1_080[Jf]00<0@FWQ0:f][@2][Jd01`37`K`00`2][Jd0a/2l0<K0_00<0<K0_080@FWQ0P36
`;`01@2][Jd0`kfk0<>m^`33_K/0@FWQ00`0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh
00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`
h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2a
Zid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH2045Yh@T0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/0060<6j/003045Yh@31^[00[Jf]00H0[Jf]0P11JN401031^[00[Jf]0<>m
/`33_K<2045Yh@/0`kfc0P11JN440<>m/`040:f][@35_[D0@FWQ045Yh@P0aKje00<0@FWQ0<Fn]@11
JN400`35_[D3045Yh@80aKje00<0[Jf]0<Jo]`36_kL01036_kL2045Yh@P0a[ng00<0@FWQ0<Jo]`36
_kL01036_kL00`2][Jd0@FWQ045Yh@0<0<O1^080@FWQ1`37`KP2045Yh@D0al6j0P11JN470<O1^P80
@FWQ1@37`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1`38`K/01011JN40b<6k0<S1^`2][Jd2
0<S1^`80@FWQ4038`K/2045Yh@80al6l1@2][Jd20<O1_003045Yh@37`K`0al6l00L0al6l00<0[Jf]
0<K0_036`;`03036`;`2045Yh@80a/2l00D0[Jf]0<>m^`33_K/0`kfk045Yh@0<0<>m^`030:f][@2n
^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102O
Vj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;VbYP03
0;VbYP80@FWQ2@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`0P11JN48
0<6j/080@FWQ102][Jd2045Yh@`0`kfc00<0@FWQ0<>m/`33_K<00P33_K<0102][Jd0aKje045Yh@11
JN470<Fn]@80@FWQ00<0aKje045Yh@35_[D00P35_[D3045Yh@80aKje00<0[Jf]0<Jo]`36_kL00`36
_kL2045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`2][Jd0@FWQ045Yh@0<0<O1^080@FWQ1`37
`KP2045Yh@D0al6j0P11JN470<O1^P03045Yh@37`KX0@FWQ00@0al6j00@0[Jf]0<S1^`11JN40@FWQ
1`38`K/2045Yh@L0b<6k00@0@FWQ0<S1^`38`K/0[Jf]0P38`K/2045Yh@h0b<6k0`11JN430:f][@80
al6l00<0@FWQ0<O1_037`K`00P37`K`00`11JN40al6l0<O1_0070<O1_0030:f][@36`;`0a/2l00`0
a/2l0P11JN430<K0_0040:f][@33_K/0@FWQ045Yh@`0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd8
0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP12
0;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2]
[Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH0102i/ZH2045Yh@T0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/080@FWQ2031^[02045Yh@040<6j/02][Jd0`kfc
0<>m/`80@FWQ1P2][Jd70<>m/`<0@FWQ00<0`kfc0:f][@35_[D00P11JN470<Fn]@80@FWQ00<0aKje
045Yh@35_[D00P35_[D00`11JN40aKje045Yh@020<Fn]@030:f][@36_kL0a[ng00<0a[ng0P11JN49
0<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0[Jf]045Yh@11JN403037`KP2045Yh@L0al6h0P11JN45
0<O1^P80@FWQ2037`KX2045Yh@@0al6j00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@L0b<6k00@0
@FWQ0<S1^`38`K/0[Jf]0P38`K/2045Yh@L0b<6k00<0@FWQ0:f][@2][Jd00`2][Jd3045Yh@030<S1
^`2][Jd0al6l00<0al6l00<0@FWQ0<O1_037`K`00P37`K`00`11JN40al6l0<O1_0070<O1_0030:f]
[@36`;`0a/2l00`0a/2l0P11JN430<K0_0040:f][@33_K/0@FWQ045Yh@`0`kfk00@0[Jf]0;ji^02]
[Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3P
iP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@@0^K:V00<0@FWQ0;VbYP2i/ZH0202i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`0P11JN480<6j/004045Yh@31^[00`KZ`0:f]
[@80`kfc0P11JN460<>m/`P0[Jf]0P33_K<2045Yh@030<Fn]@11JN40@FWQ00L0aKje0P11JN401035
_[D0@FWQ0<Fn]@35_[D2045Yh@050<Fn]@11JN40aKje0<Fn]@2][Jd01@36_kL2045Yh@T0a[ng00<0
@FWQ0<Jo]`36_kL01036_kL00`2][Jd0@FWQ045Yh@0<0<O1^080@FWQ1`37`KP2045Yh@D0al6j0P11
JN480<O1^P80@FWQ1037`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1`38`K/2045Yh@040<S1
^`2][Jd0b<6k0<S1^`80@FWQ1`2][Jd2045Yh@@0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@030<O1
_080@FWQ1037`K`00`11JN40al6l0<O1_0070<O1_0030:f][@36`;`0a/2l00`0a/2l0P11JN430<K0
_0040:f][@33_K/0@FWQ045Yh@/0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]
09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd00`11JN40^K:V0;VbYP080;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[02045Yh@P0`KZ`00@0@FWQ0<6j
/031^[00[Jf]0P33_K<2045Yh@h0`kfc102][Jd3045Yh@80[Jf]1@35_[D01P11JN40aKje0<Fn]@35
_[D0@FWQ0<Fn]@80@FWQ0P35_[D00`11JN40aKje0:f][@040<Jo]`80@FWQ2P36_kL00`11JN40a[ng
0<Jo]`040<Jo]`030:f][@11JN40@FWQ00d0al6h0P11JN460<O1^080@FWQ1@37`KX2045Yh@P0al6j
0P11JN440<O1^P040:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN450<S1^`80[Jf]0P11JN450:f][@80
@FWQ1P38`K/2045Yh@@0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@030<O1_080@FWQ1037`K`2045Y
h@P0al6l00<0[Jf]0<K0_036`;`03036`;`2045Yh@<0a/2l00<0[Jf]045Yh@11JN402@33_K/30:f]
[@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3P
iP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0
^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0
`KZ`0P11JN480<6j/004045Yh@31^[00`KZ`0:f][@80`kfc00<0@FWQ0<>m/`11JN401033_K<00`11
JN40`kfc0<>m/`090<>m/`040:f][@35_[D0@FWQ045Yh@80aKje102][Jd2045Yh@<0[Jf]00@0@FWQ
0:f][@11JN40@FWQ0P35_[D00`11JN40aKje0:f][@040<Jo]`80@FWQ1`36_kL7045Yh@<0a[ng00<0
[Jf]045Yh@11JN403P37`KP00`11JN40al6h0<O1^0040<O1^080@FWQ1@37`KX2045Yh@P0al6j0P11
JN440<O1^P040:f][@38`K/0@FWQ045Yh@80b<6k1@2][Jd2045Yh@D0[Jf]0P38`K/2045Yh@030<S1
^`2][Jd0b<6k0080b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k0080b<6k00D0@FWQ0<S1^`38`K/0
b<6k0:f][@020<O1_0<0@FWQ1037`K`2045Yh@T0al6l00<0[Jf]0<K0_036`;`02`36`;`2045Yh@<0
a/2l00<0[Jf]045Yh@11JN401P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0
];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0
302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`00D0`KZ`0P11JN480<6j/004045Yh@31^[00`KZ`0:f][@80`kfc00<0@FWQ0<>m/`11
JN400`33_K<2045Yh@H0`kfc00<0@FWQ0<>m/`33_K<00P33_K<0102][Jd0aKje045Yh@11JN460<Fn
]@80@FWQ0`35_[D01011JN40aKje045Yh@11JN420:f][@03045Yh@2][Jd0[Jf]00@0[Jf]0P11JN45
0:f][@`0a[ng00<0[Jf]045Yh@11JN403`37`KP3045Yh@<0al6h0P11JN450<O1^P80@FWQ0`37`KX5
0:f][@80@FWQ1P2][Jd2045Yh@80[Jf]1@38`K/2045Yh@L0b<6k0P11JN400`38`K/0[Jf]0<S1^`03
0<S1^`03045Yh@38`K/0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/01038`K/01011JN40b<6k0<S1^`2]
[Jd2045Yh@80al6l00<0@FWQ0<O1_037`K`00P37`K`2045Yh@T0al6l00<0[Jf]0<K0_036`;`02`36
`;`2045Yh@80a/2l0`11JN430<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d
/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`08
0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0
_[N/0140_[N/00<0[Jf]0<6j/031^[001@31^[02045Yh@L0`KZ`0P11JN420<6j/0@0@FWQ0P33_K<0
1@11JN40`kfc0<>m/`33_K<0@FWQ00D0`kfc0P11JN440<>m/`030:f][@35_[D0@FWQ00L0aKje0P11
JN430<Fn]@04045Yh@35_[D0@FWQ045Yh@80aKje00<0@FWQ0000002][Jd01036_kL2045Yh@D0a[ng
3@2][Jd2045YhA80[Jf]1@11JN450:f][@80@FWQ0`2][Jd40<O1^P80@FWQ1@37`KX0102][Jd0b<6k
045Yh@11JN470<S1^`80@FWQ1`38`K/2045Yh@030<S1^`2][Jd0b<6k00<0b<6k0P11JN450<S1^`03
045Yh@38`K/0b<6k00D0b<6k0`11JN490<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0
@FWQ00<0a/2l0:f][@33_K/00`2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d
/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M
00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[001@31^[02045Yh@L0`KZ`
0P11JN420<6j/0030:f][@33_K<0`kfc00@0`kfc0`11JN470<>m/`03045Yh@33_K<0`kfc0080`kfc
00<0[Jf]0<Fn]@11JN401`35_[D00`11JN40aKje0<Fn]@020<Fn]@03045Yh@35_[D0@FWQ00<0aKje
00<0@FWQ0<Fn]@2][Jd01036_kL2045YhA00a[ng00@000000:f][@11JN40@FWQ5@37`KP2045Yh@D0
al6j0P11JN470<O1^P80@FWQ1@37`KX0102][Jd0b<6k045Yh@11JN460<S1^`80@FWQ2038`K/2045Y
h@030<S1^`2][Jd0b<6k00@0b<6k1P11JN4:0<S1^`030:f][@37`K`0al6l00L0al6l0P11JN490<O1
_0030:f][@36`;`0a/2l00T0a/2l0`11JN420<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji
^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0
Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0
[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/0050<6j/080@FWQ1`31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33
_K<03`33_K<3045Yh@040<>m/`2][Jd0aKje045Yh@H0aKje0P11JN450<Fn]@80@FWQ1035_[D00`11
JN40[Jf]0<Jo]`030<Jo]`80@FWQ4@36_kL00`2][Jd0@FWQ045Yh@050<O1^003045Yh@37`KP0al6h
00D0al6h0P11JN460<O1^003045Yh@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1@37`KX00`2]
[Jd0b<6k045Yh@02045Yh@D0b<6k0P11JN480<S1^`80@FWQ00<0b<6k0:f][@38`K/05038`K/00`2]
[Jd0al6l0<O1_0070<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2]
[Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f]
[Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/0050<6j/080
@FWQ1P31^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<04P33_K<3045Yh@D0aKje1011JN450<Fn]@80
@FWQ1035_[D00`11JN40[Jf]0<Jo]`030<Jo]`80@FWQ4@36_kL0102][Jd0@FWQ045Yh@11JN430<O1
^003045Yh@37`KP0@FWQ00H0al6h0P11JN460<O1^003045Yh@37`KX0al6j00@0al6j0`11JN450<O1
^P80@FWQ1P37`KX01P2][Jd0b<6k045Yh@11JN40b<6k045Yh@<0b<6k0P11JN470<S1^`@0@FWQ00<0
b<6k0:f][@38`K/05038`K/00`2][Jd0al6l0<O1_0070<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0
_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0
[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[
W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0
[Jf]0<6j/031^[001@31^[02045Yh@H0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D01`35_[D4045Yh@80aKje0P11JN420<Fn]@H0@FWQ0P36_kL2045YhA40a[ng00D0
[Jf]045Yh@11JN40al6h045Yh@030<O1^080@FWQ1`37`KP00`11JN40al6h0<O1^0030<O1^003045Y
h@2][Jd0al6j00D0al6j0P11JN400`37`KX0@FWQ0<O1^P030<O1^P80@FWQ1P37`KX0102][Jd0b<6k
045Yh@11JN420<S1^`@0@FWQ3@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00L0
al6l0P11JN490<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31
^[001031^[04045Yh@D0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`020<Jo]`80@FWQ3`36_kL5045Yh@80al6h1011JN490<O1^0D0
@FWQ00<0al6h0:f][@37`KX00`37`KX4045Yh@80al6j1011JN480<O1^P040:f][@38`K/0@FWQ045Y
h@P0b<6k00<000000<S1^`38`K/02038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00L0al6l0P11JN470<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00l0_[N/1@2][Jd40<6j/0@0@FWQ0`31^[000`11JN40`KZ`0<6j/0030<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`030<Jo]`80
@FWQ2@36_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX02@37`KX00`000000al6j0<O1^P080<O1^P040:f][@38`K/0@FWQ045Yh@H0b<6k00<000000<S1
^`38`K/02P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l00<0@FWQ0<O1
_037`K`01@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]00@0`KZ`045Y
h@11JN40@FWQ1P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL00`36_kL2045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00@0[Jf]0<S1^`11JN40@FWQ4`38`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H3
0:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`030<Jo]`80@FWQ2@36_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k045Yh@11JN4@0<S1^`04045Yh@38
`K/0b<6k0:f][AD0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`
h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL01036
_kL00`11JN40a[ng0<Jo]`070<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P040:f][@38`K/0@FWQ045Yh@l0b<6k00D0@FWQ0<S1^`11JN40
b<6k0:f][@0B0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f]
[@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00@0
a[ng0P11JN480<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P040:f][@38`K/0@FWQ045Yh@l0b<6k0P11JN420<S1^`030:f][@38`K/0b<6k
00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@03
0;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL01@36_kL00`11JN40a[ng0<Jo]`050<Jo]`80@FWQ1P36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00@0[Jf]0<S1^`11JN40@FWQ4038`K/01011JN40b<6k0<S1^`2][Jd3
0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2]
[Jd0a[ng0<Jo]`050<Jo]`80@FWQ1036_kL2045Yh@030<Jo]`11JN40a[ng00D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P@0@FWQ3P38`K/90:f][A80b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3P
iP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0
a[ng0<Jo]`070<Jo]`@0@FWQ0`36_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
3`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
0`33_K/30:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX04P37`KX00`000000al6j0:f]
[@0F0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;VbYP2][Jd0
_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102][Jd@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
0`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`
h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?
0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0
[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k
202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`
h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54256 .33073 m
.53086 .33087 L
s
.51749 .3341 m
.51415 .33087 L
s
.51415 .33087 m
.5108 .33084 L
s
.51916 .33411 m
.51415 .33087 L
s
.5108 .33084 m
.50578 .33399 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56089 .33027 m
.54923 .3306 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53592 .35913 m
.53593 .36625 L
s
.5376 .35913 m
.53761 .36623 L
s
.5 Mabswid
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52499 .33862 m
.52499 .35667 L
s
.52665 .33861 m
.52665 .35667 L
s
.51671 .3386 m
.52168 .34087 L
s
.5134 .33858 m
.51671 .3386 L
s
.51008 .3408 m
.5134 .33858 L
s
.50843 .34078 m
.5134 .33858 L
s
0 0 0 r
.59492 .3286 m
.59724 .32845 L
s
.255 .412 .882 r
.53658 .33853 m
.54815 .33834 L
s
.52168 .34087 m
.52499 .34538 L
s
.50677 .34527 m
.51008 .3408 L
s
.50511 .34525 m
.50843 .34078 L
s
0 0 0 r
.52082 .36632 m
.52206 .35916 L
s
.5225 .36632 m
.52374 .35916 L
s
.50237 .36292 m
.50238 .35921 L
s
.255 .412 .882 r
.5051 .34976 m
.50677 .34527 L
s
.50344 .34973 m
.50511 .34525 L
s
0 0 0 r
.45267 .33196 m
.44777 .32843 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44777 .32843 m
.4499 .33067 L
s
.5 Mabswid
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50343 .35652 m
.5051 .34976 L
s
.50177 .35649 m
.50344 .34973 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5972 .32038 m
.6085 .31955 L
s
.57123 .33984 m
.57614 .33737 L
s
.56962 .34443 m
.57123 .33984 L
s
.57288 .33977 m
.57614 .33737 L
s
.57614 .33737 m
.58105 .33713 L
s
.57126 .34436 m
.57288 .33977 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48366 .33795 m
.49013 .36983 L
s
.4769 .3694 m
.48366 .33795 L
s
.47051 .33743 m
.4769 .3694 L
s
.46373 .36882 m
.47051 .33743 L
s
.47855 .36946 m
.48363 .34472 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52002 .35667 m
.53163 .35664 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54154 .33846 m
.54161 .37012 L
s
.54319 .33844 m
.54327 .37009 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57278 .37294 m
.57279 .37502 L
s
.57444 .37183 m
.57446 .37495 L
s
.255 .412 .882 r
.58105 .33713 m
.58434 .33921 L
s
.56962 .34443 m
.56964 .34895 L
s
.57126 .34436 m
.57129 .34888 L
s
.5034 .36784 m
.50343 .35652 L
s
.54324 .35649 m
.54492 .36326 L
s
.50174 .36782 m
.50177 .35649 L
s
.46538 .3689 m
.47047 .3442 L
s
.58434 .33921 m
.58764 .34355 L
s
.56964 .34895 m
.57131 .35341 L
s
.57129 .34888 m
.57296 .35334 L
s
.45417 .33656 m
.4558 .33665 L
s
.4509 .33861 m
.45417 .33656 L
s
.45252 .33871 m
.45417 .33656 L
s
.58924 .33893 m
.59247 .33648 L
s
.58764 .34355 m
.58924 .33893 L
s
.59247 .33648 m
.5941 .33638 L
s
.59087 .33884 m
.59247 .33648 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58927 .34345 m
.59087 .33884 L
s
.54492 .36326 m
.54825 .36773 L
s
.57131 .35341 m
.57626 .35545 L
s
.45086 .34314 m
.45252 .33871 L
s
.57296 .35334 m
.57626 .35545 L
s
.44923 .34303 m
.4509 .33861 L
s
.55486 .3653 m
.55651 .36299 L
s
.55651 .36299 m
.55817 .36521 L
s
.5034 .36784 m
.50505 .37468 L
s
.50174 .36782 m
.50338 .37466 L
s
.55486 .3653 m
.55653 .36752 L
s
.53663 .37019 m
.54327 .37009 L
s
.54825 .36773 m
.55157 .36992 L
s
.57626 .35545 m
.58611 .35723 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55817 .36521 m
.55818 .36748 L
s
.44603 .33829 m
.44923 .34303 L
s
.44281 .3358 m
.44603 .33829 L
s
.52666 .37253 m
.52667 .38618 L
s
.525 .37935 m
.52666 .37253 L
s
.43796 .33545 m
.44281 .3358 L
s
.48516 .36968 m
.4951 .36995 L
s
.55157 .36992 m
.55654 .36979 L
s
.55654 .36979 m
.55818 .36748 L
s
.57137 .36247 m
.57138 .36474 L
s
.57137 .36247 m
.57301 .3624 L
s
.50505 .37468 m
.5067 .37925 L
s
0 0 0 r
.57279 .37502 m
.57945 .37472 L
s
.255 .412 .882 r
.50338 .37466 m
.50504 .37923 L
s
.57301 .3624 m
.57303 .36467 L
s
.43472 .33746 m
.43796 .33545 L
s
.43311 .33733 m
.43796 .33545 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45072 .35901 m
.45086 .34314 L
s
.44905 .36345 m
.44923 .34303 L
s
.57138 .36474 m
.57304 .36694 L
s
.52167 .38391 m
.525 .37935 L
s
.525 .37935 m
.52667 .38618 L
s
.60389 .3425 m
.60708 .33774 L
s
.60708 .33774 m
.61028 .33523 L
s
.5067 .37925 m
.51002 .38384 L
s
.50504 .37923 m
.50835 .38382 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57304 .36694 m
.57635 .36907 L
s
.58611 .35723 m
.58777 .35941 L
s
.58927 .34345 m
.5894 .35932 L
s
.58764 .34355 m
.5878 .36395 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60205 .32004 m
.60252 .3676 L
s
.60367 .31992 m
.60414 .36749 L
s
.61028 .33523 m
.6135 .33497 L
s
.43306 .34186 m
.43472 .33746 L
s
.6135 .33497 m
.61673 .33697 L
s
.6135 .33497 m
.61833 .33683 L
s
.51667 .38617 m
.52167 .38391 L
s
.43145 .34173 m
.43311 .33733 L
s
.51002 .38384 m
.51334 .38615 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45881 .36857 m
.47031 .36913 L
s
.50835 .38382 m
.51334 .38615 L
s
.5878 .36395 m
.5894 .35932 L
s
.57635 .36907 m
.58292 .36876 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51667 .38617 m
.51334 .38615 L
s
.58618 .36631 m
.5878 .36395 L
s
.61673 .33697 m
.61999 .34122 L
s
.43301 .3464 m
.43306 .34186 L
s
.44905 .36345 m
.45072 .35901 L
s
.43777 .35358 m
.44748 .35653 L
s
.44748 .35653 m
.44909 .3589 L
s
.58292 .36876 m
.58618 .36631 L
s
.4314 .34627 m
.43145 .34173 L
s
.61833 .33683 m
.62159 .34108 L
s
.43301 .3464 m
.43457 .35107 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4474 .36562 m
.44905 .36345 L
s
.4314 .34627 m
.43296 .35094 L
s
.43457 .35107 m
.43777 .35358 L
s
.43296 .35094 m
.43777 .35358 L
s
.61999 .34122 m
.62167 .3479 L
s
.44412 .36769 m
.4474 .36562 L
s
.62159 .34108 m
.62327 .34775 L
s
.60408 .36066 m
.60736 .36498 L
s
.59764 .36792 m
.60414 .36749 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43763 .36724 m
.44412 .36769 L
s
.63263 .33322 m
.64365 .33205 L
s
.62167 .3479 m
.62173 .35245 L
s
.43286 .36004 m
.43447 .36016 L
s
.43445 .36244 m
.43447 .36016 L
s
0 0 0 r
.59122 .39368 m
.59285 .39032 L
s
.59285 .39032 m
.59453 .39349 L
s
.255 .412 .882 r
.39981 .33183 m
.41081 .33302 L
s
.43283 .36232 m
.43286 .36004 L
s
.62327 .34775 m
.62332 .3523 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43442 .36472 m
.43763 .36724 L
s
.43283 .36232 m
.43442 .36472 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62181 .35928 m
.62332 .3523 L
s
.63737 .33273 m
.63805 .38069 L
s
.62021 .35941 m
.62173 .35245 L
s
.60736 .36498 m
.61062 .36702 L
s
.61062 .36702 m
.61385 .36678 L
s
.63894 .33256 m
.63963 .38053 L
s
.61705 .36424 m
.62021 .35941 L
s
.61385 .36678 m
.61705 .36424 L
s
.61385 .36678 m
.61865 .36411 L
s
.61865 .36411 m
.62181 .35928 L
s
.4168 .36095 m
.41842 .35882 L
s
.41842 .35882 m
.41999 .36124 L
s
.41996 .36353 m
.41999 .36124 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40563 .36444 m
.40609 .33253 L
s
.40405 .36428 m
.40451 .33236 L
s
.41833 .36567 m
.41996 .36353 L
s
.4168 .36095 m
.41836 .36338 L
s
0 0 0 r
.64292 .35693 m
.64446 .3535 L
s
.255 .412 .882 r
.41355 .36522 m
.41833 .36567 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6499 .33132 m
.66073 .32997 L
s
.40582 .35073 m
.40731 .35774 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65455 .33076 m
.65496 .35588 L
s
.41041 .36263 m
.41355 .36522 L
s
.40731 .35774 m
.41041 .36263 L
s
.6393 .35762 m
.64252 .36186 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38735 .3326 m
.39037 .33755 L
s
.39037 .33755 m
.39185 .3423 L
s
.38278 .32972 m
.38735 .3326 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39185 .3423 m
.39329 .34934 L
s
.38581 .33241 m
.38882 .33736 L
s
.38882 .33736 m
.3903 .34211 L
s
.38278 .32972 m
.38581 .33241 L
s
.39933 .36378 m
.40563 .36444 L
s
.64252 .36186 m
.64727 .36364 L
s
.3903 .34211 m
.39174 .34915 L
s
.36759 .32757 m
.38278 .32972 L
s
.39311 .36078 m
.39329 .34934 L
s
.39155 .3606 m
.39174 .34915 L
s
.63328 .38114 m
.63963 .38053 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66685 .32915 m
.67746 .32762 L
s
.64727 .36364 m
.6504 .36329 L
s
.39144 .36748 m
.39311 .36078 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65348 .36064 m
.65496 .35588 L
s
.6504 .36329 m
.65504 .36046 L
s
.6504 .36329 m
.65348 .36064 L
s
.6561 .33057 m
.65651 .35569 L
s
.67142 .32851 m
.672 .3606 L
s
.65504 .36046 m
.65651 .35569 L
s
.37274 .37669 m
.37363 .32846 L
s
.38989 .3673 m
.39155 .3606 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67293 .32829 m
.67352 .36039 L
s
.37122 .37649 m
.37211 .32824 L
s
.38981 .3719 m
.39144 .36748 L
s
.38826 .37172 m
.38989 .3673 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38663 .37614 m
.38981 .3719 L
s
.38508 .37595 m
.38826 .37172 L
s
.38195 .37788 m
.38663 .37614 L
s
.66742 .36121 m
.67352 .36039 L
s
.38195 .37788 m
.38508 .37595 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68508 .33333 m
.68796 .32827 L
s
.68372 .34045 m
.68508 .33333 L
s
.68796 .32827 m
.69234 .32524 L
s
.36666 .37586 m
.38195 .37788 L
s
.68656 .33309 m
.68943 .32802 L
s
.68521 .34022 m
.68656 .33309 L
s
.68372 .34045 m
.68381 .34505 L
s
.68943 .32802 m
.69234 .32524 L
s
.68521 .34022 m
.68531 .34482 L
s
.68381 .34505 m
.68544 .35172 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69234 .32524 m
.69527 .32474 L
s
.68531 .34482 m
.68694 .35149 L
s
.67073 .37463 m
.67221 .37212 L
s
.67073 .37463 m
.6723 .37674 L
s
.67221 .37212 m
.67378 .37423 L
s
.69527 .32474 m
.6997 .32626 L
s
.6723 .37674 m
.67378 .37423 L
s
.68544 .35172 m
.68852 .35587 L
s
.68694 .35149 m
.69 .35564 L
s
.6997 .32626 m
.7027 .33034 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69 .35564 m
.69301 .35747 L
s
.68852 .35587 m
.69301 .35747 L
s
.69301 .35747 m
.69742 .35675 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70015 .347 m
.70155 .34444 L
s
.70015 .347 m
.70165 .34906 L
s
.70155 .34444 m
.70305 .34649 L
s
.69742 .35675 m
.7003 .35394 L
s
.71257 .32153 m
.71409 .32586 L
s
.71257 .32153 m
.71278 .33076 L
s
.70305 .34649 m
.70311 .34881 L
s
.7003 .35394 m
.70311 .34881 L
s
.71278 .33076 m
.71409 .32586 L
s
.71409 .32586 m
.71545 .32327 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71545 .32327 m
.7182 .32039 L
s
.7182 .32039 m
.72378 .31921 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71311 .34465 m
.71447 .34205 L
s
.71311 .34465 m
.71322 .34928 L
s
.71447 .34205 m
.71724 .33918 L
s
.71316 .34696 m
.71453 .34437 L
s
.71453 .34437 m
.7173 .3415 L
s
.72378 .31921 m
.7266 .32093 L
s
.71322 .34928 m
.71469 .35134 L
s
.71724 .33918 m
.72412 .33311 L
s
.7173 .3415 m
.72418 .33543 L
s
.71469 .35134 m
.71758 .35311 L
s
.7266 .32093 m
.72803 .32294 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72412 .33311 m
.72683 .3302 L
s
.71758 .35311 m
.72319 .352 L
s
.72803 .32294 m
.72821 .3299 L
s
.72418 .33543 m
.72689 .33252 L
s
.72683 .3302 m
.72815 .32758 L
s
.72689 .33252 m
.72821 .3299 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72319 .352 m
.72591 .3491 L
s
.72591 .3491 m
.72724 .34648 L
s
.72724 .34648 m
.7285 .34153 L
s
.7285 .34153 m
.72874 .35085 L
s
.72724 .34648 m
.72874 .35085 L
s
.73746 .31845 m
.73874 .31581 L
s
.73746 .31845 m
.73886 .32045 L
s
.73874 .31581 m
.74013 .31781 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73886 .32045 m
.74013 .31781 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73917 .3321 m
.74126 .35988 L
s
.73858 .36048 m
.73917 .3321 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73955 .34611 m
.73992 .36018 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73858 .36048 m
.74005 .36488 L
s
.29055 .31638 m
.2919 .31439 L
s
.29069 .31171 m
.2919 .31439 L
s
.74005 .36488 m
.74126 .35988 L
s
.28935 .3137 m
.29069 .31171 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28935 .3137 m
.29055 .31638 L
s
.29022 .32809 m
.29069 .35665 L
s
.28813 .356 m
.29022 .32809 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28941 .35633 m
.28981 .34219 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27936 .31084 m
.28052 .31355 L
s
.28031 .3206 m
.28052 .31355 L
s
.27698 .30776 m
.27936 .31084 L
s
.28927 .36105 m
.29069 .35665 L
s
.27907 .32024 m
.28038 .31825 L
s
.279 .32259 m
.28031 .3206 L
s
.27216 .30626 m
.27698 .30776 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28813 .356 m
.28927 .36105 L
s
.27656 .32187 m
.27907 .32024 L
s
.27648 .32423 m
.279 .32259 L
s
.27858 .33674 m
.27995 .33237 L
s
.27967 .34182 m
.27995 .33237 L
s
.27039 .32476 m
.27656 .32187 L
s
.27031 .32712 m
.27648 .32423 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26972 .30786 m
.27216 .30626 L
s
.27728 .33875 m
.27858 .33674 L
s
.27858 .33674 m
.27967 .34182 L
s
.27476 .34041 m
.27728 .33875 L
s
.26846 .30983 m
.26972 .30786 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26744 .30473 m
.26846 .30983 L
s
.26714 .31417 m
.26744 .30473 L
s
.26714 .31417 m
.26846 .30983 L
s
.26995 .33897 m
.27476 .34041 L
s
.26794 .32638 m
.27039 .32476 L
s
.26787 .32875 m
.27031 .32712 L
s
.78048 .30389 m
.79175 .29989 L
s
.26669 .32837 m
.26794 .32638 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26662 .33074 m
.26787 .32875 L
s
.26765 .33586 m
.26995 .33897 L
s
.26654 .33312 m
.26669 .32837 L
s
.26654 .33312 m
.26765 .33586 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78392 .30271 m
.78553 .35265 L
s
.78506 .30231 m
.78668 .35227 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25707 .30355 m
.25916 .30908 L
s
.25383 .29996 m
.25707 .30355 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25164 .29913 m
.25383 .29996 L
s
.25854 .32809 m
.25862 .32571 L
s
.25757 .32294 m
.25862 .32571 L
s
.79175 .29989 m
.79401 .30144 L
s
.79175 .29989 m
.79509 .30102 L
s
.25637 .32493 m
.25757 .32294 L
s
.25613 .33208 m
.25854 .32809 L
s
.78206 .35375 m
.79341 .35001 L
s
.25637 .32493 m
.25741 .3277 L
s
.24941 .30068 m
.25164 .29913 L
s
.24834 .30026 m
.25164 .29913 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79401 .30144 m
.79632 .30537 L
s
.25382 .33369 m
.25613 .33208 L
s
.79509 .30102 m
.79739 .30495 L
s
.24711 .30461 m
.24941 .30068 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24606 .30419 m
.24834 .30026 L
s
.79632 .30537 m
.79755 .30972 L
s
.25053 .33251 m
.25382 .33369 L
s
.79739 .30495 m
.79862 .30931 L
s
.24581 .31135 m
.24711 .30461 L
s
.79755 .30972 m
.79886 .31647 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24476 .31094 m
.24606 .30419 L
s
.79862 .30931 m
.79992 .31606 L
s
.24844 .32932 m
.25053 .33251 L
s
.24737 .32892 m
.25053 .33251 L
s
.24565 .31613 m
.24581 .31135 L
s
.79886 .31647 m
.79927 .32845 L
s
.24646 .32372 m
.24844 .32932 L
s
.79341 .35001 m
.79553 .34683 L
s
.79341 .35001 m
.79662 .34644 L
s
.24565 .31613 m
.24646 .32372 L
s
.2446 .31572 m
.24476 .31094 L
s
.79992 .31606 m
.80033 .32804 L
s
.80342 .29526 m
.81042 .2922 L
s
.2454 .32331 m
.24737 .32892 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2446 .31572 m
.2454 .32331 L
s
.79553 .34683 m
.79754 .34125 L
s
.23416 .29183 m
.24112 .2949 L
s
.79845 .33605 m
.79927 .32845 L
s
.79662 .34644 m
.79861 .34085 L
s
.79754 .34125 m
.79845 .33605 L
s
.79951 .33565 m
.80033 .32804 L
s
.79861 .34085 m
.79951 .33565 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80646 .29396 m
.80764 .32756 L
s
.23691 .32722 m
.2381 .2936 L
s
.80746 .29352 m
.80865 .32715 L
s
.23591 .3268 m
.2371 .29316 L
s
.80458 .32881 m
.80865 .32715 L
s
.80814 .3127 m
.80939 .31949 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80939 .31949 m
.81153 .32347 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23295 .32553 m
.23691 .32722 L
s
.22391 .28683 m
.23033 .29004 L
s
.81153 .32347 m
.81357 .32503 L
s
.23531 .34372 m
.2364 .34171 L
s
.23549 .33888 m
.2364 .34171 L
s
.23441 .34089 m
.23549 .33888 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23441 .34089 m
.23531 .34372 L
s
.22657 .31523 m
.22754 .28868 L
s
.81357 .32503 m
.81644 .32374 L
s
.22565 .31479 m
.22662 .28822 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81532 .31933 m
.81635 .32132 L
s
.81532 .31933 m
.81618 .31648 L
s
.81618 .31648 m
.81721 .31846 L
s
.81644 .32374 m
.81729 .32088 L
s
.81721 .31846 m
.81729 .32088 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22547 .31964 m
.22657 .31523 L
s
.22455 .3192 m
.22565 .31479 L
s
.82278 .29354 m
.82348 .28824 L
s
.82278 .29354 m
.82296 .29838 L
s
.82348 .28824 m
.82598 .28441 L
s
.22266 .32075 m
.22547 .31964 L
s
.82296 .29838 m
.82402 .30277 L
s
.82366 .29308 m
.82435 .28777 L
s
.82366 .29308 m
.82384 .29792 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82435 .28777 m
.82598 .28441 L
s
.22266 .32075 m
.22455 .3192 L
s
.21457 .28163 m
.22041 .28497 L
s
.82384 .29792 m
.8249 .30231 L
s
.82402 .30277 m
.82671 .30382 L
s
.8249 .30231 m
.82671 .30382 L
s
.22088 .31986 m
.22266 .32075 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82598 .28441 m
.82851 .28299 L
s
.82438 .31248 m
.82448 .31491 L
s
.82438 .31248 m
.82526 .31203 L
s
.82448 .31491 m
.82544 .3169 L
s
.82851 .28299 m
.83024 .28446 L
s
.82526 .31203 m
.82535 .31446 L
s
.21836 .31607 m
.22088 .31986 L
s
.82544 .3169 m
.82726 .31843 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21508 .33429 m
.21702 .28307 L
s
.21592 .33474 m
.21786 .28355 L
s
.83024 .28446 m
.83204 .28836 L
s
.21685 .31028 m
.21836 .31607 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82726 .31843 m
.83063 .31661 L
s
.82671 .30382 m
.8318 .30346 L
s
.83204 .28836 m
.83265 .28301 L
s
.83204 .28836 m
.83288 .31033 L
s
.83265 .28301 m
.83412 .27961 L
s
.83284 .28788 m
.83344 .28253 L
s
.83284 .28788 m
.83349 .30497 L
s
.83344 .28253 m
.83412 .27961 L
s
.83412 .27961 m
.83489 .27912 L
s
.8318 .30346 m
.8327 .30544 L
s
.83063 .31661 m
.83217 .31324 L
s
.21261 .33295 m
.21592 .33474 L
s
.83217 .31324 m
.83288 .31033 L
s
.83288 .31033 m
.83349 .30497 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20753 .27967 m
.20882 .28554 L
s
.20882 .28554 m
.2093 .29336 L
s
.20911 .29826 m
.2093 .29336 L
s
.20679 .27918 m
.20807 .28505 L
s
.20807 .28505 m
.20854 .29288 L
s
.20545 .27574 m
.20753 .27967 L
s
.20806 .30513 m
.20911 .29826 L
s
.20835 .29778 m
.20854 .29288 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20545 .27574 m
.20679 .27918 L
s
.20731 .30466 m
.20835 .29778 L
s
.20638 .3091 m
.20806 .30513 L
s
.20405 .27473 m
.20545 .27574 L
s
0 0 0 r
.1983 .26379 m
.2 .26825 L
s
.255 .412 .882 r
.20564 .30862 m
.20731 .30466 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83774 .31243 m
.84282 .30909 L
s
0 0 0 r
.1983 .26379 m
.19952 .26832 L
s
.19952 .26832 m
.1998 .27324 L
s
.255 .412 .882 r
.20258 .27618 m
.20405 .27473 L
s
.84146 .27465 m
.84554 .30715 L
s
.83997 .311 m
.84146 .27465 L
s
.2041 .31013 m
.20638 .3091 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19996 .30723 m
.20202 .25556 L
s
.19946 .25347 m
.20404 .25711 L
s
.84069 .31053 m
.84175 .282 L
s
.2041 .31013 m
.20564 .30862 L
s
.1993 .30675 m
.20137 .25504 L
s
.20104 .28008 m
.20258 .27618 L
s
0 0 0 r
.84801 .26668 m
.84881 .26967 L
s
.84801 .26668 m
.84853 .26266 L
s
.255 .412 .882 r
.20269 .30917 m
.2041 .31013 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20141 .30573 m
.20269 .30917 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20026 .29981 m
.20141 .30573 L
s
.84554 .30715 m
.84673 .27058 L
s
.8462 .30666 m
.84703 .27797 L
s
.19693 .26912 m
.19753 .26963 L
s
.19737 .30528 m
.19996 .30723 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84968 .28996 m
.84982 .29243 L
s
.8496 .29025 m
.84966 .2926 L
s
.85043 .32418 m
.85058 .33023 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19564 .27055 m
.19693 .26912 L
s
.19623 .27107 m
.19693 .26912 L
s
0 0 0 r
.85095 .32237 m
.85125 .32975 L
s
.255 .412 .882 r
.19544 .27549 m
.19623 .27107 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19486 .27498 m
.19564 .27055 L
s
.19474 .29285 m
.19544 .27549 L
s
.19394 .26898 m
.19486 .27498 L
s
.19396 .29732 m
.19486 .27498 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85142 .32071 m
.85162 .32425 L
s
.5 Mabswid
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84874 .3047 m
.8523 .30172 L
s
.84673 .27058 m
.85056 .30321 L
s
.19294 .26546 m
.19394 .26898 L
s
.19396 .29732 m
.19474 .29285 L
s
.19137 .26387 m
.19294 .26546 L
s
.19369 .28935 m
.19416 .29234 L
s
.19055 .28378 m
.19369 .28935 L
s
.19328 .29931 m
.19396 .29732 L
s
.19206 .3008 m
.19328 .29931 L
s
.19026 .26529 m
.19137 .26387 L
s
.18978 .26476 m
.19137 .26387 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8541 .27673 m
.85441 .27123 L
s
.85388 .28472 m
.8541 .27673 L
s
.85441 .27123 m
.85521 .2652 L
s
.85388 .28472 m
.8544 .2972 L
s
.18993 .29877 m
.19206 .3008 L
s
.85462 .27621 m
.85492 .27071 L
s
.85441 .28421 m
.85462 .27621 L
s
.18957 .26974 m
.19026 .26529 L
s
.85492 .27071 m
.85569 .26467 L
s
.85441 .28421 m
.85492 .29669 L
s
.85521 .2652 m
.85654 .26111 L
s
.18965 .28024 m
.19055 .28378 L
s
.18916 .27972 m
.19055 .28378 L
s
.18909 .26921 m
.18978 .26476 L
s
0 0 0 r
.18362 .25338 m
.18452 .25224 L
s
.255 .412 .882 r
.85569 .26467 m
.85654 .26111 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8544 .2972 m
.85523 .3042 L
s
.18936 .27473 m
.18957 .26974 L
s
.85492 .29669 m
.85575 .3037 L
s
.18936 .27473 m
.18965 .28024 L
s
.85654 .26111 m
.85744 .26003 L
s
.18888 .2742 m
.18909 .26921 L
s
.18903 .29525 m
.18993 .29877 L
s
.18888 .2742 m
.18916 .27972 L
s
.85523 .3042 m
.85595 .30872 L
s
.18874 .28972 m
.18923 .29024 L
s
.18913 .29274 m
.18923 .29024 L
s
0 0 0 r
.86212 .24915 m
.86337 .2475 L
s
.255 .412 .882 r
.85575 .3037 m
.85646 .30822 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85744 .26003 m
.85884 .26091 L
s
.18864 .29223 m
.18903 .29525 L
s
.18864 .29223 m
.18874 .28972 L
s
.85595 .30872 m
.85717 .31274 L
s
.85646 .30822 m
.85766 .31224 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85884 .26091 m
.85987 .26484 L
s
.85717 .31274 m
.85872 .31376 L
s
.85766 .31224 m
.85872 .31376 L
s
.85955 .25732 m
.86039 .27739 L
s
.85915 .27898 m
.86191 .27526 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18198 .28143 m
.18227 .28555 L
s
.18168 .28861 m
.18227 .28555 L
s
.1814 .28449 m
.18198 .28143 L
s
.18181 .29633 m
.18249 .30052 L
s
.255 .412 .882 r
.85994 .25678 m
.86079 .27686 L
s
.85872 .31376 m
.85964 .31275 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18475 .28503 m
.18505 .28808 L
s
.18494 .2906 m
.18505 .28808 L
s
.85964 .31275 m
.86084 .30871 L
s
.18443 .2926 m
.18494 .2906 L
s
.18425 .28703 m
.18475 .28503 L
s
.18181 .25081 m
.18403 .25468 L
s
.18425 .28703 m
.18454 .29008 L
s
.18327 .29103 m
.18443 .2926 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86402 .273 m
.86418 .27694 L
s
.86433 .2702 m
.86458 .27605 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86648 .29642 m
.86666 .29618 L
s
.255 .412 .882 r
.86084 .30871 m
.86145 .30262 L
s
.8621 .25348 m
.86417 .2496 L
s
.86153 .29452 m
.86216 .30971 L
s
.86145 .30262 m
.86153 .29452 L
s
.86145 .30262 m
.86216 .30971 L
s
.18152 .2884 m
.18302 .25303 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18265 .28745 m
.18327 .29103 L
s
.1812 .28787 m
.1827 .25247 L
s
.86305 .25183 m
.86455 .28725 L
s
.18217 .28133 m
.18265 .28745 L
s
.18217 .2732 m
.18217 .28133 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86334 .25127 m
.86484 .28672 L
s
.86359 .28884 m
.86484 .28672 L
s
0 0 0 r
.17564 .23509 m
.17669 .23786 L
s
.255 .412 .882 r
.1803 .28628 m
.18152 .2884 L
s
.8642 .27149 m
.86481 .27856 L
s
.86481 .27856 m
.86557 .28258 L
s
0 0 0 r
.17426 .28826 m
.17645 .23739 L
s
.8691 .23691 m
.87012 .23383 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17942 .26777 m
.18029 .24746 L
s
.1786 .26558 m
.18014 .26941 L
s
.1792 .26722 m
.18007 .2469 L
s
.86557 .28258 m
.86619 .28405 L
s
.17955 .24831 m
.17974 .25451 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17913 .24408 m
.17955 .24831 L
s
.86619 .28405 m
.86687 .28244 L
s
0 0 0 r
.17404 .28772 m
.1745 .28877 L
s
.255 .412 .882 r
.86644 .27787 m
.86677 .27989 L
s
.86644 .27787 m
.86655 .27478 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86655 .27478 m
.86687 .27679 L
s
.17882 .24295 m
.17913 .24408 L
s
.17801 .301 m
.17866 .28563 L
s
.17811 .29278 m
.17866 .28563 L
s
.86687 .28244 m
.86697 .27935 L
s
.86687 .27679 m
.86697 .27935 L
s
0 0 0 r
.8713 .2878 m
.87233 .28492 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17404 .28772 m
.17623 .23682 L
s
.255 .412 .882 r
.17845 .24436 m
.17882 .24295 L
s
.17834 .2438 m
.17882 .24295 L
s
.17748 .29685 m
.17811 .29278 L
s
.17801 .301 m
.17811 .29278 L
s
0 0 0 r
.8712 .22801 m
.87068 .23151 L
s
.87107 .22918 m
.8716 .28709 L
s
.17347 .30659 m
.17354 .31078 L
s
.17315 .31394 m
.17354 .31078 L
s
.17309 .30974 m
.17347 .30659 L
s
.255 .412 .882 r
.17801 .24834 m
.17845 .24436 L
s
.86696 .24427 m
.86705 .24994 L
s
.86705 .24994 m
.86727 .25505 L
s
0 0 0 r
.17426 .24253 m
.17435 .23409 L
s
.17391 .25405 m
.17426 .24253 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86727 .25505 m
.86761 .25961 L
s
.86696 .24427 m
.86716 .24001 L
s
0 0 0 r
.8694 .23615 m
.86943 .23657 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17791 .24778 m
.17834 .2438 L
s
.86707 .2437 m
.86718 .24937 L
s
.86718 .24937 m
.86739 .25449 L
s
.17683 .29784 m
.17748 .29685 L
s
.86707 .2437 m
.86716 .24001 L
s
0 0 0 r
.17309 .30974 m
.17315 .31394 L
s
.17435 .23409 m
.17426 .22869 L
s
.17359 .26136 m
.17391 .25405 L
s
.17414 .24196 m
.17426 .23351 L
s
.17378 .25348 m
.17414 .24196 L
s
.255 .412 .882 r
.86739 .25449 m
.86773 .25905 L
s
0 0 0 r
.17426 .23351 m
.17426 .22869 L
s
.17346 .2608 m
.17378 .25348 L
s
.17299 .2718 m
.17359 .26136 L
s
.255 .412 .882 r
.86761 .25961 m
.86804 .2605 L
s
.86716 .24001 m
.86738 .2383 L
s
.17769 .2529 m
.17801 .24834 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17287 .27124 m
.17346 .2608 L
s
.17426 .22869 m
.17415 .22752 L
s
.255 .412 .882 r
.86773 .25905 m
.86804 .2605 L
s
.17761 .25234 m
.17791 .24778 L
s
.86805 .26987 m
.86816 .27243 L
s
.86805 .26987 m
.86817 .26932 L
s
.17652 .29678 m
.17683 .29784 L
s
.17728 .26004 m
.17769 .2529 L
s
.86816 .27243 m
.86839 .27446 L
s
0 0 0 r
.17244 .27805 m
.17299 .2718 L
s
.255 .412 .882 r
.86817 .26932 m
.86828 .27189 L
s
0 0 0 r
.17415 .22752 m
.17391 .23001 L
s
.255 .412 .882 r
.1772 .25949 m
.17761 .25234 L
s
0 0 0 r
.17235 .2775 m
.17287 .27124 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86839 .27446 m
.8687 .27594 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86959 .23557 m
.8733 .28054 L
s
.86943 .23657 m
.87322 .28109 L
s
.255 .412 .882 r
.86804 .2605 m
.8685 .25974 L
s
.86738 .2383 m
.86758 .23972 L
s
.17636 .29313 m
.17652 .29678 L
s
.17624 .2926 m
.17652 .29678 L
s
.17673 .27291 m
.17728 .26004 L
s
.17665 .27236 m
.1772 .25949 L
s
.17636 .2869 m
.17636 .29313 L
s
.86758 .23972 m
.86785 .24372 L
s
0 0 0 r
.17391 .23001 m
.17357 .23618 L
s
.17203 .28009 m
.17244 .27805 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17624 .2926 m
.17626 .28636 L
s
.17648 .2812 m
.17673 .27291 L
s
.17636 .2869 m
.17648 .2812 L
s
0 0 0 r
.17203 .28009 m
.17235 .2775 L
s
.17404 .22517 m
.17412 .22282 L
s
.17067 .30283 m
.17404 .22517 L
s
.255 .412 .882 r
.17639 .28065 m
.17665 .27236 L
s
.17626 .28636 m
.17639 .28065 L
s
0 0 0 r
.17067 .3023 m
.17405 .22459 L
s
.255 .412 .882 r
.86764 .23801 m
.86785 .24372 L
s
.86752 .23429 m
.86764 .23801 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8729 .28273 m
.87344 .27944 L
s
.5 Mabswid
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86785 .24372 m
.86885 .26694 L
s
.8687 .27594 m
.86898 .27376 L
s
.86764 .23743 m
.86786 .24315 L
s
.86786 .24315 m
.86864 .26121 L
s
.86752 .23429 m
.86764 .23743 L
s
0 0 0 r
.17191 .27899 m
.17203 .28009 L
s
.255 .412 .882 r
.8685 .25974 m
.86863 .26176 L
s
.86894 .27007 m
.86898 .27376 L
s
0 0 0 r
.87182 .2355 m
.8723 .24711 L
s
.87146 .22698 m
.87182 .2355 L
s
.255 .412 .882 r
.86604 .21043 m
.86665 .21456 L
s
.8675 .23371 m
.86752 .23429 L
s
0 0 0 r
.87116 .22154 m
.87146 .22698 L
s
.8723 .24711 m
.87262 .25449 L
s
.87181 .23492 m
.8723 .24654 L
s
.87142 .22639 m
.87181 .23492 L
s
.17199 .27418 m
.17191 .27899 L
s
.255 .412 .882 r
.86885 .26694 m
.86894 .27007 L
s
0 0 0 r
.87116 .22154 m
.87142 .22639 L
s
.255 .412 .882 r
.17636 .26946 m
.17634 .27275 L
s
0 0 0 r
.8723 .24654 m
.87262 .25392 L
s
.87262 .25449 m
.8731 .26501 L
s
.255 .412 .882 r
.86864 .26121 m
.86885 .26694 L
s
.1763 .27111 m
.17796 .23266 L
s
.17667 .2667 m
.17796 .23266 L
s
0 0 0 r
.17228 .26567 m
.17199 .27418 L
s
.87262 .25392 m
.87309 .26445 L
s
.87101 .22036 m
.87116 .22154 L
s
.255 .412 .882 r
.17659 .26725 m
.17763 .2404 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8731 .26501 m
.87339 .27131 L
s
.87098 .22286 m
.87101 .22036 L
s
.87087 .22227 m
.87101 .22036 L
s
.87309 .26445 m
.87335 .27075 L
s
.17073 .30443 m
.17067 .3023 L
s
.17439 .22296 m
.17466 .21868 L
s
.17434 .22607 m
.17439 .22296 L
s
.87107 .22908 m
.87098 .22286 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17466 .21868 m
.17462 .22178 L
s
.87339 .27131 m
.87341 .27336 L
s
.255 .412 .882 r
.86704 .23169 m
.86747 .23802 L
s
0 0 0 r
.87093 .2285 m
.87087 .22227 L
s
.255 .412 .882 r
.8687 .26661 m
.86898 .26881 L
s
0 0 0 r
.87335 .27075 m
.87341 .27336 L
s
.17462 .22178 m
.17434 .22607 L
s
.255 .412 .882 r
.86668 .22794 m
.86704 .23169 L
s
.17667 .2667 m
.17868 .22804 L
s
.86639 .22679 m
.86668 .22794 L
s
0 0 0 r
.87142 .23963 m
.87107 .22908 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86636 .2122 m
.8687 .26661 L
s
.86645 .21279 m
.86879 .26716 L
s
.86836 .25879 m
.86838 .26289 L
s
0 0 0 r
.87341 .27336 m
.87327 .27225 L
s
.87127 .23906 m
.87093 .2285 L
s
.1717 .28887 m
.17353 .2446 L
s
.17148 .28996 m
.17353 .2446 L
s
.255 .412 .882 r
.86617 .22823 m
.86639 .22679 L
s
.86598 .22765 m
.86639 .22679 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87327 .27225 m
.87292 .26741 L
s
.87327 .27225 m
.87281 .26685 L
s
.87142 .23963 m
.87174 .24707 L
s
.255 .412 .882 r
.86825 .26439 m
.86838 .26289 L
s
0 0 0 r
.8716 .2465 m
.87127 .23906 L
s
.87236 .25882 m
.87174 .24707 L
s
.87292 .26741 m
.87236 .25882 L
s
.17158 .28942 m
.17256 .26694 L
s
.8716 .2465 m
.87223 .25826 L
s
.87281 .26685 m
.87223 .25826 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8685 .21147 m
.86941 .21384 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86825 .26439 m
.86796 .26329 L
s
.86609 .23684 m
.86614 .23955 L
s
0 0 0 r
.17126 .29693 m
.17148 .28996 L
s
.255 .412 .882 r
.86751 .25956 m
.86796 .26329 L
s
.86732 .259 m
.86796 .26329 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17799 .25304 m
.1782 .24559 L
s
.17786 .25273 m
.17806 .24582 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86587 .23593 m
.86592 .23898 L
s
.86614 .23955 m
.86636 .24478 L
s
.8669 .2532 m
.86751 .25956 L
s
0 0 0 r
.1717 .28887 m
.17126 .29693 L
s
.255 .412 .882 r
.86636 .24478 m
.8669 .2532 L
s
.86592 .23898 m
.86614 .24422 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86814 .21401 m
.86898 .22265 L
s
.86741 .20909 m
.86814 .21401 L
s
.86679 .20791 m
.86741 .20909 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86629 .21046 m
.86679 .20791 L
s
.86595 .20987 m
.86679 .20791 L
s
.87008 .25901 m
.87028 .25261 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86875 .21206 m
.87216 .29091 L
s
.8685 .21147 m
.87191 .29038 L
s
.86591 .21679 m
.86629 .21046 L
s
.86554 .2162 m
.86595 .20987 L
s
.86967 .26167 m
.87008 .25901 L
s
.86591 .21679 m
.86602 .2275 L
s
.86906 .26055 m
.86967 .26167 L
s
.86554 .2162 m
.86564 .22692 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87111 .28876 m
.87216 .29091 L
s
.86602 .2275 m
.86635 .23504 L
s
.86823 .25565 m
.86906 .26055 L
s
.86789 .25509 m
.86906 .26055 L
s
.255 .412 .882 r
.85667 .20945 m
.85691 .20975 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86564 .22692 m
.86596 .23447 L
s
.86635 .23504 m
.8672 .24695 L
s
.8672 .24695 m
.86823 .25565 L
s
.86073 .19903 m
.8626 .20139 L
s
.86596 .23447 m
.86683 .24639 L
s
.86683 .24639 m
.86789 .25509 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86122 .19962 m
.86347 .25277 L
s
.86073 .19903 m
.86298 .25221 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85989 .20163 m
.86121 .21037 L
s
.85814 .19609 m
.85989 .20163 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85702 .19492 m
.85814 .19609 L
s
.255 .412 .882 r
.18682 .24199 m
.18741 .23877 L
s
.1867 .24466 m
.18682 .24199 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85602 .19755 m
.85702 .19492 L
s
.86146 .25055 m
.86347 .25277 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85574 .20458 m
.85602 .19755 L
s
.85542 .19696 m
.85702 .19492 L
s
.85512 .204 m
.85542 .19696 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85512 .204 m
.85688 .24615 L
s
.85574 .20458 m
.85749 .2467 L
s
.85497 .24451 m
.85749 .2467 L
s
.84863 .18736 m
.84957 .21036 L
s
.84791 .18678 m
.84957 .21036 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84565 .18527 m
.84863 .18736 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85099 .24512 m
.85122 .26793 L
s
.85099 .24512 m
.85195 .26845 L
s
.84519 .21087 m
.84644 .2419 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83563 .17826 m
.84565 .18527 L
s
.84085 .22311 m
.84581 .22635 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20666 .21836 m
.20675 .21599 L
s
.5 Mabswid
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83885 .26018 m
.84894 .26655 L
s
.84894 .26655 m
.85195 .26845 L
s
.83916 .18051 m
.8424 .26222 L
s
.5 Mabswid
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83829 .17995 m
.84153 .26171 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29155 .14566 m
.3013 .14313 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29476 .14481 m
.30397 .22709 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29733 .16806 m
.31245 .16451 L
s
.326 .10953 m
.33858 .10694 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31138 .14071 m
.32177 .13839 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31598 .18016 m
.31752 .17739 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31752 .17739 m
.31769 .17763 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32929 .19345 m
.33135 .1084 L
s
.30431 .21481 m
.31653 .13954 L
s
.3311 .19311 m
.33314 .10803 L
s
.30397 .22709 m
.31827 .13915 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7215 .21013 m
.72157 .21015 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33218 .14832 m
.336 .13952 L
s
.336 .13952 m
.33976 .13479 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33976 .13479 m
.34346 .1341 L
s
.34346 .1341 m
.34709 .13748 L
s
.34346 .1341 m
.34896 .13716 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34709 .13748 m
.35067 .14495 L
s
.34896 .13716 m
.35256 .14463 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72117 .20981 m
.7215 .21013 L
s
0 0 0 r
.32389 .19448 m
.3311 .19311 L
s
.35067 .14495 m
.3523 .15685 L
s
.3314 .18084 m
.33485 .18835 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35256 .14463 m
.3542 .15653 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35212 .16501 m
.3523 .15685 L
s
.33485 .18835 m
.33845 .19179 L
s
.35403 .1647 m
.3542 .15653 L
s
.34996 .17759 m
.35212 .16501 L
s
.37397 .13321 m
.37998 .12831 L
s
.3699 .14192 m
.37397 .13321 L
s
.35186 .17728 m
.35403 .1647 L
s
.33845 .19179 m
.34217 .19115 L
s
.37595 .13293 m
.37998 .12831 L
s
.37186 .14164 m
.37595 .13293 L
s
.3677 .15445 m
.3699 .14192 L
s
.37998 .12831 m
.38396 .12778 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36966 .15417 m
.37186 .14164 L
s
.34601 .18641 m
.34996 .17759 L
s
.34217 .19115 m
.34601 .18641 L
s
.34217 .19115 m
.34789 .1861 L
s
.38396 .12778 m
.3879 .13134 L
s
.38396 .12778 m
.38992 .13108 L
s
.34789 .1861 m
.35186 .17728 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36754 .16264 m
.3677 .15445 L
s
.65707 .12722 m
.65915 .13155 L
s
.65513 .13104 m
.65707 .12722 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65721 .13537 m
.65915 .13155 L
s
.255 .412 .882 r
.66072 .1604 m
.66099 .15962 L
s
0 0 0 r
.3879 .13134 m
.3918 .139 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37245 .16955 m
.37249 .167 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3695 .16236 m
.36966 .15417 L
s
.38992 .13108 m
.39383 .13876 L
s
.65513 .13104 m
.65721 .13537 L
s
.36754 .16264 m
.36926 .17467 L
s
.3695 .16236 m
.37123 .17439 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3918 .139 m
.39363 .15105 L
s
.39383 .13876 m
.39566 .15081 L
s
.40629 .12511 m
.42082 .12366 L
s
.36926 .17467 m
.37305 .18236 L
s
.6263 .12382 m
.63462 .12464 L
s
.63462 .12464 m
.63881 .12916 L
s
.63881 .12916 m
.64093 .13347 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37123 .17439 m
.37504 .18209 L
s
.64093 .13347 m
.64111 .14576 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62217 .12752 m
.6263 .12382 L
s
.39349 .15926 m
.39363 .15105 L
s
.39553 .15903 m
.39566 .15081 L
s
.63905 .14554 m
.64105 .14166 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37305 .18236 m
.37895 .1857 L
s
.61791 .12306 m
.62012 .13143 L
s
.61791 .12306 m
.61811 .13946 L
s
.63911 .14965 m
.64111 .14576 L
s
.37504 .18209 m
.37895 .1857 L
s
.62012 .13143 m
.62217 .12752 L
s
.42922 .12291 m
.44409 .12176 L
s
.39126 .17185 m
.39349 .15926 L
s
.63497 .14922 m
.63905 .14554 L
s
.39329 .17161 m
.39553 .15903 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41128 .2112 m
.41249 .12446 L
s
.41338 .21101 m
.41456 .12426 L
s
.63503 .15334 m
.63911 .14965 L
s
.61811 .13946 m
.62012 .13143 L
s
.5988 .12159 m
.60733 .1222 L
s
.37895 .1857 m
.38296 .1852 L
s
.62463 .15647 m
.63497 .14922 L
s
.38706 .18058 m
.39126 .17185 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65756 .15584 m
.66043 .20562 L
s
.65637 .20515 m
.65756 .15584 L
s
.38909 .18034 m
.39329 .17161 L
s
.62469 .16059 m
.63503 .15334 L
s
.38296 .1852 m
.38706 .18058 L
s
.38296 .1852 m
.38909 .18034 L
s
.65798 .18054 m
.6584 .20539 L
s
.58806 .12091 m
.59455 .1254 L
s
.58374 .12067 m
.58806 .12091 L
s
.63947 .17437 m
.64142 .16633 L
s
.64142 .16633 m
.64167 .18286 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46341 .12468 m
.46778 .12035 L
s
.46778 .12035 m
.47212 .12015 L
s
.46125 .12479 m
.46778 .12035 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57727 .12444 m
.58374 .12067 L
s
.57944 .12455 m
.58374 .12067 L
s
.59455 .1254 m
.59892 .1339 L
s
.45686 .13325 m
.46125 .12479 L
s
.47212 .12015 m
.47645 .12407 L
s
.47212 .12015 m
.47863 .12399 L
s
.45902 .13313 m
.46341 .12468 L
s
.57733 .13266 m
.57944 .12455 L
s
.62047 .16023 m
.62463 .15647 L
s
.57515 .13256 m
.57727 .12444 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54449 .11924 m
.55982 .11963 L
s
.63746 .1783 m
.63947 .17437 L
s
.63947 .17437 m
.64167 .18286 L
s
.4546 .14573 m
.45686 .13325 L
s
.62052 .16436 m
.62469 .16059 L
s
.47645 .12407 m
.48076 .13213 L
s
.45676 .14561 m
.45902 .13313 L
s
.47863 .12399 m
.48295 .13205 L
s
.49614 .11934 m
.51151 .11909 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61841 .16418 m
.62047 .16023 L
s
.52031 .11903 m
.5357 .11911 L
s
.63335 .18204 m
.63746 .1783 L
s
.65854 .21371 m
.66043 .20562 L
s
.61846 .16832 m
.62052 .16436 L
s
.61841 .16418 m
.61851 .17246 L
s
.48076 .13213 m
.48289 .14443 L
s
.48295 .13205 m
.48508 .14436 L
s
.65637 .20515 m
.65854 .21371 L
s
.45453 .15399 m
.4546 .14573 L
s
.45669 .15387 m
.45676 .14561 L
s
.62495 .18128 m
.63335 .18204 L
s
.61851 .17246 m
.62068 .17678 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45453 .15399 m
.45659 .16629 L
s
.62068 .17678 m
.62495 .18128 L
s
.45669 .15387 m
.45876 .16617 L
s
.48285 .1527 m
.48289 .14443 L
s
.48504 .15263 m
.48508 .14436 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50258 .17713 m
.50272 .11921 L
s
.50479 .17709 m
.50492 .11917 L
s
.52911 .11905 m
.52914 .1645 L
s
.52691 .11904 m
.52693 .16449 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57515 .13256 m
.57546 .1781 L
s
.57733 .13266 m
.57764 .17819 L
s
.5988 .12159 m
.59935 .17937 L
s
.60094 .12173 m
.60151 .17951 L
s
.55326 .11944 m
.55348 .17735 L
s
.55107 .11938 m
.55127 .17729 L
s
.48059 .16521 m
.48285 .1527 L
s
.48278 .16514 m
.48504 .15263 L
s
.45659 .16629 m
.46086 .17436 L
s
.45876 .16617 m
.46304 .17425 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43461 .20931 m
.43557 .12239 L
s
.43676 .20916 m
.4377 .12223 L
s
.40501 .21179 m
.41338 .21101 L
s
.59287 .17897 m
.60151 .17951 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47616 .17368 m
.48059 .16521 L
s
.46086 .17436 m
.46737 .17821 L
s
.47835 .1736 m
.48278 .16514 L
s
.46304 .17425 m
.46737 .17821 L
s
.50482 .16461 m
.50922 .17287 L
s
.47175 .17802 m
.47616 .17368 L
s
.52693 .17281 m
.52914 .1645 L
s
.52472 .1728 m
.52693 .16449 L
s
.46737 .17821 m
.47175 .17802 L
s
.47175 .17802 m
.47835 .1736 L
s
.56888 .17783 m
.57764 .17819 L
s
.4282 .20978 m
.43676 .20916 L
s
.50922 .17287 m
.51586 .17698 L
s
.52029 .17697 m
.52693 .17281 L
s
.52029 .17697 m
.52472 .1728 L
s
.54465 .17716 m
.55348 .17735 L
s
.49595 .17725 m
.50479 .17709 L
s
.51586 .17698 m
.52029 .17697 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55135 .19818 m
.55358 .20243 L
s
.54915 .20233 m
.55135 .19818 L
s
.55138 .20657 m
.55358 .20243 L
s
.54915 .20233 m
.55138 .20657 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40203oYQ42000000h0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][H80/>3V
0@3oool009D0/>3V102][Jd50?nT4@030:f][@3oYQ40ojHA00<0ojHA1000000@0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00L0mY`?102][Jen0;3PiP40oooo002B0;3PiP<0[Jf]2@3oY140102][Jd0ojHA0?nV4@3o
YQ42000000030?nV4@00000000000140ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][GX0/>3V0@3o
ool008h0/>3V102][Jd<0?nT4@030:f][@3oYQ40ojHA00@0ojHA0P00000A0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?00l0mY`?102][Jef0;3PiP40oooo002:0;3PiP@0[Jf]403oY1400`2][Jd0ojHA0?nV4@040?nV
4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0
oj@A00<0[Jf]0?nV4@3oYQ40103oYQ4200000140ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0:f][@020:f][G00/>3V0@3oool008@0/>3V0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA00@0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ40102][Jd0ojH@0?nV403oYQ09000000<0ojH@2@0000030?nV40@000007P3oYA000`2][Jd0
oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P020>bF3P80[Jf]KP2`h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@040?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA0140ojHA0`00000>0:f][@8000002P2][Jd2000000X0[Jf]1P00000:0:f][@040?nU
400000000000000000/0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V
0`2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40103oYQ4200000140ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0000000000006000000T0[Jf]0P0000030:f][@800000
1@3oYQ400`2][Jd0ojH@0?nV40040?nV408000002P3oYQ02000000X0ojH@00<000000?nU40000000
303oYA02000000<0[Jf]0P0000020:f][@D000001@2][Jd00`000000[Jf]0?nS400F0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]
J02`h>H10?ooo`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@040?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@T000001P2][Jd200000080[Jf]2@3o
YQ42000000D0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00@0ojH@0P00000:0?nV408000002P3o
YQ000`000000ojD@0000000:0?nU40<000001P3oYA0010000000ojD@0000000000050?nU40050:f]
[@3oXa00oj<@0000003oXa000P2][Jd500000080[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V
0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40103oYQ4200000140ojHA
00<0[Jf]0?nV4@3oYQ40303oYQ460:f][@8000000P2][Jd40?nV4@040:f][@3oYQ40ojHA0?nV4@80
00002P3oYQ42000000H0ojHA00<000000?nV4@0000000`3oYQ400`2][Jd0ojH@0?nV40040?nV4080
00002P3oYQ02000000X0ojH@00<000000?nU400000002P3oYA02000000L0ojD@00@000000?nU4000
000000001@3oYA00102][Jd0oj<@0?nS400000020?nS40030000003oXa00oj<@00<0oj<@00<00000
0?nS402][Jd01`2][Jd00`000000[Jf]0?nS40030?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f]
[@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@040?nV4@8000004@3oYQ400`2]
[Jd0ojHA0?nV4@020?nV4@@000001P2][Jd60?nV4@8000001P3oYQ40102][Jd0ojHA0?nV4@3oYQ42
000000X0ojHA0P0000070?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV40040?nV408000002P3oYQ02
000000X0ojH@00<000000?nU400000002@3oYA000`000000ojD@000000080?nU40<000001@3oYA00
0`2][Jd0oj<@0?nS4003000000L0oj<@00<000000?nS403oXa001@3oXa02000000030?nS402][Jd0
[Jf]00D0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ
0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
00@0ojHA0P00000?0?nV4@D0[Jf]0P0000030?nV4@<000002P3oYQ42000000H0ojHA00@0[Jf]0?nV
4@3oYQ40ojHA0P0000090?nV4@800000203oYQ400`000000ojHA000000020?nV4@030:f][@3oYQ00
ojH@00@0ojH@0P00000:0?nV408000002P3oYQ000`000000ojD@000000090?nU408000002@3oYA03
000000D0ojD@00<0[Jf]0?nS403oXa000P0000080?nS40030000003oXa00oj<@00D0oj<@00<00000
0?nS40000000103oXa000`2][Jd0o:0@0?bP40060:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@040?nV4@8000002P3oYQ450:f][@80ojHA00@0[Jf]0?nV
4@00000000001@3oYQ42000000X0ojHA0P0000060?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3o
YQ42000000T0ojHA00D000000?nV4@000000ojHA0:f][@060?nV408000002P3oYQ02000000X0ojH@
00<000000?nU400000002@3oYA02000000X0ojD@0P0000050?nU40030:f][@3oXa00oj<@00800000
2@3oXa000`000000oj<@0?nS40040?nS40030000003oXa00000000@0oj<@00<0[Jf]0?bP403lX100
1P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00@0ojHA0P0000020?nV4@@00000102]
[Jd70?nV4@040:f][@3oYQ400000000000H0ojHA0P0000090?nV4@8000001P3oYQ40102][Jd0ojHA
0?nV4@3oYQ42000000T0ojHA0P0000090?nV4@050000003oYQ4000000?nV4@2][Jd01P3oYQ020000
00X0ojH@0P00000:0?nV40030000003oYA00000000T0ojD@0P00000:0?nU408000001@3oYA00102]
[Jd0oj<@0?nS4000000:0?nS40030000003oXa00oj<@00D0oj<@00<000000?nS403oXa000`3oXa00
0`2][Jd0o:0@0?bP400;0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@040?nV
4@80000000<0[Jf]0000002][Jd00P2][Jd3000000T0ojHA00<0[Jf]0000000000001`3oYQ420000
00T0ojHA0P0000060?nV4@040:f][@3oYQ40ojHA0?nV4@800000203oYQ42000000X0ojHA00D00000
0?nV4@000000ojHA0:f][@060?nV408000002P3oYQ02000000X0ojH@00<000000?nU400000002@3o
YA02000000X0ojD@0P0000050?nU40040:f][@3oXa00oj<@000000X0oj<@00<000000?nS403oXa00
2`3oXa000`2][Jd0o:0@0?bP400@0?bP40H0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0
[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A0`00
00040:f][@80000000<0ojHA0000003oYQ400`3oYQ42000000T0ojHA00<0[Jf]000000000000203o
YQ42000000P0ojHA0P0000060?nV4@040:f][@3oYQ40ojHA0?nV4@800000203oYQ42000000X0ojHA
00D000000?nV4@000000ojHA0:f][@060?nV408000002P3oYQ02000000X0ojH@00<000000?nU4000
00002@3oYA02000000X0ojD@0P0000050?nU40040:f][@3oXa00oj<@000000X0oj<@00<000000?nS
403oXa002`3oXa000`2][Jd0o:0@0?bP400F0?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1@0000000`2][Jd0ojHA0?nV4@020?nV4@<0
00001P3oYQ42000000P0ojHA0P0000090?nV4@800000203oYQ42000000H0ojHA00@0[Jf]0?nV4@3o
YQ40ojHA0P0000080?nV4@8000002`3oYQ4010000000ojHA0000002][Jd60?nV408000002P3oYQ02
000000X0ojH@00<000000?nU400000002@3oYA02000000X0ojD@0P0000050?nU40030:f][@3oXa00
oj<@00/0oj<@00<000000?nS403oXa002`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE
0;3PiP40oooo001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00/0oj@A0P0000020?nT4@@0[Jf]00<0oj@A0000000000001@3oYQ42000000L0ojHA0P0000080?nV
4@8000002@3oYQ42000000P0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000080?nV
4@8000002`3oYQ4010000000ojHA0000002][Jd60?nV408000002P3oYQ000`000000ojH@00000009
0?nV40030000003oYA00000000T0ojD@0P00000:0?nU408000001@3oYA000`2][Jd0oj<@0?nS400;
0?nS40030000003oXa00oj<@00/0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`03
0?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC
0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00T0oj@A0P0000040:f][@D0oj@A00<000000?nV4@3oYQ40103oYQ42000000P0ojHA0P0000070?nV
4@8000002@3oYQ42000000P0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000070?nV
4@800000303oYQ4010000000ojHA0000002][Jd60?nV408000002P3oYQ000`000000ojH@00000009
0?nV40030000003oYA00000000T0ojD@0P00000:0?nU408000001@3oYA000`2][Jd0oj<@0?nS400:
0?nS408000003@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00L0mY`?102][Jd9
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@
0;3PiP40oooo001W0;3PiP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@070?nT4@<0000000<0[Jf]0?nT4@3oY1401`3oY1400`000000ojHA0?nV4@040?nV
4@800000203oYQ42000000L0ojHA0P00000:0?nV4@8000001`3oYQ42000000D0ojHA00<0[Jf]0?nV
4@3oYQ400P3oYQ42000000L0ojHA0P00000<0?nV4@040000003oYQ4000000:f][@H0ojH@0P00000:
0?nV40030000003oYQ00000000T0ojH@00<000000?nU400000002@3oYA02000000X0ojD@0P000005
0?nU40030:f][@3oXa00oj<@00X0oj<@0P00000=0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<
0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@030?nT4@@0[Jf]0P3oY1400`000000oj@A0?nT4@070?nT4@8000001P3oYQ420000
00P0ojHA0P0000060?nV4@8000002`3oYQ42000000L0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA
0080ojHA0P0000070?nV4@800000303oYQ4010000000ojHA0000002][Jd60?nV408000002P3oYQ00
0`000000ojH@000000090?nV40030:f][@000000000000T0ojD@0P00000:0?nU408000001@3oYA00
0`2][Jd0oj<@0?nS40080?nS40<000003`3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd60?nT4@030000003oY140oj@A00L0oj@A0P0000050?nV
4@8000002@3oYQ42000000H0ojHA0P00000;0?nV4@8000001`3oYQ42000000D0ojHA00<0[Jf]0?nV
4@3oYQ400P3oYQ42000000L0ojHA0P00000<0?nV4@040000003oYQ4000000:f][@H0ojH@0P00000:
0?nV40030000003oYQ00000000T0ojH@00<0[Jf]0000000000002@3oYA02000000X0ojD@0P000005
0?nU40030:f][@3oXa00oj<@00L0oj<@00@000000?nS403oXa0000003`3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0
[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f]
[@3lX100o:0@00h0o:0@0`2][Jd:0?nT4@030000003oY140oj@A00L0oj@A0P0000050?nV4@800000
2@3oYQ42000000H0ojHA0P00000;0?nV4@8000001`3oYQ42000000D0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ42000000L0ojHA0P00000<0?nV4@040000003oYQ4000000:f][@H0ojH@0P00000:0?nV4003
0000003oYQ00000000T0ojH@00<0[Jf]0000000000002@3oYA02000000X0ojD@00<000000?nU4000
0000103oYA000`2][Jd0oj<@0?nS40050?nS4080000000<0oj<@000000000000403oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP05
0:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f]
[@3oY1402P3oY1400`000000oj@A0?nT4@070?nT4@8000001@3oYQ42000000T0ojHA0P0000060?nV
4@8000002`3oYQ42000000L0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000070?nV
4@800000303oYQ4010000000ojHA0000002][Jd60?nV408000002P3oYQ000`000000ojH@00000009
0?nV40030:f][@000000000000T0ojD@0P00000:0?nU40030000003oYA00000000@0ojD@00<0[Jf]
0?nS403oXa00103oXa0010000000oj<@0?nS4000000B0?nS40030:f][@3lX100o:0@01L0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0
dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX100
0`2][Jd0oj@A0?nT4@0:0?nT4@030000003oY140oj@A00H0oj@A00<000000:f][@3oYQ40103oYQ42
000000T0ojHA0P0000060?nV4@8000002`3oYQ42000000L0ojHA0P0000050?nV4@030:f][@3oYQ40
ojHA0080ojHA0P0000070?nV4@800000203oYQ440:f][@800000202][Jd2000000X0[Jf]00<00000
0:f][@0000002P2][Jd2000000D0[Jf]1@3oYA02000000T0ojD@00<000000?nU40000000103oYA00
0`2][Jd0oj<@0?nS40030?nS40040000003oXa000000000000`0oj<@00<000000?nS403oXa00103o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/
UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`
h>H0/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f][@3oY140oj@A00X0oj@A00<00000
0?nT4@3oY1401P3oY1400`000000ojHA0?nV4@040?nV4@8000002@3oYQ42000000H0ojHA0P00000;
0?nV4@8000001`3oYQ42000000D0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000030?nV4@2][Jd0
[Jf]00@0[Jf]0P0000080:f][@<0ojHA00D000000?nV4@000000ojHA0:f][@060?nV408000002P3o
YQ000`000000ojH@000000090?nV40030:f][@000000000000D0ojD@1@2][Jd2000000T0[Jf]00<0
00000?nU40000000103oYA000`2][Jd0oj<@0?nS40020?nS40030000003oXa00000000h0oj<@00<0
00000?nS403oXa00103oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140
oj@A00X0oj@A00<000000?nT4@3oY1401@3oY142000000H0ojHA0P0000090?nV4@8000001P3oYQ42
000000/0ojHA0P0000070?nV4@80000000<0ojHA0:f][@2][Jd01`2][Jd2000000030:f][@3oYQ40
ojHA00@0ojHA0P00000;0?nV4@050000003oYQ4000000?nV4@2][Jd01P3oYQ02000000X0ojH@00<0
00000?nV400000002@3oYQ000`2][Jd000000000000:0?nU408000002@3oYA000`000000[Jf]0000
00080:f][@030000003oXa00000000l0oj<@00<000000?nS403oXa00103oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3o
ool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100
o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@030000003oY140oj@A00D0oj@A0P00
00060?nV4@8000002@3oYQ42000000H0ojHA0P00000;0?nV4@80000000<0ojHA0:f][@2][Jd0102]
[Jd2000000030:f][@3oYQ40ojHA0080ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000P0ojHA0P00
000:0?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40040?nV408000002P3oYQ000`000000ojH@0000
00090?nV40030:f][@000000000000X0ojD@0P0000090?nU40030000003oYA00000000@0ojD@00H0
[Jf]0?nS403oXa0000000?nS400000090:f][@L0oj<@00<000000?nS403oXa00103oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@03
0>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40
oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@
0:f][@2][Jd>0?bP40030:f][@3oY140oj@A00X0oj@A00<000000?nT4@3oY140103oY143000000H0
ojHA0P0000090?nV4@8000001P3oYQ42000000@0ojHA1`2][Jd00`000000[Jf]0:f][@060?nV4@80
00001@3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000203oYQ42000000X0ojHA0P0000020?nV4@03
0:f][@3oYQ00ojH@00@0ojH@0P00000:0?nV40030000003oYQ00000000T0ojH@00<0[Jf]00000000
00002P3oYA02000000T0ojD@00<000000?nU40000000103oYA000`2][Jd0oj<@0?nS4002000000X0
oj<@1`2][Jd00`000000[Jf]0:f][@040?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][A00o:0@
00<0[Jf]0?nT4@3oY1402P3oY1400`000000oj@A0?nT4@04000000030?nT4@000000[Jf]00H0ojHA
0P0000090?nV4@8000001@3oYQ400`2][Jd00000000000040:f][@H0ojHA0P0000080?nV4@800000
1@3oYQ401`2][Jd0ojHA0?nV4@3oYQ4000000?nV4@000000203oYQ42000000X0ojHA00D000000?nV
4@3oYQ40ojHA0:f][@060?nV40<000002@3oYQ02000000X0ojH@00<0[Jf]0000000000002P3oYA02
000000T0ojD@00<000000?nU40000000103oYA00102][Jd0oj<@0?nS4000000:0?nS40030000003o
Xa00oj<@00D0oj<@00<000000?nS403oXa00202][JdF0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh30:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3o
ool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`2][JdA0?bP40030:f][@3oY140
oj@A00X0oj@A0`0000050?nT4@030000002][Jd0ojHA00D0ojHA0P0000090?nV4@8000001@2][Jd0
0`3oYQ4000000000000:0?nV4@800000203oYQ42000000D0ojHA00L0[Jf]0?nV4@3oYQ40ojHA0000
003oYQ40000000T0ojHA0P0000080?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV40040?nV40<00000
203oYQ000`000000ojH@0000000:0?nV40030:f][@000000000000X0ojD@0P0000090?nU40030000
003oYA00000000@0ojD@00@0[Jf]0?nS403oXa0000002P3oXa000`000000oj<@0?nS40050?nS4003
0000003oXa00oj<@00@0oj<@00@0[Jf]0?bP403lX100o:0@1P2][Jd@0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][@T0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0
dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@0:0?nT4@030000003oY140oj@A00D0oj@A00<000000:f][@3oYQ401@3oYQ42000000D0
ojHA0`2][Jd2000000P0ojHA0P0000090?nV4@800000203oYQ42000000D0ojHA00L0[Jf]0?nV4@3o
YQ40ojHA0000003oYQ40000000T0ojHA0P0000080?nV4@030000003oYQ40ojHA0080ojHA00<0[Jf]
0?nV403oYQ00103oYQ02000000030?nV40000000ojH@00H0ojH@0P00000;0?nV40030:f][@000000
000000X0ojD@0P0000090?nU40030000003oYA00000000@0ojD@00@0[Jf]0?nS403oXa0000002@3o
Xa02000000L0oj<@0P0000050?nS40030:f][@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]1`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]
09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00X0oj@A00<000000?nT4@3oY140103oY142000000030:f][@3o
YQ40ojHA00@0ojHA0P0000050:f][@<0ojHA0P0000080?nV4@8000002@3oYQ42000000P0ojHA0P00
00050?nV4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000000:0?nV4@8000001P3oYQ42000000@0
ojHA00<0[Jf]0?nV403oYQ00103oYQ0200000080ojH@00<000000?nV403oYQ00103oYQ02000000/0
ojH@00<0[Jf]0000000000002P3oYA02000000T0ojD@00<000000?nU40000000103oYA00102][Jd0
oj<@0?nS400000090?nS408000001`3oXa02000000D0oj<@00<0[Jf]0?bP403lX1003P3lX1060:f]
[@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=
00@0fhX=00<0[Jf]0=^:3@3KRPd0103KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H7
0:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH4004
0>nH40030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:
0?nT4@030000003oY140oj@A00@0oj@A0P0000000`2][Jd0ojHA0?nV4@040:f][@800000203oYQ42
000000P0ojHA0P0000080?nV4@8000002@3oYQ42000000D0ojHA00L0[Jf]0?nV4@3oYQ40ojHA0000
003oYQ40000000/0ojHA0P0000050?nV4@030000003oYQ40ojHA00<0ojHA00<0[Jf]0?nV403oYQ00
103oYQ02000000<0ojH@0P0000030?nV40800000303oYQ000`2][Jd000000000000:0?nU40800000
2@3oYA000`000000ojD@000000040?nU40040:f][@3oXa00oj<@000000T0oj<@0P0000070?nS4080
00001@3oXa000`2][Jd0o:0@0?bP400D0?bP40D0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P03
0:f][@3KRPd0fhX=00D0fhX=0P2][Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28
EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2]
[Jd0kiP@0>nH40020>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00/0oj@A00<000000?nT4@3oY1400`3oY142000000<0[Jf]103oYQ42000000P0ojHA0P0000080?nV
4@800000203oYQ42000000T0ojHA0P0000050?nV4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000
000<0?nV4@8000000`3oYQ400`000000ojHA0?nV4@040?nV4@040:f][@3oYQ00ojH@0?nV40D00000
1@3oYQ03000000/0ojH@1P00000:0?nU408000002@3oYA000`000000ojD@000000040?nU40050:f]
[@3oXa00oj<@0?nS400000001`3oXa02000000030?nS40000000oj<@00D0oj<@0P0000050?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@80fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0
R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>7
3P030:f][@3_V100kiP@0080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00/0oj@A00<000000?nT4@3oY1400`2][Jd00`000000oj@A0:f][@060?nV4@800000203oYQ420000
00P0ojHA00<0[Jf]0000000000001P3oYQ42000000X0ojHA0P0000050?nV4@070:f][@3oYQ40ojHA
0?nV4@000000ojHA0000000>0?nV4@<000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@00H0ojD@1P0000060?nU40H00000103oYA000`2][Jd0oj<@0?nS40020?nS40030000003o
Xa00oj<@00@0oj<@00@000000?nS4000000000001P3oXa02000000D0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=00T0fhX=0P2][Jd00`000000^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H7
00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3C
Q`h0dhL>00H0dhL>0`2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402P3o
Y140102][Jd000000:f][@2][Jd30?nT4@030000003oY140[Jf]00H0ojHA0P0000070?nV4@800000
2@3oYQ400`2][Jd00000000000060?nV4@8000002P3oYQ42000000D0ojHA00L0[Jf]0?nV4@3oYQ40
ojHA0000003oYQ40000001P0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@00<0oj<@0P0000030?nS40030000003oXa00oj<@008000001P3oXa020000
00D0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0000000000001`2iM@/00`2]
[Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@070?nT4@<0[Jf]00<0oj@A0000003oY140103oY1400`000000oj@A0:f][@060?nV
4@8000001`3oYQ42000000T0ojHA00@0[Jf]0?nV4@0000000000103oYQ42000000/0ojHA0P000005
0?nV4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000000H0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40050?nS40<00000103oXa000`000000oj<@
0?nS40040?nS408000001@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00/0mY`?
102][Jd50?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd00000
00000002000000D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo
001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX100
403lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]103oY1400`000000oj@A0?nT4@020?nT4@800000
00<0oj@A0:f][@3oYQ401@3oYQ43000000D0ojHA0P00000:0?nV4@040:f][@3oYQ40ojHA0?nV4@@0
00003@3oYQ42000000D0ojHA00L0[Jf]0?nV4@3oYQ40ojHA0000003oYQ40000001P0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01<0oj<@0P000005
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL3`2][Jd0
k9H>0140k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01P2][Jd000000000002][Jd0^GD;000000@0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@030=>73P2][Jd0kiP@00/0kiP@00<0[Jf]0?bP403lX100
403lX1000`2][Jd0oj@A0:f][@030:f][@P0oj@A00<000000?nT4@3oY1400P3oY142000000030?nT
4@2][Jd0ojHA00D0ojHA0`0000050?nV4@8000002@3oYQ400`2][Jd0ojHA0?nV4@0C0?nV4@800000
1@3oYQ401`2][Jd0ojHA0?nV4@3oYQ4000000?nV4@000000603oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004`3oXa02000000D0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@060:f][@00000000000;Ue2`2][Jd0^GD;0P0000020;Ue2`030:f][@28EPL0R5H70080R5H700<0
[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0
[Jf]0=>73P3CQ`h0dhL>0:f][@0<0>nH40030:f][@3lX100o:0@00l0o:0@0`2][Jd<0?nT4@030000
003oY140oj@A0080oj@A00@000000?nT4@3oY140[Jf]1P3oYQ42000000030?nV4@000000ojHA0080
ojHA0P00000:0?nV4@030:f][@3oYQ40ojHA01<0ojHA0P0000050?nV4@070:f][@3oYQ40ojHA0?nV
4@000000ojHA0000000H0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400C0?nS408000001@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0000000000000P2iM@/00`2][Jd00000000000020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je2
0;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h00`2][Jd0dhL>0=>73P02
0=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402][Jd0
oj@A00`0oj@A00<000000?nT4@3oY1400P3oY14010000000oj@A0?nT4@2][Jd60?nV4@8000000P3o
YQ400`000000ojHA0000000<0?nV4@030:f][@3oYQ40ojHA01<0ojHA0P0000050?nV4@070:f][@3o
YQ40ojHA0?nV4@000000ojHA0000000H0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400C0?nS408000001@3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd00000000000030;Ue2`8000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80
[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0=>73P3C
Q`h00`3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd40?bP4003
0:f][@3oY140oj@A00/0oj@A00<000000?nT4@3oY1400P3oY14010000000oj@A0?nT4@2][Jd60?nV
4@8000000`3oYQ400`000000ojHA0?nV4@0;0?nV4@030:f][@3oYQ40ojHA01<0ojHA0P0000050?nV
4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000000H0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400C0?nS408000001@3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd00000000000030;Ue2`80000000<0[Jf]0;Ue2`2][Jd01028
EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@H0dhL>
00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]1P3lX1000`2][Jd0oj@A
0?nT4@0;0?nT4@030000003oY140oj@A0080oj@A00@000000?nT4@3oY140[Jf]0`3oYQ43000001<0
ojHA00<0[Jf]0?nV4@3oYQ404`3oYQ42000000D0ojHA00L0[Jf]0?nV4@3oYQ40ojHA0000003oYQ40
00000140ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01<0oj<@0`0000040?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@000000000000<0^GD;0P000000102iM@/0[Jf]0:f][@00
000308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0
[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]2@3lX1000`2][Jd0oj@A0?nT
4@0<0?nT4@030000003oY140oj@A008000000P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01<0ojHA0P0000050?nV4@080:f][@3oYQ40ojHA0?nV4@000000ojHA0000003oYQ4@0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU4100[Jf]1`3oYA000`2]
[Jd0oj<@0?nS400C0?nS40<00000103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd00000000000030;Ue2`8000000P2iM@/2000000@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2]
[Jd0o:0@0?bP40020?bP4080[Jf]303lX1000`2][Jd0oj@A0?nT4@0<0?nT4@030000003oY140oj@A
008000000P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01<0ojHA0P0000000`3o
YQ40[Jf]0:f][@060:f][@040000002][Jd000000:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd000000?nU400E0?nU40`0[Jf]4@3oXa03000000@0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=
0=^:3@8000000`2iM@/200000080^GD;0P0000001@28EPL0000008QF1`28EPL0[Jf]0480/>3V0@3o
ool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP402][Jd00P2][Jd>0?bP40030:f][@3oY140oj@A00`0oj@A00@000000?nT4@3oY14000000`3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA1`2][Jd2000000030:f][@3o
YQ40ojHA0080ojHA00L0[Jf]0?nV4@3oYQ40ojHA0000003oYQ40000001P0ojHA00<0[Jf]0?nV403o
YQ00703oYQ02000001d0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@L0oj<@0`0000040?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0
[Jf]3@3KRPd2000000@0^GD;00D000000;Ue2`2iM@/000000:f][@0200000080R5H700<0[Jf]0;3P
iP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH403_
V1002`3_V1020:f][A40o:0@00<0[Jf]0?nT4@3oY140303oY14010000000oj@A0?nT4@0000030?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@L0ojHA0P0000050?nV
4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000000H0?nV4@030:f][@3oYQ00ojH@01/0ojH@00@0
00000:f][@3oYA000000703oYA000`2][Jd0oj<@0?nS400<0?nS40L0[Jf]0`0000040?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f]
[@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0000002iM@/00`2iM@/01@000000^GD;0;Ue2`000000R5H7
008000000P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP
2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0<0?nT
4@040000003oY140oj@A000000<0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ480:f][A40ojHA0P000005
0?nV4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000000H0?nV4@030:f][@3oYQ00ojH@01`0ojH@
0P00000M0?nU40030:f][@3oXa00oj<@01<0oj<@0`0000080:f][AL0o:0@00<0[Jf]0?JL3`3fW0l0
4`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0
00000;Ue2`030;Ue2`050000002iM@/0^GD;00000028EPL00P00000208QF1`030:f][@2`h>H0/>3V
0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@
00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1401000
0000oj@A0?nT4@0000030?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40
ojHA01<0ojHA0P0000050?nV4@070:f][@3oYQ40ojHA0?nV4@000000ojHA0000000H0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0000003oYA00703oYA000`2][Jd0oj<@0?nS400C0?nS40030000
003oXa00000000@0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0
00000;Ue2`030;Ue2`040000002iM@/0^GD;00000080R5H700@000000:f][@28EPL0[Jf]@P2`h>H1
0?ooo`00F@2`h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40050>nH
4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A00@000000?nT
4@00000000000`3oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@0C
0?nV4@8000001@3oYQ400`2][Jd0000000000004000001P0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01<0oj<@0P0000050?nS40030:f][@3lX100
o:0@00P0o:0@1P2][Jd80?bP4003045Yh@3lX100[Jf]01H0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd000000;Ue2`030;Ue2`0:0000002iM@/0
^GD;00000011JN40R5H70000002][Jd0R5H700000480/>3V0@3oool005T0/>3V0P2][Jd209MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@H0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@030000003oY140000000@0oj@A00@0[Jf]0?nV4@3o
YQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA0100ojHA1@0000050?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01@0oj<@00<000000?nS403oXa000`3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f]
[@<0fhX=00L0[Jf]0000002iM@/0^GD;0000002iM@/000000080^GD;00D0000008QF1`28EPL00000
08QF1`0200000480/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f]
[@3_V100kiP@0>nH4080[Jf]203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0
oj@A00<000000?nT4@0000000`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400D0?nS40030000003oXa00oj<@00<0oj<@00<0[Jf]0?bP403lX1005@3lX1060:f][A@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@00
00000P2iM@/00`000000^GD;0;Ue2`020;Ue2`0500000028EPL0R5H700000028EPL00`0000110;3P
iP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f]
[@X0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@030000003oY1400000
00<0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]00@000000;Ue2`2iM@/00000102iM@/0
1@000000[Jf]08QF1`000000R5H700<00000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]
0=>73P3CQ`h01P3CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0;
0?nT4@<0[Jf]0P0000040?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l5
0:f][@/0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@050:f][@000000
^GD;0;Ue2`000000102iM@/01@000000[Jf]08QF1`000000R5H700<00000@@2`h>H10?ooo`00E`2`
h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd00`11JN40kiP@0>nH
400:0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@<0oj@A0P00
00040?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@050:f][@000000[Jf]0:f][@000000
102iM@/01@000000[Jf]08QF1`000000R5H700<00000@@2`h>H10?ooo`00E`2`h>H00`000000[Jf]
0:f][@0309MP2`030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd70?nT4@800000103oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?00h0mY`?102][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd000000;Ue2`2iM@/0000000@0^GD;00D000000:f][@28
EPL0000008QF1`0400000400/>3V0@3oool005L0/>3V00<000000:f][@2][Jd00`2GH0/00`2][Jd0
dhL>0=>73P030=>73P040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0:f][@030:f][@/0oj@A00<000000?nT4@3oY1400`3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?0180mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00H0[Jf]0000
00000000^GD;0000002][Jd30;Ue2`050000002][Jd0R5H700000028EPL0100000100;3PiP40oooo
001G0;3PiP030000002][Jd0[Jf]00<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P2][Jd30=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][@l0oj@A00<000000?nT4@3oY140
0`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd0
0P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0000000000000P0000002@2iM@/0[Jf]
0;Ue2`2iM@/000000:f][@28EPL0000008QF1`0400000400/>3V0@3oool005L0/>3V00<000000:f]
[@2][Jd00`2GH0/0102][Jd0dhL>0=>73P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX100303lX1020:f][@030?bP402][Jd0oj@A00l0oj@A00<000000?nT4@3oY1400`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh2
0:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd000000000002iM@/000000080^GD;0P2]
[Jd0102iM@/0000008QF1`28EPL500000400/>3V0@3oool005L0/>3V00<000000:f][@2][Jd00`2G
H0/00`2][Jd0dhL>0:f][@060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3l
X1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd01@2][Jd000000000002iM@/0000000@0^GD;00@0[Jf]00000028EPL0R5H71@0000100;3PiP40
oooo001G0;3PiP030000002][Jd0[Jf]00<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd000000000002iM@/0000000D0^GD;00<0000008QF1`28
EPL01@0000100;3PiP40oooo001G0;3PiP030000002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00D0[Jf]000000000000^GD;000000050;Ue2`030000002][Jd0R5H70080
000000<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]
1`3CQ`h00`2][Jd0kiP@0>nH400<0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@03
0>bF3P2][Jd0fhX=00d0fhX=0P0000000`2iM@/000000;Ue2`040;Ue2`030000002][Jd0R5H70080
000000<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]
1`3CQ`h00`2][Jd0kiP@0>nH400<0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0
[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh30:f][@d0fhX=0P0000000`2iM@/000000;Ue2`040;Ue2`0300000028EPL0[Jf]0080
000000<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H01`000000[Jf]09MP2`2GH0/0[Jf]09MP
2`2][Jd01`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P040:f][@3KRPd0[Jf]0:f][@/0fhX=0P0000000`2iM@/000000;Ue2`040;Ue2`0300000028EPL0
[Jf]0080000000<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H010000000[Jf]09MP2`2][Jd2
09MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH402][Jd0
o:0@0100o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40
ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@80000000<0^GD;0000002iM@/0102i
M@/00`000000R5H708QF1`02000000030:f][@00000000000400/>3V0@3oool005L0/>3V00@00000
0:f][@2GH0/0[Jf]0P2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00L0kiP@0P2]
[Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@030:f][@000000^GD;00H0^GD;00D0
000008QF1`28EPL000000:f][@0300000400/>3V0@3oool005H0/>3V0P0000020:f][@<0Uf0;00<0
[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2]
[Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@050=^:3@80[Jf]1@3KRPd00`2][Jd000000;Ue2`030;Ue2`040000002iM@/0000000000080R5H7
00<000000:f][@0000000P0000100;3PiP40oooo001F0;3PiP8000000P2][Jd309MP2`030:f][@3C
Q`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203l
X1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3K
RPd20:f][@<0fhX=00<0[Jf]0000002iM@/00`2iM@/010000000^GD;0;Ue2`00000208QF1`030000
0028EPL0000000800000@02`h>H10?ooo`00EP2`h>H2000000030:f][@2GH0/0Uf0;0080Uf0;00<0
[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80
o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0
fhX=0P2][Jd00`3KRPd0[Jf]000000040;Ue2`080000002iM@/0^GD;0;Ue2`2][Jd0R5H700000028
EPL300000400/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@0
[Jf]0>nH402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A
1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=
0P2][Jd00`000000^GD;0;Ue2`020;Ue2`050000002iM@/0^GD;0;Ue2`2][Jd00P0000001028EPL0
00000000000000100;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>7
3P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3P
iPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0000
002][Jd00`2iM@/020000000^GD;0;Ue2`2iM@/0[Jf]08QF1`000000R5H70`0000100;3PiP40oooo
001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@070=>73P80[Jf]3P3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0000002iM@/0[Jf]0P2iM@/01@000000
^GD;0;Ue2`2iM@/0[Jf]00<0R5H70`0000100;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00<0
Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h20:f][@030=>73P2][Jd0kiP@00`0kiP@00<0[Jf]0?bP403l
X100403lX1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@070:f][@000000^GD;0;Ue2`2][Jd0^GD;00000003
0;Ue2`040:f][@28EPL0R5H708QF1`<00000@02`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@03
09MP2`030:f][@3CQ`h0dhL>0080dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3l
X100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0000002iM@/00P2iM@/00`2][Jd000000;Ue
2`020;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P0000100;3PiP40oooo001F0;3PiP030000002]
[Jd0[Jf]00<0Uf0;00D0[Jf]0=>73P3CQ`h0dhL>0:f][@040=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=
0P0000040;Ue2`050000002][Jd0^GD;0;Ue2`2][Jd00`28EPL0102][Jd0000000000000000o0;3P
iP40oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]1@3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@000000000000<0^GD;00<000000;Ue2`2][Jd00P2][Jd308QF
1`040:f][@0000000000000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/20:f]
[@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f]
[OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/00P0000000`2iM@/000000;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70`00000o
0;3PiP40oooo001E0;3PiP80000000<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3P
iP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue
2`8000000`2iM@/20:f][@<0R5H70`00000o0;3PiP40oooo001E0;3PiP80000000@0[Jf]09MP2`2G
H0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f]
[@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`040000002iM@/0^GD;0;Ue2`80[Jf]0`28EPL3
000003l0/>3V0@3oool005D0/>3V0P000000102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<
0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd0
0`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL3
000003l0/>3V0@3oool005D0/>3V0P0000001P2][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@P0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i
/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f]
[@0208QF1`030:f][@000000000003l0/>3V0@3oool005D0/>3V0P0000000`2][Jd0Uf0;0:f][@02
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`060:f][@28EPL0R5H70:f][@28EPL0[Jf]0P00000o0;3PiP40oooo001E0;3PiP80000000<0
[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2]
[Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102]
[Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00E@2`
h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0kiP@102]
[Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102]
[Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00E@2`
h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2]
[Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E@2`
h>H2000000030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH
403_V1020:f][@050:BNS`11JN40@FWQ0:BNS`2][Jd0102aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0
al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2]
[Jd0R5H708QF1`0208QF1`030:f][@000000000003l0/>3V0@3oool005D0/>3V0P0000001@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00T0dhL>00@0[Jf]0>nH402][Jd0[Jf]0`2TWXl3045Yh@030:f][@2aZid0
/J^M00@0/J^M0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP3045Yh@050;B`/@2]
[Jd0[Jf]0=^:3@2][Jd02P2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000400/>3V0@3oool005D0
/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd00`2TWXl0@FWQ0:BNS`020:BN
S`80@FWQ00@0Y9j?0:f][@11JN40@FWQ1P2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2@2n
^KP00`11JN40[Jf]0;B`/@03045Yh@030;B`/@2][Jd0[Jf]00X0^GD;00H0[Jf]08QF1`28EPL0R5H7
0:f][@0000100;3PiP40oooo001E0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P05
0:f][@2TWXl0Y9j?0:BNS`11JN400`2TWXl2045Yh@030:BNS`2][Jd0/J^M00<0@FWQ1P2aZid20:f]
[@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j
/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd;0;ji^004045Yh@2][Jd0];2a0;B`/@80@FWQ0`2d/;42
0:f][@P0^GD;00H0[Jf]08QF1`28EPL0R5H70:f][@0000100;3PiP40oooo001E0;3PiP80000000D0
[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@030:BNS`80
@FWQ00@0Y9j?0:f][@2aZid0@FWQ0`2aZid00`11JN40/J^M0;6[W@040;6[W@<0[Jf]3`2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf7
0;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00/0_[Vh00@0@FWQ0:f][@2d/;40];2a0P11
JN430;B`/@80@FWQ00<0[Jf]0;Ue2`2iM@/01@2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000400
/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P030=>73P80[Jf]
0P11JN430:BNS`04045Yh@2TWXl0Y9j?0:BNS`80@FWQ00@0[Jf]0;6[W@2aZid0@FWQ102aZid2045Y
h@D0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m
^`030:f][@2n^KP0_[Vh0080_[Vh0`11JN450;ji^004045Yh@2n^KP0[Jf]0;B`/@80@FWQ0P2d/;44
045Yh@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<00000
0;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@11JN40RXEe0:f][@11JN400`2T
WXl01011JN40Y9j?0:BNS`2TWXl2045Yh@040:f][@2aZid0/J^M045Yh@@0/J^M0`11JN440;6[W@03
0:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`03
0:f][@2n^KP0_[Vh00<0@FWQ1`2n^KP01011JN40_[Vh0:f][@2d/;42045Yh@80];2a1011JN40102]
[Jd0@FWQ0:f][@2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H0
0`000000/>3V0:f][@0309MP2`0;0:f][@3CQ`h0dhL>0=>73P2][Jd0RXEe045Yh@2:QGD0[Jf]045Y
h@2][Jd00P2TWXl01011JN40Y9j?0:BNS`2TWXl2045Yh@040:f][@2aZid0/J^M045Yh@@0/J^M0P11
JN450;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302]
[JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP00P2n
^KP00`11JN40_[Vh0;ji^0050;ji^004045Yh@2n^KP0[Jf]0;B`/@80@FWQ0P2d/;44045Yh@050;B`
/@11JN40Wi^P045Yh@2][Jd00P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0
/>3V00<000000;3PiP2][Jd00`2GH0/0102][Jd0dhL>0:f][@2][Jd2045Yh@80RXEe00H0[Jf]045Y
h@2TWXl0[Jf]0:BNS`11JN430:BNS`80@FWQ00@0[Jf]0;6[W@2aZid0@FWQ102aZid2045Yh@D0/J^M
0P11JN4:0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f]
[@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]
2P33_K/2045Yh@80`kfk00<0[Jf]0;ji^02n^KP00P2n^KP00`11JN40_[Vh0;ji^0050;ji^004045Y
h@2n^KP0[Jf]0;B`/@80@FWQ0P2d/;44045Yh@030;B`/@11JN40Wi^P0080@FWQ0`2][Jd408QF1`03
0:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00`2GH0/20:f][@<0RXEe
00D0@FWQ08Z5M@2:QGD0[Jf]045Yh@020:BNS`80@FWQ0`2TWXl2045Yh@040:f][@2aZid0/J^M045Y
h@@0/J^M0P11JN440;6[W@04045Yh@2][Jd0^K:V045Yh@d0^K:V0`2][JdA0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`08
0<>m^`80@FWQ0P33_K/2045Yh@030:f][@2n^KP0_[Vh0080_[Vh00<0@FWQ0;ji^02n^KP01@2n^KP2
045Yh@040:f][@2d/;40];2a045Yh@80[Jf]0P11JN400`2d/;40@FWQ0;B`/@02045Yh@0509nKX011
JN40Wi^P09nKX02][Jd01028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001E0;3PiP030000002]
[Jd0Uf0;00<0Uf0;00<0[Jf]08Z5M@2:QGD01@2:QGD0102][Jd0@FWQ0:BNS`2TWXl2045Yh@80[Jf]
00D0Y9j?045Yh@11JN40[Jf]0;6[W@02045Yh@@0/J^M0P11JN430;6[W@03045Yh@2aZid0[Jf]0080
^K:V00<0@FWQ0;VbYP2i/ZH02`2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036
`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/01@33_K/3045Yh@<0`kfk0P11JN400`2][Jd0
_[Vh0;ji^0020;ji^003045Yh@2n^KP0_[Vh00D0_[Vh1P11JN420;B`/@80@FWQ00@0];2a045Yh@2d
/;40@FWQ0P2OVj001@11JN40Wi^P09nKX011JN40[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H1
0?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1P2:QGD00`11JN40[Jf]045Yh@020:BN
S`80@FWQ0P2TWXl01@2][Jd0@FWQ045Yh@2][Jd0/J^M0080@FWQ102aZid2045Yh@<0/J^M00<0@FWQ
0;6[W@2][Jd00P2i/ZH00`11JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V00H0^K:V00<0[Jf]
0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]
0<>m^`33_K/01P33_K/2045Yh@@0`kfk0P11JN401@2][Jd0_[Vh0;ji^02n^KP0@FWQ00T0_[Vh0`2]
[Jd00`11JN40];2a0;B`/@02045Yh@040;B`/@11JN40];2a045Yh@80Wi^P00D0@FWQ09nKX02OVj00
@FWQ0:f][@0308QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0
Uf0;0P2][Jd708Z5M@80@FWQ00<0Y9j?045Yh@11JN40102TWXl2045Yh@040:f][@2aZid0@FWQ045Y
h@@0/J^M0P11JN420;6[W@80@FWQ00<0/J^M0:f][@2i/ZH00P2i/ZH01011JN40^K:V0;VbYP2i/ZH6
045Yh@<0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[00
0`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=
0<K0_0030:f][@33_K/0`kfk00H0`kfk0P11JN440<>m^`80@FWQ00D0[Jf]0;ji^02n^KP0_[Vh045Y
h@080;ji^080[Jf]0P2d/;400`11JN40];2a0;B`/@02045Yh@040;B`/@11JN40];2a0:f][@80Wi^P
00H0@FWQ09nKX02OVj00@FWQ09nKX02][Jd208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0
/>3V00<0[Jf]09MP2`2GH0/00`2][Jd708Z5M@030:f][@2TWXl0@FWQ0080@FWQ0`2TWXl2045Yh@03
0:BNS`2][Jd0[Jf]0080@FWQ102aZid2045Yh@80/J^M00@0@FWQ0;6[W@2aZid0[Jf]0`2i/ZH01011
JN40^K:V0;VbYP2i/ZH2045Yh@<0^K:V00D0@FWQ0;VbYP2i/ZH0^K:V0:f][@0=0;jg[0@0[Jf]00<0
_[N/0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0
[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102]
[JdA0<K0_0030:f][@33_K/0`kfk00H0`kfk0P11JN450<>m^`80@FWQ0`2n^KP00`11JN40_[Vh0;ji
^0040;ji^080[Jf]00D0_[Vh0:f][@2d/;40];2a045Yh@020;B`/@<0@FWQ0P2d/;40102][Jd0Wi^P
09nKX011JN4209nKX006045Yh@2OVj00[Jf]0:f][@28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H0102]
[Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]0:BNS`2TWXl01P2TWXl2045Yh@030:BNS`2][Jd0
/J^M0080@FWQ102aZid01@11JN40/J^M0;6[W@2aZid0@FWQ0080/J^M00<0[Jf]0;VbYP2i/ZH01@2i
/ZH00`11JN40^K:V0;VbYP030;VbYP04045Yh@2i/ZH0^K:V0:f][@80_[N/00<0@FWQ0;jg[02n]j`0
302n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f]
[@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]
0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0P11JN450<>m^`80@FWQ
0`2n^KP2045Yh@<0_[Vh0P2][Jd20;ji^005045Yh@2][Jd0];2a0;B`/@11JN400P2d/;42045Yh@<0
];2a00<0[Jf]09nKX02OVj000`11JN4209nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0
/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl01P2TWXl2045Yh@03
0:BNS`2][Jd0/J^M0080@FWQ0`2][Jd00`2aZid0@FWQ0;6[W@020;6[W@04045Yh@2aZid0/J^M0:f]
[@L0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH01011JN40^K:V0:f][@2n]j`2045Yh@l0_[N/00<0[Jf]
0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`5
0:f][@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`80@FWQ1@33_K/2
045Yh@<0_[Vh0P11JN430:f][@<0_[Vh0P11JN400`2][Jd0];2a045Yh@020;B`/@03045Yh@2d/;40
];2a00<0];2a00@0[Jf]09nKX02OVj00Wi^P0P11JN40102OVj00[Jf]0:f][@1`KWT20:f][D00/>3V
0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]1@2:QGD00`2][Jd0Y9j?0:BNS`060:BNS`<0@FWQ00@0
[Jf]0;6[W@11JN40@FWQ0`2aZid00`2][Jd0@FWQ0;6[W@020;6[W@04045Yh@2aZid0/J^M0:f][@h0
^K:V00@0@FWQ0;VbYP2][Jd0_[N/0P11JN4?0;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l
00<0a/2l00<0@FWQ0<K0_036`;`02P36`;`00`2][Jd0`kfk0<>m^`060<>m^`80@FWQ1P33_K/01011
JN40_[Vh0;ji^02n^KP2045Yh@L0_[Vh00@0@FWQ0:f][@2d/;40@FWQ202d/;400`2][Jd0Wi^P09nK
X00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0
Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0Y9j?0:BNS`060:BNS`<0@FWQ00<0[Jf]
0;6[W@11JN401@2aZid01@11JN40[Jf]0:f][@2][Jd0@FWQ0080/J^M00<0[Jf]0;VbYP2i/ZH0302i
/ZH00`11JN40[Jf]0;jg[0020;jg[003045Yh@2n]j`0_[N/00d0_[N/00<0[Jf]0<6j/031^[002P31
^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`00P36
`;`00`11JN40a/2l045Yh@0;0<K0_0030:f][@33_K/0`kfk00H0`kfk0P11JN460<>m^`04045Yh@2n
^KP0[Jf]0:f][@80@FWQ0P2n^KP00`11JN40_[Vh0;ji^0020;ji^004045Yh@2][Jd0];2a045Yh@P0
];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe0:f][@<0RXEe00<0[Jf]0:BN
S`2TWXl01P2TWXl2045Yh@040:BNS`11JN40/J^M045Yh@D0/J^M00P0@FWQ0;6[W@2aZid0/J^M045Y
h@2][Jd0/J^M0:f][@d0^K:V0P11JN400`2][Jd0_[N/0;jg[00A0;jg[0030:f][@31^[00`KZ`00l0
`KZ`202][Jd@0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/01011JN4@0<S1^`03
0:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00l0al6l00<0@FWQ0<O1_02]
[Jd01036`;`2045Yh@`0a/2l00<0[Jf]0<>m^`33_K/01P33_K/2045Yh@D0`kfk00<0[Jf]045Yh@2]
[Jd00P2n^KP2045Yh@80_[Vh0P11JN440;ji^080@FWQ2@2d/;400`2][Jd0Wi^P09nKX0020:f][@<0
Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C
00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0P11JN400`2TWXl0
[Jf]045Yh@060;6[W@04045Yh@2aZid0/J^M0;6[W@80@FWQ0`2][Jd;0;VbYP04045Yh@2i/ZH0@FWQ
0:f][A<0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^PD0@FWQ4P38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0
[Jf]0<O1_037`K`02P37`K`00`11JN40al6l0<O1_002045Yh@030<O1_011JN40@FWQ00D0a/2l00<0
@FWQ0<K0_036`;`02P36`;`00`2][Jd0`kfk0<>m^`060<>m^`80@FWQ0P33_K/30:f][@030<>m^`11
JN40_[Vh0080_[Vh0P11JN420;ji^080@FWQ102n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2O
Vj00[Jf]00D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0
Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@080:BNS`80@FWQ00<0Y9j?
0:f][@2aZid01P2aZid01011JN40/J^M0;6[W@2aZid2045Yh@060;6[W@2][Jd0^K:V0:f][@11JN40
[Jf]1P2i/ZH4045Yh@030;VbYP2][Jd0_[N/0180_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0
`kfc0<>m/`0>0<>m/`/0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`02045Yh@d0b<6k2@2][JdB0<S1^`03
0:f][@37`K`0al6l00X0al6l0`11JN440<O1_0030:f][@11JN40a/2l0100a/2l00<0[Jf]0<>m^`33
_K/01P33_K/2045Yh@80[Jf]1033_K/01011JN40_[Vh0;ji^02n^KP3045Yh@80_[Vh00<0@FWQ0;ji
^02n^KP00P2n^KP00`2][Jd0];2a0;B`/@080;B`/@030000002][Jd0Wi^P00D0Wi^P00<0[Jf]071^
N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:
QGD00`2:QGD20:f][@P0Y9j?0P11JN400`2TWXl0[Jf]0;6[W@040;6[W@03045Yh@2aZid0@FWQ00<0
/J^M0P11JN40102aZid0[Jf]0;VbYP2i/ZH2045Yh@<0[Jf]0P2i/ZH3045Yh@<0^K:V00<0[Jf]0;jg
[02n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00P11JN400`38`K/0[Jf]0:f][@0:0:f]
[@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_004045Yh@H0al6l0P11JN450<O1
_0030:f][@11JN40a/2l0100a/2l00<0[Jf]0<>m^`33_K/01@33_K/00`2][Jd0@FWQ045Yh@060<>m
^`04045Yh@2n^KP0_[Vh0;ji^080@FWQ00<0_[Vh045Yh@11JN401@2n^KP00`2][Jd0];2a0;B`/@08
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F
0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`06
0:BNS`80@FWQ00<0Y9j?0:f][@2aZid01@2aZid2045Yh@@0/J^M0P11JN400`2][Jd0^K:V0;VbYP02
045Yh@<0^K:V0`11JN400`2][Jd0^K:V0;VbYP020;VbYP050:f][@2n]j`0_[N/0;jg[011JN403P2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0@FWQ00<0@FWQ4033_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j3P2]
[Jd2045Yh@030:f][@38`K/0b<6k00l0b<6k00<0[Jf]0<S1^`38`K/03038`K/3045Yh@@0b<6k00<0
[Jf]045Yh@11JN401037`K`00`11JN40al6l0<O1_0030<O1_080@FWQ1@37`K`00`2][Jd0@FWQ0<K0
_00@0<K0_0030:f][@33_K/0`kfk0080`kfk0`2][Jd00`33_K/0@FWQ045Yh@060<>m^`04045Yh@2n
^KP0_[Vh0;ji^080@FWQ202n^KP00`2][Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii
071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0
[Jf]1P2TWXl2045Yh@030:BNS`2][Jd0/J^M00/0/J^M0P11JN40102][Jd0^K:V0;VbYP11JN440;Vb
YP80@FWQ0P2i/ZH30:f][@030;VbYP2][Jd0_[N/0080_[N/00<0@FWQ0;jg[02n]j`0302n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0@FWQ2`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng00T0a[ng<02][Jd;0<O1^P030:f][@38`K/0b<6k0080@FWQ4P38`K/0
0`2][Jd0b<6k0<S1^`040<S1^`<0@FWQ0P38`K/4045Yh@H0b<6k0P11JN460<O1_003045Yh@37`K`0
al6l0080al6l00<0@FWQ0<O1_037`K`01037`K`2045YhA40a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd5
0<>m^`80@FWQ1@33_K/00`11JN40_[Vh0;ji^002045Yh@T0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40
102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`
h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd40:BNS`80@FWQ
00<0Y9j?0:f][@2aZid0302aZid01@11JN40[Jf]0;VbYP2i/ZH0@FWQ00@0^K:V00<0@FWQ0;VbYP2i
/ZH0102i/ZH30:f][@80_[N/00<0@FWQ0;jg[02n]j`0302n]j`00`2][Jd0`KZ`0<6j/00B0<6j/004
0:f][@33_K<0`kfc0<>m/`80@FWQ1033_K<2045Yh@H0`kfc0`11JN400`33_K<0[Jf]0<Fn]@0C0<Fn
]@0300000035_[D0[Jf]01L0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k0080@FWQ4@38`K/3045Yh@80b<6k1011JN460<S1^`80@FWQ1P38`K/00`11
JN40al6l0<O1_00:0<O1_003045Yh@37`K`0al6l00<0al6l0P11JN450<K0_003045Yh@36`;`0a/2l
00P0a/2l102][Jd80<>m^`80@FWQ1@33_K/00`11JN40_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a
00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o
0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl0
0`2][Jd0Y9j?0:BNS`03045Yh@030:BNS`2][Jd0/J^M00d0/J^M0`11JN450;VbYP03045Yh@2i/ZH0
^K:V00<0^K:V00@0@FWQ0;VbYP2][Jd0_[N/0P2][Jd00`11JN40[Jf]0;jg[00<0;jg[0030:f][@31
^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN450<>m/`80@FWQ1`33_K<5045YhA@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/00P11JN4=0<S1^`@0@FWQ00<0b<6k0:f][@38`K/01038`K/2045Yh@H0b<6k
0P11JN450<S1^`80@FWQ4P37`K`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`00`36`;`50:f][@80a/2l
00<0[Jf]0<>m^`33_K/01`33_K/2045Yh@D0`kfk00<0@FWQ0;ji^02n^KP02`2n^KP0102][Jd0];2a
0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3P
iP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f]
[@050:BNS`11JN40@FWQ0:BNS`2][Jd03P2aZid00`2][Jd0^K:V0;VbYP050;VbYP03045Yh@2i/ZH0
^K:V00<0^K:V00<0@FWQ0;VbYP2][Jd00`2n]j`00`11JN40_[N/0:f][@030:f][@T0_[N/00<0[Jf]
0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@H0`kfc00<0@FWQ0<>m/`33_K<01@33
_K<2045Yh@030:f][@35_[D0aKje00`0aKje1011JN440<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0D0<O1^P04045Yh@2][Jd0b<6k0<S1^`80@FWQ
0P38`K/3045Yh@X0b<6k0P11JN400`38`K/0[Jf]0<S1^`040<S1^`80@FWQ1P38`K/2045Yh@D0b<6k
0P11JN4A0<O1_080@FWQ00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0:f][@030:f][@L0a/2l
00<0[Jf]0<>m^`33_K/01`33_K/2045Yh@D0`kfk00<0@FWQ0;ji^02n^KP02`2n^KP0102][Jd0];2a
0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?oo
o`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`03
0:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH00`11JN40^K:V0;VbYP030;VbYP03
045Yh@2i/ZH0[Jf]00<0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031
^[004P31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@L0`kfc00<0@FWQ0<>m/`33_K<01033_K<2045Y
h@030:f][@35_[D0aKje00X0aKje0P11JN440<Fn]@04045Yh@35_[D0aKje0<Fn]@80@FWQ1P36_kL0
0`11JN40a[ng0<Jo]`040<Jo]`03045Yh@36_kL0a[ng00H0a[ng00<0[Jf]0<O1^037`KP04P37`KP3
045Yh@`0al6j1011JN450<O1^P03045Yh@37`KX0[Jf]0080b<6k1011JN420<S1^`<0@FWQ2038`K/2
045Yh@030<S1^`2][Jd0b<6k00@0b<6k0P11JN460<S1^`80@FWQ1038`K/2045Yh@030:f][@37`K`0
al6l00d0al6l0`11JN401037`K`0[Jf]0<K0_036`;`30:f][@03045Yh@2][Jd0a/2l00X0a/2l00<0
[Jf]0<>m^`33_K/01`33_K/2045Yh@D0`kfk00<0@FWQ0;ji^02n^KP02`2n^KP30:f][@P0];2a00<0
[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0
[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@H0/J^M00<0@FWQ0;6[W@2aZid0102aZid0
0`2][Jd0^K:V0;VbYP070;VbYP80@FWQ0P2i/ZH2045Yh@030;VbYP2][Jd0_[N/0080_[N/00<0@FWQ
0;jg[02n]j`01`2n]j`40:f][@030;jg[02][Jd0`KZ`01<0`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11
JN470<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN400`2][Jd0aKje0<Fn]@090<Fn]@80@FWQ1P35
_[D01011JN40aKje045Yh@2][Jd70<Jo]`03045Yh@36_kL0a[ng00@0a[ng00<0@FWQ0<Jo]`36_kL0
1P36_kL00`2][Jd0al6h0<O1^0020<O1^0@0@FWQ0P37`KP2045Yh@@0al6h1@11JN400`37`KP0[Jf]
0<O1^P090<O1^P<0@FWQ0`37`KX2045Yh@030<O1^P11JN40@FWQ0080al6j00<0[Jf]0<S1^`38`K/0
0`11JN450<S1^`80@FWQ1`38`K/2045Yh@030<S1^`2][Jd0b<6k00@0b<6k0P11JN460<S1^`80@FWQ
1038`K/2045Yh@030:f][@37`K`0al6l00`0al6l0`11JN450:f][@<0a/2l00<0@FWQ0<K0_036`;`0
2P36`;`00`2][Jd0`kfk0<>m^`070<>m^`80@FWQ1033_K/2045Yh@`0_[Vh0P2][Jd:0;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl20:f][@D0/J^M0P11JN450;6[W@030:f][@2i/ZH0^K:V00T0^K:V0P11
JN40102i/ZH0@FWQ0;VbYP2][Jd20;jg[080@FWQ3@2n]j`50:f][A40`KZ`00@0[Jf]0<>m/`33_K<0
`kfc0P11JN470<>m/`80@FWQ1@33_K<2045Yh@030:f][@35_[D0aKje00T0aKje0P11JN460<Fn]@<0
@FWQ00<0[Jf]0<Jo]`36_kL01@36_kL00`11JN40a[ng0<Jo]`040<Jo]`03045Yh@36_kL0a[ng00H0
a[ng00<0[Jf]0<O1^037`KP00`11JN430<O1^0@0@FWQ1`37`KP2045Yh@030<O1^02][Jd0al6j00T0
al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@<0al6j00<0[Jf]0<S1^`38`K/00P11JN470<S1^`80
@FWQ1P38`K/2045Yh@030<S1^`2][Jd0b<6k00@0b<6k0P11JN460<S1^`80@FWQ1038`K/2045Yh@03
0:f][@37`K`0al6l00X0al6l00<0[Jf]045Yh@11JN400P2][Jd20<O1_0030:f][@11JN40a/2l00<0
a/2l00<0@FWQ0<K0_036`;`02P36`;`00`2][Jd0`kfk0<>m^`070<>m^`80@FWQ1033_K/2045Yh@X0
_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40
oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]
0P2aZid00`11JN40/J^M0;6[W@040;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
0P11JN4>0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[00102][Jd0`kfc0<>m/`33_K<2045Y
h@L0`kfc0P11JN450<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D02@35_[D2045Yh@L0aKje0P11JN400`2]
[Jd0a[ng0<Jo]`040<Jo]`<0@FWQ1036_kL00`11JN40a[ng045Yh@070<Jo]`040:f][@37`KP0@FWQ
045Yh@H0al6h0`11JN470<O1^080@FWQ00<0al6h0:f][@37`KX02@37`KX00`11JN40al6j0<O1^P06
0<O1^P05045Yh@37`KX0al6j0<O1^P2][Jd00P38`K/2045Yh@L0b<6k0P11JN460<S1^`80@FWQ00<0
b<6k0:f][@38`K/01038`K/2045Yh@H0b<6k0P11JN440<S1^`80@FWQ00<0[Jf]0<O1_037`K`01@37
`K`50:f][@80@FWQ1@37`K`00`2][Jd0@FWQ0<K0_0030<K0_003045Yh@36`;`0a/2l00X0a/2l00<0
[Jf]0<>m^`33_K/01`33_K/2045Yh@@0`kfk0P11JN480;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0
RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0080@FWQ3P2n]j`00`2][Jd0`KZ`0<6j/008
0<6j/0L0[Jf]0`31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@L0`kfc0P11JN450<>m/`80@FWQ00<0
[Jf]0<Fn]@35_[D02@35_[D2045Yh@L0aKje0P11JN400`2][Jd0a[ng0<Jo]`040<Jo]`<0@FWQ1036
_kL3045Yh@L0a[ng00<0[Jf]0<O1^011JN402037`KP2045Yh@L0al6h0P11JN420<O1^0030:f][@37
`KX0al6j00L0al6j00<0@FWQ0<O1^P37`KX01P37`KX01@11JN40al6j0<O1^P37`KX0[Jf]0080b<6k
0P11JN480<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN400`38`K/0[Jf]0<S1^`040<S1^`80@FWQ
1P38`K/2045Yh@@0b<6k0P11JN400`2][Jd0al6l0<O1_0040:f][@03045Yh@37`K`0al6l00<0al6l
00<0@FWQ0<O1_037`K`01037`K`2045Yh@@0a/2l00<0@FWQ0<K0_036`;`02P36`;`00`2][Jd0`kfk
0<>m^`070<>m^`80@FWQ0`33_K/2045Yh@030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo
001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@040;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0080@FWQ3P2n
]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]0P11JN480<>m/`80@FWQ1033_K<2045Yh@030:f][@35
_[D0aKje00T0aKje0P11JN470<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL01036_kL3045Yh@@0a[ng0`11
JN470<Jo]`030:f][@11JN40@FWQ00P0al6h0P11JN470<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1
^P070<O1^P03045Yh@37`KX0al6j00H0al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@020<S1^`80@FWQ
2038`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<0b<6k0:f][@38`K/01038`K/2045Yh@L0b<6k
00D0@FWQ0<S1^`38`K/0b<6k0:f][@02045Yh@<0[Jf]1037`K`2045Yh@@0al6l00<0@FWQ0<O1_037
`K`01037`K`2045Yh@@0a/2l0P11JN4<0<K0_0030:f][@33_K/0`kfk00H0`kfk0P11JN430<>m^`80
@FWQ00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nK
X02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0
RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i
/ZH03`2i/ZH00`2][Jd0_[N/0;jg[002045Yh@h0_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0
`kfc0<>m/`33_K<2045Yh@D0[Jf]0`33_K<2045Yh@@0`kfc0P11JN400`2][Jd0aKje0<Fn]@0:0<Fn
]@03045Yh@35_[D0aKje00D0aKje0P11JN400`2][Jd0a[ng0<Jo]`040<Jo]`<0@FWQ1036_kL00`11
JN40a[ng045Yh@070<Jo]`030:f][@11JN40@FWQ00P0al6h0P11JN470<O1^080@FWQ0P37`KP00`2]
[Jd0al6j0<O1^P070<O1^P03045Yh@37`KX0al6j00H0al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@02
0<S1^`80@FWQ2038`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<0b<6k0:f][@38`K/01038`K/2
045Yh@@0b<6k0`2][Jd01011JN40[Jf]0:f][@2][Jd20<S1^`80@FWQ1P37`K`2045Yh@@0al6l00<0
@FWQ0<O1_037`K`00`37`K`3045Yh@@0a/2l0P11JN4<0<K0_0030:f][@33_K/0`kfk00H0`kfk0P11
JN401`33_K/0@FWQ045Yh@11JN40`kfk0:f][@2n^KP00P2][Jd:0;ji^0030:f][@2d/;40];2a00T0
];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f]
[@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]
3`2i/ZH00`2][Jd0_[N/0;jg[002045Yh@h0_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc
0<>m/`33_K<2045Yh@D0`kfc0`2][Jd2045Yh@<0[Jf]00@0`kfc045Yh@11JN40[Jf]3035_[D00`11
JN40aKje0<Fn]@050<Fn]@03045Yh@35_[D0[Jf]00H0a[ng00@0@FWQ0<Jo]`36_kL0@FWQ0`36_kL0
0`11JN40a[ng045Yh@070<Jo]`030:f][@11JN40@FWQ00P0al6h0P11JN470<O1^080@FWQ0P37`KP0
0`2][Jd0al6j0<O1^P070<O1^P03045Yh@37`KX0al6j00H0al6j00D0@FWQ0<O1^P37`KX0al6j0:f]
[@020<S1^`80@FWQ2038`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<0b<6k0:f][@38`K/00P38
`K/20:f][@80@FWQ102][Jd30<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN460<O1_003045Yh@37
`K`0al6l00@0al6l00<0@FWQ0<O1_037`K`00P11JN400`37`K`0[Jf]045Yh@040<K0_080@FWQ3036
`;`00`2][Jd0`kfk0<>m^`060<>m^`<0@FWQ0`33_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]
0;jg[02n]j`00P11JN4>0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11
JN480<>m/`80@FWQ0`33_K<00`2][Jd0@FWQ045Yh@060:f][@P0aKje0`11JN440<Fn]@03045Yh@35
_[D0[Jf]00D0a[ng0P11JN420<Jo]`03045Yh@36_kL0a[ng0080@FWQ00<0a[ng045Yh@36_kL01P36
_kL2045Yh@T0al6h0P11JN470<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P070<O1^P80@FWQ1`37
`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/00P11JN480<S1^`03045Yh@38`K/0b<6k0080b<6k0P2]
[Jd2045Yh@D0[Jf]0P38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@D0al6l00<0
@FWQ0<O1_037`K`01@37`K`2045Yh@<0al6l00<0[Jf]0<K0_036`;`00`36`;`2045Yh@`0a/2l00<0
[Jf]0<>m^`33_K/01033_K/3045Yh@80`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d
/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;
0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]
0;jg[02n]j`00P11JN4>0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11
JN480<>m/`80@FWQ1033_K<3045Yh@D0aKje2`2][Jd2045Yh@80aKje00<0@FWQ0<Fn]@2][Jd01@36
_kL2045Yh@80a[ng00<0@FWQ0<Jo]`36_kL00P11JN420<Jo]`03045Yh@36_kL0a[ng00@0a[ng0P11
JN490<O1^080@FWQ1`37`KP2045Yh@80al6h00<0[Jf]0<O1^P37`KX02@37`KX4045Yh@<0al6j0P11
JN420<O1^P030:f][@38`K/0b<6k0080@FWQ00<0b<6k0:f][@2][Jd0102][Jd2045Yh@@0[Jf]0P38
`K/2045Yh@030<S1^`2][Jd0b<6k00@0b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k00@0b<6k00<0
[Jf]045Yh@11JN400`37`K`00`11JN40al6l0<O1_00<0<O1_0030:f][@36`;`0a/2l0080a/2l0P11
JN4<0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3oool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0
/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`00P11JN4>
0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN480<>m/`80@FWQ1033
_K<3045YhA40aKje00@0[Jf]045Yh@11JN40@FWQ1`2][Jd2045Yh@80[Jf]00@0@FWQ0:f][@36_kL0
@FWQ0`36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ1`37`KP7045Yh@@0al6h0P11JN420<O1^003
0:f][@37`KX0al6j00T0al6j102][Jd5045Yh@D0[Jf]0P11JN400`2][Jd0b<6k0<S1^`040<S1^`80
@FWQ1P38`K/3045Yh@030:f][@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01P38`K/00`11JN40
b<6k0<S1^`040<S1^`030:f][@37`K`0@FWQ00<0@FWQ3`37`K`00`2][Jd0a/2l0<K0_0020<K0_080
@FWQ3036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^003
0:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?
0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@050;Vb
YP2][Jd0_[N/0;jg[011JN403`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m
/`80@FWQ2033_K<2045Yh@@0`kfc0`11JN440<Fn]@03045Yh@35_[D0aKje00D0aKje00<0@FWQ0<Fn
]@35_[D01@35_[D00`11JN40aKje0:f][@050<Jo]`80@FWQ0`36_kL00`11JN40[Jf]045Yh@030:f]
[@03045Yh@2][Jd0[Jf]00@0[Jf]0P11JN4B0:f][@80@FWQ3P2][Jd70<O1^P80@FWQ0P37`KX00`2]
[Jd0b<6k0<S1^`02045Yh@L0b<6k0P11JN470<S1^`80@FWQ00<0[Jf]0<S1^`38`K/00P38`K/2045Y
h@L0b<6k0P11JN460<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00P36`;`2045Y
h@`0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`
/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@030;jg[011JN40_[N/00h0_[N/00<0[Jf]0<6j/031
^[004P31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@P0`kfc0P11JN440<>m/`80@FWQ00<0[Jf]045Y
h@35_[D00P35_[D2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D01@35_[D00`11JN40aKje0:f][@050<Jo
]`80@FWQ0`36_kL00`11JN40a[ng045Yh@030<Jo]`03045Yh@36_kL0a[ng00@0a[ng0P11JN4B0<O1
^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P080<O1^P03045Yh@37`KX0al6j00D0al6j00D0@FWQ0<O1
^P37`KX0al6j0:f][@020<S1^`80@FWQ1P38`K/2045Yh@P0b<6k0`11JN440<S1^`03045Yh@38`K/0
b<6k00@0b<6k0P11JN400`38`K/0@FWQ0<S1^`050<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`00P36`;`2045Yh@X0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]
0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg
[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN480<>m/`80@FWQ0P33_K<4
045Yh@030:f][@11JN40aKje0080aKje0P11JN460<Fn]@03045Yh@35_[D0aKje00D0aKje00<0@FWQ
0<Fn]@2][Jd01@36_kL00`11JN40a[ng0<Jo]`020<Jo]`03045Yh@36_kL0@FWQ00<0a[ng00<0@FWQ
0<Jo]`36_kL01036_kL2045YhA80al6h0P11JN420<O1^0040:f][@37`KX0al6j045Yh@L0al6j00<0
@FWQ0<O1^P37`KX01@37`KX01@11JN40al6j0<O1^P37`KX0[Jf]0080b<6k0P11JN450<S1^`80@FWQ
2@38`K/2045Yh@030:f][@11JN40@FWQ0080@FWQ4@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`01036`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/0
3@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo
001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m
/`33_K<2045Yh@L0`kfc0P11JN470<>m/`030:f][@35_[D0@FWQ00<0@FWQ1`35_[D00`11JN40aKje
0<Fn]@040<Fn]@04045Yh@35_[D0aKje0:f][@@0a[ng0P11JN440<Jo]`80@FWQ1@36_kL00`11JN40
a[ng0<Jo]`030<Jo]`80@FWQ4P37`KP3045Yh@060<O1^02][Jd0al6j045Yh@37`KX0@FWQ1P37`KX0
0`11JN40al6j0<O1^P040<O1^P03045Yh@37`KX0al6j0080al6j00<0[Jf]0<S1^`38`K/00`11JN43
0<S1^`80@FWQ2P38`K/2045Yh@030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_0020<K0_003045Yh@36`;`0a/2l00@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=
0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y
0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33
_K<2045Yh@L0`kfc0P11JN470<>m/`030:f][@35_[D0aKje00/0aKje1P11JN430<Fn]@030:f][@36
_kL0a[ng0080a[ng0P11JN450<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL00`36
_kL2045YhA80al6h0P11JN400`37`KP0@FWQ0:f][@020<O1^P80@FWQ1P37`KX00`11JN40al6j0<O1
^P030<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]045Yh@11JN400P11JN400`38`K/0@FWQ045Y
h@02045Yh@/0b<6k0P11JN400`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00C0<6j/0040:f][@33
_K<0`kfc0<>m/`80@FWQ1P33_K<2045Yh@P0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
045Yh@06045Yh@<0a[ng00@0@FWQ0<Jo]`36_kL0a[ng1P11JN420<Jo]`80@FWQ3`37`KP5045Yh@80
al6h1011JN480<O1^PD0@FWQ1P37`KX00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0040:f][@33_K<0`kfc0<>m/`80
@FWQ1P33_K<2045Yh@P0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`80
@FWQ2P37`KP00`11JN40al6h0<O1^0090<O1^0030:f][@37`KX0al6j00T0al6j00<000000<O1^P37
`KX02037`KX00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ00<0[Jf]0<S1^`38`K/03038`K/00`11JN40
b<6k0<S1^`040<S1^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00
K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f]
[@31^[00`KZ`0<6j/0L0[Jf]2P31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@D0`kfc0P11JN490<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0@FWQ045Yh@090<O1
^003045Yh@37`KP0al6h00T0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0B0<S1
^`80@FWQ00<0[Jf]0<S1^`38`K/02`38`K/00`11JN40b<6k045Yh@050<S1^`030:f][@37`K`0al6l
00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/003
0:f][@33_K<0@FWQ00<0@FWQ1@33_K<2045Yh@T0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@11JN40@FWQ00P0al6h0P11JN4;0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@030:f][@38`K/0b<6k00/0b<6k0P11JN460<S1^`03
0:f][@37`K`0al6l00D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]
00<0`kfc045Yh@11JN401011JN4;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0@FWQ045Yh@080<O1^080@FWQ2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k0180b<6k0P11JN400`2][Jd0b<6k0<S1^`0<0<S1^`04045Yh@38`K/0b<6k0<S1^`H0
[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0
[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^011
JN402037`KP2045Yh@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0B0<S1^`80
@FWQ00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40
oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`040:f][@37`KP0@FWQ045Yh@H0al6h0`11JN4;0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03`38`K/4045Yh@030<S1^`2][Jd0b<6k0080
b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JdA0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP00P11JN440<O1^080@FWQ00<0al6h045Yh@37`KP0
2P37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]
I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0020<O1^0@0@FWQ0`37`KP00`11JN40al6h0<O1
^0090<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j0180al6j00<000000<O1
^P2][Jd05P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0
[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f]
[H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038
`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f]
[@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k
0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f]
[Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52225 .33411 m
.51891 .3309 L
s
.51891 .3309 m
.51556 .33088 L
s
.52392 .33411 m
.51891 .3309 L
s
.51556 .33088 m
.51222 .33406 L
s
.50888 .33082 m
.5022 .33072 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54898 .3306 m
.54398 .33391 L
s
.55231 .33052 m
.54898 .3306 L
s
.55566 .33364 m
.55231 .33052 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59493 .32859 m
.59863 .32836 L
s
.44916 .32852 m
.45458 .32886 L
s
.255 .412 .882 r
.54791 .34059 m
.55121 .33826 L
s
.55121 .33826 m
.55451 .33818 L
s
.54626 .34063 m
.55121 .33826 L
s
.49165 .3382 m
.4933 .33824 L
s
.48835 .34036 m
.49165 .3382 L
s
.48999 .34041 m
.49165 .3382 L
s
.54296 .3452 m
.54626 .34063 L
s
.55451 .33818 m
.55946 .34028 L
s
0 0 0 r
.52561 .36632 m
.52684 .35915 L
s
.52728 .36631 m
.52852 .35915 L
s
.255 .412 .882 r
.54461 .34517 m
.54791 .34059 L
s
0 0 0 r
.56074 .35144 m
.56076 .35602 L
s
.54069 .35912 m
.5407 .36296 L
s
.55362 .35619 m
.56076 .35602 L
s
.5624 .35033 m
.56243 .35597 L
s
.255 .412 .882 r
.48833 .34487 m
.48999 .34041 L
s
.48668 .34482 m
.48835 .34036 L
s
.54132 .34974 m
.54296 .3452 L
s
.54297 .34972 m
.54461 .34517 L
s
.48012 .33783 m
.4834 .3402 L
s
.47519 .33763 m
.48012 .33783 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4834 .3402 m
.48668 .34482 L
s
.47189 .33975 m
.47519 .33763 L
s
.47025 .33967 m
.47519 .33763 L
s
.53967 .35655 m
.54132 .34974 L
s
.54133 .35653 m
.54297 .34972 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55946 .34028 m
.56278 .34469 L
s
.56439 .33786 m
.56449 .35593 L
s
.56275 .33792 m
.56284 .35599 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57425 .33746 m
.58571 .33688 L
s
.47022 .34419 m
.47189 .33975 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48826 .3607 m
.48833 .34487 L
s
.48659 .36519 m
.48668 .34482 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54238 .36338 m
.54239 .36616 L
s
.255 .412 .882 r
.46858 .34411 m
.47025 .33967 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52143 .33862 m
.52807 .37025 L
s
.51477 .37024 m
.52143 .33862 L
s
.50818 .33853 m
.51477 .37024 L
s
.51643 .37025 m
.52142 .34538 L
s
.50314 .37011 m
.50817 .34529 L
s
.50148 .37008 m
.50818 .33853 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59234 .35987 m
.59237 .36431 L
s
.59398 .35877 m
.59402 .36421 L
s
.255 .412 .882 r
.53967 .35655 m
.5397 .36788 L
s
.54133 .35653 m
.54136 .36785 L
s
.47019 .34871 m
.47022 .34419 L
s
.46855 .34863 m
.46858 .34411 L
s
.55788 .35615 m
.56943 .35575 L
s
.47019 .34871 m
.4718 .35331 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46855 .34863 m
.47016 .35324 L
s
.47508 .35571 m
.48496 .35834 L
s
.48496 .35834 m
.48661 .36065 L
s
.48659 .36519 m
.48826 .3607 L
s
0 0 0 r
.57568 .371 m
.57585 .37164 L
s
.255 .412 .882 r
.4718 .35331 m
.47508 .35571 L
s
0 0 0 r
.57711 .37005 m
.57751 .37157 L
s
.255 .412 .882 r
.47016 .35324 m
.47508 .35571 L
s
.43611 .3353 m
.44742 .33612 L
s
.5397 .36788 m
.54137 .37467 L
s
.54136 .36785 m
.54303 .37464 L
s
.52308 .37027 m
.53306 .37022 L
s
.49651 .36998 m
.50813 .37018 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48492 .36741 m
.48659 .36519 L
s
0 0 0 r
.57585 .37164 m
.58086 .37466 L
s
.255 .412 .882 r
.4816 .36957 m
.48492 .36741 L
s
0 0 0 r
.57751 .37157 m
.58086 .37466 L
s
.255 .412 .882 r
.54137 .37467 m
.54304 .37919 L
s
.54303 .37464 m
.54471 .37916 L
s
.4701 .3623 m
.47175 .36238 L
s
.47173 .36465 m
.47175 .36238 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44225 .36756 m
.44256 .33579 L
s
.44063 .36745 m
.44095 .33567 L
s
.47009 .36457 m
.4701 .3623 L
s
.475 .36932 m
.4816 .36957 L
s
.47009 .36457 m
.47172 .36692 L
s
.54304 .37919 m
.54638 .38368 L
s
.47172 .36692 m
.475 .36932 L
s
.54471 .37916 m
.54804 .38365 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56295 .37869 m
.56457 .37181 L
s
.56457 .37181 m
.56464 .38548 L
s
.58093 .35523 m
.58262 .36195 L
s
.57917 .33722 m
.57939 .36893 L
s
.5808 .33714 m
.58103 .36885 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6085 .34216 m
.61006 .33751 L
s
.61006 .33751 m
.61325 .33499 L
s
.60688 .34228 m
.60845 .33763 L
s
.60845 .33763 m
.61325 .33499 L
s
.58262 .36195 m
.58594 .36633 L
s
.61325 .33499 m
.61806 .33458 L
s
.60688 .34228 m
.60693 .34682 L
s
.57445 .36916 m
.58103 .36885 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6085 .34216 m
.60854 .3467 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54638 .38368 m
.55137 .38585 L
s
.54804 .38365 m
.55137 .38585 L
s
.45369 .36373 m
.45535 .36155 L
s
.45535 .36155 m
.45696 .36392 L
s
.55966 .38335 m
.56295 .37869 L
s
.56295 .37869 m
.56464 .38548 L
s
.61806 .33458 m
.62129 .33657 L
s
.60693 .34682 m
.60859 .35124 L
s
.45694 .36619 m
.45696 .36392 L
s
.58594 .36633 m
.58923 .36842 L
s
.60854 .3467 m
.61021 .35111 L
s
.55137 .38585 m
.55469 .38577 L
s
.59246 .36369 m
.59407 .36132 L
s
.59407 .36132 m
.59572 .36349 L
s
.55469 .38577 m
.55966 .38335 L
s
.45529 .36837 m
.45694 .36619 L
s
.45369 .36373 m
.45531 .3661 L
s
.44239 .35391 m
.44394 .36084 L
s
.59246 .36369 m
.59411 .36586 L
s
.62129 .33657 m
.62454 .34082 L
s
.58923 .36842 m
.59413 .36814 L
s
.60859 .35124 m
.61345 .35313 L
s
.59572 .36349 m
.59574 .36576 L
s
.4185 .33378 m
.42325 .33649 L
s
.42325 .33649 m
.42639 .34131 L
s
.45039 .36809 m
.45529 .36837 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42639 .34131 m
.42794 .34599 L
s
.61021 .35111 m
.61345 .35313 L
s
.4185 .33378 m
.42165 .33635 L
s
.42165 .33635 m
.42479 .34117 L
s
.59413 .36814 m
.59574 .36576 L
s
.44394 .36084 m
.44715 .36561 L
s
.42479 .34117 m
.42634 .34585 L
s
.40271 .33216 m
.4185 .33378 L
s
.44715 .36561 m
.45039 .36809 L
s
.42794 .34599 m
.42947 .35294 L
s
.62607 .33613 m
.62922 .33356 L
s
.62454 .34082 m
.62607 .33613 L
s
.42634 .34585 m
.42786 .3528 L
s
.62922 .33356 m
.63081 .3334 L
s
.62766 .33598 m
.62922 .33356 L
s
.62613 .34067 m
.62766 .33598 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63376 .31723 m
.64474 .31602 L
s
.60869 .36033 m
.60871 .36261 L
s
.60869 .36033 m
.6103 .36021 L
s
.42934 .36432 m
.42947 .35294 L
s
0 0 0 r
.61622 .37243 m
.61708 .37237 L
s
.255 .412 .882 r
.6103 .36021 m
.61033 .36249 L
s
.43577 .3671 m
.44225 .36756 L
s
.42773 .36419 m
.42786 .3528 L
s
.60871 .36261 m
.61035 .36476 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40833 .38078 m
.409 .33284 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61035 .36476 m
.61361 .3668 L
s
.62613 .34067 m
.62633 .35659 L
s
.62454 .34082 m
.62479 .3613 L
s
.61345 .35313 m
.62311 .3546 L
s
.64005 .31655 m
.64074 .36434 L
s
.63848 .31673 m
.63916 .3645 L
s
.62311 .3546 m
.62474 .35674 L
s
.61361 .3668 m
.62004 .36628 L
s
.42765 .37104 m
.42934 .36432 L
s
.42604 .37091 m
.42773 .36419 L
s
.62479 .3613 m
.62633 .35659 L
s
.64038 .33924 m
.64345 .33435 L
s
.64345 .33435 m
.64654 .33172 L
s
.62004 .36628 m
.62322 .36372 L
s
.62322 .36372 m
.62479 .3613 L
s
.64654 .33172 m
.64966 .33135 L
s
.42599 .37548 m
.42765 .37104 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42438 .37535 m
.42604 .37091 L
s
.42272 .37979 m
.42599 .37548 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64734 .34927 m
.64739 .35257 L
s
.64577 .35055 m
.6458 .35278 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64966 .33135 m
.65436 .33306 L
s
.64966 .33135 m
.6528 .33325 L
s
.42112 .37966 m
.42438 .37535 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6528 .33325 m
.65598 .33743 L
s
.65436 .33306 m
.65752 .33724 L
s
.41788 .38167 m
.42272 .37979 L
s
.63441 .36498 m
.64074 .36434 L
s
.64064 .35748 m
.64386 .36172 L
s
.41788 .38167 m
.42112 .37966 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65598 .33743 m
.65764 .34409 L
s
.65752 .33724 m
.65918 .34389 L
s
.64386 .36172 m
.64703 .36367 L
s
.65764 .34409 m
.65771 .34866 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.402 .38015 m
.41788 .38167 L
s
.40674 .38063 m
.40742 .33267 L
s
.64703 .36367 m
.65016 .36332 L
s
.65918 .34389 m
.65926 .34847 L
s
.66814 .32897 m
.67873 .32742 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65783 .35553 m
.65926 .34847 L
s
.65016 .36332 m
.6548 .36049 L
s
.65016 .36332 m
.65324 .36067 L
s
.65628 .35572 m
.65771 .34866 L
s
.65324 .36067 m
.65628 .35572 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6548 .36049 m
.65783 .35553 L
s
.6727 .32832 m
.67359 .37657 L
s
0 0 0 r
.686 .31856 m
.68854 .31815 L
s
.255 .412 .882 r
.67421 .3281 m
.67511 .37636 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67468 .35331 m
.6778 .35748 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6778 .35748 m
.68236 .35912 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68916 .32577 m
.68968 .35106 L
s
.69064 .32552 m
.69116 .35082 L
s
.68471 .32649 m
.69505 .32477 L
s
.66901 .37717 m
.67511 .37636 L
s
.68236 .35912 m
.68536 .35867 L
s
.68536 .35867 m
.68829 .35591 L
s
.68536 .35867 m
.68978 .35567 L
s
.70088 .32374 m
.71093 .32185 L
s
.68829 .35591 m
.68968 .35106 L
s
.68978 .35567 m
.69116 .35082 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70664 .32267 m
.70738 .35502 L
s
.70521 .32295 m
.70594 .35528 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70159 .35604 m
.70738 .35502 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71816 .32736 m
.72084 .32216 L
s
.71692 .33459 m
.71816 .32736 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72084 .32216 m
.72495 .31896 L
s
.71956 .32708 m
.72224 .32187 L
s
.71833 .33431 m
.71956 .32708 L
s
.71692 .33459 m
.71703 .33922 L
s
.72224 .32187 m
.72495 .31896 L
s
.7048 .36947 m
.7062 .36689 L
s
.7048 .36947 m
.7063 .37155 L
s
.71833 .33431 m
.71844 .33894 L
s
.7062 .36689 m
.70769 .36897 L
s
.32097 .32373 m
.32241 .32171 L
s
.32109 .3191 m
.32241 .32171 L
s
.71703 .33922 m
.7186 .34591 L
s
.31965 .32112 m
.32109 .3191 L
s
.72495 .31896 m
.7277 .31836 L
s
.71844 .33894 m
.72001 .34563 L
s
.7063 .37155 m
.70769 .36897 L
s
.31965 .32112 m
.32097 .32373 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7186 .34591 m
.72152 .35 L
s
.72001 .34563 m
.72292 .34971 L
s
.72152 .35 m
.72576 .35147 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7277 .31836 m
.73186 .31975 L
s
.73186 .31975 m
.73469 .32377 L
s
.72292 .34971 m
.72576 .35147 L
s
.30876 .31865 m
.31004 .32128 L
s
.30986 .32826 m
.31004 .32128 L
s
.72576 .35147 m
.7299 .3506 L
s
.30614 .31568 m
.30876 .31865 L
s
.30851 .32795 m
.30992 .32593 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31999 .36328 m
.32033 .34928 L
s
.3186 .363 m
.32068 .33532 L
s
.32068 .33532 m
.32138 .36356 L
s
.30085 .31437 m
.30614 .31568 L
s
.31987 .36796 m
.32138 .36356 L
s
.30845 .33027 m
.30986 .32826 L
s
.7324 .34068 m
.7337 .33804 L
s
.7324 .34068 m
.73382 .34271 L
s
.7337 .33804 m
.73512 .34007 L
s
.30577 .32965 m
.30851 .32795 L
s
.7299 .3506 m
.73258 .34768 L
s
.30571 .33198 m
.30845 .33027 L
s
.3186 .363 m
.31987 .36796 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73512 .34007 m
.73518 .34241 L
s
.73258 .34768 m
.73518 .34241 L
s
.30808 .34427 m
.30955 .33991 L
s
.30931 .34925 m
.30955 .33991 L
s
.74384 .31455 m
.74528 .31888 L
s
.74384 .31455 m
.7441 .32387 L
s
.29902 .33271 m
.30577 .32965 L
s
.29816 .31604 m
.30085 .31437 L
s
.29896 .33505 m
.30571 .33198 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30667 .3463 m
.30808 .34427 L
s
.30808 .34427 m
.30931 .34925 L
s
.7441 .32387 m
.74528 .31888 L
s
.74528 .31888 m
.74653 .31622 L
s
.74653 .31622 m
.74907 .31321 L
s
.2968 .31804 m
.29816 .31604 L
s
.30393 .34803 m
.30667 .3463 L
s
.74907 .31321 m
.75422 .31184 L
s
.29563 .31303 m
.2968 .31804 L
s
.29537 .32237 m
.29563 .31303 L
s
.29537 .32237 m
.2968 .31804 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29863 .34677 m
.30393 .34803 L
s
.74448 .33788 m
.74573 .33522 L
s
.74448 .33788 m
.74461 .34257 L
s
.29634 .3344 m
.29902 .33271 L
s
.74573 .33522 m
.74829 .33223 L
s
.74454 .34022 m
.7458 .33756 L
s
.29628 .33674 m
.29896 .33505 L
s
.7458 .33756 m
.74835 .33457 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74461 .34257 m
.74599 .34459 L
s
.74829 .33223 m
.75462 .32588 L
s
.75422 .31184 m
.75683 .31348 L
s
.74835 .33457 m
.75468 .32822 L
s
.74599 .34459 m
.74868 .3463 L
s
.29497 .33641 m
.29634 .3344 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29491 .33876 m
.29628 .33674 L
s
.29608 .34378 m
.29863 .34677 L
s
.29484 .34111 m
.29497 .33641 L
s
.75683 .31348 m
.75816 .31547 L
s
.29484 .34111 m
.29608 .34378 L
s
.74868 .3463 m
.75387 .345 L
s
.75462 .32588 m
.7571 .32285 L
s
.75468 .32822 m
.75717 .32519 L
s
.75816 .31547 m
.75836 .3225 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7571 .32285 m
.7583 .32016 L
s
.28412 .31223 m
.28649 .31763 L
s
.75717 .32519 m
.75836 .3225 L
s
.28047 .30881 m
.28412 .31223 L
s
.75387 .345 m
.75637 .34198 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75637 .34198 m
.75757 .33929 L
s
.27802 .30807 m
.28047 .30881 L
s
.75757 .33929 m
.75871 .33424 L
s
.75871 .33424 m
.75898 .34366 L
s
.75757 .33929 m
.75898 .34366 L
s
.28594 .33641 m
.28601 .33406 L
s
.28482 .33136 m
.28601 .33406 L
s
.2835 .33337 m
.28482 .33136 L
s
.28329 .34044 m
.28594 .33641 L
s
.27551 .30968 m
.27802 .30807 L
s
.27431 .30931 m
.27802 .30807 L
s
.76679 .31062 m
.76794 .3079 L
s
.2835 .33337 m
.28468 .33607 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76794 .3079 m
.76923 .30988 L
s
.76679 .31062 m
.76808 .3126 L
s
.76808 .3126 m
.76923 .30988 L
s
.28072 .34211 m
.28329 .34044 L
s
.27296 .31364 m
.27551 .30968 L
s
.27176 .31327 m
.27431 .30931 L
s
.27702 .34106 m
.28072 .34211 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27155 .32035 m
.27296 .31364 L
s
.27035 .31997 m
.27176 .31327 L
s
.27465 .33799 m
.27702 .34106 L
s
.27344 .33763 m
.27702 .34106 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76844 .32437 m
.77052 .3524 L
s
.76807 .35309 m
.76844 .32437 L
s
.76887 .33853 m
.7693 .35275 L
s
.2714 .32507 m
.27155 .32035 L
s
.27238 .33253 m
.27465 .33799 L
s
.27021 .3247 m
.27035 .31997 L
s
.2714 .32507 m
.27238 .33253 L
s
.76807 .35309 m
.76944 .3575 L
s
.27118 .33217 m
.27344 .33763 L
s
.25809 .30152 m
.26609 .30429 L
s
.27021 .3247 m
.27118 .33217 L
s
.76944 .3575 m
.77052 .3524 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26156 .33632 m
.26263 .30311 L
s
.26041 .33594 m
.26149 .30272 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25701 .33479 m
.26156 .33632 L
s
.24614 .29698 m
.25366 .29989 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25987 .35265 m
.2611 .35063 L
s
.26003 .34787 m
.2611 .35063 L
s
.25881 .34989 m
.26003 .34787 L
s
.25881 .34989 m
.25987 .35265 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24952 .32487 m
.2504 .29866 L
s
.24844 .32447 m
.24932 .29824 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24828 .32926 m
.24952 .32487 L
s
.2472 .32886 m
.24844 .32447 L
s
.245 .33045 m
.24828 .32926 L
s
.23498 .29221 m
.24199 .29527 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.245 .33045 m
.2472 .32886 L
s
.8053 .29446 m
.81507 .29003 L
s
.2429 .32963 m
.245 .33045 L
s
.23717 .34448 m
.23895 .29397 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23616 .34407 m
.23794 .29353 L
s
.23988 .326 m
.2429 .32963 L
s
.23802 .32035 m
.23988 .326 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80929 .29271 m
.81109 .3433 L
s
.8083 .29315 m
.81009 .34371 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80706 .34494 m
.81691 .3408 L
s
.81507 .29003 m
.81703 .29153 L
s
.81507 .29003 m
.81796 .29108 L
s
.23318 .34283 m
.23717 .34448 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81703 .29153 m
.81905 .29544 L
s
.81796 .29108 m
.81996 .29498 L
s
.22639 .29056 m
.22806 .29629 L
s
.22806 .29629 m
.22873 .30397 L
s
.22855 .3088 m
.22873 .30397 L
s
.22548 .2901 m
.22713 .29583 L
s
.22713 .29583 m
.22779 .30352 L
s
.22378 .28676 m
.22639 .29056 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22735 .31561 m
.22855 .3088 L
s
.22762 .30835 m
.22779 .30352 L
s
.81905 .29544 m
.82014 .29982 L
s
.22378 .28676 m
.22548 .2901 L
s
.22643 .31517 m
.22762 .30835 L
s
.81996 .29498 m
.82104 .29936 L
s
.2159 .26509 m
.22177 .26848 L
s
.22201 .28583 m
.22378 .28676 L
s
.22533 .31958 m
.22735 .31561 L
s
.82014 .29982 m
.82131 .30662 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22441 .31913 m
.22643 .31517 L
s
.82104 .29936 m
.82221 .30617 L
s
.22018 .28731 m
.22201 .28583 L
s
.82131 .30662 m
.82176 .31875 L
s
.81691 .3408 m
.81871 .33752 L
s
.81691 .3408 m
.81964 .33709 L
s
.22252 .32068 m
.22533 .31958 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21729 .31799 m
.21921 .26704 L
s
.82221 .30617 m
.82266 .31831 L
s
.21644 .31753 m
.21837 .26655 L
s
.22252 .32068 m
.22441 .31913 L
s
.81871 .33752 m
.82038 .33179 L
s
.2183 .29122 m
.22018 .28731 L
s
.82112 .32648 m
.82176 .31875 L
s
.81964 .33709 m
.8213 .33135 L
s
.82038 .33179 m
.82112 .32648 L
s
.82203 .32605 m
.82266 .31831 L
s
.8213 .33135 m
.82203 .32605 L
s
.22075 .31979 m
.22252 .32068 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.825 .28496 m
.83084 .28162 L
s
.21909 .31645 m
.22075 .31979 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21756 .31067 m
.21909 .31645 L
s
.21285 .28059 m
.21364 .28108 L
s
.21395 .31616 m
.21729 .31799 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82912 .3025 m
.83022 .30935 L
s
.82627 .31895 m
.82967 .31714 L
s
.82838 .28306 m
.82967 .31714 L
s
.82755 .28354 m
.82883 .31759 L
s
.21119 .28205 m
.21285 .28059 L
s
.21197 .28254 m
.21285 .28059 L
s
.83022 .30935 m
.83205 .31331 L
s
.211 .28693 m
.21197 .28254 L
s
.21023 .28644 m
.21119 .28205 L
s
.21034 .30403 m
.211 .28693 L
s
.83205 .31331 m
.83375 .31484 L
s
.2089 .28058 m
.21023 .28644 L
s
.20938 .30846 m
.21023 .28644 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20751 .27716 m
.2089 .28058 L
s
.83375 .31484 m
.8361 .31344 L
s
.20938 .30846 m
.21034 .30403 L
s
.20534 .27566 m
.20751 .27716 L
s
.83513 .309 m
.836 .31098 L
s
.83513 .309 m
.83581 .30608 L
s
.20889 .30063 m
.20957 .30356 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83581 .30608 m
.83668 .30806 L
s
.20457 .29528 m
.20889 .30063 L
s
.20851 .31045 m
.20938 .30846 L
s
0 0 0 r
.19956 .26475 m
.20008 .26609 L
s
.255 .412 .882 r
.8361 .31344 m
.83677 .31051 L
s
.83668 .30806 m
.83677 .31051 L
s
.20691 .31196 m
.20851 .31045 L
s
0 0 0 r
.19956 .26475 m
.20006 .26656 L
s
.255 .412 .882 r
.20384 .27711 m
.20534 .27566 L
s
.20316 .27661 m
.20534 .27566 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1982 .26371 m
.19956 .26475 L
s
.255 .412 .882 r
.20399 .31006 m
.20691 .31196 L
s
.84094 .28258 m
.84145 .27718 L
s
.84094 .28258 m
.84114 .28749 L
s
.84145 .27718 m
.8434 .27321 L
s
.20296 .28151 m
.20384 .27711 L
s
.84114 .28749 m
.84203 .29191 L
s
.84164 .28208 m
.84214 .27667 L
s
.84164 .28208 m
.84184 .28699 L
s
.84214 .27667 m
.8434 .27321 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20228 .28101 m
.20316 .27661 L
s
.20326 .29184 m
.20457 .29528 L
s
.20257 .29135 m
.20457 .29528 L
s
.84184 .28699 m
.84272 .29141 L
s
.20277 .28643 m
.20296 .28151 L
s
.8434 .27321 m
.84536 .27168 L
s
.84203 .29191 m
.84418 .29289 L
s
.20277 .28643 m
.20326 .29184 L
s
.20209 .28593 m
.20228 .28101 L
s
.84272 .29141 m
.84418 .29289 L
s
.20209 .28593 m
.20257 .29135 L
s
.20268 .30663 m
.20399 .31006 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84242 .30176 m
.84252 .30422 L
s
.84242 .30176 m
.84311 .30127 L
s
.20218 .30121 m
.20287 .30169 L
s
.20278 .30416 m
.20287 .30169 L
s
.84252 .30422 m
.84331 .30621 L
s
.84311 .30127 m
.84321 .30374 L
s
.20208 .30367 m
.20268 .30663 L
s
.20208 .30367 m
.20218 .30121 L
s
.84536 .27168 m
.84673 .27312 L
s
.84418 .29289 m
.84815 .29237 L
s
.84331 .30621 m
.84477 .30771 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84673 .27312 m
.84817 .27703 L
s
.84477 .30771 m
.84739 .30576 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84817 .27703 m
.84857 .27157 L
s
.84817 .27703 m
.84907 .29931 L
s
.84857 .27157 m
.84965 .26807 L
s
.84877 .27651 m
.84917 .27106 L
s
.84877 .27651 m
.84947 .29385 L
s
.84917 .27106 m
.84965 .26807 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84815 .29237 m
.84887 .29435 L
s
.84965 .26807 m
.85023 .26755 L
s
.84739 .30576 m
.84855 .30229 L
s
.19634 .29676 m
.19685 .29974 L
s
.19675 .30223 m
.19685 .29974 L
s
.84855 .30229 m
.84907 .29931 L
s
.19604 .30422 m
.19675 .30223 L
s
.19563 .29875 m
.19634 .29676 L
s
.19079 .26326 m
.19451 .26695 L
s
.84907 .29931 m
.84947 .29385 L
s
.19563 .29875 m
.19614 .30173 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19425 .30272 m
.19604 .30422 L
s
.19143 .30022 m
.19286 .26538 L
s
.1909 .29971 m
.19233 .26485 L
s
.1932 .29923 m
.19425 .30272 L
s
.19229 .29323 m
.1932 .29923 L
s
.19205 .28525 m
.19229 .29323 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85278 .30129 m
.85647 .29775 L
s
.85503 .26279 m
.85838 .2957 L
s
.85442 .29978 m
.85503 .26279 L
s
.18935 .29819 m
.19143 .30022 L
s
.85494 .29927 m
.85534 .27026 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18712 .28004 m
.18795 .26004 L
s
.18541 .27793 m
.1885 .28162 L
s
.18668 .27952 m
.18751 .2595 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1837 .24988 m
.18371 .24973 L
s
.18204 .30037 m
.18291 .27971 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18655 .26092 m
.1872 .267 L
s
.85867 .25849 m
.86175 .29155 L
s
.85838 .2957 m
.85867 .25849 L
s
.18545 .25679 m
.18655 .26092 L
s
.85883 .29518 m
.85899 .266 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18469 .25569 m
.18545 .25679 L
s
.18576 .31276 m
.18639 .29763 L
s
.18563 .30468 m
.18639 .29763 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18232 .2825 m
.18248 .27885 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86517 .26258 m
.86523 .26382 L
s
.255 .412 .882 r
.18387 .25711 m
.18469 .25569 L
s
.18352 .25656 m
.18469 .25569 L
s
.18456 .30871 m
.18563 .30468 L
s
.18563 .30468 m
.18576 .31276 L
s
0 0 0 r
.86529 .26151 m
.8656 .26327 L
s
.18128 .31841 m
.18157 .32237 L
s
.18098 .32565 m
.18156 .32265 L
s
.255 .412 .882 r
.86056 .29311 m
.86285 .28997 L
s
0 0 0 r
.18068 .32152 m
.18128 .31841 L
s
.255 .412 .882 r
.18298 .26104 m
.18387 .25711 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18068 .32152 m
.18098 .32565 L
s
.255 .412 .882 r
.18265 .2605 m
.18352 .25656 L
s
.18323 .30972 m
.18456 .30871 L
s
0 0 0 r
.86658 .29557 m
.86661 .29626 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18244 .26554 m
.18298 .26104 L
s
.18212 .265 m
.18265 .2605 L
s
0 0 0 r
.86661 .29626 m
.86661 .29524 L
s
.255 .412 .882 r
.18247 .3087 m
.18323 .30972 L
s
.1818 .27258 m
.18244 .26554 L
s
.18149 .27204 m
.18212 .265 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18185 .30513 m
.18247 .3087 L
s
.1815 .30461 m
.18247 .3087 L
s
.86353 .26453 m
.86362 .25893 L
s
.86353 .26453 m
.86355 .27265 L
s
.86362 .25893 m
.86397 .25277 L
s
.86355 .27265 m
.86408 .28532 L
s
.18126 .28525 m
.1818 .27258 L
s
.86383 .26398 m
.86391 .25837 L
s
.86383 .26398 m
.86386 .27211 L
s
.86391 .25837 m
.86424 .25221 L
s
.86386 .27211 m
.86439 .28479 L
s
.86397 .25277 m
.86464 .24857 L
s
.18095 .28472 m
.18149 .27204 L
s
.18137 .29901 m
.18185 .30513 L
s
.86424 .25221 m
.86464 .24857 L
s
.86408 .28532 m
.86471 .29242 L
s
.18104 .29848 m
.1815 .30461 L
s
.18126 .2934 m
.18126 .28525 L
s
.18126 .2934 m
.18137 .29901 L
s
0 0 0 r
.17599 .23616 m
.17669 .23795 L
s
.255 .412 .882 r
.86439 .28479 m
.86502 .29189 L
s
.18094 .29287 m
.18095 .28472 L
s
.18094 .29287 m
.18104 .29848 L
s
.86464 .24857 m
.8651 .24745 L
s
.86471 .29242 m
.86523 .29699 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86502 .29189 m
.86552 .29646 L
s
0 0 0 r
.86916 .23681 m
.86993 .2345 L
s
.255 .412 .882 r
.8651 .24745 m
.86584 .2483 L
s
.86523 .29699 m
.86602 .30104 L
s
.86552 .29646 m
.86629 .30052 L
s
.17831 .28192 m
.17971 .28513 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17896 .28353 m
.17963 .24569 L
s
.86584 .2483 m
.86642 .25227 L
s
.86602 .30104 m
.86691 .30204 L
s
.17758 .27976 m
.17931 .25331 L
s
.86629 .30052 m
.86691 .30204 L
s
.86609 .24464 m
.86697 .26502 L
s
0 0 0 r
.87041 .23697 m
.8704 .24538 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86626 .24407 m
.86713 .26447 L
s
0 0 0 r
.87066 .2316 m
.87041 .23697 L
s
.17335 .31438 m
.17339 .31447 L
s
.255 .412 .882 r
.86691 .30204 m
.86739 .30099 L
s
0 0 0 r
.17481 .23632 m
.17484 .2321 L
s
.17452 .23938 m
.17481 .23632 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17335 .31438 m
.17664 .23788 L
s
.255 .412 .882 r
.17742 .27921 m
.17963 .24569 L
s
0 0 0 r
.17484 .2321 m
.17455 .23516 L
s
.255 .412 .882 r
.86739 .30099 m
.86791 .29684 L
s
0 0 0 r
.87088 .23043 m
.87066 .2316 L
s
.17455 .23516 m
.17452 .23938 L
s
.87121 .23291 m
.87088 .23043 L
s
.87129 .23233 m
.87088 .23043 L
s
.255 .412 .882 r
.17742 .27921 m
.17843 .24116 L
s
.17653 .27486 m
.17843 .24116 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8664 .26667 m
.86758 .26281 L
s
0 0 0 r
.86993 .2345 m
.87214 .28554 L
s
.86975 .23508 m
.87196 .28609 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87262 .28391 m
.87196 .28609 L
s
.255 .412 .882 r
.86791 .29684 m
.86806 .29064 L
s
.8679 .2824 m
.86856 .29783 L
s
.8679 .2824 m
.86806 .29064 L
s
0 0 0 r
.17195 .30226 m
.17373 .25762 L
s
.255 .412 .882 r
.1766 .27541 m
.1781 .24882 L
s
.86806 .29064 m
.86856 .29783 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87161 .23964 m
.87121 .23291 L
s
.87167 .23906 m
.87129 .23233 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8673 .23896 m
.86885 .27493 L
s
.86737 .23839 m
.86891 .27439 L
s
.86705 .24067 m
.8675 .23667 L
s
.17637 .27322 m
.17689 .27704 L
s
.86859 .27657 m
.86891 .27439 L
s
0 0 0 r
.1715 .30913 m
.17195 .30226 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17182 .30173 m
.17278 .27961 L
s
.5 Mabswid
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17169 .3012 m
.17373 .25762 L
s
.255 .412 .882 r
.86825 .25892 m
.86864 .26609 L
s
.17786 .23545 m
.17787 .23602 L
s
0 0 0 r
.17169 .3012 m
.1715 .30913 L
s
.255 .412 .882 r
.17776 .23687 m
.17786 .23545 L
s
.17775 .23744 m
.17786 .23545 L
s
0 0 0 r
.87103 .22045 m
.87133 .22399 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86864 .26609 m
.86894 .27016 L
s
0 0 0 r
.87167 .23906 m
.87343 .27953 L
s
.87161 .23964 m
.87336 .28008 L
s
.255 .412 .882 r
.17754 .24202 m
.17775 .23744 L
s
0 0 0 r
.87356 .27787 m
.87336 .28008 L
s
.255 .412 .882 r
.17756 .24145 m
.17776 .23687 L
s
0 0 0 r
.87127 .22281 m
.87244 .26844 L
s
.255 .412 .882 r
.17676 .2601 m
.17754 .24202 L
s
.86894 .27016 m
.86908 .27165 L
s
0 0 0 r
.87123 .22222 m
.87227 .26789 L
s
.255 .412 .882 r
.17756 .24145 m
.17786 .23515 L
s
.17656 .26473 m
.17756 .24145 L
s
.17786 .23515 m
.17809 .23142 L
s
.86906 .27 m
.86908 .27165 L
s
.17656 .26473 m
.17676 .2601 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17809 .23142 m
.17835 .22969 L
s
.86885 .26536 m
.86895 .2674 L
s
.86872 .26221 m
.86885 .26536 L
s
.17678 .25955 m
.17692 .2564 L
s
.86872 .26221 m
.8688 .26425 L
s
.17692 .2564 m
.17745 .25043 L
s
.17648 .26678 m
.17656 .26473 L
s
.86891 .26685 m
.86906 .27 L
s
.8688 .26425 m
.86891 .26685 L
s
.17646 .26827 m
.17648 .26678 L
s
0 0 0 r
.87328 .27234 m
.87358 .27566 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17835 .22969 m
.17846 .23112 L
s
.17835 .22969 m
.17859 .23055 L
s
0 0 0 r
.86965 .21452 m
.87061 .21808 L
s
.87001 .21571 m
.87352 .27456 L
s
.255 .412 .882 r
.17678 .26606 m
.17646 .26827 L
s
.86694 .2312 m
.86728 .23696 L
s
.86728 .23696 m
.86751 .24215 L
s
.86641 .22688 m
.86694 .2312 L
s
.17837 .23574 m
.17846 .23112 L
s
.86751 .24215 m
.86761 .24678 L
s
.86681 .23062 m
.86717 .23639 L
s
.86717 .23639 m
.86739 .24158 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86641 .22688 m
.86681 .23062 L
s
.17851 .23516 m
.17859 .23055 L
s
.17745 .25043 m
.17779 .2467 L
s
.86739 .24158 m
.86748 .24621 L
s
.17815 .24093 m
.17837 .23574 L
s
.8659 .22514 m
.86641 .22688 L
s
.86731 .24769 m
.86761 .24678 L
s
.17779 .2467 m
.17815 .24093 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17745 .25043 m
.17792 .24614 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86731 .24769 m
.86748 .24621 L
s
.17792 .24614 m
.17793 .24604 L
s
.17678 .26606 m
.17712 .26234 L
s
.86806 .2572 m
.86817 .25981 L
s
.86793 .25664 m
.86806 .2572 L
s
.17735 .25712 m
.17747 .25657 L
s
.17723 .25973 m
.17735 .25712 L
s
.86816 .26186 m
.86817 .25981 L
s
.17736 .25918 m
.17712 .26234 L
s
.86793 .25664 m
.86804 .25925 L
s
.17747 .25657 m
.17736 .25918 L
s
.86798 .26337 m
.86816 .26186 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87191 .26677 m
.87287 .27011 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86877 .22215 m
.86951 .23394 L
s
.8679 .21351 m
.86877 .22215 L
s
.86684 .208 m
.8679 .21351 L
s
.86951 .23394 m
.86983 .24143 L
s
.8685 .22156 m
.86925 .23336 L
s
.86761 .21292 m
.8685 .22156 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86684 .208 m
.86761 .21292 L
s
.86925 .23336 m
.86957 .24086 L
s
.86983 .24143 m
.87006 .25213 L
s
.86618 .20681 m
.86684 .208 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86984 .25854 m
.87006 .25213 L
s
.86957 .24086 m
.8698 .25156 L
s
.86564 .20937 m
.86618 .20681 L
s
.86528 .20878 m
.86618 .20681 L
s
.86955 .25798 m
.8698 .25156 L
s
.86522 .21571 m
.86564 .20937 L
s
.86911 .26064 m
.86984 .25854 L
s
.86483 .21512 m
.86528 .20878 L
s
.86911 .26064 m
.86955 .25798 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86522 .21571 m
.86531 .22643 L
s
.86845 .25952 m
.86911 .26064 L
s
.86483 .21512 m
.86491 .22585 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86531 .22643 m
.86563 .23399 L
s
.86758 .25462 m
.86845 .25952 L
s
.86721 .25406 m
.86845 .25952 L
s
.86491 .22585 m
.86523 .23341 L
s
.86563 .23399 m
.86651 .24591 L
s
.86651 .24591 m
.86758 .25462 L
s
.255 .412 .882 r
.1865 .21768 m
.18717 .21383 L
s
0 0 0 r
.85981 .19794 m
.86176 .2003 L
s
.86523 .23341 m
.86612 .24535 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86612 .24535 m
.86721 .25406 L
s
.255 .412 .882 r
.18637 .22079 m
.1865 .21969 L
s
.1865 .21969 m
.18764 .21325 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86031 .19853 m
.8637 .27862 L
s
.85981 .19794 m
.86319 .27808 L
s
.255 .412 .882 r
.18478 .25867 m
.18482 .25957 L
s
0 0 0 r
.85892 .20055 m
.86029 .20929 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85767 .19559 m
.85892 .20055 L
s
.85654 .19442 m
.85767 .19559 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86085 .24625 m
.86157 .23972 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8549 .19647 m
.85654 .19442 L
s
.85551 .19705 m
.85654 .19442 L
s
.8546 .20351 m
.85551 .19705 L
s
.85396 .20294 m
.8549 .19647 L
s
.85991 .24898 m
.86085 .24625 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85444 .2144 m
.8546 .20351 L
s
.8616 .27648 m
.8637 .27862 L
s
.8538 .21383 m
.85396 .20294 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85877 .24788 m
.85991 .24898 L
s
.85444 .2144 m
.85476 .22206 L
s
.85742 .24293 m
.85877 .24788 L
s
.85681 .24238 m
.85877 .24788 L
s
.8538 .21383 m
.85411 .2215 L
s
.85476 .22206 m
.85587 .23414 L
s
.85587 .23414 m
.85742 .24293 L
s
.84654 .18572 m
.84946 .18802 L
s
.85411 .2215 m
.85524 .23358 L
s
.85524 .23358 m
.85681 .24238 L
s
.84728 .1863 m
.84948 .24024 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84654 .18572 m
.84873 .2397 L
s
.84516 .18841 m
.847 .19723 L
s
.84262 .18286 m
.84516 .18841 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84098 .18173 m
.84262 .18286 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83944 .18445 m
.84098 .18173 L
s
.83858 .18389 m
.84098 .18173 L
s
.8464 .23809 m
.84948 .24024 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83888 .19161 m
.83944 .18445 L
s
.83801 .19106 m
.83858 .18389 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83801 .19106 m
.8397 .23382 L
s
.83888 .19161 m
.84058 .23435 L
s
.255 .412 .882 r
.83691 .2139 m
.83695 .21481 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82917 .17446 m
.83007 .19779 L
s
.812 .16585 m
.82917 .17446 L
s
.82818 .17391 m
.83007 .19779 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83699 .23224 m
.84058 .23435 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83134 .25622 m
.83142 .23304 L
s
.83142 .23304 m
.83233 .25672 L
s
.8241 .19851 m
.82529 .22998 L
s
.81656 .16796 m
.81962 .25081 L
s
.81544 .16743 m
.81849 .25032 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81816 .21114 m
.82469 .21421 L
s
.81502 .24888 m
.83233 .25672 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80647 .19814 m
.8083 .20096 L
s
.80657 .20091 m
.8084 .20372 L
s
.80399 .19496 m
.80647 .19814 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25762 .15615 m
.26602 .15327 L
s
.26038 .15518 m
.26768 .23615 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27479 .15048 m
.28392 .14778 L
s
.28786 .11905 m
.29905 .11597 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2624 .17807 m
.27554 .17397 L
s
.29015 .20196 m
.2926 .11771 L
s
.29176 .20156 m
.2942 .11727 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26768 .23615 m
.28083 .14867 L
s
.26807 .224 m
.27931 .14912 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29305 .15718 m
.29651 .14832 L
s
.29651 .14832 m
.2999 .14348 L
s
.2999 .14348 m
.30321 .14266 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30321 .14266 m
.30644 .14586 L
s
.30321 .14266 m
.30813 .14546 L
s
.30644 .14586 m
.30961 .15311 L
s
.30813 .14546 m
.31131 .15272 L
s
.28537 .20318 m
.29176 .20156 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29211 .18941 m
.29513 .1967 L
s
.30961 .15311 m
.31099 .16483 L
s
.31131 .15272 m
.31271 .16445 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29513 .1967 m
.29831 .19997 L
s
.31078 .17293 m
.31099 .16483 L
s
.3125 .17255 m
.31271 .16445 L
s
.29831 .19997 m
.30164 .1992 L
s
.30874 .18547 m
.31078 .17293 L
s
.31045 .1851 m
.3125 .17255 L
s
.30164 .1992 m
.30512 .19436 L
s
.30164 .1992 m
.30682 .19398 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30512 .19436 m
.30874 .18547 L
s
.33084 .14053 m
.33638 .13543 L
s
.32706 .14934 m
.33084 .14053 L
s
.32497 .16185 m
.32706 .14934 L
s
.30682 .19398 m
.31045 .1851 L
s
.33265 .14017 m
.33638 .13543 L
s
.32885 .14898 m
.33265 .14017 L
s
.32676 .16149 m
.32885 .14898 L
s
.33638 .13543 m
.34004 .13473 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32477 .16997 m
.32497 .16185 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34004 .13473 m
.34365 .1381 L
s
.34004 .13473 m
.34551 .13777 L
s
.32656 .16961 m
.32676 .16149 L
s
.32477 .16997 m
.32625 .18183 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32656 .16961 m
.32805 .18148 L
s
.34365 .1381 m
.34719 .14555 L
s
.34551 .13777 m
.34907 .14522 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32625 .18183 m
.32966 .18931 L
s
.34719 .14555 m
.34881 .15743 L
s
.32805 .18148 m
.33148 .18897 L
s
.34907 .14522 m
.35069 .15711 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36074 .13116 m
.37435 .1291 L
s
.32966 .18931 m
.33504 .19239 L
s
.34863 .16559 m
.34881 .15743 L
s
.33148 .18897 m
.33504 .19239 L
s
.36483 .21647 m
.36653 .13025 L
s
.35052 .16527 m
.35069 .15711 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34647 .17817 m
.34863 .16559 L
s
.33504 .19239 m
.33873 .19174 L
s
.34836 .17786 m
.35052 .16527 L
s
.33873 .19174 m
.34254 .187 L
s
.33873 .19174 m
.34441 .18668 L
s
.34254 .187 m
.34647 .17817 L
s
.34441 .18668 m
.34836 .17786 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38227 .128 m
.39637 .12623 L
s
.255 .412 .882 r
.66697 .16408 m
.66698 .16405 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66501 .16382 m
.66524 .16277 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37132 .16714 m
.37175 .16917 L
s
.36938 .16735 m
.3695 .16795 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66501 .16382 m
.66505 .16598 L
s
.66697 .16408 m
.66701 .16619 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41274 .12852 m
.41905 .12382 L
s
.40849 .13713 m
.41274 .12852 L
s
.41482 .12831 m
.41905 .12382 L
s
.41905 .12382 m
.42323 .12343 L
s
.41056 .13692 m
.41482 .12831 L
s
.40624 .14965 m
.40849 .13713 L
s
.42323 .12343 m
.42739 .12716 L
s
.42323 .12343 m
.4295 .12698 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40831 .14944 m
.41056 .13692 L
s
.42739 .12716 m
.43152 .135 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3668 .2162 m
.36848 .12996 L
s
.38681 .21371 m
.38828 .12722 L
s
.38884 .21348 m
.39029 .12697 L
s
.4295 .12698 m
.43364 .13483 L
s
.60978 .12239 m
.61194 .12665 L
s
.6077 .12632 m
.60978 .12239 L
s
.40612 .15788 m
.40624 .14965 L
s
.40819 .15766 m
.40831 .14944 L
s
.60987 .13059 m
.61194 .12665 L
s
.6077 .12632 m
.60987 .13059 L
s
.35898 .21729 m
.3668 .2162 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44655 .12159 m
.46161 .12067 L
s
.40612 .15788 m
.40801 .17004 L
s
.43152 .135 m
.4335 .14717 L
s
.40819 .15766 m
.41009 .16983 L
s
.43364 .13483 m
.43562 .14701 L
s
.57757 .12035 m
.58623 .12081 L
s
.58623 .12081 m
.59057 .12516 L
s
.59057 .12516 m
.59276 .1294 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59276 .1294 m
.59287 .14174 L
s
.57326 .12426 m
.57757 .12035 L
s
.47028 .12024 m
.48553 .11964 L
s
.56888 .11997 m
.57111 .12827 L
s
.56888 .11997 m
.56898 .13642 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45248 .17898 m
.45299 .12117 L
s
.45464 .17885 m
.45514 .12104 L
s
.47654 .16536 m
.4768 .11995 L
s
.47873 .16528 m
.47898 .11987 L
s
.40801 .17004 m
.41206 .1779 L
s
.4334 .15542 m
.4335 .14717 L
s
.57111 .12827 m
.57326 .12426 L
s
.41009 .16983 m
.41415 .17771 L
s
.43553 .15526 m
.43562 .14701 L
s
.54921 .11934 m
.55797 .11958 L
s
.49428 .11938 m
.50965 .11911 L
s
.59072 .14161 m
.59284 .13762 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57379 .1727 m
.57394 .17338 L
s
0 0 0 r
.56898 .13642 m
.57111 .12827 L
s
.53823 .11914 m
.54483 .12335 L
s
.53384 .11909 m
.53823 .11914 L
s
.52944 .12316 m
.53384 .11909 L
s
.52724 .12315 m
.53384 .11909 L
s
.59075 .14573 m
.59287 .14174 L
s
.43114 .16798 m
.4334 .15542 L
s
.54483 .12335 m
.54925 .13168 L
s
.58643 .14549 m
.59072 .14161 L
s
.43326 .16782 m
.43553 .15526 L
s
.52725 .13138 m
.52944 .12316 L
s
.52504 .13138 m
.52724 .12315 L
s
.41206 .1779 m
.41829 .18147 L
s
.38074 .21442 m
.38884 .21348 L
s
.58646 .14961 m
.59075 .14573 L
s
.41415 .17771 m
.41829 .18147 L
s
.57562 .15321 m
.58643 .14549 L
s
.42679 .17661 m
.43114 .16798 L
s
.57565 .15735 m
.58646 .14961 L
s
.42891 .17644 m
.43326 .16782 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41829 .18147 m
.42251 .18111 L
s
.42251 .18111 m
.42679 .17661 L
s
.42251 .18111 m
.42891 .17644 L
s
.57128 .15716 m
.57562 .15321 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54921 .11934 m
.5494 .17725 L
s
.5007 .17716 m
.50086 .11924 L
s
.50291 .17712 m
.50306 .1192 L
s
.52725 .13138 m
.52727 .17697 L
s
.52504 .13138 m
.52506 .17697 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57131 .16131 m
.57565 .15735 L
s
.59305 .16239 m
.5932 .17899 L
s
.59096 .17056 m
.59305 .16239 L
s
.5514 .11939 m
.55161 .1773 L
s
.45475 .16639 m
.45902 .17446 L
s
.56912 .16122 m
.57128 .15716 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58883 .17459 m
.59096 .17056 L
s
.59096 .17056 m
.5932 .17899 L
s
.56914 .16537 m
.57131 .16131 L
s
.56912 .16122 m
.56917 .16952 L
s
.446 .17937 m
.45464 .17885 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6085 .2008 m
.6101 .15115 L
s
.6101 .15115 m
.61278 .2011 L
s
.61037 .17597 m
.61064 .20095 L
s
.58452 .17852 m
.58883 .17459 L
s
.4743 .17375 m
.47654 .16536 L
s
.45902 .17446 m
.46552 .17829 L
s
.47649 .17367 m
.47873 .16528 L
s
.56917 .16952 m
.57138 .17377 L
s
.57579 .17811 m
.58452 .17852 L
s
.57138 .17377 m
.57579 .17811 L
s
.46989 .1781 m
.4743 .17375 L
s
.46552 .17829 m
.46989 .1781 L
s
.46989 .1781 m
.47649 .17367 L
s
.61074 .20931 m
.61278 .2011 L
s
.6085 .2008 m
.61074 .20931 L
s
.54277 .17713 m
.55161 .1773 L
s
.49408 .1773 m
.50291 .17712 L
s
.51841 .17697 m
.52727 .17697 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50064 .19805 m
.50285 .20221 L
s
.49842 .20228 m
.50064 .19805 L
s
.49842 .20228 m
.50062 .20644 L
s
.50062 .20644 m
.50285 .20221 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][@T0oj@A
0`0000080?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0:f][@020:f][G00/>3V0@3oool008@0/>3V0`2][Jd00`3lX100[Jf]0?nT4@050?nT4@D000002P3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV4009000000/0ojH@0`0000040?nV40<000007@3oYA000`2][Jd0oj<@0?nS
400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P020>bF3P80[Jf]KP2`h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1401`3oY142
000000X0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA00X0ojHA1@0000030?nV4@T000001P2][Jd00`000000[Jf]0000000<0:f][@8000000`2][Jd2
00000080[Jf]00<000000:f][@0000000`0000040:f][@030000002][Jd0[Jf]0080[Jf]1@00000<
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2]
[Jd0oj@A0?nT4@070?nT4@8000002P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01P0ojHA00<000000?nV4@2][Jd01`3oYQ400`2][Jd0000000000004000000P0[Jf]00@0ojHA0000
003oYQ4000000`3oYQ400`2][Jd0ojH@0?nV40030?nV40030000003oYQ00000000/0ojH@0P000006
0?nV40050000003oYQ0000000:f][@0000001`3oYA000`000000ojD@0?nU400200000080ojD@0`2]
[Jd00`000000[Jf]0:f][@080:f][@030000002][Jd0[Jf]00<0[Jf]5`3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3o
ool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A00L0oj@A0P00000:0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ42000000030:f][@000000000000L0[Jf]1@3oYQ42
000000T0ojHA00<000000?nV4@0000000`3oYQ400`2][Jd0ojH@0?nV40030?nV40030000003oYQ00
000000X0ojH@00<000000?nV400000001`3oYQ02000000030:f][@000000ojD@00H0ojD@00<00000
0?nU40000000203oYA000`000000ojD@0?nU40060?nU4080000000<0[Jf]0?nS403oXa000P3oXa09
0:f][@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>00X0k9H>0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@070?nT
4@8000002P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00H0ojHA1@0000000`3o
YQ40[Jf]0:f][@060:f][@800000103oYQ42000000/0ojHA0P0000090?nV4@030000003oYQ400000
00<0ojHA00<0[Jf]0?nV403oYQ000`3oYQ000`000000ojH@0000000:0?nV40800000203oYQ020000
00030:f][@000000ojD@00H0ojD@0P0000090?nU40030000003oYA00ojD@00H0ojD@00<000000?nU
400000003@3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0
oj@A0?nT4@070?nT4@8000002P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@<000000P3oYQ400`2][Jd0
000000000003000000@0[Jf]1`3oYQ42000000D0ojHA0P00000;0?nV4@8000002@3oYQ400`000000
ojHA000000030?nV4@030:f][@3oYQ00ojH@00<0ojH@00<000000?nV400000002@3oYQ000`000000
ojH@000000090?nV40030000002][Jd0000000L0ojD@0P00000:0?nU40030000003oYA00ojD@00D0
ojD@0P0000000`2][Jd0oj<@0?nS400E0?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A
0?nT4@070?nT4@8000002P3oY1400`2][Jd0ojHA0?nV4@0C0?nV4@D00000102][Jd40?nV4@800000
2P3oYQ42000000H0ojHA00<0[Jf]0000000000002P3oYQ42000000T0ojHA00<000000?nV4@000000
0`3oYQ400`2][Jd0ojH@0?nV40030?nV40030000003oYQ00000000T0ojH@00<000000?nV40000000
2@3oYQ000`000000[Jf]000000070?nU408000002P3oYA000`000000ojD@0?nU40060?nU40030000
002][Jd0oj<@01X0oj<@00<0[Jf]0?bP403lX1001P2][JdB0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3o
Y140oj@A00L0oj@A0P00000:0?nT4@030:f][@3oYQ40ojHA0100ojHA1@2][Jd00`3oYQ4000000000
00080?nV4@8000002@3oYQ42000000L0ojHA00<0[Jf]0000000000002P3oYQ42000000T0ojHA00<0
00000?nV4@0000000`3oYQ400`2][Jd0ojH@0?nV40030?nV40030000003oYQ00000000T0ojH@00<0
00000?nV400000002@3oYQ03000000L0ojD@00<000000?nU403oYA002@3oYA000`000000ojD@0?nU
40070?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1001P3lX1050:f][@d0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`
h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@08
0?nT4@8000002P3oY1400`2][Jd0ojHA0?nV4@070?nV4@8000000P3oYQ450:f][@H0ojHA0P000008
0?nV4@8000002@3oYQ42000000L0ojHA00@0[Jf]0?nV4@00000000002@3oYQ42000000T0ojHA00<0
00000?nV4@0000000`3oYQ400`2][Jd0ojH@0?nV40030?nV40030000003oYQ00000000T0ojH@00<0
00000?nV400000002@3oYQ000`000000[Jf]000000070?nU40030000003oYA00ojD@00T0ojD@00<0
00000?nU403oYA001`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00/0o:0@1@2]
[Jd80?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@080?nT4@8000002P3oY1400`2][Jd0ojHA0?nV4@050?nV4@040:f][@000000
[Jf]0:f][@8000002`3oYQ42000000P0ojHA0P0000080?nV4@800000203oYQ40102][Jd0ojHA0000
000000090?nV4@8000002@3oYQ400`000000ojHA000000030?nV4@030:f][@3oYQ00ojH@00<0ojH@
00<000000?nV400000002@3oYQ000`000000ojH@000000090?nV40030000002][Jd0000000L0ojD@
00<000000?nU403oYA002@3oYA000`000000ojD@0?nU40070?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX100403lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_
V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@080?nT4@030000003o
Y140oj@A00T0oj@A00<0[Jf]0?nV4@3oYQ401@2][Jd2000000<0ojHA0P00000:0?nV4@800000203o
YQ42000000P0ojHA0P0000080?nV4@040:f][@3oYQ400000000000T0ojHA0P0000090?nV4@030000
003oYQ40000000<0ojHA00<0[Jf]0?nV403oYQ000`3oYQ000`000000ojH@000000090?nV40030000
003oYQ00000000T0ojH@00<000000:f][@0000004`3oYA000`000000ojD@0?nU40070?nU40030:f]
[@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005P3lX1040:f][AD0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@060=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@080?nT4@030000003oY140oj@A00P0oj@A102]
[Jd40?nV4@800000103oYQ400`000000ojHA000000090?nV4@800000203oYQ42000000P0ojHA0P00
00080?nV4@040:f][@3oYQ400000000000T0ojHA0P0000090?nV4@030000003oYQ40000000<0ojHA
00<0[Jf]0?nV403oYQ000`3oYQ000`000000ojH@000000090?nV40030000003oYQ00000000T0ojH@
00<000000:f][@0000004P3oYA02000000T0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00P0oj@A00<000000?nT4@3oY1400`0000000`3oY140[Jf]0:f]
[@020:f][@030?nT4@2][Jd0ojHA00@0ojHA0P0000060?nV4@8000002@3oYQ42000000P0ojHA0P00
00080?nV4@030000003oYQ40ojHA00H0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000080?nV4@800000
2@3oYQ42000000@0ojHA00<0[Jf]0?nV403oYQ000`3oYQ000`000000ojH@000000090?nV40030000
003oYQ00000000T0ojH@00<000000:f][@0000004P3oYA02000000T0ojD@00<0[Jf]0?nS403oXa00
6@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2]
[Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140203oY14010000000oj@A0?nT
4@0000020:f][@800000103oY1400`2][Jd0ojHA0?nV4@030?nV4@8000001P3oYQ400`000000ojHA
000000080?nV4@800000203oYQ42000000L0ojHA0P0000080?nV4@040:f][@3oYQ40ojHA0?nV4@80
0000203oYQ42000000T0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00<0ojH@00<000000?nV4000
00002@3oYQ000`000000ojH@000000090?nV40030000002][Jd000000100ojD@0`00000:0?nU4003
0:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0
[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`
h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1401`3oY140102][Jd000000:f][@0000040?nT4@030000003oY140oj@A0080
oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ42000000P0ojHA0P0000080?nV4@800000203oYQ42000000L0
ojHA0P0000080?nV4@040:f][@3oYQ40ojHA0?nV4@800000203oYQ42000000T0ojHA0P0000040?nV
4@030:f][@3oYQ00ojH@00<0ojH@00<000000?nV400000002@3oYQ000`000000ojH@000000090?nV
40030000002][Jd0000000l0ojD@00@000000?nU403oYA0000002P3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f]
[@d0kiP@00<0[Jf]0?bP403lX1003`3lX100102][Jd0oj@A0?nT4@3oY143000000<0[Jf]00@0oj@A
0000003oY1400000103oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ42000000P0ojHA0P00
00080?nV4@800000203oYQ42000000L0ojHA0P0000080?nV4@040:f][@3oYQ40ojHA0?nV4@800000
203oYQ42000000T0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00<0ojH@0P00000:0?nV40030000
003oYQ00000000X0ojH@0P00000=0?nU408000000P3oYA000`000000ojD@0?nU40090?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]
00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V
0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140000000<000001@3oY142000000H0oj@A00D000000?nT4@3oY140oj@A0:f][@040?nV4@800000
203oYQ42000000P0ojHA0P0000080?nV4@8000001`3oYQ42000000P0ojHA00@0[Jf]0?nV4@3oYQ40
ojHA0P0000070?nV4@8000002P3oYQ42000000@0ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000X0
ojH@00<000000?nV400000002P3oYQ02000000`0ojD@00D000000?nU403oYA00ojD@0000000;0?nU
40030000002][Jd0oj<@01/0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool0
06@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400<0?bP408000000`2][Jd2
0?nT4@8000001@3oY142000000H0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA0080ojHA0P000009
0?nV4@8000001`3oYQ42000000P0ojHA0P0000070?nV4@800000203oYQ40102][Jd0ojHA0?nV4@3o
YQ42000000L0ojHA0P00000:0?nV4@800000103oYQ400`2][Jd0ojH@0?nV40030?nV408000002P3o
YQ000`000000ojH@0000000:0?nV408000002`3oYA000`000000ojD@0?nU4002000000`0ojD@00<0
00000:f][@3oXa006`3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;
0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@
0?bP400:0?bP408000000P2][Jd00`3lX100[Jf]0?nT4@020?nT4@8000001@3oY1400`000000oj@A
0?nT4@050?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40ojHA00P0ojHA
0P0000070?nV4@800000203oYQ42000000L0ojHA0P0000080?nV4@040:f][@3oYQ40ojHA0?nV4@80
00001`3oYQ42000000X0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00<0ojH@0P00000:0?nV4003
0000003oYQ00000000X0ojH@0P0000090?nU4080000000<0ojD@0000000000003P3oYA000`000000
[Jf]0?nS400K0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080
^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP40080?bP40<0000000D0[Jf]0?bP403lX100o:0@0:f][@020?nT4@80
00001P3oY1400`000000oj@A0?nT4@050?nT4@8000000P3oY140102][Jd0ojHA0?nV4@3oYQ420000
00X0ojHA0P0000070?nV4@800000203oYQ42000000L0ojHA0P0000080?nV4@040:f][@3oYQ40ojHA
0?nV4@8000001`3oYQ42000000T0ojHA00<0[Jf]0000000000002P2][Jd2000000X0[Jf]00<00000
0:f][@0000002`2][Jd00`000000[Jf]0:f][@040:f][@80ojD@00@000000?nU403oYA000000403o
YA000`000000[Jf]0?nS400K0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P03
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@030?bP40000000
o:0@00<0o:0@00<0[Jf]0?nT4@3oY1400P0000060?nT4@030000003oY140oj@A00D0oj@A0P000000
0`3oY140[Jf]0?nV4@030?nV4@8000002P3oYQ42000000L0ojHA0P0000080?nV4@8000001`3oYQ42
000000P0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000020?nV4@D0[Jf]0P0000090:f][@030?nV4@00
0000000000@0ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000X0ojH@00<000000?nV400000002P3o
YQ000`2][Jd000000?nU40050?nU40030:f][@000000[Jf]008000002`2][Jd60?nU40030000002]
[Jd0oj<@01/0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2i
M@/00`2][Jd0/>3V0;3PiP180;3PiP40oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]0`3lX1000`000000o:0@0?bP4002
0?bP40030:f][@3oY140oj@A008000001@3oY142000000P0oj@A0P0000000`2][Jd0ojHA0?nV4@02
0?nV4@8000002P3oYQ42000000L0ojHA0P0000080?nV4@8000001`3oYQ42000000@0ojHA202][Jd2
00000080[Jf]1@3oYQ42000000X0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00<0ojH@0P00000:
0?nV40030000003oYQ00000000X0ojH@00<0[Jf]0000003oYA001P3oYA02000000d0ojD@1P2][Jd0
0`000000[Jf]0:f][@030:f][AP0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>
00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@H0o:0@00<00000
0?bP403lX1000P3lX1000`2][Jd0oj@A0?nT4@02000000D0oj@A0P0000080?nT4@80000000<0[Jf]
0?nV4@3oYQ400P3oYQ42000000X0ojHA0P0000070?nV4@800000203oYQ42000000@0ojHA0`2][Jd2
000000@0[Jf]103oYQ400`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000:0?nV4@800000103oYQ40
0`2][Jd0ojH@0?nV40030?nV408000002P3oYQ000`000000ojH@0000000:0?nV40030:f][@000000
ojD@00H0ojD@00<000000?nU403oYA002@3oYA000`000000ojD@0?nU40060?nU40030000002][Jd0
oj<@00<0oj<@2P2][Jd<0?nS4003045Yh@3oXa00[Jf]01T0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@T0o:0@00<000000?bP403lX1000P3lX100
0`2][Jd0oj@A0?nT4@02000000D0oj@A0P0000080?nT4@80000000<0[Jf]0?nV4@3oYQ400P3oYQ42
000000X0ojHA0P0000070?nV4@800000103oYQ440:f][@800000102][Jd30?nV4@800000203oYQ40
0`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000:0?nV4@800000103oYQ400`2][Jd0ojH@0?nV4003
0?nV408000002P3oYQ000`000000ojH@0000000:0?nV40030:f][@000000ojD@00H0ojD@00<00000
0?nU403oYA002@3oYA000`000000ojD@0?nU40060?nU40030000002][Jd0oj<@00d0oj<@2P2][Jd4
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f]
[@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][@/0o:0@00<000000?bP403lX1000P3lX1000`2]
[Jd0oj@A0?nT4@02000000D0oj@A0P0000080?nT4@80000000<0[Jf]0?nV4@3oYQ400P3oYQ420000
00X0ojHA0P0000060?nV4@030:f][@000000000000@0[Jf]103oYQ42000000P0ojHA0P0000070?nV
4@030:f][@3oYQ40ojHA00800000203oYQ42000000X0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@
00<0ojH@0P00000:0?nV40030000003oYQ00000000X0ojH@00<0[Jf]0000003oYA001P3oYA000`00
0000ojD@0?nU40080?nU40800000203oYA000`000000[Jf]0?nS400G0?nS40P0[Jf]5P3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>0P2][Jd3000000T0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0
kiP@0`2][Jd=0?bP40050000003lX100o:0@0?bP402][Jd00P3oY1400`000000oj@A0?nT4@040?nT
4@800000203oY142000000030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000001P2][Jd0103o
YQ40000000000011JN470?nV4@800000203oYQ42000000L0ojHA00<0[Jf]0?nV4@3oYQ400P000008
0?nV4@<000002@3oYQ42000000@0ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000X0ojH@00<00000
0?nV400000002P3oYQ000`2][Jd000000?nU40060?nU40030000003oYA00ojD@00P0ojD@0P000008
0?nU40030000002][Jd0oj<@01/0oj<@00@0[Jf]0?bP403lX100o:0@1P2][Jd@0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@2][Jd2000000P0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0[Jf]0?bP403lX1002`3l
X1001@000000o:0@0?bP403lX100[Jf]0080oj@A00<000000?nT4@3oY140103oY142000000P0oj@A
0P0000000`2][Jd0ojHA0?nV4@020?nV4@8000001`3oYQ430:f][@8000001`3oYQ42000000P0ojHA
0P0000080?nV4@8000001`3oYQ40102][Jd0ojHA0000000000090?nV4@<00000203oYQ42000000D0
ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000X0ojH@00<000000?nV400000002P3oYQ000`2][Jd0
00000?nU40070?nU40030000003oYA00ojD@00L0ojD@0P0000080?nU40030000002][Jd0oj<@01/0
oj<@00<0[Jf]0?bP403lX1001`3lX1070:f][@T0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@@000001P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2]
[Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400;0?bP40060000003lX100o:0@
0?bP402][Jd0oj@A0P0000060?nT4@800000203oY142000000030:f][@3oYQ40ojHA0080ojHA0P00
00020?nV4@D0[Jf]0P3oYQ42000000P0ojHA0P0000080?nV4@800000203oYQ42000000L0ojHA00@0
[Jf]0?nV4@00000000002@3oYQ42000000030?nV4@000000ojHA00H0ojHA0P0000050?nV4@030:f]
[@3oYQ00ojH@00<0ojH@0P00000:0?nV40030000003oYQ00000000X0ojH@00<0[Jf]0000003oYA00
1`3oYA000`000000ojD@045Yh@060?nU40<00000203oYA000`000000[Jf]0?nS400K0?nS40030:f]
[@3lX100o:0@00h0o:0@1P2][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh0102][Jd0fhX=0=^:3@3KRPd2000000040=^:3@2][Jd00000000000@0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;
0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V1000`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100
o:0@00/0o:0@00D000000?bP403lX100o:0@0:f][@03000000H0oj@A0P0000080?nT4@80000000<0
[Jf]0?nV4@3oYQ400P2][Jd200000080[Jf]1`3oYQ42000000L0ojHA0P0000000`2][Jd0ojHA0?nV
4@060?nV4@8000002@3oYQ42000000H0ojHA00<0[Jf]0000000000002P3oYQ4200000080ojHA00<0
00000?nV4@3oYQ40103oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000X0ojH@00<0
00000?nV400000002P3oYQ000`2][Jd000000?nU40080?nU40030000003oYA00ojD@00D0ojD@0`00
00080?nU40030000002][Jd0oj<@01/0oj<@00<0[Jf]0?bP403lX100503lX1050:f][AD0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd200000080fhX=0P2][Jd200000080fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080kiP@0P2][Jd70>nH4003
0:f][@3lX100o:0@00/0o:0@00<000000?bP400000000P0000000`3oY1400000000000060?nT4@80
0000203oY142000000<0[Jf]0P3oYQ42000000T0ojHA0P0000070?nV4@80000000<0[Jf]0?nV4@3o
YQ401P3oYQ42000000T0ojHA0P0000060?nV4@030:f][@000000000000X0ojHA0P0000030?nV4@80
00000`3oYQ42000000H0ojHA00<0[Jf]0?nV403oYQ001@0000070?nV40H000001P3oYQ06000000X0
ojD@00<000000?nU403oYA000`3oYA0010000000ojD@0?nU400000070?nU40<00000703oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P040:f][@3KRPd0fhX=0=^:3@800000103KRPd200000080fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
1@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@080=>73P030:f][@3_V100kiP@0080[Jf]2@3_V1000`2][Jd0o:0@0?bP400;0?bP408000000P3l
X100102][Jd0oj@A0000000000060?nT4@8000001@3oY1420:f][@80000000<0oj@A0:f][@3oYQ40
103oYQ400`000000ojHA0?nV4@070?nV4@8000001`3oYQ42000000030:f][@3oYQ40ojHA00H0ojHA
0P00000:0?nV4@800000103oYQ43000000P0ojHA1@0000050?nV4@<00000203oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@00X0ojD@1@0000030?nU40030000003oYA00ojD@00D0ojD@
0`00000L0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][@d0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd2000000@0fhX=0P0000030:f][@T0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f]
[@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f][@/0kiP@00<0[Jf]0?bP403lX100
2`3lX1001`000000o:0@0?bP403lX100[Jf]0?nT4@0000001`3oY1400`000000oj@A0?nT4@040:f]
[@80oj@A0P0000000`3oY140[Jf]0?nV4@040?nV4@030000003oYQ40ojHA00H0ojHA0P0000080?nV
4@80000000<0[Jf]0?nV4@3oYQ401P3oYQ42000000`0ojHA1@0000000`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006P3oYA03000001`0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P040:f][@3KRPd0fhX=0=^:3@800000103KRPd200000080fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
0`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002`3lX100
1`000000o:0@0?bP403lX100[Jf]0?nT4@0000001`3oY1400`000000[Jf]0:f][@060?nT4@800000
00<0oj@A0:f][@3oYQ40103oYQ400`000000ojHA0?nV4@060?nV4@800000203oYQ42000000030:f]
[@3oYQ40ojHA00H0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400J0?nU40<00000703oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0
fhX=0P0000040=^:3@8000000P3KRPd20:f][@030;Ue2`000000000000D0^GD;00<0[Jf]08QF1`28
EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd0203CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX100303lX1001`000000o:0@0?bP403lX100[Jf]
0?nT4@0000000`3oY1440:f][@030000003oY140oj@A00H0oj@A0P0000000`3oY140[Jf]0?nV4@04
0?nV4@8000001P3oYQ42000000T0ojHA0P0000000`2][Jd0ojHA0?nV4@060?nV4@8000004@3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006P3oYA03
000001`0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?
0:f][@3/UPh04@3/UPh0102][Jd0fhX=0=^:3@3KRPd2000000@0fhX=0P0000020=^:3@050:f][@2i
M@/000000:f][@0000001@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00<0dhL>0:f][@3_V100
2`3_V1000`2][Jd0o:0@0?bP400<0?bP40050000003lX100o:0@0?bP402][Jd00P0000030:f][@@0
oj@A00<000000?nT4@3oY1401P3oY142000000030?nT4@2][Jd0ojHA00D0ojHA00<000000?nV4@3o
YQ40103oYQ42000000T0ojHA0P0000090?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006P3oYA03000001`0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh0102][Jd0fhX=0=^:3@3KRPd20000
00@0fhX=0P0000020=^:3@050:f][@2iM@/000000;Ue2`2][Jd00P0000030;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00D0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0<0>nH40030:f][@3lX100o:0@00`0o:0@00<0
00000?bP403lX1000P2][Jd2000000L0oj@A0P0000060?nT4@8000000P3oY1400`2][Jd0ojHA0?nV
4@040?nV4@800000103oYQ42000000X0ojHA0P0000090?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006P3oYA03000001`0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/
UPh00`2][Jd0fhX=0=^:3@020=^:3@030000003KRPd0fhX=00<0fhX=00@000000=^:3@3KRPd0[Jf]
0P0000020;Ue2`<000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`
h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@
0>nH400:0>nH40030:f][@3lX100o:0@00`0o:0@00D000000:f][@2][Jd0o:0@0:f][@02000000L0
oj@A0P0000060?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@050?nV4@8000000`3oYQ400`000000
ojHA0?nV4@090?nV4@8000002@3oYQ4200000140ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01X0ojD@0`00000L0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0
fhX=0=^:3@020=^:3@030000003KRPd0fhX=00<0fhX=00@000000=^:3@3KRPd0[Jf]0P0000020;Ue
2`8000000`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400:0>nH
40030:f][@3lX100o:0@00X0o:0@0P2][Jd01P000000o:0@0?bP403lX100[Jf]000000P0oj@A0P00
00050?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@070?nV4@<00000303oYQ42000000T0ojHA0P00
000A0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400J0?nU40<00000703oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd00`000000fhX=0=^:
3@030=^:3@040000003KRPd0fhX=0:f][@8000000P2iM@/200000080[Jf]00<0^GD;0:f][@28EPL0
0`28EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@H0
dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]0P3lX1001P000000
o:0@0?bP403lX100[Jf]000000P0oj@A00<000000?nT4@000000103oY142000000<0oj@A00<0[Jf]
0?nV4@3oYQ405P3oYQ42000000T0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdE
0?nU40<00000703oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh01`3/UPh30:f][@@0k9H>00<0@FWQ0>bF3P2][Jd0103KRPd00`000000fhX=0=^:3@03
0=^:3@040000003KRPd0fhX=0:f][@8000000P2iM@/200000080^GD;00<0[Jf]0000000000000`28
EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_
V100kiP@00X0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@H0o:0@00D000000?bP403lX100[Jf]
000000080?nT4@030000003oY140000000<0oj@A0P0000040?nT4@030:f][@3oYQ40ojHA01H0ojHA
0P0000090?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd50?nU40<00000703oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@<0k9H>
00<0@FWQ0:f][@3KRPd00`3KRPd00`000000fhX=0=^:3@030=^:3@040000003KRPd0fhX=0:f][@80
00000P2iM@/2000000<0^GD;0P00000408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403l
X1000P3lX1020:f][@T0o:0@00D000000?bP403lX100[Jf]000000080?nT4@060000003oY140oj@A
0000003oY14000001P3oY1400`2][Jd0ojHA0?nV4@0F0?nV4@8000002@3oYQ42000000d0ojHA302]
[JdG0?nV4@030:f][@3oYQ00ojH@00<0ojH@00<000000?nV403oYQ005P3oYQ000`2][Jd0ojD@0?nU
400E0?nU40D0[Jf]0`0000040:f][AP0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0@FWQ0=^:3@030=^:3@040000003K
RPd0fhX=00000080fhX=00@000000=^:3@3KRPd0fhX=0P0000020;Ue2`8000000`2iM@/00`000000
[Jf]0000000308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/0
0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd;0?bP40050000
003lX100o:0@0:f][@0000001`3oY142000000<0oj@A00<000000?nT4@3oY1401@3oY1400`2][Jd0
ojHA0?nV4@0F0?nV4@8000002@3oYQ42000000<0ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000001P0ojH@00<0[Jf]0?nU403oYA006P3oYA03000000@0
oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P<0[Jf]0`3KRPd010000000fhX=0=^:3@0000060=^:3@8000000`2iM@/00`00
0000^GD;0;Ue2`02000000030:f][@00000000000080R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?oo
o`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][@h0
o:0@00<000000?bP403lX1000P0000050?nT4@80000000<0oj@A0000003oY1402P3oY1400`2][Jd0
ojHA0?nV4@0F0?nV4@800000103oYQ450:f][@8000000`2][Jd>0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ000P3oYQ000`000000ojH@0000000G0?nV40030:f][@3oYA00ojD@01X0
ojD@00<000000?nU400000003P3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00H0[Jf]045Yh@2][Jd0[Jf]0=^:3@000002
0=^:3@030000003KRPd0fhX=00@0fhX=0P0000030;Ue2`030000002iM@/0^GD;0080000000<0R5H7
00000028EPL00P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]
09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]3`3lX1000`000000o:0@0?bP4002
000001@0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ420:f][@800000102][Jd50?nV4@8000004@3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0080ojH@0P00000H0?nV40030:f][@3oYA00
ojD@01X0ojD@0P0000000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]5`3lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>0100k9H>00H0[Jf]0=^:3@3KRPd0fhX=0:f][@0000020=^:3@030000
003KRPd0fhX=00@0fhX=0P0000030;Ue2`030000002iM@/0^GD;0080000000<0R5H70000002][Jd0
0P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400=0?bP40040000
003lX100[Jf]000001D0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ460:f][@80ojHA0P0000090?nV4@80
00004@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00<0ojH@00<000000?nV403o
YQ005P3oYQ000`2][Jd0ojD@0?nU400K0?nU40030000002][Jd0oj<@01/0oj<@00@0[Jf]0?bP403l
X100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@020=^:3@040000002][Jd0[Jf]000000H0fhX=0P0000030;Ue2`030000002iM@/0
^GD;0080000000H0R5H700000028EPL0[Jf]0000002][Je20;3PiP40oooo001I0;3PiP80[Jf]0P2G
H0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd40>nH40030:f][@3l
X100o:0@00d0o:0@00@000000?bP402][Jd000005@3oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]
203oYQ42000000T0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400K0?nU40030000002][Jd0oj<@01/0oj<@00<0[Jf]0?bP403lX100
203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=0080fhX=00D000000=^:3@3KRPd000000:f][@050=^:3@8000000`2iM@/02@000000
^GD;0;Ue2`000000[Jf]08QF1`000000R5H70:f][@0200000480/>3V0@3oool005T0/>3V0P2][Jd2
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@H0kiP@00<0[Jf]
0?bP403lX1003@3lX10010000000o:0@0:f][@00000E0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]
3`3oYQ42000000T0ojHA0P00000A0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
3P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=0080fhX=0P0000000`3KRPd000000=^:3@020:f][@<0fhX=0P0000030;Ue2`070000
002iM@/0^GD;0000002][Jd0R5H70000000208QF1`800000@P2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd80>nH40030:f][@3lX100
o:0@00d0o:0@00@000000?bP402][Jd00000503oY1450:f][AD0ojHA0P0000090?nV4@8000004@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][JdD0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd4000000<0fhX=0P2][Jd00`3KRPd0[Jf]0000
00030;Ue2`070000002iM@/0^GD;0000002][Jd0R5H70000000208QF1`800000@P2`h>H10?ooo`00
F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f][@2][Jd:0>nH4003
0:f][@3lX100o:0@00d0o:0@00@000000?bP402][Jd00000403oY1440:f][@030?nT4@2][Jd0ojHA
01L0ojHA0P0000060?nV4@<000004`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l0102][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd00P3KRPd2000000030=^:3@000000000000@0fhX=0P2][Jd200000080^GD;0P0000001@2i
M@/000000;Ue2`2][Jd000000080R5H70`0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P060=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400=0?bP40040000003lX100[Jf]
000000`0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01<0ojHA1@00000L0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P0000020=^:3@030000003KRPd0
fhX=00<0fhX=00<0[Jf]0000000000000P2iM@/2000000050;Ue2`000000^GD;0:f][@0000000P28
EPL300000440/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd=
0>nH40030:f][@3lX100o:0@00d0o:0@00<000000?bP400000002@3oY1440:f][@T0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`090?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=0080fhX=0P0000020=^:3@030000003KRPd0fhX=00<0fhX=00D0[Jf]
000000000000[Jf]0;Ue2`02000000040;Ue2`000000^GD;0:f][@80000000@0R5H7000000000000
0000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0dhL>
0:f][@0=0>nH40030:f][@3lX100o:0@00d0o:0@00<000000?bP400000001@3oY1440:f][@d0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>
0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@8000000P3KRPd00`000000fhX=0=^:3@030=^:3@05
0:f][@00000000000;Ue2`2][Jd00P0000001`2iM@/000000000002][Jd0R5H700000028EPL01000
00100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P030=>73P040:f][@3CQ`h0
dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003@3lX10010000000o:0@0000003oY1440:f][A40oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`@0[Jf]4@3/UPh0102][Jd0fhX=
0=^:3@3KRPd200000080fhX=00<000000=^:3@3KRPd00`3KRPd00`2][Jd00000000000020;Ue2`80
000000L0^GD;000000000000[Jf]08QF1`000000R5H700@00000@02`h>H10?ooo`00F02`h>H20:f]
[@<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P2][Jd30=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX1003P3lX102000000030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh0102][Jd0fhX=0=^:3@3K
RPd200000080fhX=00<000000=^:3@3KRPd00`3KRPd00`2][Jd00000000000020;Ue2`80000000L0
^GD;000000000000[Jf]08QF1`000000R5H700@00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;
00@0[Jf]0=>73P3CQ`h0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0
o:0@0P2][Jd2000001H0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P040:f][@3KRPd0fhX=0=^:3@8000000P3KRPd00`00
0000fhX=0=^:3@030=^:3@030:f][@000000000000<0^GD;00P000000:f][@00000000000:f][@28
EPL0000008QF1`@00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P2][Jd01P3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd20?bP408000005P3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/
UPh30:f][@T0k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P0000020=^:3@030000003KRPd0fhX=00<0fhX=
00<0[Jf]0000000000000`2iM@/02P000000^GD;0;Ue2`000000[Jf]08QF1`000000R5H70000002]
[Jd200000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd50?bP40030000002][Jd0oj@A01D0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd6
0>bF3P030:f][@3KRPd0fhX=0080fhX=00@000000=^:3@3KRPd000001@3KRPd00`2][Jd000000000
00030;Ue2`0:0000002iM@/0^GD;0000002][Jd0R5H700000028EPL000000:f][@800000@02`h>H1
0?ooo`00E`2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH
403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]1`3lX1000`000000[Jf]0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV
4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@020=^:
3@030000003KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00`0000030;Ue2`040000002iM@/0^GD;
00000080[Jf]00@0000008QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3PiP030000002][Jd0
Uf0;0080Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP403lX100o:0@0`2]
[Jd:0?bP40030000002][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd00`3KRPd00`000000fhX=0=^:3@030=^:3@040000003K
RPd0fhX=0=^:3@8000000`2iM@/010000000^GD;0;Ue2`0000020:f][@0400000028EPL000000:f]
[@800000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1`3CQ`h00`2][Jd0
kiP@0>nH400<0>nH40040:f][@3lX100[Jf]0:f][@d0o:0@00<000000:f][@3oY140503oY1400`2]
[Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f]
[@<0fhX=00<000000=^:3@3KRPd00`3KRPd01@000000fhX=0=^:3@3KRPd0[Jf]00@0^GD;00X00000
0;Ue2`2iM@/000000:f][@28EPL0000008QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3PiP07
0000002][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@070=>73P030:f][@3_V100kiP@00/0kiP@0`2][Jd@
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<
0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>0100k9H>00H0[Jf]0=^:3@2][Jd0[Jf]0=^:3@0000050=^:3@050000
003KRPd0fhX=0=^:3@2][Jd00P2iM@/00`000000^GD;000000020;Ue2`80000000D0R5H700000028
EPL000000:f][@0200000400/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0
dhL>0=>73P050=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P06
0:f][@3KRPd0fhX=0=^:3@2][Jd000001@3KRPd01@000000fhX=0=^:3@3KRPd0[Jf]00<0^GD;0P00
00030;Ue2`0600000028EPL000000:f][@000000[Jf]0P0000100;3PiP40oooo001H0;3PiP030:f]
[@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]
0`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
5@3oYQ480:f][ID0/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@030000002][Jd0[Jf]00<0fhX=00D000000=^:3@3KRPd0
fhX=0:f][@080;Ue2`0600000028EPL0000008QF1`000000[Jf]0P0000100;3PiP40oooo001H0;3P
iP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd50>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV
4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00P2][Jd00`3KRPd000000=^:3@020=^:
3@030:f][@2iM@/0^GD;00H0^GD;00H0000008QF1`000000R5H70000002][Jd200000400/>3V0@3o
ool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1000`3_V102
0:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd00`000000fhX=0=^:3@020=^:3@030:f][@000000
fhX=0080fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01P2][Jd0000000000028EPL000000:f][@800000
@02`h>H10?ooo`00E`2`h>H20:f][@@0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@0>nH
403_V1020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f]
[@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P060:f][@3KRPd0fhX=0000003KRPd000001@3KRPd01@000000[Jf]0:f][@3K
RPd0[Jf]00T0^GD;0P0000000`28EPL000000:f][@0200000400/>3V0@3oool005L0/>3V0P2][Jd3
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P040:f][@3KRPd0fhX=0=^:3@8000001@3KRPd00`000000fhX=0=^:3@020:f][@T0^GD;
00@0[Jf]00000028EPL0R5H70`0000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>
0=>73P060=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A
102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=
0P0000030=^:3@040000003KRPd0fhX=0=^:3@<0[Jf]1`2iM@/0102][Jd0000008QF1`28EPL30000
0400/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd>0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd2000000030=^:3@000000fhX=0080
fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2iM@/0102][Jd0000008QF1`28EPL300000400/>3V0@3oool0
05L0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P030=>73P80[Jf]00<0dhL>0:f]
[@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3P
iPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P0000030=^:
3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/0102][Jd0000008QF1`28EPL300000400/>3V0@3o
ool005L0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0
dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`
h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;0080^GD;0P2][Jd30;Ue2`040:f][@000000000008QF1`<00000@02`h>H10?ooo`00E`2`
h>H00`000000[Jf]09MP2`0209MP2`050:f][@3CQ`h0dhL>0=>73P2][Jd0103CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00P0[Jf]0;Ue2`2iM@/0[Jf]08QF1`000000R5H7
0:f][@<00000?`2`h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`040:f][@3CQ`h0[Jf]
0:f][@D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H3
0:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0[Jf]00D0R5H7
00000028EPL0[Jf]045Yh@02000003l0/>3V0@3oool005L0/>3V00<000000:f][@2GH0/00P2GH0/2
0:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH3
0:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70000000208QF1`030:f][@000000000003l0/>3V0@3o
ool005L0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/4
0:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]00@00000
08QF1`28EPL0[Jf]0P00000o0;3PiP40oooo001G0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]203C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;Vb
YP0:0;VbYP<0[Jf]kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/20:f][@0400000028EPL0R5H70:f][@800000?`2`h>H10?ooo`00E`2`
h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0
_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`0000000P28EPL00`2][Jd000000000000o0;3PiP40oooo
001G0;3PiP060:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0
[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080
[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL000000080R5H700<0[Jf]00000000
0000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL000000:f][@28
EPL0[Jf]0P00000o0;3PiP40oooo001G0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]00000000
0000R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/00`2][Jd0
dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0
R5H700000028EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[
W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3P
iPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`28EPL00P28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/00`2][Jd0
dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080[Jf]0P2TWXl00`11JN40Y9j?0:f][@040;6[
W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je00;3PiP40oooo001F0;3P
iP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h01@2][Jd0kiP@0:f][@2][Jd0
@FWQ00<0Y9j?00<0@FWQ0:BNS`11JN401P2aZid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2]
[Jd80;ji^080@FWQ0P2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3C
Q`h20:f][@80Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?0P11JN400`2][Jd0@FWQ0;6[W@060;6[W@80[Jf]
0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
2`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@11JN40];2a00<0];2a0P2][Jd:0;Ue2`04
0:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]045Yh@2TWXl00P2TWXl02011JN40Y9j?0:BNS`2TWXl0@FWQ
0:BNS`2][Jd0@FWQ2@2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd70;ji^003045Yh@2n
^KP0_[Vh0080_[Vh00<0[Jf]045Yh@2d/;401@2d/;420:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h0103C
Q`h20:f][@030:BNS`11JN40Y9j?0080Y9j?00L0@FWQ0:BNS`2TWXl0Y9j?045Yh@2TWXl0[Jf]0080
@FWQ2P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/004
0:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0050;ji
^080@FWQ00<0_[Vh045Yh@2n^KP00P2n^KP00`2][Jd0@FWQ0;B`/@050;B`/@80@FWQ00<0[Jf]0;Ue
2`2iM@/01@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f]
[@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P030=>73P<0[Jf]00<0Y9j?045Yh@2TWXl00P2TWXl01P11
JN40Y9j?0:BNS`11JN40Y9j?0:f][@80/J^M00@0@FWQ0;6[W@2aZid0/J^M0`11JN450;6[W@030:f]
[@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh
0;ji^0020;ji^080@FWQ0`2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2d/;40];2a00D0];2a
0P11JN420:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001F0;3PiP030000
002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h0102][Jd0RXEe08Z5M@2][Jd20:BNS`04
045Yh@2TWXl0Y9j?045Yh@80Y9j?00<0@FWQ0:BNS`2][Jd00P2aZid2045Yh@@0/J^M0`11JN430;6[
W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m
^`040:f][@2n^KP0_[Vh0;ji^0<0@FWQ102n^KP01@11JN40_[Vh0;ji^02n^KP0@FWQ00P0];2a0P2]
[Jd00`11JN40[Jf]0:f][@030;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`
h>H00`000000[Jf]09MP2`0209MP2`080:f][@3CQ`h0dhL>0=>73P2][Jd0@FWQ08Z5M@11JN430:f]
[@040:BNS`11JN40Y9j?045Yh@80Y9j?00<0@FWQ0:BNS`2][Jd00P2aZid2045Yh@@0/J^M00@0@FWQ
0;6[W@2aZid0/J^M0P11JN400`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n
^KP0_[Vh0080_[Vh0P11JN440;ji^005045Yh@2n^KP0_[Vh0;ji^011JN401`2d/;401`2][Jd0];2a
0;B`/@11JN40Wi^P045Yh@2][Jd00P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool0
05H0/>3V00<000000:f][@2GH0/00P2GH0/0102][Jd0dhL>0:f][@2][Jd4045Yh@040:f][@2TWXl0
Y9j?0:f][@<0@FWQ0P2TWXl00`11JN40Y9j?0:f][@020;6[W@80@FWQ102aZid00`11JN40/J^M0;6[
W@020;6[W@<0@FWQ2P2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36
`;`30:f][@h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@@0_[Vh0P11JN420;ji^003045Yh@2d
/;40];2a00<0];2a0P2][Jd30;B`/@04045Yh@2OVj00@FWQ045Yh@<0[Jf]1028EPL00`2][Jd0/>3V
0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd02`11JN40RXEe08Z5
M@11JN40RXEe045Yh@2][Jd0Y9j?045Yh@2TWXl0[Jf]0080@FWQ0P2TWXl00`11JN40Y9j?0:f][@03
0;6[W@03045Yh@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@<0^K:V00<0@FWQ
0;VbYP2i/ZH02@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`02`36`;`40:f][@030<K0_02][Jd0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP2
045Yh@@0_[Vh0P11JN420;ji^0040:f][@11JN40];2a0;B`/@80[Jf]00P0];2a045Yh@11JN40];2a
045Yh@2][Jd0Wi^P045Yh@<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n0;3P
iP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@11JN400`2:QGD2045Yh@03
0:f][@2TWXl0@FWQ0080Y9j?0P11JN401@2][Jd0Y9j?045Yh@2TWXl0[Jf]00<0/J^M00<0@FWQ0;6[
W@2aZid00P2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ102i/ZH2045Yh@X0^K:V00<0[Jf]0;jg
[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jd50<K0_0030:f][@33_K/0`kfk
00d0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@@0_[Vh0P11JN420;ji^0040:f][@11JN40];2a
0:f][@<0];2a0P11JN400`2d/;40@FWQ0:f][@0609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`
h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`040:f][@11JN40RXEe045Yh@D0RXEe00<0
[Jf]0:BNS`11JN400P2TWXl2045Yh@050:BNS`2][Jd0@FWQ0:BNS`2][Jd00`2aZid00`11JN40/J^M
0;6[W@020;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN440;VbYP@0@FWQ202i/ZH00`2][Jd0_[N/
0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ1@2n^KP02011JN40_[Vh0;ji^02][Jd0@FWQ
0:f][@2d/;40@FWQ0`2d/;401011JN40];2a045Yh@2][Jd609nKX0050:f][@28EPL0R5H708QF1`2]
[Jd0@02`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`040:f][@11JN40@FWQ045Yh@D0
RXEe00<0[Jf]0:BNS`11JN400P2TWXl01@11JN40Y9j?0:BNS`2TWXl0@FWQ0080[Jf]0P2aZid2045Y
h@@0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@@0^K:V0P11JN470;VbYP04045Yh@2i/ZH0^K:V
0:f][@T0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0@FWQ0<>m^`0>
0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ1@2n^KP01@11JN40_[Vh0:f][@2][Jd0@FWQ0080];2a
0P11JN430;B`/@03045Yh@2d/;40[Jf]00L0Wi^P00@0[Jf]08QF1`28EPL0[Jf]@02`h>H10?ooo`00
E@2`h>H010000000[Jf]09MP2`2GH0/20:f][@<0@FWQ1@2:QGD01P2][Jd0Y9j?0:BNS`11JN40Y9j?
045Yh@<0Y9j?00D0@FWQ0:BNS`2][Jd0[Jf]0;6[W@02045Yh@@0/J^M00<0@FWQ0;6[W@2aZid00P2a
Zid2045Yh@@0^K:V0P11JN450;VbYP80@FWQ00@0^K:V045Yh@2i/ZH0[Jf]3@2n]j`40:f][@030;jg
[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f]
[@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]
4@36`;`00`2][Jd0@FWQ045Yh@0>0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ1@2n^KP01@11JN40
[Jf]0;ji^02][Jd0@FWQ0080];2a0P11JN450;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Jd00`28
EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]00<0RXEe045Y
h@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`80@FWQ0`2TWXl01@11JN40Y9j?0:f][@2aZid0
[Jf]0080@FWQ102aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ102i/ZH2045Yh@@0^K:V00<0@FWQ
0;VbYP2i/ZH00P2i/ZH2045YhA40_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`02P36`;`2045Yh@@0a/2l00<0[Jf]
045Yh@33_K/03P33_K/0102][Jd0_[Vh0;ji^02n^KP2045Yh@<0_[Vh0P2][Jd01@11JN40_[Vh0;ji
^02][Jd0@FWQ0080];2a0P11JN450;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0
[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]08Z5M@11JN40102:QGD00`2][Jd0Y9j?
0:BNS`070:BNS`03045Yh@2TWXl0[Jf]0080/J^M00@0@FWQ0:f][@2][Jd0[Jf]0P2aZid00`11JN40
/J^M0;6[W@020;6[W@03045Yh@2][Jd0^K:V00<0^K:V0P11JN430;VbYP80@FWQ1@2i/ZH00`11JN40
_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/00/0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036
`;`02036`;`2045Yh@80a/2l00H0@FWQ0<K0_036`;`0a/2l0:f][@11JN4?0<>m^`040:f][@2n^KP0
_[Vh0;ji^080@FWQ0`2][Jd20;ji^080@FWQ00H0_[Vh0:f][@11JN40@FWQ0;B`/@11JN460;B`/@03
0:f][@2OVj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]
0`1SH5<20:f][@D0RXEe00<0[Jf]0:BNS`2TWXl01P2TWXl3045Yh@040:f][@2aZid0/J^M045Yh@<0
/J^M0P2][Jd00`11JN40/J^M0;6[W@020;6[W@03045Yh@2][Jd0^K:V00<0^K:V0P11JN430;VbYP80
@FWQ1@2i/ZH00`2][Jd0@FWQ0;jg[0020;jg[003045Yh@2n]j`0@FWQ00@0@FWQ1`2n]j`00`2][Jd0
`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/04`38`K/3045YhA@0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_003
0:f][@36`;`0a/2l00D0a/2l00<0@FWQ0<K0_011JN401@36`;`01011JN40a/2l0<K0_02][Jd@0<>m
^`040:f][@2n^KP0_[Vh0;ji^080@FWQ1@2n^KP2045Yh@050;ji^02][Jd0@FWQ0;B`/@11JN401`2d
/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F
0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0Y9j?0:BNS`07
0:BNS`80@FWQ00<0[Jf]0;6[W@11JN401P2aZid00`11JN40[Jf]0:f][@020;6[W@03045Yh@2][Jd0
^K:V00<0^K:V0P11JN430;VbYP03045Yh@2i/ZH0^K:V00<0^K:V00<0[Jf]0;jg[011JN400`2n]j`2
045Yh@@0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/04038`K/4
045Yh@030:f][@38`K/0b<6k0100b<6k1P2][JdA0<O1_0030:f][@36`;`0a/2l00D0a/2l0P11JN46
0<K0_004045Yh@36`;`0a/2l0:f][A00`kfk00@0[Jf]0;ji^02][Jd0[Jf]0P11JN450;ji^080@FWQ
00<0_[Vh0:f][@11JN402@2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80
L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0
[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03045Yh@2aZid0@FWQ00D0/J^M00@0@FWQ0;6[W@2a
Zid0/J^M0P2][Jd00`11JN40[Jf]0;VbYP030;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0@FWQ0;Vb
YP2i/ZH00`2i/ZH00`2][Jd0_[N/0;jg[0030;jg[080@FWQ1@2n]j`00`11JN40_[N/0;jg[0030;jg
[003045Yh@2][Jd0`KZ`0100`KZ`202][Jd@0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/04P38`K/2045Yh@030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l
0100al6l1011JN450<K0_080@FWQ1P36`;`01011JN40a/2l0<K0_02][Jd?0<>m^`<0[Jf]0`2n^KP2
045Yh@@0_[Vh1011JN4:0;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2OVj000`2][Jd0L6ii071^N@02
0:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0
[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0@FWQ0;6[W@050;6[W@80@FWQ102aZid0
0`11JN40[Jf]0:f][@030;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH0
0`2][Jd0_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`0
0`11JN40_[N/045Yh@0C0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38
`K/00`2][Jd0al6l0<O1_0070<O1_0<0@FWQ1037`K`2045Yh@050<O1_02][Jd0a/2l0<K0_011JN40
1@36`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ0P36`;`00`2][Jd0`kfk0<>m^`0:0<>m^`<0[Jf]
00<0`kfk0:f][@2n^KP00`2n^KP2045Yh@@0_[Vh0P11JN400`2n^KP0[Jf]0;B`/@090;B`/@030:f]
[@2OVj00[Jf]00D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1S
H5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2a
Zid0/J^M00D0/J^M0P11JN440;6[W@03045Yh@2][Jd0^K:V00<0[Jf]00<0@FWQ0;VbYP2i/ZH00P2i
/ZH00`11JN40^K:V0;VbYP030;VbYP030:f][@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`0102n
]j`00`11JN40_[N/0;jg[0030;jg[003045Yh@2][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<03P33
_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/30:f][@80@FWQ102][JdB0<S1^`030:f][@37
`K`0al6l00@0al6l1011JN460<O1_004045Yh@37`K`0al6l0:f][@<0a/2l00<0@FWQ0<K0_036`;`0
0P36`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ0P36`;`00`2][Jd0`kfk0<>m^`070<>m^`<0[Jf]
1033_K/00`2][Jd0_[Vh0;ji^0020;ji^080@FWQ102n^KP01011JN40_[Vh0;ji^02][Jd:0;B`/@80
[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<0
0P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]2`2TWXl00`2][Jd0/J^M0;6[W@050;6[W@03045Y
h@2aZid0@FWQ00<0/J^M00<0@FWQ0:f][@2i/ZH00`2i/ZH00`11JN40[Jf]0:f][@020;VbYP03045Y
h@2i/ZH0^K:V00<0^K:V00<0[Jf]0;jg[02n]j`02P2n]j`00`11JN40_[N/0;jg[0040;jg[0030:f]
[@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]
1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]0`38`K/2045Yh@030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]045Yh@11JN400P11JN440<O1_080@FWQ1@37`K`2045Yh@80al6l00<0[Jf]0<K0_036`;`0
2`36`;`2045Yh@<0a/2l00<0[Jf]0<>m^`11JN401@33_K/20:f][@L0`kfk00<0[Jf]0;ji^02n^KP0
0P2n^KP2045Yh@@0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX005
0:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`03
0:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@050;6[W@03
045Yh@2aZid0@FWQ0080/J^M0P11JN400`2][Jd0^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V0080
[Jf]00<0@FWQ0:f][@2i/ZH00`2i/ZH00`2][Jd0_[N/0;jg[00:0;jg[003045Yh@2n]j`0_[N/00<0
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0
aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][@l0
b<6k0P11JN400`2][Jd0b<6k0<S1^`0<0<S1^`@0@FWQ0P38`K/4045Yh@H0al6l0P11JN450<O1_005
045Yh@37`K`0al6l0<O1_02][Jd03036`;`2045Yh@@0a/2l00<0[Jf]0<>m^`11JN400P33_K/30:f]
[@T0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@@0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]202d/;43
0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0
Hf1C06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2aZid01@2aZid01@11JN40/J^M0;6[
W@11JN40/J^M0080@FWQ00<0[Jf]0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;VbYP020;VbYP03045Y
h@2i/ZH0[Jf]0080[Jf]00<0^K:V0:f][@2n]j`02@2n]j`3045Yh@D0_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
2@36_kL`0:f][@/0al6j00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@030:f][@38`K/0b<6k00X0b<6k
1011JN450<S1^`030:f][@11JN40@FWQ00H0al6l0P11JN450<O1_005045Yh@37`K`0al6l0<O1_02]
[Jd02`36`;`2045Yh@D0a/2l00<0[Jf]0<>m^`11JN400P2][Jd<0<>m^`030:f][@2n^KP0_[Vh0080
_[Vh0P11JN430;ji^080@FWQ0P2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f]
[@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid01@2aZid0
1011JN40/J^M0;6[W@2aZid2045Yh@030;6[W@2][Jd0^K:V00<0^K:V00<0@FWQ0;VbYP2i/ZH00P2i
/ZH2045Yh@<0^K:V0P2][Jd00`11JN40_[N/0;jg[0050;jg[0@0@FWQ1P2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc0140`kfc1011JN4E0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k0180b<6k0P11
JN400`2][Jd0b<6k045Yh@02045Yh@X0b<6k0P11JN450<S1^`030:f][@11JN40@FWQ00H0al6l0P11
JN440<O1_080@FWQ0`37`K`00`2][Jd0a/2l0<K0_0080<K0_080@FWQ1036`;`40:f][@03045Yh@33
_K/0`kfk00`0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@<0_[Vh0P11JN420;ji^0030:f][@2d
/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii
0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl0
0P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f][@2aZid0/J^M00D0/J^M00<0@FWQ0;6[W@2aZid0
102aZid00`2][Jd0^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN440;VbYP80@FWQ
102][Jd20;jg[0<0@FWQ202n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
1P11JN4A0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k00d0b<6k0P11JN430<S1^`@0@FWQ0P38`K/3045Yh@P0b<6k
0P11JN450<S1^`030:f][@11JN40@FWQ00H0al6l0P11JN440<O1_080@FWQ0`37`K`00`2][Jd0a/2l
0<K0_0070<K0_003045Yh@36`;`0@FWQ00<0[Jf]00H0@FWQ0<K0_036`;`0[Jf]0<>m^`11JN4>0<>m
^`030:f][@2n^KP0_[Vh0080_[Vh0P11JN430;ji^080@FWQ0P2n^KP0102][Jd0];2a0;B`/@2d/;42
0:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001G
0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0
[Jf]0;6[W@2aZid01@2aZid00`11JN40/J^M0;6[W@040;6[W@030:f][@2i/ZH0^K:V00<0@FWQ1@2i
/ZH00`11JN40^K:V0;VbYP020;VbYP030:f][@11JN40_[N/00<0_[N/00@0[Jf]045Yh@11JN40[Jf]
2@2n]j`00`11JN40`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc0P11JN440<Fn]@80@FWQ
1P35_[D7045Yh@80aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/01@38`K/4045Yh@<0b<6k0P11JN440<S1^`<0@FWQ
1@38`K/00`11JN40b<6k0<S1^`060<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@060<O1_080@FWQ
1037`K`2045Yh@<0al6l00<0[Jf]0<K0_036`;`01@36`;`0102][Jd0@FWQ0:f][@11JN440<K0_006
045Yh@36`;`0a/2l0:f][@33_K/0@FWQ3P33_K/00`2][Jd0_[Vh0;ji^0020;ji^080@FWQ0`2n^KP0
1@11JN40_[Vh0;ji^02n^KP0[Jf]0080];2a00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0Wi^P09nK
X00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:
QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@050;6[W@03045Yh@2a
Zid0/J^M00<0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH2045Yh@<0^K:V00<0[Jf]045Yh@2n]j`00`2n
]j`2045Yh@80_[N/102][Jd50;jg[003045Yh@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D01P35_[D00`11JN40aKje0<Fn]@030<Fn]@030:f][@36
_kL0a[ng00L0a[ng1011JN450<Jo]`80@FWQ0`36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@11
JN40@FWQ0080@FWQ0P37`KX2045Yh@@0al6j1`11JN440<O1^P030:f][@38`K/0b<6k00<0b<6k0P11
JN440<S1^`03045Yh@38`K/0b<6k0080@FWQ1038`K/2045Yh@030:f][@38`K/0b<6k00@0b<6k00<0
@FWQ0<S1^`38`K/01@38`K/2045Yh@D0b<6k00<0[Jf]045Yh@11JN401P37`K`2045Yh@@0al6l0P11
JN430<O1_0040:f][@36`;`0a/2l045Yh@@0[Jf]00<0a/2l045Yh@11JN401036`;`2045Yh@80a/2l
00<0[Jf]0<>m^`11JN403P33_K/00`2][Jd0_[Vh0;ji^0020;ji^080@FWQ0`2n^KP01011JN40_[Vh
0;ji^02n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40
oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@L0/J^M
00<0@FWQ0;6[W@2aZid00`2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP05045Yh@2i/ZH0^K:V0;VbYP11
JN401@2n]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@2][Jd0[Jf]0080[Jf]00<0_[N/045Yh@31
^[004`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`80@FWQ1P35_[D00`11JN40aKje0<Fn]@060<Fn]@03
045Yh@35_[D0aKje00<0aKje00<0[Jf]0<Jo]`36_kL01@36_kL3045Yh@<0a[ng0P11JN400`36_kL0
@FWQ045Yh@050<Jo]`040:f][@37`KP0al6h045Yh@H0al6h00<0@FWQ0<O1^037`KP02P37`KP00`11
JN40al6j0<O1^P020<O1^P@0@FWQ1P37`KX2045Yh@L0al6j00<0[Jf]0<S1^`38`K/00P38`K/2045Y
h@H0b<6k0`11JN450<S1^`80@FWQ00<0[Jf]0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`050<S1
^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@060<O1_080@FWQ1037`K`2045Yh@030<O1_02][Jd0[Jf]
00<0[Jf]0P11JN440<K0_003045Yh@36`;`0a/2l00<0a/2l0P11JN420<K0_0040:f][@11JN40@FWQ
045Yh@d0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@80_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P2]
[Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H2
0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@H0/J^M00<0@FWQ0;6[W@2aZid00`2aZid0
0`2][Jd0^K:V0;VbYP0;0;VbYP@0@FWQ1@2n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ102n]j`0
0`2][Jd0@FWQ0:f][@020:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<2045Yh@L0aKje00<0@FWQ
0<Fn]@35_[D01@35_[D00`11JN40aKje0<Fn]@030<Fn]@030:f][@36_kL0a[ng00@0a[ng0P11JN46
0<Jo]`04045Yh@36_kL0@FWQ045Yh@D0a[ng00@0[Jf]0<O1^037`KP0@FWQ1P37`KP00`11JN40al6h
0<O1^0090<O1^080@FWQ1@37`KX3045Yh@H0al6j0P11JN470<O1^P030:f][@38`K/0b<6k0080b<6k
0P11JN470<S1^`80@FWQ1@38`K/2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN460<S1^`80@FWQ
1@38`K/00`2][Jd0@FWQ045Yh@070<O1_003045Yh@37`K`0al6l0080[Jf]0P11JN40102][Jd0al6l
0<O1_02][Jd20<K0_080@FWQ1036`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ0P36`;`0102][Jd0
@FWQ045Yh@11JN4=0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0P11JN40102n^KP0@FWQ045Yh@2n^KP2
0:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool0
05T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd0102a
Zid0@FWQ0;6[W@11JN450;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`0
0`11JN40_[N/0;jg[0030;jg[080@FWQ1@2n]j`01011JN40`KZ`0<6j/031^[070:f][@X0`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D01@35_[D00`11JN40aKje0<Fn
]@030<Fn]@030:f][@36_kL0a[ng00@0a[ng0P11JN470<Jo]`80@FWQ1P36_kL0102][Jd0al6h0<O1
^011JN450<O1^080@FWQ2P37`KP2045Yh@030:f][@37`KX0al6j00@0al6j0P11JN460<O1^P80@FWQ
1`37`KX00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ1`38`K/2045Yh@D0b<6k0P11JN400`2][Jd0b<6k
0<S1^`040<S1^`80@FWQ1P38`K/2045Yh@D0b<6k00<0[Jf]045Yh@11JN401@37`K`20:f][@03045Y
h@2][Jd0[Jf]00<0al6l0P11JN420<O1_0030:f][@36`;`0a/2l0080@FWQ1036`;`00`11JN40a/2l
0<K0_0020<K0_003045Yh@36`;`0@FWQ0080a/2l00@0[Jf]045Yh@11JN40@FWQ3@33_K/00`2][Jd0
_[Vh0;ji^0020;ji^0<0@FWQ00<0_[Vh0:f][@2][Jd00`2n^KP00`2][Jd0];2a0;B`/@090;B`/@03
0:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]0P11JN450;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ
1@2n]j`00`11JN40`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`80@FWQ
1`35_[D2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ
1`36_kL2045Yh@H0a[ng00<0[Jf]0<O1^011JN400P11JN440<O1^0<0@FWQ2037`KP2045Yh@80al6h
00<0[Jf]0<O1^P37`KX00`37`KX2045Yh@H0al6j0P11JN470<O1^P030:f][@38`K/0b<6k0080b<6k
0P11JN470<S1^`80@FWQ1@38`K/2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN460<S1^`80@FWQ
1@38`K/00`2][Jd0@FWQ045Yh@050:f][@80al6l00<0@FWQ0<O1_037`K`00`37`K`2045Yh@80al6l
00@0[Jf]0<K0_036`;`0@FWQ1@36`;`5045Yh@D0a/2l00@0[Jf]045Yh@11JN40@FWQ3@33_K/0102]
[Jd0_[Vh0;ji^02n^KP2045Yh@<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00
Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;Vb
YP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP080;VbYP030:f][@2n]j`0_[N/00D0_[N/1011JN400`2n
]j`0@FWQ0;jg[0040;jg[003045Yh@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`80@FWQ1`35_[D2045Y
h@H0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Y
h@H0a[ng00<0[Jf]0<O1^011JN400P11JN440<O1^0<0@FWQ2037`KP01@11JN40al6h0<O1^037`KP0
[Jf]00D0al6j0P11JN460<O1^P80@FWQ1`37`KX00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ1`38`K/2
045Yh@D0b<6k0P11JN400`2][Jd0b<6k0<S1^`050<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN42
0<S1^`@0[Jf]0P11JN470<O1_003045Yh@37`K`0al6l00<0al6l0P11JN420<O1_0040:f][@36`;`0
a/2l045YhA00a/2l0`11JN4=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP00`2][Jd0];2a
0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`
h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2a
Zid30:f][@030;6[W@2][Jd0^K:V00<0^K:V0P11JN4:0;VbYP030:f][@2n]j`0_[N/00X0_[N/00<0
@FWQ0;jg[02n]j`00P2n]j`2045YhA@0`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`80@FWQ
1`35_[D2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ
1`36_kL2045Yh@H0a[ng00<0[Jf]0<O1^011JN400P11JN440<O1^003045Yh@37`KP0@FWQ00P0al6h
00D0@FWQ0<O1^037`KP0al6h0:f][@050<O1^P80@FWQ1P37`KX2045Yh@L0al6j00<0[Jf]0<S1^`38
`K/00P38`K/2045Yh@L0b<6k0P11JN450<S1^`80@FWQ00<0[Jf]0<S1^`0000001@38`K/01011JN40
b<6k0<S1^`38`K/30:f][@80@FWQ0P2][Jd30<S1^`030:f][@11JN40@FWQ00L0al6l00<0@FWQ0<O1
_037`K`01037`K`2045Yh@040<O1_02][Jd0a/2l045YhA40a/2l0`11JN4=0<>m^`040:f][@2n^KP0
[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`
h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd30;VbYP80@FWQ2P2i/ZH00`2][Jd0_[N/0;jg[00?
0;jg[080@FWQ5031^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<2045Yh@P0aKje0P11JN44
0<Fn]@80@FWQ1@35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`80@FWQ1`36_kL2045Yh@H0a[ng00D0[Jf]
0<O1^011JN40al6h045Yh@030<O1^080@FWQ00<0al6h045Yh@37`KP01`37`KP01@11JN40al6h0<O1
^037`KP0[Jf]00@0al6j00<00000045Yh@11JN401P37`KX2045Yh@L0al6j00<0[Jf]0<S1^`38`K/0
0`38`K/2045Yh@H0b<6k0P11JN450<S1^`80@FWQ00@0[Jf]0<S1^`38`K/0b<6k102][Jd01011JN40
[Jf]0:f][@2][Jd30<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@070<O1_003045Yh@37`K`0al6l
00D0al6l1011JN4B0<K0_0<0@FWQ3033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2]
[Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@020:f][@03045Yh@2i/ZH0^K:V00T0
^K:V00<0[Jf]0;jg[02n]j`03`2n]j`2045YhA@0`KZ`00<0[Jf]0<>m/`33_K<04033_K<30:f][@80
@FWQ102][Jd40<Fn]@80@FWQ1035_[D2045Yh@D0aKje00<0[Jf]0<Jo]`36_kL01@36_kL2045Yh@H0
a[ng0P11JN460<Jo]`050:f][@37`KP0@FWQ0<O1^011JN400`37`KP2045Yh@030<O1^011JN40al6h
00H0al6h0P11JN430<O1^0030:f][@37`KX0al6j00<0al6j0P11JN460<O1^P80@FWQ1`37`KX00`2]
[Jd0b<6k0<S1^`040<S1^`@0@FWQ0`38`K/2045Yh@80b<6k0`2][Jd2045Yh@@0[Jf]0`38`K/2045Y
h@H0b<6k0P11JN450<S1^`030:f][@11JN40al6l00L0al6l00<0@FWQ0<O1_037`K`01`37`K`00`2]
[Jd0a/2l0<K0_00A0<K0_0<0@FWQ2@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`
/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0
Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0
_[N/0;jg[00?0;jg[080@FWQ5031^[000`2][Jd0`kfc0<>m/`0C0<>m/`80@FWQ1035_[D40:f][@80
@FWQ102][Jd2045Yh@D0aKje00<0[Jf]0<Jo]`36_kL01`36_kL4045Yh@80a[ng0P11JN460<Jo]`03
0:f][@11JN40@FWQ0080al6h00<0@FWQ0<O1^037`KP00P11JN420<O1^003045Yh@37`KP0al6h00@0
al6h0P11JN430<O1^0040:f][@37`KX000000<O1^PL0@FWQ1037`KX00`11JN40al6j0<O1^P050<O1
^P030:f][@38`K/0b<6k00<0b<6k1@2][Jd5045Yh@80[Jf]0`38`K/2045Yh@030:f][@38`K/0b<6k
00@0b<6k0P11JN460<S1^`<0@FWQ1038`K/00`2][Jd0@FWQ0<O1_0040<O1_0@0@FWQ2P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_080@FWQ1`33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2]
[Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[080
@FWQ5031^[000`2][Jd0`kfc0<>m/`0C0<>m/`03045Yh@35_[D0aKje00L0aKje0P11JN440<Fn]@80
@FWQ4@2][Jd20<Jo]`@0@FWQ1P36_kL00`2][Jd0@FWQ045Yh@020<O1^004045Yh@37`KP0al6h045Y
h@<0al6h00<0@FWQ0<O1^037`KP01037`KP2045Yh@<0al6h00<0[Jf]0<O1^P37`KX02@37`KX30:f]
[@03045Yh@2][Jd0[Jf]00/0[Jf]2038`K/2045Yh@D0b<6k0P11JN400`2][Jd0b<6k0<S1^`030<S1
^`80@FWQ1`38`K/2045Yh@030<S1^`11JN40b<6k0080b<6k00<0@FWQ0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@11JN40`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh
00`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP03
0:f][@2TWXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0
[Jf]00<0^K:V0:f][@2n]j`0402n]j`2045YhA@0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`11JN40
aKje0<Fn]@070<Fn]@80@FWQ1035_[D3045Yh@@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL40:f][@80
@FWQ1`2][Jd2045Yh@80[Jf]00@0@FWQ0:f][@11JN40@FWQ0`2][Jd00`11JN40[Jf]0:f][@040:f]
[@80@FWQ3`2][Jd30<O1^P80@FWQ1037`KX00`000000al6j0:f][@050<S1^`80@FWQ1P38`K/00`11
JN40b<6k0<S1^`040<S1^`<0@FWQ1@38`K/00`11JN40b<6k0<S1^`060<S1^`80@FWQ0P38`K/3045Y
h@030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f]
[@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?oo
o`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0
[Jf]402n]j`2045YhA@0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`11JN40aKje0<Fn]@070<Fn]@80
@FWQ1035_[D3045Yh@@0aKje00<0[Jf]045Yh@36_kL01@36_kL2045Yh@H0a[ng0P11JN460<Jo]`03
0:f][@11JN40@FWQ0080al6h00@0@FWQ0<O1^011JN40@FWQ0`37`KP00`11JN40al6h0<O1^0040<O1
^080@FWQ0`37`KP00`2][Jd0al6j0<O1^P0<0<O1^P80@FWQ1@37`KX00`11JN40[Jf]0<S1^`040<S1
^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<0[Jf]045Yh@38`K/00P38`K/00`11
JN40b<6k0<S1^`070<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00h0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2]
[Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd<0;jg[080@FWQ5031^[000`2][Jd0
`kfc0<>m/`0C0<>m/`03045Yh@35_[D0aKje00L0aKje0P11JN440<Fn]@80@FWQ00<0aKje045Yh@35
_[D00P35_[D00`11JN40a[ng045Yh@050<Jo]`80@FWQ1P36_kL00`11JN40a[ng0<Jo]`050<Jo]`03
0:f][@11JN40al6h0080al6h00@0@FWQ0<O1^011JN40@FWQ0`37`KP00`11JN40al6h0<O1^0040<O1
^080@FWQ0`37`KP00`2][Jd0al6j0<O1^P0<0<O1^P03045Yh@37`KX0@FWQ00<0al6j00<0@FWQ0<O1
^P11JN401@38`K/00`11JN40b<6k0<S1^`040<S1^`03045Yh@38`K/0b<6k00D0b<6k0P11JN400`2]
[Jd0b<6k045Yh@02045Yh@X0b<6k0P11JN450<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji
^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@P0
_[N/00<0@FWQ0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03045Yh@35_[D0aKje00L0
aKje0P11JN440<Fn]@80@FWQ0P35_[D01011JN40aKje0<Fn]@2][Jd2045Yh@D0a[ng0P11JN460<Jo
]`03045Yh@36_kL0a[ng00D0a[ng0P11JN440<O1^080@FWQ1@37`KP00`11JN40al6h0<O1^0030<O1
^080@FWQ0`37`KP00`2][Jd0al6j0<O1^P0<0<O1^P04045Yh@37`KX0al6j045Yh@<0al6j0P11JN46
0<S1^`04045Yh@38`K/0b<6k0<S1^`80@FWQ1P38`K/2045Yh@80b<6k00<0[Jf]0<S1^`38`K/03038
`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36
`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a
0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@@0_[N/00<0@FWQ0:f][@31^[004`31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`03045Yh@35_[D0aKje00H0aKje0P11JN430<Fn]@@0@FWQ0`35
_[D4045Yh@L0a[ng00<0@FWQ0<Jo]`36_kL00`36_kL00`11JN40a[ng0<Jo]`060<Jo]`80@FWQ1037
`KP2045Yh@D0al6h00<0@FWQ0<O1^037`KP00`37`KP2045Yh@<0al6h00<0[Jf]0<O1^P37`KX03037
`KX01011JN40al6j0<O1^P37`KX4045Yh@030:f][@38`K/0b<6k00D0b<6k0`11JN4<0<S1^`030:f]
[@38`K/0b<6k00`0b<6k0P11JN450<S1^`030:f][@37`K`0al6l00L0al6l00<0@FWQ0<O1_037`K`0
2037`K`00`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][E80/>3V0@3oool006/0/>3V0`2][Jd>0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`01<0`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`11JN40aKje0<Fn]@060<Fn]@80@FWQ3035_[D00`2][Jd0a[ng
0<Jo]`070<Jo]`D0@FWQ1P36_kL7045Yh@80al6h0P11JN420<O1^0H0@FWQ0`37`KP2045Yh@<0al6h
00<0[Jf]0<O1^P37`KX02@37`KX4045Yh@L0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0<0<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_0060<O1_080@FWQ2037`K`50:f][A00a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`
h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`03045Yh@35_[D0aKje00H0aKje0P11JN4<0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP04037`KP2045Yh@<0al6h00<0[Jf]0<O1^P37`KX01037
`KX00`11JN40al6j0<O1^P0=0<O1^P030:f][@38`K/0b<6k00L0b<6k00<000000<S1^`38`K/02P38
`K/00`2][Jd0b<6k0<S1^`0<0<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_0070<O1_004045Yh@37
`K`0al6l0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`11JN40aKje0<Fn]@050<Fn]@80@FWQ3@35_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h0140al6h00D0@FWQ0<O1^037`KP0al6h0:f][@060<O1^P03
045Yh@37`KX0al6j00d0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0<0<S1^`80
@FWQ1@38`K/00`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V
0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03045Yh@35_[D0aKje00D0aKje
0P11JN4=0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP04@37`KP01@11JN40al6h
0<O1^037`KP0[Jf]00D0al6j0P11JN4?0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/03038`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00
M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`03045Yh@35_[D0aKje00@0aKje0P11JN4>0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP04@37`KP01@11JN40al6h0<O1^037`KP0[Jf]00D0
al6j0P11JN4?0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02P38`K/3045Yh@<0
b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0
`kfc1`2][Jd80<>m/`@0@FWQ1P35_[D2045Yh@h0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00A0<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P030<O1^P80@FWQ3`37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080
[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`L0@FWQ
4035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h0180al6h0P11JN400`37`KP0[Jf]
0<O1^P030<O1^P<0@FWQ3`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0
[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01<0al6h0P11JN40102][Jd0al6j0<O1^P37`KX2045Yh@03
0<O1^P11JN40al6j00h0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40
oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h1011JN430<O1^P03045Yh@37`KX0al6j00d0al6j
00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V
0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37
`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo0025
0;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@03
0:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0
[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V
0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I
0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0
/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0
/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0
al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2]
[Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H9
0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1
^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52701 .3341 m
.52367 .3309 L
s
.52367 .3309 m
.52032 .3309 L
s
.52868 .33409 m
.52367 .3309 L
s
.52032 .3309 m
.51531 .33409 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54705 .33064 m
.54038 .33077 L
s
.4936 .33053 m
.49693 .33382 L
s
.48694 .33034 m
.4936 .33053 L
s
.55372 .33048 m
.5504 .33378 L
s
.55706 .33039 m
.55372 .33048 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50028 .33077 m
.50028 .33068 L
s
.50025 .33079 m
.50028 .33068 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56529 .3484 m
.56547 .34941 L
s
.56679 .3474 m
.56714 .34935 L
s
.255 .412 .882 r
.51786 .33861 m
.52117 .34087 L
s
.5129 .33858 m
.51786 .33861 L
s
.52945 .3386 m
.53111 .33859 L
s
.52614 .34087 m
.52945 .3386 L
s
.5278 .34086 m
.52945 .3386 L
s
.50958 .3408 m
.5129 .33858 L
s
.50793 .34078 m
.5129 .33858 L
s
.52117 .34087 m
.52449 .34538 L
s
.52449 .34538 m
.52614 .34087 L
s
.52614 .34537 m
.5278 .34086 L
s
.50792 .34529 m
.50958 .3408 L
s
.50626 .34526 m
.50793 .34078 L
s
0 0 0 r
.59199 .33055 m
.59349 .33191 L
s
.59246 .33024 m
.59513 .33181 L
s
.5136 .36629 m
.51361 .35918 L
s
.53039 .3663 m
.53162 .35914 L
s
.51192 .36304 m
.51193 .35919 L
s
.53207 .36629 m
.53329 .35914 L
s
.255 .412 .882 r
.4733 .33755 m
.48481 .33799 L
s
.50791 .3498 m
.50792 .34529 L
s
.50625 .34978 m
.50626 .34526 L
s
0 0 0 r
.49442 .35894 m
.49517 .35954 L
s
.49797 .35907 m
.49852 .35962 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50019 .36288 m
.49852 .35962 L
s
.255 .412 .882 r
.50791 .3498 m
.50956 .35434 L
s
0 0 0 r
.49851 .36285 m
.49517 .35954 L
s
.255 .412 .882 r
.50625 .34978 m
.5079 .35432 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50956 .35434 m
.51287 .35663 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4797 .3695 m
.47987 .33782 L
s
.47805 .36944 m
.47822 .33775 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5079 .35432 m
.51287 .35663 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53945 .37015 m
.546 .33838 L
s
.52449 .34538 m
.52449 .36573 L
s
.52614 .34537 m
.52615 .36119 L
s
.54111 .37013 m
.54602 .34515 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.546 .33838 m
.55272 .36989 L
s
.5592 .33804 m
.56596 .36949 L
s
.55272 .36989 m
.5592 .33804 L
s
.55438 .36985 m
.55923 .3448 L
s
.52283 .35894 m
.51287 .35663 L
s
.52283 .35894 m
.52449 .3612 L
s
.58384 .33924 m
.58872 .3367 L
s
.5806 .34393 m
.58384 .33924 L
s
.52449 .36573 m
.52615 .36119 L
s
.4553 .33662 m
.46018 .33916 L
s
.46018 .33916 m
.46342 .34386 L
s
.58548 .33915 m
.58872 .3367 L
s
.58224 .34384 m
.58548 .33915 L
s
.58872 .3367 m
.59198 .33651 L
s
.4553 .33662 m
.45855 .33907 L
s
.45855 .33907 m
.46178 .34377 L
s
.43909 .33553 m
.4553 .33662 L
s
.579 .34853 m
.5806 .34393 L
s
.46342 .34386 m
.46502 .34846 L
s
.50788 .36337 m
.50954 .36339 L
s
.50954 .36566 m
.50954 .36339 L
s
.58064 .34845 m
.58224 .34384 L
s
.59198 .33651 m
.59688 .33846 L
s
.50788 .36564 m
.50788 .36337 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46178 .34377 m
.46338 .34838 L
s
.52283 .368 m
.52449 .36573 L
s
.47977 .35589 m
.48139 .36275 L
s
.5774 .3554 m
.579 .34853 L
s
.50788 .36564 m
.50954 .36793 L
s
0 0 0 r
.58046 .36781 m
.58056 .36818 L
s
.255 .412 .882 r
.46502 .34846 m
.46661 .35534 L
s
.57904 .35532 m
.58064 .34845 L
s
.51951 .37026 m
.52283 .368 L
s
.4913 .36532 m
.49296 .36309 L
s
.49296 .36309 m
.49461 .3654 L
s
.46338 .34838 m
.46497 .35526 L
s
.50954 .36793 m
.51286 .37023 L
s
.4946 .36767 m
.49461 .3654 L
s
.51286 .37023 m
.51951 .37026 L
s
.59688 .33846 m
.60016 .34276 L
s
.4913 .36532 m
.49295 .36763 L
s
.53447 .37021 m
.54609 .37004 L
s
0 0 0 r
.58117 .36733 m
.58224 .37134 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49294 .3699 m
.4946 .36767 L
s
.48139 .36275 m
.48467 .3674 L
s
.46653 .36668 m
.46661 .35534 L
s
.46489 .3666 m
.46497 .35526 L
s
0 0 0 r
.58056 .36818 m
.58224 .37134 L
s
.255 .412 .882 r
.48797 .36977 m
.49294 .3699 L
s
.48467 .3674 m
.48797 .36977 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4731 .36925 m
.4797 .3695 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.561 .36966 m
.57091 .3693 L
s
.57904 .35532 m
.57912 .36667 L
s
.5774 .3554 m
.57748 .36675 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59984 .35681 m
.60023 .35435 L
s
.59819 .35695 m
.59839 .3557 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6001 .33598 m
.60027 .3541 L
s
.60172 .33587 m
.60189 .35399 L
s
.6114 .33514 m
.62261 .33418 L
s
.57748 .36675 m
.57917 .37349 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46484 .37343 m
.46653 .36668 L
s
.57912 .36667 m
.58081 .37342 L
s
.59539 .35442 m
.60675 .35365 L
s
.4632 .37335 m
.46489 .3666 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57917 .37349 m
.58085 .37797 L
s
.46317 .3779 m
.46484 .37343 L
s
.58081 .37342 m
.58249 .37789 L
s
.46152 .37782 m
.4632 .37335 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58085 .37797 m
.58417 .38237 L
s
.45985 .3823 m
.46317 .3779 L
s
.58249 .37789 m
.58581 .38229 L
s
.45821 .38222 m
.46152 .37782 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58417 .38237 m
.58911 .3844 L
s
.45491 .38432 m
.45985 .3823 L
s
.58581 .38229 m
.58911 .3844 L
s
.45491 .38432 m
.45821 .38222 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44347 .38363 m
.44394 .33588 L
s
.4451 .38374 m
.44556 .336 L
s
.58911 .3844 m
.59239 .38421 L
s
.4386 .3833 m
.45491 .38432 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60205 .36991 m
.60218 .38361 L
s
.60049 .37687 m
.60205 .36991 L
s
.61803 .35276 m
.61972 .35946 L
s
.61782 .33461 m
.61819 .36643 L
s
.61622 .33474 m
.61658 .36656 L
s
.59727 .38164 m
.60049 .37687 L
s
.60049 .37687 m
.60218 .38361 L
s
.59239 .38421 m
.59727 .38164 L
s
.61175 .36694 m
.61819 .36643 L
s
.61972 .35946 m
.62298 .36374 L
s
.62298 .36374 m
.62621 .36574 L
s
.64478 .3342 m
.64942 .33138 L
s
.64328 .33892 m
.64478 .3342 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64634 .33402 m
.64942 .33138 L
s
.64484 .33875 m
.64634 .33402 L
s
.64328 .33892 m
.64335 .34348 L
s
.62934 .36089 m
.6309 .35845 L
s
.6309 .35845 m
.63252 .36058 L
s
.62934 .36089 m
.63096 .36302 L
s
.62621 .36574 m
.63099 .3653 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6471 .34946 m
.64715 .3526 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64335 .34348 m
.64498 .34786 L
s
.64484 .33875 m
.64491 .3433 L
s
.64942 .33138 m
.65408 .33082 L
s
.63252 .36058 m
.63255 .36287 L
s
.64491 .3433 m
.64655 .34769 L
s
.63099 .3653 m
.63255 .36287 L
s
.65408 .33082 m
.65721 .33271 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64498 .34786 m
.64971 .34962 L
s
.64655 .34769 m
.64971 .34962 L
s
.65721 .33271 m
.66037 .33687 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66915 .31284 m
.67969 .31125 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64512 .357 m
.64515 .35929 L
s
.64512 .357 m
.64669 .35683 L
s
.64669 .35683 m
.64672 .35912 L
s
.64515 .35929 m
.64676 .36141 L
s
.66183 .33211 m
.66486 .32942 L
s
.66037 .33687 m
.66183 .33211 L
s
0 0 0 r
.686 .31856 m
.68681 .31843 L
s
.255 .412 .882 r
.66337 .33191 m
.66486 .32942 L
s
.66191 .33667 m
.66337 .33191 L
s
.66486 .32942 m
.66639 .32921 L
s
.64676 .36141 m
.64992 .36335 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64992 .36335 m
.65615 .36262 L
s
.67519 .31195 m
.6761 .36003 L
s
.66191 .33667 m
.66219 .35269 L
s
.67369 .31217 m
.67458 .36024 L
s
.66037 .33687 m
.66072 .35747 L
s
.64971 .34962 m
.65906 .35079 L
s
.65906 .35079 m
.66064 .35288 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65615 .36262 m
.65922 .35995 L
s
.66072 .35747 m
.66219 .35269 L
s
.65922 .35995 m
.66072 .35747 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67562 .33477 m
.67855 .32975 L
s
.67855 .32975 m
.6815 .327 L
s
.6815 .327 m
.68449 .32653 L
s
.68449 .32653 m
.6875 .32834 L
s
.68449 .32653 m
.68899 .3281 L
s
.67001 .36087 m
.6761 .36003 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67597 .35313 m
.67908 .35729 L
s
.35364 .32994 m
.35517 .32789 L
s
.35374 .32535 m
.35517 .32789 L
s
.35222 .3274 m
.35374 .32535 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68899 .3281 m
.69203 .3322 L
s
.6875 .32834 m
.69056 .33244 L
s
.69056 .33244 m
.69218 .3391 L
s
.67908 .35729 m
.68213 .35916 L
s
.35222 .3274 m
.35364 .32994 L
s
.69203 .3322 m
.69365 .33885 L
s
.68213 .35916 m
.68513 .35871 L
s
.69218 .3391 m
.69227 .3437 L
s
.35341 .34144 m
.35431 .36939 L
s
.35135 .36893 m
.35341 .34144 L
s
.69365 .33885 m
.69375 .34346 L
s
.68513 .35871 m
.68806 .35594 L
s
.68513 .35871 m
.68955 .35571 L
s
.69094 .35086 m
.69227 .3437 L
s
.68806 .35594 m
.69094 .35086 L
s
.69242 .35062 m
.69375 .34346 L
s
.7021 .32352 m
.71213 .32161 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68955 .35571 m
.69242 .35062 L
s
.34058 .32533 m
.34197 .3279 L
s
.34182 .33481 m
.34197 .3279 L
s
.35283 .36916 m
.35312 .35528 L
s
.33776 .32249 m
.34058 .32533 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34038 .33455 m
.34187 .33251 L
s
.33207 .32138 m
.33776 .32249 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34032 .33686 m
.34182 .33481 L
s
.33745 .33632 m
.34038 .33455 L
s
.35273 .3738 m
.35431 .36939 L
s
.3374 .33864 m
.34032 .33686 L
s
.35135 .36893 m
.35273 .3738 L
s
.32919 .32312 m
.33207 .32138 L
s
.34001 .35073 m
.34156 .34636 L
s
.34136 .35562 m
.34156 .34636 L
s
.33022 .33959 m
.33745 .33632 L
s
.33016 .34191 m
.3374 .33864 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33852 .35279 m
.34001 .35073 L
s
.34001 .35073 m
.34136 .35562 L
s
.32773 .32514 m
.32919 .32312 L
s
.70844 .34785 m
.71141 .35195 L
s
.33559 .35458 m
.33852 .35279 L
s
.32644 .32024 m
.32773 .32514 L
s
.32621 .32948 m
.32644 .32024 L
s
.32621 .32948 m
.32773 .32514 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70786 .32244 m
.70897 .37108 L
s
.70643 .32272 m
.70753 .37133 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71778 .32048 m
.72749 .3184 L
s
.5 Mabswid
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72197 .3196 m
.72259 .3451 L
s
.32734 .34135 m
.33022 .33959 L
s
.32989 .35352 m
.33559 .35458 L
s
.70318 .37208 m
.70897 .37108 L
s
.71141 .35195 m
.71573 .35347 L
s
.32728 .34367 m
.33016 .34191 L
s
.72336 .31931 m
.72399 .34482 L
s
.32588 .34339 m
.32734 .34135 L
s
.32582 .34571 m
.32728 .34367 L
s
.32712 .35064 m
.32989 .35352 L
s
.71573 .35347 m
.71856 .35292 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32577 .34804 m
.32588 .34339 L
s
.32577 .34804 m
.32712 .35064 L
s
0 0 0 r
.72834 .34711 m
.72932 .33839 L
s
.255 .412 .882 r
.71856 .35292 m
.72131 .35004 L
s
.71856 .35292 m
.72271 .34976 L
s
.31396 .31985 m
.31657 .3251 L
s
.72131 .35004 m
.72259 .3451 L
s
0 0 0 r
.72809 .34781 m
.72834 .34711 L
s
.255 .412 .882 r
.30996 .31659 m
.31396 .31985 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73058 .33927 m
.73086 .33672 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73295 .31717 m
.74232 .31493 L
s
.72271 .34976 m
.72399 .34482 L
s
.30727 .31596 m
.30996 .31659 L
s
.3161 .3437 m
.31616 .34137 L
s
.31485 .33874 m
.31616 .34137 L
s
.31342 .34077 m
.31485 .33874 L
s
.31324 .34777 m
.3161 .3437 L
s
.30455 .31763 m
.30727 .31596 L
s
.30322 .31731 m
.30727 .31596 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31342 .34077 m
.31473 .3434 L
s
.30177 .32164 m
.30455 .31763 L
s
.31046 .34951 m
.31324 .34777 L
s
.30046 .32131 m
.30322 .31731 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73833 .3159 m
.7392 .34855 L
s
.73699 .31622 m
.73786 .34885 L
s
.7338 .34976 m
.7392 .34855 L
s
.30641 .3486 m
.31046 .34951 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30026 .32831 m
.30177 .32164 L
s
.29895 .32799 m
.30046 .32131 L
s
.30379 .34564 m
.30641 .3486 L
s
.30246 .34533 m
.30641 .3486 L
s
.30014 .33299 m
.30026 .32831 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29882 .33266 m
.29895 .32799 L
s
.30014 .33299 m
.30126 .34033 L
s
.30126 .34033 m
.30379 .34564 L
s
.74907 .32026 m
.75152 .31492 L
s
.74796 .3276 m
.74907 .32026 L
s
.28525 .3102 m
.29414 .31264 L
s
.73688 .36322 m
.73817 .36057 L
s
.74796 .3276 m
.74809 .33228 L
s
.29994 .34001 m
.30246 .34533 L
s
.29882 .33266 m
.29994 .34001 L
s
.75152 .31492 m
.7553 .31155 L
s
.75036 .31993 m
.75281 .31458 L
s
.74926 .32727 m
.75036 .31993 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73817 .36057 m
.73958 .36262 L
s
.73688 .36322 m
.73829 .36527 L
s
.74926 .32727 m
.74939 .33195 L
s
.73829 .36527 m
.73958 .36262 L
s
.75281 .31458 m
.7553 .31155 L
s
.74809 .33228 m
.74959 .33898 L
s
.74939 .33195 m
.75089 .33866 L
s
.28936 .34444 m
.2903 .31161 L
s
.7553 .31155 m
.75783 .31085 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28808 .3441 m
.28903 .31126 L
s
.74959 .33898 m
.75232 .34302 L
s
.75783 .31085 m
.76166 .31212 L
s
.75089 .33866 m
.75361 .34269 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75232 .34302 m
.75624 .34438 L
s
.75361 .34269 m
.75624 .34438 L
s
.76166 .31212 m
.76429 .31609 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28428 .34309 m
.28936 .34444 L
s
.2718 .30615 m
.28028 .30875 L
s
.75624 .34438 m
.76005 .34337 L
s
.76229 .33326 m
.76346 .33056 L
s
.76229 .33326 m
.7636 .33527 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76005 .34337 m
.7625 .34033 L
s
.27583 .33356 m
.27661 .30765 L
s
.76346 .33056 m
.76478 .33256 L
s
.2876 .36063 m
.28895 .35859 L
s
.28774 .3559 m
.28895 .35859 L
s
.2864 .35793 m
.28774 .3559 L
s
.27461 .3332 m
.2754 .30728 L
s
.7625 .34033 m
.76485 .33492 L
s
.2864 .35793 m
.2876 .36063 L
s
.76478 .33256 m
.76485 .33492 L
s
.77259 .30646 m
.77393 .31079 L
s
.77259 .30646 m
.77288 .31588 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77288 .31588 m
.77393 .31079 L
s
.77393 .31079 m
.77504 .30806 L
s
.77504 .30806 m
.77733 .30494 L
s
.27447 .33793 m
.27583 .33356 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76855 .35876 m
.76885 .36062 L
s
.5 Mabswid
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27326 .33757 m
.27461 .3332 L
s
.77733 .30494 m
.78197 .30338 L
s
.27078 .33922 m
.27447 .33793 L
s
.25905 .30186 m
.26708 .30462 L
s
.77332 .33005 m
.77444 .32732 L
s
.77332 .33005 m
.77346 .33478 L
s
.27078 .33922 m
.27326 .33757 L
s
.77444 .32732 m
.77674 .32421 L
s
.77339 .33242 m
.77451 .32968 L
s
.77451 .32968 m
.77682 .32658 L
s
.77346 .33478 m
.77473 .33679 L
s
.77674 .32421 m
.78243 .31757 L
s
.77682 .32658 m
.7825 .31994 L
s
.77473 .33679 m
.77719 .33843 L
s
.26201 .35333 m
.2636 .30345 L
s
.78197 .30338 m
.78434 .30496 L
s
.26839 .33849 m
.27078 .33922 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26085 .35297 m
.26245 .30305 L
s
.26494 .33501 m
.26839 .33849 L
s
.77719 .33843 m
.78188 .33695 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78434 .30496 m
.78555 .30693 L
s
.78243 .31757 m
.78464 .31443 L
s
.7825 .31994 m
.78472 .3168 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78555 .30693 m
.78578 .31404 L
s
.26277 .3295 m
.26494 .33501 L
s
.78464 .31443 m
.7857 .31166 L
s
.78472 .3168 m
.78578 .31404 L
s
.78188 .33695 m
.78411 .33382 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78411 .33382 m
.78518 .33106 L
s
.78518 .33106 m
.78617 .32591 L
s
.78617 .32591 m
.78648 .33544 L
s
.78518 .33106 m
.78648 .33544 L
s
.79325 .30173 m
.79425 .29894 L
s
.79325 .30173 m
.79441 .30369 L
s
.25742 .35185 m
.26201 .35333 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79425 .29894 m
.79541 .3009 L
s
.79441 .30369 m
.79541 .3009 L
s
.24908 .30055 m
.25108 .30614 L
s
.25108 .30614 m
.25192 .31369 L
s
.25176 .31845 m
.25192 .31369 L
s
.24801 .30014 m
.24999 .30573 L
s
.24598 .29691 m
.24908 .30055 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24999 .30573 m
.25084 .31328 L
s
.25044 .32521 m
.25176 .31845 L
s
.25068 .31805 m
.25084 .31328 L
s
.24598 .29691 m
.24801 .30014 L
s
.79481 .3156 m
.79686 .34392 L
s
.79468 .3447 m
.79481 .3156 L
s
.24935 .32481 m
.25068 .31805 L
s
.23641 .27586 m
.24344 .27897 L
s
.24389 .29606 m
.24598 .29691 L
s
.24811 .3292 m
.25044 .32521 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24704 .3288 m
.24935 .32481 L
s
.79529 .32993 m
.79577 .34432 L
s
.24175 .29759 m
.24389 .29606 L
s
.23862 .32792 m
.24038 .27765 L
s
.24484 .33039 m
.24811 .3292 L
s
.79468 .3447 m
.79594 .34912 L
s
.23761 .32751 m
.23938 .2772 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24484 .33039 m
.24704 .3288 L
s
.23955 .30151 m
.24175 .29759 L
s
.79594 .34912 m
.79686 .34392 L
s
.24274 .32957 m
.24484 .33039 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24075 .32635 m
.24274 .32957 L
s
.23888 .3207 m
.24075 .32635 L
s
.2329 .29125 m
.23386 .2917 L
s
.23462 .32625 m
.23862 .32792 L
s
.2309 .29276 m
.2329 .29125 L
s
.23185 .2932 m
.2329 .29125 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23073 .29756 m
.23185 .2932 L
s
.22978 .29712 m
.2309 .29276 L
s
.23012 .31444 m
.23073 .29756 L
s
.22809 .2914 m
.22978 .29712 L
s
.229 .31884 m
.22978 .29712 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22634 .28808 m
.22809 .2914 L
s
.229 .31884 m
.23012 .31444 L
s
.22364 .28669 m
.22634 .28808 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22832 .31114 m
.22917 .314 L
s
.22292 .30604 m
.22832 .31114 L
s
.22797 .32082 m
.229 .31884 L
s
.22179 .28818 m
.22364 .28669 L
s
.22092 .28771 m
.22364 .28669 L
s
.22602 .32238 m
.22797 .32082 L
s
0 0 0 r
.22051 .31649 m
.22143 .30945 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22239 .32061 m
.22602 .32238 L
s
.22074 .29255 m
.22179 .28818 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22043 .30964 m
.2206 .30833 L
s
.5 Mabswid
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21987 .29208 m
.22092 .28771 L
s
.22125 .3027 m
.22292 .30604 L
s
.22037 .30225 m
.22292 .30604 L
s
.22056 .29739 m
.22074 .29255 L
s
.22056 .29739 m
.22125 .3027 L
s
.21969 .29693 m
.21987 .29208 L
s
.21969 .29693 m
.22037 .30225 L
s
.2207 .31728 m
.22239 .32061 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82658 .28408 m
.83466 .27927 L
s
.22001 .31197 m
.22088 .31242 L
s
.22079 .31485 m
.22088 .31242 L
s
.21992 .3144 m
.2207 .31728 L
s
.21992 .3144 m
.22001 .31197 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82908 .28266 m
.83103 .3339 L
s
.83466 .27927 m
.83627 .28073 L
s
.83466 .27927 m
.83702 .28023 L
s
.21249 .30782 m
.2132 .31073 L
s
.21311 .31318 m
.2132 .31073 L
s
.21221 .31517 m
.21311 .31318 L
s
.2116 .3098 m
.21249 .30782 L
s
.20453 .27508 m
.20963 .27856 L
s
.2116 .3098 m
.2123 .31272 L
s
.83627 .28073 m
.83795 .28463 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8285 .33524 m
.83665 .33074 L
s
.8299 .28218 m
.83185 .33346 L
s
.20984 .31377 m
.21221 .31517 L
s
.83702 .28023 m
.83869 .28414 L
s
.20606 .31142 m
.2074 .27708 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83795 .28463 m
.83888 .28904 L
s
.20532 .31094 m
.20667 .27658 L
s
.2084 .31038 m
.20984 .31377 L
s
.83869 .28414 m
.8396 .28855 L
s
.20708 .30451 m
.2084 .31038 L
s
.83888 .28904 m
.83989 .29591 L
s
.20663 .29667 m
.20708 .30451 L
s
.8396 .28855 m
.84061 .29542 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83665 .33074 m
.83809 .32735 L
s
.83665 .33074 m
.83884 .32689 L
s
.83989 .29591 m
.84038 .30821 L
s
.84061 .29542 m
.8411 .30773 L
s
.20317 .30951 m
.20606 .31142 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83809 .32735 m
.83939 .32148 L
s
.84262 .27379 m
.84716 .27022 L
s
.83994 .31608 m
.84038 .30821 L
s
.83884 .32689 m
.84013 .32102 L
s
.83939 .32148 m
.83994 .31608 L
s
.84067 .31561 m
.8411 .30773 L
s
.84013 .32102 m
.84067 .31561 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84462 .27227 m
.846 .30681 L
s
.1997 .29175 m
.20048 .27205 L
s
.84527 .27176 m
.84665 .30632 L
s
.19905 .29126 m
.19984 .27153 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19716 .28975 m
.20169 .29324 L
s
.19848 .27297 m
.19954 .27892 L
s
.84399 .30827 m
.84665 .30632 L
s
.19674 .26896 m
.19848 .27297 L
s
.84606 .29147 m
.847 .2984 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19557 .26792 m
.19674 .26896 L
s
.847 .2984 m
.84846 .30237 L
s
.19841 .32399 m
.199 .30908 L
s
.19806 .31604 m
.199 .30908 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19432 .26935 m
.19557 .26792 L
s
.19377 .26882 m
.19557 .26792 L
s
.19658 .32006 m
.19806 .31604 L
s
.19806 .31604 m
.19841 .32399 L
s
.84846 .30237 m
.84978 .30386 L
s
.19302 .27326 m
.19432 .26935 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19247 .27274 m
.19377 .26882 L
s
.84978 .30386 m
.85156 .30237 L
s
.19464 .3211 m
.19658 .32006 L
s
.85077 .29789 m
.85146 .29988 L
s
.85077 .29789 m
.85125 .2949 L
s
.19227 .27771 m
.19302 .27326 L
s
.85125 .2949 m
.85193 .29688 L
s
.19174 .27718 m
.19247 .27274 L
s
.85156 .30237 m
.85203 .29938 L
s
.85193 .29688 m
.85203 .29938 L
s
.19345 .32013 m
.19464 .3211 L
s
.19143 .28465 m
.19227 .27771 L
s
.19091 .28414 m
.19174 .27718 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1924 .31665 m
.19345 .32013 L
s
.19184 .31615 m
.19345 .32013 L
s
.19092 .29713 m
.19143 .28465 L
s
.85476 .27087 m
.85506 .26536 L
s
.85476 .27087 m
.85497 .27585 L
s
.85506 .26536 m
.85639 .26127 L
s
.1904 .29663 m
.19091 .28414 L
s
.19149 .31065 m
.1924 .31665 L
s
.85497 .27585 m
.85567 .28031 L
s
.85526 .27034 m
.85555 .26483 L
s
.85526 .27034 m
.85547 .27532 L
s
.85555 .26483 m
.85639 .26127 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19092 .29713 m
.19115 .30514 L
s
.19094 .31015 m
.19184 .31615 L
s
0 0 0 r
.18321 .2491 m
.18458 .2508 L
s
.255 .412 .882 r
.85547 .27532 m
.85617 .27979 L
s
.19115 .30514 m
.19149 .31065 L
s
.85567 .28031 m
.85722 .28124 L
s
.85639 .26127 m
.85775 .25966 L
s
.1904 .29663 m
.19061 .30464 L
s
.19061 .30464 m
.19094 .31015 L
s
.85617 .27979 m
.85722 .28124 L
s
.85609 .29031 m
.85619 .29281 L
s
.85609 .29031 m
.85658 .28979 L
s
.85619 .29281 m
.85679 .29481 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85658 .28979 m
.85668 .2923 L
s
.85775 .25966 m
.85871 .26107 L
s
.85722 .28124 m
.85997 .2806 L
s
.85679 .29481 m
.85785 .29629 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18555 .294 m
.18829 .29709 L
s
.85871 .26107 m
.85974 .265 L
s
.1866 .25834 m
.18688 .29555 L
s
.18353 .2914 m
.1866 .25834 L
s
.85785 .29629 m
.85965 .29423 L
s
.18392 .29192 m
.18628 .26584 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85974 .265 m
.85993 .25945 L
s
.85974 .265 m
.86069 .28762 L
s
.85993 .25945 m
.86059 .25585 L
s
0 0 0 r
.18136 .32607 m
.18142 .32613 L
s
.255 .412 .882 r
.86014 .26446 m
.86032 .2589 L
s
.86014 .26446 m
.86088 .28206 L
s
.86032 .2589 m
.86059 .25585 L
s
.85997 .2806 m
.86048 .28259 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18136 .32607 m
.1819 .31324 L
s
.18327 .28067 m
.18328 .28045 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85965 .29423 m
.86039 .29067 L
s
.86059 .25585 m
.86096 .2553 L
s
.86039 .29067 m
.86069 .28762 L
s
.86069 .28762 m
.86088 .28206 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18353 .2914 m
.18358 .25396 L
s
.1808 .28718 m
.18358 .25396 L
s
.18111 .28771 m
.18326 .26151 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86315 .28953 m
.86533 .28582 L
s
.17994 .28558 m
.18209 .2893 L
s
.86382 .25033 m
.86636 .28368 L
s
.86382 .25033 m
.86414 .28794 L
s
.86414 .25791 m
.86445 .28741 L
s
.18068 .24841 m
.18093 .24897 L
s
.18011 .24982 m
.18068 .24841 L
s
.18034 .25038 m
.18068 .24841 L
s
0 0 0 r
.86925 .24023 m
.86928 .24051 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1799 .2549 m
.18034 .25038 L
s
0 0 0 r
.86928 .2409 m
.86928 .24051 L
s
.255 .412 .882 r
.17968 .25434 m
.18011 .24982 L
s
.17914 .2727 m
.1799 .2549 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1795 .24814 m
.17968 .25434 L
s
.1787 .27726 m
.17968 .25434 L
s
.8657 .24585 m
.86636 .28368 L
s
0 0 0 r
.87192 .30209 m
.87211 .30613 L
s
.255 .412 .882 r
.17924 .24447 m
.1795 .24814 L
s
.86602 .25347 m
.86659 .28314 L
s
.1787 .27726 m
.17914 .2727 L
s
.17878 .24278 m
.17924 .24447 L
s
.17882 .26906 m
.17892 .27216 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17791 .2632 m
.17882 .26906 L
s
.17839 .27928 m
.1787 .27726 L
s
.17789 .28076 m
.17839 .27928 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87069 .24012 m
.87067 .2359 L
s
.87117 .25104 m
.87069 .24012 L
s
.255 .412 .882 r
.17842 .24419 m
.17878 .24278 L
s
.1783 .24363 m
.17878 .24278 L
s
0 0 0 r
.87067 .2359 m
.87076 .23111 L
s
.8713 .25047 m
.87101 .2474 L
s
.255 .412 .882 r
.86741 .28099 m
.86835 .27774 L
s
0 0 0 r
.87146 .25412 m
.87117 .25104 L
s
.87076 .23111 m
.87112 .22877 L
s
.255 .412 .882 r
.17725 .27859 m
.17789 .28076 L
s
.17808 .24874 m
.17842 .24419 L
s
0 0 0 r
.87171 .25299 m
.8713 .25047 L
s
.87211 .30613 m
.87212 .30686 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8657 .24585 m
.86793 .27937 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87187 .25665 m
.87146 .25412 L
s
.255 .412 .882 r
.17776 .25953 m
.17791 .2632 L
s
.17764 .25898 m
.17791 .2632 L
s
.17798 .24817 m
.1783 .24363 L
s
.17786 .25385 m
.17808 .24874 L
s
0 0 0 r
.87196 .26931 m
.87241 .2761 L
s
.87259 .28399 m
.87196 .26931 L
s
.255 .412 .882 r
.17776 .25953 m
.17786 .25385 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87246 .25749 m
.87171 .25299 L
s
.255 .412 .882 r
.17776 .25329 m
.17798 .24817 L
s
0 0 0 r
.87112 .22877 m
.87139 .23125 L
s
.87262 .26117 m
.87187 .25665 L
s
.255 .412 .882 r
.1771 .27493 m
.17725 .27859 L
s
.17764 .25898 m
.17776 .25329 L
s
.1772 .26924 m
.17732 .26979 L
s
.17721 .27236 m
.17732 .26979 L
s
0 0 0 r
.87241 .2761 m
.8727 .27922 L
s
.87241 .2761 m
.87259 .28399 L
s
.255 .412 .882 r
.17709 .27181 m
.1771 .27493 L
s
.17709 .27181 m
.1772 .26924 L
s
0 0 0 r
.87139 .23125 m
.8716 .23433 L
s
.8727 .27922 m
.87309 .28181 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86769 .24616 m
.86784 .25185 L
s
.86784 .25185 m
.8681 .26012 L
s
.86757 .23989 m
.86769 .24616 L
s
.8681 .26012 m
.86865 .27299 L
s
0 0 0 r
.87131 .22643 m
.8716 .23433 L
s
.87195 .24108 m
.87131 .22643 L
s
.255 .412 .882 r
.86775 .24559 m
.86791 .25129 L
s
.86791 .25129 m
.86817 .25956 L
s
.8676 .23932 m
.86775 .24559 L
s
0 0 0 r
.8716 .23433 m
.87195 .24108 L
s
.255 .412 .882 r
.86817 .25956 m
.86873 .27244 L
s
.86753 .23561 m
.86757 .23989 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86753 .23561 m
.8676 .23932 L
s
.86865 .27299 m
.86906 .28018 L
s
0 0 0 r
.87271 .26004 m
.87246 .25749 L
s
.87287 .26373 m
.87262 .26117 L
s
.255 .412 .882 r
.86752 .23446 m
.86753 .23561 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87309 .28181 m
.87342 .27961 L
s
.5 Mabswid
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86906 .28018 m
.86935 .28482 L
s
.86873 .27244 m
.86913 .27964 L
s
0 0 0 r
.87291 .26317 m
.87271 .26004 L
s
.255 .412 .882 r
.86913 .27964 m
.86941 .28428 L
s
.86752 .23446 m
.86755 .23531 L
s
0 0 0 r
.87111 .22113 m
.87131 .22349 L
s
.87307 .26686 m
.87287 .26373 L
s
.87342 .27961 m
.87336 .27481 L
s
.255 .412 .882 r
.86935 .28482 m
.86968 .28893 L
s
0 0 0 r
.87323 .27056 m
.87291 .26317 L
s
.255 .412 .882 r
.17655 .26741 m
.17665 .26427 L
s
.17644 .27 m
.17655 .26741 L
s
.86941 .28428 m
.86971 .28839 L
s
.17631 .27204 m
.17644 .27 L
s
0 0 0 r
.87336 .27481 m
.87323 .27056 L
s
.255 .412 .882 r
.17653 .26631 m
.17665 .26427 L
s
.17793 .23306 m
.17847 .22902 L
s
.17653 .26631 m
.17642 .26945 L
s
0 0 0 r
.87118 .22172 m
.87343 .27353 L
s
.255 .412 .882 r
.86755 .23531 m
.86765 .23933 L
s
.17632 .27039 m
.17631 .27204 L
s
.86968 .28893 m
.86986 .28991 L
s
0 0 0 r
.87111 .22113 m
.87337 .27298 L
s
.255 .412 .882 r
.86971 .28839 m
.86986 .28991 L
s
.86732 .23158 m
.86821 .25228 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86786 .25003 m
.86836 .25397 L
s
.17654 .26764 m
.1781 .23133 L
s
.86725 .23101 m
.86814 .25172 L
s
0 0 0 r
.87111 .22363 m
.8716 .23218 L
s
.255 .412 .882 r
.17661 .26708 m
.17817 .23075 L
s
.17648 .26669 m
.17632 .27039 L
s
0 0 0 r
.87062 .21817 m
.87111 .22363 L
s
.255 .412 .882 r
.86986 .28884 m
.86986 .28991 L
s
.17648 .26669 m
.17681 .26039 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17681 .26039 m
.17721 .25204 L
s
.86966 .28461 m
.86986 .28884 L
s
0 0 0 r
.87035 .21699 m
.87062 .21817 L
s
.8702 .2195 m
.87035 .21699 L
s
.87002 .21891 m
.87035 .21699 L
s
.255 .412 .882 r
.17691 .26543 m
.17654 .26764 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86933 .27831 m
.86966 .28461 L
s
0 0 0 r
.87311 .27131 m
.87343 .27353 L
s
.255 .412 .882 r
.86892 .26993 m
.86959 .28561 L
s
.86892 .26993 m
.86933 .27831 L
s
.86933 .27831 m
.86959 .28561 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8702 .2195 m
.87034 .22634 L
s
.87002 .21891 m
.87016 .22575 L
s
.87034 .22634 m
.87212 .26742 L
s
.255 .412 .882 r
.17813 .24753 m
.17825 .24551 L
s
.17757 .26059 m
.17813 .24753 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8665 .23853 m
.86749 .26179 L
s
.86669 .23933 m
.86767 .26235 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87016 .22575 m
.87194 .26686 L
s
.255 .412 .882 r
.17829 .24696 m
.17839 .24526 L
s
.86749 .26179 m
.86815 .26401 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17803 .25311 m
.17829 .24696 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86682 .24608 m
.86696 .25337 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86624 .2069 m
.86806 .21046 L
s
.87131 .26519 m
.87212 .26742 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86543 .25516 m
.8672 .20868 L
s
.86585 .25571 m
.8675 .20927 L
s
.8685 .25961 m
.87032 .26295 L
s
.86229 .20098 m
.86479 .20453 L
s
.86317 .20216 m
.86976 .26184 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85715 .21757 m
.85722 .21718 L
s
0 0 0 r
.86454 .25405 m
.86706 .25738 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85644 .2117 m
.85715 .21757 L
s
.85593 .21112 m
.85666 .217 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85718 .22946 m
.85743 .23562 L
s
.8577 .2307 m
.85815 .24151 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85793 .23618 m
.858 .23579 L
s
0 0 0 r
.85985 .2088 m
.86085 .22076 L
s
.85847 .20006 m
.85985 .2088 L
s
.85662 .19451 m
.85847 .20006 L
s
.86085 .22076 m
.86117 .22837 L
s
.85932 .20822 m
.86033 .22019 L
s
.85792 .19947 m
.85932 .20822 L
s
.255 .412 .882 r
.85815 .24151 m
.85826 .24211 L
s
0 0 0 r
.85662 .19451 m
.85792 .19947 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85743 .23562 m
.85815 .24151 L
s
0 0 0 r
.86033 .22019 m
.86065 .2278 L
s
.86113 .23925 m
.86117 .22837 L
s
.85544 .19334 m
.85662 .19451 L
s
.86061 .23868 m
.86065 .2278 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85375 .1954 m
.85544 .19334 L
s
.85438 .19598 m
.85544 .19334 L
s
.86039 .24578 m
.86113 .23925 L
s
.85984 .24523 m
.86061 .23868 L
s
.85342 .20245 m
.85438 .19598 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85277 .20188 m
.85375 .1954 L
s
.85324 .21335 m
.85342 .20245 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85886 .24796 m
.85984 .24523 L
s
.85886 .24796 m
.86039 .24578 L
s
.85257 .21279 m
.85277 .20188 L
s
.85767 .24686 m
.85886 .24796 L
s
.85324 .21335 m
.85356 .22102 L
s
.85628 .24191 m
.85767 .24686 L
s
.85565 .24136 m
.85767 .24686 L
s
.85257 .21279 m
.85289 .22046 L
s
.85356 .22102 m
.85469 .23311 L
s
.85469 .23311 m
.85628 .24191 L
s
.84512 .18466 m
.84813 .18696 L
s
.85289 .22046 m
.85403 .23256 L
s
.85403 .23256 m
.85565 .24136 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84589 .18524 m
.84919 .26652 L
s
.84512 .18466 m
.84841 .266 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84371 .18736 m
.84559 .19618 L
s
.84193 .18238 m
.84371 .18736 L
s
.84027 .18125 m
.84193 .18238 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83871 .18397 m
.84027 .18125 L
s
.83784 .18341 m
.84027 .18125 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84557 .23374 m
.84684 .22706 L
s
.83726 .19059 m
.83871 .18397 L
s
.83636 .19003 m
.83784 .18341 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8441 .23656 m
.84557 .23374 L
s
.84602 .26444 m
.84919 .26652 L
s
.84243 .23549 m
.8441 .23656 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83616 .21267 m
.83623 .21445 L
s
.83755 .24816 m
.83757 .2487 L
s
.83705 .21413 m
.83708 .21488 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83682 .20166 m
.83726 .19059 L
s
.83591 .20112 m
.83636 .19003 L
s
.255 .412 .882 r
.83757 .2487 m
.83807 .249 L
s
0 0 0 r
.83682 .20166 m
.83712 .20944 L
s
.84056 .23053 m
.84243 .23549 L
s
.83968 .23 m
.84243 .23549 L
s
.83591 .20112 m
.83621 .2089 L
s
.83712 .20944 m
.83848 .22166 L
s
.82632 .1729 m
.83029 .1751 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83848 .22166 m
.84056 .23053 L
s
.83621 .2089 m
.83758 .22113 L
s
.83758 .22113 m
.83968 .23 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82733 .17345 m
.82943 .22816 L
s
.82632 .1729 m
.82841 .22764 L
s
.82442 .1757 m
.82677 .18457 L
s
.82111 .17019 m
.82442 .1757 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81894 .16911 m
.82111 .17019 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81687 .17195 m
.81894 .16911 L
s
.81575 .17142 m
.81894 .16911 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8253 .22611 m
.82943 .22816 L
s
.81604 .17925 m
.81687 .17195 L
s
.81491 .17872 m
.81575 .17142 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22915 .16781 m
.23607 .16465 L
s
.255 .412 .882 r
.23444 .20158 m
.23565 .20225 L
s
0 0 0 r
.81604 .17925 m
.81764 .22258 L
s
.81491 .17872 m
.8165 .22208 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23287 .18925 m
.24383 .18472 L
s
.255 .412 .882 r
.80543 .19678 m
.80547 .19772 L
s
0 0 0 r
.81301 .22059 m
.81764 .22258 L
s
.2434 .16156 m
.25111 .15854 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80528 .19932 m
.80547 .19772 L
s
.80648 .19973 m
.80664 .1983 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80254 .16178 m
.80462 .18593 L
s
.78261 .15436 m
.80378 .16229 L
s
.80378 .16229 m
.80462 .18593 L
s
.2547 .13001 m
.2643 .12651 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23141 .16675 m
.23672 .24638 L
s
.23672 .24638 m
.2485 .15954 L
s
.23715 .23437 m
.24721 .16004 L
s
.25597 .21182 m
.25875 .1285 L
s
.25736 .21137 m
.26012 .128 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79711 .18694 m
.79821 .21881 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78962 .20002 m
.79766 .20284 L
s
.25881 .16748 m
.26186 .15859 L
s
.26186 .15859 m
.26481 .15367 L
s
.26481 .15367 m
.26768 .15273 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78679 .15581 m
.78958 .23974 L
s
.80588 .22165 m
.80673 .24565 L
s
.80547 .24518 m
.80588 .22165 L
s
.78816 .15629 m
.79096 .24018 L
s
.78536 .23843 m
.80673 .24565 L
s
.26768 .15273 m
.27046 .15577 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26768 .15273 m
.27192 .15531 L
s
.25188 .2132 m
.25736 .21137 L
s
.27046 .15577 m
.27315 .16281 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25775 .19935 m
.26029 .20645 L
s
.27192 .15531 m
.27464 .16236 L
s
.27315 .16281 m
.27427 .17435 L
s
.27464 .16236 m
.27577 .1739 L
s
.26029 .20645 m
.263 .20956 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27402 .18236 m
.27427 .17435 L
s
.263 .20956 m
.26588 .20867 L
s
.27552 .18192 m
.27577 .1739 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27215 .19484 m
.27402 .18236 L
s
.26588 .20867 m
.26893 .20377 L
s
.26588 .20867 m
.27041 .20333 L
s
.27364 .19441 m
.27552 .18192 L
s
.26893 .20377 m
.27215 .19484 L
s
.27041 .20333 m
.27364 .19441 L
s
.2885 .15839 m
.29192 .14953 L
s
.28656 .17086 m
.2885 .15839 L
s
.29192 .14953 m
.29687 .14426 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29352 .1491 m
.29687 .14426 L
s
.29009 .15797 m
.29352 .1491 L
s
.28814 .17043 m
.29009 .15797 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29687 .14426 m
.30015 .14342 L
s
.28632 .1789 m
.28656 .17086 L
s
.28791 .17848 m
.28814 .17043 L
s
.30015 .14342 m
.30335 .14661 L
s
.30015 .14342 m
.30502 .1462 L
s
.28632 .1789 m
.28755 .19058 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28791 .17848 m
.28914 .19016 L
s
.30335 .14661 m
.30648 .15384 L
s
.30502 .1462 m
.30817 .15345 L
s
.28755 .19058 m
.29051 .19785 L
s
.28914 .19016 m
.29213 .19744 L
s
.30648 .15384 m
.30784 .16555 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30817 .15345 m
.30954 .16516 L
s
.29051 .19785 m
.29527 .2007 L
s
.29213 .19744 m
.29527 .2007 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3188 .13904 m
.33121 .13644 L
s
.30762 .17363 m
.30784 .16555 L
s
.30933 .17325 m
.30954 .16516 L
s
.29527 .2007 m
.29856 .19991 L
s
.3056 .18618 m
.30762 .17363 L
s
.30729 .1858 m
.30933 .17325 L
s
.29856 .19991 m
.30201 .19507 L
s
.29856 .19991 m
.30369 .19469 L
s
.30201 .19507 m
.3056 .18618 L
s
.30369 .19469 m
.30729 .1858 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33848 .13503 m
.35151 .13268 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32193 .22344 m
.32407 .1379 L
s
.32372 .2231 m
.32584 .13753 L
s
.34208 .21989 m
.34402 .134 L
s
.34396 .21958 m
.34588 .13367 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36675 .13427 m
.37268 .12934 L
s
.36271 .143 m
.36675 .13427 L
s
.3166 .22447 m
.32372 .2231 L
s
.36869 .13398 m
.37268 .12934 L
s
.36464 .1427 m
.36869 .13398 L
s
.36053 .15553 m
.36271 .143 L
s
.37268 .12934 m
.37662 .12878 L
s
.36246 .15524 m
.36464 .1427 L
s
.37662 .12878 m
.38051 .1323 L
s
.37662 .12878 m
.3825 .13204 L
s
.36036 .16371 m
.36053 .15553 L
s
.3623 .16341 m
.36246 .15524 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38051 .1323 m
.38436 .13993 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36036 .16371 m
.36205 .17571 L
s
.255 .412 .882 r
.3692 .16822 m
.37236 .16702 L
s
.36854 .16927 m
.3692 .16822 L
s
0 0 0 r
.3825 .13204 m
.38636 .13968 L
s
.3623 .16341 m
.36399 .17542 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38436 .13993 m
.38615 .15195 L
s
.38636 .13968 m
.38817 .1517 L
s
.39871 .12596 m
.41312 .1244 L
s
.36205 .17571 m
.36578 .18336 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33649 .22082 m
.34396 .21958 L
s
.36399 .17542 m
.36774 .18309 L
s
.404 .18283 m
.40485 .12527 L
s
.40607 .18262 m
.40691 .12504 L
s
.38601 .16016 m
.38615 .15195 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38803 .15991 m
.38817 .1517 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36578 .18336 m
.3716 .18666 L
s
.36774 .18309 m
.3716 .18666 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38379 .17275 m
.38601 .16016 L
s
.42146 .1236 m
.43622 .12234 L
s
.3858 .1725 m
.38803 .15991 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3716 .18666 m
.37556 .18614 L
s
.37963 .1815 m
.38379 .17275 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38163 .18124 m
.3858 .1725 L
s
.37556 .18614 m
.37963 .1815 L
s
.37556 .18614 m
.38163 .18124 L
s
.44474 .12171 m
.45978 .12077 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40625 .17021 m
.41029 .17807 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42721 .1683 m
.42776 .12303 L
s
.42933 .16813 m
.42987 .12286 L
s
.45064 .17908 m
.45116 .12129 L
s
.45281 .17896 m
.45331 .12115 L
s
.47929 .12396 m
.48368 .1197 L
s
.48368 .1197 m
.48805 .11956 L
s
.47711 .12405 m
.48368 .1197 L
s
.56048 .11966 m
.56269 .12384 L
s
.55832 .12369 m
.56048 .11966 L
s
.39781 .18348 m
.40607 .18262 L
s
.48805 .11956 m
.4946 .12348 L
s
.47488 .13236 m
.47711 .12405 L
s
.47706 .13227 m
.47929 .12396 L
s
.499 .11928 m
.50778 .11913 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56052 .12788 m
.56269 .12384 L
s
.55832 .12369 m
.56052 .12788 L
s
.53637 .11911 m
.52757 .11904 L
s
.53637 .11911 m
.54077 .12328 L
s
.52318 .12314 m
.52757 .11904 L
s
.51878 .11904 m
.52097 .12726 L
s
.51877 .1355 m
.51878 .11904 L
s
.4946 .12348 m
.49896 .13162 L
s
.54077 .12328 m
.54298 .12743 L
s
.41029 .17807 m
.41651 .18163 L
s
.47461 .1779 m
.47488 .13236 L
s
.255 .412 .882 r
.54168 .15732 m
.54169 .16082 L
s
0 0 0 r
.52097 .12726 m
.52318 .12314 L
s
.4768 .17782 m
.47706 .13227 L
s
.54298 .12743 m
.54301 .1398 L
s
.51877 .1355 m
.52097 .12726 L
s
.425 .17676 m
.42721 .1683 L
s
.42711 .17658 m
.42933 .16813 L
s
.41651 .18163 m
.42072 .18126 L
s
.255 .412 .882 r
.54604 .158 m
.5496 .1573 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54081 .13976 m
.543 .13567 L
s
.42072 .18126 m
.425 .17676 L
s
.42072 .18126 m
.42711 .17658 L
s
.54082 .1439 m
.54301 .1398 L
s
.53641 .14384 m
.54081 .13976 L
s
.255 .412 .882 r
.54387 .16086 m
.54604 .158 L
s
.56342 .16588 m
.56343 .16717 L
s
0 0 0 r
.53642 .14797 m
.54082 .1439 L
s
.52539 .15204 m
.53641 .14384 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49213 .1601 m
.4927 .15747 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49883 .17719 m
.499 .11928 L
s
.50104 .17715 m
.5012 .11923 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52539 .15618 m
.53642 .14797 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52097 .15618 m
.52539 .15204 L
s
.44417 .17949 m
.45281 .17896 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52097 .16033 m
.52539 .15618 L
s
.51876 .16033 m
.52097 .15618 L
s
.54088 .16877 m
.54306 .1605 L
s
.54306 .1605 m
.54311 .17713 L
s
.51875 .16864 m
.51876 .16033 L
s
.51875 .16448 m
.52097 .16033 L
s
.46804 .17818 m
.4768 .17782 L
s
.53867 .1729 m
.54088 .16877 L
s
.54088 .16877 m
.54311 .17713 L
s
.51875 .16864 m
.52096 .1728 L
s
.53426 .17702 m
.53867 .1729 L
s
.52096 .1728 m
.5254 .17697 L
s
.4922 .17734 m
.50104 .17715 L
s
.5254 .17697 m
.53426 .17702 L
s
.45045 .19993 m
.45259 .20399 L
s
.44825 .20424 m
.45045 .19993 L
s
.44825 .20424 m
.45038 .2083 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45038 .2083 m
.45259 .20399 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56074 .17339 m
.56086 .19843 L
s
.55865 .19837 m
.56062 .1485 L
s
.56062 .1485 m
.56307 .1985 L
s
.5609 .20682 m
.56307 .1985 L
s
.55865 .19837 m
.5609 .20682 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000`3o
YQ05000000@0ojH@00<000000?nV403oYQ000P3oYQ05000000H0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ402@3oYQ45000000H0ojHA1@2][Jd3000000D0[Jf]0P0000070:f][@050000002][Jd0
[Jf]0:f][@0000001@2][Jd00`000000[Jf]0:f][@080:f][@030000002][Jd0[Jf]00P0[Jf]3`3o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA1@000003
0?nV4@H000002@2][Jd30?nV4@8000000P3oYQ400`2][Jd00000000000030?nV408000001`3oYQ00
10000000ojH@0?nV400000070?nV40030000003oYQ00ojH@0080ojH@00@0[Jf]0?nU403oYA00ojD@
0P00000:0?nU41@0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@D000000P3o
YQ400`2][Jd0000000000003000000H0[Jf]103oYQ42000000/0ojHA0P0000030?nV4@040:f][@3o
YQ00ojH@00000080ojH@0P0000070?nV40<00000203oYQ000`000000ojH@0?nV40020?nV40070:f]
[@3oYA00ojD@0?nU40000000ojD@0000000H0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@L0o:0@0P0000030?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@D000001@2][Jd40?nV4@80
00002P3oYQ42000000X0ojHA00<000000?nV4@0000000`3oYQ40102][Jd0ojH@0?nV400000020?nV
408000001`3oYQ02000000X0ojH@00D000000?nV403oYQ00ojH@0:f][@030?nU408000006@3oYA00
0`2][Jd0oj<@0?nS400;0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3oool007L0/>3V0`2][Jd70?bP
408000001@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@0000000P00000:0:f][@<0ojHA0P0000090?nV4@8000002P3oYQ42000000X0ojHA0P0000040?nV
4@060:f][@3oYQ00ojH@0?nV40000000ojH@0P0000070?nV408000002P3oYQ001@000000ojH@0?nV
403oYQ00[Jf]00@0ojD@00<000000?nU403oYA005`3oYA000`2][Jd0oj<@0?nS400E0?nS40L0[Jf]
603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo
001e0;3PiP80[Jf]203lX104000000D0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0E0?nV4@<0[Jf]00@000000:f][@2][Jd0[Jf]0P00000;0?nV4@8000002@3oYQ42000000X0ojHA
0P0000090?nV4@030000003oYQ40000000@0ojHA00H0[Jf]0?nV403oYQ00ojH@0000003oYQ020000
00L0ojH@0P00000:0?nV40050000003oYQ00ojH@0?nV402][Jd07P3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]2`3lX102000000D0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0<0?nV4@<0000000<0ojHA0:f][@2][Jd00`2][Jd20?nV
4@800000103oYQ42000000X0ojHA0P0000090?nV4@8000002P3oYQ42000000T0ojHA00<000000?nV
4@000000103oYQ400`2][Jd0ojH@0?nV40020?nV40<000001`3oYQ000`000000ojH@0?nV40090?nV
40050000003oYQ00ojH@0?nV402][Jd07P3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100
o:0@00H0o:0@1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
0`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@
00T0o:0@0P0000040?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ440000
00@0[Jf]1P3oYQ42000000D0ojHA0P00000:0?nV4@8000002@3oYQ42000000X0ojHA0P0000090?nV
4@030000003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000L0ojH@00<000000?nV
403oYQ002@3oYQ001@000000ojH@0?nV403oYQ00[Jf]01h0ojD@00<0[Jf]0?nS403oXa006@3oXa00
0`2][Jd0o:0@0?bP400;0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH
40030:f][@3lX100o:0@00T0o:0@0P0000040?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV
4@3oYQ400P3oYQ43000000D0[Jf]0P0000090?nV4@80000000<0[Jf]0?nV4@3oYQ400`3oYQ420000
00X0ojHA0P0000090?nV4@8000002P3oYQ42000000T0ojHA00<000000?nV4@000000103oYQ400`2]
[Jd0ojH@0?nV40030?nV408000001`3oYQ000`000000ojH@0?nV40090?nV40050000003oYQ00ojH@
0?nV402][Jd07P3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@1P2][Jd2
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@04
0=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@
00T0o:0@0P0000040?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0000000000000P0000030:f]
[@D0ojHA0P0000090?nV4@80000000<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P0000090?nV
4@8000002P3oYQ42000000T0ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@0?nV40030?nV
408000004P3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS
40030:f][@3lX100o:0@01H0o:0@102][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3lX100o:0@00T0
o:0@0P0000040?bP40030:f][@3oY140oj@A01<0oj@A102][Jd2000000P0ojHA0P0000080?nV4@80
000000<0ojHA0:f][@3oYQ401@3oYQ42000000T0ojHA0P0000090?nV4@8000002P3oYQ42000000T0
ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@0?nV40030?nV408000004P3oYQ02000000<0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00T0o:0@
0P0000040?bP40030:f][@3oY140oj@A00`0oj@A00<000000?nT4@3oY140102][Jd0103oY140[Jf]
0?nV4@3oYQ42000000P0ojHA0P0000080?nV4@80000000<0ojHA0:f][@3oYQ401@3oYQ42000000T0
ojHA0P0000080?nV4@030:f][@000000000000X0ojHA0P0000090?nV4@030000003oYQ40000000@0
ojHA00<0[Jf]0?nV403oYQ000`3oYQ0200000140ojH@0P0000040?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0
mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0
/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00T0o:0@0P0000040?bP40030:f]
[@3oY140oj@A00X0oj@A100000000`2][Jd0oj@A0?nT4@030?nT4@030:f][@3oYQ40ojHA00800000
203oYQ42000000P0ojHA0P0000000`3oYQ40[Jf]0?nV4@050?nV4@8000002@3oYQ42000000P0ojHA
00<0[Jf]0000000000002P3oYQ42000000T0ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@
0?nV40030?nV40800000403oYQ000`000000ojH@000000040?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00L0mY`?
102][Jd90?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V
0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3l
X102000000@0o:0@00<0[Jf]0?nT4@3oY1401`3oY140102][Jd000000000002][Jd20?nT4@800000
1@3oY1400`2][Jd0ojHA0?nV4@02000000P0ojHA0P0000080?nV4@80000000<0ojHA0:f][@3oYQ40
1@3oYQ42000000T0ojHA0P0000080?nV4@030:f][@000000000000X0ojHA0P0000090?nV4@030000
003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ000`3oYQ02000000l0ojH@00<000000?nV40000000
1@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP
40090?bP40800000103lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]0P0000040?nT4@030000003o
Y140000000@0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000001`3oYQ4200000080ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ42000000P0ojHA0P0000080?nV4@030:f][@000000000000X0ojHA0P00
00090?nV4@030000003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ000P3oYQ000`000000ojH@0000
000=0?nV4080000000<0ojH@0000003oYQ001@3oYQ000`2][Jd0ojD@0?nU40020?nU40030000003o
YA00ojD@01L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100
o:0@00T0o:0@00<000000?bP403lX1000`3lX1000`2][Jd0oj@A0:f][@030:f][@@0oj@A0P000005
0?nT4@800000103oY1400`2][Jd0ojHA0?nV4@02000000P0ojHA0P0000070?nV4@8000000P3oYQ40
0`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42000000P0ojHA00<0[Jf]0000000000002@3oYQ40
0`000000ojHA000000090?nV4@030000003oYQ40000000@0ojHA00<0[Jf]0?nV403oYQ000P3oYQ00
0`000000ojH@0000000<0?nV40040000003oYQ00ojH@000000L0ojH@00<0[Jf]0?nU403oYA000P3o
YA000`000000ojD@0?nU400G0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2i
M@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@
0?bP40090?bP40050000003lX100o:0@0?bP400000000`2][Jd80?nT4@8000001@3oY1400`000000
oj@A000000030?nT4@030:f][@3oYQ40ojHA00800000203oYQ42000000L0ojHA0P0000020?nV4@03
0:f][@3oYQ40ojHA00D0ojHA0P0000080?nV4@800000203oYQ400`2][Jd00000000000090?nV4@03
0000003oYQ40000000T0ojHA00<000000?nV4@000000103oYQ400`2][Jd0ojH@0?nV40020?nV4003
0000003oYQ00000000/0ojH@00@000000?nV400000000000203oYQ000`2][Jd0ojD@0?nU40020?nU
40030000003oYA00ojD@01L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP
40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>
0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP40090?bP40050000003lX100o:0@0000002][Jd00P00
00080?nT4@8000001`3oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000001`3o
YQ4200000080ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000L0ojHA0P0000090?nV4@030:f][@00
0000000000T0ojHA00<000000?nV4@0000002@3oYQ400`000000ojHA000000040?nV4@030:f][@3o
YQ00ojH@0080ojH@00<000000?nV400000002@3oYQ02000000030?nV40000000ojH@00T0ojH@00<0
[Jf]0?nU403oYA000P3oYA000`000000ojD@0?nU400G0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2]
[Jd2000000X0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`
h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX1002@3lX1000`000000[Jf]000000030?bP40030000003oY140oj@A00H0oj@A0P000007
0?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@02000000P0ojHA0P0000070?nV4@8000000P3oYQ40
0`2][Jd0ojHA0?nV4@050?nV4@8000001`3oYQ42000000T0ojHA00<0[Jf]0000000000002@3oYQ40
0`000000ojHA000000090?nV4@8000002P2][Jd00`000000[Jf]000000080:f][@040000002][Jd0
[Jf]00000100[Jf]00<000000:f][@2][Jd05`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P80[Jf]0P00
00080>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3P
iP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40040?bP4080000000<0o:0@0:f][@2][Jd00P0000040?bP408000001`3oY142
000000L0oj@A0P0000020?nT4@040:f][@3oYQ40ojHA0?nV4@800000203oYQ42000000L0ojHA00D0
00000?nV4@3oYQ40ojHA0:f][@070?nV4@8000001`3oYQ42000000T0ojHA00<0[Jf]000000000000
1@3oYQ440:f][@030000002][Jd0000000T0[Jf]0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@
00<000000?nV400000001`3oYQ0010000000ojH@00000000000<0?nV40030:f][@3oYA00ojD@0080
ojD@00<000000?nU403oYA00402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00H0k9H>00<000000:f][@00
00000P0000050>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0
/>3V0;3PiP180;3PiP40oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V100
2`3_V100102][Jd0o:0@0?bP403lX10400000080[Jf]0P3lX102000000@0o:0@00<0[Jf]0000003o
Y1401P3oY142000000L0oj@A0P0000020?nT4@040:f][@3oYQ40ojHA0?nV4@800000203oYQ420000
00H0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00D0ojHA0P0000070?nV4@8000001@3oYQ450:f]
[@8000001@2][Jd40?nV4@030000003oYQ40000000T0ojHA0P0000050?nV4@030:f][@3oYQ00@FWQ
0080ojH@00<000000?nV400000001`3oYQ02000000X0ojH@00D000000?nV403oYQ00ojH@0:f][@04
0?nU40030000003oYA00ojD@0100ojD@302][JdH0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P060>bF3P050000003/UPh0k9H>0>bF3P2][Jd00P00
00030>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3P
iP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100
102][Jd0o:0@0?bP403lX1020:f][@800000103lX1000`000000o:0@0?bP40030?bP40030:f][@00
0000000000H0oj@A0P0000070?nT4@8000000P3oY140102][Jd0ojHA0?nV4@3oYQ42000000P0ojHA
0P0000060?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000001@3oYQ420:f][@800000
1@2][Jd40?nV4@030:f][@000000000000T0ojHA00<000000?nV4@0000002@3oYQ42000000D0ojHA
00<0[Jf]0?nV403oYQ000P3oYQ000`000000ojH@000000070?nV40030000003oYQ00ojH@00T0ojH@
00D000000?nV403oYQ00ojH@0:f][@040?nU40030000003oYA00ojD@01L0ojD@00<0[Jf]0?nS403o
Xa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh00`3/UPh01@2][Jd000000000003/UPh0[Jf]
00d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd000000:f][@2][Jd20?bP
40800000103lX1000`000000o:0@0?bP40030?bP40030:f][@000000000000D0oj@A0P0000080?nT
4@8000000P3oY140102][Jd0ojHA0?nV4@3oYQ42000000P0ojHA0P0000060?nV4@8000000`3oYQ40
0`2][Jd0ojHA0?nV4@020?nV4@<0[Jf]0P0000050:f][@80ojHA0P0000090?nV4@030:f][@000000
000000T0ojHA00<000000?nV4@0000002@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ00
0`000000ojH@000000070?nV40030000003oYQ00ojH@00P0ojH@0P0000030?nV40030:f][@3oYA00
ojD@0080ojD@00<000000?nU403oYA005`3oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa00
0`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh0
0`000000k9H>0>bF3P050>bF3P030000002][Jd0[Jf]00d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/2
0:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`0000000`2]
[Jd0o:0@0?bP40020?bP40030000003lX100o:0@00<0o:0@00<000000?bP403lX1000`3lX1000`2]
[Jd00000000000050?nT4@800000203oY14200000080oj@A00@0[Jf]0?nV4@3oYQ40ojHA0P000008
0?nV4@8000001P3oYQ42000000030?nV4@2][Jd0[Jf]00D0[Jf]0P3oYQ42000000P0ojHA0P000009
0?nV4@030:f][@000000000000T0ojHA00<000000?nV4@0000002@3oYQ42000000D0ojHA00<0[Jf]
0?nV403oYQ000P3oYQ000`000000ojH@000000070?nV40030000003oYQ00ojH@00P0ojH@0P000003
0?nV40030:f][@3oYA00ojD@0080ojD@00<000000?nU403oYA005`3oYA000`2][Jd0oj<@0?nS400F
0?nS40P0[Jf]5P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00H0k9H>00<00000
0>bF3P3/UPh01@3/UPh00`000000k9H>0:f][@020:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/2
0:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00P0kiP@0P0000020:f]
[@@0o:0@0P0000050?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0000000000001@3oY1420000
00P0oj@A0P0000020?nT4@040:f][@3oYQ40ojHA0?nV4@800000203oYQ42000000<0ojHA0`2][Jd2
000000040:f][@3oYQ40ojHA0:f][@H0ojHA0P0000080?nV4@8000002@3oYQ400`2][Jd000000000
00090?nV4@030000003oYQ40000000T0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@00<0
00000?nV400000001`3oYQ000`000000ojH@0?nV40080?nV408000000`3oYQ000`2][Jd0ojD@0?nU
40020?nU40030000003oYA00ojD@01L0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP
403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P060>bF3P030000
003/UPh0k9H>00D0k9H>00<000000>bF3P2][Jd00P3KRPd20:f][@030=^:3@000000fhX=00H0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@030000003_V100[Jf]00@0o:0@0P00
00040?bP408000001@3lX1000`2][Jd0oj@A000000050?nT4@800000203oY14200000080oj@A00@0
[Jf]0?nV4@3oYQ40ojHA0P0000080?nV4@8000000`2][Jd30?nV4@030000003oYQ4000000080ojHA
00<0[Jf]0?nV4@3oYQ40103oYQ42000000P0ojHA0P0000090?nV4@030:f][@000000000000T0ojHA
00<000000?nV4@0000002@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ000`000000ojH@
000000070?nV40030000003oYQ00ojH@00L0ojH@0`0000030?nV40030:f][@3oYA00ojD@0080ojD@
00<000000?nU403oYA005`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00L0o:0@
1`2][Jd90?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh00`000000k9H>
0>bF3P050>bF3P030000003/UPh0[Jf]00<0fhX=0P0000000`2][Jd000000=^:3@050=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP
2`2][Jd80=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd20>nH40030000003_V100[Jf]00@0o:0@
0P0000040?bP408000001@3lX1000`2][Jd0oj@A000000050?nT4@800000203oY14200000080oj@A
00@0[Jf]0?nV4@3oYQ40ojHA0P0000030?nV4@D0[Jf]0P0000070?nV4@8000000P3oYQ400`2][Jd0
ojHA0?nV4@040?nV4@800000203oYQ42000000T0ojHA0P00000:0?nV4@030000003oYQ40000000T0
ojHA0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@00<000000?nV40000000203oYQ000`000000
ojH@0?nV40060?nV40<000000`3oYQ000`2][Jd0ojD@0?nU40020?nU40030000003oYA00ojD@01L0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40H0[Jf]0`3lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh01@3/UPh00`000000
k9H>0:f][@030=^:3@80000000<0fhX=0000003KRPd00P0000030=^:3@030:f][@2iM@/0^GD;00L0
^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>7
3P030:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH403_V1000P3_V1000`000000kiP@0:f][@040?bP
40800000103lX102000000D0o:0@00<0[Jf]0?nT4@0000001@3oY1400`000000oj@A0?nT4@070?nT
4@8000000P3oY140102][Jd0ojHA0?nV4@2][Jd2000000<0[Jf]1@3oYQ42000000L0ojHA0P000002
0?nV4@030:f][@3oYQ40ojHA00<0ojHA0P0000090?nV4@<00000203oYQ42000000X0ojHA00<00000
0?nV4@0000002@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ000`000000ojH@00000009
0?nV408000001@3oYQ0010000000ojH@0?nV400000030?nV40040:f][@3oYA00ojD@0?nU40<00000
603oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01@0o:0@1@2][JdE0?JL3`030:f]
[@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh01@3/UPh00`000000k9H>0:f][@030=^:3@800000
0P3KRPd400000080fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0
/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080
kiP@0P2][Jd50>nH40030000003_V100[Jf]00@0o:0@0P0000040?bP408000001@3lX1000`2][Jd0
oj@A000000050?nT4@030000003oY140oj@A00L0oj@A0P0000000`3oY140[Jf]0:f][@020:f][@03
0?nV4@000000000000P0ojHA00<000000?nV4@3oYQ401P3oYQ4200000080ojHA00<0[Jf]0?nV4@3o
YQ400`3oYQ42000000T0ojHA0`0000080?nV4@8000002P3oYQ400`000000ojHA000000090?nV4@80
00001@3oYQ400`2][Jd0ojH@00000005000000/0ojH@1@0000030?nV40050000003oYQ00ojH@0?nV
402][Jd00`3oYA03000001P0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP
40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P060>bF3P030000003/UPh0k9H>
00H0k9H>00<000000:f][@3KRPd00P3KRPd010000000fhX=0=^:3@3KRPd3000000040:f][@3KRPd0
fhX=0:f][@T0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@L0kiP@00<000000>nH402][Jd0
103lX102000000@0o:0@0P0000050?bP40030:f][@3oY140000000D0oj@A00<000000?nT4@3oY140
1P3oY1401P2][Jd000000000002][Jd0oj@A0:f][@<0ojHA0P0000070?nV4@8000002@3oYQ420000
00030?nV4@2][Jd0ojHA00<0ojHA0P00000:0?nV4@80000000<0ojHA0000000000001@3oYQ420000
00P0ojHA1P0000060?nV4@D000001@3oYQ400`2][Jd0ojH@0?nV400L0?nV40040:f][@3oYA00ojD@
0?nU40<00000603oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l00`3fW0l40:f][@d0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh2000000L0k9H>00<00000
0:f][@3KRPd00P3KRPd010000000fhX=0=^:3@3KRPd3000000040=^:3@2][Jd0[Jf]0:f][@T0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2G
H0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f][@X0kiP@00<000000:f][@3lX1000`3l
X1000`000000o:0@0?bP40030?bP408000001@3lX1000`2][Jd0oj@A000000050?nT4@030000003o
Y140oj@A0080oj@A102][Jd2000000<0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000002@3o
YQ42000000030?nV4@2][Jd0ojHA00<0ojHA0P00000:0?nV4@8000000`3oYQ45000000030?nV4@2]
[Jd0ojHA01d0ojHA00<0[Jf]0?nV403oYQ00703oYQ00102][Jd0ojD@0?nU403oYA03000001P0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00L0mY`?
102][Jd90?JL3`030:f][@3/UPh0k9H>00H0k9H>0P0000070>bF3P030000002][Jd0fhX=0080fhX=
00<000000=^:3@3KRPd00P3KRPd2000000<0fhX=00<0[Jf]0;Ue2`0000001`2iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@090=>73P030:f][@3_V100kiP@00X0kiP@00<000000:f][@3lX1000`3lX1000`000000o:0@
0?bP40030?bP408000001@3lX1000`2][Jd0oj@A000000050?nT4@030000003oY140[Jf]0080[Jf]
103oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000002P3oYQ42000000040:f]
[@3oYQ40ojHA0?nV4@800000203oYQ45000000T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40040:f][@3oYA00ojD@0?nU40<00000603oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]0>bF
3P3/UPh01P3/UPh2000000L0k9H>00<000000:f][@3KRPd00P3KRPd00`000000fhX=0=^:3@020=^:
3@8000000`3KRPd0102][Jd000000000000000060;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]
0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd<
0>nH40040000003lX100o:0@0?bP40<000001@3lX102000000D0o:0@00<0[Jf]0?nT4@0000000`3o
Y1420:f][@030000002][Jd0oj@A00H0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA00800000203o
YQ42000000/0ojHA0P0000030?nV4@030000003oYQ40ojHA01D0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40040:f][@3oYA00ojD@0?nU40<00000603oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL
3`2][Jd0k9H>00L0k9H>0P0000070>bF3P030000002][Jd0fhX=0080fhX=00<000000=^:3@3KRPd0
0P3KRPd2000000<0fhX=00H0[Jf]00000000000000000;Ue2`0000040;Ue2`030:f][@28EPL0R5H7
0080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00H0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400;0>nH40050000003lX10000000000003lX1000P000005
0?bP408000001@3lX1000`2][Jd0oj@A000000030:f][@80oj@A0P0000070?nT4@8000000`3oY140
0`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000;0?nV4@030:f][@3oYQ40000000800000603oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00@0[Jf]0?nU403oYA00ojD@0`00
000H0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL
3`0C0?JL3`<0[Jf]1`3/UPh2000000<0k9H>00H000000>bF3P3/UPh0k9H>0000002][Jd30=^:3@03
0000003KRPd0fhX=0080fhX=0P0000030=^:3@040000002iM@/000000;Ue2`<000000`2iM@/00`2]
[Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@050=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd0303_V102000000<0o:0@0P000005
0?bP40800000103lX1020:f][@030000003oY140oj@A00@0oj@A0P0000060?nT4@800000103oY140
0`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000;0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40040:f][@3oYA00ojD@0?nU40<00000603o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0:f][@020:f][@@0k9H>0P0000030>bF3P030000003/UPh0k9H>0080k9H>00D0
[Jf]0=^:3@3KRPd0fhX=000000040=^:3@8000000`3KRPd200000080^GD;0P0000040;Ue2`030:f]
[@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0
103CQ`h00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00X0kiP@00<000000?bP403lX100
0P3lX102000000D0o:0@00<000000?bP403lX1000`2][Jd00`3lX100[Jf]000000060?nT4@800000
1P3oY142000000@0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000002`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00102][Jd0ojD@
0?nU403oYA03000001P0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@80k9H>0P0000030>bF3P03
0000003/UPh0k9H>0080k9H>00D0[Jf]0=^:3@3KRPd0fhX=000000040=^:3@8000000`3KRPd20000
0080^GD;0P0000001@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je20;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100
kiP@00X0kiP@00<000000?bP403lX1000P3lX102000000D0o:0@00<000000:f][@2][Jd0103lX100
0`2][Jd000000?nT4@050?nT4@030000003oY140000000@0oj@A0P0000050?nT4@030:f][@3oYQ40
ojHA00800000203oYQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00@0[Jf]0?nU403oYA00ojD@0`00000H0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00@0k9H>0P2][Jd2000000<0k9H>00<000000>bF3P3/UPh00P3/UPh01@2][Jd0fhX=0=^:
3@3KRPd0000000@0fhX=0P0000030=^:3@8000000`2iM@/01P000000^GD;0:f][@2][Jd0^GD;0000
00@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd6
0=>73P030:f][@3_V100kiP@00X0kiP@00<000000?bP403lX1000P3lX102000000<0o:0@0P2][Jd0
0`000000o:0@0?bP40040?bP40030:f][@000000oj@A00H0oj@A0P0000040?nT4@8000001@3oY140
0`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000;0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ405@3oYQ4Z0:f][@<0000000<0[Jf]0?nU403oYA005@3oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P06
0>bF3P8000000P2][Jd00`3/UPh000000>bF3P030>bF3P050:f][@3KRPd0fhX=0=^:3@000000103K
RPd2000000<0fhX=0P0000030;Ue2`070000002iM@/0^GD;0;Ue2`000000[Jf]0000000308QF1`80
[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_
V1002P3_V1000`000000o:0@0?bP40020?bP40030000003lX100[Jf]0080[Jf]0P3lX1000`000000
o:0@0?bP40040?bP408000001`3oY1400`000000oj@A000000030?nT4@030000003oY140oj@A00@0
oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000002`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00@0[Jf]0?nU403o
YA00ojD@0`0000000`3oYA00[Jf]0:f][@0>0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh20000
0080k9H>00<0[Jf]0000003/UPh00P3/UPh00`11JN40[Jf]0=^:3@020=^:3@030000003KRPd0fhX=
0080fhX=0P0000030=^:3@8000000`2iM@/01`000000^GD;0;Ue2`2iM@/000000:f][@0000001028
EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3C
Q`h00`2][Jd0kiP@0>nH400:0>nH40040000003lX100o:0@0?bP4080000000<0[Jf]0?bP403lX100
0`3lX1000`000000o:0@0?bP40040?bP40030000003oY140oj@A00L0oj@A0P0000020?nT4@800000
1P3oY1400`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000;0?nV4@030:f][@3oYQ40ojHA01H0ojHA
302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00@0[Jf]0?nU403oYA00ojD@0`00000A0?nU40`0
[Jf]603oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh01`3/UPh01@000000k9H>0>bF3P3/UPh0000000<0[Jf]00<0k9H>045Yh@3KRPd00P3KRPd00`00
0000fhX=0=^:3@020=^:3@8000000`3KRPd2000000<0^GD;00L000000;Ue2`2iM@/0^GD;0000002]
[Jd0000000@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`02
0:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V10010000000@FWQ0:f][@2][Jd2000000H0o:0@00<0
00000?bP403lX1000`3lX102000000X0oj@A100000070?nT4@030:f][@3oYQ40ojHA00800000203o
YQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ402@3o
YQ400`000000ojHA0?nV4@0@0?nV4@030:f][@3oYQ00ojH@01`0ojH@00L0[Jf]0?nU403oYA00ojD@
0000003oYA00000001P0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0P0000020>bF3P04
0000003/UPh0k9H>0>bF3P<0[Jf]0P3KRPd00`000000fhX=0=^:3@030=^:3@040000003KRPd0fhX=
0=^:3@8000000`2iM@/02@000000^GD;0;Ue2`2iM@/000000:f][@000000R5H70000000208QF1`03
0:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>73P030:f]
[@3_V100kiP@00/0kiP@00@000000:f][@3lX100o:0@0P0000060?bP40800000103lX102000001D0
oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000002`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@080?nV4@8000004P3oYQ400`2][Jd0ojH@0?nV400L0?nV4004
0:f][@3oYA00ojD@0?nU408000006@3oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh00`00
0000k9H>00000002000000@0k9H>00H0[Jf]0=^:3@2][Jd0[Jf]0=^:3@0000040=^:3@8000000P3K
RPd2000000<0^GD;00`000000;Ue2`2iM@/0^GD;0000002][Jd000000:f][@28EPL0000008QF1`2]
[Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH
40090>nH4080[Jf]00@000000?bP403lX100o:0@0P0000060?bP408000000`3lX102000000030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@800000203oYQ480:f][AP0ojHA
00<0[Jf]0?nV4@3oYQ40203oYQ400`000000ojHA0000000A0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA000P3oYA000`000000ojD@0?nU400G0?nU40030:f][@3oXa00oj<@01H0oj<@
202][JdG0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh01@000000k9H>
0>bF3P3/UPh0000000@0k9H>00H0[Jf]0=^:3@3KRPd0fhX=0:f][@0000040=^:3@8000000P3KRPd2
000000<0^GD;00H000000;Ue2`2iM@/0^GD;0000002][Jd2000000040:f][@00000000000:f][D80
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0
kiP@0P2][Jd20>nH40040000003lX100o:0@0?bP408000001P3lX1000`000000o:0@000000020?bP
40030000002][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@8000000P3oYQ460:f]
[@<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@080?nV4@8000004P3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@0080ojD@00<000000?nU403oYA005`3oYA000`2]
[Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP40L0[Jf]403lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00H0k9H>00D000000>bF3P3/UPh0k9H>000000040>bF3P030:f][@3K
RPd0fhX=0080fhX=00<000000:f][@2][Jd00P3KRPd200000080fhX=0P0000030;Ue2`8000000P2i
M@/01@000000[Jf]08QF1`000000R5H70080000000<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`
h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_
V100102][Jd000000?bP403lX102000000H0o:0@00<000000?bP403lX1000P0000000`3lX100[Jf]
0?nT4@0E0?nT4@030:f][@3oYQ40ojHA008000001@3oYQ430:f][@8000000P2][Jd90?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV4@0@0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00P0o:0@1P2][Jd:0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
1P3/UPh01@000000k9H>0>bF3P3/UPh0000000@0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd00`000000
fhX=0=^:3@020:f][@8000000P3KRPd2000000<0^GD;0P0000001`2iM@/000000000002][Jd0R5H7
00000028EPL00`0000120;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2][Jd0dhL>0=>73P060=>7
3P030:f][@3_V100kiP@00<0kiP@0P2][Jd60>nH40050:f][@000000o:0@0?bP400000001P3lX102
000000D0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@02000000D0[Jf]0`3oYQ42
000000/0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@00h0o:0@1`2][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh0
1@000000k9H>0>bF3P3/UPh0000000@0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd00`000000fhX=0=^:
3@020=^:3@8000000P3KRPd2000000<0^GD;0P0000002P2iM@/000000000002][Jd0R5H700000028
EPL000000:f][@0000120;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0
102][Jd0kiP@0>nH403_V1020:f][@P0kiP@00<0[Jf]0000003lX1000P0000040?bP408000001`3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@@0[Jf]0P0000080?nV4@8000002`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1060:f][A@0mY`?00<0
[Jf]0>bF3P3/UPh01P3/UPh01@000000k9H>0>bF3P3/UPh0000000@0k9H>00<0[Jf]0=^:3@3KRPd0
0P3KRPd00`000000fhX=0=^:3@020=^:3@8000000P2][Jd2000000<0^GD;0P0000001P2iM@/00000
0000002][Jd0R5H700000080R5H70P0000120;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0
dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f][@X0kiP@00<0[Jf]0000003lX1000P00000=0?bP
40030:f][@3oY140oj@A00l0oj@A102][Jd0103oY140[Jf]0?nV4@3oYQ42000000P0ojHA0P00000;
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?00@0[Jf]403fW0l00`2][Jd0k9H>0>bF3P060>bF3P050000003/UPh0
k9H>0>bF3P000000103/UPh00`2][Jd0fhX=0=^:3@020=^:3@030000003KRPd0fhX=0080fhX=0P00
00020=^:3@8000000`2iM@/2000000060;Ue2`00000000000;Ue2`2][Jd000000P28EPL200000003
0:f][@2`h>H0/>3V03l0/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>
0P2][Jd<0>nH40030:f][@000000o:0@008000003@3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]
1@3oY1400`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000;0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0mY`?
1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00H0k9H>00D000000>bF3P3/UPh0k9H>000000040>bF3P03
0:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00P3KRPd2000000<0fhX=00@000000:f][@2i
M@/0^GD;0P0000001@2iM@/000000000002iM@/0[Jf]0080000000@0R5H70000000000000000@@2`
h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@d0kiP@00<0[Jf]
0000003lX1000P00000=0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40
ojHA00800000203oYQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]
0>bF3P3/UPh01P3/UPh01@000000k9H>0>bF3P3/UPh0000000@0k9H>00<0[Jf]0=^:3@3KRPd00P3K
RPd00`000000fhX=0=^:3@020=^:3@8000000`3KRPd010000000^GD;0:f][@2][Jd200000080^GD;
00<000000;Ue2`2][Jd00P0000001028EPL000000000000000110;3PiP40oooo001H0;3PiP80[Jf]
0`2GH0/00`2][Jd0dhL>0=>73P040=>73P030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0000003lX100
0P00000=0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA00800000
1P3oYQ43000000`0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0
1P3/UPh2000000H0k9H>00L000000>bF3P2][Jd0fhX=0000003KRPd0000000@0fhX=0P0000030=^:
3@040000002iM@/0^GD;0;Ue2`8000000P2iM@/00`000000^GD;0:f][@020000000308QF1`000000
000000800000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h0102]
[Jd0dhL>0=>73P2][Jd=0>nH40030:f][@000000o:0@008000003@3lX1000`2][Jd0oj@A0:f][@03
0:f][A40oj@A00<0[Jf]0?nV4@3oYQ400P00000E0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?102][Jd7
0>bF3P8000001P3/UPh00`000000k9H>0:f][@020=^:3@800000103KRPd2000000<0fhX=00@00000
0;Ue2`2iM@/0^GD;0P0000020;Ue2`030000002iM@/0[Jf]0080000000<0R5H70000000000000P00
00100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>73P3CQ`h20:f][@<0dhL>00<0
[Jf]0>nH403_V1002`3_V100102][Jd000000?bP4000000=0?bP40<0[Jf]5@3oY1400`2][Jd00000
0000000G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd40>bF3P800000
1P3/UPh00`000000k9H>0:f][@080=^:3@8000000`3KRPd200000080^GD;0P000000202][Jd0^GD;
0000002iM@/0[Jf]08QF1`000000R5H7100000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0102]
[Jd0dhL>0=>73P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0000003lX10000002`3l
X1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd20>bF3P8000001P3/UPh00`000000k9H>0:f]
[@070=^:3@<000000`3KRPd00`2][Jd000000;Ue2`020;Ue2`090000002iM@/0[Jf]0000002iM@/0
[Jf]08QF1`000000R5H700@00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P2]
[Jd01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@0000000000000000P0o:0@0`2][Jd30?bP
40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL
3`030:f][@3/UPh0k9H>00@0k9H>0P2][Jd2000000H0k9H>00<000000>bF3P2][Jd0203KRPd20000
00<0fhX=00<0[Jf]0000000000000P2iM@/00`000000^GD;0;Ue2`0200000004045Yh@28EPL00000
08QF1`@00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@
00/0kiP@00@0[Jf]00000000000000001P3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140503oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh2
00000080[Jf]103/UPh00`000000k9H>0:f][@0=0=^:3@040:f][@00000000000;Ue2`8000000P2i
M@/2000000040:f][@28EPL0000008QF1`@00000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;09MP
2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd000000000
000000030?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P060>bF3P8000000P3/UPh20:f][@80k9H>00<000000>bF3P2][Jd03@3KRPd0102][Jd00000
0000002iM@/200000080^GD;0P000000102][Jd0000000000028EPL400000400/>3V0@3oool005P0
/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP
4000000000000`2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P060>bF3P800000103/UPh20:f][@80000000<0[Jf]0=^:3@3KRPd0303KRPd0
1@2][Jd000000000002iM@/000000080^GD;0P000000102][Jd0000000000028EPL400000400/>3V
0@3oool005P0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@
00@0[Jf]0?bP4000000000003P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P060>bF3P8000001P3/UPh200000080
[Jf]3@3KRPd01@2][Jd0^GD;0000002iM@/000000080^GD;0P000000102][Jd0000000000028EPL4
00000400/>3V0@3oool005P0/>3V00H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd70=>73P030:f][@3_
V100kiP@00/0kiP@0`2][Jd2000000h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh4000000H0k9H>0P00
0000102][Jd0fhX=0:f][@2][Jd;0=^:3@050:f][@2iM@/0^GD;0;Ue2`0000000`2iM@/01@000000
[Jf]000000000000R5H700@00000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`03
0:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@040>nH402][Jd0o:0@0000
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA
0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00H0k9H>100000040>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@050:f][@2iM@/0
^GD;0;Ue2`0000000`2iM@/01@000000[Jf]000000000000[Jf]00@00000@02`h>H10?ooo`00F02`
h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001`3_
V1020:f][@<0kiP@00<0[Jf]0?bP400000003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/
UPh0k9H>00T0k9H>1P0000000`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd01@2][Jd0^GD;0;Ue
2`2iM@/0000000<0^GD;00<000000:f][@0000000P28EPL400000400/>3V0@3oool005P0/>3V0P2]
[Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@00<0
[Jf]0?bP400000003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2]
[JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00d0k9H>0P00
00000`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0000000@0^GD;
0P00000208QF1`@00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3C
Q`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_V1000`2][Jd0o:0@0000000?0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3f
W0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3K
RPd0102][Jd0^GD;0;Ue2`2iM@/2000000<0^GD;0P00000208QF1`@00000@02`h>H10?ooo`00E`2`
h>H20:f][@@0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0
[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`020;Ue2`800000102iM@/00`2][Jd0
R5H708QF1`02000000030:f][@000000000003l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=0P2][Jd30;Ue2`800000102iM@/00`2][Jd0R5H708QF1`0200000003
0:f][@000000000003l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>
0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V
1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@030;Ue
2`000000000000@0^GD;00D0[Jf]08QF1`28EPL000000:f][@03000003l0/>3V0@3oool005L0/>3V
0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2][Jd2000000@0^GD;00D0[Jf]08QF1`00
000000000:f][@03000003l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00<0
dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3o
Y140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd0102][Jd0^GD;0;Ue2`2iM@/2000000@0^GD;00<0[Jf]08QF1`28EPL01@00000o0;3P
iP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0dhL>0=>7
3P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f]
[@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;
0;Ue2`80000000D0[Jf]0;Ue2`2iM@/0^GD;0:f][@0308QF1`@00000?`2`h>H10?ooo`00E`2`h>H2
0:f][@<0Uf0;00D0[Jf]0=>73P3CQ`h0dhL>0:f][@040=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0
[Jf]0;Ue2`2iM@/0^GD;0P0000001@2iM@/0[Jf]0;Ue2`2iM@/0[Jf]00<0R5H71000000o0;3PiP40
oooo001G0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0:f][@2][Jd50=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0P0000020;Ue2`<0[Jf]0`28EPL0102][Jd0000000000000000o
0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`0000040;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP2`0209MP
2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP
40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@040:f][@2iM@/0^GD;0;Ue2`800000102iM@/20:f][@<0R5H700<0[Jf]000000000000?`2`h>H1
0?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?
0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd3
08QF1`030:f][@000000000003l0/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd8
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]
0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0
_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
[Jf]0080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP2`2][Jd0
Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0
[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H70:f][@0208QF1`030:f][@000000000003l0/>3V0@3oool005L0/>3V00<0[Jf]
09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00X0kiP@0`2][Jd0
0`2aZid0@FWQ0;6[W@050;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`4
0:f][MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP2
0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H708QF1`2][Jd0R5H70:f][@800000
?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V100203_V1020:f][@D0/J^M0P11JN440;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF
1`28EPL20:f][@800000?`2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]1@2aZid3045Yh@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@<0/J^M
0P11JN440;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V
1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H7
08QF1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP
2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f]
[@2aZid0/J^M0080/J^M0P2][Jd00`2aZid0@FWQ045Yh@040;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f]
[@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]
1P2n^KP0102][Jd0@FWQ0:f][@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28
EPL00P28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P04
0:f][@3_V100[Jf]0:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0102aZid00`2][Jd0@FWQ045Yh@040;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j
/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a045Yh@2d/;420:f][@030=^:3@2]
[Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@03045Yh@2TWXl0Y9j?00@0Y9j?1011JN450;6[W@80@FWQ
00D0[Jf]0;6[W@2aZid0/J^M0:f][@0@0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40@FWQ00<0];2a0P2][Jd:0;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00P0dhL>00@0[Jf]0:BNS`2TWXl0@FWQ1P2TWXl2045Yh@030;6[W@11JN40/J^M00@0/J^M0P11
JN401@2aZid0[Jf]0:f][@2aZid0[Jf]0100^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40@FWQ00@0];2a
00<0@FWQ0:f][@2][Jd0202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00@0@FWQ0:BNS`2TWXl0@FWQ1P2TWXl01P11
JN40[Jf]0;6[W@2aZid0@FWQ0;6[W@80@FWQ00<0/J^M045Yh@11JN400`2aZid30:f][@l0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]
Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40@FWQ00@0];2a
00@0@FWQ0;B`/@2d/;40[Jf]1`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P<0[Jf]00@0Y9j?045Yh@2TWXl0@FWQ1P2TWXl0
1011JN40/J^M0;6[W@2aZid3045Yh@80/J^M0P11JN440;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033
_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@11
JN40];2a00<0];2a0P11JN40102d/;40@FWQ0:f][@2][Jd50;Ue2`040:f][@28EPL0R5H708QF1`80
[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00@0[Jf]08Z5M@2:
QGD0[Jf]0P2TWXl2045Yh@D0Y9j?0P11JN430;6[W@80@FWQ0`2aZid2045Yh@050;6[W@11JN40/J^M
0;6[W@2][Jd01@2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]
0;ji^02n^KP0302n^KP00`2][Jd0@FWQ0;B`/@030;B`/@80@FWQ00<0];2a045Yh@11JN400`2][Jd3
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00<0dhL>00@0[Jf]08Z5M@2:QGD0RXEe0`2][Jd2045Yh@D0Y9j?0P11JN430;6[W@80@FWQ
0`2aZid3045Yh@040;6[W@11JN40/J^M0:f][@P0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0
aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP00`2][Jd0@FWQ0;B`/@030;B`/@80@FWQ00L0[Jf]045Yh@11JN40[Jf]045Yh@2OVj00
[Jf]0080^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP060:f][@2GH0/0
Uf0;09MP2`2][Jd0dhL>0P2][Jd01@11JN40RXEe08Z5M@2:QGD0[Jf]0080Y9j?0P11JN450:BNS`80
@FWQ0`2aZid2045Yh@<0/J^M0P11JN420;6[W@80@FWQ00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@03
0;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@`0`kfk00<0@FWQ0<>m^`2]
[Jd03P2n^KP00`2][Jd0@FWQ0;B`/@030;B`/@80@FWQ00D0];2a045Yh@11JN40[Jf]045Yh@0209nK
X0<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080
Uf0;0P2][Jd208Z5M@05045Yh@2:QGD0RXEe08Z5M@2][Jd00P2TWXl2045Yh@030:f][@2TWXl0Y9j?
00<0Y9j?00@0@FWQ0;6[W@2aZid0/J^M0P11JN430;6[W@80@FWQ0`2aZid00`11JN40[Jf]0;VbYP02
0;VbYP03045Yh@2i/ZH0^K:V00T0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2][Jd;
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`0<0<>m^`80@FWQ00<0[Jf]
0;ji^02n^KP0302n^KP0102][Jd0@FWQ0;B`/@2d/;420:f][@80@FWQ00D0];2a045Yh@11JN40[Jf]
045Yh@0409nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`
h>H00`2][Jd0Uf0;09MP2`0209MP2`050:f][@2:QGD0RXEe08Z5M@11JN400`2:QGD00`2][Jd0Y9j?
0:BNS`02045Yh@030:BNS`2][Jd0[Jf]00<0Y9j?00@0@FWQ0;6[W@2aZid0/J^M0P11JN420;6[W@80
@FWQ102aZid2045Yh@@0^K:V0P11JN4:0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0
a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`050<>m^`03045Yh@33_K/0`kfk00@0
`kfk00<0@FWQ0:f][@2n^KP03@2n^KP0102][Jd0@FWQ0;B`/@2][Jd20;B`/@80@FWQ00<0];2a045Y
h@11JN400P11JN4509nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102]
[Jd0Uf0;09MP2`2GH0/20:f][@<0RXEe00D0@FWQ08Z5M@2:QGD0RXEe0:f][@020:BNS`80@FWQ0`2T
WXl01@2][Jd0Y9j?0:BNS`2][Jd0@FWQ0080/J^M0P11JN420;6[W@80@FWQ1@2aZid00`11JN40^K:V
0;VbYP030;VbYP<0@FWQ00<0^K:V045Yh@11JN401@2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]
2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`030<>m^`80@FWQ
00<0`kfk045Yh@11JN401P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@11JN40[Jf]00<0];2a
0P11JN40102d/;40@FWQ045Yh@2][Jd609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?oo
o`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@<0RXEe00D0@FWQ08Z5M@2:QGD0RXEe0:f][@02
0:BNS`80@FWQ0P2TWXl00`11JN40Y9j?0:f][@020:f][@030;6[W@11JN40/J^M0080@FWQ0P2aZid2
045Yh@D0/J^M00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ0`2i/ZH0
0`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0
`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0:f][@030:f][@d0a/2l00@0[Jf]
0<>m^`33_K/0`kfk0P11JN440<>m^`03045Yh@33_K/0`kfk00@0`kfk00<0[Jf]0;ji^02n^KP02P2n
^KP20:f][@03045Yh@2d/;40];2a0080];2a0P11JN40102d/;40@FWQ045Yh@2][Jd709nKX0040:f]
[@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd308Z5M@06045Y
h@2:QGD0RXEe08Z5M@11JN40Y9j?1P11JN430:BNS`80[Jf]00@0/J^M045Yh@11JN40@FWQ0P2aZid2
045Yh@D0/J^M00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP030;VbYP@0@FWQ00<0^K:V
0:f][@11JN40302n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]4@36`;`01@2][Jd0`kfk0<>m^`33_K/0@FWQ00D0`kfk00<0
@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^0080;ji^080[Jf]00@0_[Vh0:f][@2d/;40@FWQ
0`2d/;44045Yh@030;B`/@2][Jd0Wi^P00H0Wi^P0P2][Jd00`28EPL0[Jf]0;3PiP0o0;3PiP40oooo
001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]0`2:QGD01@11JN40RXEe08Z5M@2][Jd0@FWQ0080
Y9j?1@11JN430:BNS`04045Yh@2aZid0[Jf]0:f][@80@FWQ0P2aZid2045Yh@D0/J^M0P11JN440;Vb
YP03045Yh@2i/ZH0^K:V00<0^K:V0P11JN430;VbYP040:f][@2n]j`0@FWQ045Yh@h0_[N/102][JdA
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00`0b<6k1011JN430<S1^`030:f][@37`K`0al6l00X0al6l1@2][Jd2
0<O1_0030:f][@36`;`0a/2l00/0a/2l1011JN400`36`;`0[Jf]0<>m^`020<>m^`03045Yh@33_K/0
`kfk00<0`kfk00<0@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^0060;ji^080[Jf]0`2n^KP0
0`2][Jd0];2a045Yh@030;B`/@80@FWQ0`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0
[Jf]0:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`040:f][@2:QGD0RXEe08Z5M@80@FWQ00<0
RXEe0:f][@11JN401@2TWXl2045Yh@<0Y9j?00@0@FWQ0;6[W@2aZid0/J^M0P11JN40102][Jd0/J^M
045Yh@11JN450;6[W@80@FWQ102i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ0`2i/ZH00`2][Jd0
_[N/045Yh@03045Yh@d0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00X0
b<6k1011JN450<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00X0
a/2l00<0@FWQ0<K0_036`;`00P36`;`00`11JN40[Jf]0<>m^`020<>m^`03045Yh@33_K/0`kfk00<0
`kfk00<0@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0
];2a045Yh@030;B`/@80@FWQ0`2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00<0L6ii0:f][@2]
[Jd0@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd308Z5M@04045Yh@2:QGD0[Jf]045Yh@H0
Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@030;6[W@80@FWQ00@0/J^M0:f][@11JN40@FWQ1@2aZid2
045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@<0^K:V00@0[Jf]0;jg[011JN40@FWQ1`2n
]j`00`11JN40_[N/0;jg[0050;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k00`0b<6k0P11JN450<S1^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0
_0020<K0_0@0@FWQ0`36`;`2045Yh@D0a/2l00D0@FWQ0<>m^`33_K/0`kfk045Yh@050<>m^`03045Y
h@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`2][Jd00`2n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@11JN40
0`2d/;42045Yh@<0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]
?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0[Jf]0080RXEe00@0
@FWQ08Z5M@11JN40@FWQ2P2TWXl01@11JN40/J^M0;6[W@2aZid0@FWQ00<0/J^M0P11JN420:f][@<0
/J^M00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ0P2i/ZH00`2][Jd0
_[N/0;jg[002045Yh@D0_[N/0P11JN400`2n]j`0@FWQ0;jg[0050;jg[0030:f][@31^[00`KZ`00X0
`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00`0b<6k0P11JN420<S1^`H0[Jf]4@37`K`00`2][Jd0
a/2l0<K0_004045Yh@@0a/2l0P11JN460<K0_0030:f][@33_K/0`kfk00H0`kfk0P11JN440<>m^`04
045Yh@33_K/0[Jf]0;ji^080[Jf]2P2n^KP00`2][Jd0];2a045Yh@030;B`/@80@FWQ0`2d/;400`2]
[Jd0Wi^P09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00L0[Jf]08Z5M@2:QGD0[Jf]08Z5M@11JN40RXEe0080@FWQ2P2T
WXl01@11JN40/J^M0;6[W@2aZid0@FWQ00<0/J^M0P11JN420;6[W@80[Jf]00<0/J^M045Yh@2i/ZH0
102i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[002045Yh@@0_[N/
0P11JN430;jg[080@FWQ102n]j`00`2][Jd0`KZ`045Yh@0?0<6j/0P0[Jf]4033_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/30:f][@80@FWQ
0P2][Jd30<S1^`030:f][@37`K`0al6l00h0al6l1011JN440<K0_080@FWQ1036`;`2045Yh@H0a/2l
00<0[Jf]0<>m^`33_K/01@33_K/2045Yh@D0`kfk00@0@FWQ0:f][@2][Jd0[Jf]302n^KP00`2][Jd0
];2a045Yh@030;B`/@03045Yh@2d/;40];2a0080];2a00<0[Jf]09nKX02OVj000P2][Jd309nKX003
0:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`090:f]
[@2:QGD0RXEe08Z5M@2][Jd0RXEe045Yh@2][Jd0@FWQ00X0Y9j?00D0[Jf]045Yh@2aZid0/J^M045Y
h@030;6[W@80@FWQ102aZid2045Yh@030:f][@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH00`2i
/ZH01@11JN40^K:V0;VbYP2i/ZH0[Jf]0080_[N/0P11JN440;jg[003045Yh@2n]j`0_[N/00@0_[N/
00P0@FWQ0;jg[02n]j`0_[N/0:f][@31^[00@FWQ0<6j/080@FWQ3P31^[000`2][Jd0`kfc0<>m/`03
0<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]
0<S1^`38`K/0b<6k202][Jd30<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_0080<O1_0<0@FWQ00<0
al6l045Yh@11JN400P11JN400`37`K`0[Jf]0<K0_0030<K0_080@FWQ1036`;`2045Yh@H0a/2l00<0
[Jf]0<>m^`33_K/01033_K/2045Yh@@0`kfk0P2][Jd00`11JN40`kfk0:f][@0=0;ji^0030:f][@2d
/;40@FWQ00<0];2a00<0@FWQ0;B`/@2d/;400P2d/;400`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`
KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0
RXEe0080RXEe00@0[Jf]08Z5M@2][Jd0@FWQ2P2TWXl0102][Jd0/J^M045Yh@11JN440;6[W@80@FWQ
102aZid2045Yh@060;VbYP2][Jd0[Jf]0:f][@2i/ZH0@FWQ1@2i/ZH01@11JN40^K:V0;VbYP2i/ZH0
[Jf]0080_[N/0P11JN440;jg[003045Yh@2n]j`0_[N/00@0_[N/00H0@FWQ0;jg[02n]j`0_[N/0:f]
[@31^[02045Yh@80`KZ`0P11JN4<0<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k00l0b<6k2@2][Jd;0<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_0050<O1_0<0@FWQ
1P37`K`2045Yh@030<O1_02][Jd0a/2l00<0a/2l0P11JN430<K0_080@FWQ1`36`;`00`2][Jd0`kfk
0<>m^`030<>m^`80@FWQ0P33_K/30:f][@80`kfk00<0@FWQ0<>m^`2][Jd03@2n^KP00`2][Jd0];2a
045Yh@030;B`/@03045Yh@2d/;40];2a0080];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]
?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2]
[Jd;0:BNS`030:f][@2aZid0/J^M00@0/J^M1011JN430;6[W@80@FWQ102i/ZH00`2][Jd0@FWQ0:f]
[@040;VbYP05045Yh@2i/ZH0^K:V0;VbYP2][Jd00P2n]j`2045Yh@<0_[N/0P11JN470;jg[004045Y
h@2n]j`0_[N/0:f][@80@FWQ1@31^[02045Yh@D0`KZ`00<0@FWQ0<6j/031^[000P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00<0
b<6k302][Jd50<S1^`030:f][@38`K/0b<6k00`0b<6k0P11JN450<S1^`030:f][@37`K`0al6l00L0
al6l00<0@FWQ0<O1_037`K`01037`K`2045Yh@030<O1_02][Jd0a/2l00<0a/2l0P11JN430<K0_080
@FWQ1`36`;`00`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33_K/0@FWQ0080[Jf]00<0@FWQ0<>m^`33
_K/00P33_K/00`11JN40`kfk0:f][@0=0;ji^0030:f][@2d/;40@FWQ0080];2a0P11JN440;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03
0:f][@2aZid0/J^M00D0/J^M0`11JN420;6[W@80@FWQ00<0[Jf]0;VbYP2i/ZH00`2i/ZH00`11JN40
^K:V0:f][@030:f][@05045Yh@2i/ZH0^K:V0;VbYP2][Jd00P2n]j`2045Yh@<0_[N/0P11JN490;jg
[0030:f][@31^[00@FWQ00L0`KZ`00<0@FWQ0<6j/031^[000P31^[000`11JN40`KZ`045Yh@030<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0<0<S1
^`80@FWQ0P38`K/5045Yh@P0al6l00<0@FWQ0<O1_037`K`01037`K`2045Yh@030<O1_02][Jd0a/2l
00<0a/2l0P11JN430<K0_080@FWQ1`36`;`00`2][Jd0`kfk0<>m^`020<>m^`80@FWQ00@0[Jf]0<>m
^`33_K/0@FWQ1033_K/00`11JN40`kfk0:f][@0=0;ji^0030:f][@2d/;40@FWQ0080];2a0P11JN42
0;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]
06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]2@2TWXl00`2][Jd0/J^M0;6[W@080;6[W@05045Yh@2a
Zid0@FWQ045Yh@2][Jd0102i/ZH2045Yh@D0^K:V00D0@FWQ0:f][@2][Jd0^K:V0:f][@020;jg[003
045Yh@2n]j`0_[N/0080_[N/0P11JN490;jg[0030:f][@31^[00@FWQ00L0`KZ`00<0@FWQ0<6j/031
^[000`31^[000`11JN40`KZ`0<6j/0020<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2@37`KX00`000000al6j0:f][@0F0<S1^`03
0:f][@38`K/0b<6k00P0b<6k0P11JN420<S1^`80@FWQ00<0b<6k045Yh@38`K/00P38`K/00`2][Jd0
@FWQ045Yh@070<O1_003045Yh@37`K`0al6l00@0al6l0P11JN400`37`K`0[Jf]0<K0_0030<K0_080
@FWQ0`36`;`2045Yh@L0a/2l00@0[Jf]0<>m^`2][Jd0[Jf]0P11JN440<>m^`03045Yh@33_K/0`kfk
0080`kfk00<0@FWQ0<>m^`2][Jd03@2n^KP00`2][Jd0];2a045Yh@020;B`/@04045Yh@2d/;40];2a
0:f][@80];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3o
ool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2T
WXl00`2][Jd0/J^M0;6[W@090;6[W@80@FWQ00<0/J^M0:f][@2i/ZH00`2i/ZH2045Yh@D0^K:V00<0
@FWQ0;VbYP2i/ZH00`2][Jd00`2n]j`0@FWQ0;jg[0030;jg[080@FWQ2@2n]j`00`2][Jd0`KZ`0<6j
/0070<6j/003045Yh@31^[00`KZ`00P0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<000000:f][@37`KP05@37`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01011JN430<S1^`03045Yh@38
`K/0b<6k0080b<6k0`11JN440<S1^`040:f][@11JN40al6l045Yh@H0al6l00<0@FWQ0<O1_037`K`0
1037`K`2045Yh@030<O1_02][Jd0a/2l00<0a/2l0P11JN430<K0_080@FWQ1@36`;`0102][Jd0@FWQ
0:f][@2][Jd20<>m^`03045Yh@33_K/0`kfk00<0`kfk0P11JN430<>m^`80@FWQ00<0[Jf]0;ji^02n
^KP02`2n^KP00`2][Jd0];2a045Yh@020;B`/@03045Yh@2][Jd0[Jf]00<0];2a00<0[Jf]09nKX02O
Vj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1S
H5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[
W@2aZid0302aZid00`2][Jd0^K:V0;VbYP020;VbYP<0@FWQ102i/ZH02011JN40^K:V0;VbYP2i/ZH0
[Jf]0;jg[02][Jd0@FWQ0P2][Jd20;jg[080@FWQ2@2n]j`00`2][Jd0`KZ`0<6j/0070<6j/003045Y
h@31^[00`KZ`00P0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k00P0b<6k0`11JN490<S1^`030:f][@11JN40@FWQ00@0b<6k00@0@FWQ0<S1^`38`K/0
@FWQ1038`K/3045Yh@@0b<6k00@0[Jf]0<O1_011JN40@FWQ1P37`K`00`11JN40al6l0<O1_0050<O1
_003045Yh@37`K`0[Jf]00@0a/2l0P11JN430<K0_080@FWQ1@2][Jd00`36`;`0@FWQ045Yh@030<>m
^`03045Yh@33_K/0`kfk0080`kfk0`11JN430<>m^`80@FWQ00<0[Jf]0;ji^02n^KP02`2n^KP00`2]
[Jd0];2a045Yh@02045Yh@030:f][@2d/;40];2a00<0];2a00<0[Jf]09nKX02OVj001@2OVj00102]
[Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP02
0;VbYP<0@FWQ0`2i/ZH2045Yh@<0^K:V00@0[Jf]0;jg[02n]j`0@FWQ0P2n]j`20:f][@80@FWQ2@2n
]j`00`2][Jd0`KZ`0<6j/0050<6j/0<0@FWQ2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00d0aKje1011JN430<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P040:f][@38`K/0@FWQ045Yh@<0b<6k1@11JN4;0<S1^`030:f]
[@11JN40@FWQ00D0b<6k0`11JN440<S1^`80@FWQ1@38`K/0102][Jd0al6l045Yh@11JN460<O1_003
045Yh@37`K`0al6l00D0al6l00<0@FWQ0<O1_02][Jd01036`;`2045Yh@030<K0_02][Jd0[Jf]0080
@FWQ1P36`;`2045Yh@<0`kfk00D0@FWQ0<>m^`33_K/0`kfk045Yh@020<>m^`04045Yh@33_K/0`kfk
0<>m^`80@FWQ00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0@FWQ045Yh@2][Jd70;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f]
[@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M00/0/J^M00<0
[Jf]0;VbYP2i/ZH00`2i/ZH2045Yh@040;VbYP11JN40^K:V0;VbYP80@FWQ0`2i/ZH0102][Jd0_[N/
0;jg[011JN440;jg[080@FWQ102][Jd50;jg[0030:f][@31^[00`KZ`00<0`KZ`0P11JN420<6j/003
045Yh@31^[00`KZ`00P0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@L0
@FWQ2036_kL6045Yh@P0a[ng00<0[Jf]0<O1^037`KP04`37`KP00`11JN40[Jf]0<O1^P030<O1^P03
045Yh@37`KX0al6j00`0al6j0`11JN400`37`KX0[Jf]0<S1^`02045Yh@H0b<6k0P11JN4;0<S1^`80
@FWQ1`38`K/2045Yh@D0b<6k0P11JN440<S1^`040:f][@37`K`0al6l045Yh@H0al6l00<0@FWQ0<O1
_037`K`01@37`K`00`11JN40al6l0:f][@020<K0_080[Jf]0P11JN40102][Jd0a/2l0<K0_036`;`2
045Yh@D0a/2l00<0@FWQ0:f][@33_K/00`33_K/01011JN40`kfk0<>m^`11JN460<>m^`80@FWQ00<0
[Jf]0;ji^02n^KP02`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f]
[@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl3
0:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH2045Yh@80^K:V0`11JN440;VbYP040:f][@2n]j`0
_[N/045Yh@@0_[N/0P11JN440;jg[080[Jf]00@0@FWQ0:f][@2n]j`0[Jf]0`31^[02045Yh@040<6j
/011JN40@FWQ045Yh@/0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80
@FWQ0`35_[D0102][Jd0a[ng045Yh@11JN480<Jo]`80@FWQ2P36_kL00`2][Jd0al6h0<O1^0020<O1
^0@0@FWQ1@37`KP00`11JN40al6h0<O1^0050<O1^003045Yh@2][Jd0al6j00<0al6j00<0@FWQ0<O1
^P37`KX02P37`KX2045Yh@<0al6j0P11JN400`38`K/0@FWQ045Yh@060<S1^`80@FWQ2`38`K/2045Y
h@L0b<6k0P11JN450<S1^`80@FWQ1038`K/0102][Jd0al6l0<O1_011JN460<O1_003045Yh@37`K`0
al6l00D0al6l00<0@FWQ0:f][@2][Jd00P2][Jd20<K0_080@FWQ1036`;`2045Yh@D0a/2l00<0@FWQ
0:f][@33_K/01033_K/2045Yh@L0`kfk0P11JN400`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;40
0`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11JN490;Vb
YP040:f][@2n]j`0_[N/045Yh@D0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@030;jg[02][Jd0
[Jf]0080[Jf]1011JN490<6j/003045Yh@31^[00`KZ`0080`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`02045Yh@L0a[ng0P11JN4:
0<Jo]`030:f][@37`KP0al6h0080@FWQ1037`KP2045Yh@030<O1^011JN40@FWQ00P0al6h00<0@FWQ
0:f][@37`KX00`37`KX00`11JN40al6j0<O1^P090<O1^P80@FWQ1@37`KX0102][Jd0@FWQ045Yh@11
JN460<S1^`80@FWQ2`38`K/2045Yh@L0b<6k0P11JN450<S1^`80@FWQ1038`K/0102][Jd0al6l0<O1
_011JN460<O1_003045Yh@37`K`0al6l00D0[Jf]00<0@FWQ0<O1_02][Jd01036`;`2045Yh@D0a/2l
00<0@FWQ0<K0_036`;`00P36`;`00`11JN40a/2l0:f][@0>0<>m^`80@FWQ00<0[Jf]0;ji^02n^KP0
202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V
0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2]
[Jd90;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11JN490;VbYP040:f][@11JN40_[N/045Yh@D0_[N/
0P11JN450;jg[005045Yh@2n]j`0_[N/0:f][@31^[000P11JN470:f][@D0`KZ`00<0@FWQ0<6j/031
^[000P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje0P11JN430<Fn]@04
0:f][@36_kL0a[ng0<Jo]`80@FWQ1P36_kL2045Yh@X0a[ng00@0[Jf]0<O1^011JN40@FWQ1P37`KP3
045Yh@P0al6h00<0@FWQ0<O1^011JN400`37`KX00`11JN40al6j045Yh@090<O1^P80@FWQ1P37`KX0
102][Jd0b<6k045Yh@11JN460<S1^`80@FWQ2`38`K/2045Yh@L0b<6k0P11JN450<S1^`80@FWQ1038
`K/0102][Jd0al6l0<O1_011JN440<O1_080[Jf]00<0@FWQ0:f][@2][Jd01@37`K`00`11JN40al6l
0:f][@040<K0_080@FWQ1P36`;`4045Yh@80a/2l00<0[Jf]0<>m^`33_K/03033_K/2045Yh@030:f]
[@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00
102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BN
S`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11
JN490;VbYP040:f][@2n]j`0@FWQ045Yh@H0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`01`11JN40_[N/
0;jg[02n]j`0[Jf]0<6j/011JN401`31^[000`11JN40[Jf]0:f][@030:f][@03045Yh@2][Jd0`KZ`
0080`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ0`35_[D0102]
[Jd0a[ng0<Jo]`36_kL2045Yh@H0a[ng0P11JN4:0<Jo]`040:f][@37`KP0@FWQ045Yh@L0al6h0P11
JN480<O1^0<0@FWQ00<0[Jf]0<O1^P37`KX00`11JN490<O1^P80@FWQ1P37`KX0102][Jd0b<6k045Y
h@11JN460<S1^`80@FWQ2`38`K/2045Yh@L0b<6k0P11JN450<S1^`80@FWQ1038`K/0102][Jd0al6l
0<O1_011JN440:f][@80al6l00<0@FWQ0<O1_037`K`01@37`K`00`11JN40al6l0:f][@040<K0_080
@FWQ3036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`80@FWQ00<0[Jf]0;ji^02n^KP00`2n^KP30:f][@D0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440
/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11JN490;VbYP030:f]
[@2n]j`0_[N/00P0_[N/00D0@FWQ0;jg[02n]j`0_[N/045Yh@030;jg[0030:f][@31^[00@FWQ00L0
`KZ`00<0@FWQ0<6j/031^[000`31^[000`11JN40`KZ`0:f][@060:f][A80`kfc00<0[Jf]0<Fn]@35
_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045Yh@D0a[ng0P11JN4:0<Jo]`04
0:f][@37`KP0@FWQ045Yh@L0al6h0P11JN480<O1^0<0@FWQ00<0[Jf]0<O1^P37`KX00`11JN420<O1
^P0300000037`KX0al6j00<0al6j0P11JN470<O1^P040:f][@38`K/0@FWQ045Yh@H0b<6k0P11JN4;
0<S1^`030:f][@11JN40@FWQ00H0b<6k0P11JN450<S1^`80@FWQ00<0b<6k0:f][@2][Jd00`2][Jd2
045Yh@H0al6l0P11JN450<O1_080@FWQ00<0al6l0:f][@36`;`00`36`;`2045Yh@d0a/2l00<0[Jf]
0<>m^`33_K/02`33_K/00`11JN40`kfk0:f][@030;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`/@09
0;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H00`2]
[Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid30:f]
[@030;6[W@2][Jd0^K:V00@0^K:V0P11JN490;VbYP030:f][@2n]j`0_[N/00T0_[N/0`11JN440;jg
[0030:f][@31^[00@FWQ00H0`KZ`0P11JN450<6j/003045Yh@31^[00`KZ`0080`KZ`00@0[Jf]0<>m
/`33_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje00l0aKje0P11JN430<Fn]@030:f][@36_kL0
a[ng0080a[ng0P11JN450<Jo]`80@FWQ2P36_kL0102][Jd0al6h045Yh@11JN470<O1^080@FWQ2037
`KP01011JN40al6h045Yh@2][Jd20<O1^P<0@FWQ2037`KX2045Yh@L0al6j00@0[Jf]0<S1^`11JN40
@FWQ1P38`K/2045Yh@/0b<6k00<0[Jf]0<S1^`0000000`11JN430<S1^`80@FWQ00<0b<6k0:f][@2]
[Jd00P2][Jd2045Yh@060:f][@38`K/0b<6k0<S1^`2][Jd0al6l0P11JN460<O1_080@FWQ1@37`K`2
045Yh@040<O1_02][Jd0a/2l0<K0_0@0@FWQ3@36`;`00`2][Jd0`kfk0<>m^`0;0<>m^`04045Yh@33
_K/0[Jf]0;ji^080[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P
00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2T
WXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@80^K:V1011JN490;VbYP030:f][@2n
]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00@FWQ1@31^[02045Yh@D0`KZ`00<0@FWQ0<6j/031^[00
0P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ
0`35_[D00`2][Jd0a[ng0<Jo]`020<Jo]`80@FWQ1@36_kL2045Yh@X0a[ng00@0[Jf]0<O1^011JN40
@FWQ1`37`KP2045Yh@P0al6h00@0@FWQ0<O1^011JN40[Jf]0P37`KX01011JN40al6j0<O1^P11JN47
0<O1^P80@FWQ1`37`KX0102][Jd0b<6k045Yh@11JN460<S1^`80@FWQ2`38`K/0102][Jd0b<6k0<S1
^`38`K/20:f][@D0@FWQ00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@@0b<6k00@0[Jf]0<O1_011JN40
@FWQ1P37`K`3045Yh@<0al6l0P11JN420<O1_0030:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m^`33
_K/03033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0
/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
2`2aZid00`2][Jd0^K:V0:f][@030:f][@80@FWQ2@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f]
[@31^[00`KZ`0<6j/080@FWQ0`31^[02045Yh@D0`KZ`00<0@FWQ0<6j/031^[000P31^[000`2][Jd0
`kfc0<>m/`0@0<>m/`T0[Jf]3035_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00`36_kL00`11JN40
a[ng0<Jo]`030<Jo]`80@FWQ2P36_kL00`2][Jd0al6h0<O1^002045Yh@H0al6h0P11JN470<O1^080
@FWQ00@0al6h045Yh@2][Jd0al6j0P11JN420<O1^P03045Yh@37`KX0al6j00D0al6j00<0@FWQ0<O1
^P37`KX01@37`KX7045Yh@@0b<6k0P11JN460<S1^`T0[Jf]1@38`K/2045Yh@D0b<6k0P11JN440<S1
^`030:f][@11JN40@FWQ00L0al6l0P11JN400`37`K`0@FWQ045Yh@02045Yh@<0al6l00<0[Jf]0<K0
_036`;`04@36`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2]
[Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2]
[Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP03
0:f][@2n]j`0@FWQ0100_[N/00<0[Jf]0<6j/031^[000`31^[03045Yh@030<6j/011JN40`KZ`00<0
`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@80
@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`030<Jo]`03045Yh@36_kL0a[ng00<0a[ng0P11JN4:0<Jo]`05
0:f][@37`KP0al6h0<O1^011JN401P37`KP2045Yh@L0al6h0P11JN420<O1^004045Yh@37`KX0@FWQ
045Yh@80al6j00<0@FWQ0<O1^P37`KX01@37`KX00`11JN40al6j0<O1^P060<O1^P030:f][@000000
b<6k00<0b<6k102][Jd2045Yh@H0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0
b<6k00@0b<6k0P11JN440<S1^`030:f][@11JN40al6l00L0al6l0P11JN490<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0
0`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[
W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/045Yh@0@0;jg
[0030:f][@31^[00`KZ`00`0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D03`35_[D2045Yh@T0[Jf]00<0@FWQ0:f][@2][Jd00`2][Jd2045Yh@X0a[ng00<0[Jf]0<O1
^037`KP00P37`KP3045Yh@<0al6h0P11JN470<O1^006045Yh@37`KP0al6h0<O1^011JN40al6j0P11
JN420<O1^P03045Yh@37`KX0al6j00<0al6j0P2][Jd00`11JN40[Jf]0:f][@0<0:f][@@0b<6k0`11
JN440<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0[Jf]045Yh@11JN401P38`K/00`11JN40b<6k0<S1
^`040<S1^`<0@FWQ0`38`K/00`11JN40al6l0<O1_0070<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0
[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP030:f][@2TWXl0
Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V
0:f][@2n]j`00P11JN4?0;jg[0030:f][@31^[00`KZ`00`0`KZ`0P11JN440<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00`36_kL0
0`11JN40a[ng0<Jo]`030<Jo]`80@FWQ4P2][Jd5045Yh@L0[Jf]00H0@FWQ0:f][@2][Jd0[Jf]045Y
h@2][Jd2045Yh@<0[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd20<O1^P03045Yh@37`KX0al6j00H0al6j
00<0[Jf]0<S1^`38`K/01`38`K/3045Yh@<0b<6k0P11JN450<S1^`030:f][@11JN40@FWQ00D0b<6k
00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@050<S1^`11JN40@FWQ045Yh@2][Jd02@37`K`2045Yh@T0
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]00<0@FWQ0;jg[02n]j`0
3P2n]j`00`2][Jd0`KZ`0<6j/00<0<6j/080@FWQ1031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00l0aKje0P11JN430<Fn]@030:f][@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL0
0`36_kL3045Yh@T0a[ng00<0[Jf]0<O1^037`KP02037`KP2045Yh@L0al6h00H0@FWQ0<O1^037`KP0
al6h045Yh@37`KX2045Yh@<0al6j00<0@FWQ0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P060<O1
^P030:f][@38`K/0b<6k00L0b<6k0`11JN430<S1^`03045Yh@38`K/0@FWQ00@0b<6k00<0[Jf]0<S1
^`11JN401038`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ1P38`K/00`2][Jd0al6l0<O1_0070<O1
_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_0020<K0_003045Yh@36`;`0a/2l00T0a/2l102][Jd>0<>m
^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3P
iP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`00`0`KZ`0P11JN440<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36
_kL00`36_kL00`11JN40a[ng0<Jo]`030<Jo]`<0@FWQ1036_kL00`11JN40a[ng0<Jo]`020<Jo]`03
0:f][@37`KP0al6h0080@FWQ1P37`KP00`11JN40al6h0<O1^0060<O1^007045Yh@37`KP0al6h0<O1
^011JN40al6j045Yh@040<O1^P03045Yh@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37`KX01P37`KX0
0`2][Jd0b<6k0<S1^`070<S1^`80@FWQ00<0b<6k045Yh@38`K/00P38`K/2045Yh@@0b<6k00<0[Jf]
0<S1^`38`K/01@11JN4>0<S1^`030:f][@37`K`0al6l00L0al6l0P11JN490<O1_0040:f][@36`;`0
a/2l0<K0_080@FWQ1P36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`4
0:f][@T0_[N/00<0[Jf]0<6j/031^[003031^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`030<Jo]`03045Yh@36_kL0
a[ng00<0a[ng0`11JN440<Jo]`80@FWQ0`36_kL00`2][Jd0al6h0<O1^002045Yh@H0al6h00<0@FWQ
0<O1^037`KP01@37`KP00`11JN40al6h0<O1^0020<O1^0030:f][@11JN40@FWQ00@0al6j00<0@FWQ
0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P060<O1^P030:f][@38`K/0b<6k00L0b<6k0P11JN42
0<S1^`@0@FWQ1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00L0al6l0P11JN49
0<O1_0030:f][@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`0102][Jd70<K0_0030:f][@33_K/0
`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`/@2d/;420:f][E00/>3V0@3o
ool006T0/>3V0P2][Jd20:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00<0<6j/080@FWQ1031^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje0P11JN430<Fn]@030:f][@36_kL0
a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL00`36_kL2045Yh@030<Jo]`11JN40a[ng0080a[ng0P11JN43
0<Jo]`050:f][@37`KP0al6h0<O1^011JN401@37`KP00`11JN40al6h0<O1^0060<O1^003045Yh@37
`KP0al6h0080al6h00<0[Jf]045Yh@11JN401@37`KX00`11JN40al6j0<O1^P030<O1^P03045Yh@00
0000al6j00H0al6j00<0[Jf]0<S1^`38`K/01@38`K/3045Yh@`0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_0070<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][E80/>3V
0@3oool006/0/>3V0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n
]j`40:f][@030;jg[02][Jd0`KZ`00d0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00`36_kL01011JN40a[ng0<Jo
]`36_kL4045Yh@80a[ng1011JN440<Jo]`030:f][@37`KP0al6h0080al6h1@11JN460<O1^0L0@FWQ
00@0al6h0:f][@11JN40@FWQ0P37`KX6045Yh@<0al6j00<0@FWQ0<O1^P37`KX01P37`KX0102][Jd0
b<6k0<S1^`11JN4C0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01`37`K`2045Y
h@L0al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f]
[E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`03`2n]j`50:f][@/0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045YhA40a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0;0<O1^P80@FWQ1`37`KX0102][Jd0b<6k0<S1^`11JN4C0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`4045Yh@80al6l1@2][Jd20<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji
^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]1@31^[000`11JN40`KZ`0<6j/0020<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[D2045Yh@<0aKje00<0[Jf]0<Jo
]`36_kL00P36_kL2045YhA40a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0;0<O1
^P80@FWQ1`37`KX0102][Jd0b<6k045Yh@11JN4C0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`01@37`K`60:f][@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40oooo001a0;3PiP<0[Jf]202aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002031^[070:f]
[@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ0`35_[D0102]
[Jd0a[ng0<Jo]`36_kL2045YhA80a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0;
0<O1^P80@FWQ1`37`KX0102][Jd0b<6k045Yh@11JN4C0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB
0<>m/`030:f][@35_[D0aKje00l0aKje0P11JN430<Fn]@040:f][@36_kL0a[ng0<Jo]`80@FWQ4P36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00`0al6j0P11JN460<O1^P040:f][@38
`K/0@FWQ045YhA<0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo
001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D0
3`35_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00P11JN4C0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX03@37`KX2045Yh@D0al6j00@0[Jf]045Yh@11JN40@FWQ4`38`K/00`2][Jd0
b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V
0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ
0`35_[D0102][Jd0a[ng045Yh@11JN4D0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX03P37`KX2045Yh@@0al6j00@0@FWQ0<S1^`38`K/0@FWQ4`38`K/0102][Jd0b<6k0<S1^`38`K/8
0:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][@T0aKje2`11JN4E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX03`37`KX5045Yh@040:f][@38`K/0b<6k
045Yh@h0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0
aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0
`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg
[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0
a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V
0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37
`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f]
[IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0
[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V
0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52508 .3309 m
.53177 .33087 L
s
.52174 .33411 m
.52508 .3309 L
s
.53177 .33087 m
.53512 .33404 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53845 .3308 m
.53679 .33723 L
s
.5067 .33079 m
.50502 .33398 L
s
.50836 .33402 m
.5067 .33079 L
s
.52007 .33732 m
.52174 .33411 L
s
.53512 .33404 m
.53679 .33723 L
s
.50669 .33721 m
.50836 .33402 L
s
.50502 .33398 m
.50669 .33721 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55847 .33034 m
.55348 .3337 L
s
.56179 .33024 m
.55847 .33034 L
s
.5 Mabswid
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51099 .33856 m
.52258 .33862 L
s
0 0 0 r
.56955 .34555 m
.57021 .34923 L
s
.57105 .34455 m
.57187 .34916 L
s
.5326 .35914 m
.53348 .35981 L
s
.255 .412 .882 r
.54741 .34061 m
.5507 .33828 L
s
.5507 .33828 m
.55565 .33814 L
s
.54575 .34064 m
.5507 .33828 L
s
.4928 .33823 m
.4961 .34056 L
s
.47633 .33768 m
.4928 .33823 L
s
.4928 .33823 m
.49775 .3406 L
s
.54411 .34518 m
.54575 .34064 L
s
.54577 .34515 m
.54741 .34061 L
s
.49775 .3406 m
.50104 .34518 L
s
0 0 0 r
.58506 .33885 m
.58773 .3334 L
s
.255 .412 .882 r
.55565 .33814 m
.55896 .3403 L
s
0 0 0 r
.53616 .35913 m
.53683 .35978 L
s
.255 .412 .882 r
.4961 .34056 m
.49939 .34515 L
s
0 0 0 r
.59488 .32863 m
.59817 .33161 L
s
.255 .412 .882 r
.54411 .34518 m
.54412 .3497 L
s
0 0 0 r
.53684 .36301 m
.53348 .35981 L
s
.255 .412 .882 r
.50104 .34518 m
.50269 .34972 L
s
.54577 .34515 m
.54578 .34967 L
s
.49939 .34515 m
.50103 .34969 L
s
0 0 0 r
.53852 .36299 m
.53683 .35978 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56718 .33775 m
.56883 .33769 L
s
.56391 .34013 m
.56718 .33775 L
s
.56555 .34007 m
.56718 .33775 L
s
0 0 0 r
.53852 .36622 m
.53684 .36301 L
s
.255 .412 .882 r
.50269 .34972 m
.50433 .35653 L
s
.54412 .3497 m
.54579 .35419 L
s
.50103 .34969 m
.50267 .3565 L
s
.54578 .34967 m
.54745 .35415 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56393 .34465 m
.56555 .34007 L
s
.56228 .3447 m
.56391 .34013 L
s
0 0 0 r
.55023 .35906 m
.55025 .36277 L
s
.255 .412 .882 r
.55896 .3403 m
.56228 .3447 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48268 .38554 m
.48291 .33793 L
s
.48102 .38548 m
.48126 .33787 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5176 .35666 m
.51926 .36346 L
s
.51759 .37026 m
.51761 .33861 L
s
.51593 .37025 m
.51595 .3386 L
s
0 0 0 r
.5049 .39215 m
.50505 .38869 L
s
.50812 .38868 m
.50826 .39219 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56393 .34465 m
.56401 .36048 L
s
.56228 .3447 m
.56238 .36507 L
s
.54579 .35419 m
.55077 .35634 L
s
.54745 .35415 m
.55077 .35634 L
s
.5043 .36786 m
.50433 .35653 L
s
.50264 .36783 m
.50267 .3565 L
s
.55077 .35634 m
.5607 .35833 L
s
0 0 0 r
.50658 .39217 m
.50659 .38869 L
s
.255 .412 .882 r
.51926 .36346 m
.52258 .368 L
s
.52922 .36571 m
.53088 .36344 L
s
.53088 .36344 m
.53255 .36569 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52922 .36571 m
.53089 .36797 L
s
.53255 .36569 m
.53255 .36796 L
s
.54582 .36324 m
.54582 .36551 L
s
.54582 .36324 m
.54748 .36321 L
s
.5607 .35833 m
.56236 .36054 L
s
.54748 .36321 m
.54748 .36547 L
s
.52258 .368 m
.5259 .37026 L
s
.53089 .37024 m
.53255 .36796 L
s
.54582 .36551 m
.54749 .36774 L
s
.50263 .37464 m
.5043 .36786 L
s
.50097 .37461 m
.50264 .36783 L
s
.5259 .37026 m
.53089 .37024 L
s
.56238 .36507 m
.56401 .36048 L
s
.51094 .37021 m
.51759 .37026 L
s
.54749 .36774 m
.55081 .36994 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60328 .35211 m
.6033 .35388 L
s
.60491 .35092 m
.60494 .35377 L
s
.255 .412 .882 r
.56074 .3674 m
.56238 .36507 L
s
.55081 .36994 m
.55744 .36977 L
s
.55744 .36977 m
.56074 .3674 L
s
.50095 .37916 m
.50263 .37464 L
s
.49929 .37913 m
.50097 .37461 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49762 .38365 m
.50095 .37916 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57889 .36896 m
.58363 .34377 L
s
.57724 .36903 m
.58358 .33699 L
s
.58358 .33699 m
.59037 .36836 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60288 .35656 m
.6033 .35388 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.592 .36827 m
.59667 .343 L
s
.59037 .36836 m
.59661 .33621 L
s
.59661 .33621 m
.6034 .36754 L
s
.49596 .38362 m
.49929 .37913 L
s
.57231 .36925 m
.58382 .36871 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58383 .39531 m
.58384 .39733 L
s
.58548 .39421 m
.58551 .39724 L
s
.255 .412 .882 r
.49263 .38582 m
.49762 .38365 L
s
.49263 .38582 m
.49596 .38362 L
s
.47606 .38531 m
.49263 .38582 L
s
.6208 .33661 m
.62556 .33391 L
s
.61766 .34142 m
.6208 .33661 L
s
.6161 .3461 m
.61766 .34142 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6224 .33647 m
.62556 .33391 L
s
.61926 .34129 m
.6224 .33647 L
s
.61771 .34596 m
.61926 .34129 L
s
.62556 .33391 m
.62874 .33361 L
s
.61457 .35304 m
.6161 .3461 L
s
.61618 .35291 m
.61771 .34596 L
s
.62874 .33361 m
.63352 .3354 L
s
.59853 .36787 m
.60827 .3672 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58384 .39733 m
.59049 .39699 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63352 .3354 m
.63675 .33962 L
s
.63665 .33281 m
.63691 .35101 L
s
.63823 .33264 m
.63848 .35085 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61618 .35291 m
.61631 .3643 L
s
.61457 .35304 m
.6147 .36443 L
s
.6147 .36443 m
.61639 .37115 L
s
.61631 .3643 m
.618 .37102 L
s
.61639 .37115 m
.61805 .37559 L
s
.618 .37102 m
.61966 .37546 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61805 .37559 m
.62133 .3799 L
s
.61966 .37546 m
.62293 .37977 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63215 .35148 m
.64321 .35034 L
s
.64763 .33159 m
.65848 .33026 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62133 .3799 m
.62617 .38179 L
s
.62293 .37977 m
.62617 .38179 L
s
.38816 .33499 m
.38974 .3329 L
s
.38823 .33043 m
.38974 .3329 L
s
.38665 .33251 m
.38823 .33043 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38665 .33251 m
.38816 .33499 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62617 .38179 m
.62936 .3815 L
s
.63871 .36684 m
.63891 .3806 L
s
.63723 .37387 m
.63871 .36684 L
s
.62936 .3815 m
.63411 .37877 L
s
.63411 .37877 m
.63723 .37387 L
s
.63723 .37387 m
.63891 .3806 L
s
0 0 0 r
.686 .31855 m
.68808 .31823 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38797 .3464 m
.38906 .37412 L
s
.38596 .37375 m
.38797 .3464 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64812 .36355 m
.65436 .36284 L
s
.65414 .3491 m
.65581 .35577 L
s
.65385 .33085 m
.65436 .36284 L
s
.6523 .33104 m
.65281 .36302 L
s
.65581 .35577 m
.65898 .35998 L
s
.37441 .33086 m
.37589 .33336 L
s
.37576 .34022 m
.37589 .33336 L
s
.37142 .32814 m
.37441 .33086 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3654 .32723 m
.37142 .32814 L
s
.37424 .34001 m
.37581 .33793 L
s
.38751 .37393 m
.38774 .36015 L
s
.3742 .3423 m
.37576 .34022 L
s
.65898 .35998 m
.66211 .3619 L
s
.37117 .34187 m
.37424 .34001 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37112 .34416 m
.3742 .3423 L
s
.36236 .32906 m
.3654 .32723 L
s
.66211 .3619 m
.66672 .3613 L
s
.66511 .35691 m
.66668 .35901 L
s
.66511 .35691 m
.6666 .35441 L
s
.6666 .35441 m
.66817 .35651 L
s
.67982 .32955 m
.68426 .32656 L
s
.67841 .33436 m
.67982 .32955 L
s
.38743 .37854 m
.38906 .37412 L
s
.67841 .33436 m
.67849 .33894 L
s
.37395 .35606 m
.37556 .35168 L
s
.37539 .36087 m
.37556 .35168 L
s
.68132 .32932 m
.68426 .32656 L
s
.67991 .33413 m
.68132 .32932 L
s
.66817 .35651 m
.66821 .3588 L
s
.67991 .33413 m
.68 .33872 L
s
.38596 .37375 m
.38743 .37854 L
s
.66672 .3613 m
.66821 .3588 L
s
.36083 .33111 m
.36236 .32906 L
s
.68426 .32656 m
.68871 .32584 L
s
.67849 .33894 m
.68009 .34331 L
s
.68 .33872 m
.68159 .34308 L
s
.37239 .35815 m
.37395 .35606 L
s
.37395 .35606 m
.37539 .36087 L
s
.35943 .32629 m
.36083 .33111 L
s
.35925 .33546 m
.35943 .32629 L
s
.35925 .33546 m
.36083 .33111 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68009 .34331 m
.68463 .34492 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3635 .34765 m
.37112 .34416 L
s
.36355 .34535 m
.37117 .34187 L
s
.36931 .36003 m
.37239 .35815 L
s
.68871 .32584 m
.69171 .32765 L
s
.68159 .34308 m
.68463 .34492 L
s
.36051 .34719 m
.36355 .34535 L
s
.36046 .34949 m
.3635 .34765 L
s
.36328 .35916 m
.36931 .36003 L
s
.68026 .3525 m
.68031 .3548 L
s
.68026 .3525 m
.68177 .35228 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69171 .32765 m
.69475 .33174 L
s
.68463 .34492 m
.69357 .3458 L
s
.68031 .3548 m
.68186 .35689 L
s
.68177 .35228 m
.68181 .35458 L
s
.35897 .34926 m
.36051 .34719 L
s
.70297 .30723 m
.71296 .30527 L
s
.35892 .35156 m
.36046 .34949 L
s
.68186 .35689 m
.6849 .35874 L
s
.69612 .32689 m
.69898 .32408 L
s
.69475 .33174 m
.69612 .32689 L
s
.35888 .35387 m
.35897 .34926 L
s
.36032 .3564 m
.36328 .35916 L
s
.69758 .32664 m
.69898 .32408 L
s
.69621 .33149 m
.69758 .32664 L
s
.69898 .32408 m
.70044 .32382 L
s
.35888 .35387 m
.36032 .3564 L
s
.69621 .33149 m
.69656 .34762 L
s
.34615 .32634 m
.34897 .33145 L
s
.6849 .35874 m
.69086 .35782 L
s
.34186 .32326 m
.34615 .32634 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69357 .3458 m
.69509 .34786 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33898 .32272 m
.34186 .32326 L
s
.33606 .32448 m
.33898 .32272 L
s
.33464 .3242 m
.33898 .32272 L
s
.34858 .34989 m
.34862 .34758 L
s
.34721 .34503 m
.34862 .34758 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69519 .35248 m
.69656 .34762 L
s
.69086 .35782 m
.69376 .35503 L
s
.7087 .30612 m
.70981 .35458 L
s
.70727 .3064 m
.70838 .35484 L
s
.69475 .33174 m
.69519 .35248 L
s
.69376 .35503 m
.69519 .35248 L
s
.3457 .34708 m
.34721 .34503 L
s
.34555 .35402 m
.34858 .34989 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3457 .34708 m
.34711 .34964 L
s
.33311 .32854 m
.33606 .32448 L
s
.33169 .32826 m
.33464 .3242 L
s
.70923 .32913 m
.71197 .32396 L
s
.34259 .35583 m
.34555 .35402 L
s
.71197 .32396 m
.71475 .32109 L
s
.71475 .32109 m
.71757 .32052 L
s
.33153 .33519 m
.33311 .32854 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33825 .35507 m
.34259 .35583 L
s
.33011 .33492 m
.33169 .32826 L
s
.70405 .35562 m
.70981 .35458 L
s
.71757 .32052 m
.72042 .32225 L
s
.71757 .32052 m
.72181 .32196 L
s
.33142 .33982 m
.33153 .33519 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70965 .34762 m
.71262 .35173 L
s
.33543 .35222 m
.33825 .35507 L
s
.334 .35196 m
.33825 .35507 L
s
.31517 .31779 m
.32483 .3199 L
s
.33 .33955 m
.33011 .33492 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33142 .33982 m
.33268 .34705 L
s
.72042 .32225 m
.72332 .32629 L
s
.33268 .34705 m
.33543 .35222 L
s
.33 .33955 m
.33125 .34678 L
s
.72181 .32196 m
.7247 .326 L
s
.33125 .34678 m
.334 .35196 L
s
.71262 .35173 m
.71552 .35351 L
s
.72332 .32629 m
.72488 .33295 L
s
.7247 .326 m
.72626 .33266 L
s
.71552 .35351 m
.71834 .35296 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31985 .35152 m
.32066 .31901 L
s
.31847 .35123 m
.31929 .31871 L
s
.72488 .33295 m
.72499 .3376 L
s
.71834 .35296 m
.7211 .35008 L
s
.71834 .35296 m
.7225 .3498 L
s
.72626 .33266 m
.72637 .3373 L
s
.72378 .34486 m
.72499 .3376 L
s
.7211 .35008 m
.72378 .34486 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73068 .33692 m
.73074 .33923 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72516 .34457 m
.72637 .3373 L
s
.7225 .3498 m
.72516 .34457 L
s
.7341 .3169 m
.74344 .31465 L
s
.30045 .31427 m
.30975 .31654 L
s
.31434 .35036 m
.31985 .35152 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30505 .34122 m
.30574 .31558 L
s
.30372 .34091 m
.30441 .31526 L
s
.31806 .36759 m
.31951 .36553 L
s
.31818 .36291 m
.31951 .36553 L
s
.31673 .36497 m
.31818 .36291 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73145 .36723 m
.73151 .36956 L
s
.5 Mabswid
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31673 .36497 m
.31806 .36759 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74015 .34127 m
.74294 .34532 L
s
.30359 .34559 m
.30505 .34122 L
s
.74867 .31332 m
.75764 .3109 L
s
.30226 .34528 m
.30372 .34091 L
s
.28631 .3105 m
.29524 .31293 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29955 .34699 m
.30359 .34559 L
s
.74294 .34532 m
.74697 .34672 L
s
.29955 .34699 m
.30226 .34528 L
s
.75255 .31229 m
.75328 .33805 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73538 .36591 m
.74078 .36471 L
s
.73946 .31563 m
.74078 .36471 L
s
.73813 .31595 m
.73943 .36502 L
s
.75383 .31195 m
.75456 .33771 L
s
.28997 .36123 m
.29138 .3119 L
s
.28869 .36091 m
.29011 .31155 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29692 .34635 m
.29955 .34699 L
s
.74697 .34672 m
.74959 .34607 L
s
.29309 .34303 m
.29692 .34635 L
s
.74959 .34607 m
.75212 .34307 L
s
.74959 .34607 m
.75341 .34274 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75212 .34307 m
.75328 .33805 L
s
.29064 .33766 m
.29309 .34303 L
s
.75341 .34274 m
.75456 .33771 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76635 .30838 m
.76734 .34136 L
s
.76757 .30801 m
.76857 .341 L
s
.76265 .30947 m
.77121 .3069 L
s
.28487 .35992 m
.28997 .36123 L
s
.27515 .30957 m
.27743 .31501 L
s
.27743 .31501 m
.27844 .32243 L
s
.2783 .32714 m
.27844 .32243 L
s
.27162 .30609 m
.27515 .30957 L
s
.27394 .3092 m
.27621 .31464 L
s
.27621 .31464 m
.27722 .32207 L
s
.27708 .32678 m
.27722 .32207 L
s
.27686 .33386 m
.2783 .32714 L
s
.76362 .3424 m
.76857 .341 L
s
.27162 .30609 m
.27394 .3092 L
s
.26054 .28568 m
.26859 .28848 L
s
.27564 .3335 m
.27708 .32678 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26925 .30533 m
.27162 .30609 L
s
.27428 .33788 m
.27686 .33386 L
s
.27307 .33752 m
.27564 .3335 L
s
.26683 .30692 m
.26925 .30533 L
s
.26352 .33695 m
.26511 .28729 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26236 .33658 m
.26396 .28689 L
s
.76653 .35591 m
.7677 .3532 L
s
.76653 .35591 m
.76784 .35794 L
s
.2706 .33917 m
.27428 .33788 L
s
.7677 .3532 m
.769 .35523 L
s
.77737 .31207 m
.77956 .30658 L
s
.77641 .31954 m
.77737 .31207 L
s
.26435 .31087 m
.26683 .30692 L
s
.2706 .33917 m
.27307 .33752 L
s
.77641 .31954 m
.77656 .32427 L
s
.76784 .35794 m
.769 .35523 L
s
.77956 .30658 m
.78295 .30305 L
s
.77854 .31169 m
.78072 .30619 L
s
.77759 .31916 m
.77854 .31169 L
s
.77759 .31916 m
.77774 .32389 L
s
.77656 .32427 m
.77797 .331 L
s
.78072 .30619 m
.78295 .30305 L
s
.77774 .32389 m
.77914 .33063 L
s
.26821 .33844 m
.2706 .33917 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78295 .30305 m
.78522 .30225 L
s
.77797 .331 m
.78046 .335 L
s
0 0 0 r
.25005 .291 m
.25109 .29138 L
s
.255 .412 .882 r
.26593 .33532 m
.26821 .33844 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77914 .33063 m
.78163 .33463 L
s
.78522 .30225 m
.78867 .30342 L
s
.26375 .32982 m
.26593 .33532 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78046 .335 m
.78401 .33625 L
s
.25664 .30099 m
.25775 .3014 L
s
.78163 .33463 m
.78401 .33625 L
s
.25435 .30255 m
.25664 .30099 L
s
.25545 .30296 m
.25664 .30099 L
s
.25893 .33544 m
.26352 .33695 L
s
.78867 .30342 m
.79105 .30735 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25419 .3073 m
.25545 .30296 L
s
.78401 .33625 m
.78744 .33511 L
s
.25309 .30689 m
.25435 .30255 L
s
.25364 .32396 m
.25419 .3073 L
s
.25107 .30132 m
.25309 .30689 L
s
.25237 .32834 m
.25309 .30689 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78937 .3248 m
.79041 .32203 L
s
.78937 .3248 m
.79057 .32679 L
s
.78744 .33511 m
.78961 .33196 L
s
.79041 .32203 m
.7916 .32401 L
s
.249 .29811 m
.25107 .30132 L
s
.78961 .33196 m
.79168 .3264 L
s
.7916 .32401 m
.79168 .3264 L
s
.25237 .32834 m
.25364 .32396 L
s
.24582 .29685 m
.249 .29811 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25152 .32078 m
.25253 .32356 L
s
.24517 .31594 m
.25152 .32078 L
s
.79837 .29733 m
.79958 .30167 L
s
.79837 .29733 m
.79869 .30686 L
s
.2512 .33033 m
.25237 .32834 L
s
.24365 .29838 m
.24582 .29685 L
s
.24262 .29795 m
.24582 .29685 L
s
.24895 .33193 m
.2512 .33033 L
s
.79869 .30686 m
.79958 .30167 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80062 .31898 m
.80078 .31668 L
s
.5 Mabswid
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79958 .30167 m
.80055 .29887 L
s
.80055 .29887 m
.80254 .29563 L
s
.24246 .30273 m
.24365 .29838 L
s
.80254 .29563 m
.80661 .2939 L
s
.24468 .33033 m
.24895 .33193 L
s
.24143 .3023 m
.24262 .29795 L
s
.79918 .3212 m
.80015 .31839 L
s
.79918 .3212 m
.79934 .32599 L
s
.24316 .31272 m
.24517 .31594 L
s
.24212 .3123 m
.24517 .31594 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79926 .32359 m
.80024 .32079 L
s
.80015 .31839 m
.80217 .31517 L
s
.24229 .30751 m
.24246 .30273 L
s
.79934 .32599 m
.80048 .32798 L
s
.80024 .32079 m
.80225 .31757 L
s
.24229 .30751 m
.24316 .31272 L
s
.24126 .30709 m
.24143 .3023 L
s
.24126 .30709 m
.24212 .3123 L
s
.24266 .32711 m
.24468 .33033 L
s
.80661 .2939 m
.80868 .29541 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80225 .31757 m
.8072 .31066 L
s
.80048 .32798 m
.80266 .32957 L
s
.80217 .31517 m
.80711 .30827 L
s
.24179 .32189 m
.24283 .32231 L
s
.24275 .32471 m
.24283 .32231 L
s
.24171 .32429 m
.24266 .32711 L
s
.24171 .32429 m
.24179 .32189 L
s
.80266 .32957 m
.80678 .32792 L
s
.80868 .29541 m
.80976 .29737 L
s
.80711 .30827 m
.80902 .305 L
s
.8072 .31066 m
.80911 .30741 L
s
.80976 .29737 m
.81001 .30457 L
s
.80902 .305 m
.80993 .30217 L
s
.80911 .30741 m
.81001 .30457 L
s
.80678 .32792 m
.80871 .32467 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80871 .32467 m
.80962 .32184 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80962 .32184 m
.81044 .3166 L
s
.80962 .32184 m
.81078 .32624 L
s
.81044 .3166 m
.81078 .32624 L
s
.23277 .31809 m
.23366 .32093 L
s
.23357 .32334 m
.23366 .32093 L
s
.22262 .28616 m
.22897 .28938 L
s
.23251 .32533 m
.23357 .32334 L
s
.23171 .32007 m
.23277 .31809 L
s
.81638 .29185 m
.81722 .28899 L
s
.81638 .29185 m
.8174 .2938 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81722 .28899 m
.81823 .29094 L
s
.23171 .32007 m
.2326 .32292 L
s
.22963 .32405 m
.23251 .32533 L
s
.8174 .2938 m
.81823 .29094 L
s
.22496 .32187 m
.2262 .28801 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22405 .32143 m
.2253 .28755 L
s
.81784 .30586 m
.81982 .33452 L
s
.81784 .30586 m
.81796 .33538 L
s
.22783 .32076 m
.22963 .32405 L
s
.22614 .31503 m
.22783 .32076 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22549 .30732 m
.22614 .31503 L
s
.81836 .32038 m
.8189 .33495 L
s
.81796 .33538 m
.81907 .33982 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22136 .3201 m
.22496 .32187 L
s
.81907 .33982 m
.81982 .33452 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21674 .30276 m
.21748 .28333 L
s
.21345 .30089 m
.21929 .30415 L
s
.21591 .30229 m
.21664 .28285 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21491 .28432 m
.21637 .29013 L
s
.21261 .28044 m
.21491 .28432 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21105 .27947 m
.21261 .28044 L
s
.21554 .33453 m
.21609 .31984 L
s
.21498 .32673 m
.21609 .31984 L
s
.20942 .28093 m
.21105 .27947 L
s
.20867 .28044 m
.21105 .27947 L
s
.21314 .33073 m
.21498 .32673 L
s
.21498 .32673 m
.21554 .33453 L
s
.20774 .28483 m
.20942 .28093 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.207 .28434 m
.20867 .28044 L
s
.21063 .33184 m
.21314 .33073 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20681 .28924 m
.20774 .28483 L
s
.20608 .28875 m
.207 .28434 L
s
.20579 .29611 m
.20681 .28924 L
s
0 0 0 r
.19921 .26809 m
.20006 .26672 L
s
.255 .412 .882 r
.20906 .33093 m
.21063 .33184 L
s
.20507 .29562 m
.20608 .28875 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20761 .32754 m
.20906 .33093 L
s
.20686 .32708 m
.20906 .33093 L
s
.20531 .3084 m
.20579 .29611 L
s
.20459 .30793 m
.20507 .29562 L
s
.2063 .32168 m
.20761 .32754 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20531 .3084 m
.20575 .31627 L
s
.20556 .32121 m
.20686 .32708 L
s
.20575 .31627 m
.2063 .32168 L
s
.20459 .30793 m
.20502 .3158 L
s
.20502 .3158 m
.20556 .32121 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84581 .27132 m
.84789 .32331 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19772 .30554 m
.20168 .30847 L
s
.84644 .27081 m
.84853 .32283 L
s
.19848 .27043 m
.19966 .30701 L
s
.19466 .30307 m
.19848 .27043 L
s
.19525 .30357 m
.19818 .27782 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84386 .27286 m
.85006 .2677 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85006 .2677 m
.85129 .26913 L
s
.85006 .2677 m
.85185 .26861 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85129 .26913 m
.85259 .27304 L
s
.19378 .26627 m
.19466 .30307 L
s
.19021 .29905 m
.19378 .26627 L
s
.85185 .26861 m
.85313 .27252 L
s
.19074 .29956 m
.19348 .2737 L
s
.85259 .27304 m
.85334 .27749 L
s
.85313 .27252 m
.85386 .27697 L
s
.85334 .27749 m
.85417 .28444 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84593 .32474 m
.85218 .31993 L
s
.85386 .27697 m
.85469 .28393 L
s
.1887 .29752 m
.19236 .30107 L
s
.85218 .31993 m
.85322 .31644 L
s
.85218 .31993 m
.85378 .31595 L
s
.85417 .28444 m
.85468 .29693 L
s
.85469 .28393 m
.8552 .29642 L
s
.85322 .31644 m
.85412 .31044 L
s
.85585 .26189 m
.85896 .25811 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85446 .30494 m
.85468 .29693 L
s
.85378 .31595 m
.85467 .30995 L
s
.85412 .31044 m
.85446 .30494 L
s
.18872 .26095 m
.18918 .26149 L
s
.85499 .30443 m
.8552 .29642 L
s
.85467 .30995 m
.85499 .30443 L
s
.18771 .26237 m
.18872 .26095 L
s
.18816 .26291 m
.18872 .26095 L
s
.85724 .26028 m
.8587 .29534 L
s
.1875 .26737 m
.18816 .26291 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85768 .25974 m
.85914 .29482 L
s
.18707 .26683 m
.18771 .26237 L
s
.18678 .2849 m
.1875 .26737 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8573 .29688 m
.85914 .29482 L
s
.18643 .26075 m
.18707 .26683 L
s
.18613 .28941 m
.18707 .26683 L
s
.18572 .25717 m
.18643 .26075 L
s
.85852 .27975 m
.85927 .28676 L
s
.18613 .28941 m
.18678 .2849 L
s
.18458 .25553 m
.18572 .25717 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18601 .28134 m
.18634 .28438 L
s
.18374 .27564 m
.18601 .28134 L
s
.85927 .28676 m
.86032 .29075 L
s
.18559 .2914 m
.18613 .28941 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18465 .29288 m
.18559 .2914 L
s
.18376 .25694 m
.18458 .25553 L
s
.18342 .25639 m
.18458 .25553 L
s
.86032 .29075 m
.86124 .29223 L
s
.1831 .29079 m
.18465 .29288 L
s
.18321 .26142 m
.18376 .25694 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86124 .29223 m
.86238 .29066 L
s
.18313 .27205 m
.18374 .27564 L
s
.18278 .27151 m
.18374 .27564 L
s
.18288 .26088 m
.18342 .25639 L
s
.183 .26646 m
.18321 .26142 L
s
.8618 .28613 m
.86228 .28813 L
s
.8618 .28613 m
.86206 .28307 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86206 .28307 m
.86253 .28507 L
s
.183 .26646 m
.18313 .27205 L
s
.18266 .26592 m
.18288 .26088 L
s
.18249 .28721 m
.1831 .29079 L
s
.18266 .26592 m
.18278 .27151 L
s
.86238 .29066 m
.86264 .2876 L
s
.86253 .28507 m
.86264 .2876 L
s
.18236 .28162 m
.1827 .28215 L
s
.18259 .28468 m
.1827 .28215 L
s
.18225 .28415 m
.18249 .28721 L
s
.18225 .28415 m
.18236 .28162 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86382 .25854 m
.86389 .25294 L
s
.86382 .25854 m
.86404 .2636 L
s
.86389 .25294 m
.86456 .24874 L
s
.86404 .2636 m
.86453 .26812 L
s
.8641 .25799 m
.86416 .25238 L
s
.8641 .25799 m
.86432 .26305 L
s
.86416 .25238 m
.86456 .24874 L
s
.86432 .26305 m
.8648 .26757 L
s
.86453 .26812 m
.86543 .26902 L
s
.86456 .24874 m
.86526 .24706 L
s
.8648 .26757 m
.86543 .26902 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86496 .27827 m
.86507 .28081 L
s
.86496 .27827 m
.86524 .27773 L
s
.86507 .28081 m
.86545 .28282 L
s
.86524 .27773 m
.86534 .28027 L
s
.86526 .24706 m
.86578 .24847 L
s
.86543 .26902 m
.86684 .26829 L
s
.86545 .28282 m
.86608 .2843 L
s
.1797 .27679 m
.17985 .27988 L
s
.17974 .28242 m
.17985 .27988 L
s
.17938 .28444 m
.17974 .28242 L
s
.17935 .2788 m
.1797 .27679 L
s
.17863 .24212 m
.17977 .24608 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17935 .2788 m
.17948 .28189 L
s
.86578 .24847 m
.86637 .25244 L
s
.17867 .28283 m
.17938 .28444 L
s
.86608 .2843 m
.86699 .28215 L
s
.17769 .28013 m
.17922 .24439 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86632 .24679 m
.86637 .25244 L
s
.86637 .25244 m
.86735 .27541 L
s
.86632 .24679 m
.86652 .24311 L
s
.17836 .27919 m
.17867 .28283 L
s
.86648 .24622 m
.86654 .25188 L
s
.86654 .25188 m
.8673 .26975 L
s
.86648 .24622 m
.86652 .24311 L
s
.86684 .26829 m
.86713 .27029 L
s
.86699 .28215 m
.86728 .27851 L
s
.86652 .24311 m
.86666 .24254 L
s
.17819 .27299 m
.17836 .27919 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17753 .27959 m
.17906 .24382 L
s
.17819 .27299 m
.17835 .26477 L
s
.86728 .27851 m
.86735 .27541 L
s
.8673 .26975 m
.86735 .27541 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17709 .27796 m
.17769 .28013 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17757 .25208 m
.17772 .24639 L
s
.17732 .26035 m
.17757 .25208 L
s
.17772 .24639 m
.17784 .24013 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17677 .27321 m
.17732 .26035 L
s
.1775 .25152 m
.17766 .24583 L
s
.17724 .25979 m
.1775 .25152 L
s
.86745 .23742 m
.86875 .27565 L
s
.17766 .24583 m
.1778 .23956 L
s
.17669 .27266 m
.17724 .25979 L
s
.17784 .24013 m
.17786 .23584 L
s
.1778 .23956 m
.17786 .23584 L
s
.86778 .24511 m
.86883 .2751 L
s
.17636 .28041 m
.17677 .27321 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17629 .27986 m
.17669 .27266 L
s
.17786 .23584 m
.17828 .23009 L
s
.17606 .28504 m
.17636 .28041 L
s
0 0 0 r
.8715 .22842 m
.87165 .23151 L
s
.87133 .22417 m
.8715 .22842 L
s
.87147 .22725 m
.87133 .22417 L
s
.255 .412 .882 r
.176 .2845 m
.17629 .27986 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86745 .23742 m
.86909 .27127 L
s
.86845 .27728 m
.869 .27346 L
s
0 0 0 r
.87165 .23151 m
.87147 .22725 L
s
.255 .412 .882 r
.17573 .28914 m
.17606 .28504 L
s
.17569 .28861 m
.176 .2845 L
s
.86744 .23282 m
.86874 .26686 L
s
.86744 .23282 m
.86909 .27127 L
s
.17553 .29013 m
.17573 .28914 L
s
.17564 .28691 m
.17798 .2324 L
s
.86777 .24056 m
.86908 .27072 L
s
.17553 .29013 m
.17569 .28861 L
s
.1757 .28637 m
.17804 .23182 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87245 .24992 m
.87437 .29391 L
s
.87245 .24992 m
.8744 .29499 L
s
.255 .412 .882 r
.17593 .28475 m
.17553 .29013 L
s
0 0 0 r
.87439 .29445 m
.87342 .27212 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87119 .22682 m
.87092 .22254 L
s
.87167 .23792 m
.87119 .22682 L
s
.87092 .22254 m
.87051 .21767 L
s
.87157 .23734 m
.87151 .23422 L
s
.8744 .29499 m
.87472 .30192 L
s
.255 .412 .882 r
.86843 .2652 m
.86895 .26851 L
s
0 0 0 r
.86989 .2153 m
.87051 .21767 L
s
.87173 .24105 m
.87167 .23792 L
s
.87148 .2399 m
.87157 .23734 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87472 .30192 m
.87437 .29391 L
s
.87164 .24361 m
.87173 .24105 L
s
.87248 .25648 m
.8727 .26337 L
s
.87313 .2714 m
.87248 .25648 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87099 .24447 m
.87148 .2399 L
s
.86967 .21782 m
.86989 .2153 L
s
.87116 .24821 m
.87164 .24361 L
s
.8727 .26337 m
.87274 .26655 L
s
.8727 .26337 m
.87313 .2714 L
s
.86962 .22095 m
.86967 .21782 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86673 .23949 m
.8672 .2473 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87274 .26655 m
.87264 .26917 L
s
.255 .412 .882 r
.8672 .2473 m
.86776 .26037 L
s
.86653 .23869 m
.86703 .24673 L
s
0 0 0 r
.86908 .21292 m
.86962 .22095 L
s
.86908 .21292 m
.86973 .22781 L
s
.255 .412 .882 r
.86703 .24673 m
.86759 .25981 L
s
0 0 0 r
.86962 .22095 m
.86973 .22781 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86776 .26037 m
.86792 .26768 L
s
0 0 0 r
.87264 .26917 m
.87197 .26694 L
s
.87075 .24707 m
.87099 .24447 L
s
.87092 .25081 m
.87116 .24821 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8707 .25024 m
.87075 .24707 L
s
.86662 .20758 m
.86783 .20996 L
s
.87086 .254 m
.87092 .25081 L
s
.255 .412 .882 r
.8678 .27656 m
.86796 .27274 L
s
0 0 0 r
.8714 .26207 m
.87197 .26694 L
s
.8707 .25024 m
.87102 .25775 L
s
.255 .412 .882 r
.86759 .27602 m
.86777 .27199 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87102 .25775 m
.8714 .26207 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86662 .20758 m
.86888 .26025 L
s
.86694 .20818 m
.8692 .26081 L
s
.86611 .21014 m
.8671 .21881 L
s
.86485 .20462 m
.86611 .21014 L
s
.86407 .20344 m
.86485 .20462 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86339 .20601 m
.86407 .20344 L
s
.86296 .20543 m
.86407 .20344 L
s
.86786 .25858 m
.8692 .26081 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86328 .21296 m
.86339 .20601 L
s
.86284 .21238 m
.86296 .20543 L
s
.86328 .21296 m
.86506 .25468 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86284 .21238 m
.86461 .25413 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85554 .19343 m
.85893 .19695 L
s
.86321 .25247 m
.86506 .25468 L
s
.255 .412 .882 r
.85796 .24639 m
.85841 .24557 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84896 .18762 m
.85304 .1911 L
s
.85037 .18878 m
.85331 .20705 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85331 .20705 m
.86008 .24915 L
s
.85777 .24695 m
.86117 .25025 L
s
.85258 .24257 m
.85411 .22715 L
s
.85411 .22715 m
.85728 .19519 L
s
.85429 .23255 m
.85784 .19577 L
s
.85327 .24312 m
.85429 .23255 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85116 .24149 m
.85527 .24476 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84493 .1957 m
.84617 .20782 L
s
.84303 .18688 m
.84493 .1957 L
s
.8404 .18133 m
.84303 .18688 L
s
.84414 .19514 m
.84539 .20726 L
s
.84221 .18631 m
.84414 .19514 L
s
.84617 .20782 m
.84649 .21554 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8404 .18133 m
.84221 .18631 L
s
.84539 .20726 m
.84571 .21499 L
s
.84617 .2266 m
.84649 .21554 L
s
.83869 .18021 m
.8404 .18133 L
s
.84538 .22606 m
.84571 .21499 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83403 .17622 m
.83413 .17887 L
s
.83492 .1777 m
.83498 .17932 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20648 .18035 m
.21185 .17699 L
s
.83709 .18294 m
.83869 .18021 L
s
.83619 .18238 m
.83869 .18021 L
s
.84489 .23329 m
.84617 .2266 L
s
.255 .412 .882 r
.20533 .22103 m
.20592 .22593 L
s
.2049 .23189 m
.20533 .22103 L
s
0 0 0 r
.84407 .23275 m
.84538 .22606 L
s
.255 .412 .882 r
.20592 .22593 m
.2049 .23189 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84256 .23558 m
.84489 .23329 L
s
.84256 .23558 m
.84407 .23275 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8363 .21289 m
.83636 .21452 L
s
.8354 .21141 m
.83551 .21409 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83468 .18901 m
.83619 .18238 L
s
.83559 .18956 m
.83709 .18294 L
s
.83513 .20066 m
.83559 .18956 L
s
.8342 .20011 m
.83468 .18901 L
s
.84084 .23451 m
.84256 .23558 L
s
.2091 .20134 m
.21776 .19649 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20822 .17922 m
.21152 .2575 L
s
.83513 .20066 m
.83543 .20844 L
s
.83893 .22955 m
.84084 .23451 L
s
.83803 .22902 m
.84084 .23451 L
s
.8342 .20011 m
.8345 .2079 L
s
.83543 .20844 m
.83681 .22067 L
s
.82443 .17189 m
.82848 .17408 L
s
.83681 .22067 m
.83893 .22955 L
s
.21764 .17367 m
.22384 .17041 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83589 .22014 m
.83803 .22902 L
s
.8345 .2079 m
.83589 .22014 L
s
.21198 .24566 m
.22069 .17203 L
s
.21152 .2575 m
.22173 .17149 L
s
.82248 .1747 m
.82487 .18357 L
s
.22729 .22278 m
.23032 .14049 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22701 .14213 m
.23489 .13831 L
s
.5 Mabswid
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82019 .16973 m
.82248 .1747 L
s
.22842 .22228 m
.23145 .13994 L
s
.81801 .16866 m
.82019 .16973 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82443 .17189 m
.82755 .25438 L
s
.82546 .17244 m
.82859 .25488 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81592 .1715 m
.81801 .16866 L
s
.81479 .17097 m
.81801 .16866 L
s
.82425 .22173 m
.82606 .21489 L
s
.81394 .17828 m
.81592 .1715 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81278 .17776 m
.81479 .17097 L
s
.23002 .17894 m
.23259 .17006 L
s
.23259 .17006 m
.23507 .16509 L
s
.82225 .22466 m
.82425 .22173 L
s
.81321 .18955 m
.81394 .17828 L
s
.23507 .16509 m
.23745 .16405 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81204 .18904 m
.81278 .17776 L
s
.255 .412 .882 r
.23295 .20976 m
.23334 .2087 L
s
0 0 0 r
.23745 .16405 m
.23973 .16695 L
s
.23745 .16405 m
.24096 .16643 L
s
.82005 .22365 m
.82225 .22466 L
s
.255 .412 .882 r
.23334 .2087 m
.23451 .20155 L
s
0 0 0 r
.82437 .2529 m
.82859 .25488 L
s
.22395 .22429 m
.22842 .22228 L
s
.255 .412 .882 r
.23285 .21252 m
.23448 .2082 L
s
0 0 0 r
.81321 .18955 m
.8135 .19743 L
s
.255 .412 .882 r
.23448 .2082 m
.23564 .20114 L
s
0 0 0 r
.81204 .18904 m
.81233 .19692 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81766 .21869 m
.82005 .22365 L
s
.81652 .21819 m
.82005 .22365 L
s
.8135 .19743 m
.81509 .20978 L
s
.22886 .21041 m
.23087 .21732 L
s
.23973 .16695 m
.24192 .1738 L
s
.81509 .20978 m
.81766 .21869 L
s
.81233 .19692 m
.81393 .20928 L
s
.24096 .16643 m
.24317 .17329 L
s
.81393 .20928 m
.81652 .21819 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80021 .16084 m
.8052 .16289 L
s
.23087 .21732 m
.23308 .2203 L
s
.24192 .1738 m
.24276 .18514 L
s
.24317 .17329 m
.24402 .18464 L
s
.79779 .16377 m
.80063 .17266 L
s
.79374 .15833 m
.79779 .16377 L
s
.23308 .2203 m
.23547 .21932 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24248 .19306 m
.24276 .18514 L
s
.24374 .19257 m
.24402 .18464 L
s
.79107 .15735 m
.79374 .15833 L
s
.23547 .21932 m
.23805 .21437 L
s
.23547 .21932 m
.23928 .21389 L
s
.24081 .20545 m
.24248 .19306 L
s
.24206 .20496 m
.24374 .19257 L
s
.23805 .21437 m
.24081 .20545 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80021 .16084 m
.80215 .2163 L
s
.80148 .16135 m
.80342 .21678 L
s
.7885 .16032 m
.79107 .15735 L
s
.78713 .15984 m
.79107 .15735 L
s
.23928 .21389 m
.24206 .20496 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78739 .16776 m
.7885 .16032 L
s
.25492 .16885 m
.25791 .15996 L
s
.25317 .18123 m
.25492 .16885 L
s
.25791 .15996 m
.2622 .15456 L
s
.79827 .21488 m
.80342 .21678 L
s
.78601 .16728 m
.78713 .15984 L
s
.25627 .16837 m
.25928 .15948 L
s
.25452 .18075 m
.25627 .16837 L
s
.25928 .15948 m
.2622 .15456 L
s
.2529 .18918 m
.25317 .18123 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78739 .16776 m
.78885 .21164 L
s
.2622 .15456 m
.26503 .1536 L
s
.25425 .18871 m
.25452 .18075 L
s
.78601 .16728 m
.78746 .21118 L
s
.2529 .18918 m
.25385 .20067 L
s
.25425 .18871 m
.25521 .20021 L
s
.26503 .1536 m
.26777 .15663 L
s
.26503 .1536 m
.26922 .15616 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25385 .20067 m
.25632 .20775 L
s
.26777 .15663 m
.27043 .16366 L
s
.25521 .20021 m
.2577 .20729 L
s
.26922 .15616 m
.2719 .1632 L
s
.77273 .15114 m
.77349 .17506 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77125 .15068 m
.77349 .17506 L
s
.25632 .20775 m
.26037 .21039 L
s
.27043 .16366 m
.27152 .17518 L
s
.2577 .20729 m
.26037 .21039 L
s
.2719 .1632 m
.273 .17473 L
s
.78323 .20983 m
.78885 .21164 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27127 .18318 m
.27152 .17518 L
s
.26037 .21039 m
.26322 .20949 L
s
.2813 .14853 m
.29228 .14546 L
s
.27275 .18273 m
.273 .17473 L
s
.26941 .19566 m
.27127 .18318 L
s
.26322 .20949 m
.26623 .20458 L
s
.26322 .20949 m
.26769 .20414 L
s
.27089 .19522 m
.27275 .18273 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74785 .14408 m
.75649 .14654 L
s
.75649 .14654 m
.77273 .15114 L
s
.26623 .20458 m
.26941 .19566 L
s
.26769 .20414 m
.27089 .19522 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28342 .23191 m
.28595 .1472 L
s
.285 .23151 m
.28751 .14676 L
s
.77389 .23507 m
.77462 .21121 L
s
.77462 .21121 m
.77539 .23549 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29876 .14377 m
.31045 .14092 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75559 .18999 m
.76503 .1925 L
s
.76454 .17642 m
.76552 .20866 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30136 .22766 m
.30371 .14253 L
s
.30305 .22729 m
.30538 .14213 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27873 .23312 m
.285 .23151 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75026 .22907 m
.75899 .2313 L
s
.75899 .2313 m
.77539 .23549 L
s
.7527 .14535 m
.75516 .23023 L
s
.7543 .14578 m
.75677 .23062 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32424 .14188 m
.32969 .13674 L
s
.32051 .1507 m
.32424 .14188 L
s
.31844 .1632 m
.32051 .1507 L
s
.32601 .14151 m
.32969 .13674 L
s
.32227 .15032 m
.32601 .14151 L
s
.3202 .16283 m
.32227 .15032 L
s
.32969 .13674 m
.33329 .13603 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31824 .17131 m
.31844 .1632 L
s
.33329 .13603 m
.33684 .13936 L
s
.33329 .13603 m
.33867 .13902 L
s
.31999 .17094 m
.3202 .16283 L
s
.31824 .17131 m
.31968 .18314 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31999 .17094 m
.32145 .18278 L
s
.33684 .13936 m
.34032 .14678 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29636 .22879 m
.30305 .22729 L
s
.33867 .13902 m
.34217 .14644 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31968 .18314 m
.32302 .19058 L
s
.32145 .18278 m
.32481 .19023 L
s
.34032 .14678 m
.34189 .15863 L
s
.34217 .14644 m
.34375 .1583 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35369 .13231 m
.36712 .13016 L
s
.32302 .19058 m
.3283 .19363 L
s
.32481 .19023 m
.3283 .19363 L
s
.34171 .16678 m
.34189 .15863 L
s
.35822 .18857 m
.3594 .13137 L
s
.34357 .16645 m
.34375 .1583 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36016 .18829 m
.36132 .13106 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33957 .17936 m
.34171 .16678 L
s
.3283 .19363 m
.33193 .19296 L
s
.34143 .17903 m
.34357 .16645 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33193 .19296 m
.33569 .1882 L
s
.33193 .19296 m
.33754 .18787 L
s
.33569 .1882 m
.33957 .17936 L
s
.33754 .18787 m
.34143 .17903 L
s
.37495 .12901 m
.38889 .12714 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38008 .17322 m
.38089 .12819 L
s
.38208 .17296 m
.38288 .12792 L
s
.39698 .12616 m
.41136 .12458 L
s
.36041 .17595 m
.36412 .1836 L
s
.35247 .18946 m
.36016 .18829 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40224 .18301 m
.40311 .12546 L
s
.40431 .1828 m
.40517 .12523 L
s
.36412 .1836 m
.36992 .18689 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36992 .18689 m
.37388 .18636 L
s
.37793 .18171 m
.38008 .17322 L
s
.37993 .18146 m
.38208 .17296 L
s
.37388 .18636 m
.37793 .18171 L
s
.37388 .18636 m
.37993 .18146 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42803 .1271 m
.43442 .12248 L
s
.42582 .13548 m
.42803 .1271 L
s
.43014 .12692 m
.43442 .12248 L
s
.43442 .12248 m
.43866 .12215 L
s
.42793 .1353 m
.43014 .12692 L
s
.43866 .12215 m
.44502 .12579 L
s
.42527 .18088 m
.42582 .13548 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44935 .1214 m
.45795 .12087 L
s
.44502 .12579 m
.44923 .13372 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46877 .12031 m
.47088 .12842 L
s
.46865 .13675 m
.46877 .12031 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47308 .12421 m
.47746 .11993 L
s
.48619 .11961 m
.47746 .11993 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42739 .18071 m
.42793 .1353 L
s
.44881 .1792 m
.44935 .1214 L
s
.45097 .17907 m
.45149 .12126 L
s
.39607 .18367 m
.40431 .1828 L
s
.47088 .12842 m
.47308 .12421 L
s
.48619 .11961 m
.49055 .12359 L
s
.46865 .13675 m
.47088 .12842 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51032 .1191 m
.51251 .12319 L
s
.50811 .12323 m
.51032 .1191 L
s
.49055 .12359 m
.49273 .12764 L
s
.255 .412 .882 r
.49194 .16107 m
.49195 .15747 L
s
0 0 0 r
.50811 .12323 m
.5103 .12732 L
s
.5103 .12732 m
.51251 .12319 L
s
.49268 .14001 m
.49273 .12764 L
s
.49049 .14007 m
.4927 .13588 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41893 .18142 m
.42739 .18071 L
s
.255 .412 .882 r
.55073 .1639 m
.55209 .15843 L
s
0 0 0 r
.48608 .14432 m
.49049 .14007 L
s
.49047 .1442 m
.49268 .14001 L
s
.255 .412 .882 r
.49629 .15807 m
.49886 .15745 L
s
.49411 .16102 m
.49629 .15807 L
s
0 0 0 r
.47509 .15298 m
.48608 .14432 L
s
.40193 .20377 m
.40394 .20773 L
s
.3998 .20814 m
.40193 .20377 L
s
.48606 .14846 m
.49047 .1442 L
s
.3998 .20814 m
.4018 .2121 L
s
.47506 .15712 m
.48606 .14846 L
s
.47069 .15731 m
.47509 .15298 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49411 .16128 m
.49412 .15747 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55039 .16436 m
.55073 .1639 L
s
0 0 0 r
.4018 .2121 m
.40394 .20773 L
s
.46848 .16155 m
.47069 .15731 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47067 .16145 m
.47506 .15712 L
s
.46843 .16985 m
.46848 .16155 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46846 .16569 m
.47067 .16145 L
s
.44234 .17961 m
.45097 .17907 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49037 .16906 m
.4926 .1607 L
s
.49254 .17733 m
.4926 .1607 L
s
.46843 .16985 m
.47059 .17391 L
s
.47059 .17391 m
.47494 .17789 L
s
.48815 .17328 m
.49037 .16906 L
s
.49037 .16906 m
.49254 .17733 L
s
.47494 .17789 m
.48373 .17758 L
s
.48373 .17758 m
.48815 .17328 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51027 .14796 m
.51241 .1979 L
s
.50797 .19795 m
.51027 .14796 L
s
.51019 .19792 m
.51023 .17286 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50797 .19795 m
.51018 .20631 L
s
.51018 .20631 m
.51241 .1979 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00203o
YQ000`000000ojH@0?nV400A0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/
UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00P0ojHA1@000004
0?nV4@030000003oYQ40ojHA0080[Jf]1@00000:0:f][@8000008`2][Jd?0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@030000
0080ojHA0`2][Jd2000000L0[Jf]00D000000:f][@2][Jd0ojHA000000050?nV4@030000003oYQ00
ojH@00L0ojH@00<000000?nV400000004P3oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh3
0:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@@000000`3oYQ450:f][@8000000`2][Jd20000
00<0ojHA0P0000070?nV4@80000000<0ojHA0000003oYQ401@3oYQ400`2][Jd000000?nV40070?nV
408000004`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00@0ojHA100000030?nV4@D000001P2][Jd40?nV4@80
00001P3oYQ42000000030?nV4@000000000000L0ojHA0`0000070?nV4@030:f][@000000ojH@00P0
ojH@00<000000?nV403oYQ004@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0
oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00D000001`2][Jd20?nV4@800000
2P3oYQ42000000L0ojHA00@000000?nV4@00000000001`3oYQ400`000000ojHA000000070?nV4@03
0:f][@3oYQ00000001`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400E0?nS40L0
[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40
oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0180ojHA
1@0000050:f][@030?nV4@000000000000T0ojHA0P0000090?nV4@8000002@3oYQ43000000L0ojHA
0P0000080?nV4@030:f][@3oYQ00000001`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA00l0ojHA1@000000102][Jd0ojHA0?nV4@2][Jd50?nV4@800000
2@3oYQ42000000T0ojHA0P0000090?nV4@<000001`3oYQ42000000P0ojHA00<0[Jf]0?nV40000000
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
1P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd20?nV4@8000000`3o
YQ400`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000T0ojHA0P00000:0?nV4@8000001`3o
YQ400`000000ojHA0?nV4@070?nV4@030:f][@3oYQ00000001`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00/0o:0@1@2][Jd80?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`
h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D
0?nT4@030:f][@3oYQ40ojHA00<0ojHA100000040:f][@L0ojHA0P0000030?nV4@030:f][@3oYQ40
ojHA00<0ojHA0P0000090?nV4@8000002@3oYQ42000000X0ojHA0P0000070?nV4@030000003oYQ40
ojHA00L0ojHA00<0[Jf]0?nV40000000703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP403lX100403lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3P
iP030:f][@3_V100kiP@00@0kiP@00<000000?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA0080[Jf]00@000000:f][@2][Jd0ojHA0`0000090?nV4@8000000`3oYQ40
0`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000T0ojHA0P00000:0?nV4@8000004@3oYQ40
0`2][Jd000000000000L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa00
0`2][Jd0o:0@0?bP400F0?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1@3_V102000000030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY140403oY142000000030?nT4@2][Jd0[Jf]0080[Jf]00<0ojHA0000
00000000103oYQ42000000T0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00<0ojHA0P0000090?nV
4@8000002@3oYQ42000000X0ojHA0P00000A0?nV4@030:f][@000000000001`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f]
[ED0/>3V0@3oool006X0/>3V0P2][Jd50>nH40<0000000<0kiP@0:f][@3lX100403lX1000`2][Jd0
oj@A0?nT4@0=0?nT4@<000000`2][Jd00`3oY140[Jf]0?nV4@020?nV4@030000003oYQ40ojHA00@0
ojHA00<000000?nV4@3oYQ401`3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000T0
ojHA0P0000090?nV4@8000002P3oYQ4200000140ojHA0P00000M0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0
mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0
/>3V0@3oool006P0/>3V0P2][Jd90>nH40030000003_V100[Jf]0140o:0@00<0[Jf]0?nT4@3oY140
1`3oY14200000080oj@A100000050?nT4@030:f][@3oYQ40ojHA008000001P3oYQ42000000P0ojHA
0P0000030?nV4@030:f][@3oYQ40ojHA00<0ojHA0P0000090?nV4@8000002@3oYQ42000000X0ojHA
0P00000@0?nV4@030000002][Jd0000001d0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l20:f][@@00000
1`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0
D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH40090>nH40030000003_V100[Jf]0140o:0@00<0
[Jf]0?nT4@3oY140103oY143000000@0[Jf]0P3oY142000000D0oj@A00@0[Jf]0?nV4@3oYQ400000
203oYQ400`000000ojHA0?nV4@060?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@800000
2@3oYQ42000000T0ojHA0P00000:0?nV4@8000003`3oYQ400`000000ojHA0000000N0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00/0mY`?00<0[Jf]0000000000000P0000040?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd;0>nH40030000003_
V100[Jf]0140o:0@00<0[Jf]0?nT4@3oY1400P3oY144000000030:f][@3oY140oj@A00@0oj@A0P00
00050?nT4@040:f][@3oYQ400000000000P0ojHA00<000000?nV4@3oYQ401P3oYQ42000000<0ojHA
00<0[Jf]0?nV4@3oYQ400`3oYQ42000000T0ojHA0P0000090?nV4@8000002P3oYQ42000000d0ojHA
0P0000000`3oYQ4000000:f][@0:0?nV40030000003oYQ00ojH@0140ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
303fW0l2000000030?JL3`2][Jd0000000<0000000<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd02`3_
V1000`000000kiP@0:f][@0A0?bP40030:f][@3oY140[Jf]00<0[Jf]00<0oj@A0000000000001`3o
Y142000000D0oj@A00@0[Jf]0?nV4@0000000000203oYQ400`000000ojHA0?nV4@060?nV4@800000
0`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002P3oYQ42000000T0ojHA0P00000:0?nV4@800000
303oYQ401P000000ojHA0?nV4@000000ojHA0:f][@X0ojH@00<000000?nV403oYQ004@3oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0<0?JL3`8000001@3fW0l0102][Jd0000000000000000@0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2]
[Jd;0>nH40030000003_V100[Jf]0100o:0@0`2][Jd50?nT4@8000001`3oY142000000D0oj@A00@0
[Jf]0?nV4@0000000000203oYQ400`000000ojHA0?nV4@060?nV4@8000000`3oYQ400`2][Jd0ojHA
0?nV4@020?nV4@8000002P3oYQ42000000T0ojHA0P00000:0?nV4@8000002`3oYQ4010000000ojHA
0000000000020?nV4@030:f][@3oYQ00ojH@00P0ojH@00<000000?nV403oYQ004@3oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0
mY`?0?JL3`0<0?JL3`8000001P3fW0l00`2][Jd00000000000020:f][@h0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3C
Q`h0dhL>0:f][@0;0>nH40030000003_V100[Jf]00d0o:0@0P0000000`2][Jd0o:0@0:f][@060?nT
4@8000001`3oY142000000D0oj@A00@0[Jf]0?nV4@0000000000203oYQ42000000L0ojHA0P000003
0?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000090?nV4@8000002P3oYQ42000000X0ojHA0P000009
0?nV4@80000000<0ojHA0000003oYQ400`3oYQ400`2][Jd0ojH@0?nV40080?nV40030000003oYQ00
ojH@0140ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l2000000H0mY`?00<0[Jf]0000000000000P3/UPh2
0:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H1
0?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00T0kiP@00<000000>nH
402][Jd02`3lX100102][Jd000000:f][@3lX102000000030:f][@3oY140oj@A00@0oj@A0P000007
0?nT4@8000001@3oY1400`2][Jd00000000000090?nV4@8000001`3oYQ42000000<0ojHA00<0[Jf]
0?nV4@3oYQ400P3oYQ42000000T0ojHA0P00000:0?nV4@8000002P3oYQ42000000P0ojHA00@00000
0?nV4@2][Jd00000402][Jd00`000000[Jf]0:f][@0I0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00`0mY`?0P0000060?JL3`030:f][@00
0000000000@0k9H>0`2][Jd00`3/UPh000000>bF3P060>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0
dhL>00<0dhL>00<0[Jf]0>nH403_V1002@3_V1000`000000kiP@0:f][@090?bP4080[Jf]0P000002
0?bP4080000000<0[Jf]0?nT4@3oY140103oY142000000L0oj@A0P0000040?nT4@040:f][@3oYQ40
0000000000T0ojHA0P0000070?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002@3o
YQ42000000X0ojHA0P0000060?nV4@@0[Jf]0P0000070:f][@040000002][Jd00000000000H0ojHA
00<0[Jf]0?nV403oYQ00203oYQ000`000000ojH@0?nV400A0?nV40030:f][@3oYA00ojD@00D0ojD@
402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`0<0?JL3`8000001P3fW0l00`2][Jd00000000000070>bF3P030000002][Jd0000000H0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V
0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH40090>nH40030000003_
V100[Jf]00H0o:0@0`2][Jd20?bP40030000003lX100o:0@0080o:0@0P0000060?nT4@8000001`3o
Y142000000@0oj@A00@0[Jf]0?nV4@00000000002@3oYQ42000000H0ojHA0P0000040?nV4@030:f]
[@3oYQ40ojHA0080ojHA0P0000090?nV4@8000001P3oYQ450:f][@030000002][Jd0[Jf]00@0[Jf]
103oYQ42000000L0ojHA0P0000080?nV4@040:f][@3oYQ000000045Yh@L0ojH@00<000000?nV403o
YQ004@3oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?00`0mY`?0P0000060?JL3`030:f][@000000000000H0k9H>0P0000020>bF3P04
0000002][Jd0000000000080k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0
kiP@0>nH40080>nH4080000000<0kiP@0:f][@3lX1000P3lX1030:f][@@0o:0@0P0000040?bP4080
00001P3oY142000000L0oj@A0P0000040?nT4@040:f][@3oYQ400000000000T0ojHA0P0000060?nV
4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000203oYQ400`2][Jd00000000000060:f]
[@@0ojHA00<0[Jf]0000003oYQ402@3oYQ42000000L0ojHA0P0000080?nV4@030:f][@3oYQ000000
00P0ojH@00<000000?nV403oYQ004@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l20000
00H0mY`?00<0[Jf]0000000000001P3/UPh200000080k9H>00<000000>bF3P0000000`0000000`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?oo
o`00GP2`h>H00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P0000000`3_V100
0000000000020:f][@L0o:0@00<000000?bP403lX100103lX1000`000000oj@A0?nT4@040?nT4@80
00001`3oY142000000@0oj@A00@0[Jf]0?nV4@00000000002@3oYQ42000000H0ojHA0P0000040?nV
4@030:f][@3oYQ40ojHA0080ojHA0P0000080:f][@030?nV4@000000000000X0ojHA00<0[Jf]0000
003oYQ402@3oYQ42000000L0ojHA00<000000?nV4@3oYQ401`3oYQ400`2][Jd00000000000080?nV
40030000003oYQ00ojH@0140ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS
40X0[Jf]103oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00`0mY`?0P0000060?JL
3`030:f][@3/UPh0000000D0k9H>0P0000040>bF3P<0000000<0k9H>0:f][@2][Jd03@3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_
V100203_V102000000030>nH40000000[Jf]008000001P3lX102000000H0o:0@00<000000?nT4@3o
Y140103oY142000000L0oj@A0P0000040?nT4@030:f][@3oYQ40000000X0ojHA0P0000060?nV4@80
00000P3oYQ470:f][@8000002@3oYQ42000000X0ojHA00<0[Jf]0000003oYQ402@3oYQ42000000L0
ojHA00<000000?nV4@3oYQ401`3oYQ400`2][Jd00000000000080?nV40030000003oYQ00ojH@0140
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]5P3lX1000`2][Jd0
mY`?0?JL3`0<0?JL3`8000001P3fW0l00`2][Jd0k9H>000000050>bF3P800000103/UPh300000080
k9H>0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]
203CQ`h00`2][Jd0kiP@0>nH40080>nH40<0000000@0[Jf]0?bP4000000000001P3lX102000000H0
o:0@00<000000?nT4@3oY140103oY142000000L0oj@A0P0000040?nT4@030:f][@3oYQ40000000X0
ojHA0P0000040?nV4@80[Jf]0P0000020:f][@80ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000T0
ojHA0P00000:0?nV4@030:f][@000000ojHA00T0ojHA0P0000070?nV4@030000003oYQ40ojHA00L0
ojHA00<0[Jf]000000000000203oYQ000`000000ojH@0?nV400A0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL
3`3fW0l0303fW0l2000000H0mY`?00<0[Jf]0>bF3P0000001@3/UPh2000000D0k9H>0P0000020>bF
3P030:f][@3KRPd0fhX=0080[Jf]00<000000=^:3@3KRPd01P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0
kiP@0>nH40040>nH40040000003_V10000000:f][@<0000000<0[Jf]0?bP403lX1000P0000050?bP
408000001P3lX102000000D0oj@A0P0000070?nT4@800000103oY1400`2][Jd0ojHA0000000:0?nV
4@800000102][Jd20?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002@3oYQ420000
00X0ojHA00<0[Jf]0000003oYQ402@3oYQ42000000L0ojHA00<000000?nV4@3oYQ401`3oYQ430000
00P0ojH@00<000000?nV403oYQ004@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1001`3lX1070:f][@T0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l20000
00H0mY`?00<0[Jf]0>bF3P0000001@3/UPh2000000D0k9H>0P0000020>bF3P070:f][@3KRPd0fhX=
0=^:3@000000[Jf]000000070=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`
h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@0P00
00000`2][Jd0kiP@00000002000000030:f][@3lX100o:0@008000001@3lX102000000H0o:0@0P00
00050?nT4@8000001`3oY142000000@0oj@A00<0[Jf]0?nV4@0000001P3oYQ430:f][@8000001`3o
YQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000T0ojHA0P00000:0?nV4@030:f][@00
0000ojHA00T0ojHA0P0000070?nV4@030000003oYQ40ojHA00L0ojHA0`0000080?nV40030000003o
YQ00ojH@0140ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@00h0o:0@1P2][Jd30?bP40030:f][@3fW0l0mY`?00`0mY`?0P0000060?JL3`030:f][@3/
UPh0000000D0k9H>0P0000050>bF3P8000000P3/UPh01@2][Jd0fhX=0=^:3@3KRPd000000080fhX=
0`0000040=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00
F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@0080kiP@0`0000030>nH4080
000000<0kiP@0:f][@3lX1000P3lX1000`000000o:0@0?bP40020?bP408000001`3lX102000000D0
oj@A0P0000070?nT4@800000103oY1400`2][Jd0ojHA000000060:f][@<0ojHA0P0000070?nV4@80
0000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002@3oYQ42000000X0ojHA00<0[Jf]0000003o
YQ402@3oYQ42000000P0ojHA00<000000?nV4@3oYQ401@3oYQ4010000000[Jf]0?nV400000070?nV
40<000004P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100503lX1050:f][@d0mY`?0P0000060?JL3`030:f][@3/UPh0000000D0k9H>0P0000050>bF
3P8000000P3/UPh0102][Jd0fhX=0=^:3@0000040=^:3@@000000P3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00P0dhL>00D0[Jf]0>nH403_V10000000>nH40020:f][@040000003_V100kiP@0>nH4080
000000<0kiP@0:f][@3lX1000P3lX1000`000000o:0@0?bP40020?bP408000001`3lX102000000D0
oj@A0P0000070?nT4@8000000`3oY1430:f][@030000003oYQ40ojHA00L0ojHA0P0000070?nV4@<0
00000`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40ojHA00P0ojHA0P00000:0?nV4@03
0:f][@000000ojHA00T0ojHA0P0000090?nV4@8000000`3oYQ42000000040?nV4@2][Jd0ojH@0000
00L0ojH@0`00000B0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]00<0[Jf]2@3fW0l2000000@0mY`?00<000000?JL
3`2][Jd01`3/UPh2000000D0k9H>0P0000020>bF3P040:f][@3KRPd0fhX=000000@0fhX=0P000002
0:f][@030=^:3@11JN40[Jf]00T0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd00000000000020:f][@80kiP@00@0
00000>nH403_V100kiP@0P0000000`3_V100[Jf]0?bP40020?bP40030000003lX100o:0@0080o:0@
0P0000070?bP408000001@3oY142000000L0oj@A0P0000030:f][@030?nT4@2][Jd0ojHA00800000
203oYQ42000000L0ojHA0`0000030?nV4@040:f][@3oYQ40ojHA0?nV4@8000002P3oYQ42000000X0
ojHA00<0[Jf]0000003oYQ401@3oYQ46000000/0ojHA0`0000030?nV4@030:f][@3oYQ00ojH@00L0
ojH@0`00000B0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd50?JL3`800000103fW0l00`000000
mY`?0:f][@070>bF3P8000001@3/UPh200000080k9H>00@0[Jf]0=^:3@3KRPd00000103KRPd20000
0080fhX=0P2][Jd00`11JN40^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3P
iP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0
dhL>0P000000102][Jd0kiP@0>nH403_V102000000<0kiP@0P0000000`3_V100[Jf]0?bP40020?bP
408000000`3lX102000000L0o:0@0P0000050?nT4@800000103oY1430:f][@800000103oY140102]
[Jd0ojHA0000000000080?nV4@8000001`3oYQ42000000050?nV4@000000ojHA0?nV4@2][Jd00`3o
YQ42000000X0ojHA0P0000070?nV4@D000007@3oYQ400`2][Jd0ojH@0?nV40070?nV40<000004P3o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]00<0mY`?000000000000103fW0l00`000000mY`?0:f]
[@070>bF3P8000001@3/UPh200000080k9H>00@0[Jf]0=^:3@3KRPd00000103KRPd2000000@0fhX=
00<0[Jf]0;Ue2`0000001`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@000000kiP@00<0kiP@
00<000000>nH403_V1000P3_V10010000000kiP@0>nH402][Jd30?bP408000000`3lX102000000L0
o:0@0P0000050?nT4@80000000@0oj@A0:f][@2][Jd0[Jf]0`3oY142000000@0oj@A00@0[Jf]0?nV
4@00000000001`3oYQ42000000P0ojHA0P0000001@3oYQ4000000?nV4@3oYQ40[Jf]00<0ojHA00<0
00000?nV4@3oYQ401P3oYQ45000000X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
40070?nV40<000004P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`040:f][@00000000000:f][@<0mY`?
00<000000?JL3`2][Jd01`3/UPh2000000D0k9H>0P0000020>bF3P040:f][@3KRPd0fhX=000000@0
fhX=0P0000040=^:3@@000001P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]00<000000>nH403_
V1000P3_V1000`000000kiP@0>nH40020>nH40030000003_V100[Jf]00@0o:0@0P0000030?bP4080
00001`3lX102000000@0oj@A00@0[Jf]000000000000[Jf]1@3oY142000000D0oj@A00@0[Jf]0?nV
4@00000000001`3oYQ42000000P0ojHA0P0000020?nV4@80000000@0[Jf]0?nV4@3oYQ400000603o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00L0ojH@0`00000B0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00`0mY`?0P0000001`3fW0l0[Jf]0:f][@2][Jd000000?JL3`2][Jd01`3/UPh2000000D0
k9H>0P0000020>bF3P040:f][@3KRPd00000000000@0fhX=0P0000040=^:3@80000000<0[Jf]0000
002iM@/01@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00<0dhL>0:f][@000000103_V1000`00
0000kiP@0>nH40020>nH40030000003_V100[Jf]00@0o:0@0P0000030?bP408000001`3lX1020000
00@0[Jf]00<0oj@A0000000000001P3oY142000000D0oj@A00<0[Jf]0?nV4@3oYQ400P0000050?nV
4@8000002@3oYQ42000000<0ojHA00@0[Jf]00000000000000006@3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@00L0ojH@0`00000B0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00`0mY`?0P000004
0?JL3`040000002][Jd0[Jf]0:f][@H0k9H>0P0000050>bF3P8000000P3/UPh0102][Jd0fhX=0000
000000040=^:3@800000103KRPd00`000000^GD;0;Ue2`0200000080^GD;00@000000;Ue2`2iM@/0
[Jf]1028EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd01@3CQ`h01P2][Jd0dhL>0=>73P3CQ`h0[Jf]000000@0kiP@00<000000>nH403_V1000P3_V100
0`000000kiP@0:f][@040?bP40030000003lX100o:0@0080o:0@0P0000060?bP4080000000<0[Jf]
0?nT4@3oY1400P3oY142000000L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA008000001@3oYQ42
000000L0ojHA100000030?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV40070?nV40<000004P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0=0?JL3`030000003fW0l0
mY`?0080mY`?00@000000?JL3`2][Jd0k9H>0`2][Jd30>bF3P8000001@3/UPh200000080k9H>00@0
[Jf]0=^:3@0000000000103KRPd2000000@0fhX=00<000000;Ue2`2iM@/00P0000001P2][Jd0^GD;
000000000000^GD;0:f][@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd0103CQ`h00`2][Jd0dhL>0=>73P020=>73P030:f][@000000kiP@00<0kiP@00<000000>nH
403_V1000P3_V1000`000000kiP@0:f][@040?bP40030000003lX100o:0@0080o:0@0P0000030?bP
40<0[Jf]0P0000050?nT4@8000001`3oY142000000D0oj@A00@0[Jf]0?nV4@3oYQ40ojHA0P000003
0?nV4@8000003`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ001`3oYQ0300000180ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03@3fW0l300000080mY`?00<00000
0?JL3`2][Jd0103/UPh20:f][@80k9H>0P0000050>bF3P80000000<0k9H>0:f][@3KRPd00P000004
0=^:3@800000103KRPd00`000000^GD;0;Ue2`02000000060;Ue2`2][Jd000000;Ue2`000000[Jf]
1028EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f]
[@3CQ`h0dhL>00<0dhL>00<0[Jf]0000003_V1000`3_V1000`000000kiP@0>nH40020>nH40030000
003_V100[Jf]00@0o:0@00<000000?bP403lX1000P3lX102000000030?bP402][Jd0[Jf]00<0o:0@
0P0000050?nT4@8000001`3oY142000000D0oj@A00<0[Jf]0?nV4@3oYQ400`3oYQ4300000140ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00L0ojH@
0`00000B0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?00d0mY`?0P0000001P3fW0l00000000000000000mY`?0:f]
[@H0k9H>0P2][Jd2000000D0k9H>0P0000000`3/UPh0[Jf]0=^:3@02000000@0fhX=0P0000040=^:
3@040000002iM@/0^GD;0;Ue2`80000000D0^GD;0000002][Jd0^GD;0000000408QF1`80[Jf]@P2`
h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1P3CQ`h00`2][Jd00000
0>nH40030>nH40030000003_V100kiP@0080kiP@00<000000>nH402][Jd0103lX1000`000000o:0@
0?bP40020?bP4080000000<0[Jf]0?bP403lX1000`3lX102000000D0oj@A0P0000070?nT4@800000
1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
5@3oYQ4A0:f][@<000006P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0<0?JL3`8000000`3fW0l00`000000mY`?0:f][@080>bF3P800000
0P2][Jd30>bF3P80000000<0k9H>0:f][@3KRPd00P0000050=^:3@8000000P3KRPd2000000<0^GD;
0P0000020;Ue2`040000002][Jd0[Jf]000000<0R5H70P2][Je20;3PiP40oooo001I0;3PiP040:f]
[@2GH0/0Uf0;09MP2`80[Jf]203CQ`h00`2][Jd000000>nH40020>nH40800000103_V1000`000000
kiP@0:f][@040?bP40030000003lX100[Jf]0080[Jf]0P0000060?bP408000001@3oY142000000L0
oj@A0P0000050?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV40070?nV40<000004P3oYQ000`2][Jd0
ojD@0?nU40050?nU4100[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0303fW0l2000000<0mY`?00<000000?JL3`2][Jd0203/UPh200000080
k9H>0P2][Jd01P3/UPh000000000003/UPh0[Jf]0=^:3@8000001@3KRPd200000080fhX=0P000003
0;Ue2`8000000P2iM@/00`000000^GD;0:f][@02000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0000003_V10010000004
0>nH40030000003_V100[Jf]00<0o:0@0P000000102][Jd0o:0@0?bP403lX102000000H0o:0@00<0
00000:f][@3oY140103oY142000000L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ001`3oYQ0300000180ojH@00<0
[Jf]0?nU403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0<0?JL3`8000000`3fW0l00`000000mY`?0:f][@080>bF3P800000103/UPh01P2][Jd000000000
003/UPh0[Jf]0=^:3@8000001@3KRPd200000080fhX=0P0000000`2][Jd0^GD;0;Ue2`0200000080
^GD;00@000000;Ue2`2][Jd000001028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP03
0:f][@2GH0/0Uf0;0080[Jf]203CQ`h0102][Jd0kiP@0000000000020>nH40030000003_V100kiP@
00<0kiP@00@000000>nH402][Jd0@FWQ0P2][Jd2000000@0o:0@0P0000050?bP4080000000<0[Jf]
0?nT4@3oY1400`3oY142000000L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV4007
0?nV40030000003oYQ0000000180ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS4002
0?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00`0mY`?0P000003
0?JL3`030000003fW0l0[Jf]00P0k9H>0P0000050>bF3P8000000`2][Jd2000000D0fhX=0P000002
0=^:3@80000000<0[Jf]0;Ue2`2iM@/00P0000020;Ue2`040000002iM@/0[Jf]000000@0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]
0>nH400000000`3_V1000`000000kiP@0>nH40020>nH4080000000<0kiP@0:f][@2][Jd00P3lX102
000000D0o:0@00<000000?bP403lX1000`3lX1000`000000o:0@0:f][@050?nT4@8000001`3oY142
000000D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]0P3oYQ40
0`000000ojHA0?nV4@090?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ001`3oYQ02
000001<0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00`0mY`?0P0000030?JL3`030000003fW0l0
[Jf]00P0k9H>0P0000050>bF3P80000000<0k9H>0:f][@3KRPd00P0000050=^:3@8000000P3KRPd2
000000050:f][@2iM@/0^GD;0;Ue2`0000000`2iM@/3000000050:f][@28EPL0000008QF1`2][Jd0
@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH40000000
0`3_V1000`000000kiP@0>nH40020>nH408000000P2][Jd30?bP408000001@3lX102000000@0o:0@
00<000000?bP402][Jd01@3oY142000000L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA01@0ojHA
202][Jd<0?nV4@030000003oYQ40ojHA00T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV40080?nV40030000003oYQ00ojH@0140ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400F0?nS40P0[Jf]5`3lX1000`2][Jd0mY`?0?JL3`0<0?JL3`8000000`3fW0l00`000000mY`?
0:f][@080>bF3P8000001@3/UPh2000000040>bF3P2][Jd0fhX=0=^:3@80000000@0[Jf]0=^:3@3K
RPd0fhX=0P0000020=^:3@80000000D0[Jf]0;Ue2`2iM@/0^GD;000000030;Ue2`<0000000D0R5H7
0:f][@00000000000:f][@120;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0203C
Q`h00`2][Jd0kiP@000000030>nH40050000003_V100kiP@0>nH402][Jd00P0000000`3_V100[Jf]
0?bP40020?bP408000001P3lX1001`000000o:0@0?bP403lX10000000?bP402][Jd01P3oY1420000
00L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA
00d0ojHA00<000000?nV4@0000002P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
00P0ojH@00<000000?nV403oYQ004@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?00`0mY`?0P000003
0?JL3`040000003fW0l0mY`?0:f][@L0k9H>0P0000050>bF3P80000000@0k9H>0:f][@3KRPd0fhX=
0P000000103KRPd0[Jf]0:f][@3KRPd2000000<0fhX=00<000000:f][@2iM@/00P2iM@/010000000
^GD;0;Ue2`2iM@/2000000<0R5H70P0000000`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP80
[Jf]0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100000000<0kiP@00D000000>nH402]
[Jd0[Jf]0>nH4002000000030>nH402][Jd0o:0@0080o:0@00<000000?bP403lX1001P3lX1000`00
0000o:0@000000020?bP40030:f][@3oY140oj@A00@0oj@A0P0000070?nT4@8000001@3oY1400`2]
[Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@0=0?nV4@030000003oYQ400000
00X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40080?bP40H0[Jf]2P3lX1000`2]
[Jd0mY`?0?JL3`0<0?JL3`8000000`3fW0l010000000mY`?0?JL3`2][Jd70>bF3P8000001@3/UPh2
000000040>bF3P2][Jd0fhX=0=^:3@8000000`3KRPd00`2][Jd00000000000030=^:3@030000002]
[Jd0^GD;0080^GD;00@000000;Ue2`2iM@/0^GD;0P00000308QF1`<00000@P2`h>H10?ooo`00F@2`
h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@000000030>nH40030000002]
[Jd0kiP@0080kiP@0P000000103_V100[Jf]0?bP403lX102000000T0o:0@00D000000?bP403lX100
o:0@0:f][@060?nT4@8000001`3oY142000000D0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@0?nV
4@030:f][@3oYQ40ojHA00d0ojHA0P00000;0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l2000000H0mY`?00<0[Jf]0>bF
3P0000000`3/UPh4000000D0k9H>0P000000103/UPh0[Jf]0=^:3@3KRPd2000000@0fhX=0P000000
1@2][Jd0fhX=0=^:3@000000[Jf]00<0^GD;00@000000;Ue2`2iM@/0^GD;0P00000308QF1`<00000
@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@0[Jf]0>nH40000000
kiP@0P2][Jd00`000000kiP@0>nH40020>nH4080000000D0kiP@0:f][@3lX100o:0@0000000>0?bP
40030:f][@3oY140oj@A00@0oj@A0P0000070?nT4@800000103oY1450:f][AH0ojHA00<0[Jf]0?nV
4@3oYQ403P3oYQ400`000000ojHA0?nV4@090?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX1005@3lX1060:f][@`0mY`?0P0000060?JL3`030:f][@3/UPh0000000`0k9H>0P0000000`3/
UPh0[Jf]0=^:3@020=^:3@030000003KRPd0fhX=0080fhX=0P0000001@3KRPd0[Jf]0:f][@000000
[Jf]00<0^GD;00@000000;Ue2`2iM@/0^GD;0P00000308QF1`@00000@@2`h>H10?ooo`00F02`h>H2
0:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h01@2][Jd0kiP@0000002][Jd0kiP@00800000103_
V103000000040:f][@3lX100o:0@000000h0o:0@00<0[Jf]0?nT4@3oY140103oY142000000L0oj@A
0P0000040:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0102][Jd80?JL3`800000
1P3fW0l00`2][Jd0k9H>0000000:0>bF3P@0000000<0k9H>0:f][@3KRPd00P3KRPd2000000<0fhX=
0P0000030=^:3@030000002][Jd0^GD;0080^GD;00<000000;Ue2`2iM@/00P2iM@/010000000[Jf]
08QF1`28EPL400000440/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>
0P2][Jd00`000000kiP@0>nH4002000000@0kiP@0`0000000`2][Jd0o:0@0000000?0?bP40030:f]
[@3oY140oj@A00@0oj@A0P0000050?nT4@80[Jf]0P0000050?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0103fW0l50:f][@<0mY`?0P0000060?JL3`030:f][@3/UPh0000000`0k9H>
0P0000000`3/UPh0[Jf]0=^:3@030=^:3@040000003KRPd0fhX=0=^:3@8000000`3KRPd200000004
0:f][@2iM@/0^GD;000000@0^GD;00@000000:f][@28EPL0R5H7100000110;3PiP40oooo001H0;3P
iP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P80[Jf]0P3_V1000`000000kiP@000000050>nH
40<0000000<0[Jf]0000003lX1003`3lX1000`2][Jd0oj@A0?nT4@040?nT4@80000000<0oj@A0:f]
[@2][Jd00P2][Jd20?nT4@8000001@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00T0mY`?0`2][Jd2000000H0mY`?00<0[Jf]0>bF3P0000003`3/UPh00`2][Jd0fhX=0=^:3@020=^:
3@030000003KRPd0fhX=00<000000`3KRPd2000000040;Ue2`2][Jd0[Jf]000000<0^GD;0P000000
0`2][Jd0R5H708QF1`0400000440/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>
00@0dhL>00<0[Jf]0=>73P2][Jd00P3_V1000`000000kiP@000000050>nH4080000000<0kiP@0000
003lX100403lX1000`2][Jd0oj@A0?nT4@030?nT4@040:f][@00000000000:f][@H0oj@A0P000005
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l2000000@0[Jf]0P3fW0l0
0`2][Jd0k9H>0000000@0>bF3P050:f][@3KRPd0fhX=0=^:3@0000000P3KRPd3000000<0fhX=0P00
00030;Ue2`040000002iM@/0^GD;0;Ue2`80000000D0[Jf]08QF1`28EPL0000008QF1`0300000400
/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00<0dhL>00@0[Jf]0=>73P3CQ`h0
[Jf]0P3_V1000`000000kiP@000000050>nH4080000000<0kiP@0:f][@3lX100403lX1000`2][Jd0
oj@A0:f][@030:f][@030?nT4@000000000000L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0303fW0l2000000@0mY`?0`2][Jd200000100k9H>00<0[Jf]0=^:3@3K
RPd00P3KRPd2000000030=^:3@000000000000<0fhX=0P0000030;Ue2`040000002][Jd0^GD;0;Ue
2`80000000D0[Jf]08QF1`28EPL0000008QF1`0300000400/>3V0@3oool005P0/>3V0P2][Jd309MP
2`040:f][@3CQ`h0dhL>0=>73P80[Jf]0`3CQ`h01P2][Jd0kiP@0>nH40000000kiP@000000@0kiP@
0P0000020>nH40030:f][@3lX100o:0@00h0o:0@0`2][Jd50?nT4@8000001`3oY142000000D0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0<0?JL3`8000001P3fW0l00`2][Jd00000
000000020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd010000000fhX=0000000000030=^:3@80
00000`2iM@/010000000^GD;0:f][@2iM@/2000000050:f][@28EPL0R5H700000028EPL00`000010
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>73P2][Jd50=>73P060:f][@3_V100
kiP@0000003_V1000000203_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY140
1@3oY142000000L0oj@A0P0000050?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
303fW0l2000000H0mY`?00<0[Jf]0000000000000P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd0
1@3KRPd2000000@0fhX=0P0000020;Ue2`040000002iM@/0^GD;0:f][@80000000D0[Jf]08QF1`28
EPL0000008QF1`0300000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0[Jf]00H0
dhL>00H0[Jf]0>nH403_V10000000>nH400000080>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd3
0?bP40030:f][@3oY140oj@A00@0oj@A0P0000050?nT4@8000001`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?00X0mY`?100000060?JL3`030:f][@000000000000@0k9H>0`2][Jd9
0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P0000040=^:3@8000000P2iM@/01`000000^GD;0;Ue2`2i
M@/000000:f][@0000000P28EPL01@000000R5H70000002][Jd000000400/>3V0@3oool005P0/>3V
0P2][Jd309MP2`80[Jf]1`3CQ`h01P2][Jd0kiP@0>nH40000000kiP@000000P0kiP@00<0[Jf]0?bP
403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140103oY142000000h0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0<0?JL3`@00000103fW0l00`2][Jd00000000000070>bF
3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@050=^:3@800000103KRPd00`2][Jd000000;Ue2`020000
00<0^GD;00<000000;Ue2`0000000P28EPL01@000000R5H70000002][Jd000000400/>3V0@3oool0
05P0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00<00000203_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@020?nT
4@8000003`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?0100mY`?100000000`2][Jd000000000000:0>bF3P80[Jf]103/UPh00`2]
[Jd0fhX=0=^:3@050=^:3@800000103KRPd00`2][Jd0000000000002000000<0^GD;00X000000;Ue
2`000000[Jf]08QF1`000000R5H70000002][Jd00000@02`h>H10?ooo`00F02`h>H0102][Jd0Uf0;
09MP2`2GH0/20:f][@L0dhL>00@0[Jf]0>nH403_V100kiP@0`0000080>nH40040:f][@3lX100o:0@
0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?0`00000<
0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd01`3KRPd2000000@0fhX=00<0[Jf]000000000000102iM@/0
1@000000^GD;0000002][Jd0R5H700<0000000<0[Jf]0000002`h>H0?`2`h>H10?ooo`00F02`h>H0
102][Jd0Uf0;09MP2`2GH0/20:f][@L0dhL>00@0[Jf]0>nH403_V100kiP@0P0000090>nH40040:f]
[@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@03
0:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@L0fhX=0P0000040=^:3@03
0:f][@2iM@/0^GD;00@0^GD;00D000000;Ue2`000000R5H70:f][@0500000400/>3V0@3oool005P0
/>3V00H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd70=>73P040:f][@3_V100kiP@0>nH40800000203_
V1030:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3o
YQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd50=^:3@800000
103KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`050000002iM@/0000008QF1`2][Jd01@0000100;3PiP40
oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@
0>nH403_V102000000H0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:
3@80[Jf]0`3KRPd2000000@0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/2000000040;Ue2`000000R5H7
08QF1`D00000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>
00D0dhL>00@0[Jf]0>nH403_V100kiP@0P0000040>nH4080[Jf]0`3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB
0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@03
0=^:3@80[Jf]00<0fhX=000000000000103KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`050000002iM@/0
[Jf]00000028EPL01@0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P05
0=>73P040:f][@3_V100kiP@0>nH408000000P3_V1020:f][@D0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3l
X1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3K
RPd00`2][Jd00000000000040=^:3@030:f][@2iM@/0^GD;00D0^GD;00@000000:f][@000000R5H7
1@0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P040:f][@3_
V100kiP@0>nH408000000P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0
5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P0000001@2][Jd0fhX=
0=^:3@3KRPd0[Jf]00P0^GD;0P0000000`28EPL000000000000300000400/>3V0@3oool005L0/>3V
0P2][Jd409MP2`030:f][@3CQ`h0dhL>00D0dhL>00H0[Jf]0>nH403_V100kiP@0000002][Jd90>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ47
0:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@060=^:3@80000000D0fhX=0:f][@2][Jd0fhX=0:f][@090;Ue2`0500000028
EPL000000000002][Jd00P0000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>7
3P060=>73P050:f][@3_V100[Jf]0:f][@0000002P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00H0fhX=0P0000030=^:3@80[Jf]2@2iM@/01@2][Jd00000000000000000[Jf]0080
0000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f][@80kiP@
00<000000>nH403_V100203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A
102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=
100000040=^:3@<0[Jf]1`2iM@/01@2][Jd0R5H7000000000000[Jf]00800000@02`h>H10?ooo`00
E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@<0kiP@00<000000>nH403_V100
203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]
303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P0000040=^:3@040:f]
[@2iM@/0^GD;0:f][@H0^GD;00D0[Jf]08QF1`00000000000:f][@0200000400/>3V0@3oool005L0
/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH40020>nH4003
0000003_V100kiP@00L0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040?nT4@D0
[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@05
0:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]00800000@02`h>H1
0?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0
[Jf]00d0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd2
0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`02
0;Ue2`80[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL300000400/>3V0@3oool005L0/>3V0P2][Jd3
09MP2`050:f][@3CQ`h0dhL>0=>73P2][Jd0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL0102][Jd0000000000000000o0;3PiP40
oooo001G0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0:f][@2][Jd50=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0R5H700@0[Jf]045Yh@0000000000?`2`h>H10?oo
o`00E`2`h>H20:f][@<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2]
[Jd000000000000o0;3PiP40oooo001G0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80
[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/20:f][@<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H0102][Jd0Uf0;
09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0
[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@000000000003l0
/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0
/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3K
RPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL0[Jf]08QF1`11JN40[Jf]0P00000o
0;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n
]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H700<0
[Jf]0;3PiP000000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`080:f][@28EPL0
R5H70:f][@28EPL0[Jf]0;3PiP00000o0;3PiP40oooo001G0;3PiP030:f][@2GH0/0[Jf]0080Uf0;
00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`2`h>H000000;3PiP0n0;3PiP40oooo001G0;3PiP80[Jf]
0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030;3PiP000000/>3V03h0/>3V0@3oool005L0/>3V
0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BN
S`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0
_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V
00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080
[Jf]00D0Y9j?045Yh@2TWXl0Y9j?0:f][@040;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f]
[@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0:f][@2][Jd20:BNS`80@FWQ0P2TWXl00`2][Jd0/J^M0;6[
W@040;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V00T0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]
202n^KP0102][Jd0];2a0;B`/@2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28
EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd02@3CQ`h20:f][@04045Yh@2TWXl0Y9j?0:BNS`80@FWQ0P2TWXl00`2][Jd0@FWQ045Yh@06
0;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP030;VbYP80@FWQ2@2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`
/@030;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V
0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f][@2TWXl0Y9j?045Yh@@0
Y9j?00@0@FWQ0:BNS`2TWXl0[Jf]0`11JN470;6[W@80[Jf]00<0/J^M0:f][@2i/ZH01@2i/ZH3045Y
h@L0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f]
[@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00`0`kfk0`2][Jd80;ji^005045Yh@2n^KP0_[Vh0;ji^02][Jd01`2d/;420:f][@P0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd01P3CQ`h20:f][@04045Yh@2TWXl0Y9j?045Yh@@0Y9j?00@0@FWQ0:BNS`2TWXl0
[Jf]0P11JN4:0;6[W@<0[Jf]1@2i/ZH00`11JN40^K:V0;VbYP070;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m
^`<0[Jf]00<0`kfk0:f][@2n^KP01`2n^KP2045Yh@<0_[Vh00<0[Jf]0;B`/@2d/;401`2d/;400`2]
[Jd0^GD;0;Ue2`050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H1
0?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]045Yh@2][Jd0@FWQ0:BN
S`02045Yh@@0Y9j?00@0@FWQ0:BNS`2][Jd0/J^M0P11JN4;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]
00<0^K:V045Yh@2i/ZH0202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh
0;ji^0020;ji^003045Yh@2n^KP0_[Vh0080_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP00`2][Jd0];2a
0;B`/@060;B`/@03045Yh@2][Jd0[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000
/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01P2][Jd0
@FWQ045Yh@2][Jd0@FWQ0:BNS`80@FWQ102TWXl01011JN40Y9j?0:f][@2aZid2045Yh@/0/J^M00<0
[Jf]0;VbYP2i/ZH00`2i/ZH00`2][Jd0@FWQ0:f][@080;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102]
[Jd70<>m^`030:f][@2n^KP0_[Vh0080@FWQ00<0_[Vh045Yh@2n^KP01`2n^KP00`2][Jd0];2a0;B`
/@060;B`/@03045Yh@2][Jd0[Jf]0080[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000
002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P070:f]
[@2:QGD0@FWQ08Z5M@2][Jd0@FWQ0:f][@02045Yh@@0Y9j?00@0@FWQ0:BNS`2][Jd0/J^M0P11JN47
0;6[W@@0@FWQ00<0[Jf]0;VbYP2i/ZH0102i/ZH00`11JN40^K:V0:f][@020:f][@D0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/0
0`2][Jd0@FWQ045Yh@030;ji^003045Yh@2n^KP0_[Vh00H0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40
102][Jd0@FWQ0;B`/@2][Jd209nKX0040:f][@2iM@/0^GD;0:f][@<0R5H70P2][Jd00`000000/>3V
0;3PiP0m0;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd01`11JN40
RXEe045Yh@2:QGD0[Jf]045Yh@2TWXl00P11JN440:BNS`04045Yh@2TWXl0[Jf]0;6[W@80@FWQ1`2a
Zid01@11JN40/J^M0;6[W@11JN40[Jf]00H0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH40:f][@030;Vb
YP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@h0`kfk00<0[Jf]045Yh@11JN40
0`2n^KP00`11JN40_[Vh0;ji^0060;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd20;B`/@05045Y
h@2][Jd0Wi^P09nKX011JN400`2][Jd408QF1`030:f][@2`h>H0000003h0/>3V0@3oool005H0/>3V
00<0[Jf]09MP2`2GH0/00P2GH0/20:f][@<0RXEe0P11JN40102:QGD0[Jf]045Yh@2TWXl2045Yh@03
0:f][@2TWXl0@FWQ0080@FWQ00<0Y9j?0:f][@2aZid00P11JN460;6[W@80@FWQ0`2aZid01011JN40
^K:V0;VbYP11JN430;VbYP03045Yh@2i/ZH0^K:V00H0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`0>0<>m
^`030:f][@11JN40_[Vh00<0_[Vh00<0@FWQ0;ji^02n^KP01P2n^KP0102][Jd0];2a0;B`/@2d/;42
0:f][@@0];2a00<0@FWQ0:f][@2OVj000P11JN4209nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]
0;3PiP000000?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@2:QGD0RXEe
00<0RXEe00H0@FWQ08Z5M@2][Jd0@FWQ0:BNS`11JN420:BNS`80[Jf]00D0Y9j?045Yh@11JN40[Jf]
0;6[W@02045Yh@H0/J^M0P11JN430;6[W@03045Yh@2i/ZH0@FWQ00@0^K:V00<0@FWQ0;VbYP2i/ZH0
1`2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l
00<0[Jf]0<>m^`33_K/01P33_K/4045Yh@<0`kfk00<0[Jf]045Yh@2n^KP00`2n^KP00`11JN40_[Vh
0;ji^0060;ji^0040:f][@2d/;40];2a0:f][@H0];2a00<0@FWQ0:f][@2OVj000P11JN4309nKX005
0:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@L0RXEe0P11JN400`2TWXl0@FWQ0:BNS`030:BNS`060:f][@2TWXl0Y9j?0:f][@2aZid0@FWQ1`2a
Zid2045Yh@<0/J^M00<0[Jf]045Yh@11JN40102i/ZH01011JN40^K:V045Yh@11JN460;VbYP030:f]
[@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<0
5033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_0080<O1_0<0@FWQ1P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]
2@36`;`00`2][Jd0`kfk0<>m^`050<>m^`05045Yh@33_K/0`kfk0<>m^`11JN401033_K/00`11JN40
_[Vh0;ji^0020;ji^005045Yh@2n^KP0_[Vh0;ji^011JN40102n^KP30:f][@L0];2a00<0@FWQ0:f]
[@2OVj000P11JN4309nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102]
[Jd0Uf0;09MP2`2GH0/20:f][@L0RXEe00@0[Jf]045Yh@2TWXl0@FWQ1@2TWXl30:f][@030;6[W@11
JN40/J^M00H0/J^M0P11JN430;6[W@030:f][@11JN40@FWQ00@0^K:V0P11JN400`2i/ZH0@FWQ045Y
h@050;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0
[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0@0@FWQ2037`K`00`2][Jd0a/2l0:f]
[@030:f][@d0a/2l00@0[Jf]045Yh@11JN40@FWQ0`33_K/2045Yh@@0`kfk00D0@FWQ0<>m^`33_K/0
`kfk045Yh@030;ji^080@FWQ0`2n^KP01011JN40_[Vh0;ji^02n^KP20:f][@T0];2a00<0@FWQ0:f]
[@2OVj000P11JN4409nKX0040:f][@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V00<0[Jf]09MP
2`2GH0/00`2][Jd708Z5M@040:f][@2TWXl0@FWQ045Yh@L0Y9j?0P2][Jd00`11JN40/J^M0;6[W@05
0;6[W@80@FWQ0`2aZid00`2][Jd0@FWQ045Yh@040;VbYP04045Yh@2i/ZH0^K:V0;VbYP80@FWQ102i
/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00L0al6l0P11JN460<O1_0@0[Jf]4036`;`3045Yh@@0`kfk0P11
JN490<>m^`050:f][@2n^KP0_[Vh0;ji^011JN40102n^KP01P11JN40_[Vh0:f][@2][Jd0_[Vh0:f]
[@T0];2a00<0@FWQ0:f][@2OVj000P11JN4409nKX080[Jf]00<0R5H70:f][@2`h>H0?`2`h>H10?oo
o`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00D0[Jf]0:BNS`2TWXl0Y9j?045Yh@07
0:BNS`040:f][@2aZid0@FWQ0:f][@L0/J^M00D0@FWQ0;6[W@2aZid0/J^M0:f][@02045Yh@@0^K:V
00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;VbYP020;VbYP040:f][@11JN40@FWQ045Yh@h0
_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01`37`K`2045Yh@03
0<O1_02][Jd0[Jf]00<0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00:0<K0_0<0@FWQ0`36`;`00`2][Jd0
@FWQ0<>m^`030<>m^`80@FWQ2@33_K/00`2][Jd0_[Vh0;ji^002045Yh@@0_[Vh00<0@FWQ0:f][@2n
^KP00P2n^KP00`2][Jd0];2a0;B`/@070;B`/@03045Yh@2][Jd0Wi^P0080@FWQ102OVj00102][Jd0
L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@04
0:f][@2TWXl0Y9j?0:BNS`80@FWQ1P2TWXl0102][Jd0/J^M045Yh@11JN430:f][@@0/J^M00D0@FWQ
0;6[W@2aZid0/J^M0:f][@02045Yh@<0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@<0^K:V00<0
[Jf]0;jg[02n]j`00`11JN420;jg[003045Yh@2n]j`0_[N/00P0_[N/00<0[Jf]0<6j/031^[001@2]
[Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`20:f][@80@FWQ00<0
[Jf]0<O1_037`K`01@37`K`00`2][Jd0a/2l0<K0_0080<K0_0<0@FWQ1@36`;`00`2][Jd0@FWQ0<>m
^`030<>m^`80@FWQ2@33_K/0102][Jd0_[Vh045Yh@11JN420;ji^0<0[Jf]00<0@FWQ0;ji^02n^KP0
0P2n^KP00`2][Jd0];2a0;B`/@070;B`/@04045Yh@2][Jd0Wi^P045Yh@@0Wi^P0P2][Jd00`1`KWT0
[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00@0[Jf]0:BNS`2TWXl0
Y9j?0P11JN460:BNS`040:f][@2aZid0@FWQ045Yh@<0/J^M0P2][Jd30;6[W@05045Yh@2aZid0/J^M
0:f][@11JN40102i/ZH00`11JN40^K:V0;VbYP040;VbYP05045Yh@2i/ZH0^K:V0;VbYP2][Jd00P2n
]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ202n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]0P37`K`2045Yh@P0al6l00<0
[Jf]0<K0_036`;`00`36`;`3045Yh@@0a/2l00<0@FWQ0<K0_036`;`00`36`;`00`2][Jd0@FWQ0<>m
^`030<>m^`03045Yh@33_K/0`kfk00P0`kfk00@0[Jf]045Yh@11JN40_[Vh0P2][Jd30;ji^003045Y
h@2n^KP0_[Vh0080_[Vh00<0[Jf]0;B`/@2d/;401`2d/;401011JN40[Jf]09nKX011JN4309nKX003
0:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C
00<0[Jf]08Z5M@2][Jd0102:QGD0102][Jd0Y9j?0:BNS`2TWXl2045Yh@H0Y9j?00@0[Jf]0;6[W@11
JN40@FWQ0P2aZid00`11JN40/J^M0;6[W@030:f][@050;6[W@11JN40/J^M0:f][@11JN40102i/ZH0
0`11JN40^K:V0;VbYP040;VbYP04045Yh@2i/ZH0^K:V0:f][@<0_[N/00<0@FWQ0;jg[02n]j`0102n
]j`3045Yh@80_[N/0`11JN400`2n]j`0[Jf]0<6j/00;0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0@0<S1^`H0[Jf]1`37`K`2045Yh@P0al6l00@0[Jf]0<K0_036`;`0a/2l0`11JN460<K0_003045Y
h@36`;`0a/2l00<0a/2l00<0[Jf]045Yh@33_K/00`33_K/00`11JN40`kfk0<>m^`080<>m^`80@FWQ
0P2][Jd20;ji^004045Yh@2n^KP0_[Vh045Yh@@0_[Vh00<0[Jf]0;B`/@2d/;401`2d/;401011JN40
[Jf]045Yh@11JN4209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD0102][Jd0Y9j?0:BNS`2T
WXl2045Yh@@0Y9j?00H0@FWQ0:BNS`11JN40/J^M045Yh@2aZid3045Yh@D0/J^M0P2][Jd00`11JN40
[Jf]045Yh@040;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]0`2n]j`00`11
JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00@0_[N/1011JN4@0<6j/0P0[Jf]4033_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f]
[@<0b<6k00<0[Jf]0<O1_037`K`01`37`K`2045Yh@P0al6l00<0[Jf]0<K0_036`;`00`36`;`00`11
JN40a/2l0<K0_0040<K0_003045Yh@36`;`0a/2l00<0a/2l00<0[Jf]045Yh@33_K/00`33_K/00`11
JN40`kfk0<>m^`070<>m^`030:f][@11JN40[Jf]00<0_[Vh0P11JN420;ji^003045Yh@2n^KP0_[Vh
0080_[Vh00<0[Jf]0;B`/@2d/;401`2d/;401011JN40[Jf]045Yh@2OVj020:f][@<0Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5
M@2:QGD0RXEe0:f][@0208Z5M@040:f][@2TWXl0Y9j?0:BNS`80@FWQ102TWXl00`11JN40Y9j?0:f]
[@02045Yh@040;6[W@11JN40@FWQ045Yh@<0/J^M0P11JN420;6[W@030:f][@11JN40@FWQ00@0^K:V
00<0@FWQ0;VbYP2i/ZH0102i/ZH2045Yh@030;VbYP2][Jd0_[N/0080_[N/00<0@FWQ0;jg[02n]j`0
102n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc
0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00L0al6l0P11JN420<O1_0@0
@FWQ0P37`K`00`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l00@0a/2l00<0@FWQ0<K0_036
`;`00`36`;`00`2][Jd0@FWQ0<>m^`030<>m^`03045Yh@33_K/0`kfk00@0`kfk00D0@FWQ0:f][@2]
[Jd0`kfk045Yh@040;ji^080@FWQ0P2n^KP2045Yh@<0_[Vh00<0[Jf]0;B`/@2d/;401`2d/;42045Y
h@0309nKX02][Jd0Wi^P00@0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@030:BNS`80
@FWQ0`2TWXl2045Yh@030:BNS`2][Jd0/J^M0080/J^M00<0@FWQ0;6[W@11JN400`2aZid2045Yh@<0
/J^M00<0[Jf]045Yh@2][Jd00P2][Jd00`2i/ZH0@FWQ0;VbYP050;VbYP80@FWQ00<0^K:V0:f][@2n
]j`00P2n]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN400`2][Jd0
`KZ`0<6j/0030<6j/0@0@FWQ2P31^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0[Jf]4@35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0030<O1_080@FWQ0P37`K`2045Yh@03
0<O1_011JN40al6l0080al6l0P11JN400`37`K`0[Jf]0<K0_0040<K0_003045Yh@36`;`0a/2l00@0
a/2l00<0@FWQ0<K0_036`;`00`36`;`00`2][Jd0@FWQ0<>m^`030<>m^`04045Yh@33_K/0`kfk0<>m
^`80[Jf]0P11JN430<>m^`03045Yh@2n^KP0_[Vh0080_[Vh0P11JN420;ji^080@FWQ0`2n^KP00`2]
[Jd0];2a0;B`/@070;B`/@03045Yh@2][Jd0[Jf]00H0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@@0
Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?0P11JN400`2TWXl0[Jf]0;6[W@030;6[W@80@FWQ0`2aZid2045Y
h@<0/J^M00<0[Jf]045Yh@2i/ZH00P2i/ZH00`2][Jd0@FWQ0:f][@050;VbYP80@FWQ00<0^K:V0:f]
[@2n]j`00P2n]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN400`2]
[Jd0`KZ`0<6j/0020<6j/0<0@FWQ0P31^[02045Yh@H0`KZ`00<0@FWQ0<6j/02][Jd05@33_K<00`2]
[Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@11JN40al6l0080al6l00<0@FWQ0<O1_037`K`00P37`K`3045Y
h@D0al6l0P11JN400`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l00@0a/2l0P11JN440<K0
_0030:f][@11JN40@FWQ00<0`kfk00@0@FWQ0<>m^`2][Jd0[Jf]0P33_K/2045Yh@<0`kfk00<0@FWQ
0;ji^02n^KP00P2n^KP2045Yh@80_[Vh0P11JN430;ji^0030:f][@2d/;40];2a00H0];2a00<0@FWQ
0;B`/@2][Jd01`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?0080Y9j?00D0@FWQ
0:BNS`2TWXl0Y9j?045Yh@020:BNS`030:f][@2aZid0/J^M00P0/J^M00H0@FWQ0;6[W@2aZid0/J^M
0:f][@11JN440;VbYP03045Yh@2i/ZH0[Jf]00<0[Jf]00D0^K:V045Yh@11JN40^K:V0:f][@030;jg
[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`0102n]j`2045Yh@@0`KZ`0P11JN460<6j
/003045Yh@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/02][Jd01011JN4A0<>m/`030:f][@35_[D0aKje
00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f]
[A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/2045Yh@050<O1_011JN40al6l0<O1_011JN401037`K`3
045Yh@D0al6l0P11JN400`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l00@0a/2l0P11JN44
0<K0_0030:f][@11JN40@FWQ0080`kfk00<0[Jf]045Yh@2][Jd01@33_K/01P11JN40`kfk0<>m^`33
_K/0[Jf]045Yh@80_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP2045Yh@<0_[Vh00<0[Jf]0;B`/@2d/;40
1P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f]
[@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@80Y9j?00<0@FWQ0:BNS`2TWXl00P11JN420:BNS`03
0:f][@2aZid0/J^M00T0/J^M00@0@FWQ0;6[W@2aZid0@FWQ1@2i/ZH00`11JN40^K:V0;VbYP030;Vb
YP050:f][@11JN40@FWQ0;VbYP2][Jd00`2n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ1P2n]j`2
045Yh@@0`KZ`0P11JN460<6j/003045Yh@31^[00`KZ`00<0`KZ`0`11JN430<>m/`03045Yh@33_K<0
`kfc00l0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00<0b<6k0`11JN4:0<S1^`80@FWQ00@0b<6k
0:f][@37`K`0al6l0`11JN440<O1_080@FWQ1P37`K`2045Yh@030:f][@36`;`0a/2l00<0a/2l00<0
@FWQ0<K0_036`;`01036`;`2045Yh@@0a/2l00<0[Jf]045Yh@11JN400P2][Jd00`33_K/0@FWQ045Y
h@040<>m^`03045Yh@33_K/0`kfk0080`kfk00@0[Jf]0;ji^011JN40@FWQ1@2n^KP2045Yh@<0_[Vh
00<0[Jf]0;B`/@2d/;401@2d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^
N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BN
S`2TWXl00P2][Jd00`2TWXl0@FWQ045Yh@02045Yh@80Y9j?00<0[Jf]0;6[W@2aZid02P2aZid2045Y
h@030:f][@2i/ZH0^K:V00<0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@040;VbYP2][Jd0[Jf]
0:f][@80_[N/00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@H0_[N/0P11JN430<6j/003045Yh@31^[00
@FWQ00L0`KZ`00<0@FWQ0<6j/031^[000P31^[02045Yh@030:f][@33_K<0`kfc0080`kfc00<0@FWQ
0<>m/`33_K<01033_K<00`11JN40`kfc0<>m/`070<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k045Yh@04045Yh@/0b<6k0P11JN420<S1^`040:f][@37`K`0
al6l0<O1_080@FWQ1037`K`2045Yh@L0al6l0P11JN450<K0_003045Yh@36`;`0a/2l00@0a/2l0P11
JN420<K0_0<0[Jf]0P11JN430<>m^`80@FWQ1033_K/00`11JN40`kfk0<>m^`020<>m^`030:f][@2n
^KP0_[Vh00H0_[Vh0P11JN430;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1S
H5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl01@2][Jd0Y9j?0:BNS`2TWXl0@FWQ0080
Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP030;VbYP80@FWQ102i/ZH2045Yh@80
^K:V00H0[Jf]0;jg[02][Jd0[Jf]045Yh@2][Jd40;jg[080@FWQ1P2n]j`2045Yh@<0`KZ`0P11JN4=
0<6j/003045Yh@31^[00[Jf]00D0`kfc00<0@FWQ0<>m/`33_K<00`33_K<2045Yh@P0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0<0<S1^`80@FWQ0`38`K/2045Yh@030<S1^`2][Jd0
b<6k00<0b<6k0P11JN4;0<S1^`80@FWQ0P38`K/0102][Jd0al6l0<O1_037`K`2045Yh@D0al6l00<0
@FWQ0<O1_037`K`01@37`K`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`00`36`;`00`2][Jd0@FWQ045Y
h@020:f][@80a/2l00<0[Jf]045Yh@11JN401033_K/01@11JN40`kfk0<>m^`33_K/0@FWQ00D0`kfk
00<0[Jf]0;ji^02n^KP01P2n^KP2045Yh@<0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0
Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd01@2TWXl0@FWQ0:BNS`2TWXl0
[Jf]00h0/J^M00H0[Jf]0;VbYP2i/ZH0^K:V045Yh@2i/ZH2045Yh@<0^K:V0P11JN430;VbYP060:f]
[@2n]j`0_[N/0;jg[011JN40_[N/102][Jd2045Yh@H0_[N/00<0@FWQ0:f][@31^[000P31^[02045Y
h@d0`KZ`00<0@FWQ0<6j/02][Jd01@33_K<00`11JN40`kfc0<>m/`030<>m/`03045Yh@33_K<0`kfc
00L0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`11JN40b<6k0<S1^`0:0<S1^`80@FWQ0P38`K/2045Y
h@050<S1^`11JN40@FWQ0<S1^`2][Jd01038`K/2045Yh@/0b<6k0P11JN420<S1^`040:f][@37`K`0
al6l0<O1_080@FWQ1@37`K`00`11JN40al6l0<O1_0050<O1_080@FWQ1@36`;`00`11JN40a/2l0:f]
[@030:f][@030<K0_011JN40@FWQ00@0a/2l00<0[Jf]045Yh@11JN401@33_K/4045Yh@D0`kfk00<0
[Jf]0;ji^02n^KP01P2n^KP2045Yh@<0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P
09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd0
1`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f]
[@2i/ZH0^K:V00<0^K:V0P11JN40102i/ZH0@FWQ0;VbYP2i/ZH2045Yh@<0^K:V00<0[Jf]0;jg[02n
]j`00P11JN450;jg[080@FWQ0P2][Jd40;jg[003045Yh@2][Jd0`KZ`0080`KZ`0P11JN4?0<6j/003
0:f][@33_K<0`kfc00<0`kfc00<0@FWQ0<>m/`33_K<03@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng00P0a[ng2@11JN440<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]045Yh@11
JN400P11JN440<O1^P80@FWQ1`37`KX00`11JN40al6j0<O1^P030<O1^P03045Yh@38`K/0b<6k00T0
b<6k0P11JN450<S1^`<0@FWQ00<0b<6k0:f][@38`K/00`38`K/2045Yh@/0b<6k0P11JN420<S1^`04
0:f][@37`K`0al6l0<O1_080@FWQ1@37`K`00`11JN40al6l0<O1_0050<O1_080@FWQ0P36`;`30:f]
[@03045Yh@2][Jd0a/2l00@0a/2l0P11JN440<K0_0030:f][@11JN40@FWQ00h0`kfk00<0[Jf]0;ji
^02n^KP01P2n^KP2045Yh@<0_[Vh0`2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^
N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0
Y9j?0`2][Jd=0;6[W@030:f][@2i/ZH0^K:V00L0^K:V0`11JN440;VbYP030:f][@2n]j`0_[N/0080
@FWQ1@2n]j`2045Yh@80_[N/102][Jd00`11JN40[Jf]0<6j/0020<6j/080@FWQ3`31^[000`2][Jd0
`kfc0<>m/`020<>m/`80@FWQ3`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00/0
a[ng00<0@FWQ0<Jo]`36_kL00`36_kL2045Yh@80a[ng00@0[Jf]0<O1^037`KP0al6h1`11JN4<0<O1
^003045Yh@37`KX0al6j0080al6j00<0@FWQ0<O1^P37`KX00P11JN480<O1^P03045Yh@37`KX0al6j
00<0al6j00<0@FWQ0<S1^`38`K/02038`K/2045Yh@L0b<6k0P11JN400`38`K/0[Jf]0<S1^`030<S1
^`80@FWQ2`38`K/2045Yh@80b<6k00@0[Jf]0<O1_037`K`0al6l0P11JN450<O1_003045Yh@37`K`0
al6l00@0al6l00<0[Jf]045Yh@11JN400P2][Jd30<K0_003045Yh@36`;`0a/2l00@0a/2l0P11JN44
0<K0_0030:f][@11JN40@FWQ00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP00`11JN40_[Vh0;ji^002
0:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3P
iP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP060:f][@2n]j`0_[N/045Yh@2n]j`0@FWQ102n]j`2045Yh@H0_[N/00<0@FWQ0:f][@2][Jd00P2]
[Jd2045Yh@l0`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN4@0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL02`36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ00<0a[ng0:f][@37`KP0
1@37`KP2045Yh@d0al6h0P11JN450<O1^P04045Yh@37`KX0@FWQ045Yh@L0al6j0P11JN440<O1^P03
045Yh@2][Jd0@FWQ00T0b<6k00<0@FWQ0<S1^`38`K/01P38`K/2045Yh@030<S1^`2][Jd0b<6k00<0
b<6k0P11JN4;0<S1^`80@FWQ0P38`K/0102][Jd0al6l0<O1_037`K`2045Yh@D0al6l00<0@FWQ0<O1
_02][Jd0102][Jd2045Yh@030:f][@36`;`0a/2l00<0a/2l0P11JN440<K0_080@FWQ1036`;`4045Y
h@h0`kfk00<0[Jf]0;ji^02n^KP0202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nK
X02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00H0[Jf]0;jg[02n
]j`0@FWQ0;jg[011JN440;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0@FWQ0:f][@31^[000P31^[02
045Yh@D0[Jf]2P31^[000`2][Jd0`kfc045Yh@02045YhA40`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0;0<Jo]`03045Yh@36_kL0a[ng00D0a[ng0P11JN400`2][Jd0al6h0<O1^004
0<O1^080@FWQ3037`KP2045Yh@030:f][@37`KX0al6j00<0al6j0`11JN480<O1^P<0@FWQ0`37`KX3
045Yh@P0b<6k0P11JN480<S1^`80@FWQ00<0b<6k0:f][@38`K/00`38`K/2045Yh@`0b<6k00@0@FWQ
0<S1^`38`K/0[Jf]0`37`K`2045Yh@80al6l0`2][Jd00`11JN40[Jf]0<O1_0040<O1_080@FWQ00<0
[Jf]0<K0_036`;`00`36`;`2045Yh@@0a/2l0P11JN450<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nK
X00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
102][Jd0_[N/0;jg[011JN420;jg[080@FWQ0P2n]j`00`11JN40_[N/0;jg[0050;jg[003045Yh@2]
[Jd0`KZ`00<0`KZ`0P11JN440<6j/080[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd30<6j/0@0@FWQ2033
_K<00`11JN40`kfc0<>m/`070<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02`36
_kL00`11JN40a[ng0<Jo]`060<Jo]`80@FWQ1P37`KP2045Yh@`0al6h0P11JN400`37`KP0[Jf]0<O1
^P040<O1^P80@FWQ0P37`KX00`000000al6j0<O1^P030<O1^P<0@FWQ0`37`KX3045Yh@P0b<6k0P11
JN480<S1^`80@FWQ00<0b<6k0:f][@38`K/00`38`K/2045Yh@d0b<6k2011JN420:f][@<0al6l00<0
@FWQ0<O1_037`K`01037`K`2045Yh@030:f][@36`;`0a/2l00<0a/2l0`11JN420<K0_080@FWQ1P36
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d
/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K
0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@04
0;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;VbYP0>0;VbYP040:f][@2n]j`0_[N/045Yh@@0_[N/0P11
JN480;jg[003045Yh@2][Jd0`KZ`00<0`KZ`0P11JN450<6j/003045Yh@31^[00@FWQ00<0`KZ`0P2]
[Jd3045Yh@80[Jf]2033_K<00`11JN40`kfc0<>m/`070<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02`36_kL00`11JN40a[ng0<Jo]`060<Jo]`80@FWQ1P37`KP2045Yh@`0al6h0P11
JN400`37`KP0[Jf]0<O1^P040<O1^P80@FWQ2037`KX3045Yh@<0al6j0`11JN480<S1^`80@FWQ2038
`K/2045Yh@030<S1^`2][Jd0b<6k00<0b<6k0P11JN4<0<S1^`H0[Jf]00<0al6l045Yh@11JN401@37
`K`00`11JN40al6l0<O1_0030<O1_080@FWQ00<0al6l0:f][@36`;`01036`;`2045Yh@030<K0_011
JN40@FWQ00T0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh
00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V
0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2a
Zid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP040:f][@2n]j`0_[N/045Yh@`0_[N/
00@0@FWQ0;jg[011JN40[Jf]1031^[02045Yh@H0`KZ`0P11JN440<6j/080@FWQ00@0[Jf]0<>m/`33
_K<0`kfc1`2][Jd00`33_K<0@FWQ0<>m/`080<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL02`36_kL00`11JN40a[ng0<Jo]`070<Jo]`03045Yh@37`KP0al6h00@0al6h0P11JN4<0<O1
^080@FWQ00<0al6h0:f][@37`KX01037`KX2045Yh@L0al6j0P11JN400`37`KX0@FWQ0<O1^P020<O1
^P03045Yh@2][Jd0@FWQ00L0b<6k0P11JN490<S1^`@0@FWQ1038`K/2045Yh@D0b<6k1`2][Jd30<S1
^`040:f][@37`K`0al6l0<O1_080@FWQ1@37`K`2045Yh@@0al6l0P11JN400`37`K`0[Jf]0<K0_004
0<K0_080@FWQ3036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V0@3o
ool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00X0/J^M0`2][Jd?0;VbYP040:f][@2n]j`0_[N/045Yh@d0_[N/0P11JN400`2][Jd0`KZ`0<6j
/0030<6j/080@FWQ1@31^[000`11JN40`KZ`0<6j/0030<6j/003045Yh@31^[00[Jf]00D0`kfc00<0
@FWQ0<>m/`33_K<00P33_K<00`2][Jd0@FWQ0:f][@050:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0;0<Jo]`03045Yh@36_kL0a[ng00L0a[ng00<0@FWQ0<O1^037`KP01037
`KP2045Yh@`0al6h0P11JN400`37`KP0[Jf]0<O1^P040<O1^P80@FWQ1`37`KX2045Yh@040<O1^P11
JN40al6j0<O1^P80@FWQ00<0[Jf]045Yh@38`K/00P0000040<S1^`80@FWQ1`38`K/4045Yh@030<S1
^`2][Jd0b<6k0080b<6k00<0[Jf]045Yh@11JN401@2][Jd70<S1^`04045Yh@38`K/0b<6k0:f][@<0
al6l00<0@FWQ0<O1_037`K`01037`K`00`11JN40al6l045Yh@020<O1_080@FWQ0P37`K`00`2][Jd0
a/2l0<K0_0030<K0_080@FWQ3036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]
2`2i/ZH0102][Jd0_[N/0;jg[011JN4?0;jg[0030:f][@31^[00`KZ`00@0`KZ`00<0@FWQ0<6j/031
^[000P31^[000`11JN40`KZ`0<6j/0040<6j/003045Yh@31^[00[Jf]00@0`kfc0P11JN450<>m/`03
045Yh@33_K<0`kfc00@0`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36
_kL01`36_kL00`11JN40al6h0<O1^0040<O1^080@FWQ3@37`KP2045Yh@030:f][@37`KX0al6j00<0
al6j0P11JN470<O1^P80@FWQ0P37`KX01`11JN40al6j045Yh@11JN40[Jf]0<S1^`11JN401P38`K/2
045Yh@L0b<6k2@2][Jd01038`K/0@FWQ045Yh@11JN440<S1^`03045Yh@38`K/0b<6k00@0b<6k00@0
@FWQ0<S1^`38`K/0[Jf]0`37`K`00`11JN40al6l0<O1_0040<O1_003045Yh@37`K`0al6l00<0@FWQ
0`37`K`00`2][Jd0a/2l0<K0_0030<K0_080@FWQ3036`;`00`11JN40`kfk0<>m^`090<>m^`<0[Jf]
00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V
0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i
/ZH0^K:V00<0^K:V0`2][Jd80;VbYP040:f][@2n]j`0_[N/045Yh@l0_[N/00<0[Jf]0<6j/031^[00
1@31^[04045Yh@L0`KZ`00<0@FWQ0<6j/02][Jd01033_K<2045Yh@D0`kfc00<0@FWQ0<>m/`33_K<0
1`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0;0<Jo]`03045Y
h@36_kL0a[ng00L0a[ng0P11JN450<O1^080@FWQ3P37`KP4045Yh@<0al6j0P11JN470<O1^P80@FWQ
0P37`KX01`11JN40al6j045Yh@11JN40[Jf]0<S1^`11JN400`38`K/30:f][@80@FWQ1`2][Jd50<S1
^`030:f][@38`K/0b<6k0080b<6k0`11JN430<S1^`80@FWQ1P38`K/01011JN40b<6k0<S1^`2][Jd2
0<O1_003045Yh@37`K`0al6l00<0al6l0`11JN490<O1_0030:f][@36`;`0a/2l0080a/2l0P11JN4<
0<K0_080@FWQ1`33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@09
0;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH0102][Jd0_[N/0;jg[011JN4?0;jg[0030:f][@31^[00
`KZ`0140`KZ`00<0@FWQ0:f][@33_K<00P33_K<3045Yh@D0`kfc00<0@FWQ0<>m/`33_K<01`33_K<0
0`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]0P36_kL00`11JN40a[ng0<Jo]`070<Jo]`80@FWQ1@37`KP2
045Yh@l0al6h00<0[Jf]0<O1^P37`KX01@11JN440<O1^P80[Jf]0P11JN430:f][@04045Yh@2][Jd0
@FWQ045Yh@80[Jf]00@0@FWQ0:f][@2][Jd0[Jf]0`38`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/0
0P38`K/3045Yh@<0b<6k00<0@FWQ0<S1^`11JN401P38`K/00`11JN40b<6k0:f][@02045YhA80al6l
00<0[Jf]0<K0_036`;`00P36`;`2045Yh@`0a/2l00<0@FWQ0<>m^`33_K/00P33_K/40:f][@L0`kfk
00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V
0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V00T0^K:V102][Jd01@2i/ZH0[Jf]045Yh@2n]j`0@FWQ00l0_[N/00<0[Jf]0<6j/031^[00
4P31^[04045Yh@80`kfc00<0@FWQ0<>m/`33_K<00P33_K<2045Yh@T0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`090<Jo]`80[Jf]00<0@FWQ0:f][@2][Jd01`2][Jd2045Yh@D0[Jf]
0P11JN4D0:f][@<0@FWQ102][Jd20<O1^P80@FWQ0`37`KX01`11JN40al6j045Yh@11JN40[Jf]0<S1
^`11JN401P38`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@030<S1^`11JN40b<6k
0080b<6k0P11JN470<S1^`80@FWQ5037`K`00`2][Jd0a/2l0<K0_0020<K0_080@FWQ3036`;`00`2]
[Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`
/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0
^K:V0;VbYP0=0;VbYP<0[Jf]0P11JN4?0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<00`33_K<00`11JN40`kfc0<>m/`020<>m/`<0@FWQ2033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL2045Yh@D0al6h0`11JN4>0<O1^003
0:f][@37`KX0al6j00<0al6j0P11JN460<O1^P80@FWQ0`37`KX01`11JN40al6j045Yh@37`KX0[Jf]
0<S1^`11JN401P38`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@80b<6k1011JN49
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00P36`;`2045Yh@X0a/2l102][Jd>
0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;
0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd;0;jg[003045Yh@2n]j`0[Jf]01@0`KZ`00<0[Jf]0<>m
/`33_K<02033_K<3045Yh@P0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0;0<Jo
]`03045Yh@36_kL0a[ng00L0a[ng0P11JN450<O1^0<0@FWQ1037`KP00`11JN40al6h0<O1^0050<O1
^080@FWQ00<0[Jf]0<O1^P37`KX00`37`KX00`11JN40al6j0<O1^P050<O1^P80@FWQ1037`KX2045Y
h@050<O1^P2][Jd0b<6k0<S1^`11JN401@38`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/01011JN4?
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00P36`;`2045Yh@D0a/2l1@2][Jd2
0<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@03
0;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd70;jg[080@FWQ00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`<0@FWQ2033_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL2045Yh@D0al6h0`11JN440<O1
^080@FWQ1P37`KP2045Yh@030:f][@37`KX0al6j00<0al6j00<0@FWQ0<O1^P37`KX01037`KX2045Y
h@D0al6j0P11JN401@37`KX0[Jf]0<S1^`38`K/0@FWQ00D0b<6k0P11JN4<0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_004045Yh@030<K0_02][Jd0
[Jf]0080[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]
0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@<0_[N/00<0@FWQ
0;jg[02][Jd05031^[000`2][Jd0`kfc0<>m/`080<>m/`<0@FWQ2033_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36_kL01`36_kL2045Yh@D0al6h0P11JN40
0`37`KP0@FWQ0<O1^0020<O1^080@FWQ1`37`KP00`11JN40[Jf]0<O1^P030<O1^P03045Yh@37`KX0
al6j00D0al6j0P11JN450<O1^P80@FWQ00<0al6j0:f][@11JN401@11JN420<S1^`80@FWQ2P38`K/0
0`11JN40b<6k0:f][@0E0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2]
[JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33_K<0`kfc00P0`kfc0`11JN48
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02`36_kL00`11JN40a[ng0<Jo]`07
0<Jo]`80@FWQ0P37`KP5045Yh@80al6h1011JN490<O1^0D0@FWQ1P37`KX7045Yh@D0al6j00<0[Jf]
0<S1^`38`K/01`38`K/2045Yh@T0b<6k00<0@FWQ0<S1^`2][Jd05@38`K/00`2][Jd0al6l0<O1_00@
0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC
0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
00l0_[N/1@2][JdA0<6j/0030:f][@33_K<0`kfc00P0`kfc0`11JN480<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL02`36_kL00`11JN40a[ng0<Jo]`060<Jo]`80@FWQ5`37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00L0b<6k0P11JN480<S1^`80@FWQ00<0b<6k0:f]
[@38`K/05038`K/00`2][Jd0al6l0<O1_00;0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0
/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0
`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]0<>m/`33_K<02033_K<3045Yh@P0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0;0<Jo]`03045Yh@36_kL0a[ng00H0a[ng0P11JN4G0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/01`38`K/2045Yh@P0b<6k0P11JN400`38
`K/0[Jf]0<S1^`0D0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?oo
o`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc00P0`kfc0P11JN490<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02`36_kL00`11JN40a[ng0<Jo]`060<Jo]`80
@FWQ5`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00P0b<6k0P11JN470<S1^`80
@FWQ00<0b<6k0:f][@38`K/05038`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40
oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[003`31^[070:f][@P0`kfc00<0@FWQ0<>m/`33_K<01`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36_kL01P36_kL00`11JN40[Jf]
0<O1^00F0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02038`K/2045Yh@H0b<6k
0`11JN400`38`K/0[Jf]0<S1^`0A0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2]
[Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36_kL01P36_kL00`11JN40[Jf]0<O1^00F0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@@0b<6k0P11JN401038`K/0@FWQ
0<S1^`2][Jd;0<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V
0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng00/0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40a[ng0:f][@0G0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02`38`K/4045Yh@<0b<6k00<0@FWQ0<S1^`2][Jd0
0`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0
[Jf]0<Jo]`36_kL02`36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ00<0a[ng0:f][@37`KP05P37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`
h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]
0<Jo]`36_kL02036_kL:045Yh@<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][JeY
0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2]
[Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?oo
o`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0
[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2]
[Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00l0al6j00<000000<O1^P37`KX00P37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80
/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
3`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/7
0:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1
^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0
/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54488 .33069 m
.54322 .33393 L
s
.54656 .33386 m
.54488 .33069 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5449 .33711 m
.54656 .33386 L
s
.54322 .33393 m
.5449 .33711 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57655 .34087 m
.57656 .3425 L
s
.255 .412 .882 r
.53061 .33859 m
.53392 .34082 L
s
.51405 .33859 m
.53061 .33859 L
s
.53061 .33859 m
.53557 .3408 L
s
0 0 0 r
.57619 .34111 m
.57656 .3425 L
s
.255 .412 .882 r
.53392 .34082 m
.53724 .34529 L
s
.53557 .3408 m
.53889 .34527 L
s
.5488 .33832 m
.56035 .338 L
s
0 0 0 r
.56144 .35097 m
.56332 .35271 L
s
.255 .412 .882 r
.53724 .34529 m
.5389 .34978 L
s
0 0 0 r
.58811 .33868 m
.59135 .33205 L
s
.59135 .33205 m
.59625 .32852 L
s
.255 .412 .882 r
.53889 .34527 m
.54056 .34976 L
s
0 0 0 r
.59952 .3283 m
.59625 .32852 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5389 .34978 m
.54057 .35654 L
s
.54056 .34976 m
.54223 .35651 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52066 .38618 m
.52067 .33862 L
s
.51899 .38618 m
.51901 .33861 L
s
0 0 0 r
.54336 .39211 m
.54351 .38861 L
s
.54657 .3886 m
.54673 .39205 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55375 .3382 m
.55387 .36987 L
s
.5554 .33815 m
.55553 .36982 L
s
.54057 .35654 m
.5406 .36787 L
s
.54223 .35651 m
.54226 .36784 L
s
.58335 .33926 m
.58823 .33673 L
s
.58174 .34387 m
.58335 .33926 L
s
.58498 .33918 m
.58823 .33673 L
s
.58823 .33673 m
.59311 .33644 L
s
.58338 .34378 m
.58498 .33918 L
s
.55548 .35622 m
.55716 .36297 L
s
0 0 0 r
.54504 .3886 m
.54505 .39208 L
s
.255 .412 .882 r
.58174 .34387 m
.58178 .34839 L
s
.58338 .34378 m
.58341 .34831 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59311 .33644 m
.59638 .33849 L
s
0 0 0 r
.58994 .36147 m
.58997 .36444 L
s
.255 .412 .882 r
.58178 .34839 m
.58345 .35284 L
s
.58341 .34831 m
.58508 .35275 L
s
.53895 .3747 m
.5406 .36787 L
s
.55716 .36297 m
.56049 .3674 L
s
.54061 .37468 m
.54226 .36784 L
s
.59638 .33849 m
.59967 .3428 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57509 .37167 m
.57529 .37126 L
s
.56949 .37514 m
.57178 .37506 L
s
.58858 .36238 m
.59 .36769 L
s
.255 .412 .882 r
.5489 .36998 m
.55553 .36982 L
s
.60125 .33816 m
.60446 .33567 L
s
.59967 .3428 m
.60125 .33816 L
s
.58345 .35284 m
.58837 .35484 L
s
0 0 0 r
.57178 .37506 m
.57509 .37167 L
s
.255 .412 .882 r
.60446 .33567 m
.60608 .33555 L
s
.60287 .33805 m
.60446 .33567 L
s
.56708 .36491 m
.56872 .36258 L
s
.56872 .36258 m
.57038 .36478 L
s
.58508 .35275 m
.58837 .35484 L
s
.60129 .34269 m
.60287 .33805 L
s
.56049 .3674 m
.5638 .36957 L
s
.5373 .37927 m
.53895 .3747 L
s
.56708 .36491 m
.56874 .36712 L
s
.53896 .37925 m
.54061 .37468 L
s
.57038 .36478 m
.57039 .36705 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5638 .36957 m
.56876 .36939 L
s
.56876 .36939 m
.57039 .36705 L
s
.53398 .38385 m
.5373 .37927 L
s
.53564 .38384 m
.53896 .37925 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59967 .3428 m
.59986 .36322 L
s
.60129 .34269 m
.60144 .35857 L
s
.58837 .35484 m
.59817 .35651 L
s
.58351 .36191 m
.58353 .36418 L
s
.58351 .36191 m
.58515 .36182 L
s
.58515 .36182 m
.58517 .36409 L
s
.53065 .38616 m
.53398 .38385 L
s
.53065 .38616 m
.53564 .38384 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58353 .36418 m
.58519 .36637 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.514 .38615 m
.53065 .38616 L
s
.58519 .36637 m
.58848 .36847 L
s
.59817 .35651 m
.59982 .35868 L
s
.42415 .3343 m
.42572 .33671 L
s
.42252 .33643 m
.42415 .3343 L
s
.42409 .33884 m
.42572 .33671 L
s
.58848 .36847 m
.59502 .36809 L
s
.59986 .36322 m
.60144 .35857 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42252 .33643 m
.42409 .33884 L
s
.59826 .3656 m
.59986 .36322 L
s
.59502 .36809 m
.59826 .3656 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42395 .35019 m
.42523 .37771 L
s
.42202 .37744 m
.42395 .35019 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4067 .33259 m
.40982 .33519 L
s
.40982 .33519 m
.41137 .33763 L
s
.41128 .34445 m
.41137 .33763 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60964 .3671 m
.62092 .3662 L
s
.62732 .36564 m
.63325 .33316 L
s
.63325 .33316 m
.64002 .36442 L
s
.61609 .3666 m
.62061 .34117 L
s
.61448 .36673 m
.62053 .33437 L
s
.62053 .33437 m
.62732 .36564 L
s
.62891 .3655 m
.63334 .33997 L
s
.40043 .3319 m
.4067 .33259 L
s
.4097 .34429 m
.41131 .34217 L
s
.40966 .34656 m
.41128 .34445 L
s
.40651 .34624 m
.4097 .34429 L
s
.39727 .33381 m
.40043 .3319 L
s
.42362 .37757 m
.42379 .36386 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40648 .34852 m
.40966 .34656 L
s
.39859 .34995 m
.40651 .34624 L
s
.39567 .33591 m
.39727 .33381 L
s
.39855 .35223 m
.40648 .34852 L
s
.40947 .36025 m
.41112 .35584 L
s
.411 .36498 m
.41112 .35584 L
s
.39419 .33117 m
.39567 .33591 L
s
.39405 .34028 m
.39419 .33117 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39405 .34028 m
.39567 .33591 L
s
.42357 .38216 m
.42523 .37771 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40786 .36238 m
.40947 .36025 L
s
.40947 .36025 m
.411 .36498 L
s
.42202 .37744 m
.42357 .38216 L
s
.63527 .36489 m
.64474 .36392 L
s
.40467 .36434 m
.40786 .36238 L
s
.65372 .33771 m
.65674 .33277 L
s
.65224 .34246 m
.65372 .33771 L
s
.65674 .33277 m
.66133 .32989 L
s
.39543 .35188 m
.39859 .34995 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65079 .34949 m
.65224 .34246 L
s
.65527 .33752 m
.65829 .33257 L
s
.6538 .34227 m
.65527 .33752 L
s
.65829 .33257 m
.66133 .32989 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39539 .35416 m
.39855 .35223 L
s
.65235 .34931 m
.6538 .34227 L
s
.66133 .32989 m
.66439 .32948 L
s
.39838 .36367 m
.40467 .36434 L
s
.65079 .34949 m
.65097 .36093 L
s
.39383 .35398 m
.39543 .35188 L
s
.65235 .34931 m
.65253 .36075 L
s
.66439 .32948 m
.66901 .33114 L
s
.39379 .35627 m
.39539 .35416 L
s
.39376 .35856 m
.39383 .35398 L
s
.38027 .33167 m
.38326 .33665 L
s
.37574 .32876 m
.38027 .33167 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39528 .36103 m
.39838 .36367 L
s
.39376 .35856 m
.39528 .36103 L
s
.37271 .32832 m
.37574 .32876 L
s
.66901 .33114 m
.67214 .33528 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65253 .36075 m
.6542 .36745 L
s
.65097 .36093 m
.65264 .36763 L
s
.67201 .32842 m
.67235 .34673 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36964 .33017 m
.37271 .32832 L
s
.36813 .32994 m
.37271 .32832 L
s
.67352 .3282 m
.67386 .34652 L
s
.65264 .36763 m
.65428 .37205 L
s
.38295 .35495 m
.38299 .35266 L
s
.38149 .35017 m
.38299 .35266 L
s
.37991 .35226 m
.38149 .35017 L
s
.6542 .36745 m
.65583 .37187 L
s
.37979 .35915 m
.38295 .35495 L
s
.36654 .33429 m
.36964 .33017 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66778 .34736 m
.6784 .34586 L
s
.37991 .35226 m
.38141 .35476 L
s
.65428 .37205 m
.65746 .37629 L
s
.36504 .33407 m
.36813 .32994 L
s
.65583 .37187 m
.65901 .37611 L
s
.37669 .36104 m
.37979 .35915 L
s
.36491 .34095 m
.36654 .33429 L
s
.68254 .32684 m
.69291 .32514 L
s
.36341 .34072 m
.36504 .33407 L
s
.37211 .36042 m
.37669 .36104 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65901 .37611 m
.66215 .37804 L
s
.65746 .37629 m
.66215 .37804 L
s
.36482 .34554 m
.36491 .34095 L
s
.34744 .32427 m
.35772 .32602 L
s
.66215 .37804 m
.66523 .37765 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36332 .34531 m
.36341 .34072 L
s
.36482 .34554 m
.36619 .35266 L
s
.36912 .3577 m
.37211 .36042 L
s
.36761 .35748 m
.37211 .36042 L
s
.66523 .37765 m
.6698 .37476 L
s
.36332 .34531 m
.36468 .35244 L
s
.36619 .35266 m
.36912 .3577 L
s
.67416 .36261 m
.67442 .37646 L
s
.67277 .36973 m
.67416 .36261 L
s
.35262 .35751 m
.35329 .32528 L
s
.36468 .35244 m
.36761 .35748 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68701 .32612 m
.68766 .35832 L
s
.68849 .32588 m
.68915 .35809 L
s
.6698 .37476 m
.67277 .36973 L
s
.35114 .35727 m
.35182 .32503 L
s
.67277 .36973 m
.67442 .37646 L
s
.68886 .34425 m
.69049 .35093 L
s
.68318 .359 m
.68915 .35809 L
s
.69049 .35093 m
.69354 .35507 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33164 .32129 m
.34164 .32322 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69354 .35507 m
.69653 .3569 L
s
.34674 .35654 m
.35262 .35751 L
s
.33675 .34781 m
.33733 .32241 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33531 .34755 m
.3359 .32213 L
s
.69653 .3569 m
.70092 .35616 L
s
.69936 .35178 m
.70087 .35384 L
s
.69936 .35178 m
.70077 .34922 L
s
.70077 .34922 m
.70227 .35128 L
s
.3508 .37349 m
.35233 .37141 L
s
.3509 .36885 m
.35233 .37141 L
s
.34938 .37094 m
.3509 .36885 L
s
.70227 .35128 m
.70233 .35359 L
s
.71317 .32373 m
.71735 .32057 L
s
.71186 .32862 m
.71317 .32373 L
s
.70092 .35616 m
.70233 .35359 L
s
.71186 .32862 m
.71197 .33324 L
s
.34938 .37094 m
.3508 .37349 L
s
.71459 .32344 m
.71735 .32057 L
s
.71328 .32834 m
.71459 .32344 L
s
.71328 .32834 m
.71339 .33296 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71197 .33324 m
.7135 .33759 L
s
.71735 .32057 m
.72155 .31969 L
s
.71339 .33296 m
.71492 .33731 L
s
.33521 .35218 m
.33675 .34781 L
s
.31633 .31806 m
.32601 .32015 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7135 .33759 m
.7178 .33907 L
s
.33378 .35192 m
.33531 .34755 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71492 .33731 m
.7178 .33907 L
s
.72155 .31969 m
.72438 .32141 L
s
.33088 .3537 m
.33521 .35218 L
s
.33088 .3537 m
.33378 .35192 L
s
.71372 .34686 m
.71377 .34918 L
s
.71372 .34686 m
.71514 .34658 L
s
.71377 .34918 m
.71525 .35123 L
s
.7178 .33907 m
.72622 .33967 L
s
.71514 .34658 m
.71519 .34891 L
s
.72438 .32141 m
.72725 .32545 L
s
.71525 .35123 m
.71813 .35301 L
s
.32804 .35316 m
.33088 .3537 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32388 .35 m
.32804 .35316 L
s
.72851 .32051 m
.73118 .31758 L
s
.72725 .32545 m
.72851 .32051 L
s
.72725 .32545 m
.72778 .34636 L
s
.71813 .35301 m
.72374 .35189 L
s
.72988 .3202 m
.73118 .31758 L
s
.72863 .32514 m
.72988 .3202 L
s
.32121 .34478 m
.32388 .35 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72863 .32514 m
.72904 .34141 L
s
.73118 .31758 m
.73254 .31727 L
s
.73482 .30043 m
.74411 .29811 L
s
.72622 .33967 m
.72766 .34171 L
s
.72374 .35189 m
.72646 .34899 L
s
.72646 .34899 m
.72778 .34636 L
s
.72778 .34636 m
.72904 .34141 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31924 .36783 m
.32045 .31897 L
s
.32063 .36811 m
.32184 .31926 L
s
.30414 .31754 m
.30668 .32283 L
s
.30668 .32283 m
.30784 .33013 L
s
.31509 .36698 m
.32063 .36811 L
s
.30025 .31422 m
.30414 .31754 L
s
.30771 .33479 m
.30784 .33013 L
s
.30282 .31721 m
.30535 .32251 L
s
.30535 .32251 m
.3065 .32982 L
s
.74078 .32233 m
.7433 .31703 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74016 .29912 m
.74147 .34802 L
s
.73883 .29945 m
.74013 .34833 L
s
.30025 .31422 m
.30282 .31721 L
s
.30637 .33448 m
.3065 .32982 L
s
.30619 .34149 m
.30771 .33479 L
s
.28785 .29446 m
.29679 .29694 L
s
.7433 .31703 m
.74587 .31404 L
s
.30485 .34118 m
.30637 .33448 L
s
.29763 .31356 m
.30025 .31422 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74587 .31404 m
.74848 .31337 L
s
.7361 .34925 m
.74147 .34802 L
s
.30339 .34554 m
.30619 .34149 L
s
.29153 .345 m
.29293 .29589 L
s
.29497 .31521 m
.29763 .31356 L
s
.74848 .31337 m
.75113 .31502 L
s
.74848 .31337 m
.75242 .31468 L
s
.30206 .34523 m
.30485 .34118 L
s
0 0 0 r
.76474 .30121 m
.76548 .301 L
s
.255 .412 .882 r
.29025 .34467 m
.29165 .29553 L
s
.74128 .341 m
.74407 .34505 L
s
0 0 0 r
.2843 .30563 m
.28471 .3054 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29227 .3192 m
.29497 .31521 L
s
.29935 .34694 m
.30339 .34554 L
s
.75113 .31502 m
.75383 .31901 L
s
.29935 .34694 m
.30206 .34523 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75242 .31468 m
.75511 .31867 L
s
.74407 .34505 m
.74677 .34677 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29672 .3463 m
.29935 .34694 L
s
.75383 .31901 m
.75531 .32569 L
s
.74677 .34677 m
.74939 .34612 L
s
.75511 .31867 m
.75659 .32535 L
s
.29418 .34331 m
.29672 .3463 L
s
.74939 .34612 m
.75192 .34312 L
s
.74939 .34612 m
.75322 .34279 L
s
.75531 .32569 m
.75545 .33038 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29173 .33795 m
.29418 .34331 L
s
.75659 .32535 m
.75672 .33004 L
s
.75192 .34312 m
.75437 .33776 L
s
.28362 .30973 m
.28487 .31009 L
s
.75437 .33776 m
.75545 .33038 L
s
.75322 .34279 m
.75565 .33743 L
s
.28107 .31135 m
.28362 .30973 L
s
.28231 .31171 m
.28362 .30973 L
s
.75565 .33743 m
.75672 .33004 L
s
.28642 .34367 m
.29153 .345 L
s
.28093 .31604 m
.28231 .31171 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2797 .31568 m
.28107 .31135 L
s
.28044 .33251 m
.28093 .31604 L
s
.27739 .31025 m
.2797 .31568 L
s
.27906 .33688 m
.2797 .31568 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7637 .30917 m
.77222 .30658 L
s
.27504 .30716 m
.27739 .31025 L
s
.27144 .30603 m
.27504 .30716 L
s
.27906 .33688 m
.28044 .33251 L
s
.27804 .32944 m
.2792 .33216 L
s
.27085 .3249 m
.27804 .32944 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27776 .33889 m
.27906 .33688 L
s
.269 .30763 m
.27144 .30603 L
s
.26782 .30724 m
.27144 .30603 L
s
.27524 .34055 m
.27776 .33889 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76739 .30807 m
.76888 .35765 L
s
.7686 .3077 m
.77011 .35731 L
s
.76939 .33361 m
.77196 .33762 L
s
.26767 .31196 m
.269 .30763 L
s
.77697 .30506 m
.78505 .30231 L
s
.76517 .35868 m
.77011 .35731 L
s
.27041 .33911 m
.27524 .34055 L
s
.2665 .31158 m
.26782 .30724 L
s
.26855 .32179 m
.27085 .3249 L
s
.26738 .32141 m
.27085 .3249 L
s
.77196 .33762 m
.77564 .33891 L
s
.26752 .31669 m
.26767 .31196 L
s
.78047 .30389 m
.7813 .32993 L
s
.26635 .3163 m
.2665 .31158 L
s
.26752 .31669 m
.26855 .32179 L
s
.78162 .3035 m
.78246 .32955 L
s
.26635 .3163 m
.26738 .32141 L
s
.26811 .33601 m
.27041 .33911 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26708 .33089 m
.26826 .33126 L
s
.26818 .33363 m
.26826 .33126 L
s
.77564 .33891 m
.77801 .33818 L
s
.267 .33326 m
.26708 .33089 L
s
.267 .33326 m
.26811 .33601 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77801 .33818 m
.78028 .33506 L
s
.77801 .33818 m
.78145 .33468 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78028 .33506 m
.7813 .32993 L
s
.78145 .33468 m
.78246 .32955 L
s
.78954 .30071 m
.79714 .29781 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79283 .29948 m
.79395 .33284 L
s
.24462 .29636 m
.25207 .29929 L
s
.25673 .32746 m
.25778 .33023 L
s
.2577 .33262 m
.25778 .33023 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25553 .32946 m
.25673 .32746 L
s
.25649 .33462 m
.2577 .33262 L
s
.79392 .29906 m
.79504 .33245 L
s
.25553 .32946 m
.25657 .33223 L
s
.25315 .33345 m
.25649 .33462 L
s
.79064 .33401 m
.79504 .33245 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24771 .33147 m
.24884 .29805 L
s
.24664 .33107 m
.24777 .29763 L
s
.25103 .33027 m
.25315 .33345 L
s
.24902 .32469 m
.25103 .33027 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24819 .31711 m
.24902 .32469 L
s
.79333 .34761 m
.79435 .34482 L
s
.79333 .34761 m
.79451 .34962 L
s
.79435 .34482 m
.79552 .34684 L
s
.24347 .32986 m
.24771 .33147 L
s
.79451 .34962 m
.79552 .34684 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80263 .30285 m
.80452 .29722 L
s
.80184 .31045 m
.80263 .30285 L
s
.80184 .31045 m
.80201 .31524 L
s
.80366 .30243 m
.80553 .29679 L
s
.80288 .31003 m
.80366 .30243 L
s
.80452 .29722 m
.80746 .29353 L
s
.80288 .31003 m
.80304 .31482 L
s
.80553 .29679 m
.80746 .29353 L
s
.23781 .31294 m
.23849 .29377 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80304 .31482 m
.80433 .3216 L
s
.80201 .31524 m
.80329 .32201 L
s
.80746 .29353 m
.80944 .29265 L
s
.23385 .31122 m
.24086 .31421 L
s
.80329 .32201 m
.80552 .32599 L
s
.23681 .31251 m
.23749 .29333 L
s
.80433 .3216 m
.80654 .32557 L
s
.23543 .29485 m
.23724 .30051 L
s
.80944 .29265 m
.81244 .29371 L
s
.23261 .29112 m
.23543 .29485 L
s
.80552 .32599 m
.80864 .32715 L
s
.80654 .32557 m
.80864 .32715 L
s
.2307 .29022 m
.23261 .29112 L
s
.81244 .29371 m
.81453 .29763 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23671 .34429 m
.23722 .32979 L
s
.23596 .33662 m
.23722 .32979 L
s
.80864 .32715 m
.81162 .32588 L
s
.22874 .29172 m
.2307 .29022 L
s
.22781 .29126 m
.2307 .29022 L
s
0 0 0 r
.82575 .27732 m
.82693 .27671 L
s
.255 .412 .882 r
.2338 .34063 m
.23596 .33662 L
s
.23596 .33662 m
.23671 .34429 L
s
.81162 .32588 m
.81348 .32261 L
s
.81322 .31537 m
.81409 .31252 L
s
.81322 .31537 m
.81427 .31735 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22074 .27793 m
.22248 .28117 L
s
.255 .412 .882 r
.22671 .29563 m
.22874 .29172 L
s
0 0 0 r
.22243 .28231 m
.22244 .28236 L
s
.255 .412 .882 r
.81409 .31252 m
.81514 .3145 L
s
0 0 0 r
.22074 .27793 m
.22243 .28231 L
s
.255 .412 .882 r
.2258 .29517 m
.22781 .29126 L
s
.81348 .32261 m
.81522 .31692 L
s
.81514 .3145 m
.81522 .31692 L
s
.23079 .34181 m
.2338 .34063 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22562 .3 m
.22671 .29563 L
s
.22471 .29955 m
.2258 .29517 L
s
.82073 .28722 m
.8218 .29159 L
s
.82073 .28722 m
.82108 .29688 L
s
.22445 .30681 m
.22562 .3 L
s
.22887 .34097 m
.23079 .34181 L
s
.22355 .30635 m
.22471 .29955 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82108 .29688 m
.8218 .29159 L
s
.8218 .29159 m
.8226 .28871 L
s
.8226 .28871 m
.82426 .28536 L
s
.224 .31893 m
.22445 .30681 L
s
.22707 .33769 m
.22887 .34097 L
s
.22613 .33726 m
.22887 .34097 L
s
.2231 .31849 m
.22355 .30635 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82162 .3114 m
.82243 .30853 L
s
.82162 .3114 m
.8218 .31626 L
s
.22538 .33196 m
.22707 .33769 L
s
.82171 .31383 m
.82252 .31095 L
s
.82243 .30853 m
.82411 .30519 L
s
.224 .31893 m
.22464 .32666 L
s
.8218 .31626 m
.82279 .31824 L
s
.82252 .31095 m
.8242 .30762 L
s
.22446 .33153 m
.22613 .33726 L
s
.22464 .32666 m
.22538 .33196 L
s
.2231 .31849 m
.22373 .32623 L
s
.22373 .32623 m
.22446 .33153 L
s
.82279 .31824 m
.82465 .31978 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82411 .30519 m
.82822 .29803 L
s
.8242 .30762 m
.82831 .30046 L
s
.82426 .28536 m
.82767 .28347 L
s
.82767 .28347 m
.82942 .28494 L
s
.82465 .31978 m
.82811 .31798 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82942 .28494 m
.83033 .28689 L
s
.82822 .29803 m
.82979 .29466 L
s
.2144 .31641 m
.21947 .31913 L
s
.82831 .30046 m
.82988 .29709 L
s
.21488 .28182 m
.2169 .31778 L
s
.21038 .3141 m
.21488 .28182 L
s
.83033 .28689 m
.83061 .29419 L
s
.82979 .29466 m
.83052 .29175 L
s
.82988 .29709 m
.83061 .29419 L
s
.21117 .31456 m
.2146 .28911 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82811 .31798 m
.8297 .31463 L
s
.8297 .31463 m
.83044 .31172 L
s
.83044 .31172 m
.83107 .30638 L
s
.83044 .31172 m
.83144 .31615 L
s
.83107 .30638 m
.83144 .31615 L
s
.83574 .28107 m
.8364 .27814 L
s
.83574 .28107 m
.83659 .28302 L
s
.8364 .27814 m
.83724 .28009 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20865 .27792 m
.21038 .3141 L
s
.20438 .31032 m
.20865 .27792 L
s
.83659 .28302 m
.83724 .28009 L
s
.2051 .3108 m
.20837 .28525 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83707 .29525 m
.83897 .32428 L
s
.83707 .29525 m
.83746 .32521 L
s
.83764 .30997 m
.83822 .32475 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20226 .30888 m
.20732 .31222 L
s
.83746 .32521 m
.83841 .32968 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83841 .32968 m
.83897 .32428 L
s
.2016 .27291 m
.20227 .27342 L
s
.20019 .27435 m
.2016 .27291 L
s
.20084 .27486 m
.2016 .27291 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19999 .27927 m
.20084 .27486 L
s
.19935 .27876 m
.20019 .27435 L
s
.1993 .29655 m
.19999 .27927 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19829 .27281 m
.19935 .27876 L
s
.19846 .301 m
.19935 .27876 L
s
.19716 .26932 m
.19829 .27281 L
s
.19846 .301 m
.1993 .29655 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19539 .26776 m
.19716 .26932 L
s
.19812 .29308 m
.19866 .29605 L
s
.19459 .28757 m
.19812 .29308 L
s
.19772 .30299 m
.19846 .301 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19637 .30448 m
.19772 .30299 L
s
.19415 .26919 m
.19539 .26776 L
s
.1936 .26866 m
.19539 .26776 L
s
.19398 .3025 m
.19637 .30448 L
s
.1934 .27362 m
.19415 .26919 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19285 .2731 m
.1936 .26866 L
s
.19355 .28407 m
.19459 .28757 L
s
.19299 .28355 m
.19459 .28757 L
s
.19319 .27858 m
.1934 .27362 L
s
.19319 .27858 m
.19355 .28407 L
s
.19265 .27807 m
.19285 .2731 L
s
.19265 .27807 m
.19299 .28355 L
s
.19294 .299 m
.19398 .3025 L
s
.19258 .29351 m
.19314 .29402 L
s
.19304 .29651 m
.19314 .29402 L
s
.19248 .296 m
.19294 .299 L
s
.19248 .296 m
.19258 .29351 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85672 .2609 m
.86084 .25547 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85805 .25928 m
.86025 .31205 L
s
.18797 .28889 m
.18835 .29192 L
s
.18824 .29442 m
.18835 .29192 L
s
.18766 .29642 m
.18824 .29442 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1874 .29088 m
.18797 .28889 L
s
.85848 .25874 m
.86068 .31155 L
s
.18417 .25489 m
.18689 .25871 L
s
.1874 .29088 m
.18777 .29391 L
s
.18629 .29488 m
.18766 .29642 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18419 .29228 m
.18566 .25708 L
s
.18553 .29132 m
.18629 .29488 L
s
.1838 .29176 m
.18528 .25654 L
s
.8589 .31356 m
.86307 .30849 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18491 .28524 m
.18553 .29132 L
s
.86084 .25547 m
.86166 .25688 L
s
.86084 .25547 m
.862 .25633 L
s
.18482 .27716 m
.18491 .28524 L
s
.86166 .25688 m
.86255 .26082 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18268 .29019 m
.18419 .29228 L
s
.862 .25633 m
.86287 .26027 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86255 .26082 m
.86308 .26532 L
s
.86287 .26027 m
.8634 .26477 L
s
.86308 .26532 m
.86372 .27236 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8634 .26477 m
.86402 .27182 L
s
.18189 .25915 m
.18198 .26475 L
s
.18197 .27287 m
.18198 .26475 L
s
.18153 .253 m
.18189 .25915 L
s
.18143 .28554 m
.18197 .27287 L
s
.86307 .30849 m
.86368 .30492 L
s
.86307 .30849 m
.86403 .3044 L
s
.1816 .2586 m
.18168 .2642 L
s
.18166 .27233 m
.18168 .2642 L
s
.18126 .25244 m
.1816 .2586 L
s
.86372 .27236 m
.86425 .28503 L
s
.18112 .28501 m
.18166 .27233 L
s
.18085 .2488 m
.18153 .253 L
s
.86402 .27182 m
.86456 .2845 L
s
.18085 .2488 m
.18126 .25244 L
s
.86368 .30492 m
.86415 .29879 L
s
.1808 .29263 m
.18143 .28554 L
s
.86427 .24938 m
.86583 .24546 L
s
.86403 .3044 m
.86447 .29827 L
s
.86425 .28503 m
.86426 .29318 L
s
.18049 .29211 m
.18112 .28501 L
s
.86415 .29879 m
.86426 .29318 L
s
.17888 .24317 m
.18085 .2488 L
s
.86456 .2845 m
.86457 .29266 L
s
.86447 .29827 m
.86457 .29266 L
s
.18028 .2972 m
.1808 .29263 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17998 .29668 m
.18049 .29211 L
s
.865 .24771 m
.86652 .28331 L
s
.17948 .30126 m
.18028 .2972 L
s
.86522 .24714 m
.86674 .28277 L
s
.17921 .30074 m
.17998 .29668 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86578 .28491 m
.86674 .28277 L
s
.17858 .30225 m
.17948 .30126 L
s
.86609 .26746 m
.86663 .27457 L
s
.17858 .30225 m
.17921 .30074 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86663 .27457 m
.86725 .2786 L
s
.17658 .29699 m
.17858 .30225 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17707 .29857 m
.17937 .24487 L
s
.17725 .2991 m
.17955 .24543 L
s
.86725 .2786 m
.86771 .28008 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86771 .28008 m
.86818 .27845 L
s
.86781 .27386 m
.86807 .27588 L
s
.86781 .27386 m
.86785 .27075 L
s
.86785 .27075 m
.86809 .27277 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86818 .27845 m
.8682 .27534 L
s
.86809 .27277 m
.8682 .27534 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86756 .24007 m
.86773 .24577 L
s
.86773 .24577 m
.86795 .2509 L
s
.86753 .23578 m
.86756 .24007 L
s
.86795 .2509 m
.86822 .25548 L
s
.86759 .2395 m
.86778 .2452 L
s
.86778 .2452 m
.868 .25034 L
s
.86753 .23578 m
.86759 .2395 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.868 .25034 m
.86826 .25492 L
s
.86822 .25548 m
.86841 .25638 L
s
.86751 .23406 m
.86753 .23578 L
s
.86826 .25492 m
.86841 .25638 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86866 .26579 m
.8687 .26524 L
s
.86866 .26579 m
.86877 .26837 L
s
.86877 .26837 m
.86892 .27041 L
s
.8687 .26524 m
.86881 .26782 L
s
.86751 .23406 m
.86756 .23549 L
s
.8684 .25561 m
.86841 .25638 L
s
.86892 .27041 m
.86908 .2719 L
s
.86756 .23549 m
.86767 .23951 L
s
.86904 .2697 m
.86908 .2719 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86738 .23377 m
.86767 .23951 L
s
.86767 .23951 m
.86868 .26284 L
s
.8671 .23003 m
.86738 .23377 L
s
.8673 .23319 m
.86761 .23894 L
s
.86761 .23894 m
.86839 .25709 L
s
.8671 .23003 m
.8673 .23319 L
s
.8684 .25561 m
.86845 .25764 L
s
.867 .22945 m
.8671 .23003 L
s
.86885 .266 m
.86904 .2697 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86868 .26284 m
.86885 .266 L
s
.86839 .25709 m
.86868 .26284 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86642 .23822 m
.86789 .26307 L
s
.86625 .23751 m
.86773 .26252 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86814 .21064 m
.86856 .21496 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86803 .21378 m
.86814 .21064 L
s
.86846 .2181 m
.86856 .21496 L
s
.86803 .21378 m
.86846 .2181 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86927 .2368 m
.87148 .28258 L
s
.87024 .25935 m
.87122 .28204 L
s
.86544 .20905 m
.86597 .21339 L
s
.86597 .21339 m
.86645 .22466 L
s
.86452 .20412 m
.86544 .20905 L
s
.86609 .22408 m
.86629 .2209 L
s
.86287 .20175 m
.86452 .20412 L
s
.86625 .22785 m
.86645 .22466 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87148 .28258 m
.87155 .28962 L
s
.86927 .2368 m
.87095 .28149 L
s
.86549 .22669 m
.86609 .22408 L
s
.86565 .23047 m
.86625 .22785 L
s
.87095 .28149 m
.87155 .28962 L
s
.86722 .25052 m
.86726 .24352 L
s
.86726 .24352 m
.86791 .25866 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86371 .23139 m
.86549 .22669 L
s
.86213 .20434 m
.86287 .20175 L
s
.86387 .23519 m
.86565 .23047 L
s
.86701 .25375 m
.86722 .25052 L
s
.86722 .25052 m
.86791 .25866 L
s
.255 .412 .882 r
.1866 .21545 m
.18681 .21678 L
s
.18667 .21357 m
.18703 .2115 L
s
.18703 .2115 m
.18738 .21356 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86183 .20753 m
.86213 .20434 L
s
.86639 .25644 m
.86701 .25375 L
s
.255 .412 .882 r
.18681 .21678 m
.18738 .21356 L
s
.85648 .20922 m
.85694 .21054 L
s
0 0 0 r
.86103 .19939 m
.86183 .20753 L
s
.86103 .19939 m
.86167 .21451 L
s
.86167 .21451 m
.86183 .20753 L
s
.255 .412 .882 r
.85648 .20922 m
.85696 .21091 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1851 .251 m
.18612 .23258 L
s
0 0 0 r
.86468 .25421 m
.86639 .25644 L
s
.86295 .23405 m
.86371 .23139 L
s
.255 .412 .882 r
.85546 .20807 m
.85648 .20922 L
s
0 0 0 r
.86311 .23785 m
.86387 .23519 L
s
.255 .412 .882 r
.18492 .262 m
.18559 .24598 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86263 .23729 m
.86295 .23405 L
s
.85622 .1941 m
.85847 .19645 L
s
.8628 .2411 m
.86311 .23785 L
s
.8636 .24929 m
.86468 .25421 L
s
.86263 .23729 m
.86296 .24491 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18469 .26733 m
.18469 .26735 L
s
.18617 .23312 m
.18619 .23252 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86296 .24491 m
.8636 .24929 L
s
.255 .412 .882 r
.18469 .26735 m
.18469 .26732 L
s
0 0 0 r
.18979 .19349 m
.19359 .19 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85881 .26522 m
.85893 .26501 L
s
.85881 .26522 m
.85897 .2651 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85518 .19674 m
.85669 .2055 L
s
.85314 .19119 m
.85518 .19674 L
s
.255 .412 .882 r
.85779 .26415 m
.85881 .26522 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19101 .19232 m
.19232 .26927 L
s
.85183 .19003 m
.85314 .19119 L
s
.85063 .19268 m
.85183 .19003 L
s
.84993 .19211 m
.85183 .19003 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85622 .1941 m
.85845 .24758 L
s
.8568 .19469 m
.85904 .24813 L
s
.85663 .24593 m
.85904 .24813 L
s
.19133 .21407 m
.19761 .209 L
s
.85025 .19976 m
.85063 .19268 L
s
.84954 .19919 m
.84993 .19211 L
s
.85025 .19976 m
.85198 .24211 L
s
.84954 .19919 m
.85127 .24157 L
s
.1978 .18653 m
.20243 .1831 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1928 .2576 m
.20006 .18481 L
s
.20514 .15513 m
.21121 .15108 L
s
.19232 .26927 m
.20084 .18424 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20574 .19529 m
.20652 .19392 L
s
0 0 0 r
.83882 .18029 m
.84379 .18369 L
s
.84907 .23995 m
.85198 .24211 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20445 .23457 m
.20767 .15339 L
s
.20533 .23404 m
.20854 .15281 L
s
.20702 .19128 m
.2091 .18244 L
s
.2091 .18244 m
.21107 .17746 L
s
.84097 .23459 m
.84597 .23779 L
s
.21107 .17746 m
.21293 .17635 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83155 .17582 m
.84435 .23672 L
s
.82962 .17471 m
.83528 .17804 L
s
.2019 .23616 m
.20533 .23404 L
s
.21293 .17635 m
.2147 .17911 L
s
.21293 .17635 m
.21567 .17857 L
s
.20579 .22233 m
.20726 .22907 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2147 .17911 m
.21635 .18579 L
s
.21567 .17857 m
.21735 .18525 L
s
.20726 .22907 m
.20894 .23193 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83462 .23091 m
.84218 .18256 L
s
.83366 .23039 m
.84136 .18199 L
s
.21635 .18579 m
.2169 .19694 L
s
.83172 .22935 m
.83741 .23248 L
s
.21735 .18525 m
.21791 .19641 L
s
.20894 .23193 m
.21081 .23089 L
s
.2166 .20475 m
.2169 .19694 L
s
.21081 .23089 m
.21289 .22592 L
s
.21081 .23089 m
.21386 .2254 L
s
.21761 .20423 m
.21791 .19641 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21515 .21703 m
.2166 .20475 L
s
.82399 .18312 m
.82547 .19537 L
s
.82158 .17425 m
.82399 .18312 L
s
.21289 .22592 m
.21515 .21703 L
s
.81818 .16874 m
.82158 .17425 L
s
.21615 .21651 m
.21761 .20423 L
s
.82293 .18258 m
.82443 .19484 L
s
.8205 .17371 m
.82293 .18258 L
s
.82547 .19537 m
.82577 .2032 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21386 .2254 m
.21615 .21651 L
s
.81818 .16874 m
.8205 .17371 L
s
.82443 .19484 m
.82473 .20267 L
s
.81595 .16767 m
.81818 .16874 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82517 .21445 m
.82577 .2032 L
s
.82412 .21393 m
.82473 .20267 L
s
.81382 .17053 m
.81595 .16767 L
s
.81267 .17 m
.81595 .16767 L
s
.22683 .18043 m
.22935 .17156 L
s
.22529 .19271 m
.22683 .18043 L
s
.22935 .17156 m
.23291 .16606 L
s
.22794 .17991 m
.23048 .17103 L
s
.22639 .19219 m
.22794 .17991 L
s
.82334 .2213 m
.82517 .21445 L
s
.225 .20056 m
.22529 .19271 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23048 .17103 m
.23291 .16606 L
s
.82226 .22079 m
.82412 .21393 L
s
.2261 .20005 m
.22639 .19219 L
s
.81179 .17732 m
.81382 .17053 L
s
.23291 .16606 m
.23525 .16501 L
s
.225 .20056 m
.22566 .21186 L
s
.255 .412 .882 r
.80739 .17684 m
.80744 .17692 L
s
0 0 0 r
.81062 .17681 m
.81267 .17 L
s
.2261 .20005 m
.22677 .21135 L
s
.82022 .22373 m
.82334 .2213 L
s
.23525 .16501 m
.23749 .1679 L
s
.23525 .16501 m
.2387 .16738 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82022 .22373 m
.82226 .22079 L
s
.81104 .18861 m
.81179 .17732 L
s
.22566 .21186 m
.22761 .21875 L
s
.80986 .1881 m
.81062 .17681 L
s
.22677 .21135 m
.22874 .21825 L
s
.23749 .1679 m
.23964 .17473 L
s
.2387 .16738 m
.24087 .17423 L
s
.81798 .22273 m
.82022 .22373 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81104 .18861 m
.81133 .19649 L
s
.22761 .21875 m
.2309 .22121 L
s
.80986 .1881 m
.81014 .19599 L
s
.81555 .21777 m
.81798 .22273 L
s
.81439 .21727 m
.81798 .22273 L
s
.22874 .21825 m
.2309 .22121 L
s
.81133 .19649 m
.81294 .20885 L
s
.23964 .17473 m
.24045 .18606 L
s
.81294 .20885 m
.81555 .21777 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79785 .15991 m
.80292 .16194 L
s
.81014 .19599 m
.81176 .20836 L
s
.24087 .17423 m
.24169 .18556 L
s
.81176 .20836 m
.81439 .21727 L
s
.2309 .22121 m
.23326 .22023 L
s
.24017 .19397 m
.24045 .18606 L
s
.24142 .19348 m
.24169 .18556 L
s
.24889 .15938 m
.25825 .15593 L
s
.23326 .22023 m
.23579 .21528 L
s
.23326 .22023 m
.23701 .21479 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23852 .20635 m
.24017 .19397 L
s
.79539 .16285 m
.79826 .17174 L
s
.23975 .20586 m
.24142 .19348 L
s
.23579 .21528 m
.23852 .20635 L
s
.79261 .15791 m
.79539 .16285 L
s
.23701 .21479 m
.23975 .20586 L
s
.78993 .15693 m
.79261 .15791 L
s
.24999 .24164 m
.25284 .15789 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25134 .24119 m
.25417 .1574 L
s
.78734 .15991 m
.78993 .15693 L
s
.78596 .15943 m
.78993 .15693 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78483 .16688 m
.78734 .15991 L
s
.79702 .21049 m
.79936 .20346 L
s
.78343 .16641 m
.78596 .15943 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78382 .17834 m
.78483 .16688 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79785 .15991 m
.80074 .24348 L
s
.79913 .16041 m
.80204 .24394 L
s
.7945 .21355 m
.79702 .21049 L
s
.78241 .17787 m
.78343 .16641 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27364 .15328 m
.27369 .15166 L
s
.5 Mabswid
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26382 .15401 m
.27398 .15073 L
s
.26542 .23681 m
.26812 .15259 L
s
.7918 .21262 m
.7945 .21355 L
s
.78382 .17834 m
.78408 .18632 L
s
.79679 .24211 m
.80204 .24394 L
s
.78241 .17787 m
.78267 .18586 L
s
.78408 .18632 m
.78588 .19877 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76849 .14984 m
.77443 .15167 L
s
.78893 .2077 m
.7918 .21262 L
s
.78754 .20724 m
.7918 .21262 L
s
.78267 .18586 m
.78447 .19831 L
s
.24601 .243 m
.25134 .24119 L
s
.78588 .19877 m
.78893 .2077 L
s
.78447 .19831 m
.78754 .20724 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2725 .18955 m
.27255 .18792 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76558 .15292 m
.76886 .16179 L
s
.76084 .14759 m
.76558 .15292 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76999 .15029 m
.77173 .20638 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76849 .14984 m
.77022 .20595 L
s
.75771 .14672 m
.76084 .14759 L
s
.28271 .16 m
.28607 .15113 L
s
.28081 .17245 m
.28271 .16 L
s
.75466 .14985 m
.75771 .14672 L
s
.75306 .14942 m
.75771 .14672 L
s
.28607 .15113 m
.29092 .14583 L
s
.28427 .15956 m
.28764 .15069 L
s
.28235 .17201 m
.28427 .15956 L
s
.28764 .15069 m
.29092 .14583 L
s
.28056 .18048 m
.28081 .17245 L
s
.29092 .14583 m
.29413 .14497 L
s
.28211 .18005 m
.28235 .17201 L
s
.75329 .15743 m
.75466 .14985 L
s
.26108 .2381 m
.26688 .23638 L
s
.28056 .18048 m
.28174 .19212 L
s
.75168 .15701 m
.75306 .14942 L
s
.29413 .14497 m
.29726 .14813 L
s
.29413 .14497 m
.29889 .14772 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26688 .23638 m
.26957 .15212 L
s
.28211 .18005 m
.2833 .1917 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29726 .14813 m
.30031 .15533 L
s
.29889 .14772 m
.30197 .15493 L
s
.28174 .19212 m
.28463 .19936 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75168 .15701 m
.75296 .20139 L
s
.75329 .15743 m
.75458 .2018 L
s
.76563 .20468 m
.77173 .20638 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2833 .1917 m
.28621 .19895 L
s
.30031 .15533 m
.30163 .16701 L
s
.30197 .15493 m
.3033 .16661 L
s
.28463 .19936 m
.28928 .20218 L
s
.73646 .14128 m
.73711 .16545 L
s
.28621 .19895 m
.28928 .20218 L
s
.73476 .14088 m
.73711 .16545 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31242 .14047 m
.32461 .13779 L
s
.30141 .17508 m
.30163 .16701 L
s
.30308 .17469 m
.3033 .16661 L
s
.28928 .20218 m
.2925 .20137 L
s
.29941 .18762 m
.30141 .17508 L
s
.74805 .2002 m
.75458 .2018 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70826 .13528 m
.73646 .14128 L
s
.30107 .18723 m
.30308 .17469 L
s
.2925 .20137 m
.29588 .19652 L
s
.2925 .20137 m
.29753 .19613 L
s
.29588 .19652 m
.29941 .18762 L
s
.29753 .19613 m
.30107 .18723 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31612 .19604 m
.31759 .1393 L
s
.31788 .19568 m
.31933 .13892 L
s
.33176 .13633 m
.34458 .1339 L
s
.72686 .16722 m
.7277 .19978 L
s
.255 .412 .882 r
.72171 .1761 m
.72352 .1793 L
s
0 0 0 r
.33616 .17997 m
.33721 .13527 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33801 .17963 m
.33904 .13492 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73704 .22615 m
.73809 .20198 L
s
.73809 .20198 m
.73876 .22651 L
s
.31091 .19714 m
.31788 .19568 L
s
.7166 .18134 m
.72728 .18347 L
s
.31819 .18345 m
.32151 .19088 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35208 .13258 m
.36548 .13041 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32151 .19088 m
.32677 .19392 L
s
.35659 .18882 m
.35778 .13163 L
s
.35852 .18853 m
.35969 .13132 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71551 .13671 m
.71759 .22235 L
s
.32677 .19392 m
.33039 .19324 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33414 .18848 m
.33616 .17997 L
s
.33039 .19324 m
.33414 .18848 L
s
.33039 .19324 m
.33597 .18815 L
s
.33597 .18815 m
.33801 .17963 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38112 .13222 m
.38718 .12736 L
s
.37898 .14065 m
.38112 .13222 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38311 .13196 m
.38718 .12736 L
s
.38097 .14038 m
.38311 .13196 L
s
.38718 .12736 m
.39121 .12685 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71371 .13635 m
.71578 .22202 L
s
.71027 .22105 m
.73876 .22651 L
s
.39121 .12685 m
.39723 .1302 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37816 .1858 m
.37898 .14065 L
s
.38016 .18555 m
.38097 .14038 L
s
.35085 .18972 m
.35852 .18853 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39723 .1302 m
.40119 .13791 L
s
.40138 .12565 m
.4096 .12476 L
s
.40049 .18319 m
.40138 .12565 L
s
.40256 .18298 m
.40343 .12542 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42 .12373 m
.42199 .13172 L
s
.41979 .14012 m
.42 .12373 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35616 .20945 m
.35801 .2133 L
s
.35415 .21387 m
.35616 .20945 L
s
.42414 .12744 m
.4284 .12298 L
s
.4284 .12298 m
.43686 .12229 L
s
.35415 .21387 m
.35599 .21773 L
s
.3722 .18658 m
.38016 .18555 L
s
.42199 .13172 m
.42414 .12744 L
s
.41979 .14012 m
.42199 .13172 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35599 .21773 m
.35801 .2133 L
s
.43686 .12229 m
.44108 .12607 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44108 .12607 m
.44317 .13002 L
s
.44304 .14235 m
.44317 .13002 L
s
.46043 .12073 m
.46256 .12472 L
s
.45824 .12496 m
.46043 .12073 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45824 .12496 m
.46037 .12894 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46037 .12894 m
.46256 .12472 L
s
.39434 .18386 m
.40256 .18298 L
s
.44091 .1425 m
.44309 .13824 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4366 .14694 m
.44091 .1425 L
s
.42589 .15602 m
.4366 .14694 L
s
.44086 .14662 m
.44304 .14235 L
s
.42162 .16051 m
.42589 .15602 L
s
.41947 .16483 m
.42162 .16051 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43655 .15106 m
.44086 .14662 L
s
.41936 .1731 m
.41947 .16483 L
s
.42584 .16015 m
.43655 .15106 L
s
.42157 .16464 m
.42584 .16015 L
s
.41941 .16896 m
.42157 .16464 L
s
.41936 .1731 m
.42141 .17706 L
s
.42141 .17706 m
.42559 .18085 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44061 .17143 m
.44284 .163 L
s
.44267 .17959 m
.44284 .163 L
s
.42559 .18085 m
.4341 .18019 L
s
.43842 .17573 m
.44061 .17143 L
s
.44061 .17143 m
.44267 .17959 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4341 .18019 m
.43842 .17573 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46021 .14955 m
.462 .19932 L
s
.45764 .19954 m
.46021 .14955 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45982 .19943 m
.46001 .17441 L
s
.45764 .19954 m
.45975 .2078 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45975 .2078 m
.462 .19932 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0=0?nV4@030000003oYQ40ojHA00@0ojHA=P2][Jd?
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ460000
0080ojHA1`2][Jd2000000H0[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
00d0ojD@502][JdG0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?ooo`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00h0ojHA00@000000?nV4@00
00000000103oYQ4010000000[Jf]0:f][@0000060:f][@030000002][Jd0ojHA00H0ojHA00<00000
0?nV4@000000303oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa000P3oXa090:f][@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ430000
00<0ojHA00@0[Jf]00000000000000001P2][Jd01@000000ojHA0000003oYQ40[Jf]00H0ojHA00<0
00000?nV4@3oYQ401@3oYQ42000000d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@00/0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H3
0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA0080ojHA0`2][Jd010000000[Jf]0:f][@2][Jd2000000040:f][@3oYQ400000000000L0ojHA
00D000000?nV4@000000ojHA0:f][@060?nV4@030000003oYQ40ojHA00H0ojHA00<000000?nV4@3o
YQ402`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa005@3oXa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80
[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0B0?nV4@@000001P2][Jd20?nV4@8000001@3oYQ4010000000ojHA0000000000070?nV4@80
00000P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40ojHA01<0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1001P2][JdB0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0
/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
3P3oYQ4500000080[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000001P3oYQ4010000000ojHA
0000000000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40ojHA01<0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0
oj<@00<0[Jf]0?bP403lX1001P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA
1@0000040:f][@030?nV4@000000000000@0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000L0ojHA
0`0000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40ojHA01<0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1002`3lX1050:f][@040?bP400000000000000000@0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40
oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A
00<0[Jf]0?nV4@3oYQ40103oYQ4500000080[Jf]1P3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ42000000P0ojHA0`0000070?nV4@050000003oYQ40ojHA0?nV4@2][Jd01`3oYQ400`000000
ojHA0?nV4@0C0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@0`2][Jd5000000030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]F@2`h>H10?ooo`00
KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
503oY145000000<0[Jf]0P3oYQ42000000P0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA
0P0000090?nV4@8000001`3oYQ401@000000ojHA0?nV4@3oYQ40[Jf]00L0ojHA00<000000?nV4@3o
YQ404`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006@3oXa000`2][Jd0o:0@0?bP400C0?bP4080000000<0o:0@0:f][@2][Jd01@00000B0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V
0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404P3oY144000000030:f]
[@3oYQ40ojHA00D0ojHA0P0000080?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000
2@3oYQ42000000L0ojHA00D000000?nV4@3oYQ40ojHA0:f][@060?nV4@8000005@3oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0
o:0@0?bP400C0?bP408000000`3lX1000`2][Jd0mY`?0:f][@020:f][@<000003`3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]
2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A102][Jd00`3oY1400000
000000080?nV4@800000203oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000T0ojHA
0P00000:0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000E0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01<0o:0@
0P0000030?bP40030:f][@3fW0l0mY`?00<0mY`?0P0000020:f][@d0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@030000003oY140[Jf]00<0[Jf]1@3o
Y142000000P0ojHA0P0000080?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002@3o
YQ42000000X0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ43000001H0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1004`3l
X102000000<0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l200000080mY`?102][Jd90?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W
0;3PiP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@07
0?nT4@@000002@3oY142000000P0ojHA0P0000080?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@02
0?nV4@8000002@3oYQ42000000X0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4010000000ojHA0?nV4@00
000F0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400I0?nS40030:f][@3lX100o:0@01<0o:0@0P0000030?bP40030:f][@3fW0l0mY`?00<0mY`?0P00
00060?JL3`<0[Jf]00<000000?JL3`3fW0l00`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00<0oj@A0`2][Jd010000000oj@A0?nT4@3oY142000000P0oj@A0P00
00080?nV4@800000203oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000T0ojHA0P00
000:0?nV4@060:f][@3oYQ40ojHA0?nV4@000000ojHA0P00000G0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@0180
o:0@0P0000030?bP40030:f][@3fW0l0mY`?00<0mY`?0P0000070?JL3`80000000<0mY`?00000000
00000P2][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2]
[Jd0D02`h>H10?ooo`00I@2`h>H01@2][Jd0dhL>0:f][@3_V100000000/0kiP@00<0[Jf]0?bP403l
X1003`3lX102000000@0[Jf]0P3oY1400`000000oj@A0?nT4@030?nT4@030000003oY140oj@A00H0
oj@A0P0000080?nV4@800000203oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000T0
ojHA0P00000:0?nV4@060:f][@3oYQ40ojHA0000003oYQ4000002`3oYQ400`000000ojHA0?nV4@0;
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@0180o:0@0P0000030?bP40030:f][@3fW0l0mY`?00<0mY`?0P000007
0?JL3`8000000`3fW0l00`000000mY`?0:f][@0200000140k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP030:f][@3CQ`h0dhL>00800000303_V100
0`2][Jd0o:0@0?bP400=0?bP408000000P2][Jd60?nT4@030000003oY140oj@A00<0oj@A0P000007
0?nT4@800000203oYQ42000000P0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA0P000009
0?nV4@8000002P3oYQ401@2][Jd0ojHA0000003oYQ40000000`0ojHA00<000000?nV4@3oYQ402`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400B0?bP408000000`3lX1000`2][Jd0mY`?0?JL3`030?JL3`8000001P3f
W0l00`000000mY`?000000040?JL3`040000003fW0l000000>bF3P80000000<0[Jf]0>bF3P3/UPh0
303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00
H`2`h>H00`2][Jd0dhL>0=>73P03000000`0kiP@00<0[Jf]0?bP403lX1002`3lX102000000030:f]
[@000000[Jf]00H0oj@A00<000000?nT4@3oY1401@3oY1400`000000oj@A0?nT4@050?nT4@800000
203oYQ42000000P0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000080?nV4@030000
003oYQ40000000X0ojHA00@0[Jf]0000003oYQ4000003@3oYQ400`000000ojHA0?nV4@0;0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@0180o:0@0P0000030?bP40030:f][@3fW0l0mY`?00@0mY`?00<000000?JL3`3f
W0l0103fW0l2000000D0mY`?00<000000?JL3`000000103/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>
0=>73P020=>73P800000303_V1000`2][Jd0o:0@0?bP40070?bP40<000000P2][Jd20?bP40030000
002][Jd0oj@A00D0oj@A00<000000?nT4@3oY1401@3oY1400`000000oj@A0?nT4@050?nT4@800000
203oYQ400`000000ojHA0?nV4@070?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000
203oYQ400`000000ojHA0000000:0?nV4@030000003oYQ40000000h0ojHA00<000000?nV4@3oYQ40
103oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400B0?bP40800000
0`3lX1000`2][Jd0mY`?0?JL3`040?JL3`030000003fW0l0mY`?00@0mY`?0P0000060?JL3`800000
1P3/UPh30:f][@030000003/UPh0k9H>00H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3C
Q`h2000000`0kiP@00<0[Jf]0?bP403lX100103lX104000000030:f][@3lX100o:0@00<0o:0@00<0
00000:f][@3oY140103oY142000000L0oj@A00<000000?nT4@3oY140103oY1400`2][Jd000000000
00070?nV4@8000002@3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000P0ojHA00<0
00000?nV4@0000002@3oYQ400`000000[Jf]000000060?nV4@T0[Jf]00<000000:f][@2][Jd0102]
[Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400B0?bP408000000`3lX1000`2][Jd0mY`?0?JL
3`040?JL3`030000003fW0l0mY`?00@0mY`?0P0000060?JL3`8000001`3/UPh2000000030:f][@00
0000000000H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`
h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h2000000`0kiP@00<0[Jf]
0?bP403lX100103lX1020:f][@8000001P3lX1000`000000[Jf]0?nT4@040?nT4@8000001`3oY140
0`000000oj@A0?nT4@040?nT4@030:f][@000000000000L0ojHA0P0000090?nV4@800000103oYQ40
0`2][Jd0ojHA0?nV4@020?nV4@800000203oYQ400`000000ojHA000000060?nV4@80[Jf]00<00000
0:f][@0000001`2][Jd90?nV4@030000003oYQ40ojHA00/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP400B0?bP408000000`3lX100
0`2][Jd0mY`?0?JL3`040?JL3`030000003fW0l0mY`?00@0mY`?0P0000070?JL3`030000003/UPh0
k9H>00D0k9H>0P0000020>bF3P040000002][Jd00000000000<0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]
0=>73P3CQ`h01@3CQ`h2000000`0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd20?bP408000001P3l
X1000`000000[Jf]0?nT4@040?nT4@8000001`3oY142000000D0oj@A00<0[Jf]0000000000001`3o
YQ42000000T0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@3oYQ401`3o
YQ400`000000[Jf]000000060:f][@050?nV4@000000ojHA0000002][Jd0203oYQ400`000000ojHA
0?nV4@050?nV4@030000003oYQ40ojHA00/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@0180o:0@
0P0000030?bP40030:f][@3fW0l0mY`?00@0mY`?00<000000?JL3`3fW0l0103fW0l2000000L0mY`?
00<000000>bF3P3/UPh0103/UPh00`000000k9H>000000030>bF3PD0000000<0k9H>0:f][@3KRPd0
303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0
[Jf]0=>73P3CQ`h01P3CQ`h2000000`0kiP@00@000000?bP402][Jd0[Jf]1@3lX102000000H0o:0@
00<000000:f][@3oY140103oY142000000L0oj@A0P0000050?nT4@030:f][@000000000000L0ojHA
0P0000090?nV4@800000103oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0[Jf]00<000000?nV4@00
00001`3oYQ42000000030?nV4@2][Jd0ojHA00H0ojHA0P0000070?nV4@030000003oYQ40ojHA00/0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0
oj<@2P2][Jd40?nS40030:f][@3lX100o:0@0180o:0@0P0000030?bP40030:f][@3fW0l0mY`?00@0
mY`?00<000000?JL3`3fW0l0103fW0l2000000L0mY`?00<000000>bF3P3/UPh0103/UPh2000000@0
k9H>0`0000020>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00
G@2`h>H20:f][@P0dhL>0P00000;0>nH40@000001P3lX102000000H0o:0@00<000000:f][@3oY140
0`3oY142000000P0oj@A0P0000050?nT4@030:f][@000000ojHA00L0ojHA0P0000090?nV4@800000
0P3oYQ460:f][@8000002@3oYQ400`000000ojHA000000070?nV4@040000003oYQ40ojHA0:f][@L0
ojHA0P0000070?nV4@030000003oYQ40ojHA00/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdA0?bP408000000`3lX1000`2][Jd0
mY`?0000000;0?JL3`8000001`3fW0l00`000000k9H>0>bF3P040>bF3P800000103/UPh3000000<0
k9H>0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]
203CQ`h2000000X0kiP@00<000000:f][@2][Jd00P0000060?bP408000001P3lX1000`000000[Jf]
0?nT4@030?nT4@800000203oY142000000D0oj@A0P0000080?nV4@8000001`3oYQ420:f][@800000
0P2][Jd20?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ400`000000ojHA000000070?nV4@04
0000003oYQ40ojHA0:f][@H0ojHA00<000000?nV4@0000001`3oYQ400`000000ojHA0?nV4@0;0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40040:f][@3lX100o:0@0?bP40H0[Jf]2`3lX102000000<0o:0@00<0[Jf]0?JL3`0000002`3fW0l2
000000L0mY`?00<000000>bF3P3/UPh0103/UPh2000000D0k9H>0P0000030>bF3P040:f][@3KRPd0
fhX=0:f][@800000203KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3o
ool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h2000000P0kiP@00D0[Jf]000000000000kiP@0:f]
[@02000000H0o:0@0P0000060?bP40030000002][Jd0oj@A00<0oj@A0P0000080?nT4@8000001@3o
Y142000000P0ojHA0P0000020?nV4@D0[Jf]0P3oYQ42000000@0ojHA00@0[Jf]0?nV4@3oYQ40ojHA
0P0000090?nV4@030000003oYQ40000000L0ojHA00@000000?nV4@3oYQ40[Jf]1P3oYQ42000000P0
ojHA00<000000?nV4@3oYQ402`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40070?bP40L0[Jf]103lX102000000<0
o:0@00<0[Jf]0?JL3`0000002`3fW0l2000000L0mY`?00<000000>bF3P3/UPh0103/UPh2000000D0
k9H>0P0000030>bF3P070:f][@3KRPd0fhX=0000003KRPd0[Jf]000000070=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd8
0=>73P8000001P3_V1020:f][@060>nH4000000000000>nH402][Jd0o:0@0P0000050?bP40800000
1P3lX1000`000000[Jf]0?nT4@030?nT4@800000203oY142000000D0oj@A0P0000070?nV4@030:f]
[@00000000000080[Jf]1`3oYQ42000000@0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000090?nV4@03
0000003oYQ40000000L0ojHA00@000000?nV4@3oYQ40[Jf]1P3oYQ42000000P0ojHA00<000000?nV
4@3oYQ402`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40@0[Jf]0P0000030?bP40030:f][@3fW0l00000
00/0mY`?0P0000070?JL3`030000003/UPh0k9H>00@0k9H>00<000000>bF3P3/UPh0103/UPh20000
00<0k9H>00@0[Jf]0=^:3@3KRPd000000P3KRPd00`000000[Jf]0=^:3@050=^:3@030:f][@2iM@/0
^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2]
[Jd80=>73P030000003_V100kiP@00@0kiP@00@0[Jf]0>nH403_V100kiP@0P0000000`3_V100[Jf]
0?bP4002000000D0o:0@0P0000050?bP4080000000<0[Jf]0?nT4@3oY1400P3oY142000000P0oj@A
0P0000050?nT4@80000000<0ojHA0:f][@2][Jd0102][Jd00`3oYQ400000000000090?nV4@800000
103oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA00<000000?nV4@0000001`3oYQ4010000000
ojHA0?nV4@2][Jd50?nV4@<000001`3oYQ42000000d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004P3lX1020000
00D0[Jf]00<000000?JL3`3fW0l02@3fW0l2000000L0mY`?00<000000>bF3P3/UPh0103/UPh00`00
0000k9H>0>bF3P040>bF3P8000000`3/UPh00`2][Jd0fhX=000000040=^:3@050000002][Jd0[Jf]
0=^:3@0000000P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`
h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00D000000>nH400000000000
0>nH40020:f][@<0kiP@0P0000020>nH40040:f][@3lX1000000000000D0o:0@0P0000050?bP4080
000000<0[Jf]0?nT4@3oY1400P3oY142000000P0oj@A0P0000040?nT4@040:f][@00000000000:f]
[@L0ojHA0P0000090?nV4@800000103oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA00<00000
0?nV4@000000203oYQ400`000000ojHA0:f][@050?nV4@030000003oYQ40000000L0ojHA0`00000<
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@0180o:0@0P0000030?bP40030:f][@3fW0l0000000<0[Jf]203fW0l2
000000L0mY`?00<000000>bF3P3/UPh0103/UPh00`000000k9H>0>bF3P040>bF3P8000000`3/UPh0
0`2][Jd0fhX=000000040=^:3@030000003KRPd0fhX=0080[Jf]0P0000000`2][Jd0^GD;0;Ue2`07
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00P0dhL>00D000000>nH40000000[Jf]000000050>nH408000000P3_V100102][Jd0o:0@
0000000000050?bP40030000003lX100o:0@00@0o:0@0P0000000`2][Jd0oj@A0?nT4@020?nT4@80
0000203oY142000000@0[Jf]00<0oj@A000000000000203oYQ42000000T0ojHA0P0000040?nV4@04
0:f][@3oYQ40ojHA0?nV4@8000002@3oYQ400`000000ojHA000000090?nV4@030000002][Jd0ojHA
00<0ojHA00@000000?nV4@3oYQ4000001`3oYQ43000000`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004P3lX102
000000<0o:0@00<0[Jf]0?JL3`0000000`3fW0l40:f][@@0mY`?0P0000070?JL3`030000003/UPh0
k9H>00@0k9H>00<000000>bF3P3/UPh0103/UPh2000000<0k9H>00<0[Jf]0=^:3@000000103KRPd0
0`000000fhX=0=^:3@020=^:3@030000002][Jd0000000T0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>7
3P3CQ`h01P3CQ`h2000000030:f][@3_V100000000D0kiP@0P0000020>nH40040:f][@3lX1000000
000000D0o:0@00<000000?bP403lX100103lX102000000030:f][@3oY140oj@A0080oj@A0P000006
0?nT4@040:f][@00000000000:f][@D0oj@A0P0000080?nV4@8000002@3oYQ42000000@0ojHA00@0
[Jf]0?nV4@3oYQ40ojHA0P0000090?nV4@030000003oYQ40000000X0ojHA1@00000;0?nV4@<00000
303oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400C0?bP40@0000000<0[Jf]0?JL3`0000001`3fW0l40:f][@030?JL
3`000000000000H0mY`?00<0[Jf]0000003/UPh0103/UPh00`000000k9H>0>bF3P040>bF3P800000
0`3/UPh00`2][Jd0fhX=000000050=^:3@090000003KRPd0fhX=0=^:3@000000fhX=0:f][@2iM@/0
000000L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd01`3CQ`h010000000dhL>0000000000020>nH40800000103_
V10200000080kiP@00@0[Jf]0?bP403lX10000001@3lX1000`000000o:0@0?bP40040?bP40800000
00<0[Jf]0?nT4@3oY1400P3oY142000000<0oj@A0`2][Jd00`3oY1400000000000060?nT4@<00000
1`3oYQ42000000T0ojHA0P0000040?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ43000000X0
ojHA00<0[Jf]0?nV4@3oYQ403@3oYQ43000000`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004`3lX10200000080
o:0@0`00000;0?JL3`040:f][@00000000000:f][@D0mY`?00<0[Jf]0000003/UPh0103/UPh00`00
0000k9H>0>bF3P050>bF3P050000003/UPh0k9H>0>bF3P2][Jd00P0000050=^:3@030000003KRPd0
fhX=0080fhX=00@000000:f][@2][Jd0^GD;0P0000050;Ue2`030:f][@28EPL0R5H70080R5H700<0
[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>00<0
00000=>73P2][Jd00P0000030>nH40030000003_V100kiP@0080kiP@0P0000000`3_V100[Jf]0?bP
40020?bP40030000003lX100o:0@00<0o:0@00<000000?bP403lX100103lX102000000030:f][@3o
Y140oj@A0080oj@A0P0000030:f][@@0oj@A0P0000060?nT4@<000001P3oYQ42000000X0ojHA0P00
00040?nV4@040:f][@3oYQ40ojHA0?nV4@8000001P3oYQ43000000d0ojHA00<0[Jf]0?nV4@3oYQ40
3@3oYQ43000000`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004`3lX10200000080o:0@00<0[Jf]0?JL3`000000
303fW0l2000000030?JL3`2][Jd0[Jf]0080[Jf]00<0mY`?0:f][@0000001@3/UPh00`000000k9H>
0>bF3P050>bF3P050000003/UPh0k9H>0>bF3P2][Jd00P0000050=^:3@030000003KRPd0fhX=0080
fhX=00D000000:f][@2iM@/0[Jf]000000060;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3P
iP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>0P0000000`2]
[Jd0dhL>000000040>nH40040000003_V100kiP@0>nH408000000P3_V1001@2][Jd0o:0@0?bP403l
X100000000D0o:0@00<000000?bP403lX100103lX102000000030:f][@3oY140[Jf]0080[Jf]0P00
00070?nT4@8000001P3oY143000000H0ojHA0P00000:0?nV4@8000000`3oYQ400`2][Jd0ojHA0000
0003000001L0ojHA00<0[Jf]0?nV4@3oYQ403@3oYQ43000000`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004`3l
X10200000080o:0@00<0[Jf]0?JL3`000000303fW0l2000000D0mY`?0P2][Jd00`000000k9H>0>bF
3P030>bF3P030000003/UPh0k9H>00D0k9H>00D000000>bF3P3/UPh0k9H>0:f][@02000000D0fhX=
00<000000=^:3@3KRPd00P3KRPd01P000000[Jf]0;Ue2`2iM@/000000:f][@D0^GD;00<0[Jf]08QF
1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd01@3CQ`h01@2][Jd000000=>73P3CQ`h0000000@0kiP@00@000000>nH403_V100kiP@0P00
00020>nH40050:f][@3lX100o:0@0?bP400000001@3lX1000`000000o:0@0?bP40040?bP40800000
0P2][Jd30?nT4@8000001`3oY142000000H0oj@A0P0000000`3oYQ4000000?nV4@040?nV4@800000
1`3oYQ45000000<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0=0?nV4@<00000
303oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400C0?bP408000000P3lX1000`2][Jd0mY`?0000000<0?JL3`800000
1P3fW0l00`2][Jd000000:f][@020:f][@80k9H>00<000000>bF3P3/UPh01@3/UPh01@000000k9H>
0>bF3P3/UPh0[Jf]008000001@3KRPd00`000000fhX=0=^:3@020=^:3@030000002][Jd0^GD;0080
000000<0^GD;0:f][@2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00
F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]0080dhL>00D000000=>73P2][Jd0dhL>000000020=>7
3P030000003_V100kiP@0080kiP@00@000000>nH403_V100kiP@0P0000020>nH40050:f][@3lX100
o:0@0?bP400000001@3lX1000`000000o:0@0?bP40020?bP4080[Jf]0P0000000`2][Jd0oj@A0?nT
4@020?nT4@8000001P3oY142000000L0oj@A0P0000000`3oYQ4000000?nV4@030?nV4@800000403o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00d0ojHA0`00000<0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01<0o:0@0P0000020?bP40030:f][@3fW0l0000000`0mY`?0P0000060?JL3`030:f][@00
0000k9H>0080k9H>0P2][Jd00`000000k9H>0>bF3P050>bF3P050000003/UPh0k9H>0>bF3P2][Jd0
0P0000050=^:3@8000000`3KRPd010000000[Jf]0;Ue2`0000030;Ue2`050:f][@2iM@/000000000
002][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V00T0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h0
00000=>73P2][Jd00P3CQ`h010000000dhL>0=>73P0000040>nH408000000P3_V10200000080kiP@
00D0[Jf]0?bP403lX100o:0@000000050?bP40030000003lX100o:0@0080[Jf]0P3lX10200000003
0:f][@3oY140oj@A0080oj@A0P0000060?nT4@8000001`3oY14200000080ojHA0P0000020?nV4@03
0000003oYQ40ojHA00l0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0=0?nV4@<0
0000303oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400C0?bP408000000P3lX1000`2][Jd0mY`?0000000<0?JL3`80
00001P3fW0l00`2][Jd000000>bF3P040>bF3P030000002][Jd0[Jf]00D0k9H>00D000000>bF3P3/
UPh0k9H>0:f][@02000000D0fhX=0P0000040=^:3@030000002iM@/0000000@0^GD;0`0000000`2]
[Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0202][Jd0Uf0;09MP2`2GH0/0[Jf]
0=>73P000000[Jf]0P3CQ`h2000000030=>73P000000000000@0kiP@0P0000020>nH408000000P3_
V1001@2][Jd0o:0@0?bP403lX100000000D0o:0@00<000000:f][@2][Jd0103lX1000`000000o:0@
0:f][@050?nT4@800000103oY142000000P0oj@A0P0000040?nV4@8000004P3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00d0ojHA0`0000050?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01<0o:0@0P0000030?bP40030:f][@000000mY`?00/0mY`?
0P0000060?JL3`030:f][@000000k9H>00D0k9H>00<000000>bF3P2][Jd00P2][Jd20>bF3P050000
003/UPh0k9H>0>bF3P2][Jd00P0000050=^:3@800000103KRPd00`000000^GD;000000040;Ue2`80
000000<0[Jf]0000000000000`28EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0
Uf0;0P2][Jd01@000000dhL>0=>73P3CQ`h000000080dhL>0P0000040>nH408000000P3_V1020000
0080kiP@00D0[Jf]0?bP403lX100o:0@000000020?bP40<0[Jf]00<000000?bP403lX100103lX100
0`000000o:0@0:f][@050?nT4@800000103oY142000000H0oj@A0`00000I0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ480:f][@<000001@2][Jd70?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400C0?bP408000000`3lX1000`2][Jd000000?JL3`0;0?JL3`8000001P3fW0l0
0`2][Jd000000>bF3P050>bF3P030000003/UPh0k9H>0080k9H>0P2][Jd01@000000k9H>0>bF3P3/
UPh0[Jf]008000001@3KRPd2000000@0fhX=00<000000;Ue2`000000102iM@/00`000000^GD;0;Ue
2`02000000@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`2G
H0/0[Jf]0=>73P0000000`3CQ`h00`000000dhL>0=>73P02000000@0kiP@0P0000020>nH40800000
0P3_V1001@2][Jd0o:0@0?bP403lX10000000080[Jf]0`3lX1000`000000o:0@0?bP40040?bP4003
0000003lX100[Jf]00H0oj@A0P0000020?nT4@8000002@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01H0ojHA302][Jd80?nV4@<00000303oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01D0ojD@302][JdH0?nS40030:f][@3lX100o:0@01<0o:0@0P0000030?bP4003
0:f][@000000mY`?00/0mY`?0P0000060?JL3`030:f][@000000k9H>00D0k9H>00<000000>bF3P3/
UPh0103/UPh01@000000[Jf]0:f][@3/UPh0[Jf]008000001@3KRPd2000000@0fhX=00<000000:f]
[@000000102iM@/00`000000^GD;0;Ue2`020000000508QF1`000000R5H708QF1`2][Jd0@P2`h>H1
0?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@030=>73P000000dhL>0080dhL>00<000000=>7
3P3CQ`h00P0000040>nH40040000003_V100kiP@0>nH408000000P3_V1001@2][Jd0o:0@0:f][@00
0000[Jf]00@0o:0@0P0000060?bP40030000003lX100[Jf]00L0oj@A00@000000?nT4@3oY1400000
2P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@030:f]
[@3oYQ40ojHA00d0ojHA00<000000?nV4@000000303oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX100
4`3lX102000000<0o:0@00<0[Jf]0000003fW0l0203fW0l2000000030?JL3`000000000000H0mY`?
00<0[Jf]0000003/UPh01@3/UPh00`000000k9H>0>bF3P040>bF3P030000003/UPh0k9H>0080[Jf]
0P0000060=^:3@030000003KRPd0fhX=0080fhX=0`0000040;Ue2`030000002iM@/0^GD;00800000
00D0R5H7000000000000R5H70:f][@120;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080[Jf]
00<0dhL>0000003CQ`h00P3CQ`h00`000000dhL>0=>73P02000000@0kiP@00@000000>nH403_V100
kiP@0P0000020>nH4080[Jf]00<0o:0@0000003lX100103lX102000000H0o:0@00<000000?bP402]
[Jd0203oY142000000/0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0=0?nV4@8000003@3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403l
X1004`3lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l00`000000mY`?0?JL3`030?JL3`<0
00001P3fW0l00`2][Jd000000>bF3P050>bF3P8000001@3/UPh200000080k9H>00@0[Jf]00000000
0000[Jf]1@3KRPd00`000000fhX=0=^:3@030=^:3@800000102iM@/00`000000^GD;0;Ue2`020000
00050:f][@000000000008QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;0:f][@2GH0/0
[Jf]0=>73P0000000`3CQ`h00`000000dhL>0=>73P02000000@0kiP@00@000000>nH403_V100kiP@
0P0000030:f][@80o:0@00<000000?bP403lX1000`3lX102000000H0o:0@00<000000?bP402][Jd0
5@3oY1400`2][Jd0ojHA0?nV4@0D0?nV4@P0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0>0?nV4@030000
003oYQ40ojHA00/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01H0oj<@202][JdB0?bP408000000`3lX1000`2][Jd0mY`?0?JL3`040?JL3`030000
003fW0l0mY`?00X0mY`?0P0000000`2][Jd000000>bF3P060>bF3P030000003/UPh0k9H>00<0k9H>
0P0000020>bF3P040:f][@3KRPd0000000000080[Jf]0`3KRPd00`000000fhX=0=^:3@030=^:3@80
0000102iM@/00`000000^GD;0;Ue2`020000000508QF1`000000000008QF1`2][Jd0@P2`h>H10?oo
o`00F@2`h>H01`2][Jd0Uf0;0:f][@2GH0/0[Jf]0=>73P0000000`3CQ`h00`000000dhL>0=>73P02
000000@0kiP@00@000000>nH403_V100kiP@0P0000020>nH40040:f][@3lX100o:0@000000D0o:0@
0P0000060?bP40030000002][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ460:f][@<0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0>0?nV4@030000003oYQ40ojHA00/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00@0[Jf]0?bP403lX100o:0@1`2][Jd;0?bP408000000`3lX1000`2][Jd0mY`?0?JL3`040?JL3`03
0000003fW0l0mY`?00`0mY`?0P0000070>bF3P8000000`3/UPh300000080k9H>00@0[Jf]0=^:3@00
000000000P3KRPd20:f][@030=^:3@000000fhX=00@0fhX=00<000000;Ue2`2iM@/00`2iM@/00`00
0000^GD;0;Ue2`020000000508QF1`000000000008QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H20:f]
[@80Uf0;00<0[Jf]0=>73P0000000P3CQ`h200000080dhL>0P0000040>nH40040000003_V100[Jf]
0:f][@8000000P3_V100102][Jd0o:0@0000000000050?bP408000001P3lX1000`000000[Jf]0?nT
4@0E0?nT4@030:f][@3oYQ40ojHA00L0ojHA1`2][Jd30?nV4@030000003oYQ40ojHA00<0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00P0o:0@1P2]
[Jd50?bP408000000`3lX1000`2][Jd0mY`?0?JL3`040?JL3`030000003fW0l0mY`?00d0mY`?00<0
[Jf]0>bF3P3/UPh01P3/UPh010000000k9H>0>bF3P3/UPh300000080k9H>00@0[Jf]0=^:3@000000
0000103KRPd2000000D0fhX=00<000000;Ue2`2iM@/00`2iM@/00`000000^GD;0;Ue2`0200000005
08QF1`000000[Jf]0000002][Jd0@P2`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00L0[Jf]0=>73P00
0000dhL>0000003CQ`h000000080dhL>0P0000030>nH4080000000<0[Jf]0>nH403_V1000P000002
0>nH40030:f][@3lX100000000H0o:0@0P0000060?bP40030000002][Jd0oj@A01D0oj@A00@0[Jf]
0?nV4@3oYQ40ojHA1P2][Jd:0?nV4@030000003oYQ40ojHA00<0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1@2][Jd2000000<0o:0@00<0
[Jf]0?JL3`3fW0l0103fW0l00`000000mY`?0?JL3`0=0?JL3`030:f][@3/UPh0k9H>00H0k9H>0P00
00020>bF3P<000000P3/UPh0102][Jd0fhX=0000000000040=^:3@8000000P2][Jd30=^:3@030000
002iM@/0^GD;00<0^GD;00<000000;Ue2`2iM@/00P0000000`28EPL0000008QF1`0200000480/>3V
0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h2000000030=>73P00000000000080
dhL>0P0000020>nH40030:f][@000000000000<0kiP@0P0000020>nH40030:f][@000000000000H0
o:0@0P0000060?bP40030000002][Jd0oj@A01@0oj@A1@2][Jd?0?nV4@030000003oYQ40000000@0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01<0
o:0@0P0000060:f][@@0mY`?00<000000?JL3`3fW0l03@3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0
000000<0k9H>0000000000000P3/UPh0102][Jd0fhX=0000000000040=^:3@8000000P3KRPd20:f]
[@<00000102iM@/00`000000^GD;0;Ue2`020000000308QF1`000000R5H700800000@P2`h>H10?oo
o`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P0000000P3CQ`h200000080dhL>00D000000>nH402]
[Jd0[Jf]0>nH4002000000<0kiP@0P0000020>nH40030:f][@000000000000H0o:0@0P0000060?bP
40030000002][Jd0oj@A0100oj@A102][Jd00`3oY140[Jf]0?nV4@0A0?nV4@8000001@3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004`3lX1020000
00<0o:0@00<0[Jf]0?JL3`3fW0l00`2][Jd2000000l0mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh20000
0080k9H>00<0[Jf]0=^:3@3KRPd00P0000030=^:3@800000103KRPd3000000@0^GD;00<000000;Ue
2`2iM@/00P0000000`28EPL0000008QF1`02000000030:f][@2`h>H0/>3V03l0/>3V0@3oool005P0
/>3V0P2][Jd309MP2`030:f][@3CQ`h000000080dhL>00H000000=>73P3CQ`h0dhL>0000002][Jd3
0>nH40800000103_V102000000030>nH402][Jd0000000L0o:0@0P0000050?bP4080000000<0[Jf]
0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ404@3oYQ400`000000ojHA0?nV4@03
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400C
0?bP408000000`3lX1000`2][Jd0mY`?0?JL3`030?JL3`800000102][Jd;0?JL3`030:f][@3/UPh0
k9H>00/0k9H>0P0000020>bF3P030:f][@3KRPd0fhX=008000000`3KRPd2000000@0fhX=0`000004
0;Ue2`030000002iM@/0^GD;008000000`28EPL2000000030:f][@2`h>H0/>3V03l0/>3V0@3oool0
05P0/>3V0P2][Jd309MP2`030:f][@3CQ`h000000080dhL>00D000000=>73P3CQ`h0[Jf]00000004
0>nH40800000103_V102000000030>nH40000000000000L0o:0@0P0000050?bP4080000000<0[Jf]
0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004`3lX102000000<0o:0@00<0[Jf]
0?JL3`3fW0l00`3fW0l2000000@0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>00/0k9H>0P000002
0>bF3P050:f][@3KRPd0fhX=0=^:3@0000000P3KRPd2000000D0fhX=0`0000020:f][@80^GD;00<0
00000;Ue2`2iM@/00P00000308QF1`80000000<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00F02`h>H2
0:f][@<0Uf0;00<0[Jf]0=>73P0000000P3CQ`h01@000000dhL>0:f][@3CQ`h0000000@0kiP@00<0
00000>nH403_V100103_V103000000P0o:0@00<000000?bP403lX100103lX102000000030:f][@3o
Y140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@0140o:0@100000030?bP40030:f][@3f
W0l0mY`?00<0mY`?0P0000090?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P8000000`3/
UPh00`2][Jd0fhX=0=^:3@02000000030=^:3@000000000000D0fhX=0`0000020;Ue2`050:f][@2i
M@/000000000002iM@/00P00000308QF1`030000002][Jd0[Jf]0440/>3V0@3oool005P0/>3V0P2]
[Jd309MP2`030:f][@3CQ`h000000080dhL>00@000000:f][@3CQ`h0dhL>0P0000020>nH40800000
203_V1000`2][Jd0o:0@0?bP40060?bP40030000003lX100o:0@00@0o:0@0P0000000`2][Jd0oj@A
0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004`3lX105000000030:f][@3fW0l0mY`?00<0mY`?
0P00000=0?JL3`@0[Jf]3@3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00<0fhX=0`0000060=^:3@04
0000002][Jd0^GD;00000080^GD;00<0[Jf]0;Ue2`0000000P2iM@/200000080R5H700<000000:f]
[@2][Jd0@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00H0[Jf]0=>73P000000dhL>0:f][@000003
0=>73P8000000P3_V102000000P0kiP@00<0[Jf]0?bP403lX1001P3lX1000`000000o:0@0?bP4004
0?bP408000000P2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@1@0000000`3fW0l000000000000?
0?JL3`030:f][@3/UPh0[Jf]0080[Jf]2P3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00/0fhX=0P00
00000`2][Jd0^GD;000000030;Ue2`040:f][@000000^GD;0;Ue2`8000000P28EPL00`000000[Jf]
0:f][@110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/01P2][Jd0dhL>0000002][Jd0dhL>000000<0
dhL>0P0000020>nH40030000003_V100kiP@00L0kiP@00<0[Jf]0?bP403lX1001P3lX1000`000000
o:0@0?bP40030?bP40040:f][@00000000000:f][AH0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`020?JL3`<000003`3fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]203/UPh01@00
0000k9H>0>bF3P3/UPh0[Jf]00/0fhX=0P0000000`2][Jd0^GD;000000040;Ue2`030000002][Jd0
^GD;008000000P28EPL00`000000[Jf]0:f][@110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2]
[Jd0dhL>000000020=>73P040000003CQ`h0dhL>0=>73P80000000<0kiP@0000000000002@3_V100
0`2][Jd0o:0@0?bP40060?bP40030000003lX100o:0@00<0[Jf]00@0o:0@000000000000[Jf]5P3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/
UPh30:f][@D0k9H>00D000000>bF3P3/UPh0k9H>0:f][@0:0=^:3@<0000000<0[Jf]0;Ue2`000000
102iM@/00`000000^GD;0:f][@020000000308QF1`00000000000080[Jf]@@2`h>H10?ooo`00F02`
h>H20:f][@<0Uf0;0P2][Jd010000000dhL>0000000000030=>73P80000000<0kiP@0000003_V100
2@3_V1000`2][Jd0o:0@0?bP40060?bP40030000002][Jd0[Jf]00@0o:0@0P0000000`2][Jd0oj@A
0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P070>bF3P<0[Jf]0P3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00/0fhX=0P0000000`2][Jd0
^GD;000000040;Ue2`030000002iM@/0^GD;0080000000<0R5H70000000000000P2][Je10;3PiP40
oooo001H0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h00`0000030=>73P030000
003_V100000000/0kiP@00<0[Jf]0?bP403lX100103lX1020:f][@030000003lX100o:0@00@0o:0@
0P0000000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]
00D000000>bF3P3/UPh0k9H>0:f][@0=0=^:3@040000002iM@/0^GD;000000<0^GD;00<000000;Ue
2`2iM@/00P0000000`28EPL0000008QF1`020:f][D40/>3V0@3oool005P0/>3V00@0[Jf]09MP2`2G
H0/0Uf0;0P2][Jd20=>73P<000000P3CQ`h00`2][Jd000000>nH400<0>nH40040:f][@3lX100o:0@
0?bP40<0[Jf]0P3lX1000`000000o:0@0?bP40040?bP4080000000<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@
0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>00D000000:f][@2][Jd0k9H>0:f]
[@0>0=^:3@030:f][@000000000000<0^GD;00<000000;Ue2`2iM@/00P0000000`28EPL0000008QF
1`020:f][D40/>3V0@3oool005P0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd20=>73P<000000P3C
Q`h00`000000kiP@0>nH400<0>nH40040:f][@3lX100[Jf]0:f][@D0o:0@00<000000?bP403lX100
103lX102000000030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>00<000000>bF3P3/UPh00`2][Jd=0=^:3@040:f]
[@2iM@/0000000000080^GD;00<000000;Ue2`2iM@/00P0000001@2][Jd00000045Yh@2][Jd00000
0440/>3V0@3oool005P0/>3V00H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd20=>73P8000000`3CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40<0[Jf]1`3lX1000`000000o:0@0?bP40020?bP408000000P3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:
0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P060000003/UPh0k9H>0>bF3P2][Jd0fhX=0P2][Jd;0=^:3@030:f]
[@2iM@/0^GD;0080^GD;0P0000020;Ue2`80000000D0[Jf]00000028EPL0[Jf]000000110;3PiP40
oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h00P0000030=>73P030:f]
[@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP40070?bP40030000003lX100o:0@00H0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA
2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>
00D000000>bF3P3/UPh0k9H>0:f][@030=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80
00000P2iM@/20000000508QF1`000000R5H70:f][@000000@@2`h>H10?ooo`00F02`h>H01P2][Jd0
Uf0;0:f][@2GH0/0@FWQ0:f][@80dhL>0P0000030=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd3
0>nH40030:f][@3lX100o:0@00@0o:0@0P0000090?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]
0>bF3P3/UPh02@3/UPh3000000<0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]
0;Ue2`2iM@/00`2iM@/00`000000^GD;0;Ue2`020000000308QF1`000000[Jf]00800000@@2`h>H1
0?ooo`00F02`h>H20:f][@80Uf0;00@0@FWQ0:f][@3CQ`h0dhL>0P0000030=>73P030:f][@3_V100
kiP@00D0kiP@0P2][Jd50>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0
^GD;00H0^GD;0P0000000`28EPL000000:f][@0200000440/>3V0@3oool005P0/>3V0P2][Jd209MP
2`04045Yh@2][Jd0dhL>0=>73P8000000`3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ46
0:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80000000<0R5H7
00000028EPL00P0000110;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/01011JN40[Jf]0=>73P3CQ`h2
000000<0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f]
[@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]
00<0fhX=0:f][@2iM@/0202iM@/010000000R5H700000028EPL200000440/>3V0@3oool005L0/>3V
0P2][Jd309MP2`040:f][@3CQ`h0dhL>0=>73P8000000`3CQ`h0102][Jd0kiP@0:f][@2][Jd;0>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@T0^GD;00@0[Jf]08QF
1`000000R5H70P0000110;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>73P3CQ`h2
000000<0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY144
0:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd3
0:f][@L0^GD;00<0[Jf]08QF1`28EPL00`0000110;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/0102]
[Jd0dhL>0=>73P3CQ`h200000080dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2][Jd60;Ue2`030:f][@28EPL0R5H700<00000@@2`
h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P0000020:f][@030=>73P2]
[Jd0kiP@00`0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]h`2`
h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2i
M@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0300000440/>3V0@3oool005L0/>3V0P2]
[Jd309MP2`060:f][@3CQ`h0dhL>0=>73P000000[Jf]0`3CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0
k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0
^GD;00@0[Jf]08QF1`28EPL0R5H70P0000110;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/01@2][Jd0
dhL>0=>73P3CQ`h0000000@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP
40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue
2`040:f][@2iM@/0^GD;0:f][@<0R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H20:f]
[@<0Uf0;00D0[Jf]0=>73P2][Jd0[Jf]000000040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/01@2iM@/30:f][@<0R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H20:f]
[@<0Uf0;00D0@FWQ0:f][@3CQ`h0dhL>000000040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28
EPL200000400/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/01@2][Jd0dhL>0=>73P3C
Q`h0000000@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i
/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00L0^GD;0P2][Jd308QF1`800000@02`h>H10?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`2G
H0/20:f][@<0dhL>00<000000=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`h>H30:f][@l0`kfk0`2]
[Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H70P00
00100;3PiP40oooo001G0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2]
[JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2]
[Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@00
0000/>3V03l0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd80=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V
00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0
0P28EPL00`2][Jd000000;3PiP0o0;3PiP40oooo001G0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00L0
[Jf]08QF1`28EPL0[Jf]08QF1`2][Jd000000400/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2][Jd0
0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V
0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00
E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]
00@0Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@000000/>3V03l0/>3V0@3oool005L0/>3V
00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080
[Jf]00D0@FWQ0:BNS`2TWXl0Y9j?0:f][@040;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f]
[@H0_[Vh00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0000002`h>H0?`2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00T0dhL>00@0[Jf]0>nH402][Jd0[Jf]0P2TWXl01@11JN40Y9j?0:BNS`2TWXl0[Jf]00H0/J^M
0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]1`2n^KP2045Yh@030;B`/@11JN40];2a0080
[Jf]00<0fhX=0:f][@2iM@/02@2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000400/>3V0@3oool0
05L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P80[Jf]0P11JN420:BNS`05045Yh@2TWXl0
Y9j?0:BNS`2][Jd0202aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]202n^KP2045Yh@030:f]
[@2d/;40@FWQ00<0];2a0P2][Jd:0;Ue2`060:f][@28EPL0R5H708QF1`2][Jd00000@02`h>H10?oo
o`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0:BNS`2TWXl00P11JN400`2T
WXl0@FWQ045Yh@030:BNS`030:f][@2aZid0/J^M00P0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m
^`<0[Jf]2P2n^KP2045Yh@030:f][@2d/;40@FWQ00D0];2a0P2][Jd80;Ue2`060:f][@28EPL0R5H7
08QF1`2][Jd00000@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2]
[Jd30:BNS`80@FWQ00<0Y9j?045Yh@11JN400`2TWXl00`2][Jd0/J^M0;6[W@03045Yh@L0/J^M0`2]
[Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m
/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP02P2n^KP00`11JN40_[Vh
0:f][@020;B`/@03045Yh@2d/;40];2a00@0];2a00<0[Jf]0;Ue2`2iM@/01@2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80
[Jf]00@0@FWQ0:BNS`2TWXl0Y9j?0P11JN400`2TWXl0@FWQ045Yh@020:BNS`040:f][@2aZid0/J^M
045Yh@80/J^M00@0@FWQ0;6[W@11JN40@FWQ1@2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202]
[Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP4045Yh@<0_[Vh00@0
@FWQ0;ji^02n^KP0[Jf]0P11JN470;B`/@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00
/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P040:f][@2:QGD0RXEe045Y
h@<0Y9j?0P11JN400`2TWXl0@FWQ045Yh@020:BNS`040:f][@2aZid0/J^M045Yh@<0/J^M0`11JN45
0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@11JN40@FWQ0080@FWQ3P2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/4
0:f][@L0`kfk00D0[Jf]0;ji^02n^KP0_[Vh045Yh@030;ji^005045Yh@2n^KP0_[Vh0;ji^011JN40
0P2n^KP00`2][Jd0@FWQ0;B`/@020;B`/@04045Yh@2d/;40];2a0;B`/@D0[Jf]0`2iM@/0102][Jd0
R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>7
3P050:f][@11JN40RXEe08Z5M@11JN400P2][Jd00`2TWXl0@FWQ0:BNS`03045Yh@80Y9j?00<0[Jf]
0;6[W@11JN40102aZid3045Yh@80/J^M0`11JN400`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH0
0`2][Jd0_[N/0;jg[004045Yh@`0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@36`;`2045Yh@T0a/2l00<0[Jf]
0<>m^`2][Jd00P2][Jd;0<>m^`050:f][@2n^KP0_[Vh0;ji^011JN40102n^KP01011JN40_[Vh0;ji
^011JN420;ji^080@FWQ0`2d/;401011JN40];2a0;B`/@2][Jd20;B`/@040:f][@2OVj00Wi^P0:f]
[@80^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;
09MP2`2][Jd0dhL>0P2][Jd01@2:QGD0@FWQ08Z5M@2:QGD0@FWQ0080Y9j?00<0[Jf]045Yh@2TWXl0
0`11JN420:BNS`030:f][@2aZid0@FWQ00D0/J^M0P11JN430;6[W@@0@FWQ2P2i/ZH40:f][@040;Vb
YP2][Jd0_[N/0;jg[080@FWQ3P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_080@FWQ2P36`;`30:f][@`0
`kfk0P11JN401@2][Jd0_[Vh0;ji^02n^KP0@FWQ00T0_[Vh0P11JN440;B`/@03045Yh@2][Jd0[Jf]
00<0];2a00@0[Jf]09nKX02OVj00Wi^P0`2][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool0
05H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/20:f][@<0RXEe00@0@FWQ08Z5M@2:QGD0@FWQ0`2TWXl0
2P11JN40[Jf]045Yh@11JN40Y9j?045Yh@2TWXl0[Jf]0;6[W@11JN450;6[W@80@FWQ0`2aZid2045Y
h@030:f][@2i/ZH0^K:V00d0^K:V0`2][Jd00`2n]j`0@FWQ045Yh@0>0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0a/2l0<K0_0@0@FWQ1P36`;`40:f][@030<K0_02][Jd0
`kfk00X0`kfk0`11JN401@33_K/0[Jf]0;ji^02n^KP0@FWQ00X0_[Vh0P11JN430;B`/@030:f][@11
JN40];2a00@0];2a00<0[Jf]09nKX02OVj000P2OVj000`11JN40[Jf]08QF1`0308QF1`030:f][@2`
h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe08Z5M@03
08Z5M@03045Yh@2:QGD0@FWQ0080Y9j?0P11JN401`2TWXl0@FWQ045Yh@2TWXl0@FWQ0:BNS`2][Jd0
0P11JN450;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN400`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0[Jf]0080@FWQ00<0[Jf]0;jg[02n]j`02`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_080@FWQ
0P36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/01@33_K/3045Yh@<0`kfk00<0@FWQ0<>m^`2][Jd0
0P2n^KP00`11JN40_[Vh0;ji^0070;ji^080@FWQ00H0[Jf]0;B`/@2d/;40[Jf]0;B`/@11JN450;B`
/@030:f][@2OVj00Wi^P0080Wi^P0P11JN401@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3oool0
05H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd608Z5M@05045Yh@2][Jd0Y9j?0:BNS`11JN400P2T
WXl2045Yh@040:f][@11JN40Y9j?0:f][@80@FWQ1@2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ
00<0[Jf]0;VbYP2i/ZH01`2i/ZH00`11JN40^K:V0;VbYP040;VbYP030:f][@2n]j`0_[N/0080@FWQ
00<0_[N/0:f][@2][Jd00P2][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<0
5033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l0P11JN420:f][@T0a/2l
00<0[Jf]0<>m^`33_K/00`33_K/3045Yh@D0`kfk00H0@FWQ0<>m^`33_K/0[Jf]0;ji^011JN490;ji
^080@FWQ0`2][Jd20;B`/@03045Yh@2d/;40];2a00<0];2a00<0[Jf]09nKX02OVj000P2OVj02045Y
h@050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/2
0:f][@L0RXEe00@0[Jf]0:BNS`2TWXl0@FWQ0P2TWXl2045Yh@040:BNS`11JN40[Jf]0:f][@80@FWQ
1@2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ00<0[Jf]0;VbYP2i/ZH01@2i/ZH2045Yh@030;Vb
YP11JN40@FWQ00@0^K:V00<0[Jf]0;jg[02n]j`00P11JN450;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`
0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l
0:f][@030:f][@80@FWQ2`36`;`00`2][Jd0@FWQ045Yh@02045Yh@<0`kfk00<0@FWQ0<>m^`33_K/0
0`33_K/01011JN40`kfk0<>m^`2][Jd2045Yh@P0_[Vh0P11JN420:f][@050;B`/@11JN40];2a0;B`
/@11JN401@2d/;400`2][Jd0Wi^P09nKX00209nKX0<0@FWQ00@0[Jf]08QF1`28EPL0[Jf]@02`h>H1
0?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`030:f][@L0RXEe00@0[Jf]0:BNS`11JN40@FWQ0P2TWXl0
1P11JN40Y9j?0:BNS`11JN40Y9j?0:f][@80@FWQ1@2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ
00<0[Jf]0;VbYP2i/ZH01@2i/ZH00`11JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V0080@FWQ
0P2n]j`2045Yh@T0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`03`37`K`40:f][@@0a/2l0P11JN4:0<K0_0@0@FWQ1@33_K/00`11JN40`kfk
0<>m^`030<>m^`04045Yh@33_K/0`kfk0:f][@80@FWQ202n^KP2045Yh@040;ji^02][Jd0@FWQ045Y
h@80];2a00<0@FWQ0;B`/@2d/;400`2d/;400`2][Jd0Wi^P09nKX00209nKX0<0@FWQ0P2][Jd00`28
EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]1P2:QGD0102]
[Jd0Y9j?0:BNS`2TWXl2045Yh@070:BNS`11JN40Y9j?0:BNS`11JN40Y9j?0:f][@02045Yh@040:f]
[@2aZid0/J^M0;6[W@80@FWQ102aZid2045Yh@030:f][@2i/ZH0^K:V00D0^K:V00<0@FWQ0;VbYP2i
/ZH00P2i/ZH01@11JN40^K:V045Yh@11JN40[Jf]0080_[N/0P11JN4=0;jg[0@0[Jf]4@31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l
00<0a/2l0P11JN4;0<K0_0030:f][@11JN40@FWQ00D0`kfk00<0@FWQ0<>m^`33_K/00`33_K/01011
JN40`kfk0<>m^`2][Jd2045Yh@H0_[Vh0P2][Jd2045Yh@040;ji^02][Jd0@FWQ045Yh@80];2a0P11
JN440;B`/@030:f][@2OVj00Wi^P0080Wi^P0P11JN400`2OVj00[Jf]071^N@020:f][D00/>3V0@3o
ool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl0102TWXl0
1P11JN40Y9j?0:BNS`11JN40Y9j?0:f][@80@FWQ00D0/J^M0:f][@2][Jd0[Jf]0;6[W@03045Yh@80
/J^M0P11JN400`2][Jd0^K:V0;VbYP050;VbYP03045Yh@2i/ZH0^K:V00<0^K:V0P11JN40102i/ZH0
[Jf]0;jg[02n]j`2045Yh@040;jg[011JN40@FWQ045Yh@X0_[N/00<0[Jf]0<6j/031^[001@2][Jd<
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]
0<K0_036`;`00`36`;`2045Yh@040<K0_011JN40@FWQ045Yh@L0a/2l00<0[Jf]045Yh@11JN401@33
_K/00`11JN40`kfk0<>m^`030<>m^`04045Yh@33_K/0`kfk0:f][@80@FWQ0`2n^KP00`2][Jd0@FWQ
0:f][@020;ji^004045Yh@2n^KP0_[Vh0:f][@80@FWQ0P2d/;42045Yh@@0];2a00<0[Jf]09nKX02O
Vj000P2OVj001@11JN40Wi^P0:f][@2][Jd0L6ii0080[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0
Hf1C0P2][Jd508Z5M@030:f][@2TWXl0Y9j?00@0Y9j?00H0@FWQ0:BNS`2TWXl0@FWQ0:BNS`2][Jd2
045Yh@@0/J^M0P2][Jd40;6[W@03045Yh@2aZid0[Jf]00L0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2
045Yh@040;VbYP2][Jd0_[N/0;jg[0<0@FWQ0P2n]j`2045Yh@T0_[N/00<0[Jf]0<6j/031^[001@31
^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0
[Jf]0<K0_036`;`00`36`;`3045Yh@<0a/2l0P11JN450<K0_0030:f][@11JN40@FWQ00D0`kfk00<0
@FWQ0<>m^`33_K/00`33_K/01011JN40`kfk0<>m^`2][Jd2045Yh@040;ji^02][Jd0[Jf]0;ji^080
@FWQ0P2n^KP01011JN40_[Vh0;ji^02][Jd2045Yh@80];2a0P11JN440;B`/@030:f][@2OVj00Wi^P
00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1S
H5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0P11JN40102TWXl0
[Jf]045Yh@11JN460;6[W@<0[Jf]00@0/J^M045Yh@11JN40[Jf]1`2i/ZH00`11JN40^K:V0;VbYP03
0;VbYP80@FWQ00@0[Jf]0;jg[02n]j`0_[N/0P11JN440;jg[080@FWQ1@2n]j`2045Yh@030;jg[02]
[Jd0`KZ`00/0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdA0<O1_0040:f][@36
`;`0@FWQ045Yh@80a/2l0`11JN430<K0_080@FWQ1@36`;`00`2][Jd0@FWQ045Yh@050<>m^`80@FWQ
1033_K/2045Yh@050<>m^`2][Jd0@FWQ045Yh@2][Jd00`2n^KP2045Yh@<0_[Vh00<0@FWQ0;ji^011
JN40102d/;42045Yh@@0];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^
N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe0:f]
[@<0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl2045Yh@030:f][@11JN40@FWQ00T0/J^M00@0[Jf]045Y
h@11JN40[Jf]1`2i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ00@0[Jf]0;jg[02n]j`0_[N/0P11
JN440;jg[080@FWQ1`2n]j`3045YhA00`KZ`202][Jd@0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1
_00>0<O1_005045Yh@37`K`0al6l0:f][@11JN401036`;`3045Yh@@0a/2l0P11JN440<K0_0030:f]
[@11JN40@FWQ00D0`kfk0P11JN440<>m^`80@FWQ0`2][Jd00`11JN40_[Vh0;ji^0030;ji^003045Y
h@2n^KP0_[Vh0080_[Vh00<0@FWQ0:f][@2d/;400`2d/;42045Yh@@0];2a00<0[Jf]09nKX02OVj00
0P2][Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@11JN40@FWQ00X0/J^M0P11JN420:f][@H0^K:V0P11JN440;VbYP80@FWQ00D0[Jf]0;jg[02n]j`0
_[N/045Yh@060;jg[080@FWQ1P2n]j`00`11JN40[Jf]0<6j/0020<6j/0<0@FWQ3@31^[000`2][Jd0
`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00`0al6l0P11JN401@37
`K`0@FWQ045Yh@2][Jd0@FWQ00@0a/2l0P11JN450<K0_080@FWQ1036`;`00`2][Jd0@FWQ045Yh@05
0<>m^`80@FWQ0`33_K/01`2][Jd0@FWQ045Yh@33_K/0[Jf]0;ji^011JN40102n^KP00`11JN40_[Vh
0;ji^0040;ji^0030:f][@2d/;40];2a0080];2a0P11JN440;B`/@030:f][@2OVj00[Jf]00D0Wi^P
00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0
[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@11JN40@FWQ00X0/J^M0P11
JN400`2][Jd0^K:V0:f][@020:f][@@0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045Yh@050:f][@2n
]j`0_[N/0;jg[011JN401P2n]j`2045Yh@H0_[N/00<0@FWQ0:f][@31^[001031^[04045Yh@80`KZ`
0`11JN450<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k
2@2][JdB0<S1^`030:f][@37`K`0al6l00X0al6l0P11JN440<O1_0<0@FWQ1036`;`2045Yh@H0a/2l
0P11JN430<K0_0030:f][@11JN40@FWQ00D0`kfk0P11JN430:f][@060<>m^`11JN40@FWQ0<>m^`2]
[Jd0_[Vh0P11JN430;ji^003045Yh@2n^KP0_[Vh00@0_[Vh00<0[Jf]0;B`/@2d/;400P2d/;42045Y
h@@0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`030:f][@11JN40@FWQ00X0
/J^M0P11JN400`2][Jd0^K:V0;VbYP020;VbYP<0[Jf]0P2i/ZH01011JN40^K:V0;VbYP2i/ZH2045Y
h@050:f][@2n]j`0_[N/0;jg[011JN401P2n]j`2045Yh@H0_[N/00<0@FWQ0:f][@31^[001031^[02
045Yh@H0`KZ`1011JN420<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<
0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/4
045Yh@T0al6l00<0@FWQ0<O1_037`K`01037`K`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`01036`;`2
045Yh@<0a/2l00<0[Jf]045Yh@11JN401@33_K/2045Yh@@0`kfk0P11JN401033_K/0[Jf]0;ji^02n
^KP2045Yh@030;ji^011JN40_[Vh00H0_[Vh00<0[Jf]0;B`/@2d/;400P2d/;42045Yh@@0];2a00<0
[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]045Yh@11JN402P2aZid2045Yh@040:f][@2i/ZH0^K:V045Yh@@0^K:V0`2][Jd2045Yh@040;Vb
YP11JN40@FWQ0:f][@<0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`00`11JN40_[N/0;jg[0040;jg[003
045Yh@31^[00`KZ`00@0`KZ`0P11JN460<6j/080@FWQ1031^[00102][Jd0`kfc0<>m/`33_K<2045Y
hA00`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0<0<S1^`03045Yh@38`K/0b<6k
0080b<6k1011JN4:0<O1_080@FWQ1P37`K`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`01036`;`2045Y
h@<0a/2l00<0[Jf]045Yh@11JN400P33_K/30:f][@80@FWQ1033_K/2045Yh@030<>m^`2][Jd0_[Vh
0080_[Vh0P11JN480;ji^0030:f][@2d/;40];2a0080];2a00@0@FWQ0;B`/@2d/;40];2a0`2][Jd7
09nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1S
H5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0@FWQ00D0/J^M00T0@FWQ0;6[W@2aZid0@FWQ
0;6[W@11JN40/J^M045Yh@2i/ZH00P11JN480;VbYP050:f][@11JN40@FWQ045Yh@2][Jd00`2n]j`0
0`11JN40_[N/0;jg[0050;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0<6j/031^[001031^[02
045Yh@H0`KZ`0P11JN440<6j/0030:f][@33_K<0@FWQ0080@FWQ00<0`kfc045Yh@33_K<03P33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng<02][Jd;0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01P38`K/3045Yh@<0b<6k00<0@FWQ0<S1^`38`K/01038`K/2
045Yh@X0al6l0P11JN460<O1_080@FWQ1@36`;`00`11JN40a/2l0<K0_0040<K0_080@FWQ0`36`;`0
0`2][Jd0@FWQ045Yh@020:f][@<0`kfk0P11JN440<>m^`80@FWQ00<0`kfk0:f][@2n^KP0302n^KP0
0`2][Jd0];2a0;B`/@020;B`/@04045Yh@2d/;40];2a0:f][@80];2a00<0[Jf]09nKX02OVj001@2O
Vj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C
0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M045Yh@050;6[W@04045Y
h@2aZid0/J^M0;6[W@80@FWQ00D0/J^M045Yh@2i/ZH0^K:V045Yh@040;VbYP80@FWQ102i/ZH2045Y
h@80[Jf]0P2n]j`00`11JN40_[N/0;jg[0050;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0<6j
/031^[001031^[02045Yh@H0`KZ`0P11JN440<6j/0030:f][@11JN40@FWQ00@0`kfc0P11JN460<>m
/`03045Yh@33_K<0`kfc0080@FWQ0P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0B0<O1^P0400000037`KX0al6j
0:f][AH0b<6k00<0[Jf]0<S1^`38`K/01@38`K/01011JN40b<6k0<S1^`38`K/2045Yh@030<S1^`11
JN40b<6k00D0b<6k0P11JN4:0<O1_080@FWQ1P37`K`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`01036
`;`2045Yh@040<K0_02][Jd0[Jf]0:f][@80@FWQ1@33_K/2045Yh@@0`kfk0P11JN400`33_K/0[Jf]
0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0
RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f][@2aZid0@FWQ00D0
/J^M00<0@FWQ0;6[W@2aZid0102aZid0102][Jd0@FWQ0;VbYP11JN440;VbYP80@FWQ102i/ZH2045Y
h@060:f][@2n]j`0[Jf]0:f][@11JN40[Jf]1P2n]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@31
^[00`KZ`00@0`KZ`0P11JN460<6j/080@FWQ1031^[000`2][Jd0@FWQ045Yh@060<>m/`03045Yh@33
_K<0`kfc00<0`kfc00<0@FWQ0<>m/`11JN400P33_K<3045Yh@L0aKje00<0@FWQ0<Fn]@35_[D03035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`090<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/00P38
`K/00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ1@38`K/2045Yh@H0b<6k0P11JN4;0<O1_003045Yh@37
`K`0al6l00@0al6l0P11JN450<K0_003045Yh@36`;`0a/2l0080a/2l0P2][Jd00`11JN40[Jf]0:f]
[@020<K0_0030:f][@33_K/0@FWQ00D0`kfk00<0@FWQ0<>m^`33_K/00P33_K/3045Yh@030<>m^`2]
[Jd0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@03
0:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`040:f][@2aZid0/J^M045Yh@@0/J^M00<0@FWQ0;6[
W@2aZid0102aZid0102][Jd0^K:V045Yh@11JN450;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0@FWQ
0;VbYP2][Jd00`2n]j`00`11JN40_[N/0:f][@030:f][@80_[N/00<0@FWQ0;jg[02n]j`0102n]j`0
0`11JN40`KZ`0<6j/0040<6j/080@FWQ1P31^[02045Yh@@0`KZ`00<0[Jf]045Yh@11JN401P33_K<0
0`11JN40`kfc0<>m/`030<>m/`80@FWQ1@33_K<00`2][Jd0@FWQ0<Fn]@040<Fn]@80@FWQ3P35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
102][Jd0b<6k0<S1^`38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1
^`020<S1^`030:f][@38`K/0b<6k00<0b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11
JN4;0<O1_003045Yh@37`K`0al6l00@0al6l0P11JN450<K0_003045Yh@2][Jd0[Jf]0080[Jf]0P36
`;`00`11JN40a/2l0<K0_0020<K0_0030:f][@33_K/0@FWQ00D0`kfk00<0@FWQ0<>m^`33_K/01P33
_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj00
1@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe
00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00@0[Jf]0;6[W@2aZid0@FWQ102aZid00`11JN40
/J^M0;6[W@030;6[W@030:f][@2i/ZH0^K:V00L0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`11JN40
^K:V0:f][@030;jg[003045Yh@2n]j`0_[N/00<0_[N/0P2][Jd00`11JN40[Jf]0;jg[0040;jg[003
045Yh@31^[00`KZ`00@0`KZ`0P11JN460<6j/080@FWQ1031^[02045Yh@P0`kfc00<0@FWQ0<>m/`33
_K<00P33_K<00`11JN40`kfc0<>m/`040<>m/`030:f][@35_[D0@FWQ00@0aKje00<0@FWQ0<Fn]@11
JN403@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h1`11JN4<0<O1^P@0
@FWQ00<0al6j0:f][@38`K/00P11JN480<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN430<S1^`03
0:f][@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`040<S1^`80
@FWQ2`37`K`2045Yh@D0al6l0P11JN400`36`;`0[Jf]0:f][@020:f][@03045Yh@36`;`0a/2l00@0
a/2l00<0@FWQ0<K0_036`;`00P36`;`0102][Jd0`kfk045Yh@11JN420<>m^`80@FWQ2@33_K/00`2]
[Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]
0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0
[Jf]0P2aZid01011JN40/J^M0;6[W@2aZid2045Yh@D0/J^M00<0[Jf]0;VbYP2i/ZH0202i/ZH01011
JN40^K:V0;VbYP11JN420;VbYP040:f][@2n]j`0_[N/0;jg[080@FWQ1@2n]j`2045Yh@030;jg[02]
[Jd0[Jf]0080[Jf]00<0_[N/045Yh@31^[001@31^[02045Yh@H0`KZ`0P11JN440<6j/080@FWQ3@33
_K<00`11JN40`kfc0<>m/`040<>m/`030:f][@35_[D0@FWQ00D0aKje00<0@FWQ0<Fn]@35_[D03035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00<0al6h2P11JN470<O1^0030:f][@37
`KX0al6j0080@FWQ3037`KX3045Yh@<0al6j0P11JN400`38`K/0@FWQ045Yh@070<S1^`03045Yh@38
`K/0@FWQ00<0b<6k0`11JN430<S1^`030:f][@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01P38
`K/2045Yh@D0b<6k0P11JN4<0<O1_0P0@FWQ00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l0<K0
_0030<K0_080@FWQ1036`;`0102][Jd0`kfk045Yh@33_K/2045Yh@/0`kfk00<0[Jf]0;ji^02n^KP0
2P2n^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo
001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]0P2aZid3045Yh@030;6[W@11
JN40/J^M00@0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH2045Yh@<0^K:V00@0[Jf]0;jg[02n]j`0_[N/
0P11JN450;jg[080@FWQ1@2n]j`00`2][Jd0@FWQ0:f][@020:f][@<0`KZ`0P11JN460<6j/080@FWQ
1031^[02045YhA@0`kfc00<0[Jf]0<Fn]@11JN405035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h00D0al6h0P11JN450<O1^0<0@FWQ1@37`KP00`2][Jd0al6j0<O1^P02045Yh@`0al6j
0P11JN450<O1^P030:f][@11JN40@FWQ00P0b<6k0`11JN430<S1^`<0@FWQ0`38`K/00`2][Jd0b<6k
0<S1^`020<S1^`80@FWQ2038`K/2045Yh@D0b<6k0P11JN4;0<O1_0D0[Jf]0P37`K`2045Yh@D0a/2l
00<0@FWQ0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0030<K0_0030:f][@33_K/0@FWQ00h0`kfk
00<0[Jf]0;ji^02n^KP0202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj00
1@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]0;6[W@2][Jd00P2][Jd30;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH01`2][Jd0_[N/045Yh@2n]j`0@FWQ0;jg[011JN400`2n]j`2045Yh@H0_[N/0P11JN430<6j/0<0
[Jf]0P11JN420:f][@@0`KZ`0P11JN440<6j/080@FWQ5033_K<00`2][Jd0@FWQ045Yh@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@L0al6h00<0@FWQ0<O1^037
`KP00`37`KP00`2][Jd0al6j0<O1^P02045Yh@`0al6j0P11JN450<O1^P030:f][@38`K/0@FWQ00P0
b<6k0`11JN430<S1^`<0@FWQ0`38`K/00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ2038`K/2045Yh@D0
b<6k0P11JN460<O1_0D0[Jf]1`37`K`00`11JN40a/2l0<K0_0040<K0_003045Yh@36`;`0a/2l0080
a/2l0P11JN450<K0_0030:f][@33_K/0@FWQ00h0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00
FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
0P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[002045Yh@80_[N/
00@0@FWQ0;jg[011JN40@FWQ1`2n]j`2045Yh@H0`KZ`0P11JN420<6j/0@0[Jf]0P11JN40102][Jd0
`KZ`0<6j/031^[02045YhA<0`kfc0P11JN400`35_[D0@FWQ0<Fn]@0C0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@P0al6h00<0@FWQ0<O1^037`KP00`37`KP0102]
[Jd0al6j045Yh@11JN4<0<O1^P80@FWQ1@37`KX00`2][Jd0b<6k045Yh@080<S1^`<0@FWQ0`38`K/2
045Yh@050<S1^`11JN40b<6k0<S1^`2][Jd01038`K/00`11JN40b<6k0<S1^`070<S1^`@0@FWQ0`38
`K/2045Yh@030<O1_02][Jd0[Jf]00<0[Jf]3037`K`00`11JN40a/2l0<K0_0040<K0_080@FWQ0P36
`;`2045Yh@H0a/2l00<0[Jf]0<>m^`11JN403033_K/00`11JN40`kfk0:f][@050;ji^0<0[Jf]1@2n
^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]
0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[005
0;jg[080@FWQ202n]j`2045Yh@H0`KZ`0P11JN460<6j/080@FWQ00@0`KZ`0:f][@2][Jd0[Jf]0P11
JN420:f][@l0`kfc0P11JN400`33_K<0[Jf]045Yh@0E0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP01@37`KP2045Yh@P0al6h00<0@FWQ0<O1^037`KP00`37`KP0102][Jd0al6j045Y
h@11JN4<0<O1^P80@FWQ1@37`KX00`2][Jd0b<6k045Yh@080<S1^`<0@FWQ0`38`K/01011JN40b<6k
0<S1^`11JN420<S1^`040:f][@38`K/0b<6k0<S1^`80@FWQ1`38`K/4045Yh@80b<6k0`2][Jd2045Y
h@030:f][@37`K`0al6l00P0al6l0P11JN450<O1_003045Yh@36`;`0a/2l00@0a/2l00@0@FWQ0<K0
_011JN40@FWQ2@36`;`00`2][Jd0@FWQ0<>m^`0:0<>m^`80@FWQ00<0`kfk0:f][@2n^KP00P2n^KP2
0:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0
/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/
00l0_[N/0`11JN440<6j/080@FWQ1`31^[02045Yh@@0`KZ`00@0[Jf]045Yh@33_K<0`kfc1@2][Jd0
0`11JN40[Jf]0<>m/`060<>m/`03045Yh@33_K<0@FWQ0080@FWQ1`35_[D00`11JN40aKje0<Fn]@0<
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@P0al6h0P11JN44
0<O1^0040:f][@37`KX0@FWQ045Yh@`0al6j0P11JN450<O1^P030:f][@38`K/0@FWQ00P0b<6k00<0
@FWQ0<S1^`11JN400P38`K/2045Yh@80b<6k00@0@FWQ0<S1^`38`K/0[Jf]0`38`K/2045Yh@H0b<6k
1`2][Jd30<S1^`<0@FWQ1037`K`00`11JN40al6l0<O1_0030<O1_080@FWQ1@37`K`00`11JN40a/2l
0<K0_0020<K0_080@FWQ3@36`;`00`2][Jd0@FWQ0<>m^`0;0<>m^`04045Yh@33_K/0[Jf]0;ji^080
[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`
h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`2045Yh@030<6j
/011JN40`KZ`0080`KZ`0P11JN470<6j/080@FWQ1031^[000`2][Jd0@FWQ0<>m/`050<>m/`80@FWQ
00<0`kfc0:f][@2][Jd00`2][Jd4045Yh@80`kfc00<0[Jf]0<Fn]@35_[D01@35_[D00`11JN40aKje
0<Fn]@0<0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@P0al6h
0P11JN440<O1^0040:f][@37`KX0@FWQ045Yh@d0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0
b<6k045Yh@070<S1^`80@FWQ0P38`K/01011JN40b<6k045Yh@11JN420<S1^`04045Yh@38`K/0b<6k
0:f][@<0b<6k0P11JN460:f][@X0b<6k0`11JN430<O1_003045Yh@37`K`0@FWQ00D0al6l00@0@FWQ
0<O1_037`K`0al6l0P11JN400`2][Jd0a/2l0<K0_00A0<K0_0030:f][@11JN40`kfk00`0`kfk0`2]
[Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N
0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]
0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/00l0_[N/0P11JN420<6j/0@0@FWQ2031^[02
045Yh@@0`KZ`00<0[Jf]045Yh@33_K<01@33_K<00`11JN40`kfc045Yh@040<>m/`<0@FWQ00<0`kfc
0:f][@2][Jd01`2][Jd20<Fn]@03045Yh@35_[D0aKje00`0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^0050<O1^080@FWQ2037`KP2045Yh@@0al6h00@0[Jf]0<O1^P11JN40@FWQ3@37
`KX00`11JN40al6j0<O1^P030<O1^P030:f][@38`K/0@FWQ00L0b<6k0P11JN420<S1^`04045Yh@38
`K/0@FWQ045Yh@<0[Jf]00<0@FWQ0:f][@2][Jd00`2][Jd2045YhA00b<6k0`11JN440<O1_080@FWQ
1P37`K`3045Yh@80al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0@FWQ0<>m^`090<>m^`<0[Jf]
00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V
0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i
/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/00l0_[N/0P11JN4>0<6j/080@FWQ1031
^[000`2][Jd0`kfc045Yh@060<>m/`80@FWQ1033_K<00`11JN40`kfc0<>m/`040<>m/`030:f][@35
_[D0@FWQ00<0aKje0P2][Jd00`11JN40[Jf]0:f][@070:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^0050<O1^080@FWQ2@37`KP2045Yh@<0al6h00@0[Jf]0<O1^P11JN40@FWQ
3P37`KX4045Yh@040<O1^P2][Jd0b<6k045Yh@<0b<6k102][Jd2045Yh@80[Jf]00@0@FWQ0:f][@11
JN40@FWQ0`38`K/00`11JN40b<6k0:f][@030<S1^`80@FWQ4038`K/2045Yh@030<O1_011JN40al6l
0080al6l00<0@FWQ0<O1_037`K`02`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@11JN40`kfk
00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f]
[DT0/>3V0@3oool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH01P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`2045Yh@`0`KZ`1011JN440<6j/004
0:f][@33_K<0@FWQ045Yh@D0`kfc00<0@FWQ0<>m/`33_K<00`33_K<00`11JN40`kfc0<>m/`040<>m
/`030:f][@11JN40@FWQ00D0aKje00<0@FWQ0<Fn]@35_[D01`35_[DA0:f][@`0a[ng00<0[Jf]0<O1
^037`KP01@37`KP2045Yh@T0al6h0P11JN430<O1^0040:f][@37`KX0@FWQ045Yh@P0al6j2P2][Jd4
045Yh@<0[Jf]1038`K/2045Yh@80b<6k00@0@FWQ0<S1^`11JN40@FWQ0`38`K/00`11JN40b<6k0:f]
[@030<S1^`80@FWQ4038`K/2045Yh@80al6l0`11JN4>0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]045Yh@33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`
/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00@
0;jg[080@FWQ5031^[000`2][Jd0`kfc0<>m/`03045Yh@80`kfc00<0@FWQ0<>m/`33_K<01033_K<0
0`11JN40`kfc0<>m/`040<>m/`030:f][@11JN40@FWQ00D0aKje00<0@FWQ0<Fn]@35_[D03035_[D0
0`2][Jd0a[ng0<Jo]`090<Jo]a@0[Jf]0P11JN490:f][@80@FWQ1@2][Jd2045Yh@P0[Jf]2`37`KX0
0`2][Jd0b<6k045Yh@070<S1^`80@FWQ0P38`K/00`11JN40b<6k045Yh@040<S1^`03045Yh@38`K/0
[Jf]00<0b<6k0P11JN4>0<S1^`80@FWQ00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?
0<K0_080@FWQ00@0`kfk0:f][@2][Jd0[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d
/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][Jd@0;jg[080@FWQ5031^[000`2][Jd0`kfc0<>m/`03
0<>m/`80@FWQ2033_K<00`11JN40`kfc0<>m/`030<>m/`<0@FWQ1@35_[D00`11JN40aKje0<Fn]@0<
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@T0al6h0P11JN43
0<O1^0040:f][@37`KX0@FWQ045Yh@d0al6j00<0@FWQ0<O1^P0000000`37`KX00`2][Jd0b<6k045Y
h@070<S1^`03045Yh@38`K/0b<6k0080b<6k0P11JN450<S1^`03045Yh@2][Jd0b<6k0080b<6k0P11
JN4@0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03P36`;`40:f][@h0`kfk00<0
[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0/>3V0@3o
ool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0:f][@030:f][@`0_[N/0P11JN4D0<6j/0030:f][@33_K<0`kfc00h0`kfc1@11JN40
0`2][Jd0aKje045Yh@040<Fn]@80@FWQ3P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h00D0al6h0P11JN490<O1^080@FWQ0`37`KP0102][Jd0al6j045Yh@11JN450<O1^P03045Yh@37
`KX0al6j00D0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k045Yh@060<S1^`80@FWQ1038
`K/2045Yh@D0b<6k0`11JN420<S1^`80@FWQ2P38`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33
_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W
0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`00`2n]j`40:f][@P0_[N/0P11JN4D0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@11JN401035_[D3045Yh@d0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^005
0<O1^080@FWQ2@37`KP2045Yh@<0al6h00<0[Jf]0<O1^P11JN400P11JN430<O1^P03045Yh@37`KX0
@FWQ00H0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0@FWQ0<S1^`060<S1^`@0@FWQ0P38`K/2
045Yh@80b<6k0`11JN400`38`K/0[Jf]0<S1^`030<S1^`80@FWQ2@38`K/00`11JN40b<6k0<S1^`03
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]
0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`
h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd20;jg[0@0@FWQ5031^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00@0aKje0`11JN4=0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP01@37`KP2045Yh@T0al6h0P11JN430<O1^0060:f][@37`KX0@FWQ045Yh@37`KX0@FWQ
0`37`KX2045Yh@L0al6j1P11JN460<S1^`@0@FWQ3038`K/00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ
2038`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050:f][@/0a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][E80
/>3V0@3oool006/0/>3V0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
2`2n]j`40:f][@030;jg[02][Jd0`KZ`00d0`KZ`00<0@FWQ0<6j/031^[000`31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00@0aKje0`11JN4=0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP01@37`KP2045Yh@T0al6h0P11JN420<O1^0D0@FWQ0P37`KX4045Yh@d0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ2038`K/2045Yh@D0b<6k
00<0[Jf]0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]2P31^[02045Yh@D0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@040<Fn]@<0@FWQ3@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00D0al6h0P11JN480<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P090<O1^P0300000037
`KX0al6j00P0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`030<S1^`80@FWQ1`38
`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_
0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]
0<6j/031^[00`KZ`1`2][Jd40<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@040<Fn]@<0@FWQ3@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00D0al6h0P11JN480<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`11JN401@38
`K/00`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd8
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/008
0<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00@0aKje0`11JN4=
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@P0al6h0P11JN44
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`04
0<S1^`80@FWQ1038`K/2045Yh@030<S1^`11JN40b<6k00@0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^005
0;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f][@35_[D0aKje
00@0aKje0`11JN4=0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Y
h@P0al6h00<0@FWQ0<O1^037`KP00`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/01P38`K/4045Yh@H0b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?oo
o`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje
00@0aKje0P11JN4>0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Y
h@P0al6h00<0@FWQ0<O1^037`KP00`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3P
iP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35
_[D01@35_[D00`11JN40aKje0<Fn]@0<0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP01@37`KP2045Yh@L0al6h00<0@FWQ0<O1^037`KP01037`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?oo
o`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP01@37`KP2045Yh@H0al6h0P11JN460<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00<0al6h
2P11JN480<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i
/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0
[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@03
0:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]
4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H8
0:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0
b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?
0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55185 .33825 m
.56833 .33771 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59767 .33165 m
.60091 .3282 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56833 .33771 m
.57327 .33976 L
s
.56833 .33771 m
.57163 .33983 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57163 .33983 m
.57494 .3442 L
s
.57327 .33976 m
.57658 .34412 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46108 .33695 m
.4627 .3393 L
s
.45943 .33912 m
.46108 .33695 L
s
.57494 .3442 m
.57661 .34864 L
s
.46105 .34147 m
.4627 .3393 L
s
.58635 .33684 m
.59774 .33614 L
s
.57658 .34412 m
.57825 .34857 L
s
.45943 .33912 m
.46105 .34147 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57661 .34864 m
.5783 .35536 L
s
.57825 .34857 m
.57994 .35528 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4432 .33583 m
.44642 .33832 L
s
.44642 .33832 m
.44802 .34069 L
s
.43674 .33535 m
.4432 .33583 L
s
.44796 .34748 m
.44802 .34069 L
s
.46096 .35278 m
.4624 .38015 L
s
.45912 .37998 m
.46096 .35278 L
s
.44633 .34737 m
.44798 .34521 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43349 .33736 m
.43674 .33535 L
s
.44631 .34964 m
.44796 .34748 L
s
.44307 .34942 m
.44633 .34737 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57994 .35528 m
.58002 .36663 L
s
.5783 .35536 m
.57837 .36671 L
s
.59286 .33645 m
.59314 .3682 L
s
.59124 .33655 m
.5915 .36829 L
s
.55845 .33806 m
.55866 .38566 L
s
.5568 .33811 m
.557 .38571 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59302 .35456 m
.59471 .36128 L
s
.44304 .35169 m
.44631 .34964 L
s
.43186 .3395 m
.43349 .33736 L
s
.57677 .3736 m
.57837 .36671 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43031 .33484 m
.43186 .3395 L
s
.4302 .3439 m
.43031 .33484 L
s
.57842 .37353 m
.58002 .36663 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43493 .35337 m
.44307 .34942 L
s
.4302 .3439 m
.43186 .3395 L
s
.46076 .38007 m
.46086 .3664 L
s
.43491 .35564 m
.44304 .35169 L
s
.57516 .37823 m
.57677 .3736 L
s
.55202 .38584 m
.5686 .38533 L
s
.44618 .36327 m
.44785 .35882 L
s
.44777 .36792 m
.44785 .35882 L
s
.59471 .36128 m
.59801 .36562 L
s
.5768 .37816 m
.57842 .37353 L
s
.5866 .36857 m
.59314 .3682 L
s
.62032 .33666 m
.62508 .33395 L
s
.61877 .34133 m
.62032 .33666 L
s
.57189 .38293 m
.57516 .37823 L
s
.62191 .33651 m
.62508 .33395 L
s
.62037 .34119 m
.62191 .33651 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57354 .38286 m
.5768 .37816 L
s
.61877 .34133 m
.61882 .34587 L
s
.62508 .33395 m
.62984 .3335 L
s
.5686 .38533 m
.57189 .38293 L
s
.62037 .34119 m
.62043 .34573 L
s
.44453 .36544 m
.44618 .36327 L
s
.44618 .36327 m
.44777 .36792 L
s
.5686 .38533 m
.57354 .38286 L
s
0 0 0 r
.58295 .3959 m
.58334 .39735 L
s
.255 .412 .882 r
.43168 .35539 m
.43493 .35337 L
s
.59801 .36562 m
.60128 .36769 L
s
.61882 .34587 m
.62048 .35028 L
s
0 0 0 r
.58334 .39735 m
.58384 .39531 L
s
.255 .412 .882 r
.43166 .35767 m
.43491 .35564 L
s
.44126 .36749 m
.44453 .36544 L
s
.60449 .36291 m
.60608 .36052 L
s
.60608 .36052 m
.60773 .36268 L
s
.46072 .38463 m
.4624 .38015 L
s
.62984 .3335 m
.63304 .33545 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62043 .34573 m
.62208 .35014 L
s
.60449 .36291 m
.60613 .36507 L
s
.41591 .33581 m
.41903 .34065 L
s
.41119 .33306 m
.41591 .33581 L
s
.45912 .37998 m
.46072 .38463 L
s
.60128 .36769 m
.60615 .36735 L
s
.43005 .35754 m
.43168 .35539 L
s
.60773 .36268 m
.60775 .36496 L
s
.43478 .36703 m
.44126 .36749 L
s
.43002 .35981 m
.43166 .35767 L
s
.62048 .35028 m
.6253 .35213 L
s
.40804 .33273 m
.41119 .33306 L
s
.60615 .36735 m
.60775 .36496 L
s
.63304 .33545 m
.63627 .33967 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43 .36209 m
.43005 .35754 L
s
.62208 .35014 m
.6253 .35213 L
s
.40486 .33467 m
.40804 .33273 L
s
.40329 .3345 m
.40804 .33273 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43158 .3645 m
.43478 .36703 L
s
.43 .36209 m
.43158 .3645 L
s
.63778 .33496 m
.64089 .33235 L
s
.63627 .33967 m
.63778 .33496 L
s
.6253 .35213 m
.63487 .3535 L
s
.64089 .33235 m
.64246 .33218 L
s
.63935 .3348 m
.64089 .33235 L
s
.63784 .33951 m
.63935 .3348 L
s
.62059 .35938 m
.62062 .36166 L
s
.62059 .35938 m
.62219 .35924 L
s
.63627 .33967 m
.63655 .36019 L
s
.40165 .33887 m
.40486 .33467 L
s
.62219 .35924 m
.62222 .36152 L
s
.62062 .36166 m
.62225 .36381 L
s
.63784 .33951 m
.63807 .35546 L
s
.40009 .3387 m
.40329 .3345 L
s
.41727 .35415 m
.41883 .35657 L
s
.41564 .35628 m
.41727 .35415 L
s
.4188 .35885 m
.41883 .35657 L
s
.62225 .36381 m
.62548 .36581 L
s
.41555 .36313 m
.4188 .35885 L
s
.41564 .35628 m
.41721 .35871 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39998 .34553 m
.40165 .33887 L
s
.63487 .3535 m
.63649 .35562 L
s
.62548 .36581 m
.63186 .36522 L
s
.39842 .34536 m
.40009 .3387 L
s
.41234 .36511 m
.41555 .36313 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64599 .35276 m
.64638 .35005 L
s
.6444 .35296 m
.64461 .35149 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38161 .32957 m
.3924 .33095 L
s
.63655 .36019 m
.63807 .35546 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39991 .3501 m
.39998 .34553 L
s
.63186 .36522 m
.635 .36263 L
s
.635 .36263 m
.63655 .36019 L
s
.40759 .36464 m
.41234 .36511 L
s
.39835 .34992 m
.39842 .34536 L
s
.65077 .36325 m
.65647 .33052 L
s
.38723 .36238 m
.38776 .33037 L
s
.39991 .3501 m
.40138 .35712 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39835 .34992 m
.39981 .35695 L
s
.38568 .36219 m
.38622 .33017 L
s
.40446 .36203 m
.40759 .36464 L
s
.40289 .36186 m
.40759 .36464 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40138 .35712 m
.40446 .36203 L
s
.39981 .35695 m
.40289 .36186 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36495 .32716 m
.37551 .32872 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66318 .36176 m
.66874 .32888 L
s
.66874 .32888 m
.67541 .36013 L
s
.64608 .36377 m
.657 .36252 L
s
.65233 .36307 m
.65658 .33736 L
s
.65647 .33052 m
.66318 .36176 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66472 .36156 m
.66886 .33574 L
s
.37049 .35328 m
.37096 .32807 L
s
.36898 .35306 m
.36945 .32785 L
s
.38106 .36161 m
.38723 .36238 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38541 .3783 m
.387 .37618 L
s
.38549 .37369 m
.387 .37618 L
s
.3839 .37581 m
.38549 .37369 L
s
.34867 .32448 m
.35898 .32622 L
s
.3839 .37581 m
.38541 .3783 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67084 .36076 m
.67994 .35948 L
s
.36889 .35766 m
.37049 .35328 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36738 .35745 m
.36898 .35306 L
s
0 0 0 r
.68819 .34597 m
.68829 .35104 L
s
.255 .412 .882 r
.36432 .35931 m
.36889 .35766 L
s
.6884 .3328 m
.69126 .32772 L
s
.68701 .33763 m
.6884 .3328 L
s
.36432 .35931 m
.36738 .35745 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68967 .3446 m
.68972 .3469 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68566 .34476 m
.68701 .33763 L
s
.69126 .32772 m
.69562 .32467 L
s
.68988 .33256 m
.69274 .32747 L
s
.6885 .33739 m
.68988 .33256 L
s
.69274 .32747 m
.69562 .32467 L
s
.68715 .34453 m
.6885 .33739 L
s
.68566 .34476 m
.68589 .35628 L
s
.69562 .32467 m
.69854 .32416 L
s
.68715 .34453 m
.68739 .35605 L
s
.36132 .35887 m
.36432 .35931 L
s
.69854 .32416 m
.70294 .32567 L
s
.35689 .35587 m
.36132 .35887 L
s
.68589 .35628 m
.68753 .36298 L
s
.68739 .35605 m
.68901 .36275 L
s
.35402 .35079 m
.35689 .35587 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35206 .37369 m
.35307 .32524 L
s
.35354 .37392 m
.35454 .32549 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70294 .32567 m
.70593 .32975 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70577 .32284 m
.70619 .34129 L
s
.68901 .36275 m
.6906 .36714 L
s
.68753 .36298 m
.68911 .36737 L
s
.70721 .32257 m
.70763 .34102 L
s
.68911 .36737 m
.69217 .37155 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6906 .36714 m
.69366 .37131 L
s
.70185 .34207 m
.71192 .34022 L
s
.33563 .32439 m
.33839 .32955 L
s
.33839 .32955 m
.33967 .33674 L
s
.33142 .32125 m
.33563 .32439 L
s
0 0 0 r
.32175 .31154 m
.32282 .31261 L
s
.255 .412 .882 r
.33421 .32412 m
.33695 .32928 L
s
.33695 .32928 m
.33823 .33647 L
s
.33956 .34136 m
.33967 .33674 L
s
.33142 .32125 m
.33421 .32412 L
s
.69217 .37155 m
.69666 .37316 L
s
0 0 0 r
.32175 .31154 m
.32281 .31304 L
s
.255 .412 .882 r
.33812 .34109 m
.33823 .33647 L
s
.34763 .37298 m
.35354 .37392 L
s
.33797 .34803 m
.33956 .34136 L
s
.69366 .37131 m
.69666 .37316 L
s
.3286 .32068 m
.33142 .32125 L
s
.33653 .34777 m
.33812 .34109 L
s
.71573 .3209 m
.72549 .31884 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32221 .352 m
.32341 .30337 L
s
.3179 .30214 m
.32759 .30427 L
s
.32574 .32241 m
.3286 .32068 L
s
.69666 .37316 m
.69959 .37268 L
s
.33499 .35214 m
.33797 .34803 L
s
.33356 .35188 m
.33653 .34777 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69959 .37268 m
.70392 .36962 L
s
.71994 .32003 m
.72073 .35249 L
s
.32284 .32646 m
.32574 .32241 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72133 .31974 m
.72213 .35221 L
s
.70799 .35724 m
.70831 .3712 L
s
.70671 .36447 m
.70799 .35724 L
s
.33066 .35366 m
.33499 .35214 L
s
.70392 .36962 m
.70671 .36447 L
s
.70671 .36447 m
.70831 .3712 L
s
.33066 .35366 m
.33356 .35188 L
s
.32783 .35312 m
.33066 .35366 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32082 .35172 m
.32203 .30307 L
s
.72179 .33826 m
.72335 .34495 L
s
.7165 .35332 m
.72213 .35221 L
s
.32507 .35024 m
.32783 .35312 L
s
.3134 .31739 m
.31476 .3177 L
s
.32239 .34502 m
.32507 .35024 L
s
.31063 .31909 m
.3134 .31739 L
s
.31198 .3194 m
.3134 .31739 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72335 .34495 m
.72625 .34903 L
s
.31051 .32373 m
.31198 .3194 L
s
.31667 .35085 m
.32221 .352 L
s
.30916 .32342 m
.31063 .31909 L
s
.72625 .34903 m
.72907 .35078 L
s
.31008 .34003 m
.31051 .32373 L
s
.3066 .31813 m
.30916 .32342 L
s
.30861 .34439 m
.30916 .32342 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.304 .31516 m
.3066 .31813 L
s
.73169 .34552 m
.73311 .34756 L
s
.73169 .34552 m
.73299 .34289 L
s
.30005 .31417 m
.304 .31516 L
s
.30861 .34439 m
.31008 .34003 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73299 .34289 m
.73441 .34492 L
s
.72907 .35078 m
.73317 .3499 L
s
.73441 .34492 m
.73447 .34726 L
s
.73317 .3499 m
.73447 .34726 L
s
.30745 .33708 m
.30873 .33972 L
s
.29954 .33284 m
.30745 .33708 L
s
.74442 .31675 m
.74828 .31342 L
s
.74323 .32174 m
.74442 .31675 L
s
.29737 .31583 m
.30005 .31417 L
s
.29607 .3155 m
.30005 .31417 L
s
.74323 .32174 m
.74336 .3264 L
s
.3072 .34643 m
.30861 .34439 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74573 .31642 m
.74828 .31342 L
s
.74455 .32141 m
.74573 .31642 L
s
.74455 .32141 m
.74468 .32607 L
s
.74336 .3264 m
.7448 .33074 L
s
.30446 .34815 m
.3072 .34643 L
s
.74468 .32607 m
.74612 .33042 L
s
.74828 .31342 m
.75216 .3124 L
s
.29594 .32017 m
.29737 .31583 L
s
.7448 .33074 m
.7488 .3321 L
s
0 0 0 r
.76474 .3012 m
.76654 .30068 L
s
.255 .412 .882 r
.29465 .31983 m
.29607 .3155 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29915 .34689 m
.30446 .34815 L
s
.74612 .33042 m
.7488 .3321 L
s
.29698 .32985 m
.29954 .33284 L
s
.29568 .32952 m
.29954 .33284 L
s
.29581 .32484 m
.29594 .32017 L
s
.75216 .3124 m
.75478 .31404 L
s
.74506 .3401 m
.74512 .34244 L
s
.74506 .3401 m
.74638 .33978 L
s
.29452 .3245 m
.29465 .31983 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29581 .32484 m
.29698 .32985 L
s
.74512 .34244 m
.74651 .34447 L
s
.74638 .33978 m
.74644 .34212 L
s
.29452 .3245 m
.29568 .32952 L
s
.7488 .3321 m
.7566 .33244 L
s
.74651 .34447 m
.74919 .34617 L
s
.75478 .31404 m
.75746 .31803 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29659 .34391 m
.29915 .34689 L
s
.29542 .33889 m
.29672 .33921 L
s
.29666 .34156 m
.29672 .33921 L
s
.29535 .34123 m
.29542 .33889 L
s
.29535 .34123 m
.29659 .34391 L
s
.74919 .34617 m
.75437 .34487 L
s
.75859 .31299 m
.76103 .30994 L
s
.75746 .31803 m
.75859 .31299 L
s
.75746 .31803 m
.75807 .33916 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75984 .31264 m
.76103 .30994 L
s
.75872 .31768 m
.75984 .31264 L
s
.75872 .31768 m
.7592 .33411 L
s
.76103 .30994 m
.76227 .30958 L
s
0 0 0 r
.28322 .33569 m
.28386 .33429 L
s
.255 .412 .882 r
.7566 .33244 m
.75793 .33445 L
s
.75437 .34487 m
.75687 .34185 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75687 .34185 m
.75807 .33916 L
s
.75807 .33916 m
.7592 .33411 L
s
.27007 .30559 m
.2785 .30822 L
s
.28392 .33586 m
.28511 .33856 L
s
.28504 .34092 m
.28511 .33856 L
s
.2826 .33787 m
.28392 .33586 L
s
.28371 .34293 m
.28504 .34092 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76426 .29248 m
.77273 .28983 L
s
.2826 .33787 m
.28378 .34058 L
s
.27997 .3419 m
.28371 .34293 L
s
.27384 .34014 m
.27485 .30711 L
s
.76985 .31444 m
.77211 .30899 L
s
.27263 .33978 m
.27365 .30673 L
s
.77211 .30899 m
.77443 .30588 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27757 .33884 m
.27997 .3419 L
s
.77443 .30588 m
.77679 .30511 L
s
.27527 .3334 m
.27757 .33884 L
s
.27428 .32595 m
.27527 .3334 L
s
.77679 .30511 m
.77921 .3067 L
s
.77679 .30511 m
.78037 .30631 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77042 .33331 m
.77299 .33732 L
s
.76573 .34181 m
.77064 .3404 L
s
.76913 .29098 m
.77064 .3404 L
s
.76792 .29136 m
.76942 .34076 L
s
.26904 .33869 m
.27384 .34014 L
s
.77921 .3067 m
.78168 .31065 L
s
.77299 .33732 m
.77546 .33896 L
s
.78037 .30631 m
.78283 .31026 L
s
.26247 .3222 m
.26308 .30327 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77546 .33896 m
.77783 .33823 L
s
.78168 .31065 m
.78305 .31736 L
s
.26132 .32182 m
.26193 .30287 L
s
.25792 .32065 m
.26595 .32335 L
s
.78283 .31026 m
.7842 .31698 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77783 .33823 m
.78011 .33512 L
s
.77783 .33823 m
.78127 .33474 L
s
.25958 .30444 m
.2617 .30997 L
s
.78305 .31736 m
.78321 .32211 L
s
.2563 .30087 m
.25958 .30444 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78011 .33512 m
.78228 .32961 L
s
.7842 .31698 m
.78435 .32172 L
s
.78228 .32961 m
.78321 .32211 L
s
.78127 .33474 m
.78344 .32923 L
s
.78344 .32923 m
.78435 .32172 L
s
.25409 .30005 m
.2563 .30087 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26148 .35317 m
.26194 .33885 L
s
.26056 .34563 m
.26194 .33885 L
s
.25182 .30161 m
.25409 .30005 L
s
.25074 .30119 m
.25409 .30005 L
s
.25811 .34966 m
.26056 .34563 L
s
.26056 .34563 m
.26148 .35317 L
s
.79376 .29913 m
.79544 .3493 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79047 .30036 m
.79804 .29746 L
s
.5 Mabswid
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2495 .30554 m
.25182 .30161 L
s
.79484 .29871 m
.79653 .34891 L
s
.24843 .30512 m
.25074 .30119 L
s
.25465 .35092 m
.25811 .34966 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24816 .32234 m
.24845 .32038 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24827 .30989 m
.2495 .30554 L
s
.24721 .30948 m
.24843 .30512 L
s
.24696 .31664 m
.24827 .30989 L
s
.25243 .35016 m
.25465 .35092 L
s
.2459 .31623 m
.24721 .30948 L
s
.79572 .32493 m
.79803 .32891 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79213 .35045 m
.79653 .34891 L
s
.24655 .32861 m
.24696 .31664 L
s
.80223 .29576 m
.80929 .29271 L
s
.25031 .34699 m
.25243 .35016 L
s
.24922 .3466 m
.25243 .35016 L
s
.24549 .32821 m
.2459 .31623 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24829 .34141 m
.25031 .34699 L
s
.24655 .32861 m
.24738 .33621 L
s
.24722 .34101 m
.24922 .3466 L
s
.24738 .33621 m
.24829 .34141 L
s
.24549 .32821 m
.24631 .33581 L
s
.24631 .33581 m
.24722 .34101 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8063 .29403 m
.80723 .32041 L
s
.80529 .29446 m
.80621 .32083 L
s
.79803 .32891 m
.8013 .3301 L
s
.8013 .3301 m
.80338 .32928 L
s
.80338 .32928 m
.80536 .32605 L
s
.80338 .32928 m
.80638 .32564 L
s
.23516 .32648 m
.24123 .32898 L
s
.23537 .29238 m
.23816 .32773 L
s
.23029 .32435 m
.23537 .29238 L
s
.80536 .32605 m
.80621 .32083 L
s
.23125 .32478 m
.23511 .29957 L
s
.80638 .32564 m
.80723 .32041 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81317 .29093 m
.81969 .28775 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81601 .28958 m
.81723 .32337 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81694 .28913 m
.81817 .32294 L
s
.22776 .28879 m
.23029 .32435 L
s
.22287 .32085 m
.22776 .28879 L
s
.22377 .3213 m
.22749 .29601 L
s
.81438 .32467 m
.81817 .32294 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81682 .33837 m
.81767 .33551 L
s
.81682 .33837 m
.81785 .34038 L
s
.81767 .33551 m
.8187 .33752 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22021 .31952 m
.22652 .32261 L
s
.81785 .34038 m
.8187 .33752 L
s
.8244 .29269 m
.82594 .28691 L
s
.82379 .30041 m
.8244 .29269 L
s
.82379 .30041 m
.82398 .30526 L
s
.2189 .28413 m
.21975 .28461 L
s
.82526 .29222 m
.82679 .28644 L
s
.82467 .29995 m
.82526 .29222 L
s
.82398 .30526 m
.82512 .3121 L
s
.82467 .29995 m
.82485 .30481 L
s
.21713 .28561 m
.2189 .28413 L
s
.21797 .28608 m
.2189 .28413 L
s
.82485 .30481 m
.82599 .31164 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82703 .307 m
.82704 .30723 L
s
.82787 .30513 m
.82792 .30667 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82679 .28644 m
.82838 .28306 L
s
.82594 .28691 m
.82838 .28306 L
s
.21695 .29046 m
.21797 .28608 L
s
.82838 .28306 m
.83002 .28211 L
s
.82512 .3121 m
.82703 .31606 L
s
.21612 .28999 m
.21713 .28561 L
s
.82599 .31164 m
.82789 .31561 L
s
.2163 .30749 m
.21695 .29046 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83002 .28211 m
.83252 .28309 L
s
.21467 .28418 m
.21612 .28999 L
s
.21528 .31191 m
.21612 .28999 L
s
.21316 .28078 m
.21467 .28418 L
s
.21528 .31191 m
.2163 .30749 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82789 .31561 m
.82967 .31714 L
s
.82703 .31606 m
.82967 .31714 L
s
.21081 .27932 m
.21316 .28078 L
s
.21474 .30412 m
.21547 .30703 L
s
.83252 .28309 m
.83428 .28699 L
s
.21006 .29885 m
.21474 .30412 L
s
.21437 .31389 m
.21528 .31191 L
s
.82967 .31714 m
.83214 .31576 L
s
.21265 .31542 m
.21437 .31389 L
s
.20919 .28078 m
.21081 .27932 L
s
.20844 .28029 m
.21081 .27932 L
s
.83214 .31576 m
.83365 .31239 L
s
.83337 .30504 m
.83406 .30213 L
s
.83337 .30504 m
.83425 .30702 L
s
.20949 .31356 m
.21265 .31542 L
s
.83406 .30213 m
.83494 .3041 L
s
.20825 .28517 m
.20919 .28078 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83365 .31239 m
.83503 .30655 L
s
.20751 .28468 m
.20844 .28029 L
s
.20862 .29544 m
.21006 .29885 L
s
.20787 .29496 m
.21006 .29885 L
s
.83494 .3041 m
.83503 .30655 L
s
.20806 .29006 m
.20825 .28517 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20806 .29006 m
.20862 .29544 L
s
.20732 .28958 m
.20751 .28468 L
s
.20732 .28958 m
.20787 .29496 L
s
.20805 .31016 m
.20949 .31356 L
s
.83923 .27623 m
.84014 .28063 L
s
.83923 .27623 m
.83961 .28602 L
s
.20749 .30477 m
.20824 .30525 L
s
.20815 .3077 m
.20824 .30525 L
s
.20739 .30723 m
.20805 .31016 L
s
.20739 .30723 m
.20749 .30477 L
s
.83961 .28602 m
.84014 .28063 L
s
.84014 .28063 m
.84075 .27768 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84075 .27768 m
.84204 .27422 L
s
.84204 .27422 m
.84471 .27219 L
s
.84019 .30075 m
.84081 .29781 L
s
.84019 .30075 m
.84039 .30567 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84029 .30321 m
.84091 .30027 L
s
.84081 .29781 m
.84213 .29437 L
s
.84039 .30567 m
.8412 .30766 L
s
.84091 .30027 m
.84222 .29683 L
s
.84213 .29437 m
.8453 .28696 L
s
.8412 .30766 m
.84271 .30917 L
s
.84222 .29683 m
.8454 .28943 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84471 .27219 m
.8461 .27363 L
s
.84271 .30917 m
.84543 .30723 L
s
.20109 .30042 m
.20167 .30338 L
s
.20157 .30585 m
.20167 .30338 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20079 .30784 m
.20157 .30585 L
s
.8461 .27363 m
.84683 .27558 L
s
.20032 .3024 m
.20109 .30042 L
s
.8453 .28696 m
.84649 .28349 L
s
.19473 .26716 m
.19892 .27079 L
s
.8454 .28943 m
.84659 .28596 L
s
.20032 .3024 m
.20089 .30536 L
s
.19881 .30638 m
.20079 .30784 L
s
.84683 .27558 m
.84713 .28299 L
s
.84649 .28349 m
.84703 .28052 L
s
.84659 .28596 m
.84713 .28299 L
s
.84543 .30723 m
.84665 .30377 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19567 .30391 m
.19707 .26924 L
s
.84665 .30377 m
.84719 .3008 L
s
.19507 .30342 m
.19647 .26872 L
s
.19763 .30291 m
.19881 .30638 L
s
.84719 .3008 m
.84762 .29535 L
s
.84719 .3008 m
.84802 .30527 L
s
.84762 .29535 m
.84802 .30527 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19658 .29696 m
.19763 .30291 L
s
.19627 .28902 m
.19658 .29696 L
s
.8509 .2695 m
.85136 .2665 L
s
.8509 .2695 m
.85156 .27145 L
s
.85136 .2665 m
.85201 .26845 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19332 .30192 m
.19567 .30391 L
s
.85156 .27145 m
.85201 .26845 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85268 .2988 m
.85329 .31379 L
s
.85207 .28386 m
.85272 .31429 L
s
.85207 .28386 m
.85384 .3133 L
s
.19119 .27145 m
.1915 .27695 L
s
.1915 .27695 m
.19172 .28493 L
s
.19038 .26542 m
.19119 .27145 L
s
.19121 .29741 m
.19172 .28493 L
s
.19068 .27092 m
.19098 .27643 L
s
.19098 .27643 m
.19119 .28442 L
s
.18989 .26489 m
.19068 .27092 L
s
.85272 .31429 m
.85349 .3188 L
s
.19068 .2969 m
.19119 .28442 L
s
.18904 .26133 m
.19038 .26542 L
s
.18904 .26133 m
.18989 .26489 L
s
.19037 .30441 m
.19121 .29741 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85349 .3188 m
.85384 .3133 L
s
.18985 .30391 m
.19068 .2969 L
s
.18484 .25591 m
.18904 .26133 L
s
.18964 .30892 m
.19037 .30441 L
s
.18913 .30842 m
.18985 .30391 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18842 .31295 m
.18964 .30892 L
s
.18793 .31245 m
.18913 .30842 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18686 .31397 m
.18842 .31295 L
s
.1842 .31094 m
.18641 .25809 L
s
.18686 .31397 m
.18793 .31245 L
s
.18379 .31043 m
.186 .25754 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18261 .3089 m
.18686 .31397 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86473 .24835 m
.86662 .24272 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86541 .24667 m
.86769 .30026 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86662 .24272 m
.86698 .24413 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86698 .24413 m
.86742 .24811 L
s
.86662 .24272 m
.8671 .24357 L
s
.86561 .24611 m
.8679 .29973 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8671 .24357 m
.86751 .24755 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86742 .24811 m
.86773 .25267 L
s
.86751 .24755 m
.86781 .25211 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86701 .30183 m
.86893 .29656 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86781 .25211 m
.86821 .25926 L
s
.86773 .25267 m
.86814 .25981 L
s
.86893 .29656 m
.86908 .29292 L
s
.86893 .29656 m
.86919 .29238 L
s
.86814 .25981 m
.86869 .27269 L
s
.86821 .25926 m
.86877 .27214 L
s
.86907 .28668 m
.86908 .29292 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .23242 m
.86751 .23644 L
s
.86916 .28614 m
.86919 .29238 L
s
.86869 .27269 m
.86894 .28097 L
s
.86894 .28097 m
.86907 .28668 L
s
.86877 .27214 m
.86903 .28043 L
s
.86903 .28043 m
.86916 .28614 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86753 .23472 m
.86908 .27088 L
s
.86751 .23415 m
.86907 .27033 L
s
.86906 .27253 m
.86907 .27033 L
s
.8684 .25479 m
.86871 .262 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86871 .262 m
.86885 .26608 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86884 .26758 m
.86885 .26608 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86858 .26592 m
.86884 .26758 L
s
.86845 .26126 m
.86847 .26331 L
s
.86824 .2581 m
.86845 .26126 L
s
.86824 .2581 m
.86824 .26015 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86836 .26276 m
.86858 .26592 L
s
.86824 .26015 m
.86836 .26276 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86638 .23806 m
.86641 .24259 L
s
.86618 .2372 m
.86618 .23737 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86618 .23737 m
.8662 .24203 L
s
.86685 .25307 m
.86697 .25569 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17912 .20696 m
.18134 .20341 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17921 .28144 m
.17981 .20578 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17959 .22716 m
.18349 .22197 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18398 .19986 m
.18702 .19633 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18924 .16872 m
.19347 .16451 L
s
.85941 .2047 m
.85977 .20149 L
s
.85909 .19713 m
.85977 .20149 L
s
.85871 .20032 m
.85909 .19713 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8576 .246 m
.85777 .23087 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85871 .20032 m
.85941 .2047 L
s
.255 .412 .882 r
.18741 .23624 m
.1873 .2389 L
s
.18801 .23302 m
.18741 .23624 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1797 .26994 m
.18545 .1981 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17921 .28144 m
.18596 .19751 L
s
.18765 .24692 m
.19098 .16691 L
s
.18826 .24637 m
.19159 .16631 L
s
.255 .412 .882 r
.85576 .2261 m
.8576 .246 L
s
0 0 0 r
.8602 .22368 m
.86266 .27017 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85521 .2248 m
.85561 .22922 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86117 .24659 m
.86214 .26963 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85403 .19566 m
.85482 .20005 L
s
.85482 .20005 m
.85529 .21149 L
s
.19001 .20423 m
.19158 .19546 L
s
.85259 .19069 m
.85403 .19566 L
s
.19158 .19546 m
.19303 .19049 L
s
.85467 .21092 m
.85514 .20767 L
s
.84988 .18838 m
.85259 .19069 L
s
.85483 .21475 m
.85529 .21149 L
s
.19303 .19049 m
.19436 .18933 L
s
.86246 .27734 m
.86266 .27017 L
s
.85354 .21361 m
.85467 .21092 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8602 .22368 m
.8616 .26909 L
s
.5 Mabswid
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18589 .24857 m
.18826 .24637 L
s
.8537 .21744 m
.85483 .21475 L
s
.19436 .18933 m
.19559 .19199 L
s
.19436 .18933 m
.1963 .19142 L
s
.8616 .26909 m
.86246 .27734 L
s
.85578 .23777 m
.85609 .23064 L
s
.85609 .23064 m
.85673 .24602 L
s
.18874 .23484 m
.18967 .24142 L
s
.84862 .19105 m
.84988 .18838 L
s
.85043 .21848 m
.85354 .21361 L
s
.85059 .22234 m
.8537 .21744 L
s
.19559 .19199 m
.19671 .19851 L
s
.1963 .19142 m
.19745 .19794 L
s
.8553 .24107 m
.85578 .23777 L
s
.85578 .23777 m
.85673 .24602 L
s
.84804 .19431 m
.84862 .19105 L
s
.18967 .24142 m
.19081 .24418 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85415 .24383 m
.8553 .24107 L
s
.84699 .18607 m
.84804 .19431 L
s
.84699 .18607 m
.84762 .20141 L
s
.84762 .20141 m
.84804 .19431 L
s
.19671 .19851 m
.19698 .20947 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19745 .19794 m
.19772 .20891 L
s
.19081 .24418 m
.19215 .24309 L
s
.84914 .22123 m
.85043 .21848 L
s
.85138 .24165 m
.85415 .24383 L
s
.8493 .22509 m
.85059 .22234 L
s
.19666 .21718 m
.19698 .20947 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19215 .24309 m
.1937 .23814 L
s
.19215 .24309 m
.19442 .23759 L
s
.19741 .21662 m
.19772 .20891 L
s
.19546 .22931 m
.19666 .21718 L
s
.83981 .18094 m
.84312 .18321 L
s
.84856 .22454 m
.84914 .22123 L
s
.1937 .23814 m
.19546 .22931 L
s
.19619 .22876 m
.19741 .21662 L
s
.84871 .2284 m
.8493 .22509 L
s
.19442 .23759 m
.19619 .22876 L
s
.84977 .23669 m
.85138 .24165 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84856 .22454 m
.84887 .23228 L
s
.84887 .23228 m
.84977 .23669 L
s
.84065 .18151 m
.84282 .23574 L
s
.83981 .18094 m
.84197 .23521 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83657 .21333 m
.83657 .21348 L
s
0 0 0 r
.20457 .19287 m
.20659 .18403 L
s
.20327 .20502 m
.20457 .19287 L
s
.20659 .18403 m
.20939 .17849 L
s
.83824 .18367 m
.84027 .19251 L
s
.20542 .19231 m
.20746 .18347 L
s
.20411 .20446 m
.20542 .19231 L
s
.20296 .21276 m
.20327 .20502 L
s
.83541 .17813 m
.83824 .18367 L
s
.20746 .18347 m
.20939 .17849 L
s
.2038 .21221 m
.20411 .20446 L
s
.20296 .21276 m
.20333 .22387 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20939 .17849 m
.21121 .17738 L
s
.83358 .17701 m
.83541 .17813 L
s
.2038 .21221 m
.20419 .22333 L
s
.21121 .17738 m
.21293 .18013 L
s
.21121 .17738 m
.21388 .17958 L
s
.20333 .22387 m
.20474 .23058 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83088 .17922 m
.83358 .17701 L
s
.83184 .17978 m
.83358 .17701 L
s
.20419 .22333 m
.20562 .23005 L
s
.255 .412 .882 r
.83796 .24883 m
.83796 .24893 L
s
0 0 0 r
.83935 .23362 m
.84282 .23574 L
s
.255 .412 .882 r
.83796 .24893 m
.83797 .24884 L
s
0 0 0 r
.21293 .18013 m
.21454 .18679 L
s
.83118 .18699 m
.83184 .17978 L
s
.21388 .17958 m
.21552 .18625 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20474 .23058 m
.20725 .2329 L
s
.83021 .18644 m
.83088 .17922 L
s
.20562 .23005 m
.20725 .2329 L
s
.21454 .18679 m
.21507 .19793 L
s
.21552 .18625 m
.21606 .19739 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83021 .18644 m
.83187 .22943 L
s
.83118 .18699 m
.83285 .22995 L
s
.20725 .2329 m
.20908 .23185 L
s
.21477 .20574 m
.21507 .19793 L
s
.20908 .23185 m
.21111 .22688 L
s
.20908 .23185 m
.21207 .22636 L
s
.21576 .2052 m
.21606 .19739 L
s
.21334 .218 m
.21477 .20574 L
s
.22205 .17132 m
.22966 .16757 L
s
.21111 .22688 m
.21334 .218 L
s
.81612 .16775 m
.82265 .17097 L
s
.21432 .21747 m
.21576 .2052 L
s
.21207 .22636 m
.21432 .21747 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80998 .21935 m
.82052 .16989 L
s
.22215 .25239 m
.22524 .1697 L
s
.82888 .22788 m
.83285 .22995 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22325 .2519 m
.22633 .16917 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23425 .16546 m
.24272 .16184 L
s
.81815 .2228 m
.82472 .22583 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80435 .16253 m
.81154 .16564 L
s
.80679 .16356 m
.82243 .22426 L
s
.82243 .22426 m
.82258 .22482 L
s
.255 .412 .882 r
.80601 .19795 m
.80628 .19785 L
s
.80601 .19795 m
.80623 .19778 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21893 .25386 m
.22325 .2519 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80876 .21886 m
.81944 .16936 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23484 .2471 m
.23782 .16389 L
s
.23606 .24663 m
.23902 .16338 L
s
.79716 .17132 m
.79887 .18368 L
s
.79427 .16243 m
.79716 .17132 L
s
.79014 .157 m
.79427 .16243 L
s
.79586 .17083 m
.79757 .18319 L
s
.79295 .16194 m
.79586 .17083 L
s
.79014 .157 m
.79295 .16194 L
s
.24999 .17065 m
.25291 .16176 L
s
.24827 .18302 m
.24999 .17065 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79887 .18368 m
.79914 .19161 L
s
.80631 .21789 m
.81355 .22082 L
s
.25291 .16176 m
.25709 .15634 L
s
.25131 .17016 m
.25424 .16127 L
s
.24958 .18253 m
.25131 .17016 L
s
.78741 .15603 m
.79014 .157 L
s
.79757 .18319 m
.79785 .19113 L
s
.25424 .16127 m
.25709 .15634 L
s
.248 .19096 m
.24827 .18302 L
s
.23124 .24853 m
.23606 .24663 L
s
.79826 .20306 m
.79914 .19161 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25709 .15634 m
.25984 .15537 L
s
.24931 .19048 m
.24958 .18253 L
s
.79695 .20258 m
.79785 .19113 L
s
.78478 .15902 m
.78741 .15603 L
s
.78338 .15854 m
.78741 .15603 L
s
.248 .19096 m
.2489 .20242 L
s
.24931 .19048 m
.25022 .20194 L
s
.25984 .15537 m
.2625 .15837 L
s
.25984 .15537 m
.26391 .1579 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7959 .21009 m
.79826 .20306 L
s
.78223 .16601 m
.78478 .15902 L
s
.79457 .20962 m
.79695 .20258 L
s
.2489 .20242 m
.25129 .20946 L
s
.78081 .16554 m
.78338 .15854 L
s
.2625 .15837 m
.26508 .16537 L
s
.25022 .20194 m
.25263 .20899 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26391 .1579 m
.26651 .1649 L
s
.79201 .21269 m
.7959 .21009 L
s
.7812 .17748 m
.78223 .16601 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79201 .21269 m
.79457 .20962 L
s
.77977 .17702 m
.78081 .16554 L
s
.25129 .20946 m
.25522 .21207 L
s
.26508 .16537 m
.26612 .17686 L
s
.25263 .20899 m
.25522 .21207 L
s
.26651 .1649 m
.26757 .1764 L
s
.78927 .21177 m
.79201 .21269 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7812 .17748 m
.78146 .18547 L
s
.76569 .149 m
.7717 .15082 L
s
.77977 .17702 m
.78003 .18501 L
s
.26587 .18485 m
.26612 .17686 L
s
.25522 .21207 m
.25799 .21116 L
s
.78146 .18547 m
.78327 .19793 L
s
.2757 .1502 m
.28642 .14707 L
s
.78636 .20685 m
.78927 .21177 L
s
.78495 .2064 m
.78927 .21177 L
s
.26731 .18439 m
.26757 .1764 L
s
.78003 .18501 m
.78185 .19747 L
s
.26404 .19731 m
.26587 .18485 L
s
.78327 .19793 m
.78636 .20685 L
s
.25799 .21116 m
.26093 .20624 L
s
.25799 .21116 m
.26235 .20579 L
s
.26548 .19686 m
.26731 .18439 L
s
.78185 .19747 m
.78495 .2064 L
s
.26093 .20624 m
.26404 .19731 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27852 .20502 m
.28024 .14884 L
s
.26235 .20579 m
.26548 .19686 L
s
.28006 .20459 m
.28177 .14839 L
s
.255 .412 .882 r
.76719 .18416 m
.7672 .18444 L
s
.76887 .18587 m
.77012 .19224 L
s
.7672 .18444 m
.76894 .1933 L
s
0 0 0 r
.76274 .15209 m
.76605 .16097 L
s
.75951 .14722 m
.76274 .15209 L
s
.255 .412 .882 r
.76894 .1933 m
.77024 .196 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75637 .14635 m
.75951 .14722 L
s
.7533 .14948 m
.75637 .14635 L
s
.7517 .14906 m
.75637 .14635 L
s
.29276 .14533 m
.30422 .14241 L
s
.75031 .15666 m
.7533 .14948 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74868 .15624 m
.7517 .14906 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27395 .20629 m
.28006 .20459 L
s
.29636 .18835 m
.29762 .14406 L
s
.28043 .19248 m
.2833 .19971 L
s
.29801 .18796 m
.29925 .14365 L
s
.74903 .1683 m
.75031 .15666 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76721 .14945 m
.76981 .23396 L
s
.76569 .149 m
.76827 .23354 L
s
.7642 .20028 m
.76704 .19306 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74739 .1679 m
.74868 .15624 L
s
.76119 .20349 m
.7642 .20028 L
s
.2833 .19971 m
.28792 .20252 L
s
.7316 .14015 m
.7384 .14174 L
s
.74903 .1683 m
.74926 .17637 L
s
.74739 .1679 m
.74762 .17596 L
s
.75803 .20267 m
.76119 .20349 L
s
.74926 .17637 m
.75123 .1889 L
s
.73331 .14055 m
.73482 .19721 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31097 .1408 m
.32311 .13811 L
s
.74762 .17596 m
.7496 .1885 L
s
.75471 .1978 m
.75803 .20267 L
s
.75309 .1974 m
.75803 .20267 L
s
.7316 .14015 m
.73309 .19684 L
s
.28792 .20252 m
.29113 .20172 L
s
.75123 .1889 m
.75471 .1978 L
s
.7496 .1885 m
.75309 .1974 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76361 .23233 m
.76981 .23396 L
s
.29449 .19686 m
.29636 .18835 L
s
.29113 .20172 m
.29449 .19686 L
s
.29113 .20172 m
.29613 .19646 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72825 .1434 m
.73192 .15223 L
s
.7229 .13824 m
.72825 .1434 L
s
.29613 .19646 m
.29801 .18796 L
s
.71936 .13749 m
.7229 .13824 L
s
.71588 .1408 m
.71936 .13749 L
s
.71408 .14044 m
.71936 .13749 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31464 .19635 m
.31612 .13963 L
s
.31639 .19598 m
.31785 .13924 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71247 .14817 m
.71408 .14044 L
s
.71428 .14853 m
.71588 .1408 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33739 .13926 m
.34301 .13418 L
s
.33538 .1477 m
.33739 .13926 L
s
.30945 .19745 m
.31639 .19598 L
s
.33923 .13891 m
.34301 .13418 L
s
.3372 .14736 m
.33923 .13891 L
s
.72786 .19575 m
.73482 .19721 L
s
.33432 .19252 m
.33538 .1477 L
s
.34301 .13418 m
.34673 .13351 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33616 .19219 m
.3372 .14736 L
s
.34673 .13351 m
.35228 .13659 L
s
.69557 .13297 m
.6961 .15735 L
s
.68842 .13187 m
.69557 .13297 L
s
.69368 .13265 m
.6961 .15735 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35228 .13659 m
.35591 .14408 L
s
.35616 .1319 m
.36384 .13067 L
s
.35496 .18907 m
.35616 .1319 L
s
.35688 .18878 m
.35807 .13158 L
s
.31411 .2168 m
.31575 .22055 L
s
.31226 .22126 m
.31411 .2168 L
s
.31226 .22126 m
.3139 .22501 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71247 .14817 m
.71354 .19297 L
s
.71428 .14853 m
.71536 .19331 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32885 .19353 m
.33616 .19219 L
s
.3139 .22501 m
.31575 .22055 L
s
.70803 .19198 m
.71536 .19331 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66459 .1282 m
.68842 .13187 L
s
.37358 .12921 m
.3754 .13707 L
s
.37327 .14551 m
.37358 .12921 L
s
.3754 .13707 m
.37745 .13272 L
s
.37745 .13272 m
.38149 .12811 L
s
.38149 .12811 m
.3895 .12707 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37327 .14551 m
.3754 .13707 L
s
.68474 .15959 m
.68541 .19242 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6725 .12931 m
.67413 .21561 L
s
.3895 .12707 m
.39347 .13065 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34924 .18997 m
.35688 .18878 L
s
.69554 .21865 m
.6969 .19419 L
s
.6969 .19419 m
.69744 .21895 L
s
.67335 .17428 m
.68507 .17597 L
s
.39347 .13065 m
.39544 .13449 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39524 .14677 m
.39544 .13449 L
s
.37487 .1657 m
.37891 .16107 L
s
.37281 .17008 m
.37487 .1657 L
s
.37891 .16107 m
.38909 .15159 L
s
.37266 .1783 m
.37281 .17008 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39321 .147 m
.39531 .14267 L
s
.41199 .12451 m
.41401 .12839 L
s
.40986 .12881 m
.41199 .12451 L
s
.37479 .16981 m
.37884 .16517 L
s
.37273 .17419 m
.37479 .16981 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38909 .15159 m
.39321 .147 L
s
.37884 .16517 m
.38902 .15569 L
s
.40986 .12881 m
.41187 .13269 L
s
.39314 .1511 m
.39524 .14677 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38902 .15569 m
.39314 .1511 L
s
.41187 .13269 m
.41401 .12839 L
s
.37266 .1783 m
.37456 .18215 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37456 .18215 m
.37847 .18576 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37847 .18576 m
.38651 .18477 L
s
.39274 .17579 m
.39491 .16731 L
s
.39465 .18383 m
.39491 .16731 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66614 .2146 m
.69022 .21795 L
s
.69022 .21795 m
.69744 .21895 L
s
.5 Mabswid
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67053 .12903 m
.67214 .21536 L
s
.41159 .15321 m
.41299 .20271 L
s
.4088 .2031 m
.41159 .15321 L
s
.39063 .18016 m
.39274 .17579 L
s
.39274 .17579 m
.39465 .18383 L
s
.38651 .18477 m
.39063 .18016 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41089 .2029 m
.41124 .17798 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4088 .2031 m
.41078 .21124 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41078 .21124 m
.41299 .20271 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@040000003oYQ40ojHA0?nV4@`0[Jf]5P3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa090:f]
[@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00X0k9H>0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000000@0ojHA1@2][Jd2000000<0
[Jf]103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400;0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3oool007L0/>3V
0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
000000020?nV4@040:f][@000000000000000080[Jf]00@000000:f][@2][Jd0[Jf]1@3oYQ400`00
0000ojHA000000060?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01D0oj<@0P2][Jd5000001P0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0C0?nV4@800000102][Jd010000000
[Jf]0:f][@0000060?nV4@030000003oYQ40ojHA00D0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA
01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01T0oj<@00<0[Jf]000000000000100000020:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@<000000P2][Jd20?nV4@050:f][@3oYQ4000000?nV
4@0000001`3oYQ400`000000ojHA0?nV4@060?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0?nV
4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006@3oXa000`2][Jd00000000000040?bP40L000003@3lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80
[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3o
YQ402P3oYQ43000000<0[Jf]0P0000050?nV4@040:f][@3oYQ400000000000T0ojHA00<000000?nV
4@3oYQ403@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@000000000000T0o:0@0P0000050:f]
[@P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ430:f][@80000000<0[Jf]0?nV4@3o
YQ400P0000000`3oYQ400000000000050?nV4@040:f][@3oYQ400000000000T0ojHA00<000000?nV
4@3oYQ403@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@000000000000T0o:0@0P0000050?bP
40H0[Jf]00<000000?bP402][Jd05P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@@00000102][Jd20?nV4@8000001@3oYQ4010000000
ojHA0000000000050?nV4@040:f][@3oYQ400000000000T0ojHA00<000000?nV4@3oYQ403@3oYQ40
0`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400I0?nS40030:f][@000000000000T0o:0@0P00000:0?bP40050000002][Jd0
00000000002][Jd05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2]
[JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A0140oj@A100000020:f][@L0ojHA0P0000060?nV4@<000001@3oYQ400`2][Jd0ojHA0000000:
0?nV4@030000003oYQ40ojHA00d0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd000000000000:
0?bP40030000003lX100o:0@00L0o:0@00D000000?bP403lX100o:0@0:f][@02000000030:f][@00
000000000140mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`
h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0<
0?nT4@<00000102][Jd2000000T0ojHA00<000000?nV4@3oYQ401@3oYQ43000000D0ojHA00<0[Jf]
0?nV4@0000002P3oYQ400`000000ojHA0?nV4@0<0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0000000000002P3lX1000`000000o:0@0?bP40070?bP40050000003lX100o:0@0?bP402][Jd00P3f
W0l6000000030:f][@3fW0l0mY`?00/0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@080?nT4@@000000`2][Jd40?nT4@800000203oYQ42000000P0ojHA0P000005
0?nV4@030:f][@3oYQ40000000T0ojHA0P00000>0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0000000000002P3lX1000`000000o:0@0?bP40060?bP408000000`3lX1000`2][Jd0mY`?0?JL3`03
000000@0mY`?102][Jd90?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0
0`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@040?nT4@80000000@0oj@A0:f][@2][Jd0[Jf]0P000007
0?nT4@800000203oYQ42000000P0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA00T0ojHA0P00000>
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0000000000002P3lX102000000L0o:0@0P000003
0?bP40030:f][@3fW0l0mY`?00<00000203fW0l20:f][@<00000103fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2]
[Jd0o:0@0?bP400?0?bP40040:f][@3oY140oj@A0?nT4@<000000`2][Jd30?nT4@8000001`3oY142
000000P0ojHA0P0000080?nV4@8000001@3oYQ400`2][Jd0ojHA0?nV4@080?nV4@8000003`3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS408000002P3lX102000000L0o:0@0P0000030?bP40040:f][@3fW0l0
mY`?0?JL3`800000203fW0l3000000040?JL3`2][Jd000000:f][@80000000<0[Jf]0>bF3P3/UPh0
403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0
[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40060:f][@3oY14000000000002][Jd0
00001`3oY142000000L0oj@A0P0000080?nV4@800000203oYQ42000000D0ojHA00<0[Jf]0?nV4@3o
YQ40203oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa02000000X0o:0@0P0000070?bP4080
00000`3lX100102][Jd0mY`?0?JL3`3fW0l2000000P0mY`?0P0000030?JL3`030000003fW0l00000
00<000004@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool0
06@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]0`3oY140
0`000000oj@A0?nT4@050?nT4@8000001`3oY142000000P0ojHA0P0000080?nV4@8000001@3oYQ40
0`2][Jd0ojHA0?nV4@070?nV4@8000002@3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@0P00000;0?bP40030000003lX100o:0@00D0o:0@0P0000030?bP40040:f][@3fW0l0
mY`?0?JL3`8000001`3fW0l2000000D0mY`?0`0000000`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0
[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00T0o:0@00<000000?bP403lX100
0P2][Jd00`3lX100[Jf]0?nT4@030?nT4@030000003oY140oj@A00D0oj@A0P0000070?nT4@800000
203oYQ42000000P0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA00H0ojHA00<000000?nV4@000000
2@3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@0P00000;0?bP40030000
003lX100o:0@00D0o:0@0P0000030?bP40040:f][@3fW0l0mY`?0?JL3`8000001`3fW0l2000000D0
mY`?0`0000000`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40080?bP40040000002][Jd000000:f][@<0
o:0@00<0[Jf]0?nT4@3oY1400P3oY1400`000000oj@A0?nT4@050?nT4@8000001`3oY142000000P0
ojHA0P0000080?nV4@8000001@3oYQ400`2][Jd0ojHA0?nV4@040?nV4@80000000<0ojHA0000003o
YQ402@3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU4003
0:f][@3oXa00oj<@01X0oj<@0P00000;0?bP40030000003lX100o:0@00D0o:0@0P0000030?bP4004
0:f][@3fW0l0mY`?0?JL3`8000001`3fW0l2000000D0mY`?0`0000000`2][Jd0k9H>0>bF3P040>bF
3P80[Jf]0P0000080>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2]
[Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40050000002][Jd0o:0@0?bP400000000`3lX1000`2]
[Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00D0oj@A0P0000070?nT4@800000203oYQ420000
00P0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA00<0ojHA00@000000?nV4@3oYQ4000002`3oYQ40
0`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa02
000000D0o:0@00<000000?bP403lX1002`3lX102000000<0o:0@00@0[Jf]0?JL3`3fW0l0mY`?0P00
00070?JL3`8000001P3fW0l2000000030:f][@3/UPh0k9H>00@0k9H>0P000000103/UPh0[Jf]0000
002][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V
0;3PiP180;3PiP40oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00@000000?bP403lX100o:0@0P0000020?bP40030:f]
[@3oY140oj@A0080oj@A00<000000?nT4@3oY1401@3oY142000000L0oj@A0P0000080?nV4@800000
203oYQ42000000D0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4010000000ojHA00000000000<0?nV4@03
0000003oYQ40ojHA00`0[Jf]5`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01D0
ojD@302][JdH0?nS408000001@3lX1000`000000o:0@0?bP400;0?bP408000000`3lX100102][Jd0
mY`?0?JL3`3fW0l2000000L0mY`?0P0000060?JL3`80000000<0[Jf]0>bF3P3/UPh0103/UPh01P00
0000k9H>0>bF3P3/UPh000000>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P05
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP400000000P0000020:f][@80o:0@0P000004
0?bP40040000003lX100o:0@0:f][@@0oj@A00<000000?nT4@3oY1401@3oY142000000L0oj@A0P00
00080?nV4@800000203oYQ42000000D0ojHA00L0[Jf]0?nV4@3oYQ40ojHA0000003oYQ40000000P0
ojHA1P2][Jd00`000000[Jf]0:f][@040?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS4080
00001@3lX1000`000000o:0@0?bP400;0?bP408000000`3lX100102][Jd0mY`?0?JL3`3fW0l20000
00H0mY`?0P0000070?JL3`80000000<0[Jf]0>bF3P3/UPh00`3/UPh2000000@0k9H>00<000000>bF
3P3/UPh00P2][Jd00`000000k9H>0000000=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0;3P
iP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>000000060=>73P030:f][@3_V100kiP@00/0
kiP@0`0000000`2][Jd0o:0@0?bP40030?bP40030000003lX100o:0@00<0o:0@0P0000000`3lX100
[Jf]0?nT4@030?nT4@030000003oY140oj@A00D0oj@A0P0000070?nT4@800000203oYQ42000000P0
ojHA0P0000050?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@2][Jd60?nV4@030000003oYQ40ojHA
00@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@0P0000050?bP40030000003lX100o:0@
00/0o:0@0P0000030?bP40040:f][@3fW0l0mY`?0?JL3`8000001P3fW0l2000000L0mY`?0P000000
0`2][Jd0k9H>0>bF3P030>bF3P030000003/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh2
000000d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd00`00
0000dhL>0=>73P050=>73P030:f][@3_V100kiP@00P0kiP@00<000000>nH403_V1000P2][Jd00`00
0000o:0@0?bP40030?bP408000001@3lX102000000030?bP402][Jd0oj@A00<0oj@A00<000000?nT
4@3oY1401@3oY1400`000000oj@A0?nT4@060?nT4@800000203oYQ42000000P0ojHA0P0000030?nV
4@D0[Jf]0P0000080?nV4@030000003oYQ40ojHA00D0ojHA00<000000?nV4@3oYQ40103oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400F0?nS40@0[Jf]0P0000020:f][@<0o:0@00<000000?bP403lX1002`3lX1020000
00<0o:0@00@0[Jf]0?JL3`3fW0l0mY`?0P0000060?JL3`8000001`3fW0l2000000030:f][@3/UPh0
k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh2000000D0k9H>0`00000;0=^:3@030:f][@2iM@/0
^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP030:f][@000000000000L0dhL>00<0[Jf]0>nH
403_V1001P3_V102000000060>nH402][Jd0[Jf]0:f][@3lX10000001@3lX1000`000000o:0@0?bP
40040?bP4080000000<0o:0@0:f][@3oY1400`3oY1400`000000oj@A0?nT4@050?nT4@030000003o
Y140oj@A00H0oj@A0P0000080?nV4@8000001`3oYQ400`2][Jd00000000000030:f][@80ojHA00D0
[Jf]0?nV4@000000ojHA000000080?nV4@030000003oYQ40ojHA00D0ojHA00<000000?nV4@3oYQ40
103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS408000000P3lX1030:f][@030000002][Jd0[Jf]00/0o:0@
0P0000030?bP40040:f][@3fW0l0mY`?0?JL3`8000001P3fW0l2000000L0mY`?0P0000000`2][Jd0
k9H>0>bF3P030>bF3P030000003/UPh0k9H>00@0k9H>00<000000>bF3P3/UPh00`3/UPh0102][Jd0
00000=^:3@2][Jd3000000L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3P
iP40oooo001L0;3PiP040:f][@2GH0/0[Jf]000000L0dhL>00<0[Jf]0>nH403_V1001@3_V1030000
00060:f][@3_V100kiP@0:f][@3lX10000001@3lX1000`000000o:0@0?bP40040?bP4080000000<0
o:0@0:f][@3oY1400`3oY1400`000000oj@A0?nT4@050?nT4@030000003oY140oj@A00H0oj@A0P00
00080?nV4@040000003oYQ40ojHA0?nV4@D0[Jf]00<0ojHA0000000000001@3oYQ40102][Jd0ojHA
0000000000090?nV4@030000003oYQ40ojHA00D0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS408000001@3lX1000`000000o:0@0?bP40070:f][@@0o:0@0P0000030?bP4003
0:f][@3fW0l0mY`?0080mY`?0P0000050?JL3`800000203fW0l00`000000[Jf]0>bF3P030>bF3P80
00001P3/UPh2000000@0k9H>00<0[Jf]0000003KRPd00P3KRPd0102][Jd000000000000000050=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H01@2][Jd0
Uf0;09MP2`2][Jd0000000L0dhL>00<0[Jf]0>nH403_V1001@3_V1000`2][Jd00000000000030>nH
40030:f][@3lX100000000D0o:0@00<000000?bP403lX1001@3lX1000`000000o:0@0:f][@040?nT
4@030000003oY140oj@A00D0oj@A00<000000?nT4@3oY1401P3oY142000000L0ojHA00<0[Jf]0000
002][Jd00P2][Jd60?nV4@8000001@3oYQ400`2][Jd0ojHA000000090?nV4@8000001`3oYQ400`00
0000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]000000000000103lX1000`00
0000o:0@0?bP40070?bP40@0[Jf]0P0000030?bP40030:f][@3fW0l0mY`?0080mY`?0P0000050?JL
3`800000203fW0l00`000000[Jf]0>bF3P030>bF3P8000001P3/UPh2000000@0k9H>00<0[Jf]0000
003KRPd00`3KRPd2000000H0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je5
0;3PiP40oooo001K0;3PiP050:f][@2GH0/0Uf0;0:f][@0000001`3CQ`h00`2][Jd0kiP@0>nH4004
0>nH40040:f][@3_V1000000000000<0kiP@00<0[Jf]0?bP400000001@3lX1000`000000o:0@0?bP
40050?bP40030000003lX100[Jf]00@0oj@A00<000000?nT4@3oY1401@3oY1400`000000oj@A0?nT
4@060?nT4@80000000<0ojHA0:f][@2][Jd0102][Jd00`3oYQ4000000?nV4@080?nV4@8000001@3o
YQ400`2][Jd0ojHA000000090?nV4@8000001`3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00@0[Jf]00000000000000000`3lX1000`000000o:0@0?bP400;0?bP40800000
1@2][Jd30?JL3`8000001@3fW0l2000000P0mY`?00<000000:f][@3/UPh00`3/UPh2000000H0k9H>
0P0000040>bF3P030:f][@000000fhX=0080fhX=0P0000000`3KRPd0[Jf]0:f][@040=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP060:f]
[@2GH0/0Uf0;09MP2`2][Jd000001`3CQ`h00`2][Jd0kiP@000000020>nH4080[Jf]0P3_V1020000
00<0kiP@00<0[Jf]0?bP40000000103lX1000`000000o:0@0?bP40060?bP40030000003lX100[Jf]
00<0oj@A0P0000070?nT4@030000003oY140oj@A00D0oj@A00@0[Jf]000000000000[Jf]1`3oYQ40
0`000000ojHA0?nV4@070?nV4@8000001@3oYQ400`2][Jd0ojHA000000090?nV4@8000001`3oYQ40
0`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]000000000000o:0@1000
000=0?bP408000000`3lX1000`2][Jd0mY`?0:f][@020:f][@8000001@3fW0l2000000P0mY`?00<0
00000:f][@3/UPh00`3/UPh2000000H0k9H>0P0000040>bF3P030:f][@3KRPd000000080fhX=0P00
00030=^:3@80[Jf]00<0fhX=0000002][Jd02@2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V
0@3oool005X0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@0000070=>73P030:f][@00000000000080
0000103_V102000000<0kiP@00<0[Jf]0?bP40000000103lX1000`000000o:0@0?bP40060?bP4003
0000003lX100[Jf]00<0oj@A0P0000070?nT4@040000003oY140oj@A0?nT4@@0[Jf]00<0oj@A0000
00000000203oYQ400`000000ojHA0?nV4@070?nV4@8000001@3oYQ400`2][Jd0ojHA000000080?nV
4@<000001P3oYQ43000000D0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd00000000000040?bP
40030000003lX100o:0@00/0o:0@0P0000030?bP40030:f][@3fW0l0mY`?0080mY`?0P0000030:f]
[@80mY`?0P0000080?JL3`030000002][Jd0k9H>00<0k9H>0P0000070>bF3P8000000`3/UPh00`2]
[Jd0fhX=000000020=^:3@8000001@3KRPd00`000000[Jf]000000090;Ue2`030:f][@28EPL0R5H7
0080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`03
0:f][@000000dhL>00H0dhL>0P0000000`2][Jd00000000000040>nH408000000`3_V1000`2][Jd0
o:0@000000040?bP40030000003lX100o:0@00D0o:0@0P0000000`3lX100[Jf]0?nT4@020?nT4@80
00001`3oY14010000000[Jf]0:f][@2][Jd50?nT4@800000203oYQ400`000000ojHA0?nV4@070?nV
4@8000001@3oYQ400`2][Jd0ojHA000000080?nV4@<000001P3oYQ43000000D0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd00000000000040?bP40030000003lX100o:0@00/0o:0@0P0000030?bP
40030:f][@3fW0l0mY`?0080mY`?0P0000030?JL3`80[Jf]0P0000080?JL3`030000002][Jd0k9H>
00<0k9H>0P0000070>bF3P8000000`3/UPh00`2][Jd0fhX=000000020=^:3@8000001@3KRPd01000
0000fhX=0000002iM@/2000000H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP11
0;3PiP40oooo001I0;3PiP070:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>000000070=>73P030000003_
V100kiP@00800000103_V102000000<0kiP@00<0[Jf]0?bP40000000103lX1000`000000o:0@0?bP
40050?bP4080000000<0o:0@0:f][@3oY1400P3oY142000000@0oj@A0`2][Jd00`000000oj@A0?nT
4@060?nT4@800000203oYQ400`000000ojHA0?nV4@070?nV4@8000001@3oYQ40102][Jd0ojHA0?nV
4@0000060?nV4@040000003oYQ40ojHA000000H0ojHA0`0000050?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]000000000000103lX1000`000000o:0@0?bP400;0?bP408000000`3lX1000`2][Jd0
mY`?0?JL3`020?JL3`8000001@3fW0l2000000@0[Jf]103fW0l00`000000[Jf]0>bF3P030>bF3P80
00001`3/UPh2000000<0k9H>00<0[Jf]0=^:3@0000000P3KRPd00`000000fhX=0=^:3@030=^:3@80
000000<0fhX=0:f][@0000000`0000050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P0000001P3CQ`h00`2]
[Jd000000>nH40020>nH40030000003_V100kiP@0080kiP@0P0000020>nH40040:f][@3lX100o:0@
000000@0o:0@00<000000?bP403lX1001@3lX102000000030?bP402][Jd0oj@A0080oj@A0P000004
0:f][@<0oj@A00<000000?nT4@3oY1401P3oY142000000P0ojHA00<000000?nV4@3oYQ401`3oYQ42
000000D0ojHA00D0[Jf]0?nV4@3oYQ40ojHA000000030?nV4@8000000`3oYQ400`000000ojHA0?nV
4@040?nV4@<000001@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@000000000000@0o:0@00<0
00000?bP403lX1002`3lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l2000000H0mY`?0P00
00030?JL3`@0[Jf]00<000000:f][@3/UPh00`3/UPh2000000L0k9H>0P0000030>bF3P040:f][@3K
RPd000000=^:3@8000001@3KRPd2000000030=^:3@2][Jd00000008000001P2iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00L0[Jf]09MP2`2GH0/0Uf0;
0:f][@3CQ`h0000000@0dhL>0P2][Jd00`3CQ`h000000>nH40020>nH40030000003_V100kiP@0080
kiP@0P0000020>nH40040:f][@3lX1000000000000@0o:0@00<000000?bP403lX1001@3lX1020000
00030?bP402][Jd0oj@A0080[Jf]0P0000070?nT4@030000003oY140oj@A00H0oj@A0P0000080?nV
4@030000003oYQ40ojHA00L0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00<0ojHA0`00000<0?nV
4@<000001@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@000000000000@0o:0@00<000000?bP
403lX1002`3lX102000000<0o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l2000000H0mY`?0P0000070?JL
3`030000002][Jd0[Jf]00<0k9H>0P0000070>bF3P8000000`3/UPh00`2][Jd0fhX=0=^:3@030000
00D0fhX=0P0000000`3KRPd0[Jf]00000002000000030:f][@2iM@/0000000<0^GD;00<0[Jf]08QF
1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP0;0:f][@2GH0/0Uf0;09MP
2`2][Jd0dhL>0000003CQ`h000000=>73P2][Jd00P3CQ`h00`000000[Jf]0>nH40020>nH40030000
003_V100kiP@0080kiP@0P0000020>nH40040:f][@3lX1000000000000@0o:0@00<000000?bP403l
X1001@3lX102000000<0[Jf]0P3oY142000000L0oj@A00<000000?nT4@3oY1401P3oY142000000P0
ojHA00<000000?nV4@3oYQ401`3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ43000000D0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd00000000000040?bP40030000003lX100o:0@00/0
o:0@0P0000030?bP40030:f][@3fW0l0mY`?0080mY`?0P0000060?JL3`8000001`3fW0l00`000000
[Jf]0>bF3P030:f][@8000001`3/UPh2000000<0k9H>00<0[Jf]0=^:3@3KRPd00`0000050=^:3@80
000000<0fhX=0:f][@2iM@/00P000000102iM@/0[Jf]0000000000020;Ue2`030:f][@28EPL0R5H7
0080R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>10000003
0=>73P030000002][Jd0kiP@0080kiP@00<000000>nH403_V1000P3_V1001P000000kiP@0>nH403_
V100[Jf]0?bP40800000103lX1000`000000o:0@0?bP40040?bP40050:f][@000000[Jf]0?bP402]
[Jd00`3oY142000000L0oj@A00<000000?nT4@3oY1401P3oY142000000P0ojHA00<000000?nV4@3o
YQ40103oYQ43000000H0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ43000000D0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd00000000000040?bP40030000003lX100o:0@00/0o:0@0P0000030?bP4003
0:f][@3fW0l0mY`?0080mY`?0P0000060?JL3`8000001`3fW0l00`000000[Jf]0>bF3P030>bF3P80
00001`3/UPh2000000<0k9H>00<0[Jf]0=^:3@3KRPd00P0000060=^:3@80000000<0fhX=0:f][@2i
M@/00P0000020;Ue2`@0000000<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V
00P0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h000000=>73P8000000`3CQ`h00`000000[Jf]0>nH4002
0>nH408000000`3_V1001P000000kiP@0>nH403_V100[Jf]0?bP40800000103lX1000`000000o:0@
0?bP40020?bP4080[Jf]00D0o:0@0000003lX100o:0@0:f][@030?nT4@8000001P3oY142000000P0
oj@A0P0000050?nV4@@000003`3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@<000001@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@000000000000@0o:0@00<000000?bP403lX1002@3lX104000000<0
o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l2000000L0mY`?0P0000060?JL3`8000001@3/UPh200000080
[Jf]103/UPh2000000<0k9H>00<0[Jf]0=^:3@3KRPd00P0000060=^:3@80000000<0fhX=0:f][@2i
M@/00P0000020;Ue2`050000002][Jd0[Jf]0000002][Jd01028EPL20:f][D80/>3V0@3oool005T0
/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h000000:f][@8000000`3CQ`h00`000000[Jf]0>nH
40020>nH408000000`3_V1001P000000kiP@0>nH403_V100[Jf]0?bP40800000103lX1000`000000
o:0@0:f][@020:f][@<0o:0@00@000000?bP403lX100[Jf]0`3oY142000000H0oj@A0P0000080?nT
4@800000603oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@<000001@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV
4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@000000000000X0o:0@00<000000?bP
403lX1002`3lX100102][Jd000000000003fW0l2000000L0mY`?0P0000060?JL3`8000001@3/UPh2
00000080k9H>0`2][Jd00`3/UPh00000000000030>bF3P030:f][@3KRPd0fhX=008000001P3KRPd2
000000030=^:3@2][Jd0^GD;008000000P2iM@/01@000000^GD;0;Ue2`000000[Jf]00@0R5H70P2]
[Je20;3PiP40oooo001I0;3PiP070:f][@2GH0/0Uf0;09MP2`000000[Jf]000000020=>73P060000
003CQ`h0dhL>0=>73P000000[Jf]0`3_V102000000<0kiP@00H000000>nH403_V100kiP@0:f][@3l
X102000000<0o:0@00<0[Jf]0000002][Jd01P3lX10010000000o:0@0?bP402][Jd30?nT4@<00000
1@3oY142000000D0oj@A1@00000H0?nV4@030:f][@3oYQ40ojHA0180ojHA0`0000050?nV4@030:f]
[@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
1@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd000000000000:0?bP40030000
003lX100o:0@00/0o:0@00<0[Jf]0?JL3`3fW0l00`0000080?JL3`800000103fW0l300000003045Y
h@3/UPh0k9H>0080k9H>0P0000050>bF3P030:f][@000000k9H>00<0k9H>00<0[Jf]0=^:3@3KRPd0
0P0000060=^:3@80000000<0fhX=0:f][@2iM@/00P0000020;Ue2`070000002iM@/0^GD;0000002]
[Jd0R5H70000000308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2G
H0/00P0000001@3CQ`h000000=>73P3CQ`h000000080dhL>0P000000102][Jd0kiP@0>nH403_V102
000000<0kiP@00H000000>nH403_V100kiP@0:f][@3lX102000000040?bP402][Jd0[Jf]0?bP4080
00001P3lX10010000000o:0@0?bP402][Jd30?nT4@<00000103oY142000000T0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@<0000000<0ojHA0:f][@2][Jd02P2][JdG0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0000
000000002P3lX1000`000000o:0@0?bP400;0?bP40030:f][@3fW0l0mY`?00`0mY`?00<000000?JL
3`3fW0l00P3fW0l3000000D0k9H>0P0000060>bF3P060000002][Jd0[Jf]0:f][@3/UPh0[Jf]0P3K
RPd2000000H0fhX=0P0000020=^:3@030:f][@00000000000080^GD;00L000000;Ue2`2iM@/0^GD;
0000002][Jd0000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;
09MP2`02000000050=>73P000000dhL>0=>73P0000000P3CQ`h2000000@0kiP@0P0000030>nH4006
0000003_V100kiP@0>nH402][Jd0o:0@0P000000102][Jd0o:0@0?bP403lX102000000D0o:0@00D0
00000?bP403lX100o:0@0:f][@030?nT4@80000000D0oj@A0000003oY140oj@A0000000;0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ460:f][@<0000000<0[Jf]0?nV4@3o
YQ400P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd000000000000:0?bP4003
0000003lX100o:0@00/0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l00`000000mY`?0?JL3`020?JL3`<0
00001P3/UPh00`000000k9H>0>bF3P040>bF3P040000003/UPh0k9H>0>bF3P<0[Jf]00<0fhX=0000
000000001P3KRPd200000080fhX=00<0[Jf]0000000000000P2iM@/01`000000^GD;0;Ue2`2iM@/0
00000:f][@0000000`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@000000
Uf0;0080000000D0dhL>0000003CQ`h0dhL>000000020=>73P800000103_V102000000<0kiP@00@0
00000>nH403_V100kiP@0P2][Jd2000000@0o:0@0P0000050?bP40050000003lX100o:0@0?bP402]
[Jd00`3oY14200000080oj@A0P00000<0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ400P3oYQ4:0:f][@H0ojHA0`0000050?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS4003
0:f][@000000000000X0o:0@00<000000?bP403lX1002`3lX1000`2][Jd0mY`?0?JL3`0=0?JL3`@0
000000<0mY`?0000000000001P3/UPh2000000D0k9H>00<000000>bF3P3/UPh00P3/UPh01P2][Jd0
fhX=0:f][@000000fhX=000000D0fhX=0P0000020=^:3@030:f][@000000000000H0^GD;00<00000
08QF1`0000000`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP80000000D0[Jf]0000
00000000dhL>000000020=>73P80000000<0dhL>000000000000103_V102000000<0kiP@00<00000
0>nH402][Jd00P2][Jd00`3lX10000000?bP40040?bP40800000103lX102000000<0o:0@00@0[Jf]
0?nT4@3oY140oj@A0P00000@0?nT4@030:f][@3oYQ40ojHA01@0ojHA202][Jd@0?nV4@030000003o
YQ40000000D0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa050:f][@80000000<0[Jf]0?bP403lX1001`3l
X1000`000000o:0@0?bP400;0?bP40030:f][@3fW0l0mY`?0180mY`?0P0000070>bF3P030000003/
UPh0k9H>00<0k9H>00<000000>bF3P3/UPh00P3/UPh01P2][Jd0fhX=000000000000[Jf]000000D0
fhX=0P0000020=^:3@030:f][@000000000000H0^GD;00@0000008QF1`000000[Jf]0P28EPL00`2]
[Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP80000000@0[Jf]00000000000000000`3CQ`h20000
00030=>73P000000000000@0kiP@0P0000030>nH40070000002][Jd0kiP@0>nH402][Jd0o:0@0000
00060?bP408000000`3lX1001P000000o:0@0?bP403lX100[Jf]0?nT4@<000004P3oY1400`2][Jd0
ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@8000001P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40040:f][@00000000000?bP40L0[Jf]00<0o:0@0000000000003@3lX1000`2]
[Jd0mY`?0?JL3`0B0?JL3`80000000<0[Jf]0>bF3P3/UPh0103/UPh2000000<0k9H>00<000000>bF
3P3/UPh00`3/UPh00`2][Jd0fhX=000000020=^:3@030000002][Jd0[Jf]00<0fhX=0P0000020=^:
3@030:f][@000000000000H0^GD;00L0000008QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3o
ool005T0/>3V00H0[Jf]0000002GH0/000000:f][@0000030=>73P80000000<0dhL>000000000000
103_V102000000040>nH402][Jd0[Jf]000000<0kiP@00<0[Jf]0?bP400000001P3lX10200000080
o:0@0P0000030?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0
ojHA00<0[Jf]0?nV4@3oYQ404`3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]000000000000203lX1000`2][Jd00000000000030:f][@X0o:0@00<0[Jf]0?JL3`3f
W0l04P3fW0l2000000030:f][@3/UPh0k9H>00D0k9H>00D000000>bF3P3/UPh0k9H>000000050>bF
3P030:f][@3KRPd000000080fhX=00<000000=^:3@3KRPd00P2][Jd20=^:3@050000003KRPd0fhX=
0:f][@2iM@/00P0000050;Ue2`0700000028EPL0R5H708QF1`2][Jd0R5H70:f][@120;3PiP40oooo
001I0;3PiP060:f][@000000Uf0;0000002][Jd000000`3CQ`h2000000030=>73P000000000000@0
kiP@00<000000:f][@2][Jd00P3_V1001`000000kiP@0>nH403_V100[Jf]0?bP400000001`3lX100
10000000o:0@0?bP400000040?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA
1P2][Jd@0?nV4@030:f][@3oYQ40ojHA01<0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@000000000000T0o:0@0P0000030?bP40L0[Jf]0`3lX1000`2][Jd0mY`?
0?JL3`0B0?JL3`80000000<0[Jf]0>bF3P3/UPh01P3/UPh010000000k9H>0000000000050>bF3P03
0:f][@3KRPd000000080fhX=00<000000=^:3@3KRPd00P3KRPd20:f][@80000000<0fhX=0:f][@2i
M@/00P0000050;Ue2`0300000028EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f]
[@000000Uf0;0000002][Jd000000`3CQ`h00`000000dhL>0=>73P02000000<0kiP@0P0000030>nH
408000000`3_V1000`2][Jd0o:0@000000080?bP408000001@3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@D0[Jf]5P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0000
000000002@3lX102000000X0o:0@1P2][JdC0?JL3`030000002][Jd0k9H>00P0k9H>0P0000060>bF
3P030:f][@3KRPd0000000<0fhX=00<000000=^:3@3KRPd00`3KRPd2000000030=^:3@11JN40^GD;
00800000102iM@/2000000D0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F02`h>H20:f][@05
0000002GH0/000000:f][@0000000`3CQ`h00`000000dhL>0=>73P02000000030>nH402][Jd0[Jf]
008000000`3_V102000000<0kiP@00<0[Jf]0?bP400000003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT
4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01P0oj<@1@0000090?bP408000003@3lX1000`2][Jd0mY`?0?JL3`040:f][@l0mY`?00<000000:f]
[@3/UPh0403/UPh00`2][Jd000000=^:3@030=^:3@030000003KRPd0fhX=00<0fhX=0P0000020:f]
[@030;Ue2`000000000000<0^GD;00@000000;Ue2`000000[Jf]1028EPL20:f][D40/>3V0@3oool0
05P0/>3V0P2][Jd3000000030:f][@000000dhL>0080dhL>00<000000=>73P3CQ`h00P0000000`2]
[Jd0kiP@0>nH4002000000<0kiP@0P0000030>nH40030:f][@3lX100000000l0o:0@00<0[Jf]0?nT
4@3oY1402`3oY1440:f][@@0oj@A00<000000:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]000000000000100000050?bP408000003@3lX1000`2]
[Jd0mY`?0?JL3`040?JL3`D0[Jf]2P3fW0l00`000000[Jf]0>bF3P0@0>bF3P030:f][@000000fhX=
00<0fhX=00<000000=^:3@3KRPd00`3KRPd2000000030=^:3@2][Jd0[Jf]008000000`2iM@/20000
00030;Ue2`2][Jd0R5H700<0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`0000000`2][Jd0
00000=>73P020=>73P030000003CQ`h0dhL>008000000`3_V102000000<0kiP@0P0000030>nH4003
0:f][@3lX100000000l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@P0oj@A00<000000:f][@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100103lX107000000d0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@D0mY`?00<000000:f][@3/
UPh03`3/UPh3000000@0fhX=00<000000=^:3@3KRPd00`3KRPd2000000030=^:3@2][Jd0^GD;0080
00000P2iM@/01@000000^GD;0000002iM@/0[Jf]00@0R5H70P2][Je10;3PiP40oooo001H0;3PiP80
[Jf]0`0000000`2][Jd000000=>73P020=>73P030000003CQ`h0[Jf]008000000`3_V102000000<0
kiP@0P0000030>nH40030:f][@3lX100000000l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@`0
oj@A0P00000I0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00h0mY`?102][Jd00`3fW0l000000:f][@0B0>bF3P<0
00000`3KRPd00`000000fhX=0=^:3@020=^:3@80000000<0fhX=0:f][@2iM@/00P000000102][Jd0
^GD;0000000000020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001H0;3PiP80
[Jf]0`000000102][Jd000000=>73P3CQ`h2000000040:f][@3CQ`h0000000000080kiP@0P000004
0>nH408000000`3_V1000`2][Jd0o:0@0000000?0?bP40030:f][@3oY140[Jf]00<0[Jf]403oY140
0`000000[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?00@0[Jf]0000002][Jd0[Jf]4@3/
UPh0102][Jd0fhX=0=^:3@3KRPd3000000@0fhX=0P0000000`3KRPd0[Jf]0;Ue2`02000000040;Ue
2`000000^GD;00000080^GD;00<0[Jf]00000028EPL00P28EPL20:f][D40/>3V0@3oool005P0/>3V
0P2][Jd3000000040:f][@000000dhL>0=>73P8000000P3CQ`h200000080kiP@0P0000040>nH4080
00000`3_V1000`2][Jd0o:0@0000000>0?bP40<0[Jf]503oY1400`000000[Jf]0?nV4@0H0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<000000:f][@3/UPh00`2][Jd>0>bF3P030:f][@3KRPd0fhX=00<0
fhX=0`0000020=^:3@80000000<0fhX=0:f][@2iM@/00P0000000`2iM@/00000000000020;Ue2`03
045Yh@2][Jd0000000<0R5H70P2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`000000102][Jd00000
0=>73P2][Jd200000080dhL>0P0000020>nH40800000103_V102000000<0kiP@00<0[Jf]00000000
0000303lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030000002][Jd0k9H>00<0k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00L0
fhX=0`0000000`3KRPd0[Jf]0;Ue2`02000000030;Ue2`00000000000080[Jf]00<0^GD;0:f][@00
00000`28EPL20:f][D40/>3V0@3oool005P0/>3V0P2][Jd20000000509MP2`2][Jd000000:f][@3C
Q`h00P0000030=>73P040000003_V1000000000000D0kiP@0P0000030>nH40030:f][@0000000000
00T0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`0C0?JL3`030000002][Jd0k9H>00D0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=
00P0fhX=0P0000000`3KRPd0[Jf]0;Ue2`02000000030;Ue2`00000000000080^GD;0P2][Jd01000
0000R5H708QF1`28EPL20:f][D40/>3V0@3oool005P0/>3V0P2][Jd20000000309MP2`2][Jd00000
0080dhL>0P0000030=>73P030000003_V100000000H0kiP@00<000000>nH403_V1000P3_V1000`2]
[Jd00000000000070?bP4080[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`000000[Jf]0>bF3P080>bF3P<0[Jf]1P3/UPh00`2]
[Jd0fhX=0=^:3@090=^:3@040000003KRPd0[Jf]0;Ue2`8000000P2iM@/01P000000^GD;0;Ue2`00
0000[Jf]000000<0R5H70P2][Je10;3PiP40oooo001H0;3PiP070:f][@2GH0/000000000002GH0/0
[Jf]000000020=>73P030000003CQ`h0dhL>0080dhL>00<0[Jf]0000003_V1001P3_V1000`000000
kiP@0>nH40020>nH40030:f][@000000000000@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0
ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0@0?JL3`80000000<0mY`?0000002][Jd0303/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd0102][Jd000000000000000020;Ue2`060000002iM@/0^GD;0000002][Jd000000`28
EPL20:f][D40/>3V0@3oool005P0/>3V00@0[Jf]09MP2`00000000000P2][Jd010000000dhL>0=>7
3P0000030=>73P030:f][@3_V100kiP@00L0kiP@00<000000>nH403_V1000P3_V100102][Jd00000
0000003lX1030:f][@/0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`80
000000<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]00000000
00000P2iM@/01P000000^GD;0;Ue2`000000[Jf]000000<0R5H70P2][Je10;3PiP40oooo001H0;3P
iP040:f][@2GH0/0000000000080[Jf]00@000000=>73P3CQ`h000000`3CQ`h00`2][Jd0kiP@0>nH
40070>nH40030000003_V100kiP@0080kiP@00@0[Jf]000000000000[Jf]3P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V
3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`050000002iM@/0^GD;0000002]
[Jd00P0000001028EPL0@FWQ0:f][@2][Je10;3PiP40oooo001H0;3PiP060:f][@2GH0/000000000
002GH0/0[Jf]0P0000000`3CQ`h000000=>73P020=>73P030:f][@3_V100kiP@00L0kiP@00@00000
0>nH403_V100kiP@0P2][Jd2000000l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f]
[@2][Jd;0=^:3@030:f][@2iM@/0^GD;0080^GD;00D000000;Ue2`2iM@/000000:f][@0200000080
R5H70P2][Je10;3PiP40oooo001H0;3PiP060:f][@2GH0/000000000002GH0/0[Jf]0`0000040=>7
3P030:f][@3_V100kiP@00L0kiP@00H000000>nH402][Jd0[Jf]0>nH402][Jd2000000l0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2]
[Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0
[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00<0^GD;00<000000;Ue2`000000
0`000000102][Jd0R5H70:f][@2][Je10;3PiP40oooo001H0;3PiP060:f][@000000[Jf]0000002G
H0/0[Jf]0`0000040=>73P030:f][@3_V100kiP@00L0kiP@00<000000:f][@3_V1000P3_V1000`2]
[Jd000000000000?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f]
[ID0/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030000002iM@/00000
0080000000@0R5H70:f][@2][Jd0[Jf]@@2`h>H10?ooo`00F02`h>H01P2][Jd0000009MP2`000000
Uf0;0:f][@8000001@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]00<000000>nH403_V1000P3_
V1000`2][Jd000000000000?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3o
YQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`<0000000@0
R5H70:f][@2][Jd0[Jf]@@2`h>H10?ooo`00F02`h>H01`2][Jd0000009MP2`000000Uf0;0:f][@00
00001P3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]0P3_V1000`000000kiP@0>nH40020>nH4003
0:f][@000000000000l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0
[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0000008QF1`00
00000P28EPL20:f][D40/>3V0@3oool005L0/>3V0P2][Jd01@000000Uf0;0000002GH0/0000000L0
dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40>nH40040000003_V100kiP@0>nH408000004@3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0
[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2]
[Jd00`3KRPd0[Jf]0;Ue2`080;Ue2`040:f][@000000R5H708QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H20:f][@<0000000<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f][@2][Jd60>nH40030000
003_V100kiP@0080kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]
a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]
2@2iM@/0102][Jd0000008QF1`28EPL20:f][D40/>3V0@3oool005L0/>3V0P2][Jd20000000309MP
2`2][Jd0dhL>00L0dhL>0P2][Jd60>nH40<00000103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=0`2][Jd70;Ue2`040:f][@000000R5H708QF1`80[Jf]@@2`h>H10?ooo`00
E`2`h>H20:f][@80000000<0Uf0;0:f][@3CQ`h01P3CQ`h20:f][@h0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00H0[Jf]00000028
EPL0R5H70:f][@11JN510;3PiP40oooo001G0;3PiP80[Jf]0P0000000`2GH0/0[Jf]0=>73P040=>7
3P80[Jf]00<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A
00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`060:f][@000000R5H708QF1`2][Jd0@FWQ
@@2`h>H10?ooo`00E`2`h>H20:f][@80000000<0Uf0;0:f][@3CQ`h00`3CQ`h01@2][Jd0dhL>0=>7
3P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V
1@2][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`020;Ue2`80[Jf]0`2iM@/01P2][Jd0000008QF1`28EPL0[Jf]045YhD40/>3V0@3oool005L0
/>3V0P2][Jd20000000309MP2`2][Jd0dhL>0080dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0P0000000`28
EPL0[Jf]045Yh@110;3PiP40oooo001G0;3PiP80[Jf]0P0000000`2GH0/0[Jf]0=>73P020:f][@D0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0[Jf]0P0000000`28EPL0
[Jf]045Yh@110;3PiP40oooo001G0;3PiP80[Jf]0P0000000`2GH0/0[Jf]0:f][@070=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]
00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]0000000000000P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP060:f]
[@2GH0/000000000002GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd000000000000208QF1`030:f][@2`h>H0/>3V
03l0/>3V0@3oool005L0/>3V00@0[Jf]09MP2`00000000000P2][Jd80=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3P
iP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@00000000000080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00E`2`h>H0102][Jd0
Uf0;0000002GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP
4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk
00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;
00L0^GD;00<0[Jf]0000000000000P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3PiP06
0:f][@2GH0/000000:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100
[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H3
0:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@00000000000080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H1
0?ooo`00E`2`h>H00`2][Jd0Uf0;0000000209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH
403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg
[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji
^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@000000R5H70:f][@28EPL0[Jf]@@2`
h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0000000209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]
0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[007
0;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^007
0;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@000000R5H708QF1`80[Jf]@@2`
h>H10?ooo`00E`2`h>H20:f][@040000002GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1001P3_
V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`
h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H20:f][@040000002GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BN
S`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0
_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D00/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2GH0/0
0P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080[Jf]0P2TWXl00`11JN40
Y9j?0:f][@040;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]045Yh@2]
[Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je00;3P
iP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0:f][@2][Jd2
0:BNS`@0@FWQ00<0[Jf]0;6[W@2aZid0102aZid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2]
[Jd80;ji^080@FWQ0P2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@80@FWQ
0P2TWXl3045Yh@030:BNS`2][Jd0/J^M00L0/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@L0
_[Vh00<0@FWQ0;ji^02n^KP00P11JN420;B`/@04045Yh@2d/;40[Jf]0:f][@X0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0
0`2][Jd0Y9j?0:BNS`02045Yh@<0Y9j?00H0@FWQ0:BNS`2TWXl0[Jf]0;6[W@11JN480;6[W@80[Jf]
00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`
1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00D0[Jf]0<>m^`33_K/0`kfk045Yh@0:0<>m^`<0[Jf]1`2n^KP2045Yh@<0_[Vh0P11JN460;B`/@80
[Jf]202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@060=>73P80[Jf]0`2TWXl2045Yh@<0Y9j?00H0@FWQ0:BNS`2TWXl0[Jf]0;6[W@11
JN4:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0
[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l0100a/2l00@0[Jf]045Yh@11JN40@FWQ2033_K/30:f][@030<>m^`2][Jd0_[Vh00H0
_[Vh0`11JN420;ji^080@FWQ202d/;400`11JN40[Jf]0;Ue2`060;Ue2`040:f][@28EPL0R5H708QF
1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00<0[Jf]045Y
h@2][Jd0102TWXl01`11JN40Y9j?0:BNS`2TWXl0@FWQ0:BNS`2][Jd00P2aZid01@11JN40/J^M0;6[
W@2aZid0@FWQ00L0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0<0@FWQ1P33_K/30:f][@@0`kfk
00@0[Jf]0;ji^02n^KP0_[Vh0`11JN420;ji^080@FWQ0P2n^KP2045Yh@030:f][@2d/;40];2a00@0
];2a0P11JN400`2d/;40[Jf]0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?oo
o`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00@0[Jf]045Yh@11JN40[Jf]102TWXl0
1`11JN40Y9j?0:BNS`2TWXl0@FWQ0:BNS`2][Jd00P2aZid01@11JN40/J^M0;6[W@2aZid0@FWQ00L0
/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]045Yh@11JN400P33_K/40:f][@L0
`kfk00<0[Jf]0;ji^011JN400P11JN440;ji^080@FWQ0P2n^KP2045Yh@030:f][@2d/;40];2a00@0
];2a00@0@FWQ0;B`/@2][Jd0@FWQ0`2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H1
0?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00@0[Jf]08Z5M@11JN40@FWQ0`2]
[Jd20:BNS`08045Yh@2TWXl0Y9j?0:BNS`11JN40Y9j?0:f][@2aZid2045Yh@<0/J^M00<0@FWQ0;6[
W@2aZid01@2aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn
]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]045Yh@11JN400P2][Jd;0<>m^`05045Yh@2n^KP0_[Vh
0;ji^011JN40102n^KP2045Yh@80_[Vh0P11JN400`2][Jd0];2a0;B`/@040;B`/@08045Yh@2][Jd0
];2a045Yh@2][Jd0@FWQ09nKX02][Jd20;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?oo
o`00E`2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]00D0@FWQ08Z5M@11JN40@FWQ0:f]
[@020:BNS`040:f][@2TWXl0Y9j?045Yh@80Y9j?00@0@FWQ0:BNS`2][Jd0/J^M0`11JN420;6[W@03
045Yh@2aZid0/J^M00D0/J^M00<0[Jf]0;VbYP11JN402@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0
aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`03`36`;`20:f][@80@FWQ2`33_K/2045Yh@050:f][@2n^KP0_[Vh0;ji
^011JN40102n^KP2045Yh@80_[Vh0P11JN400`2][Jd0];2a0;B`/@030;B`/@80@FWQ0P2d/;401@11
JN40[Jf]045Yh@11JN40Wi^P00<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd208Z5M@@0@FWQ00@0[Jf]045Yh@2TWXl0Y9j?0P2][Jd0
1`2TWXl0@FWQ045Yh@11JN40Y9j?0:f][@2aZid00`11JN400`2aZid0@FWQ045Yh@070;6[W@80@FWQ
00<0^K:V045Yh@2i/ZH02`2i/ZH30:f][@h0_[N/0P11JN400`2n]j`0[Jf]0<6j/00C0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]
2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00@0a/2l0:f][@11JN40@FWQ2P33_K/3045Yh@05
0:f][@2n^KP0_[Vh0;ji^011JN40102n^KP2045Yh@80_[Vh0P11JN40102][Jd0];2a0;B`/@11JN42
0:f][@80@FWQ0P2d/;401011JN40[Jf]09nKX011JN4309nKX0030:f][@28EPL0R5H70080R5H700<0
[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`060:f][@11JN40
RXEe08Z5M@11JN40RXEe0P11JN400`2][Jd0@FWQ045Yh@030:BNS`80[Jf]0P11JN400`2TWXl0[Jf]
0;6[W@03045Yh@040;6[W@11JN40@FWQ045Yh@D0/J^M00D0@FWQ0:f][@2i/ZH0^K:V045Yh@020;Vb
YP03045Yh@2i/ZH0^K:V00P0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd<0;jg[080@FWQ5031^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f]
[@D0a/2l00<0[Jf]045Yh@11JN402`33_K/2045Yh@050:f][@2n^KP0_[Vh0;ji^011JN40102n^KP2
045Yh@80_[Vh0P11JN400`2][Jd0];2a0;B`/@02045Yh@030;B`/@11JN40];2a0080];2a00@0@FWQ
0:f][@2OVj00@FWQ102OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00@0
[Jf]09MP2`2GH0/0Uf0;0P2][Jd01011JN40RXEe08Z5M@11JN4208Z5M@03045Yh@2][Jd0@FWQ0080
Y9j?0P11JN420:BNS`80@FWQ00<0Y9j?0:f][@2aZid00`11JN40102aZid0@FWQ045Yh@11JN450;6[
W@03045Yh@2][Jd0^K:V0080^K:V00<0@FWQ0;VbYP11JN400`2i/ZH2045Yh@D0^K:V00<0[Jf]0;jg
[02n]j`00`2n]j`40:f][@P0_[N/1011JN4A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0@FWQ045Yh@020<>m
^`80@FWQ1`33_K/2045Yh@050<>m^`2][Jd0_[Vh0;ji^011JN40102n^KP2045Yh@80_[Vh0P11JN40
0`000000[Jf]0:f][@02045Yh@040;B`/@11JN40];2a0;B`/@80@FWQ00<0[Jf]09nKX011JN40102O
Vj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd01011JN40RXEe045Yh@11JN4308Z5M@80@FWQ0P2TWXl2045Yh@80Y9j?0P11JN420:f][@08
0;6[W@11JN40@FWQ045Yh@2aZid0@FWQ0;6[W@11JN440;6[W@80@FWQ00L0[Jf]0;VbYP2i/ZH0^K:V
045Yh@2i/ZH0@FWQ00@0^K:V1011JN420;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd40;jg[080
@FWQ4`31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02]
[Jd00`2][Jd=0<K0_0050:f][@11JN40@FWQ0<>m^`11JN400P33_K/2045Yh@D0`kfk0P11JN401@33
_K/0[Jf]0;ji^02n^KP0@FWQ00D0_[Vh00<0@FWQ0;ji^02n^KP00P11JN400`2][Jd0];2a0;B`/@02
045Yh@80];2a00L0@FWQ0;B`/@11JN40];2a0:f][@2OVj00@FWQ00D0Wi^P00@0[Jf]08QF1`28EPL0
[Jf]@02`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`020:f][@80@FWQ00<0RXEe045Yh@11JN40
0`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`04045Yh@2TWXl0Y9j?045Yh@80Y9j?0P2][Jd01`11JN40
/J^M045Yh@2aZid0@FWQ0;6[W@11JN40102aZid2045Yh@030:f][@2i/ZH0^K:V0080^K:V0P11JN44
0;VbYP80@FWQ102i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]0P11JN4C0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][@l0a/2l0P11JN40102][Jd0@FWQ045Yh@11
JN430<>m^`03045Yh@33_K/0@FWQ00@0`kfk0P11JN401033_K/0[Jf]0;ji^02n^KP2045Yh@@0_[Vh
00H0@FWQ0;ji^02][Jd0[Jf]045Yh@2][Jd30;B`/@05045Yh@2d/;40];2a0;B`/@11JN400P2d/;40
0`2][Jd0Wi^P045Yh@0509nKX080[Jf]00<0R5H70:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102]
[Jd0Uf0;0:f][@1SH5<20:f][@03045Yh@2:QGD0@FWQ00<0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl0
1011JN40Y9j?0:BNS`11JN420:BNS`090:f][@2aZid0@FWQ0:f][@11JN40/J^M045Yh@2aZid0@FWQ
00@0/J^M0P11JN400`2][Jd0^K:V0;VbYP030;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN440;Vb
YP030:f][@2n]j`0_[N/00l0_[N/0P11JN420:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00=0<K0_004045Yh@36`;`0a/2l
0:f][@<0@FWQ1033_K/2045Yh@@0`kfk0P11JN401033_K/0[Jf]0;ji^02n^KP2045Yh@@0_[Vh00H0
@FWQ0:f][@2n^KP0_[Vh045Yh@2][Jd20;B`/@03045Yh@2d/;40];2a00D0];2a00<0[Jf]09nKX011
JN401@2OVj00102][Jd0L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<0102][Jd0
RXEe045Yh@11JN4308Z5M@030:f][@2TWXl0Y9j?00<0Y9j?00@0@FWQ0:BNS`2TWXl0@FWQ0P2TWXl0
2@2][Jd0@FWQ045Yh@2aZid0@FWQ0:f][@11JN40/J^M045Yh@040;6[W@03045Yh@2aZid0[Jf]00@0
^K:V0P11JN440;VbYP80@FWQ102i/ZH00`2][Jd0_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00P0
_[N/0P11JN420<6j/0D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0
al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00P0a/2l1011JN401@36`;`0@FWQ0<K0_036`;`0[Jf]
0080@FWQ1@33_K/2045Yh@@0`kfk0P11JN401033_K/0[Jf]0;ji^02n^KP2045Yh@050;ji^02][Jd0
[Jf]0:f][@11JN400`2n^KP01@11JN40[Jf]0;B`/@2d/;40@FWQ00L0];2a00<0[Jf]09nKX011JN40
102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]1@2:
QGD00`2][Jd0Y9j?0:BNS`040:BNS`80@FWQ0`2TWXl02@2][Jd0@FWQ045Yh@2aZid0@FWQ0;6[W@11
JN40[Jf]045Yh@040;6[W@03045Yh@2aZid0[Jf]00@0^K:V0P11JN440;VbYP80@FWQ102i/ZH00`2]
[Jd0_[N/0;jg[0020;jg[080@FWQ00<0_[N/045Yh@11JN40202n]j`2045Yh@L0`KZ`1@2][Jd70<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l
00L0a/2l00@0@FWQ0<K0_036`;`0a/2l0`11JN420<K0_0030:f][@11JN40@FWQ00H0`kfk00<0@FWQ
0<>m^`33_K/00P33_K/2045Yh@040<>m^`2][Jd0_[Vh0;ji^080@FWQ00D0[Jf]0;ji^02n^KP0_[Vh
045Yh@040;ji^003045Yh@2d/;40@FWQ00P0];2a00<0[Jf]09nKX011JN400`2OVj000`2][Jd0Wi^P
0:f][@02071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:
QGD0[Jf]00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0@FWQ045Yh@020;6[W@80@FWQ00<0
/J^M045Yh@2][Jd00P2][Jd0102aZid0@FWQ0;6[W@2][Jd40;VbYP80@FWQ102i/ZH2045Yh@<0^K:V
00<0[Jf]0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ0P2n]j`2045Yh@80_[N/
0P11JN4<0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`00`2][Jd0a/2l
0<K0_0060<K0_003045Yh@36`;`0a/2l00<0a/2l0P11JN420<K0_0040:f][@33_K/0@FWQ045Yh@D0
`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@040<>m^`2][Jd0_[Vh0:f][@80@FWQ102n^KP00`11
JN40_[Vh0;ji^0020;ji^0030:f][@11JN40];2a00P0];2a00<0[Jf]09nKX011JN400P2OVj00102]
[Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=P
D`040:f][@2:QGD0RXEe0:f][@<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl3045Yh@80/J^M00D0@FWQ
0;6[W@2aZid0/J^M045Yh@020;6[W@040:f][@11JN40/J^M0:f][@@0^K:V0P11JN440;VbYP80@FWQ
0`2i/ZH00`2][Jd0_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[011JN40
102n]j`2045YhA40`KZ`202][Jd@0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00=0<O1_0@0@FWQ
00<0[Jf]0<K0_036`;`01@36`;`2045Yh@D0a/2l0P11JN420<K0_0040:f][@33_K/0@FWQ045Yh@D0
`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@<0[Jf]00<0_[Vh045Yh@11JN40102n^KP00`11JN40
_[Vh0;ji^0020;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX011JN400P2][Jd309nKX003
0:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`050:f]
[@2:QGD0RXEe08Z5M@2][Jd00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@11JN40@FWQ0080
/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@020;6[W@80@FWQ0`2][Jd20;VbYP<0@FWQ102i/ZH2045Y
h@<0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ102n]j`2045Y
h@80`KZ`0P11JN4?0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]
0<O1_037`K`02`37`K`4045Yh@80al6l00<0[Jf]0<K0_036`;`01@36`;`2045Yh@D0a/2l0P11JN42
0<K0_0040:f][@33_K/0@FWQ045Yh@D0`kfk0P11JN420<>m^`050:f][@11JN40@FWQ0<>m^`2][Jd0
0P2n^KP2045Yh@@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f]
[@2OVj00[Jf]00D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1S
H5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@0;0:BNS`060:f][@2a
Zid0/J^M045Yh@2aZid0@FWQ0`2aZid00`11JN40/J^M0;6[W@02045Yh@030000002][Jd0^K:V00<0
[Jf]00@0^K:V045Yh@11JN40@FWQ0P2i/ZH00`11JN40^K:V0;VbYP020;VbYP030:f][@2n]j`0_[N/
00<0_[N/00<0@FWQ0;jg[02n]j`0102n]j`2045Yh@@0_[N/1011JN420<6j/003045Yh@31^[00`KZ`
00`0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f]
[A80b<6k00<0[Jf]0<O1_037`K`00`37`K`00`11JN40al6l0<O1_002045Yh@D0al6l0P11JN420<O1
_0030:f][@36`;`0a/2l00D0a/2l0P11JN450<K0_080@FWQ0P36`;`0102][Jd0`kfk045Yh@11JN45
0<>m^`80@FWQ0P2][Jd01@33_K/0@FWQ045Yh@33_K/0[Jf]0080_[Vh0P11JN440;ji^003045Yh@2n
^KP0_[Vh0080_[Vh00<0[Jf]0;B`/@2d/;40202d/;420:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD2
0:f][@/0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid01@11JN40/J^M0;6[W@2aZid0@FWQ0080/J^M0P11
JN400`2aZid0[Jf]0;VbYP030;VbYP<0[Jf]0`2i/ZH2045Yh@<0^K:V00<0[Jf]0;jg[02n]j`00`2n
]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ102n]j`2045Yh@D0`KZ`00<0@FWQ0<6j/031^[001031
^[06045Yh@030<6j/02][Jd0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1
_037`K`2045Yh@030<O1_011JN40@FWQ0080@FWQ1@37`K`2045Yh@80al6l00<0[Jf]0<K0_036`;`0
1@36`;`2045Yh@D0a/2l0P11JN420<K0_0040:f][@33_K/0@FWQ045Yh@@0`kfk00<0[Jf]045Yh@33
_K/01033_K/2045Yh@030:f][@2n^KP0_[Vh0080@FWQ0P2n^KP2045Yh@D0_[Vh00<0[Jf]0;B`/@2d
/;40202d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0@FWQ0P2aZid2045Yh@030;6[W@2][Jd0^K:V00H0
^K:V0`2][Jd2045Yh@<0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[0040;jg[080
@FWQ102n]j`2045Yh@D0`KZ`0P11JN470<6j/080@FWQ0`31^[000`2][Jd0@FWQ045Yh@02045YhA40
`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0@FWQ045Y
h@D0al6l0P11JN450<O1_080@FWQ0P37`K`00`2][Jd0a/2l0<K0_0050<K0_080@FWQ1@36`;`2045Y
h@80a/2l00D0[Jf]0<>m^`11JN40@FWQ0<>m^`030:f][@030<>m^`11JN40`kfk00@0`kfk0P11JN40
102][Jd0_[Vh045Yh@11JN4:0;ji^0030:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`
KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe
0`2][Jd90:BNS`030:f][@2aZid0/J^M00H0/J^M0P11JN401@2aZid0@FWQ045Yh@2aZid0[Jf]00X0
^K:V0P11JN420:f][@030;VbYP2][Jd0_[N/00@0_[N/0P11JN450;jg[080@FWQ102n]j`2045Yh@H0
`KZ`0P11JN460<6j/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`04045Yh@80`kfc0`11JN4:0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0:0<S1^`03045Yh@38`K/0b<6k00H0b<6k00@0[Jf]0<O1_011
JN40@FWQ1@37`K`2045Yh@D0al6l0P11JN420<O1_0030:f][@36`;`0a/2l00D0a/2l00<0@FWQ0<K0
_011JN401036`;`2045Yh@80a/2l00D0[Jf]0<>m^`11JN40@FWQ0:f][@040<>m^`03045Yh@33_K/0
`kfk00<0`kfk1@11JN4;0;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d/;40[Jf]1`2O
Vj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C
0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@090;6[W@80@FWQ
00<0/J^M0:f][@2i/ZH02@2i/ZH2045Yh@80^K:V0`2][Jd50;jg[003045Yh@2n]j`0_[N/00<0_[N/
00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@H0`KZ`0P11JN460<6j/080@FWQ0`31^[000`2][Jd0`kfc
0<>m/`02045Yh@H0`kfc1011JN470<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
4`38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`060<S1^`030:f]
[@11JN40@FWQ00H0al6l0P11JN450<O1_080@FWQ0P37`K`00`2][Jd0a/2l0<K0_0060<K0_0@0@FWQ
0P36`;`2045Yh@@0[Jf]0P11JN440<>m^`80@FWQ1@33_K/2045Yh@030:f][@2n^KP0_[Vh00/0_[Vh
00<0[Jf]0;B`/@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii
071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0
Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid00`11JN40
/J^M0:f][@0:0;VbYP80@FWQ0`2i/ZH00`2][Jd0_[N/0:f][@030:f][@80_[N/00<0@FWQ0;jg[02n
]j`00P2n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ1P31^[02045Yh@H0`KZ`0P11JN430<6j/003
0:f][@33_K<0`kfc0080@FWQ1P33_K<2045Yh@T0`kfc0`11JN4D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00/0
b<6k1011JN430<S1^`03045Yh@38`K/0[Jf]00H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40
b<6k0<S1^`060<S1^`030:f][@11JN40@FWQ00L0al6l00<0@FWQ0<O1_037`K`00`37`K`2045Yh@80
al6l00<0[Jf]0<K0_036`;`02@36`;`00`2][Jd0@FWQ045Yh@02045Yh@80a/2l00@0[Jf]0<>m^`11
JN40@FWQ1033_K/00`11JN40`kfk0<>m^`040<>m^`80@FWQ00<0[Jf]0;ji^02n^KP02`2n^KP0102]
[Jd0];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2]
[Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2T
WXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid00`11JN40/J^M0:f][@0:0;VbYP80@FWQ0`2i
/ZH00`11JN40_[N/0;jg[0030;jg[0<0[Jf]0P11JN420;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11
JN460<6j/080@FWQ1P31^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN460<>m/`80@FWQ1`33
_K<2045Yh@030:f][@35_[D0aKje0080@FWQ1P35_[D01011JN40aKje0<Fn]@35_[D4045Yh@@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01@0al6j
0`11JN4;0<S1^`03045Yh@38`K/0b<6k0080b<6k00H0@FWQ0<S1^`38`K/0@FWQ0<S1^`2][Jd60<S1
^`03045Yh@38`K/0b<6k0080b<6k0`11JN470<S1^`80@FWQ2037`K`00`11JN40al6l0<O1_0030<O1
_080@FWQ0P37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]0`36`;`2045Yh@80a/2l00@0[Jf]0<>m
^`11JN40@FWQ0`33_K/2045Yh@H0`kfk0P11JN400`2][Jd0_[Vh0;ji^0060;ji^003045Yh@2n^KP0
_[Vh0080_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`
KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BN
S`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@03045Yh@2][Jd0^K:V00X0^K:V00<0
@FWQ0;VbYP11JN400P2i/ZH00`11JN40_[N/0;jg[0070;jg[0040:f][@11JN40@FWQ045Yh@D0_[N/
0P11JN460<6j/080@FWQ1P31^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN460<>m/`80@FWQ
1P33_K<2045Yh@030<>m/`2][Jd0aKje00<0aKje00<0@FWQ0<Fn]@35_[D00`35_[D01011JN40aKje
045Yh@11JN440<Fn]@05045Yh@35_[D0aKje0<Fn]@2][Jd00`36_kL00`11JN40a[ng0<Jo]`0A0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P11JN402011JN480<O1^P@0@FWQ00<0al6j0:f]
[@38`K/02P38`K/2045Yh@D0b<6k0`11JN400`38`K/0[Jf]0<S1^`040<S1^`<0@FWQ0`38`K/3045Y
h@L0b<6k0P11JN480<O1_003045Yh@37`K`0al6l00@0al6l0P11JN401037`K`0[Jf]0<K0_036`;`5
0:f][@L0a/2l00H0@FWQ0<K0_036`;`0a/2l0:f][@33_K/3045Yh@030<>m^`11JN40@FWQ00L0`kfk
0P11JN400`2][Jd0_[Vh0;ji^0060;ji^080@FWQ0`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj00
1@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0
[Jf]0:BNS`2TWXl01`2TWXl30:f][@`0/J^M0P11JN460;VbYP03045Yh@2i/ZH0^K:V00<0@FWQ00@0
^K:V045Yh@2i/ZH0^K:V0P11JN440;jg[080@FWQ1@2n]j`00`11JN40[Jf]0:f][@020:f][@030;jg
[011JN40@FWQ00H0`KZ`0P11JN460<6j/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`02045Yh@H0`kfc
0P11JN450<>m/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn]@020<Fn]@03045Yh@35_[D0aKje00<0aKje
0P11JN460<Fn]@05045Yh@35_[D0aKje0<Fn]@2][Jd00P36_kL2045YhA<0a[ng00<0[Jf]0<O1^037
`KP05037`KP0102][Jd0al6j0<O1^P37`KX2045Yh@D0al6j0P11JN480<O1^P80@FWQ00<0al6j0:f]
[@38`K/02@38`K/2045Yh@L0b<6k0P11JN400`38`K/0[Jf]0<S1^`040<S1^`<0@FWQ0`38`K/3045Y
h@L0b<6k0P11JN480<O1_0<0@FWQ1037`K`2045Yh@@0[Jf]1P36`;`2045Yh@@0a/2l00H0@FWQ0<K0
_036`;`0a/2l0:f][@33_K/2045Yh@030<>m^`11JN40`kfk00P0`kfk0P11JN400`2][Jd0_[Vh0;ji
^0060;ji^004045Yh@2n^KP0_[Vh0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f]
[@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2]
[Jd;0;6[W@80@FWQ1P2i/ZH00`11JN40^K:V0;VbYP050;VbYP04045Yh@2i/ZH0@FWQ045Yh@@0_[N/
0P11JN450;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]045Yh@11JN400P2][Jd40<6j/080@FWQ
1P31^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN460<>m/`80@FWQ1@33_K<2045Yh@80`kfc
00<0[Jf]0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@020<Fn]@03045Yh@35_[D0aKje00H0aKje
00@0@FWQ0<Fn]@35_[D0[Jf]0`36_kL00`11JN40a[ng0<Jo]`0A0<Jo]`030:f][@37`KP0al6h01@0
al6h00@0[Jf]0<O1^P37`KX0al6j0P11JN460<O1^P80@FWQ1`37`KX2045Yh@030<O1^P2][Jd0b<6k
00T0b<6k0P11JN470<S1^`80@FWQ00<0b<6k0:f][@38`K/01038`K/3045Yh@<0b<6k0`11JN460<S1
^`80@FWQ1P37`K`4045Yh@80al6l102][Jd2045Yh@030<O1_02][Jd0a/2l00L0a/2l0P11JN440<K0
_004045Yh@36`;`0a/2l0<K0_0<0@FWQ3033_K/2045Yh@030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd0
0`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3P
iP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]202aZid2045Y
h@D0^K:V0P11JN480;VbYP80@FWQ1P2n]j`00`11JN40_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/
00<0_[N/0P11JN420<6j/0@0[Jf]0P11JN400`2][Jd0`KZ`0<6j/0030<6j/080@FWQ0`31^[000`2]
[Jd0`kfc0<>m/`02045Yh@H0`kfc0P11JN440<>m/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@080<Fn
]@03045Yh@35_[D0aKje00H0aKje00@0@FWQ0<Fn]@35_[D0[Jf]5`36_kL00`2][Jd0al6h0<O1^00D
0<O1^0040:f][@37`KX0al6j0<O1^P80@FWQ1`37`KX2045Yh@H0al6j0P11JN400`37`KX0[Jf]0<S1
^`090<S1^`80@FWQ1`38`K/2045Yh@030<S1^`2][Jd0b<6k00@0b<6k0`11JN430<S1^`03045Yh@38
`K/0@FWQ00H0b<6k0P11JN470<O1_0D0[Jf]1037`K`2045Yh@050<O1_02][Jd0a/2l0<K0_011JN40
1@36`;`00`11JN40a/2l0<K0_0020<K0_003045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/0
3033_K/2045Yh@030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a
00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:
QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@80@FWQ102i
/ZH2045Yh@T0^K:V00<0[Jf]0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0020;jg[003045Yh@2n
]j`0_[N/00@0_[N/0P11JN460<6j/003045Yh@31^[00`KZ`00D0[Jf]0P11JN430<6j/0030:f][@33
_K<0`kfc0080@FWQ1P33_K<2045Yh@@0`kfc0P11JN430<>m/`030:f][@35_[D0aKje0140aKje00@0
@FWQ0<Fn]@35_[D0[Jf]5`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ
1`37`KX2045Yh@H0al6j0P11JN400`37`KX0[Jf]0<S1^`090<S1^`80@FWQ1`38`K/2045Yh@030<S1
^`2][Jd0b<6k00@0b<6k00<0@FWQ0<S1^`11JN400P38`K/2045Yh@80b<6k00<0@FWQ0<S1^`38`K/0
0`38`K/2045Yh@0300000037`K`0[Jf]00@0[Jf]2@37`K`2045Yh@060<O1_02][Jd0a/2l045Yh@36
`;`0@FWQ1@36`;`5045Yh@@0a/2l00<0[Jf]0<>m^`33_K/03033_K/2045Yh@030:f][@2n^KP0_[Vh
00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2]
[Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid2045Yh@<0^K:V0P11JN4:0;VbYP03
0:f][@2n]j`0_[N/00D0_[N/1011JN470;jg[080@FWQ1P31^[000`11JN40`KZ`0<6j/0050<6j/080
@FWQ1P2][Jd2045Yh@H0`kfc0P11JN440<>m/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@0@0<Fn]@80
@FWQ0P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX00P11JN480<O1^P80@FWQ1@37`KX2045Yh@030<O1^P2][Jd0b<6k00T0b<6k0P11JN470<S1^`80
@FWQ00<0b<6k0:f][@38`K/00`38`K/2045Yh@80b<6k00@0@FWQ0<S1^`11JN40@FWQ0P38`K/01011
JN40b<6k0<S1^`38`K/20:f][@80@FWQ0P2][Jd>0<O1_0<0@FWQ00<0[Jf]0<K0_036`;`00P11JN4?
0<K0_0030:f][@33_K/0`kfk00/0`kfk0P11JN40102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3o
ool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00L0/J^M0`2][Jd0102aZid0[Jf]045Yh@11JN420;VbYP80@FWQ2P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0<0@FWQ1031^[000`11JN40`KZ`0<6j/0050<6j/080@FWQ1031^[000`2][Jd0`kfc0<>m
/`02045Yh@H0[Jf]0P11JN440<>m/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]@80@FWQ0`35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00P11
JN480<O1^P80@FWQ1@37`KX2045Yh@030<O1^P2][Jd0b<6k00X0b<6k0P11JN460<S1^`80@FWQ00@0
b<6k0:f][@38`K/000000P38`K/2045Yh@80b<6k00@0@FWQ0<S1^`11JN40@FWQ0P2][Jd01011JN40
[Jf]0:f][@2][Jd20<S1^`80@FWQ4037`K`2045Yh@050<O1_011JN40a/2l0<K0_011JN404036`;`0
0`2][Jd0`kfk0<>m^`0;0<>m^`80@FWQ00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H0
0`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid3
0:f][@050;VbYP11JN40@FWQ0;VbYP11JN402P2i/ZH00`2][Jd0_[N/0;jg[00>0;jg[0D0@FWQ0`31
^[02045Yh@L0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc0080@FWQ1P33_K<2045Yh@@0[Jf]0P11
JN430<>m/`030:f][@35_[D0aKje00d0aKje0`11JN440<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P02045Yh@P0al6j0P11JN450<O1^P80@FWQ00<0
al6j0:f][@38`K/02`38`K/4045Yh@<0b<6k0P11JN400`38`K/0[Jf]000000020<S1^`030:f][@11
JN40@FWQ0080[Jf]00@0@FWQ0:f][@11JN40@FWQ0P38`K/00`11JN40b<6k0<S1^`040<S1^`03045Y
h@37`K`0al6l00h0al6l0P11JN401037`K`0[Jf]045Yh@11JN4A0<K0_0030:f][@33_K/0`kfk00T0
`kfk0P11JN401033_K/0[Jf]0:f][@2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nK
X02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03
0:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd00`11JN40^K:V0;VbYP080;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001011JN480<6j/0<0@FWQ0`31^[000`2][Jd0
`kfc0<>m/`02045Yh@H0`kfc0P11JN440<>m/`80@FWQ202][Jd00`11JN40aKje0<Fn]@060<Fn]@@0
@FWQ1@35_[D01@2][Jd0a[ng0<Jo]`36_kL0@FWQ01<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P02045Yh@T0al6j0P11JN450<O1^P03045Yh@37`KX0[Jf]0100b<6k1@11JN450:f]
[@030<S1^`11JN40@FWQ0080b<6k00@0@FWQ0<S1^`11JN40@FWQ0P38`K/00`11JN40b<6k0<S1^`04
0<S1^`03045Yh@37`K`0al6l00`0al6l0`11JN420<O1_0030:f][@36`;`0a/2l0140a/2l00<0[Jf]
0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;40
0`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[
W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00`0`KZ`0P11JN401P31^[00@FWQ0<6j/031^[00[Jf]0<>m/`80@FWQ1`33
_K<2045Yh@D0`kfc0P11JN420<>m/`040:f][@35_[D0aKje0<Fn]@80@FWQ1P2][Jd4045Yh@80[Jf]
1@35_[D01@2][Jd0a[ng0<Jo]`36_kL0@FWQ01<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P02045Yh@T0al6j0P11JN450<O1^P03045Yh@37`KX0[Jf]00D0b<6k302][Jd20<S1^`80
@FWQ00<0b<6k0:f][@38`K/00`38`K/2045Yh@80b<6k00<0@FWQ0<S1^`11JN401038`K/00`11JN40
b<6k0<S1^`030<S1^`03045Yh@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0
];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
3031^[02045Yh@80`KZ`00@0@FWQ0<6j/02][Jd0`kfc0P11JN470<>m/`80@FWQ1@33_K<2045Yh@80
`kfc00L0[Jf]0<Fn]@35_[D0aKje045Yh@35_[D0@FWQ00@0aKje0`11JN440<Fn]@T0[Jf]00<0@FWQ
0:f][@2][Jd01@2][Jd<0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00P11JN47
0<O1^P80[Jf]0P11JN450:f][@03045Yh@2][Jd0[Jf]00D0[Jf]3P38`K/01011JN40b<6k0<S1^`2]
[Jd40<S1^`03045Yh@38`K/0b<6k0080b<6k0P11JN440<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0
@FWQ0<O1_037`K`02037`K`00`11JN40al6l0<O1_0070<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`
/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A
0;jg[0030:f][@31^[00`KZ`00`0`KZ`0P11JN430<6j/0<0@FWQ2@33_K<2045Yh@H0`kfc00@0@FWQ
0<>m/`33_K<0[Jf]1035_[D2045Yh@@0aKje00<0@FWQ0<Fn]@35_[D01P35_[D01011JN40aKje0<Fn
]@2][Jd30<Jo]`03045Yh@36_kL0a[ng00D0a[ng9`2][Jd2045Yh@L0[Jf]0P37`KX2045Yh@D0al6j
0P11JN400`2][Jd0b<6k0<S1^`090<S1^`80@FWQ1P38`K/01011JN40b<6k0<S1^`2][Jd30<S1^`80
@FWQ1038`K/2045Yh@@0b<6k1011JN420<S1^`03045Yh@37`K`0al6l00P0al6l00<0@FWQ0<O1_037
`K`01`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]
202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[0030:f]
[@31^[00`KZ`00`0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc00H0`kfc1011JN470<>m/`03045Y
h@33_K<0[Jf]00@0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@050<Fn]@80@FWQ
0P35_[D01@2][Jd0a[ng0<Jo]`36_kL0@FWQ01<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P02045Yh@T0al6j0P11JN450<O1^P80@FWQ00<0[Jf]0<S1^`38`K/00P38`K/00`11JN40
b<6k0<S1^`040<S1^`80@FWQ1@38`K/01@11JN40b<6k0<S1^`38`K/0[Jf]00<0b<6k0P11JN440<S1
^`80@FWQ0P38`K/3045Yh@D0b<6k0P11JN480<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_00>0<K0
_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3P
iP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00<0<6j/080
@FWQ1031^[000`2][Jd0`kfc0<>m/`0B0<>m/`03045Yh@2][Jd0aKje0080aKje00<0@FWQ0<Fn]@35
_[D01@35_[D00`11JN40aKje0<Fn]@040<Fn]@80@FWQ0P35_[D01@2][Jd0a[ng0<Jo]`36_kL0@FWQ
01<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P02045Yh@T0al6j0P11JN450<O1
^P03045Yh@37`KX0@FWQ00<0b<6k00<0@FWQ0<S1^`11JN401P38`K/00`11JN40b<6k0<S1^`030<S1
^`06045Yh@38`K/0b<6k0<S1^`2][Jd0b<6k1P11JN4>0<S1^`80@FWQ2037`K`2045Yh@T0al6l00<0
[Jf]0<K0_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji
^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`4
0:f][@T0_[N/00<0[Jf]0<6j/031^[003031^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<4
045Yh@T0aKje00<0@FWQ0<Fn]@35_[D00P35_[D3045Yh@80aKje00D0[Jf]0<Jo]`36_kL0a[ng045Y
h@0C0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00P11JN490<O1^P80@FWQ1@37
`KX01011JN40al6j0:f][@11JN430<S1^`80@FWQ1`38`K/5045Yh@@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/2045Yh@P0al6l0P11JN490<O1_0030:f][@36`;`0a/2l00D0a/2l102][Jd70<K0_0030:f]
[@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`/@2d/;420:f][E00
/>3V0@3oool006T0/>3V0P2][Jd20:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00<0<6j/080@FWQ
1031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00/0aKje1011JN420<Fn]@04045Y
h@35_[D0aKje0:f][@80a[ng0P11JN4C0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX00P11JN490<O1^P80@FWQ1037`KX2045Yh@030<O1^P2][Jd0b<6k00@0@FWQ4@38`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@11JN40@FWQ00H0al6l0`11JN490<O1_0030:f][@36`;`0a/2l00D0
[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d
/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[003@31^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080@FWQ4`36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ2@37`KX2045Yh@80al6j0P11JN430<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l045Yh@060<O1_003
045Yh@37`K`0@FWQ00L0al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`03`2n]j`50:f][@/0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`02045YhA<0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P02045Yh@P0al6j0P11JN480<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_011JN430<O1_080@FWQ0P37`K`00`11JN40
al6l0<O1_0050:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd20<6j/0@0
@FWQ1031^[000`2][Jd0`kfc0<>m/`080<>m/`03045Yh@33_K<0`kfc00P0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`02045YhA<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P02045Yh@P0al6j0P11JN480<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/0102][Jd0al6l0<O1_037`K`3045Yh@030<O1_02][Jd0[Jf]00@0[Jf]1`37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f]
[EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`070<>m/`03
045Yh@33_K<0@FWQ00T0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`02045YhA<0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j0P11JN490<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@d0
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0
_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f][@L0`kfc00<0@FWQ0<>m/`33_K<0
2033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080@FWQ4`36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ1`37`KX2045Yh@T0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2]
[Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng0080@FWQ4`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ
1`37`KX2045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]
0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0[Jf]0;Vb
YP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080@FWQ4`36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ1P37`KX2045Yh@X0al6j00<0
[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo
001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00@0[Jf]0<Jo]`36_kL0@FWQ5036_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j0080@FWQ1P37`KX2045Yh@X0al6j00<0[Jf]0<S1^`38`K/0
3`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@030<Fn]@`0[Jf]1@35_[D0102][Jd0a[ng0<Jo]`11JN4D0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]045Yh@11JN402011JN4<0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`030<>m^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f]
[@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0=0<O1^P030000
0037`KX0al6j00@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102]
[Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V
1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40
oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`
h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?oo
o`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49866 .33837 m
.5003 .34065 L
s
.497 .34058 m
.49866 .33837 L
s
.49864 .34287 m
.5003 .34065 L
s
.497 .34058 m
.49864 .34287 L
s
.47394 .33758 m
.48051 .33784 L
s
.48051 .33784 m
.48379 .34021 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48379 .34021 m
.48543 .34252 L
s
.4854 .3493 m
.48543 .34252 L
s
.47064 .33969 m
.47394 .33758 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46738 .33728 m
.46899 .34187 L
s
.46732 .34631 m
.46738 .33728 L
s
.48375 .34924 m
.48541 .34704 L
s
.46899 .34187 m
.47064 .33969 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48374 .3515 m
.4854 .3493 L
s
.49861 .35417 m
.50019 .38142 L
s
.49687 .38136 m
.49861 .35417 L
s
.48044 .35139 m
.48375 .34924 L
s
.46732 .34631 m
.46899 .34187 L
s
.48043 .35365 m
.48374 .3515 L
s
.47218 .35559 m
.48044 .35139 L
s
.58936 .33667 m
.60558 .33559 L
s
.47217 .35786 m
.48043 .35365 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45267 .33872 m
.45589 .34344 L
s
.44781 .33615 m
.45267 .33872 L
s
.48368 .3651 m
.48535 .36061 L
s
.48531 .36969 m
.48535 .36061 L
s
.44457 .33593 m
.44781 .33615 L
s
.46888 .35771 m
.47218 .35559 L
s
.49853 .38139 m
.49857 .36776 L
s
.44131 .33796 m
.44457 .33593 L
s
.4397 .33784 m
.44457 .33593 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46887 .35998 m
.47217 .35786 L
s
.48201 .36731 m
.48368 .3651 L
s
.48368 .3651 m
.48531 .36969 L
s
.46722 .3599 m
.46888 .35771 L
s
.60558 .33559 m
.60883 .3376 L
s
.43803 .34225 m
.44131 .33796 L
s
.46721 .36217 m
.46887 .35998 L
s
.4787 .36947 m
.48201 .36731 L
s
.46719 .36444 m
.46722 .3599 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43642 .34213 m
.4397 .33784 L
s
.4721 .36921 m
.4787 .36947 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59587 .33626 m
.5963 .38398 L
s
.59424 .33637 m
.59466 .38408 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60883 .3376 m
.6121 .34188 L
s
.60558 .33559 m
.61045 .33748 L
s
.46719 .36444 m
.46882 .36679 L
s
.61045 .33748 m
.61371 .34175 L
s
.46882 .36679 m
.4721 .36921 L
s
.43635 .34893 m
.43803 .34225 L
s
.45414 .35694 m
.45576 .3593 L
s
.45249 .35911 m
.45414 .35694 L
s
.49852 .38595 m
.50019 .38142 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49687 .38136 m
.49852 .38595 L
s
.45574 .36158 m
.45576 .3593 L
s
.43474 .34881 m
.43642 .34213 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41729 .33367 m
.42846 .33468 L
s
.45243 .36593 m
.45574 .36158 L
s
.45249 .35911 m
.4541 .36148 L
s
.6121 .34188 m
.61376 .34629 L
s
0 0 0 r
.64209 .32449 m
.64417 .32427 L
s
.255 .412 .882 r
.61371 .34175 m
.61537 .34616 L
s
.42327 .3661 m
.42366 .33426 L
s
.4363 .35347 m
.43635 .34893 L
s
.62324 .33412 m
.63435 .33305 L
s
.42167 .36596 m
.42206 .33412 L
s
.43469 .35335 m
.43474 .34881 L
s
.44915 .36801 m
.45243 .36593 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61376 .34629 m
.61545 .35297 L
s
.61537 .34616 m
.61706 .35284 L
s
.4363 .35347 m
.43785 .36041 L
s
.43469 .35335 m
.43623 .36029 L
s
.44427 .3677 m
.44915 .36801 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43785 .36041 m
.44104 .3652 L
s
.44104 .3652 m
.44427 .3677 L
s
.43942 .36508 m
.44427 .3677 L
s
.43623 .36029 m
.43942 .36508 L
s
.39995 .33184 m
.41095 .33304 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58975 .38436 m
.60607 .38335 L
s
.61706 .35284 m
.61719 .36423 L
s
.61545 .35297 m
.61558 .36436 L
s
.6296 .33352 m
.63002 .3654 L
s
.62801 .33368 m
.62843 .36554 L
s
0 0 0 r
.64414 .35187 m
.64619 .35331 L
s
.255 .412 .882 r
.61404 .37133 m
.61558 .36436 L
s
.61566 .37121 m
.61719 .36423 L
s
.62984 .3517 m
.63152 .35839 L
s
.61248 .37602 m
.61404 .37133 L
s
.61409 .3759 m
.61566 .37121 L
s
.60929 .38084 m
.61248 .37602 L
s
.60607 .38335 m
.60929 .38084 L
s
.60607 .38335 m
.61091 .38072 L
s
.41688 .36553 m
.42327 .3661 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40586 .3576 m
.40622 .33254 L
s
.40429 .35743 m
.40465 .33237 L
s
.61091 .38072 m
.61409 .3759 L
s
.62363 .36597 m
.63002 .3654 L
s
.63152 .35839 m
.63476 .36265 L
s
.38291 .32974 m
.39372 .33111 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63476 .36265 m
.63796 .36463 L
s
.42153 .3774 m
.4231 .37982 L
s
.4199 .37955 m
.42153 .3774 L
s
.42147 .38198 m
.4231 .37982 L
s
.40422 .36201 m
.40586 .3576 L
s
.65627 .33283 m
.66086 .32995 L
s
.6548 .33758 m
.65627 .33283 L
s
.40265 .36184 m
.40429 .35743 L
s
.4199 .37955 m
.42147 .38198 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6548 .33758 m
.65487 .34214 L
s
.65782 .33263 m
.66086 .32995 L
s
.65635 .33739 m
.65782 .33263 L
s
.64105 .35973 m
.64259 .35727 L
s
.64259 .35727 m
.6442 .35939 L
s
.64105 .35973 m
.64266 .36185 L
s
.63796 .36463 m
.64269 .36414 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65635 .33739 m
.65642 .34195 L
s
.66086 .32995 m
.66546 .32934 L
s
.39947 .36379 m
.40422 .36201 L
s
.65487 .34214 m
.6565 .34652 L
s
.6442 .35939 m
.64423 .36168 L
s
.39947 .36379 m
.40265 .36184 L
s
.65642 .34195 m
.65805 .34633 L
s
.64269 .36414 m
.64423 .36168 L
s
.66546 .32934 m
.66855 .3312 L
s
.39633 .36345 m
.39947 .36379 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38673 .37846 m
.38753 .33034 L
s
.38828 .37864 m
.38907 .33054 L
s
.39169 .36062 m
.39633 .36345 L
s
.66855 .3312 m
.67167 .33534 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65805 .34633 m
.66117 .34823 L
s
.6565 .34652 m
.66117 .34823 L
s
.65665 .35567 m
.65669 .35796 L
s
.65665 .35567 m
.6582 .35548 L
s
.38866 .35566 m
.39169 .36062 L
s
.66117 .34823 m
.6704 .3493 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65669 .35796 m
.65827 .36007 L
s
.6582 .35548 m
.65824 .35778 L
s
.67311 .33055 m
.67608 .32782 L
s
.67167 .33534 m
.67311 .33055 L
s
.67167 .33534 m
.67205 .35598 L
s
.65827 .36007 m
.6614 .36198 L
s
.67462 .33033 m
.67608 .32782 L
s
.67319 .33513 m
.67462 .33033 L
s
.67608 .32782 m
.67759 .3276 L
s
.35025 .30867 m
.36056 .31043 L
s
.67319 .33513 m
.67349 .35117 L
s
.36918 .3301 m
.37212 .33511 L
s
.37212 .33511 m
.37351 .3422 L
s
.36472 .32713 m
.36918 .3301 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36768 .32987 m
.37061 .3349 L
s
.37061 .3349 m
.37199 .34198 L
s
.36472 .32713 m
.36768 .32987 L
s
.37342 .34678 m
.37351 .3422 L
s
.6614 .36198 m
.66755 .3612 L
s
.36173 .32666 m
.36472 .32713 L
s
.37191 .34657 m
.37199 .34198 L
s
.6704 .3493 m
.67197 .35138 L
s
.37178 .35346 m
.37342 .34678 L
s
.37026 .35325 m
.37191 .34657 L
s
.35871 .32847 m
.36173 .32666 L
s
.38208 .37789 m
.38828 .37864 L
s
.66755 .3612 m
.67057 .35849 L
s
.67205 .35598 m
.67349 .35117 L
s
.67057 .35849 m
.67205 .35598 L
s
.36866 .35763 m
.37178 .35346 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35565 .33258 m
.35871 .32847 L
s
.36715 .35742 m
.37026 .35325 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35513 .35791 m
.35612 .30969 L
s
.35365 .35768 m
.35465 .30943 L
s
.36409 .35928 m
.36866 .35763 L
s
.36409 .35928 m
.36715 .35742 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68571 .35862 m
.69099 .32546 L
s
.68721 .35839 m
.69114 .33235 L
s
.68122 .35929 m
.69166 .35769 L
s
.36109 .35883 m
.36409 .35928 L
s
.34554 .32393 m
.34699 .32419 L
s
.35815 .35607 m
.36109 .35883 L
s
.34259 .3257 m
.34554 .32393 L
s
.34404 .32596 m
.34554 .32393 L
s
.35527 .35099 m
.35815 .35607 L
s
.34249 .3303 m
.34404 .32596 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34104 .33004 m
.34259 .3257 L
s
.34923 .35696 m
.35513 .35791 L
s
.34213 .34646 m
.34249 .3303 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69902 .35648 m
.70282 .33032 L
s
.69755 .35673 m
.70267 .32342 L
s
.70267 .32342 m
.70916 .3547 L
s
.69099 .32546 m
.69755 .35673 L
s
.33827 .3249 m
.34104 .33004 L
s
.34058 .35083 m
.34104 .33004 L
s
.33547 .32205 m
.33827 .3249 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33121 .32121 m
.33547 .32205 L
s
0 0 0 r
.32154 .31149 m
.32284 .31177 L
s
.255 .412 .882 r
.34058 .35083 m
.34213 .34646 L
s
.32833 .32295 m
.33121 .32121 L
s
.32693 .32266 m
.33121 .32121 L
s
.33929 .34363 m
.34068 .3462 L
s
.33077 .3397 m
.33929 .34363 L
s
0 0 0 r
.72717 .31141 m
.72797 .3106 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33908 .35289 m
.34058 .35083 L
s
.70484 .35548 m
.71345 .3539 L
s
.32682 .32728 m
.32833 .32295 L
s
.33615 .35469 m
.33908 .35289 L
s
.32542 .32699 m
.32693 .32266 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32671 .33191 m
.32682 .32728 L
s
.328 .33682 m
.33077 .3397 L
s
.3266 .33654 m
.33077 .3397 L
s
.33044 .35362 m
.33615 .35469 L
s
.32531 .33162 m
.32542 .32699 L
s
.32671 .33191 m
.328 .33682 L
s
.72129 .32672 m
.72396 .3215 L
s
.72001 .33164 m
.72129 .32672 L
s
.71877 .33888 m
.72001 .33164 L
s
.32531 .33162 m
.3266 .33654 L
s
.72396 .3215 m
.72803 .31828 L
s
.72268 .32643 m
.72534 .3212 L
s
.7214 .33135 m
.72268 .32643 L
s
.71877 .33888 m
.71905 .35049 L
s
.72018 .33859 m
.7214 .33135 L
s
.72534 .3212 m
.72803 .31828 L
s
.72018 .33859 m
.72046 .35021 L
s
.32637 .34582 m
.32778 .3461 L
s
.32772 .34843 m
.32778 .3461 L
s
.32767 .35075 m
.33044 .35362 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72803 .31828 m
.73077 .31767 L
s
.32632 .34815 m
.32637 .34582 L
s
.32632 .34815 m
.32767 .35075 L
s
.71905 .35049 m
.72063 .3572 L
s
.72046 .35021 m
.72203 .35692 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73077 .31767 m
.73489 .31905 L
s
.72063 .3572 m
.72214 .36158 L
s
.72203 .35692 m
.72354 .3613 L
s
.73489 .31905 m
.7377 .32307 L
s
.72214 .36158 m
.72505 .3657 L
s
.29854 .31379 m
.3078 .31608 L
s
.72354 .3613 m
.72644 .36542 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31389 .34322 m
.3152 .34585 L
s
.31514 .34818 m
.3152 .34585 L
s
.31247 .34526 m
.31389 .34322 L
s
.31372 .35022 m
.31514 .34818 L
s
.30292 .34779 m
.3038 .31511 L
s
.31247 .34526 m
.31378 .34789 L
s
.30963 .34933 m
.31372 .35022 L
s
.30159 .34748 m
.30248 .31478 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72505 .3657 m
.72927 .36719 L
s
.72644 .36542 m
.72927 .36719 L
s
.73396 .33564 m
.74335 .33345 L
s
.73886 .31578 m
.73935 .3344 L
s
.73752 .3161 m
.73801 .33472 L
s
.72927 .36719 m
.73202 .36662 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28275 .30182 m
.2848 .3024 L
s
.255 .412 .882 r
.307 .34638 m
.30963 .34933 L
s
.74678 .31381 m
.7558 .31141 L
s
.73202 .36662 m
.73605 .3634 L
s
.3033 .33375 m
.30444 .34108 L
s
.30444 .34108 m
.307 .34638 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73863 .35811 m
.73979 .35077 L
s
.75067 .31279 m
.7516 .34557 L
s
.73605 .3634 m
.73863 .35811 L
s
.75196 .31245 m
.75289 .34525 L
s
.29764 .34653 m
.30292 .34779 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73863 .35811 m
.74017 .36485 L
s
.73979 .35077 m
.74017 .36485 L
s
.29026 .33047 m
.2908 .31174 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28899 .33013 m
.28953 .31139 L
s
.28519 .3291 m
.29412 .33147 L
s
.74768 .34654 m
.75289 .34525 L
s
.75249 .33116 m
.75398 .33786 L
s
.28693 .31303 m
.28932 .31841 L
s
.28324 .30962 m
.28693 .31303 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75398 .33786 m
.75667 .3419 L
s
.28076 .3089 m
.28324 .30962 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27824 .31051 m
.28076 .3089 L
s
.27702 .31014 m
.28076 .3089 L
s
.75667 .3419 m
.75928 .34358 L
s
.28939 .36108 m
.28979 .34692 L
s
.28831 .35367 m
.28979 .34692 L
s
.27566 .31447 m
.27824 .31051 L
s
.75928 .34358 m
.76305 .34256 L
s
.28563 .35773 m
.28831 .35367 L
s
.28831 .35367 m
.28939 .36108 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27445 .31411 m
.27702 .31014 L
s
.76166 .33818 m
.76299 .3402 L
s
.76166 .33818 m
.76285 .33548 L
s
.76285 .33548 m
.76416 .33749 L
s
.76416 .33749 m
.76423 .33985 L
s
.76305 .34256 m
.76423 .33985 L
s
.27431 .31882 m
.27566 .31447 L
s
.2731 .31845 m
.27445 .31411 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28178 .3591 m
.28563 .35773 L
s
.77313 .30867 m
.77661 .30517 L
s
.77208 .31375 m
.77313 .30867 L
s
.77208 .31375 m
.77222 .31847 L
s
.27289 .32553 m
.27431 .31882 L
s
.77432 .30829 m
.77661 .30517 L
s
.77327 .31338 m
.77432 .30829 L
s
.77327 .31338 m
.77342 .31809 L
s
.27169 .32516 m
.2731 .31845 L
s
.27928 .35842 m
.28178 .3591 L
s
.77661 .30517 m
.78012 .30401 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77342 .31809 m
.77476 .32244 L
s
.77222 .31847 m
.77357 .32282 L
s
.27252 .33735 m
.27289 .32553 L
s
.77357 .32282 m
.77721 .32406 L
s
.27132 .33699 m
.27169 .32516 L
s
.27688 .35536 m
.27928 .35842 L
s
.27566 .35502 m
.27928 .35842 L
s
.77476 .32244 m
.77721 .32406 L
s
.27458 .34992 m
.27688 .35536 L
s
.77386 .33227 m
.77393 .33464 L
s
.77386 .33227 m
.77505 .33191 L
s
.27252 .33735 m
.27351 .34482 L
s
.78012 .30401 m
.7825 .30559 L
s
.77393 .33464 m
.7752 .33665 L
s
.27351 .34482 m
.27458 .34992 L
s
.27337 .34957 m
.27566 .35502 L
s
.77505 .33191 m
.77513 .33428 L
s
.27132 .33699 m
.2723 .34447 L
s
.77721 .32406 m
.78426 .32415 L
s
.2723 .34447 m
.27337 .34957 L
s
.7752 .33665 m
.77765 .33829 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7825 .30559 m
.78494 .30953 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77765 .33829 m
.78233 .3368 L
s
.25949 .30202 m
.26299 .33678 L
s
.25392 .33372 m
.25949 .30202 L
s
.25955 .33565 m
.2665 .3379 L
s
.78592 .3044 m
.78809 .30123 L
s
.78494 .30953 m
.78592 .3044 L
s
.78494 .30953 m
.78563 .33091 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78704 .304 m
.78809 .30123 L
s
.78607 .30914 m
.78704 .304 L
s
.78607 .30914 m
.78661 .32576 L
s
.25503 .33411 m
.25926 .30912 L
s
.78809 .30123 m
.7892 .30083 L
s
.78426 .32415 m
.78547 .32615 L
s
0 0 0 r
.24955 .2908 m
.25054 .2946 L
s
.255 .412 .882 r
.78233 .3368 m
.78456 .33367 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24932 .29136 m
.24955 .2908 L
s
.5 Mabswid
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79412 .28218 m
.7958 .33217 L
s
.78456 .33367 m
.78563 .33091 L
s
.78563 .33091 m
.78661 .32576 L
s
.79519 .28176 m
.79688 .33177 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79086 .28345 m
.79837 .28047 L
s
.25066 .29875 m
.25392 .33372 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24847 .35594 m
.2485 .35196 L
s
.2487 .32199 m
.24871 .3205 L
s
.24827 .32227 m
.24839 .32036 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24525 .33055 m
.25066 .29875 L
s
.24631 .33095 m
.25042 .30589 L
s
.79599 .3055 m
.79796 .2999 L
s
.79796 .2999 m
.79999 .29668 L
s
.79252 .33335 m
.79688 .33177 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79999 .29668 m
.80207 .29582 L
s
.79664 .32459 m
.79894 .32857 L
s
.24211 .32932 m
.24953 .33215 L
s
.80207 .29582 m
.80421 .29735 L
s
.80207 .29582 m
.80522 .29692 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24744 .35326 m
.24749 .35155 L
s
.5 Mabswid
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2402 .29451 m
.24121 .29494 L
s
.79894 .32857 m
.80114 .33016 L
s
.80421 .29735 m
.8064 .30127 L
s
.2381 .29603 m
.2402 .29451 L
s
.2391 .29646 m
.2402 .29451 L
s
.80522 .29692 m
.8074 .30084 L
s
.23793 .30082 m
.2391 .29646 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80114 .33016 m
.80323 .32935 L
s
.8064 .30127 m
.80766 .30803 L
s
.23693 .30038 m
.2381 .29603 L
s
.8074 .30084 m
.80866 .3076 L
s
.23734 .31762 m
.23793 .30082 L
s
.80323 .32935 m
.80521 .32612 L
s
.80323 .32935 m
.80623 .3257 L
s
.23513 .29471 m
.23693 .30038 L
s
.23617 .32201 m
.23693 .30038 L
s
.80766 .30803 m
.80783 .31283 L
s
.80521 .32612 m
.80707 .32047 L
s
.23327 .29143 m
.23513 .29471 L
s
.80707 .32047 m
.80783 .31283 L
s
.80866 .3076 m
.80883 .31241 L
s
.80623 .3257 m
.80808 .32005 L
s
.80808 .32005 m
.80883 .31241 L
s
.23617 .32201 m
.23734 .31762 L
s
.23041 .29008 m
.23327 .29143 L
s
.23543 .31436 m
.23634 .3172 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22972 .30934 m
.23543 .31436 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23509 .324 m
.23617 .32201 L
s
.81398 .29055 m
.82046 .28736 L
s
.22845 .29158 m
.23041 .29008 L
s
.22753 .29112 m
.23041 .29008 L
s
.23304 .32557 m
.23509 .324 L
s
.8168 .2892 m
.81865 .34002 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22735 .29594 m
.22845 .29158 L
s
.22919 .32385 m
.23304 .32557 L
s
.81772 .28874 m
.81958 .33959 L
s
.22643 .29549 m
.22753 .29112 L
s
.22793 .30604 m
.22972 .30934 L
s
.227 .3056 m
.22972 .30934 L
s
0 0 0 r
.8258 .2785 m
.82666 .27685 L
s
.255 .412 .882 r
.22718 .30077 m
.22735 .29594 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22718 .30077 m
.22793 .30604 L
s
.22626 .30032 m
.22643 .29549 L
s
.22626 .30032 m
.227 .3056 L
s
.2274 .32056 m
.22919 .32385 L
s
.22665 .31527 m
.22758 .31571 L
s
.22749 .31814 m
.22758 .31571 L
s
.22656 .3177 m
.2274 .32056 L
s
.81869 .3153 m
.82071 .31926 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22656 .3177 m
.22665 .31527 L
s
.81581 .34129 m
.81958 .33959 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82071 .31926 m
.8235 .32036 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82657 .28409 m
.82758 .3108 L
s
.82741 .28361 m
.82842 .31034 L
s
.82399 .2855 m
.8299 .28218 L
s
.8235 .32036 m
.82526 .31947 L
s
.82526 .31947 m
.8269 .31613 L
s
.82526 .31947 m
.82776 .31568 L
s
.21862 .31123 m
.21939 .31412 L
s
.2193 .31656 m
.21939 .31412 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21835 .31855 m
.2193 .31656 L
s
.21768 .31322 m
.21862 .31123 L
s
.20993 .27876 m
.21545 .28215 L
s
.8269 .31613 m
.82758 .3108 L
s
.21768 .31322 m
.21844 .31611 L
s
.21581 .31719 m
.21835 .31855 L
s
.82776 .31568 m
.82842 .31034 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21172 .31489 m
.21304 .28071 L
s
.8331 .28025 m
.8384 .2768 L
s
.21093 .31442 m
.21225 .28022 L
s
.21424 .31382 m
.21581 .31719 L
s
.21281 .308 m
.21424 .31382 L
s
.21229 .3002 m
.21281 .308 L
s
.83542 .27878 m
.83675 .31304 L
s
.83617 .27829 m
.83751 .31257 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2086 .31302 m
.21172 .31489 L
s
.83441 .31444 m
.83751 .31257 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20523 .28313 m
.20575 .28852 L
s
.20575 .28852 m
.20619 .29637 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20401 .27723 m
.20523 .28313 L
s
.20571 .30866 m
.20619 .29637 L
s
.83655 .32827 m
.83722 .32535 L
s
.83655 .32827 m
.83741 .33028 L
s
.20452 .28263 m
.20503 .28803 L
s
.20503 .28803 m
.20546 .29588 L
s
.20332 .27673 m
.20452 .28263 L
s
.83722 .32535 m
.83808 .32735 L
s
.20206 .27326 m
.20401 .27723 L
s
.20498 .30819 m
.20546 .29588 L
s
.83741 .33028 m
.83808 .32735 L
s
.20206 .27326 m
.20332 .27673 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20469 .31558 m
.20571 .30866 L
s
.84223 .28166 m
.84339 .27574 L
s
.84182 .28953 m
.84223 .28166 L
s
.84182 .28953 m
.84202 .29445 L
s
.20397 .31511 m
.20498 .30819 L
s
.1958 .26812 m
.20206 .27326 L
s
.84291 .28116 m
.84405 .27524 L
s
.84252 .28903 m
.84291 .28116 L
s
.84339 .27574 m
.84526 .27176 L
s
.84202 .29445 m
.84301 .30135 L
s
.84252 .28903 m
.84271 .29395 L
s
.20377 .32005 m
.20469 .31558 L
s
.84405 .27524 m
.84526 .27176 L
s
.84271 .29395 m
.84369 .30086 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20306 .31958 m
.20397 .31511 L
s
.84301 .30135 m
.84456 .30531 L
s
.20216 .32406 m
.20377 .32005 L
s
.84526 .27176 m
.84653 .27074 L
s
.84369 .30086 m
.84523 .30483 L
s
.20147 .32359 m
.20306 .31958 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84653 .27074 m
.84848 .27165 L
s
.84456 .30531 m
.84665 .30633 L
s
.2 .32512 m
.20216 .32406 L
s
.84523 .30483 m
.84665 .30633 L
s
.2 .32512 m
.20147 .32359 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84848 .27165 m
.84986 .27556 L
s
.84665 .30633 m
.84855 .30485 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19368 .32032 m
.2 .32512 L
s
.19548 .32177 m
.19758 .26968 L
s
.1961 .32226 m
.1982 .27019 L
s
.84855 .30485 m
.84968 .30138 L
s
.84938 .29393 m
.84988 .29094 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84988 .29094 m
.85057 .29292 L
s
.84938 .29393 m
.85008 .29591 L
s
.84968 .30138 m
.85067 .2954 L
s
.85057 .29292 m
.85067 .2954 L
s
.85343 .26447 m
.85415 .26891 L
s
.85343 .26447 m
.85384 .27441 L
s
.85384 .27441 m
.85415 .26891 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85415 .26891 m
.85456 .2659 L
s
.85456 .2659 m
.85544 .26234 L
s
.85544 .26234 m
.85731 .2602 L
s
.85445 .28936 m
.85487 .28635 L
s
.85445 .28936 m
.85466 .29435 L
s
.85455 .29185 m
.85497 .28884 L
s
.85487 .28635 m
.85577 .28281 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85466 .29435 m
.85528 .29634 L
s
.85497 .28884 m
.85588 .28531 L
s
.85577 .28281 m
.85793 .27519 L
s
.85528 .29634 m
.85639 .29783 L
s
.85588 .28531 m
.85803 .27769 L
s
.85731 .2602 m
.85829 .26162 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85639 .29783 m
.85831 .29578 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85829 .26162 m
.85882 .26358 L
s
.85793 .27519 m
.8587 .27162 L
s
.85803 .27769 m
.85881 .27413 L
s
.85882 .26358 m
.85913 .27109 L
s
.8587 .27162 m
.85902 .26858 L
s
.85881 .27413 m
.85913 .27109 L
s
.85831 .29578 m
.8591 .29223 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8591 .29223 m
.85944 .28919 L
s
.85944 .28919 m
.85965 .28364 L
s
.85944 .28919 m
.86007 .29371 L
s
.85965 .28364 m
.86007 .29371 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86142 .25727 m
.86166 .25421 L
s
.86142 .25727 m
.86187 .25923 L
s
.86166 .25421 m
.8621 .25617 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86187 .25923 m
.8621 .25617 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8624 .27183 m
.86402 .3017 L
s
.8624 .27183 m
.86333 .30274 L
s
.86304 .287 m
.86368 .30222 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86333 .30274 m
.8639 .30731 L
s
.8639 .30731 m
.86402 .3017 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17792 .24101 m
.17775 .243 L
s
.17797 .23787 m
.17792 .24101 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17782 .23987 m
.17797 .23787 L
s
.17775 .243 m
.17782 .23987 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17592 .28738 m
.1772 .25585 L
s
.17582 .2863 m
.1772 .25585 L
s
.86703 .22963 m
.86753 .23538 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17587 .28684 m
.17653 .27131 L
s
.17592 .28738 m
.17564 .29203 L
s
.86749 .23366 m
.86983 .28809 L
s
.86746 .23309 m
.8698 .28755 L
s
.17769 .23844 m
.17784 .23529 L
s
.17736 .24618 m
.17769 .23844 L
s
.17564 .29203 m
.17582 .2863 L
s
.17784 .23529 m
.17807 .23156 L
s
.1774 .24562 m
.17747 .2436 L
s
.17729 .2482 m
.17736 .24618 L
s
.17807 .23156 m
.17843 .22925 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1774 .24562 m
.1774 .24707 L
s
0 0 0 r
.17435 .22051 m
.17504 .21696 L
s
.255 .412 .882 r
.17729 .2482 m
.17729 .24966 L
s
.17662 .26376 m
.1768 .25912 L
s
.17636 .26951 m
.1768 .25912 L
s
.86938 .28432 m
.86987 .2897 L
s
.1774 .24707 m
.17765 .24944 L
s
.17754 .25205 m
.17729 .24966 L
s
.17636 .26951 m
.17662 .26376 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17656 .2658 m
.17662 .26376 L
s
.86691 .23106 m
.86703 .22963 L
s
.86678 .23049 m
.86703 .22963 L
s
.17843 .22925 m
.17856 .23069 L
s
.17656 .2658 m
.17658 .2673 L
s
.86686 .2351 m
.86691 .23106 L
s
.17856 .23069 m
.17859 .2327 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86671 .23453 m
.86678 .23049 L
s
.17658 .2673 m
.17698 .26509 L
s
.17896 .22694 m
.17859 .2327 L
s
0 0 0 r
.1738 .24036 m
.17538 .23516 L
s
.255 .412 .882 r
.1778 .25092 m
.17765 .24944 L
s
.86693 .23974 m
.86686 .2351 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17769 .25353 m
.17754 .25205 L
s
.86677 .23917 m
.86671 .23453 L
s
.17784 .25297 m
.1778 .25092 L
s
.17698 .26509 m
.17736 .26137 L
s
.17773 .25558 m
.17769 .25353 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86678 .23972 m
.86693 .24643 L
s
.86695 .24042 m
.86711 .24699 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17762 .2582 m
.17784 .25297 L
s
0 0 0 r
.17613 .2134 m
.17762 .20984 L
s
.255 .412 .882 r
.86904 .28061 m
.86938 .28432 L
s
.86891 .28007 m
.86938 .28432 L
s
.17736 .26137 m
.17762 .2582 L
s
.86711 .24699 m
.86767 .26006 L
s
.86693 .24643 m
.86749 .25951 L
s
.86854 .27427 m
.86904 .28061 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86767 .26006 m
.86817 .26848 L
s
.86839 .27373 m
.86891 .28007 L
s
.86854 .27427 m
.86817 .26848 L
s
.86749 .25951 m
.868 .26793 L
s
0 0 0 r
.17933 .18261 m
.18173 .17834 L
s
.255 .412 .882 r
.86839 .27373 m
.868 .26793 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1769 .25958 m
.18029 .18078 L
s
.17725 .25903 m
.18063 .18017 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17213 .29375 m
.17454 .21933 L
s
.5 Mabswid
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17213 .29375 m
.17708 .21103 L
s
.17262 .28243 m
.17682 .21162 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17903 .21752 m
.18007 .20884 L
s
.18007 .20884 m
.181 .20391 L
s
.181 .20391 m
.18181 .20273 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17594 .26126 m
.17725 .25903 L
s
.18181 .20273 m
.18251 .20531 L
s
.18181 .20273 m
.18296 .20472 L
s
.17774 .24766 m
.17813 .25412 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18251 .20531 m
.1831 .21168 L
s
.18296 .20472 m
.18357 .2111 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17813 .25412 m
.17874 .2568 L
s
.255 .412 .882 r
.85663 .2094 m
.85693 .21026 L
s
0 0 0 r
.18309 .22246 m
.1831 .21168 L
s
.255 .412 .882 r
.85663 .2094 m
.85694 .21051 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18608 .24793 m
.18674 .23206 L
s
.18561 .24848 m
.18629 .23244 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18357 .2111 m
.18357 .22189 L
s
.17874 .2568 m
.17956 .25569 L
s
.18276 .23005 m
.18309 .22246 L
s
.17956 .25569 m
.18058 .25076 L
s
.17956 .25569 m
.18103 .25021 L
s
.18325 .22948 m
.18357 .22189 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85751 .23063 m
.8576 .23047 L
s
.85751 .23063 m
.85764 .23055 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18181 .24203 m
.18276 .23005 L
s
.18058 .25076 m
.18181 .24203 L
s
.18228 .24146 m
.18325 .22948 L
s
.18103 .25021 m
.18228 .24146 L
s
.255 .412 .882 r
.85818 .24664 m
.85843 .24618 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18831 .20588 m
.18981 .19711 L
s
.18726 .21788 m
.18831 .20588 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85739 .23061 m
.85751 .23063 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18981 .19711 m
.19183 .19156 L
s
.18694 .22551 m
.18726 .21788 L
s
.1889 .2053 m
.19042 .19653 L
s
.18784 .21731 m
.1889 .2053 L
s
.19042 .19653 m
.19183 .19156 L
s
.18752 .22494 m
.18784 .21731 L
s
.18694 .22551 m
.18704 .23642 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19183 .19156 m
.19313 .1904 L
s
.18752 .22494 m
.18762 .23587 L
s
.19313 .1904 m
.19431 .19306 L
s
.19313 .1904 m
.195 .19248 L
s
.18704 .23642 m
.1879 .24299 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18762 .23587 m
.18851 .24244 L
s
.19431 .19306 m
.19539 .19956 L
s
.1879 .24299 m
.18961 .24519 L
s
.195 .19248 m
.1961 .19899 L
s
.18851 .24244 m
.18961 .24519 L
s
.19539 .19956 m
.19563 .21051 L
s
.1961 .19899 m
.19635 .20995 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18961 .24519 m
.19091 .2441 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19531 .2182 m
.19563 .21051 L
s
.19091 .2441 m
.19242 .23915 L
s
.19091 .2441 m
.19311 .2386 L
s
.19604 .21765 m
.19635 .20995 L
s
.19413 .23032 m
.19531 .2182 L
s
.19242 .23915 m
.19413 .23032 L
s
.84434 .19155 m
.84497 .18828 L
s
.84403 .18387 m
.84497 .18828 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84339 .18714 m
.84403 .18387 L
s
.19484 .22977 m
.19604 .21765 L
s
.19311 .2386 m
.19484 .22977 L
s
.84339 .18714 m
.84434 .19155 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20108 .18406 m
.20687 .18009 L
s
.84512 .21082 m
.84779 .25798 L
s
.84512 .21082 m
.8462 .25693 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84606 .23407 m
.847 .25745 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2068 .21596 m
.20698 .21861 L
s
.5 Mabswid
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8366 .18264 m
.83765 .18706 L
s
.83765 .18706 m
.8381 .19867 L
s
.83464 .17766 m
.8366 .18264 L
s
.21043 .17785 m
.2171 .17397 L
s
.84732 .26528 m
.84779 .25798 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83723 .21496 m
.83726 .21447 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83737 .202 m
.8381 .19867 L
s
.83088 .17543 m
.83464 .17766 L
s
.83721 .19812 m
.83795 .19479 L
s
.83555 .2009 m
.83721 .19812 L
s
.8357 .20479 m
.83737 .202 L
s
.8462 .25693 m
.84732 .26528 L
s
.1978 .26546 m
.20106 .26339 L
s
.82908 .17821 m
.83088 .17543 L
s
.83829 .22535 m
.83887 .21809 L
s
.83887 .21809 m
.83949 .2337 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20106 .26339 m
.20432 .18179 L
s
.20023 .2639 m
.20349 .18236 L
s
.21003 .25828 m
.21322 .17618 L
s
.21099 .25778 m
.21418 .17562 L
s
.83829 .22535 m
.83949 .2337 L
s
.82824 .18155 m
.82908 .17821 L
s
.82694 .17323 m
.82824 .18155 L
s
.82694 .17323 m
.82753 .18879 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83754 .22873 m
.83829 .22535 L
s
.83126 .20991 m
.8357 .20479 L
s
.83111 .206 m
.83555 .2009 L
s
.83585 .23159 m
.83754 .22873 L
s
.82753 .18879 m
.82824 .18155 L
s
.82929 .20885 m
.83111 .206 L
s
.83202 .22951 m
.83585 .23159 L
s
.82944 .21277 m
.83126 .20991 L
s
.81741 .16837 m
.82176 .17051 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82843 .21224 m
.82929 .20885 L
s
.82858 .21617 m
.82944 .21277 L
s
.22283 .1824 m
.22526 .17352 L
s
.22133 .19465 m
.22283 .1824 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20722 .2598 m
.21099 .25778 L
s
.22526 .17352 m
.22871 .16802 L
s
.82989 .22454 m
.83202 .22951 L
s
.82843 .21224 m
.82873 .22009 L
s
.22389 .18186 m
.22635 .17299 L
s
.22238 .19413 m
.22389 .18186 L
s
.81851 .1689 m
.82056 .22388 L
s
.22103 .20249 m
.22133 .19465 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22635 .17299 m
.22871 .16802 L
s
.82873 .22009 m
.82989 .22454 L
s
.81741 .16837 m
.81944 .22338 L
s
.22209 .20196 m
.22238 .19413 L
s
.22871 .16802 m
.23097 .16696 L
s
.22103 .20249 m
.22165 .21375 L
s
.22209 .20196 m
.22272 .21324 L
s
.81531 .17121 m
.81784 .18009 L
s
.23097 .16696 m
.23312 .16982 L
s
.81172 .16572 m
.81531 .17121 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23097 .16696 m
.23429 .1693 L
s
.5 Mabswid
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22165 .21375 m
.2235 .22061 L
s
.80937 .16468 m
.81172 .16572 L
s
.22272 .21324 m
.2246 .22011 L
s
.23312 .16982 m
.23519 .17662 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23429 .1693 m
.23638 .17611 L
s
.80711 .16756 m
.80937 .16468 L
s
.8059 .16705 m
.80937 .16468 L
s
.2235 .22061 m
.22668 .22305 L
s
.2246 .22011 m
.22668 .22305 L
s
.23519 .17662 m
.23595 .18792 L
s
.80618 .17491 m
.80711 .16756 L
s
.81605 .22188 m
.82056 .22388 L
s
.23638 .17611 m
.23715 .18742 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80495 .1744 m
.8059 .16705 L
s
.22668 .22305 m
.22895 .22205 L
s
.23567 .19581 m
.23595 .18792 L
s
.23687 .19531 m
.23715 .18742 L
s
.24416 .16125 m
.25324 .15774 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22895 .22205 m
.2314 .2171 L
s
.22895 .22205 m
.23258 .2166 L
s
.23405 .20818 m
.23567 .19581 L
s
.2314 .2171 m
.23405 .20818 L
s
.23524 .20768 m
.23687 .19531 L
s
.23258 .2166 m
.23524 .20768 L
s
.24607 .21526 m
.24799 .15973 L
s
.24738 .21479 m
.24929 .15923 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78762 .1561 m
.79565 .15906 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77812 .20825 m
.79168 .15757 L
s
.77958 .20869 m
.79302 .15806 L
s
.80495 .1744 m
.80649 .21796 L
s
.80618 .17491 m
.80773 .21845 L
s
.80273 .21652 m
.80773 .21845 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25867 .15578 m
.26856 .15244 L
s
.24222 .21669 m
.24738 .21479 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24779 .20282 m
.25015 .20985 L
s
.26141 .19815 m
.26284 .15434 L
s
.77341 .15135 m
.78206 .15417 L
s
.26283 .1977 m
.26426 .15386 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78948 .21184 m
.79756 .21463 L
s
.25015 .20985 m
.25406 .21246 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77633 .15228 m
.79491 .21369 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25406 .21246 m
.25681 .21154 L
s
.255 .412 .882 r
.76751 .18731 m
.76997 .18727 L
s
0 0 0 r
.27443 .15059 m
.2851 .14744 L
s
.25681 .21154 m
.25974 .20662 L
s
.25681 .21154 m
.26115 .20617 L
s
.25974 .20662 m
.26141 .19815 L
s
.26115 .20617 m
.26283 .1977 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27722 .20537 m
.27894 .14922 L
s
.27875 .20495 m
.28047 .14877 L
s
.77518 .20738 m
.78388 .21003 L
s
.76143 .15172 m
.76476 .16059 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75661 .14641 m
.76143 .15172 L
s
.76476 .16059 m
.76665 .17304 L
s
.76322 .16015 m
.76512 .1726 L
s
.75987 .15128 m
.76322 .16015 L
s
.75661 .14641 m
.75987 .15128 L
s
.76665 .17304 m
.7669 .18106 L
s
.75343 .14555 m
.75661 .14641 L
s
.76512 .1726 m
.76537 .18063 L
s
.76573 .1927 m
.7669 .18106 L
s
.75033 .1487 m
.75343 .14555 L
s
.7487 .14828 m
.75343 .14555 L
s
.76419 .19227 m
.76537 .18063 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27268 .20666 m
.27875 .20495 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7473 .15589 m
.75033 .1487 L
s
.74565 .15548 m
.7487 .14828 L
s
.29775 .14801 m
.30281 .14276 L
s
.29589 .15645 m
.29775 .14801 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76131 .19951 m
.76419 .19227 L
s
.76288 .19992 m
.76573 .1927 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29939 .14759 m
.30281 .14276 L
s
.29753 .15603 m
.29939 .14759 L
s
.29463 .20086 m
.29589 .15645 L
s
.30281 .14276 m
.30615 .14194 L
s
.29627 .20046 m
.29753 .15603 L
s
.74599 .16755 m
.7473 .15589 L
s
.74434 .16715 m
.74565 .15548 L
s
.75827 .20273 m
.76288 .19992 L
s
.30615 .14194 m
.31112 .14476 L
s
.75827 .20273 m
.76131 .19951 L
s
.27495 .2301 m
.2766 .22562 L
s
.27495 .2301 m
.27635 .23375 L
s
.2766 .22562 m
.27801 .22927 L
s
.72841 .13944 m
.73528 .141 L
s
.74599 .16755 m
.74622 .17562 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74434 .16715 m
.74456 .17522 L
s
.75507 .20192 m
.75827 .20273 L
s
.31112 .14476 m
.31434 .15204 L
s
.27635 .23375 m
.27801 .22927 L
s
.31466 .13996 m
.32162 .13843 L
s
.31317 .19666 m
.31466 .13996 L
s
.74622 .17562 m
.74821 .18816 L
s
.28976 .20206 m
.29627 .20046 L
s
.74456 .17522 m
.74656 .18776 L
s
.75171 .19706 m
.75507 .20192 L
s
.75008 .19666 m
.75507 .20192 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72841 .13944 m
.73062 .22484 L
s
.73014 .13982 m
.73237 .22519 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74821 .18816 m
.75171 .19706 L
s
.74656 .18776 m
.75008 .19666 L
s
.72502 .1427 m
.72872 .15153 L
s
.7214 .13792 m
.72502 .1427 L
s
.71785 .13718 m
.7214 .13792 L
s
.71436 .14049 m
.71785 .13718 L
s
.71255 .14014 m
.71785 .13718 L
s
.33051 .13658 m
.33212 .1443 L
s
.33012 .15275 m
.33051 .13658 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31835 .17635 m
.31861 .17813 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31491 .19629 m
.31638 .13957 L
s
.33212 .1443 m
.33402 .1399 L
s
.33402 .1399 m
.33777 .13516 L
s
.33012 .15275 m
.33212 .1443 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7091 .14753 m
.71255 .14014 L
s
.71093 .14788 m
.71436 .14049 L
s
.33777 .13516 m
.34515 .1338 L
s
.308 .19777 m
.31491 .19629 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72626 .19137 m
.72956 .18394 L
s
.70939 .15971 m
.71093 .14788 L
s
.70755 .15937 m
.7091 .14753 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34515 .1338 m
.3488 .13719 L
s
.69018 .13206 m
.69773 .13335 L
s
.72282 .19474 m
.72626 .19137 L
s
.70939 .15971 m
.70958 .16784 L
s
.3488 .13719 m
.35059 .14092 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70755 .15937 m
.70774 .16751 L
s
.33143 .17272 m
.33518 .16796 L
s
.32952 .17714 m
.33143 .17272 L
s
.32933 .1853 m
.32952 .17714 L
s
.33518 .16796 m
.3446 .15815 L
s
.35033 .15311 m
.35059 .14092 L
s
.33134 .17679 m
.33508 .17204 L
s
.32943 .18122 m
.33134 .17679 L
s
.33508 .17204 m
.34451 .16223 L
s
.32933 .1853 m
.33104 .18905 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70774 .16751 m
.70987 .18008 L
s
.71925 .19404 m
.72282 .19474 L
s
.70958 .16784 m
.7117 .18042 L
s
.69018 .13206 m
.69139 .18922 L
s
.69208 .13237 m
.6933 .18952 L
s
.3446 .15815 m
.34844 .15343 L
s
.34844 .15343 m
.35042 .14904 L
s
.68645 .13549 m
.69044 .14424 L
s
.68059 .13052 m
.68645 .13549 L
s
.71554 .18927 m
.71925 .19404 L
s
.71372 .18893 m
.71925 .19404 L
s
.7117 .18042 m
.71554 .18927 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34451 .16223 m
.34835 .15751 L
s
.34835 .15751 m
.35033 .15311 L
s
.72533 .2238 m
.73237 .22519 L
s
.67671 .12993 m
.68059 .13052 L
s
.70987 .18008 m
.71372 .18893 L
s
.33104 .18905 m
.3346 .19247 L
s
.36607 .13032 m
.36793 .13409 L
s
.36405 .13468 m
.36607 .13032 L
s
.36405 .13468 m
.36591 .13845 L
s
.67287 .13342 m
.67671 .12993 L
s
.67091 .13314 m
.67671 .12993 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36591 .13845 m
.36793 .13409 L
s
.3346 .19247 m
.342 .19118 L
s
.67106 .14129 m
.67287 .13342 L
s
.66908 .14101 m
.67091 .13314 L
s
.34782 .18203 m
.34988 .17352 L
s
.34953 .18993 m
.34988 .17352 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.342 .19118 m
.34584 .18644 L
s
.34584 .18644 m
.34782 .18203 L
s
.34782 .18203 m
.34953 .18993 L
s
.67106 .14129 m
.6719 .18641 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3655 .15885 m
.36649 .20797 L
s
.36257 .20852 m
.3655 .15885 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68562 .18834 m
.6933 .18952 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66908 .14101 m
.66992 .18615 L
s
.64881 .12621 m
.65124 .15099 L
s
.61773 .12304 m
.65084 .12645 L
s
.65084 .12645 m
.65124 .15099 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36452 .20824 m
.36501 .18347 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66392 .18538 m
.6719 .18641 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36257 .20852 m
.36436 .21654 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63899 .15374 m
.63947 .18678 L
s
.36436 .21654 m
.36649 .20797 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61163 .16116 m
.61196 .1614 L
s
.6102 .16028 m
.61163 .16116 L
s
0 0 0 r
.62671 .16903 m
.63923 .17022 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65184 .18808 m
.65224 .213 L
s
.65019 .21278 m
.65184 .18808 L
s
.62403 .12361 m
.62514 .21042 L
s
.62612 .1238 m
.62726 .21059 L
s
.61877 .2099 m
.65224 .213 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU4180[Jf]1000000E0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF
3P<0[Jf]J02`h>H10?ooo`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdF0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40020?nS40030:f][@000000000000L0
00003@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS40030?nS408000001P3oXa000`2][Jd0000000000003000000@0[Jf]103oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V
0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS408000002P3o
Xa02000000@0oj<@1`2][JdH0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh20:f][F40/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405@3oYQ400`000000[Jf]0:f][@040:f][AP0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa02
000000X0oj<@0P0000080?nS40030:f][@3lX100o:0@00@000000P2][JdB0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ440:f][@80000000<0ojHA0:f]
[@3oYQ406`3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS408000002P3oXa02000000P0oj<@00@0[Jf]0000
0000000000000`3lX10010000000o:0@0:f][@2][Jd4000000`0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H2
0:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40
ojHA00L0ojHA1@0000040:f][@@0ojHA00@000000?nV4@000000[Jf]703oYQ400`2][Jd0ojHA0?nV
4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
40030?nS408000002P3oXa02000000P0oj<@00<0[Jf]0000000000001@3lX1000`000000o:0@0?bP
4002000000030?bP402][Jd0[Jf]00<0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd4
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@04
0?nV4@030000002][Jd0000000@0[Jf]00<0ojHA0000000000001P3oYQ42000000030?nV4@2][Jd0
ojHA01/0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000X0oj<@0P0000080?nS408000001`3lX100
10000000o:0@0000000000060?bP40D0[Jf]00@000000?bP403lX100[Jf]5P3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_
V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@00
0000000000@0[Jf]00<000000?nV4@0000001P3oYQ400`000000ojHA0?nV4@050?nV4@030000003o
YQ40[Jf]01`0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000X0oj<@0P0000080?nS408000001`3l
X10010000000o:0@00000000000:0?bP40040000003lX100000000000080[Jf]00<0mY`?00000000
00004P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40
oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A
0P0000020:f][@@0ojHA0P0000080?nV4@030000003oYQ40ojHA00H0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS40030?nS408000002`3oXa000`000000oj<@0?nS40060?nS40800000
203lX103000000T0o:0@0P0000030?bP40030000003fW0l0[Jf]00@00000403fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A0`0000030:f][@8000001P3o
YQ400`000000ojHA0?nV4@070?nV4@030000003oYQ40ojHA00H0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS40030?nS408000002`3oXa000`000000oj<@0?nS40060?nS40800000203l
X103000000P0o:0@0P0000040?bP40030:f][@000000mY`?0080000000<0mY`?0:f][@2][Jd00P2]
[Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3o
ool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY140
1@2][Jd000000:f][@2][Jd0oj@A0080000000<0oj@A0000000000001@3oYQ42000000T0ojHA00<0
00000?nV4@3oYQ401P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@0P00
000;0?nS40030000003oXa00oj<@00H0oj<@0P0000090?bP40800000203lX102000000@0o:0@00<0
[Jf]0000003fW0l00P0000050?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY14200000080oj@A102][Jd2
000000@0oj@A00@000000?nT4@00000000001@3oYQ42000000T0ojHA00<000000?nV4@3oYQ401P3o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@0P00000;0?nS40030000003o
Xa00oj<@00H0oj<@0P0000090?bP408000001`3lX102000000D0o:0@00<0[Jf]0?JL3`0000000P00
00090?JL3`040:f][@0000000000000000D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3l
X100102][Jd0oj@A0?nT4@3oY142000000@0[Jf]0`3oY142000000H0oj@A0`0000050?nV4@030000
003oYQ40ojHA00P0ojHA00<000000?nV4@3oYQ401P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@00<0oj<@0P00000;0?nS40030000003oXa00oj<@00H0oj<@0P0000090?bP40800000
1`3lX102000000D0o:0@00<0[Jf]0?JL3`0000000P0000080?JL3`8000000P3fW0l2000000<0[Jf]
00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V
0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140000000<000001`3oY142000000H0oj@A0`0000050?nV4@030000003oYQ40ojHA00L0ojHA0P00
00080?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000/0oj<@00<0
00000?nS403oXa001P3oXa02000000T0o:0@0P0000070?bP408000001@3lX1000`2][Jd0mY`?0?JL
3`02000000L0mY`?0P0000040?JL3`040000003fW0l0mY`?0?JL3`<0[Jf]00<000000>bF3P3/UPh0
3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V
00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400=0?bP408000000P2][Jd20?nT4@80
00001P3oY142000000P0oj@A0P0000050?nV4@030000003oYQ40ojHA00L0ojHA0P0000080?nV4@03
0:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa02000001@0oj<@0P0000090?bP4080
00001P3lX1000`000000o:0@000000050?bP40030:f][@3fW0l0mY`?008000001`3fW0l2000000@0
mY`?0P0000030?JL3`030:f][@3/UPh0[Jf]008000003P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@05
0:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]
00d0kiP@00<0[Jf]0?bP403lX1002`3lX102000000030:f][@3lX100[Jf]00<0oj@A0P0000060?nT
4@800000203oY142000000h0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa000`3oXa02000000D0oj<@00<000000?nS403oXa00303oXa02000000T0o:0@0P0000060?bP
408000001P3lX1000`2][Jd0mY`?0?JL3`02000000H0mY`?0P0000060?JL3`050000003fW0l0mY`?
0?JL3`2][Jd00`3/UPh3000000`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`02
0;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1002@3lX10400000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P000006
0?nT4@800000203oY142000000h0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]
0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000D0oj<@00<00000
0?nS403oXa00303oXa02000000T0o:0@0P0000060?bP408000001P3lX1000`2][Jd0mY`?0?JL3`02
000000H0mY`?0P0000060?JL3`8000000P3fW0l00`2][Jd0k9H>0>bF3P020>bF3P040000003/UPh0
[Jf]0:f][@<000001`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0
[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX10300000080[Jf]0P3lX10200000080o:0@00@0[Jf]
0?nT4@3oY140oj@A0P0000060?nT4@800000203oY142000000d0ojHA0P0000080?nV4@030000003o
YQ40[Jf]01/0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU40050?nU4100[Jf]1`3oYA000`2][Jd0oj<@0?nS40030?nS408000001@3o
Xa000`000000oj<@0?nS400<0?nS408000002@3lX102000000H0o:0@0P0000060?bP40030:f][@3f
W0l0mY`?008000001P3fW0l2000000L0mY`?00@000000?JL3`3fW0l0[Jf]103/UPh00`000000k9H>
0>bF3P020>bF3P040:f][@0000000000000000D0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0
103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0`0000020:f][@@0o:0@
0P0000020?bP40040:f][@3oY140oj@A0?nT4@8000001P3oY142000000P0oj@A0P00000<0?nV4@03
0000003oYQ40000000P0ojHA00<000000?nV4@2][Jd05`3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]00<0oj<@0000000000001@3oXa000`000000
oj<@0?nS400<0?nS408000002@3lX102000000H0o:0@0P0000060?bP40030:f][@3fW0l0mY`?0080
00001P3fW0l2000000L0mY`?0P0000000`3fW0l0[Jf]0>bF3P030>bF3P030000003/UPh0k9H>0080
k9H>00<000000>bF3P0000000P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>
00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@030000003lX100o:0@00@0
o:0@0P0000020?bP40040:f][@3oY140oj@A0?nT4@8000001P3oY142000000P0oj@A0P00000;0?nV
4@030000003oYQ40000000T0ojHA00<000000?nV4@2][Jd03P3oYQ490:f][@@0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa000P3oXa000`2][Jd00000000000050:f][@030000002][Jd0oj<@00`0oj<@0P0000090?bP
408000001P3lX102000000H0o:0@00<0[Jf]0?JL3`3fW0l00P0000060?JL3`030000003fW0l0mY`?
00H0mY`?0P0000000`3fW0l0[Jf]0>bF3P030>bF3P030000003/UPh0k9H>0080k9H>0P0000030>bF
3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V
04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH4004
0:f][@3lX100[Jf]0:f][@<0o:0@00<000000?bP403lX100103lX10200000080o:0@00@0[Jf]0?nT
4@3oY140oj@A0P0000060?nT4@800000203oY142000000X0ojHA00<000000?nV4@0000002P3oYQ40
0`000000ojHA0:f][@040?nV4@X0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS408000001@3oXa00
0`000000oj<@0:f][@090:f][@@0oj<@0P0000080?bP408000001P3lX102000000H0o:0@00<0[Jf]
0?JL3`3fW0l00P0000060?JL3`030000003fW0l0mY`?00H0mY`?0P0000000`3fW0l0[Jf]0>bF3P04
0>bF3P040000003/UPh0k9H>0>bF3P8000001P3/UPh20:f][@030000003KRPd0fhX=00X0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100
kiP@00T0kiP@00@000000>nH402][Jd0[Jf]1@3lX1000`000000o:0@0?bP40040?bP408000000P3l
X100102][Jd0oj@A0?nT4@3oY142000000H0oj@A0P0000080?nT4@8000002@3oYQ400`000000ojHA
0000000;0?nV4@030000002][Jd0[Jf]00@0[Jf]5`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS40800000
1@3oXa000`000000oj<@0?nS40090?nS40@0[Jf]0P0000020:f][@H0o:0@0P0000060?bP40800000
1P3lX1000`2][Jd0mY`?0?JL3`02000000H0mY`?00<000000?JL3`3fW0l01P3fW0l2000000030?JL
3`2][Jd0k9H>00@0k9H>00@000000>bF3P3/UPh0k9H>0P0000060>bF3P80000000<0[Jf]0000003K
RPd02P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>
00<0[Jf]0>nH403_V100203_V104000000H0o:0@00<000000?bP403lX100103lX10200000080o:0@
00@0[Jf]0?nT4@3oY140oj@A0P0000060?nT4@8000001`3oY142000000T0ojHA00<000000?nV4@00
00001P3oYQ460:f][@030000003oYQ40[Jf]01/0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa04000000<0
oj<@00<000000?nS403oXa003@3oXa0200000080o:0@1P2][Jd2000000H0o:0@0P0000060?bP4003
0:f][@3fW0l0mY`?008000001P3fW0l00`000000mY`?0?JL3`070?JL3`80000000<0[Jf]0>bF3P3/
UPh00`3/UPh01P000000k9H>0>bF3P000000k9H>000000H0k9H>0P0000020=^:3@040000002][Jd0
0000000000L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L
0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1000`000000[Jf]0>nH4002
000000H0o:0@00<000000?bP403lX100103lX10200000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P00
00060?nT4@8000001`3oY142000000P0ojHA00<000000?nV4@0000000P3oYQ450:f][@H0ojHA00<0
00000?nV4@2][Jd06`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS408000000P3oXa04000000l0oj<@0P00
00080?bP408000001@2][Jd00`3lX1000000000000060?bP40030:f][@3fW0l0mY`?008000001P3f
W0l00`000000mY`?0?JL3`070?JL3`80000000<0[Jf]0>bF3P3/UPh0103/UPh010000000k9H>0000
000000070>bF3P030000002][Jd0fhX=0080fhX=100000060=^:3@030:f][@2iM@/0^GD;00L0^GD;
00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f]
[@3_V100kiP@00D0kiP@00<0[Jf]0000000000000P3_V102000000H0o:0@00<000000?bP403lX100
103lX10200000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000060?nT4@8000001`3oY142000000L0
ojHA00<000000:f][@0000000`2][Jd30?nV4@030000003oYQ40ojHA00D0ojHA00<000000?nV4@2]
[Jd06`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS40030?nS408000001@3oXa000`000000oj<@0?nS400=0?nS4080
0000203lX102000000D0o:0@00<0[Jf]0000000000000`2][Jd30?bP40030:f][@3fW0l0mY`?0080
00001P3fW0l2000000P0mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P040000003/UPh000000000
00L0k9H>00<000000:f][@3KRPd00P3KRPd3000000040:f][@3KRPd0fhX=000000<0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0
Uf0;0:f][@P0dhL>00@0[Jf]0>nH403_V100kiP@0P0000000`3_V100[Jf]0>nH4002000000<0kiP@
0P0000050?bP40030000003lX100o:0@00@0o:0@0P0000020?bP40040:f][@3oY140oj@A0?nT4@80
00001P3oY142000000L0oj@A0P0000020?nV4@@0[Jf]00<000000:f][@0000001`3oYQ400`000000
ojHA0?nV4@050?nV4@030000003oYQ40[Jf]01/0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000D0
oj<@00<000000?nS403oXa003@3oXa02000000P0o:0@0P0000070?bP40040000003lX100o:0@0?bP
40D0[Jf]00<0mY`?0000000000001P3fW0l2000000P0mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF
3P040000003/UPh00000000000L0k9H>00<000000:f][@3KRPd00P3KRPd3000000080=^:3@2][Jd0
[Jf]0000003KRPd000000=^:3@2][Jd90;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?oo
o`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P0000020:f]
[@80kiP@0P0000030>nH408000001@3lX1000`000000o:0@0?bP40030?bP408000000`3lX1000`2]
[Jd0oj@A0?nT4@02000000L0oj@A0P0000070?nT4@8000000P2][Jd40?nV4@800000203oYQ400`00
0000ojHA0?nV4@050?nV4@030000003oYQ40[Jf]01/0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000`3oXa020000
00D0oj<@00<000000?nS403oXa003@3oXa02000000P0o:0@0P0000070?bP408000001@3lX1000`2]
[Jd0mY`?0:f][@02000000030:f][@3fW0l0mY`?00<0mY`?0P0000080?JL3`80000000<0[Jf]0>bF
3P3/UPh01@3/UPh2000000P0k9H>00<000000:f][@3KRPd00`3KRPd2000000<0fhX=0P0000000`3K
RPd00000000000090;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2]
[Jd0000009MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH400000000P0000030>nH40800000103_V102
000000D0o:0@00<000000?bP403lX1000`3lX102000000<0o:0@00<0[Jf]0?nT4@3oY1400P000007
0?nT4@8000000`3oY1440:f][@8000001P3oYQ400`000000ojHA0?nV4@060?nV4@8000001`3oYQ40
0`000000ojHA0:f][@0K0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@0P0000050?nS40030000003oXa00
oj<@00d0oj<@0P0000080?bP408000001`3lX102000000D0o:0@00<0[Jf]0?JL3`3fW0l00P000000
0`3fW0l0[Jf]0:f][@020:f][@030?JL3`000000000000P0mY`?0P0000000`2][Jd0k9H>0>bF3P05
0>bF3P800000203/UPh00`000000[Jf]0=^:3@030=^:3@8000000`3KRPd200000080[Jf]00<00000
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool0
05T0/>3V00<0[Jf]0000002GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030000002][Jd0[Jf]
008000000`3_V102000000@0kiP@0P0000050?bP40030000003lX100o:0@00<0o:0@0P0000030?bP
40030:f][@3oY140oj@A008000001`3oY142000000<0[Jf]103oY142000000H0ojHA00<000000?nV
4@3oYQ401P3oYQ42000000L0ojHA00<000000?nV4@2][Jd06`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS
408000001@3oXa000`000000oj<@0?nS400=0?nS40800000203lX102000000L0o:0@0P0000050?bP
40030:f][@3fW0l0mY`?008000001@3fW0l0102][Jd000000000002][Jd70?JL3`80000000<0[Jf]
0>bF3P3/UPh01@3/UPh2000000P0k9H>00<000000:f][@3KRPd00`3KRPd2000000<0fhX=00H00000
0=^:3@3KRPd0fhX=0:f][@0000080;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0
@@2`h>H10?ooo`00F@2`h>H200000080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h2000000030:f][@3_
V100kiP@008000000`3_V102000000@0kiP@0P0000050?bP40030000003lX100o:0@00<0o:0@0P00
00030?bP40030:f][@3oY140oj@A008000001@3oY1420:f][@8000001`3oY142000000H0ojHA00<0
00000?nV4@3oYQ401P3oYQ42000000L0ojHA00<000000?nV4@2][Jd06`3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
40030?nS408000001@3oXa000`000000oj<@0?nS400=0?nS40800000203lX102000000L0o:0@0P00
00050?bP40050:f][@3fW0l0mY`?0?JL3`0000001`3fW0l2000000@0[Jf]0`3fW0l2000000030:f]
[@3/UPh0k9H>00@0k9H>0`0000080>bF3P030000002][Jd0fhX=00<0fhX=0P0000030=^:3@060000
003KRPd0fhX=0=^:3@2][Jd00000202iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V
0440/>3V0@3oool005T0/>3V00D0[Jf]0000002GH0/0Uf0;0:f][@060=>73P<0000000<0[Jf]0>nH
403_V1000P0000030>nH408000000`3_V1000`2][Jd0o:0@000000050?bP40030000003lX100o:0@
00<0o:0@0P0000030?bP40030:f][@3oY140oj@A0080000000<0oj@A0:f][@2][Jd00P2][Jd20?nT
4@8000001`3oY142000000H0ojHA00<000000?nV4@3oYQ401@3oYQ43000000H0ojHA0`0000000`2]
[Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@0P0000050?nS40030000003oXa00oj<@
00X0oj<@0P0000000`3oXa000000000000080?bP40800000203lX102000000@0o:0@00<0[Jf]0?JL
3`3fW0l00`0000060?JL3`800000103fW0l30:f][@80000000<0[Jf]0>bF3P3/UPh0103/UPh30000
00P0k9H>00<000000:f][@3KRPd00`3KRPd2000000<0fhX=00H000000=^:3@3KRPd0fhX=0:f][@00
00020:f][@030000002iM@/0^GD;00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3P
iP110;3PiP40oooo001I0;3PiP050:f][@000000Uf0;09MP2`2][Jd01P3CQ`h0102][Jd000000000
002][Jd20>nH408000000`3_V102000000<0kiP@00<0[Jf]0?bP40000000103lX102000000D0o:0@
0P0000030?bP40030:f][@3oY140[Jf]0080000000<0[Jf]0?nT4@3oY140103oY142000000L0oj@A
0P0000060?nV4@030000003oYQ40ojHA00D0ojHA0`0000060?nV4@80000000<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS40030?nS408000001@3oXa000`000000oj<@0?nS400<0?nS40<00000
203lX102000000P0o:0@0P0000040?bP40030:f][@3fW0l0mY`?00<000001P3fW0l2000000L0mY`?
00@000000:f][@2][Jd0[Jf]1@3/UPh3000000P0k9H>00<000000:f][@3KRPd00`3KRPd2000000<0
fhX=00H000000=^:3@3KRPd0fhX=0:f][@0000020;Ue2`030000002iM@/0^GD;00<0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@000000Uf0;
09MP2`2][Jd01@3CQ`h01@2][Jd0dhL>000000000000[Jf]0080kiP@0P0000020>nH40800000103_
V1000`2][Jd0o:0@000000040?bP40030000003lX100o:0@00@0o:0@0P0000020?bP40<0[Jf]00<0
oj@A0000000000001`3oY142000000L0oj@A0P0000070?nV4@030000003oYQ40ojHA00<0ojHA00@0
00000?nV4@3oYQ4000001P3oYQ42000000030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
0`3oXa02000000`0oj<@00<000000?nS403oXa001P3oXa000`2][Jd0o:0@0?bP40040?bP40D00000
2@3lX102000000<0o:0@00@0[Jf]0?JL3`000000mY`?0P0000060?JL3`8000001`3fW0l010000000
mY`?0:f][@3/UPh30:f][@80k9H>0`0000080>bF3P030000002][Jd0fhX=00<0fhX=0P0000030=^:
3@060000003KRPd0fhX=0=^:3@2][Jd000000P2iM@/2000000@0^GD;00<0[Jf]08QF1`28EPL00P28
EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]0000002GH0/0Uf0;0:f][@020=>73P030000003C
Q`h0[Jf]0080dhL>0P0000000`2][Jd0kiP@0>nH400200000080kiP@0P0000040>nH40030:f][@3l
X100000000@0o:0@00<000000?bP403lX100103lX10200000080[Jf]00@0o:0@0:f][@3oY140oj@A
0P0000070?nT4@8000001`3oY142000000P0ojHA00<000000?nV4@3oYQ400P0000030?nV4@030000
003oYQ40ojHA00@0ojHA0P0000000`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@
0P00000<0?nS40030000003oXa00oj<@00H0oj<@00<0[Jf]0?bP403lX1004`3lX10200000080o:0@
00@0[Jf]0?JL3`000000mY`?0P0000060?JL3`8000001`3fW0l00`000000mY`?0:f][@040>bF3P06
0:f][@000000k9H>0000003/UPh000001`3/UPh00`000000[Jf]0=^:3@030=^:3@8000001`3KRPd0
1`2][Jd000000;Ue2`2iM@/000000;Ue2`2][Jd00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@P2`h>H10?ooo`00F@2`h>H01@2][Jd0000009MP2`2GH0/0[Jf]0080dhL>0P0000030=>73P800000
00<0[Jf]0>nH403_V1000P0000020>nH40800000103_V1000`2][Jd00000000000040?bP40030000
003lX100o:0@00<0o:0@00<0[Jf]0000000000000`3lX1000`2][Jd0oj@A0?nT4@02000000L0oj@A
0P0000070?nT4@8000002@3oYQ42000000`0ojHA0P0000000`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@00<0oj<@0P00000<0?nS40030000003oXa00oj<@00H0oj<@00<0[Jf]0?bP403lX100
503lX1001@000000o:0@0?bP402][Jd000000080mY`?0P0000060?JL3`8000001`3fW0l00`000000
mY`?0:f][@050>bF3P8000000P2][Jd00`000000k9H>0>bF3P050>bF3P030000002][Jd0fhX=00<0
fhX=0P0000070=^:3@030:f][@000000^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80
[Jf]@P2`h>H10?ooo`00F@2`h>H02@2][Jd0000009MP2`2GH0/0[Jf]0=>73P000000[Jf]00000003
0=>73P80000000<0[Jf]0>nH403_V1000P0000020>nH40800000103_V1000`2][Jd0000000000004
0?bP40030000003lX100o:0@00<0[Jf]00<0o:0@0000000000000`3lX1000`2][Jd0oj@A0?nT4@02
000000L0oj@A0P0000070?nT4@8000005`3oYQ42000000030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000`0oj<@00<00000
0?nS403oXa001P3oXa000`2][Jd0o:0@0?bP400E0?bP40<0000000<0[Jf]0?JL3`3fW0l00P000007
0?JL3`8000001@3fW0l2000000030?JL3`2][Jd0k9H>00@0k9H>0P0000020>bF3P030000002][Jd0
[Jf]00D0k9H>00<000000:f][@3KRPd00`3KRPd2000000L0fhX=00<0[Jf]0000002iM@/01P2iM@/2
0:f][@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP040:f][@000000Uf0;09MP2`80[Jf]00@00000
0=>73P00000000000P3CQ`h2000000040:f][@3_V100kiP@000000<0kiP@0P0000040>nH40030:f]
[@000000000000@0o:0@00<000000:f][@2][Jd0103lX102000000<0o:0@00<0[Jf]0?nT4@3oY140
0P0000070?nT4@8000001`3oY142000001L0ojHA0P0000000`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
1@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000`0oj<@00<000000?nS403oXa00
1P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?008000001`3fW0l2000000D0mY`?
00@000000?JL3`3fW0l0[Jf]1@3/UPh2000000<0k9H>00@000000>bF3P2][Jd0[Jf]0`3/UPh00`00
0000[Jf]0=^:3@040=^:3@8000001P3KRPd00`2][Jd000000;Ue2`070;Ue2`030:f][@28EPL0R5H7
00<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H0202][Jd0000009MP2`2GH0/0[Jf]
0=>73P000000dhL>0P0000020=>73P80000000@0[Jf]0>nH403_V10000000`3_V102000000@0kiP@
00<0[Jf]0000000000000P3lX1020:f][@030000003lX100o:0@00@0o:0@0P0000030?bP40030:f]
[@3oY140oj@A008000001`3oY142000000@0oj@A0`0000000`3oY140[Jf]0?nV4@0F0?nV4@800000
00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400E0?nU40`0[Jf]00<0oj<@000000000000303oXa000`000000oj<@0?nS40060?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P0000080?JL3`8000000`3fW0l200000080mY`?
00<0[Jf]0>bF3P3/UPh00P3/UPh2000000@0k9H>00@000000>bF3P3/UPh0k9H>0`2][Jd00`3/UPh0
00000=^:3@040=^:3@8000001`3KRPd00`000000^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0
/>3V0;3PiP100;3PiP40oooo001I0;3PiP030000002GH0/0Uf0;0080[Jf]0P0000000`3CQ`h00000
000000020=>73P8000000`3_V10010000000kiP@0>nH403_V102000000@0kiP@00<0[Jf]0000002]
[Jd00P2][Jd20?bP40030000003lX100o:0@00@0o:0@0P0000030?bP40030:f][@3oY140oj@A0080
00001`3oY142000000P0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ42000000030:f][@3oYQ40ojHA00`0
ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@00<0[Jf]0000000000001`2][Jd40?nS4080
0000203oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?008000002@3fW0l01P000000
mY`?0?JL3`000000mY`?00000080mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh2000000@0k9H>00<00000
0>bF3P3/UPh0103/UPh00`2][Jd000000:f][@040=^:3@8000001P3KRPd2000000P0^GD;0P2][Jd4
08QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0000009MP2`0000000P2][Jd00`00
0000dhL>0=>73P0200000080dhL>00<000000:f][@3_V1000P3_V10010000000kiP@0>nH403_V102
000000@0kiP@00<0[Jf]0000003lX100103lX1000`000000o:0@0?bP40030?bP40800000103lX100
0`2][Jd0oj@A0?nT4@02000000@0oj@A0`00000:0?nT4@030:f][@3oYQ40ojHA01D0ojHA0P000000
0`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS408000001`3oXa04
0:f][@800000102][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P00000:
0?JL3`@000000`3fW0l00`2][Jd0k9H>0>bF3P020>bF3P800000103/UPh00`000000k9H>0>bF3P05
0>bF3P040000003KRPd0[Jf]0:f][@80fhX=0P0000050=^:3@030000003KRPd0000000P0^GD;00<0
[Jf]08QF1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP<0000000<0Uf0;
0:f][@0000000P3CQ`h200000080dhL>00<000000:f][@3_V1000P3_V10010000000kiP@0>nH403_
V10200000080kiP@0`2][Jd00`000000o:0@0?bP40030?bP40030000003lX100o:0@00<0o:0@0P00
00040?bP40030:f][@3oY140oj@A008000004@3oY1400`2][Jd0ojHA0?nV4@0D0?nV4@030:f][@00
0000000000D0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS408000002`3oXa02000000@0oj<@202]
[JdG0?bP40030:f][@3fW0l0mY`?008000004@3fW0l00`2][Jd0k9H>0>bF3P020>bF3P8000001@3/
UPh00`000000k9H>0>bF3P040>bF3P040000003KRPd0fhX=0=^:3@80[Jf]0P0000050=^:3@800000
00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`2][Jd208QF1`030:f][@2`h>H0/>3V0400
/>3V0@3oool005T0/>3V0`0000000`2GH0/0[Jf]000000020=>73P8000000P3CQ`h00`000000[Jf]
0>nH40020>nH40040000003_V100kiP@0>nH408000000P2][Jd20>nH40030:f][@000000o:0@00@0
o:0@0P0000040?bP408000000`3lX100102][Jd0oj@A00000000000C0?nT4@030:f][@3oYQ40ojHA
00h0ojHA1P2][Jd0103oYQ4000000000002][JdL0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<0oj<@0P00000;
0?nS40800000203oXa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0[Jf]0?JL3`3fW0l00P00
000B0?JL3`030:f][@3/UPh00000008000001P3/UPh00`000000k9H>0>bF3P040>bF3P030000003K
RPd0fhX=00<0fhX=0P0000040=^:3@80000000<0fhX=0:f][@2iM@/01`2iM@/01`2][Jd0R5H708QF
1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H30000000309MP2`2][Jd000000080dhL>
0P0000020=>73P030000002][Jd0kiP@0080kiP@00@000000>nH403_V100kiP@0P0000040>nH4003
0:f][@000000o:0@00@0o:0@0P0000030?bP40800000103lX1000`2][Jd0oj@A0?nT4@0D0?nT4@03
0:f][@3oYQ40ojHA00L0ojHA1`2][Jd70?nV4@<00000703oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40030?nS4080
00002`3oXa02000000P0oj<@00<0[Jf]0?bP403lX100203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3f
W0l00P00000B0?JL3`030:f][@3/UPh0k9H>008000001P3/UPh00`000000k9H>0>bF3P040>bF3P03
0000003KRPd0fhX=00<0fhX=0P0000020:f][@060=^:3@000000fhX=0000003KRPd0[Jf]202iM@/0
1`2][Jd0@FWQ08QF1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F02`h>H40000000309MP2`2]
[Jd000000080dhL>0P0000020=>73P030000002][Jd0kiP@0080kiP@00@000000>nH402][Jd0[Jf]
0P0000040>nH408000001@3lX1000`000000o:0@000000020?bP40030000003lX100o:0@00<0o:0@
00<0[Jf]0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ460:f][@h0ojHA0P0000000`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00T000001`3oXa02000000P0oj<@00<0[Jf]0?bP403l
X1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l00P00000B0?JL3`030:f][@3/UPh0k9H>0080
k9H>0P0000050>bF3P030000003/UPh0k9H>00<0k9H>00<000000=^:3@3KRPd00`3KRPd200000080
fhX=00<000000:f][@0000000P3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0000000@0^GD;00<0[Jf]045Y
h@28EPL00P28EPL20:f][D80/>3V0@3oool005P0/>3V0P0000000`2GH0/0000009MP2`0200000080
dhL>0P0000020=>73P030000002][Jd0kiP@0080kiP@00@000000:f][@3_V100kiP@0P0000040>nH
40030000003lX100o:0@00@0o:0@00<000000?bP403lX1000P0000060?bP40030:f][@3oY140oj@A
01<0oj@A1@2][JdD0?nV4@80000000<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40090?nS
40T00000203oXa000`2][Jd0o:0@0?bP400E0?bP40H0[Jf]0P00000B0?JL3`030:f][@3/UPh0k9H>
00H0k9H>0P0000000`3/UPh000000>bF3P040>bF3P030000003KRPd0fhX=00<0fhX=0P0000020=^:
3@8000000P2][Jd00`3KRPd0[Jf]0;Ue2`020;Ue2`030000002iM@/0^GD;0080^GD;00<0[Jf]08QF
1`28EPL00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001H0;3PiP80000000<0Uf0;0000002G
H0/00P0000020=>73P8000000P3CQ`h00`000000[Jf]0>nH40020:f][@040000003_V100kiP@0>nH
408000000`3_V102000000H0o:0@00<000000?bP403lX100203lX1000`2][Jd0oj@A0?nT4@0?0?nT
4@@0[Jf]00<0oj@A0:f][@3oYQ405P3oYQ400`000000ojHA0:f][@0L0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0200000080[Jf]403fW0l00`2]
[Jd0k9H>0>bF3P080>bF3P<00000103/UPh00`000000fhX=0=^:3@030=^:3@8000000P3KRPd20000
0080fhX=0P2][Jd30;Ue2`030000002iM@/0^GD;00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f]
[D40/>3V0@3oool005L0/>3V0`0000000`2GH0/0000009MP2`0200000080dhL>0P0000020=>73P03
0000002][Jd0[Jf]0080kiP@00@000000>nH403_V100kiP@0P0000030>nH40800000103lX1020000
00/0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ400`00
0000ojHA0:f][@0L0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`0200000080mY`?1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00d0k9H>00<000000>bF
3P0000001@3KRPd200000080fhX=0P0000030=^:3@80[Jf]0P2iM@/00`000000^GD;0;Ue2`030;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000<0Uf0;0000002G
H0/00P0000020=>73P8000000P3CQ`h010000000[Jf]045Yh@3_V102000000@0kiP@0P0000020>nH
40030000002][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`02000000L0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>
00h0k9H>0P0000050=^:3@8000000`3KRPd01P000000fhX=0=^:3@3KRPd0[Jf]00000080[Jf]00<0
00000;Ue2`2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H3
0000000409MP2`000000Uf0;000000<0dhL>0P000000103CQ`h0[Jf]0000002][Jd20>nH40800000
103_V102000000040>nH4000000000000:f][A40o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`02000000`0mY`?102][Jd20?JL3`03
0:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd2000000<0fhX=00H000000=^:3@3K
RPd0fhX=0:f][@0000020;Ue2`030000002iM@/0^GD;00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL2
0:f][D40/>3V0@3oool005L0/>3V0`000000102GH0/0000009MP2`0000030=>73P030000003CQ`h0
[Jf]0080000000<0[Jf]0>nH403_V1000P0000050>nH40<0000000<0kiP@0:f][@3lX100403lX100
0`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX102000000030?JL3`000000
00000100mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00@000000`3KRPd010000000fhX=0=^:3@3K
RPd200000080^GD;00<000000:f][@2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`
h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;000000<0dhL>00<000000:f][@3CQ`h00P00
00000`2][Jd0kiP@0>nH4002000000T0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][@80oj@A00<0
00000?nT4@3oY140403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l00000008000004P3f
W0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd010000000fhX=0=^:
3@3KRPd200000080^GD;00<000000;Ue2`2][Jd00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@@2`h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;00000080dhL>00@0[Jf]0000003CQ`h0
dhL>0P0000000`2][Jd0kiP@0>nH4002000000T0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@03
0?bP402][Jd0oj@A0080oj@A00<000000?nT4@3oY140403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3K
RPd01`3KRPd010000000fhX=0=^:3@3KRPd200000080^GD;00<000000;Ue2`2iM@/00P2][Jd00`2i
M@/0[Jf]08QF1`0308QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000809MP2`000000Uf0;0000
003CQ`h0[Jf]0=>73P0000020=>73P80000000<0[Jf]0>nH403_V1000P0000090>nH40030:f][@3l
X100o:0@00T0o:0@0`2][Jd30?bP40060:f][@3oY140oj@A0000003oY14000004@3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0
k9H>00<0[Jf]0=^:3@3KRPd0203KRPd00`000000fhX=0=^:3@0200000080^GD;00<000000;Ue2`2i
M@/00P2iM@/20:f][@@0R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000<0Uf0;0000002GH0/0
0P0000020=>73P030000003CQ`h0dhL>0080000000<0[Jf]0>nH403_V1000P0000090>nH40030:f]
[@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f][@3oY140oj@A008000004P3oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>
00<0[Jf]0=^:3@3KRPd02@3KRPd2000000050:f][@000000^GD;0;Ue2`0000001@2iM@/00`2][Jd0
R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H01P000000[Jf]0000002GH0/0000009MP
2`8000000P3CQ`h00`000000dhL>0=>73P02000000030:f][@3_V100kiP@008000002@3_V1000`2]
[Jd0o:0@0?bP40040?bP40<0[Jf]203lX1001@2][Jd0oj@A0?nT4@3oY14000000140oj@A00<0[Jf]
0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]
0000002iM@/0^GD;000000050;Ue2`80[Jf]0`28EPL20:f][D40/>3V0@3oool005L0/>3V00H00000
0:f][@000000Uf0;0000002][Jd2000000030=>73P000000dhL>0080dhL>0P0000030>nH40800000
2@3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0
/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@03
0:f][@2iM@/0^GD;00800000102iM@/20:f][@<0R5H70P2][Je10;3PiP40oooo001G0;3PiP060000
002][Jd0000009MP2`000000[Jf]0P0000000`3CQ`h000000=>73P020=>73P8000000`3_V1000`00
0000kiP@0>nH40080>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh3
0:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/00P0000040;Ue2`030:f][@28EPL0[Jf]0080R5H70P2][Je1
0;3PiP40oooo001G0;3PiP060000002][Jd0000009MP2`000000Uf0;0P0000000`3CQ`h000000=>7
3P020=>73P8000000`3_V1000`000000kiP@0>nH40070>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2]
[Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/00P0000040;Ue2`030:f]
[@28EPL0[Jf]0080R5H700<0@FWQ0:f][@2`h>H0@02`h>H10?ooo`00E`2`h>H20000000809MP2`2]
[Jd0000009MP2`2][Jd000000=>73P0000030=>73P8000000`3_V1000`000000kiP@0>nH40050>nH
4080[Jf]00<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V2P2][JdH0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]
0;Ue2`2iM@/00P0000040;Ue2`070:f][@28EPL0R5H70:f][@28EPL0@FWQ0:f][@110;3PiP40oooo
001G0;3PiP80000000D0Uf0;0:f][@000000Uf0;0:f][@02000000@0dhL>00<000000:f][@3_V100
0P3_V1000`000000kiP@0>nH40030>nH4080[Jf]0`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB0?bP40030:f]
[@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]
1`3KRPd00`2][Jd0^GD;0;Ue2`02000000@0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@11JN40[Jf]
0440/>3V0@3oool005L0/>3V0P0000001`2][Jd0Uf0;0000002GH0/0[Jf]0=>73P000000103CQ`h0
0`000000[Jf]0>nH40020>nH40040000003_V100kiP@0>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2]
[Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`02000000@0^GD;00L0[Jf]08QF1`28EPL0R5H7
0:f][@11JN40[Jf]0440/>3V0@3oool005L0/>3V1000000209MP2`030:f][@3CQ`h0dhL>00@0dhL>
00<000000:f][@3_V1000P3_V10010000000kiP@0:f][@2][Jd70>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0
o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00L0
fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00800000102iM@/00`2][Jd0R5H708QF1`0208QF1`80
[Jf]@@2`h>H10?ooo`00E`2`h>H400000080Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h00`000000[Jf]
0>nH40020>nH40030000002][Jd0kiP@00P0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3f
W0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd0103KRPd0
[Jf]0;Ue2`2iM@/2000000D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001G0;3P
iP@0000000<0Uf0;0:f][@3CQ`h01P3CQ`h00`000000[Jf]0>nH40020:f][@030000003_V100kiP@
00P0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f]
[AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]0P2iM@/20000
00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001G0;3PiP@0000000<0Uf0;0:f]
[@3CQ`h01P3CQ`h00`000000[Jf]0:f][@020>nH40030000003_V100kiP@00P0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f][A00mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@<0[Jf]0P0000050;Ue2`040:f][@28EPL0R5H7
08QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H40000000309MP2`2][Jd0dhL>00H0dhL>00<000000:f]
[@3_V1000P3_V1000`000000kiP@0>nH40080>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`02000000D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je1
0;3PiP40oooo001F0;3PiP@000000P2GH0/00`2][Jd0dhL>0=>73P030=>73P80[Jf]00<000000:f]
[@3_V1000P3_V1000`000000kiP@0>nH40070>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT
4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`02000000D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je1
0;3PiP40oooo001F0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P020=>73P060:f][@3CQ`h0dhL>
0000002][Jd0kiP@0`0000090>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102]
[Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/00P0000020:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo
001F0;3PiP<000000`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00<0dhL>00<000000:f][@3_V100
303_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`0200000080^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL00`2][Jd0
@FWQ0;3PiP100;3PiP40oooo001F0;3PiP80000000H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f]
[@@0dhL>00<000000:f][@3_V100303_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f]
[@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0000000<0^GD;0`2][Jd3
08QF1`030:f][@11JN40/>3V0400/>3V0@3oool005H0/>3V0P000000102][Jd0Uf0;09MP2`2GH0/2
0:f][@D0dhL>00<000000=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH3
0:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0
[Jf]0;Ue2`2iM@/0^GD;000000050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0
?`2`h>H10?ooo`00EP2`h>H2000000@0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102]
[Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0
[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H2000000<0Uf0;0P2][Jd80=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^
0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`80[Jf]0`28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP8000000`2GH0/20:f]
[@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2]
[Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji
^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`2][Jd00P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;09MP
2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd6
0;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3P
iP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:
0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH
0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2][Je10;3PiP40oooo
001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/
102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh
0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40
oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/
102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh
102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40
oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0
a/2l00<0[Jf]0<>m^`33_K/03@33_K/3045Yh@H0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je00;3PiP40oooo001F0;3PiP030000
002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@05
045Yh@2TWXl0Y9j?0:BNS`2][Jd0102aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0
_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0;0<>m^`<0@FWQ00<0[Jf]0;ji^02n^KP00`2n^KP20:f]
[@H0_[Vh00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>7
3P3CQ`h01`3CQ`h01P2][Jd0kiP@0:f][@2][Jd0Y9j?045Yh@@0Y9j?00<0[Jf]0;6[W@2aZid0102a
Zid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00/0`kfk0P11JN40102][Jd0_[Vh0;ji^02n^KP20:f][@L0_[Vh0`11JN420;B`/@80[Jf]
00<0fhX=0:f][@2iM@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V
00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]00@0@FWQ0:BNS`2TWXl0
@FWQ102TWXl00`2][Jd0/J^M0;6[W@060;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02`33_K/2045Yh@040:f][@2n^KP0[Jf]0:f]
[@P0_[Vh00@0@FWQ0;ji^02][Jd0@FWQ0`2d/;400`11JN40[Jf]0:f][@0:0;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0
dhL>00H0dhL>00@0[Jf]0:BNS`11JN40@FWQ0P2TWXl00`11JN40Y9j?0:BNS`020:BNS`050:f][@2a
Zid0/J^M0;6[W@11JN401P2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00/0`kfk0P11JN420:f][@P0_[Vh
0P11JN420;ji^0030:f][@11JN40];2a0080];2a00<0@FWQ0;B`/@2d/;400P2][Jd80;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f]
[@3CQ`h0dhL>00@0dhL>0P2][Jd20:BNS`80@FWQ0P2TWXl00`11JN40Y9j?0:BNS`020:BNS`060:f]
[@2aZid0@FWQ045Yh@2aZid0@FWQ1`2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0P2][Jd2
045Yh@030:f][@2n^KP0_[Vh00D0_[Vh0`11JN430;ji^0030:f][@11JN40];2a0080];2a00H0@FWQ
0;B`/@2d/;40@FWQ0;B`/@2][Jd70;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00
EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]045Yh@11JN40
0P2TWXl2045Yh@80Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?0:f][@020;6[W@04045Yh@2aZid0/J^M045Y
h@P0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd20<>m
^`80@FWQ00<0[Jf]0;ji^02n^KP01`2n^KP00`11JN40_[Vh0;ji^0020;ji^005045Yh@2d/;40];2a
0;B`/@11JN400P2d/;42045Yh@030;B`/@2][Jd0[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2]
[Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0@FWQ08Z5
M@11JN420:BNS`80@FWQ0P2TWXl01@11JN40Y9j?0:BNS`2TWXl0[Jf]0080/J^M00H0@FWQ0;6[W@2a
Zid0/J^M045Yh@2aZid2045Yh@@0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY
0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/00P33_K/40:f][@D0`kfk0P11JN400`2][Jd0_[Vh045Yh@070;ji^003045Yh@2n^KP0
_[Vh0080_[Vh00D0@FWQ0;B`/@2d/;40];2a045Yh@020;B`/@80@FWQ0P2][Jd00`11JN40[Jf]0:f]
[@030;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00<0dhL>00@0[Jf]08Z5M@11JN40@FWQ0`2][Jd2045Yh@80Y9j?00D0@FWQ0:BNS`2T
WXl0Y9j?0:f][@020;6[W@07045Yh@2aZid0/J^M0;6[W@11JN40/J^M045Yh@050;6[W@030:f][@2i
/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0:f][@020:f][@T0`kfk0P11JN400`2][Jd0@FWQ0;ji^002045Yh@D0_[Vh00<0
@FWQ0;ji^02n^KP00P2n^KP00`11JN40];2a0;B`/@020;B`/@04045Yh@2d/;40@FWQ045Yh@80];2a
00@0[Jf]045Yh@2OVj00[Jf]0P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0
/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@80RXEe0P11JN400`2][Jd0Y9j?0:BNS`02
045Yh@030:BNS`11JN40@FWQ00<0Y9j?00@0[Jf]0;6[W@2aZid0@FWQ102aZid2045Yh@D0/J^M00<0
@FWQ0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36
`;`30:f][@`0`kfk0`11JN430;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00<0@FWQ0;ji^02n^KP00P2n
^KP00`11JN40];2a0;B`/@020;B`/@04045Yh@2][Jd0[Jf]045Yh@80];2a00@0@FWQ09nKX02OVj00
Wi^P0`2][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/0
0P2GH0/20:f][@@0RXEe0P11JN400`2][Jd0Y9j?0:BNS`02045Yh@030:f][@11JN40@FWQ00<0Y9j?
00@0[Jf]0;6[W@2aZid0@FWQ102aZid2045Yh@D0/J^M00D0@FWQ0;VbYP2i/ZH0^K:V045Yh@0;0;Vb
YP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0
_0@0[Jf]00<0a/2l0:f][@33_K/02@33_K/2045Yh@040<>m^`11JN40@FWQ045Yh@@0_[Vh00<0@FWQ
0;ji^02n^KP00P2n^KP00`11JN40_[Vh0;ji^0020;ji^006045Yh@2d/;40];2a0;B`/@2][Jd0@FWQ
0P2d/;401011JN40];2a0;B`/@11JN4509nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@2:QGD0RXEe00<0RXEe
0P11JN400`2][Jd0Y9j?0:BNS`02045Yh@030:BNS`11JN40@FWQ00<0Y9j?00@0[Jf]0;6[W@2aZid0
@FWQ102aZid2045Yh@D0/J^M00D0@FWQ0;VbYP2i/ZH0^K:V045Yh@0<0;VbYP030:f][@2n]j`0[Jf]
00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`040<>m
^`03045Yh@33_K/0`kfk0080@FWQ0P33_K/2045Yh@030:f][@2n^KP0_[Vh0080_[Vh00<0@FWQ0;ji
^02n^KP00P2n^KP00`11JN40_[Vh0;ji^0020;ji^006045Yh@2d/;40];2a0:f][@2d/;40@FWQ0P2d
/;401011JN40];2a045Yh@2][Jd609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00
EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@D0RXEe0P11JN400`2][Jd0Y9j?0:BNS`02045Yh@04
0:BNS`11JN40@FWQ0:f][@80Y9j?00<0[Jf]0;6[W@2aZid00P11JN430;6[W@80@FWQ102aZid2045Y
h@<0^K:V00<0@FWQ0;VbYP2i/ZH02P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2]
[Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2]
[Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`030<>m^`03045Yh@33_K/0@FWQ
00<0@FWQ0P33_K/2045Yh@030<>m^`2][Jd0_[Vh0080_[Vh0P11JN430;ji^003045Yh@2n^KP0_[Vh
0080_[Vh00<0@FWQ0:f][@2][Jd00P2d/;401011JN40];2a0;B`/@2d/;42045Yh@030:f][@2OVj00
Wi^P00@0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0
Uf0;09MP2`80[Jf]1@2:QGD2045Yh@030:f][@2TWXl0Y9j?0080@FWQ00@0Y9j?045Yh@11JN40Y9j?
0`2][Jd20;6[W@80@FWQ0`2aZid2045Yh@@0/J^M0P11JN430;VbYP03045Yh@2i/ZH0^K:V00X0^K:V
00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc
0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f]
[@33_K/0`kfk0080`kfk00@0@FWQ0<>m^`33_K/0`kfk0P11JN430<>m^`04045Yh@33_K/0@FWQ0:f]
[@<0_[Vh0P11JN430;ji^006045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ102d/;400`11JN40];2a0;B`
/@020;B`/@03045Yh@2][Jd0Wi^P00D0Wi^P00D0@FWQ0:f][@28EPL0R5H70:f][@100;3PiP40oooo
001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1@2:QGD2045Yh@030:f][@2TWXl0Y9j?0080@FWQ00<0
Y9j?045Yh@11JN400`2TWXl20:f][@80/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@050;6[W@<0@FWQ
00<0^K:V045Yh@11JN40202i/ZH4045Yh@030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]
0<6j/00;0<6j/0@0@FWQ0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje
00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l
102][JdA0<K0_0040:f][@33_K/0`kfk0<>m^`80@FWQ1033_K/00`11JN40`kfk0<>m^`020<>m^`80
@FWQ00@0[Jf]0;ji^02n^KP0_[Vh0P11JN430;ji^006045Yh@2n^KP0[Jf]0:f][@2n^KP0@FWQ102d
/;400`11JN40];2a0;B`/@030;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Jd00`28EPL0[Jf]0;3P
iP0o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]1@2:QGD2045Yh@<0Y9j?0P11
JN40202TWXl0@FWQ045Yh@11JN40Y9j?045Yh@2][Jd0/J^M0P2][Jd01@2aZid0@FWQ0;6[W@2aZid0
@FWQ00D0/J^M0`11JN40102i/ZH0@FWQ045Yh@11JN460;VbYP03045Yh@2i/ZH0@FWQ0080^K:V00@0
@FWQ0;jg[011JN40@FWQ3P2n]j`40:f][@d0`KZ`1011JN400`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l00X0a/2l0P11JN440<K0_0030:f]
[@33_K/0`kfk0080@FWQ1@33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ00@0[Jf]0;ji^02n^KP0
_[Vh0P11JN430;ji^003045Yh@2][Jd0_[Vh0080_[Vh00<0@FWQ0;B`/@2d/;400P2d/;400`11JN40
];2a0;B`/@030;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?oo
o`00EP2`h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD2045Yh@<0Y9j?00<0@FWQ0:BNS`11
JN401@11JN40102][Jd0/J^M0;6[W@2aZid20:f][@03045Yh@2aZid0@FWQ00D0/J^M00@0@FWQ0:f]
[@11JN40^K:V0`11JN460;VbYP80@FWQ0`2i/ZH0102][Jd0@FWQ045Yh@11JN430;jg[080@FWQ2P2n
]j`00`2][Jd0`KZ`0<6j/0050:f][@P0`KZ`00D0@FWQ0<6j/031^[00`KZ`0:f][@0E0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00L0a/2l0`11JN460<K0_0030:f]
[@33_K/0`kfk0080@FWQ1@33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ00@0[Jf]0;ji^02n^KP0
_[Vh0P11JN430:f][@03045Yh@2n^KP0_[Vh0080_[Vh00<0@FWQ0;B`/@2d/;400P2d/;400`11JN40
];2a0;B`/@030;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40
oooo001F0;3PiP80[Jf]0`1SH5<20:f][@@0RXEe0P11JN430:BNS`03045Yh@2TWXl0Y9j?00<0@FWQ
00<0Y9j?045Yh@2][Jd00P2aZid01011JN40/J^M0;6[W@2aZid2045Yh@@0/J^M0P11JN401P2][Jd0
@FWQ0;VbYP11JN40^K:V045Yh@H0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH0102][Jd0@FWQ045Yh@11
JN450;jg[0<0@FWQ1`2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]0`31^[001@11JN40`KZ`0<6j
/031^[00[Jf]01D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l0080a/2l
0P11JN450<K0_003045Yh@36`;`0a/2l00@0a/2l00<0[Jf]0<>m^`33_K/00P11JN450<>m^`03045Y
h@33_K/0`kfk0080`kfk0P11JN40102][Jd0_[Vh0;ji^02n^KP2045Yh@@0_[Vh00D0@FWQ0;ji^02n
^KP0_[Vh045Yh@020;B`/@80@FWQ1P2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]
0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2]
[Jd00`2:QGD2045Yh@80Y9j?0P11JN450:BNS`80@FWQ00@0[Jf]0;6[W@2aZid0@FWQ102aZid01@11
JN40[Jf]0:f][@2][Jd0/J^M0080@FWQ00H0[Jf]045Yh@2i/ZH0@FWQ0;VbYP11JN450;VbYP80@FWQ
0`2i/ZH00`2][Jd0_[N/0;jg[002045Yh@D0_[N/00<0@FWQ0;jg[02n]j`01`2n]j`00`2][Jd0`KZ`
0<6j/00:0<6j/0<0[Jf]00D0@FWQ0:f][@31^[00`KZ`0:f][@0E0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`00`2][Jd0
@FWQ045Yh@020<K0_080@FWQ1@36`;`00`11JN40a/2l0<K0_0040<K0_0050:f][@33_K/0`kfk0<>m
^`11JN401@33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ00D0[Jf]0;ji^02][Jd0[Jf]045Yh@05
0;ji^005045Yh@2n^KP0_[Vh045Yh@2][Jd02P2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2O
Vj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0
[Jf]08Z5M@2:QGD0[Jf]0P2:QGD2045Yh@80Y9j?0P11JN460:BNS`05045Yh@2][Jd0/J^M0;6[W@11
JN40102aZid01@11JN40/J^M0;6[W@2aZid0[Jf]0080@FWQ00H0[Jf]045Yh@2i/ZH0@FWQ0;VbYP11
JN450;VbYP80@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[002045Yh@D0_[N/00<0@FWQ0;jg[02n]j`01`2n
]j`00`2][Jd0`KZ`0<6j/00=0<6j/003045Yh@31^[00[Jf]00L0[Jf]4033_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0
[Jf]0<O1_037`K`04037`K`2045Yh@80a/2l1011JN450<K0_003045Yh@36`;`0a/2l00@0a/2l00D0
[Jf]0<>m^`33_K/0`kfk045Yh@050<>m^`80@FWQ0`33_K/2045Yh@80[Jf]0P2n^KP00`11JN40_[Vh
0;ji^0030;ji^080@FWQ00<0_[Vh045Yh@2][Jd02P2d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P
00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00H0
[Jf]08Z5M@2:QGD0RXEe0:f][@2:QGD2045Yh@030:BNS`11JN40@FWQ00P0Y9j?00@0[Jf]0;6[W@2a
Zid0@FWQ102aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ00H0[Jf]045Yh@2i/ZH0@FWQ0;VbYP11
JN450;VbYP80@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[002045Yh@D0_[N/00<0@FWQ0;jg[02n]j`01`2n
]j`0102][Jd0`KZ`0<6j/031^[03045Yh@T0`KZ`00D0@FWQ0<6j/031^[00`KZ`0:f][@050<>m/`/0
[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38
`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00l0al6l0P11JN40102][Jd0a/2l0<K0_036`;`3
045Yh@D0a/2l00<0@FWQ0<K0_036`;`01036`;`0102][Jd0`kfk0<>m^`33_K/2045Yh@@0`kfk0P11
JN400`33_K/0[Jf]0:f][@02045Yh@050:f][@2n^KP0_[Vh0;ji^011JN401@2n^KP01@11JN40_[Vh
045Yh@2n^KP0[Jf]00X0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f]
[@2:QGD0@FWQ00<0@FWQ202TWXl01@2][Jd0/J^M0;6[W@2aZid0@FWQ0080/J^M00<0@FWQ0;6[W@2a
Zid00`2aZid2045Yh@060:f][@11JN40[Jf]045Yh@2][Jd0@FWQ102i/ZH2045Yh@@0^K:V00<0[Jf]
0;jg[02n]j`00P11JN450;jg[003045Yh@2n]j`0_[N/00L0_[N/00@0[Jf]0<6j/011JN40@FWQ0P31
^[000`11JN40`KZ`0<6j/0020<6j/080@FWQ0`31^[001@11JN40`KZ`0<6j/031^[00[Jf]0100`kfc
2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00D0al6l
00<0@FWQ0<O1_037`K`01`37`K`2045Yh@030:f][@36`;`0a/2l0080a/2l0P11JN450<K0_003045Y
h@36`;`0a/2l00@0a/2l00@0[Jf]0<>m^`33_K/0`kfk2011JN400`2][Jd0`kfk0<>m^`02045Yh@04
0:f][@2n^KP0_[Vh045Yh@H0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh0:f][@0:0;B`/@80[Jf]1P2OVj00
0`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2]
[Jd0RXEe08Z5M@0308Z5M@80[Jf]00<0Y9j?045Yh@2TWXl0202TWXl00`2][Jd0/J^M0;6[W@020;6[
W@80@FWQ1P2aZid01011JN40/J^M0:f][@2i/ZH2045Yh@040;VbYP11JN40[Jf]0:f][@80^K:V0P11
JN440;VbYP030:f][@2n]j`0_[N/0080@FWQ1@2n]j`00`11JN40_[N/0;jg[0070;jg[0030:f][@11
JN40@FWQ00@0`KZ`00@0@FWQ0<6j/031^[00@FWQ1@31^[001@11JN40`KZ`0<6j/031^[00[Jf]01D0
`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l045Yh@050<O1_003045Yh@37`K`0al6l00H0
al6l0P11JN400`37`K`0[Jf]0<K0_0030<K0_080@FWQ1@36`;`00`11JN40a/2l0<K0_0040<K0_003
0:f][@33_K/0`kfk00D0`kfk0P2][Jd2045Yh@<0`kfk0P11JN40102][Jd0_[Vh0;ji^011JN460;ji
^005045Yh@2n^KP0_[Vh0;ji^02][Jd0102d/;400`11JN40];2a0;B`/@030;B`/@030:f][@2OVj00
Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0
Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00T0/J^M0P11JN40102aZid0[Jf]0;VbYP11JN420;VbYP03045Yh@2i/ZH0^K:V0080[Jf]0P11
JN440;VbYP030:f][@2n]j`0_[N/0080@FWQ1@2n]j`00`11JN40_[N/0;jg[0060;jg[0040:f][@31
^[00@FWQ045Yh@D0`KZ`0`11JN450<6j/003045Yh@31^[00`KZ`00<0@FWQ5033_K<00`2][Jd0aKje
0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j
4@2][JdA0<S1^`030:f][@38`K/0b<6k00h0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0al6l
045Yh@050<O1_003045Yh@37`K`0al6l00H0al6l0P11JN400`37`K`0[Jf]0<K0_0030<K0_080@FWQ
1@36`;`00`11JN40a/2l0<K0_0040<K0_0030:f][@33_K/0`kfk0080`kfk0`2][Jd20<>m^`80@FWQ
0`33_K/2045Yh@030:f][@2n^KP0@FWQ00L0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh0:f][@040;B`/@04
045Yh@2d/;40];2a0;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool0
05H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]2@2TWXl00`2][Jd0/J^M0;6[W@08
0;6[W@<0@FWQ00@0/J^M0:f][@2i/ZH0@FWQ0`2i/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@<0[Jf]
00<0^K:V0:f][@11JN400`11JN450;jg[003045Yh@2n]j`0_[N/00H0_[N/00@0[Jf]0<6j/011JN40
@FWQ1P31^[02045Yh@D0`KZ`00H0@FWQ0<6j/011JN40`KZ`0:f][@33_K<2045Yh@H0`kfc0`11JN49
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`060<S1^`<0@FWQ1038`K/00`11JN40b<6k0<S1^`03
0<S1^`030:f][@37`K`0@FWQ00@0al6l0`11JN470<O1_004045Yh@37`K`0al6l0:f][@@0a/2l0P11
JN450<K0_003045Yh@36`;`0a/2l00@0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd50<>m^`03045Yh@33
_K/0`kfk0080`kfk1@11JN470;ji^005045Yh@2n^KP0_[Vh0;ji^02][Jd0102d/;401011JN40];2a
0;B`/@2][Jd20;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3P
iP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f]
[@L0Y9j?00<0[Jf]0;6[W@2aZid02@2aZid3045Yh@030:f][@2i/ZH0@FWQ00<0^K:V00@0@FWQ0;Vb
YP2i/ZH0^K:V0P11JN430;VbYP<0[Jf]0P2n]j`3045Yh@80_[N/0P11JN480;jg[0040:f][@31^[00
@FWQ045Yh@H0`KZ`0P11JN450<6j/080@FWQ0P31^[00102][Jd0`kfc0<>m/`11JN480<>m/`@0@FWQ
0P33_K<3045Yh@030<>m/`2][Jd0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`050<S1^`04045Yh@38`K/0b<6k0<S1^`80@FWQ00<0b<6k045Yh@11JN401@38`K/0102][Jd0
@FWQ045Yh@11JN430<O1_0<0@FWQ1`37`K`01011JN40al6l0<O1_02][Jd40<K0_080@FWQ1@36`;`2
045Yh@<0a/2l102][Jd20<>m^`80@FWQ1033_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ00<0[Jf]
0;ji^02n^KP01`2n^KP01@11JN40_[Vh0;ji^02n^KP0[Jf]00D0];2a0P2][Jd30;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1S
H5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP11JN400`2i/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@@0
^K:V00<0[Jf]0;jg[02][Jd00`2][Jd30;jg[080@FWQ202n]j`0102][Jd0`KZ`045Yh@11JN460<6j
/080@FWQ1031^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN470<>m/`80@FWQ1`33_K<4045Y
h@80aKje1011JN4>0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00X0b<6k1`11JN430<S1^`030:f][@38`K/0b<6k
00@0b<6k0P11JN440<S1^`<0@FWQ1P38`K/0102][Jd0@FWQ045Yh@11JN430<O1_0<0@FWQ1`37`K`0
1011JN40al6l0<O1_02][Jd40<K0_0@0@FWQ0`36`;`2045Yh@<0[Jf]0P36`;`0102][Jd0`kfk0<>m
^`33_K/2045Yh@@0`kfk00@0@FWQ0<>m^`33_K/0`kfk0P11JN400`33_K/0[Jf]0;ji^0080;ji^005
045Yh@2n^KP0_[Vh0;ji^02][Jd00`2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102]
[Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl00`2TWXl20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0102][Jd0^K:V0;VbYP2i
/ZH3045Yh@<0^K:V0P11JN440;VbYP030:f][@2n]j`0_[N/00<0_[N/0`2][Jd2045Yh@P0_[N/00@0
[Jf]0<6j/031^[00@FWQ1P31^[02045Yh@@0`KZ`0P11JN430<6j/0050:f][@33_K<0`kfc0<>m/`11
JN401`33_K<2045Yh@L0`kfc00<0@FWQ0:f][@35_[D01@35_[D4045Yh@L0aKje0`11JN420<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0D0<O1^PL0
@FWQ2P38`K/2045Yh@D0b<6k00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@H0b<6k0P11JN460<S1^`04
0:f][@11JN40@FWQ045Yh@<0al6l0`11JN460<O1_080@FWQ0P37`K`00`2][Jd0a/2l0<K0_004045Y
h@030<K0_02][Jd0[Jf]0080[Jf]0P11JN440<K0_003045Yh@2][Jd0`kfk0080`kfk00<0@FWQ0<>m
^`33_K/00P33_K/00`11JN40`kfk0<>m^`050<>m^`030:f][@2n^KP0_[Vh00L0_[Vh00D0@FWQ0;ji
^02n^KP0_[Vh0:f][@020;B`/@030:f][@2d/;40];2a00D0];2a00<0[Jf]09nKX02OVj001@2OVj00
102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]
0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP04
0;VbYP<0@FWQ00<0^K:V045Yh@11JN40102i/ZH00`2][Jd0_[N/0;jg[0060;jg[080@FWQ0`2][Jd5
0;jg[0040:f][@31^[00`KZ`045Yh@H0`KZ`0P11JN440<6j/080@FWQ0`31^[001@2][Jd0`kfc0<>m
/`33_K<0@FWQ00L0`kfc0P11JN470<>m/`03045Yh@2][Jd0aKje00D0aKje0P11JN470<Fn]@80@FWQ
0`35_[D00`11JN40aKje0:f][@060<Jo]`03045Yh@36_kL0a[ng00@0@FWQ2036_kL00`11JN40a[ng
0:f][@0F0<O1^0030:f][@37`KX0al6j0140al6j1@11JN450<S1^`80@FWQ2038`K/2045Yh@D0b<6k
00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@H0b<6k0P11JN460<S1^`040:f][@11JN40@FWQ045Yh@<0
al6l00<0@FWQ0<O1_011JN401P37`K`2045Yh@80al6l00<0[Jf]0<K0_036`;`01@2][Jd40<K0_080
@FWQ0`36`;`2045Yh@030:f][@33_K/0`kfk0080`kfk1@11JN470<>m^`030:f][@2n^KP0_[Vh00L0
_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0`2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^
N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0
Y9j?0`2][Jd=0;6[W@030:f][@2i/ZH0^K:V00P0^K:V0P11JN440;VbYP030:f][@2n]j`0_[N/00H0
_[N/0`11JN420;jg[0@0[Jf]00<0_[N/0:f][@31^[000P31^[02045Yh@@0`KZ`00<0@FWQ0<6j/031
^[000`31^[02045Yh@<0`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN460<>m/`80@FWQ1`33_K<00`11
JN40[Jf]0<Fn]@050<Fn]@80@FWQ1P35_[D2045Yh@D0aKje00<0@FWQ0:f][@36_kL01@36_kL3045Y
h@@0a[ng0P11JN460<Jo]`03045Yh@36_kL0[Jf]01H0al6h00<0[Jf]0<O1^P37`KX05037`KX2045Y
h@H0b<6k0P11JN470<S1^`80@FWQ1@38`K/00`2][Jd0b<6k0<S1^`030<S1^`80@FWQ1P38`K/2045Y
h@H0b<6k00@0[Jf]045Yh@37`K`0@FWQ0`37`K`00`11JN40al6l045Yh@060<O1_080@FWQ1@2][Jd9
0<K0_0<0@FWQ0`36`;`2045YhA00`kfk00<0[Jf]0;ji^02n^KP01`2n^KP00`11JN40_[Vh0;ji^002
0:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3P
iP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP080;Vb
YP80@FWQ102i/ZH00`2][Jd0_[N/0;jg[0060;jg[0<0@FWQ1P2n]j`50:f][@80`KZ`0P11JN420<6j
/003045Yh@31^[00`KZ`00<0`KZ`0P11JN430<6j/0040:f][@33_K<0`kfc0<>m/`80@FWQ1P33_K<2
045Yh@L0`kfc00<0@FWQ0:f][@35_[D01@35_[D2045Yh@D0aKje0P11JN470<Fn]@03045Yh@36_kL0
a[ng00@0a[ng0P11JN460<Jo]`03045Yh@36_kL0a[ng00@0a[ng0P11JN400`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01@0al6j0P11JN470<S1^`80@FWQ1P38`K/2045Yh@D0b<6k00<0[Jf]
0<S1^`38`K/00`38`K/2045Yh@H0b<6k0P11JN460<S1^`040:f][@11JN40al6l045Yh@80al6l0P11
JN420<O1_003045Yh@37`K`0al6l00<0[Jf]0P11JN420<O1_0030:f][@36`;`0a/2l00T0a/2l0P11
JN401P36`;`0@FWQ0<K0_036`;`0@FWQ0:f][A00`kfk00<0[Jf]0;ji^02n^KP01@2n^KP2045Yh@05
0;ji^02][Jd0[Jf]0;ji^02][Jd02P2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?oo
o`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0
/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH00`11JN40^K:V0;VbYP020;VbYP030:f][@2n]j`0_[N/00H0
_[N/0`11JN430;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd00`31^[040:f][@<0@FWQ1@31^[02045Y
h@<0`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN460<>m/`80@FWQ1`33_K<00`11JN40[Jf]0<Fn]@05
0<Fn]@80@FWQ1@35_[D2045Yh@L0aKje00<0[Jf]045Yh@36_kL01036_kL00`11JN40a[ng0<Jo]`06
0<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`2][Jd05P37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P80@FWQ1`38`K/2045Yh@H0b<6k0P11JN450<S1^`030:f][@38`K/0b<6k00<0b<6k0P11JN46
0<S1^`80@FWQ1P38`K/2045Yh@80al6l00@0@FWQ0<O1_011JN40@FWQ0P2][Jd00`11JN40[Jf]0:f]
[@030<O1_080@FWQ0P37`K`00`2][Jd0a/2l0<K0_0090<K0_080@FWQ0P36`;`3045Yh@030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@05
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]
0;VbYP2i/ZH02@2i/ZH00`11JN40^K:V0;VbYP020;VbYP030:f][@2n]j`0_[N/00H0_[N/0P11JN40
102n]j`0@FWQ0;jg[02n]j`2045Yh@80_[N/00@0[Jf]0<6j/031^[00@FWQ1P31^[000`11JN40[Jf]
0:f][@030:f][@80@FWQ0`31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@H0`kfc0P11JN460<>m/`80
@FWQ00<0[Jf]0<Fn]@35_[D01035_[D2045Yh@D0aKje00<0@FWQ0<Fn]@35_[D01P35_[D00`2][Jd0
a[ng0<Jo]`040<Jo]`03045Yh@36_kL0a[ng00H0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0al6j0P11JN480<S1^`03045Yh@38`K/0b<6k00@0
b<6k0P11JN450<S1^`030:f][@38`K/0b<6k00@0b<6k0P11JN450<S1^`80@FWQ1P38`K/2045Yh@04
0<O1_02][Jd0@FWQ0:f][@80@FWQ0P37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ0P37`K`00`2]
[Jd0a/2l0<K0_0090<K0_080@FWQ1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2]
[Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;VbYP090;VbYP03
045Yh@2i/ZH0^K:V0080^K:V00@0[Jf]0;jg[02n]j`0@FWQ0`2n]j`4045Yh@040;jg[011JN40_[N/
0;jg[080@FWQ0P2n]j`0102][Jd0`KZ`0<6j/011JN460<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11
JN470:f][@80@FWQ1P33_K<2045Yh@H0`kfc0P11JN400`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ1@35
_[D00`11JN40aKje0<Fn]@060<Fn]@030:f][@36_kL0a[ng00d0a[ng00<0@FWQ0<Jo]`36_kL01@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0al6j0P11JN480<S1^`03045Yh@38
`K/0b<6k00@0b<6k0P11JN450<S1^`030:f][@38`K/0b<6k00@0b<6k1@11JN430<S1^`04045Yh@38
`K/0b<6k0<S1^`<0[Jf]0P11JN40102][Jd0al6l045Yh@37`K`2045Yh@80al6l00<0@FWQ0<O1_037
`K`00`37`K`2045Yh@80al6l00<0[Jf]0<K0_036`;`01`36`;`2045Yh@P0a/2l00<0[Jf]0<>m^`33
_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2]
[Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:
QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0
[Jf]0;VbYP0:0;VbYP80@FWQ0`2i/ZH0102][Jd0_[N/0;jg[011JN490;jg[0<0@FWQ0`2n]j`0102]
[Jd0`KZ`0<6j/011JN460<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11JN430<6j/0040:f][@33_K<0
`kfc0<>m/`80@FWQ1@2][Jd00`33_K<0@FWQ045Yh@060<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D01035
_[D2045Yh@D0aKje00<0@FWQ0<Fn]@35_[D01P35_[D00`2][Jd0a[ng0<Jo]`0<0<Jo]`80@FWQ1`36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0al6j0P11JN480<S1^`03045Yh@38
`K/0b<6k00@0b<6k0P11JN450<S1^`030:f][@38`K/0b<6k00T0b<6k1011JN430:f][@<0b<6k0P11
JN420<O1_004045Yh@37`K`0@FWQ045Yh@80al6l00<0@FWQ0<O1_037`K`00`37`K`2045Yh@80al6l
00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0
/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M00X0/J^M0`2][Jd:0;VbYP80@FWQ0`2i/ZH0102][Jd0_[N/0;jg[011JN4?0;jg[004
0:f][@31^[00`KZ`045Yh@H0`KZ`00<0@FWQ0<6j/031^[000`31^[02045Yh@<0`KZ`00<0[Jf]0<>m
/`33_K<00P11JN460<>m/`030:f][@11JN40@FWQ00D0[Jf]00@0`kfc045Yh@11JN40[Jf]1P35_[D2
045Yh@@0aKje0P11JN480<Fn]@030:f][@36_kL0a[ng00X0a[ng0`11JN480<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX04`37`KX2045Yh@P0b<6k0P11JN450<S1^`80@FWQ1@38`K/0
102][Jd000000<S1^`38`K/80:f][@<0b<6k00<0@FWQ0<S1^`38`K/01038`K/01`11JN40al6l0<O1
_037`K`0@FWQ0<O1_011JN401037`K`00`11JN40al6l0<O1_0020<O1_080@FWQ0P37`K`00`2][Jd0
a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l00/0a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@`0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V
0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid00`000000[Jf]
0;VbYP040:f][@L0^K:V0P11JN420;VbYP040:f][@2n]j`0_[N/045Yh@l0_[N/00@0[Jf]0<6j/031
^[00`KZ`0P11JN430<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc
0080@FWQ1`33_K<2045Yh@D0`kfc00<0[Jf]045Yh@11JN401P2][Jd00`35_[D0@FWQ045Yh@040<Fn
]@80@FWQ2035_[D00`2][Jd0a[ng0<Jo]`080<Jo]`@0@FWQ1`36_kL00`11JN40a[ng0:f][@0G0<O1
^0030:f][@37`KX0al6j01<0al6j0P11JN480<S1^`80@FWQ1@38`K/2045Yh@T0[Jf]2`38`K/00`11
JN40b<6k0<S1^`040<S1^`03045Yh@37`K`0al6l0080al6l0P11JN440<O1_0<0@FWQ0P37`K`2045Y
h@80al6l00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_00;0<K0_0030:f][@33_K/0`kfk
00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nK
X02][Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0
/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@@0^K:V0P11JN420;VbYP040:f][@2n]j`0@FWQ045Y
h@l0_[N/00<0[Jf]0<6j/031^[000`31^[03045Yh@L0`KZ`0`11JN420<6j/0040:f][@33_K<0@FWQ
045Yh@P0`kfc0P11JN460<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D00`35_[D00`2][Jd0@FWQ045Yh@04
0:f][@80@FWQ0`2][Jd50<Fn]@030:f][@36_kL0a[ng00H0a[ng1011JN490<Jo]`03045Yh@36_kL0
[Jf]01L0al6h00<0[Jf]0<O1^P37`KX04`37`KX2045Yh@D0b<6k0`2][Jd2045Yh@D0[Jf]0P11JN45
0<S1^`030:f][@38`K/0b<6k00@0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN44
0<O1_080@FWQ0P37`K`3045Yh@D0al6l0P11JN420<O1_0030:f][@36`;`0a/2l0080a/2l00<0@FWQ
0<K0_036`;`02`36`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd20;VbYP80@FWQ00D0^K:V0:f]
[@11JN40_[N/045Yh@0?0;jg[0030:f][@31^[00`KZ`00/0`KZ`1011JN401@31^[00@FWQ0<6j/02]
[Jd0`kfc0080@FWQ2033_K<2045Yh@H0`kfc0P11JN400`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ1@35
_[D2045Yh@80aKje1@2][Jd00`11JN40[Jf]0:f][@050:f][@<0@FWQ00<0[Jf]0<Jo]`36_kL02036
_kL00`11JN40a[ng0:f][@0G0<O1^0030:f][@37`KX0al6j00T0al6j2P2][Jd00`11JN40[Jf]0:f]
[@040:f][@<0b<6k0P11JN450<S1^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ1@38
`K/00`11JN40b<6k0<S1^`040<S1^`@0@FWQ0P37`K`2045Yh@X0al6l0P11JN420<O1_0030:f][@36
`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`02`36`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33
_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`
h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
0;VbYP2i/ZH02@2i/ZH40:f][@80@FWQ0P2n]j`00`11JN40_[N/0;jg[00=0;jg[0030:f][@31^[00
`KZ`0140`KZ`0`11JN4:0<>m/`03045Yh@33_K<0@FWQ00D0`kfc00<0@FWQ0<>m/`2][Jd01P35_[D2
045Yh@D0aKje0P11JN460<Fn]@03045Yh@2][Jd0@FWQ00D0a[ng0P11JN430<Jo]`X0[Jf]00<0@FWQ
0:f][@2][Jd08`2][Jd:0<O1^P03045Yh@2][Jd0b<6k00P0b<6k00<0@FWQ0<S1^`38`K/00`38`K/3
045Yh@<0b<6k00<0@FWQ0:f][@11JN401P38`K/00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0
b<6k0080b<6k0`11JN400`2][Jd0al6l0<O1_00>0<O1_080@FWQ0P37`K`0102][Jd0a/2l0<K0_036
`;`3045Yh@`0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0
[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0
/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@030;jg[011JN40_[N/00h0_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`090<>m/`03045Yh@33_K<0@FWQ00D0`kfc00<0@FWQ
0<>m/`2][Jd01P35_[D2045Yh@H0aKje0P11JN460<Fn]@80@FWQ1@36_kL00`11JN40a[ng0<Jo]`06
0<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`2][Jd05`37`KP00`2][Jd0al6j0<O1^P0C
0<O1^P03045Yh@2][Jd0b<6k00P0b<6k00<0@FWQ0<S1^`38`K/00`38`K/3045Yh@@0b<6k0P11JN47
0<S1^`D0@FWQ2038`K/00`2][Jd0al6l0<O1_00?0<O1_004045Yh@37`K`0al6l0:f][@<0a/2l0`11
JN4:0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0
[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc00T0`kfc00<0@FWQ0<>m/`33_K<01@11JN420<>m/`030:f][@35_[D0
aKje00@0aKje0P11JN460<Fn]@80@FWQ1P35_[D00`11JN40a[ng0<Jo]`040<Jo]`03045Yh@36_kL0
a[ng00D0a[ng0P11JN450<Jo]`03045Yh@36_kL0[Jf]01L0al6h00<0[Jf]0<O1^P37`KX04`37`KX0
0`11JN40[Jf]0<S1^`080<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN400`38`K/0@FWQ0<S1^`02
0<S1^`03045Yh@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`2045Yh@050<O1_02][Jd0
a/2l0<K0_011JN400P36`;`00`11JN40a/2l0<K0_0030<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m
^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3o
ool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc00T0`kfc00<0@FWQ0<>m/`33_K<01`33_K<00`2][Jd0aKje0<Fn]@020<Fn]@@0@FWQ1`35_[D2
045Yh@@0aKje00<0@FWQ0:f][@36_kL01@36_kL00`11JN40a[ng0<Jo]`050<Jo]`80@FWQ1@36_kL0
0`11JN40a[ng0:f][@0G0<O1^0030:f][@37`KX0al6j01<0al6j00<0@FWQ0:f][@38`K/02038`K/0
1011JN40b<6k0<S1^`38`K/4045Yh@80b<6k0`11JN400`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0100al6l0P11JN400`2][Jd0a/2l045Yh@030<K0_003045Yh@36`;`0[Jf]00<0[Jf]1`36
`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a
0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`090<>m/`03045Yh@33_K<0`kfc00L0`kfc00<0[Jf]0<Fn]@35_[D03P35
_[D5045Yh@030<Fn]@2][Jd0a[ng00D0a[ng00<0@FWQ0<Jo]`36_kL01036_kL3045Yh@@0a[ng0P11
JN400`36_kL0[Jf]0<O1^00F0<O1^0030:f][@37`KX0al6j01<0al6j00<0@FWQ0:f][@38`K/01`38
`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0<0@FWQ00<0
a/2l0:f][@2][Jd00`2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33
_K<0`kfc00T0`kfc00<0@FWQ0<>m/`33_K<01`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng00D0a[ng1P11JN420<Jo]`03045Yh@36_kL0a[ng0080a[ng0`11JN400`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01<0al6j00<0@FWQ0:f][@38`K/01`38`K/2045Yh@`0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33_K<0
`kfc00T0`kfc00<0@FWQ0<>m/`33_K<01`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng0180a[ng0`11JN400`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0al6j00<0@FWQ
0:f][@38`K/01`38`K/2045Yh@`0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00;
0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]
0<>m/`33_K<02@33_K<00`11JN40`kfc0<>m/`070<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL04P36_kL3045Yh@030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX04`37`KX0
0`11JN40[Jf]0<S1^`060<S1^`80@FWQ3@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j
/0030:f][@33_K<0`kfc00T0`kfc00<0@FWQ0<>m/`33_K<01`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng0180a[ng0`11JN400`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01<0al6j00<0@FWQ0:f][@38`K/01P38`K/2045Yh@d0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f][@D0
`kfc0P11JN400`33_K<0@FWQ0<>m/`080<>m/`030:f][@35_[D0aKje00@0aKje00<0@FWQ0<Fn]@35
_[D03@35_[D00`2][Jd0a[ng0<Jo]`0B0<Jo]`<0@FWQ00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0C0<O1^P03045Yh@2][Jd0b<6k00D0b<6k0P11JN4>0<S1^`030:f][@38`K/0b<6k0100
b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0
`kfc1`2][Jd2045Yh@T0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D00`11JN40aKje045Yh@0>0<Fn]@03
0:f][@36_kL0a[ng0180a[ng0`11JN400`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0
al6j00<0@FWQ0:f][@38`K/01@38`K/2045Yh@h0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH0
3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
2033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D01035_[D00`11JN40aKje0<Fn]@0=0<Fn]@030:f]
[@36_kL0a[ng0180a[ng0`11JN400`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01<0al6j
00<0@FWQ0:f][@38`K/01038`K/2045Yh@l0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0
[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng0180a[ng
0P11JN400`36_kL0[Jf]0<O1^00F0<O1^0030:f][@37`KX0al6j0140al6j2P11JN4;0<S1^`T0[Jf]
4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
2@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302]
[Jd50<Fn]@030:f][@36_kL0a[ng01<0a[ng00<0@FWQ0<Jo]`2][Jd05`37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2]
[JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL0
0`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H1
0?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo
]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
2`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l102]
[Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H1
0?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0
[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3PiP40
oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l
1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37
`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo002i
0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool0
0<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0
[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51164 .33856 m
.51826 .33861 L
s
.51826 .33861 m
.52157 .34087 L
s
.50832 .34078 m
.51164 .33856 L
s
.53647 .33854 m
.53813 .34077 L
s
.53482 .34081 m
.53647 .33854 L
s
.50502 .33848 m
.50666 .34301 L
s
.505 .3475 m
.50502 .33848 L
s
.52157 .34087 m
.52323 .34312 L
s
.53482 .34081 m
.53648 .34304 L
s
.50666 .34301 m
.50832 .34078 L
s
.53648 .34304 m
.53813 .34077 L
s
.52323 .34312 m
.52323 .34989 L
s
.505 .3475 m
.50666 .34301 L
s
.4852 .33801 m
.49014 .34041 L
s
.48191 .33789 m
.4852 .33801 L
s
.49014 .34041 m
.49342 .34501 L
s
.47861 .34002 m
.48191 .33789 L
s
.47696 .33996 m
.48191 .33789 L
s
.52157 .34989 m
.52323 .34764 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52157 .35215 m
.52323 .34989 L
s
.51825 .35214 m
.52157 .34989 L
s
.47529 .34441 m
.47861 .34002 L
s
.47365 .34434 m
.47696 .33996 L
s
.51825 .3544 m
.52157 .35215 L
s
.50995 .3566 m
.51825 .35214 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50995 .35887 m
.51825 .3544 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45407 .33655 m
.46549 .33719 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5365 .35433 m
.53821 .38153 L
s
.53488 .38157 m
.5365 .35433 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47361 .35112 m
.47529 .34441 L
s
.50663 .35883 m
.50995 .3566 L
s
.47196 .35105 m
.47365 .34434 L
s
.46035 .36865 m
.46059 .33693 L
s
.50663 .36109 m
.50995 .35887 L
s
.50497 .36107 m
.50663 .35883 L
s
.45871 .36856 m
.45896 .33684 L
s
.52157 .36573 m
.52323 .3612 L
s
.52323 .3612 m
.52323 .37027 L
s
.50496 .36333 m
.50663 .36109 L
s
.50496 .3656 m
.50497 .36107 L
s
.49172 .35853 m
.49337 .36084 L
s
.49006 .36075 m
.49172 .35853 L
s
.47358 .35565 m
.47361 .35112 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5199 .36799 m
.52157 .36573 L
s
.52157 .36573 m
.52323 .37027 L
s
.49336 .3631 m
.49337 .36084 L
s
.47193 .35558 m
.47196 .35105 L
s
.49006 .36075 m
.4917 .36306 L
s
.50496 .3656 m
.50661 .36789 L
s
.51658 .37025 m
.5199 .36799 L
s
.49003 .36756 m
.49336 .3631 L
s
.53652 .36792 m
.53654 .38155 L
s
.43625 .33532 m
.44757 .33613 L
s
.50661 .36789 m
.50993 .3702 L
s
.47358 .35565 m
.47519 .36252 L
s
.50993 .3702 m
.51658 .37025 L
s
.47193 .35558 m
.47354 .36245 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48671 .36973 m
.49003 .36756 L
s
.47519 .36252 m
.47846 .36718 L
s
.47354 .36245 m
.47681 .36712 L
s
.48175 .36957 m
.48671 .36973 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44246 .36074 m
.44271 .3358 L
s
.44084 .36063 m
.44109 .33568 L
s
.47846 .36718 m
.48175 .36957 L
s
.47681 .36712 m
.48175 .36957 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53488 .38157 m
.53655 .38611 L
s
.53655 .38611 m
.53821 .38153 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41864 .3338 m
.42982 .3348 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42444 .38223 m
.42501 .33438 L
s
.4538 .36829 m
.46035 .36865 L
s
.42283 .3821 m
.42342 .33424 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62618 .33385 m
.64198 .33223 L
s
.44079 .36518 m
.44246 .36074 L
s
.43917 .36507 m
.44084 .36063 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45862 .37995 m
.46024 .38232 L
s
.45696 .38215 m
.45862 .37995 L
s
.43591 .36711 m
.44079 .36518 L
s
.45858 .38452 m
.46024 .38232 L
s
.43591 .36711 m
.43917 .36507 L
s
.45696 .38215 m
.45858 .38452 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43268 .36687 m
.43591 .36711 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63253 .33323 m
.63318 .38115 L
s
.63095 .33339 m
.63159 .3813 L
s
.38449 .31399 m
.39529 .31538 L
s
.42787 .3642 m
.43268 .36687 L
s
.42471 .35937 m
.42787 .3642 L
s
.64198 .33223 m
.64515 .33415 L
s
.64198 .33223 m
.64671 .33398 L
s
.39971 .33182 m
.40438 .33462 L
s
.40438 .33462 m
.40746 .3395 L
s
.40746 .3395 m
.40894 .34649 L
s
.39971 .33182 m
.40281 .33444 L
s
.40281 .33444 m
.40589 .33933 L
s
.40589 .33933 m
.40737 .34633 L
s
.39659 .33146 m
.39971 .33182 L
s
.40888 .35105 m
.40894 .34649 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38986 .3627 m
.39064 .3148 L
s
.38831 .36251 m
.3891 .3146 L
s
.4073 .35089 m
.40737 .34633 L
s
.39345 .33336 m
.39659 .33146 L
s
.4072 .35773 m
.40888 .35105 L
s
.40562 .35757 m
.4073 .35089 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64671 .33398 m
.6499 .33817 L
s
.64515 .33415 m
.64835 .33835 L
s
.64835 .33835 m
.64998 .34273 L
s
.39027 .33754 m
.39345 .33336 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6499 .33817 m
.65153 .34254 L
s
.40398 .36198 m
.4072 .35773 L
s
.41802 .38168 m
.42444 .38223 L
s
.40241 .36181 m
.40562 .35757 L
s
.64998 .34273 m
.65164 .34939 L
s
.65153 .34254 m
.6532 .34921 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65909 .33018 m
.6698 .32874 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62679 .38173 m
.64269 .38022 L
s
.39923 .36377 m
.40398 .36198 L
s
.39923 .36377 m
.40241 .36181 L
s
.65164 .34939 m
.65182 .36084 L
s
.37962 .3293 m
.38115 .3295 L
s
.37653 .33116 m
.37962 .3293 L
s
.37805 .33137 m
.37962 .3293 L
s
.3961 .36342 m
.39923 .36377 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37644 .33573 m
.37805 .33137 L
s
.39301 .36077 m
.3961 .36342 L
s
.37492 .33551 m
.37653 .33116 L
s
.38997 .35582 m
.39301 .36077 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65037 .36789 m
.65182 .36084 L
s
.66523 .32937 m
.66579 .36143 L
s
.6532 .34921 m
.65338 .36065 L
s
.6637 .32958 m
.66425 .36162 L
s
.65193 .36772 m
.65338 .36065 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64888 .37266 m
.65037 .36789 L
s
.37616 .35176 m
.37644 .33573 L
s
.64269 .38022 m
.64581 .37759 L
s
.64269 .38022 m
.64738 .37743 L
s
.65044 .37249 m
.65193 .36772 L
s
.64581 .37759 m
.64888 .37266 L
s
.37197 .33051 m
.37492 .33551 L
s
.37455 .35615 m
.37492 .33551 L
s
.38367 .36194 m
.38986 .3627 L
s
.369 .32778 m
.37197 .33051 L
s
.64738 .37743 m
.65044 .37249 L
s
.66555 .34766 m
.6672 .35433 L
s
.36449 .32709 m
.369 .32778 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65963 .3622 m
.66579 .36143 L
s
.36146 .32891 m
.36449 .32709 L
s
.35997 .32868 m
.36449 .32709 L
s
.6672 .35433 m
.67034 .35852 L
s
.37455 .35615 m
.37616 .35176 L
s
.37315 .34905 m
.37463 .35155 L
s
.36413 .34544 m
.37315 .34905 L
s
.35988 .33326 m
.36146 .32891 L
s
.37298 .35824 m
.37455 .35615 L
s
.67034 .35852 m
.67343 .3604 L
s
.35839 .33302 m
.35997 .32868 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3699 .36012 m
.37298 .35824 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35978 .33785 m
.35988 .33326 L
s
.67343 .3604 m
.67797 .35976 L
s
.3583 .33762 m
.35839 .33302 L
s
.67637 .35537 m
.67793 .35746 L
s
.67637 .35537 m
.67784 .35286 L
s
.36118 .34268 m
.36413 .34544 L
s
.35969 .34245 m
.36413 .34544 L
s
.67784 .35286 m
.67939 .35494 L
s
.35978 .33785 m
.36118 .34268 L
s
.36386 .35925 m
.3699 .36012 L
s
.68943 .33263 m
.69082 .3278 L
s
.3583 .33762 m
.35969 .34245 L
s
.67939 .35494 m
.67944 .35724 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68943 .33263 m
.68953 .33722 L
s
.69082 .3278 m
.69518 .32475 L
s
.69229 .32755 m
.69518 .32475 L
s
.69091 .33239 m
.69229 .32755 L
s
.67797 .35976 m
.67944 .35724 L
s
.69091 .33239 m
.69101 .33698 L
s
.68953 .33722 m
.6911 .34158 L
s
.69518 .32475 m
.69955 .32398 L
s
.69101 .33698 m
.69258 .34134 L
s
.35951 .35165 m
.361 .35188 L
s
.36096 .35419 m
.361 .35188 L
s
.36091 .35649 m
.36386 .35925 L
s
.35946 .35396 m
.35951 .35165 L
s
.6911 .34158 m
.69557 .34315 L
s
.35946 .35396 m
.36091 .35649 L
s
.69955 .32398 m
.7025 .32576 L
s
.69258 .34134 m
.69557 .34315 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69129 .3508 m
.69134 .35311 L
s
.69129 .3508 m
.69277 .35056 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7025 .32576 m
.70549 .32983 L
s
.69134 .35311 m
.69287 .35518 L
s
.69277 .35056 m
.69282 .35287 L
s
.32958 .32088 m
.33954 .32283 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69287 .35518 m
.69586 .35701 L
s
.69557 .34315 m
.70436 .34394 L
s
.70682 .32495 m
.70963 .3221 L
s
.70549 .32983 m
.70682 .32495 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70549 .32983 m
.70596 .35062 L
s
.70825 .32468 m
.70963 .3221 L
s
.70693 .32956 m
.70825 .32468 L
s
.70963 .3221 m
.71105 .32183 L
s
.34622 .34949 m
.34763 .35205 L
s
.34758 .35436 m
.34763 .35205 L
s
.70693 .32956 m
.70729 .34573 L
s
.69586 .35701 m
.70171 .35602 L
s
.34471 .35155 m
.34622 .34949 L
s
.3345 .35438 m
.33525 .32201 L
s
.34607 .35643 m
.34758 .35436 L
s
.33307 .35412 m
.33383 .32173 L
s
.34471 .35155 m
.34612 .35412 L
s
.70436 .34394 m
.70585 .34599 L
s
.3417 .35568 m
.34607 .35643 L
s
.70171 .35602 m
.70456 .3532 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70596 .35062 m
.70729 .34573 L
s
.70456 .3532 m
.70596 .35062 L
s
.33886 .35285 m
.3417 .35568 L
s
.33482 .34048 m
.33609 .34769 L
s
.33609 .34769 m
.33886 .35285 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32881 .35331 m
.3345 .35438 L
s
.7189 .35286 m
.72369 .31923 L
s
.7203 .35258 m
.72386 .32618 L
s
.71465 .35368 m
.72449 .35173 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31523 .33649 m
.32493 .33853 L
s
.31936 .33738 m
.31983 .31883 L
s
.32075 .33767 m
.32121 .31913 L
s
.31702 .32054 m
.31965 .32577 L
s
.31299 .3173 m
.31702 .32054 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72369 .31923 m
.73002 .35058 L
s
.31028 .31667 m
.31299 .3173 L
s
.73002 .35058 m
.73463 .31678 L
s
.30753 .31836 m
.31028 .31667 L
s
.3062 .31803 m
.31028 .31667 L
s
.31878 .36068 m
.32034 .35396 L
s
.73139 .35028 m
.73481 .32375 L
s
.30474 .32237 m
.30753 .31836 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31999 .36798 m
.32034 .35396 L
s
.30341 .32204 m
.3062 .31803 L
s
.31589 .36479 m
.31878 .36068 L
s
.31878 .36068 m
.31999 .36798 L
s
.30329 .3267 m
.30474 .32237 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73463 .31678 m
.74086 .34817 L
s
.30196 .32638 m
.30341 .32204 L
s
.31172 .36627 m
.31589 .36479 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30177 .33339 m
.30329 .3267 L
s
.30045 .33306 m
.30196 .32638 L
s
.73683 .34909 m
.74485 .34723 L
s
.309 .36569 m
.31172 .36627 L
s
.30145 .34509 m
.30177 .33339 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30013 .34477 m
.30045 .33306 L
s
.30636 .36274 m
.309 .36569 L
s
.30501 .36244 m
.309 .36569 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30145 .34509 m
.30259 .35243 L
s
.3038 .35744 m
.30636 .36274 L
s
0 0 0 r
.76483 .3044 m
.76501 .3045 L
s
.255 .412 .882 r
.75196 .31951 m
.7544 .31415 L
s
.75081 .32452 m
.75196 .31951 L
s
.30259 .35243 m
.3038 .35744 L
s
.74971 .33187 m
.75081 .32452 L
s
.30013 .34477 m
.30126 .35212 L
s
.30246 .35713 m
.30501 .36244 L
s
.7544 .31415 m
.75813 .31076 L
s
.74971 .33187 m
.75003 .3436 L
s
.30126 .35212 m
.30246 .35713 L
s
.75325 .31917 m
.75567 .3138 L
s
.7521 .32418 m
.75325 .31917 L
s
.751 .33154 m
.7521 .32418 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75567 .3138 m
.75813 .31076 L
s
.751 .33154 m
.75133 .34327 L
s
.75813 .31076 m
.76065 .31005 L
s
.2868 .31064 m
.29095 .34485 L
s
.75003 .3436 m
.75153 .35033 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28711 .34385 m
.29483 .34583 L
s
.75133 .34327 m
.75283 .35 L
s
.76065 .31005 m
.76444 .31131 L
s
.75153 .35033 m
.75296 .35471 L
s
.75283 .35 m
.75425 .35439 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28083 .34214 m
.2868 .31064 L
s
.28208 .34249 m
.2866 .31766 L
s
.75296 .35471 m
.75567 .35879 L
s
.75425 .35439 m
.75695 .35846 L
s
.75567 .35879 m
.75957 .36017 L
s
.27691 .30774 m
.28083 .34214 L
s
.27106 .33931 m
.27691 .30774 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76798 .32988 m
.76821 .32729 L
s
.5 Mabswid
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76683 .30824 m
.7674 .32705 L
s
.76805 .30787 m
.76862 .32669 L
s
.76369 .32812 m
.77226 .3256 L
s
.76444 .31131 m
.76704 .31528 L
s
.75695 .35846 m
.75957 .36017 L
s
.27227 .33967 m
.27669 .31479 L
s
.75957 .36017 m
.7621 .3595 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7621 .3595 m
.76578 .35612 L
s
.77525 .30561 m
.78339 .30289 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76578 .35612 m
.76811 .35069 L
s
.26749 .33821 m
.2759 .34074 L
s
.76912 .34323 m
.76955 .35747 L
s
.76811 .35069 m
.76912 .34323 L
s
.76811 .35069 m
.76955 .35747 L
s
.77878 .30446 m
.77983 .33761 L
s
.26503 .30393 m
.26619 .30432 L
s
.77994 .30407 m
.78099 .33723 L
s
.26265 .30551 m
.26503 .30393 L
s
.2638 .3059 m
.26503 .30393 L
s
.2625 .31024 m
.2638 .3059 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26136 .30985 m
.26265 .30551 L
s
.77629 .33871 m
.78099 .33723 L
s
.26197 .32684 m
.2625 .31024 L
s
.78054 .32299 m
.78193 .32973 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25924 .30432 m
.26136 .30985 L
s
.26067 .33121 m
.26136 .30985 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25707 .30115 m
.25924 .30432 L
s
.78193 .32973 m
.78439 .33373 L
s
.25376 .29993 m
.25707 .30115 L
s
.26067 .33121 m
.26197 .32684 L
s
.25976 .32369 m
.26082 .32645 L
s
.25312 .31895 m
.25976 .32369 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25945 .33321 m
.26067 .33121 L
s
.78439 .33373 m
.78675 .33535 L
s
.25149 .30148 m
.25376 .29993 L
s
.25041 .30107 m
.25376 .29993 L
s
.25711 .33483 m
.25945 .33321 L
s
.78675 .33535 m
.79013 .33419 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25025 .30582 m
.25149 .30148 L
s
.78885 .32981 m
.79005 .3318 L
s
.78885 .32981 m
.78989 .32703 L
s
.25265 .33327 m
.25711 .33483 L
s
.78989 .32703 m
.79108 .32903 L
s
.24918 .30541 m
.25041 .30107 L
s
.25102 .31576 m
.25312 .31895 L
s
.25009 .31059 m
.25025 .30582 L
s
.79108 .32903 m
.79116 .33141 L
s
.79013 .33419 m
.79116 .33141 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24993 .31536 m
.25312 .31895 L
s
.25009 .31059 m
.25102 .31576 L
s
.24902 .31018 m
.24918 .30541 L
s
.24902 .31018 m
.24993 .31536 L
s
.25054 .33009 m
.25265 .33327 L
s
.79796 .30473 m
.79886 .29955 L
s
.79796 .30473 m
.79813 .3095 L
s
.24961 .32491 m
.2507 .32531 L
s
.25062 .3277 m
.2507 .32531 L
s
.79902 .30431 m
.79991 .29912 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79813 .3095 m
.79935 .31386 L
s
.79902 .30431 m
.79919 .30908 L
s
.79991 .29912 m
.80191 .29589 L
s
.79886 .29955 m
.80191 .29589 L
s
.24953 .3273 m
.25054 .33009 L
s
.24953 .3273 m
.24961 .32491 L
s
.79919 .30908 m
.8004 .31345 L
s
.80191 .29589 m
.80498 .2946 L
s
.79935 .31386 m
.80257 .31501 L
s
.8004 .31345 m
.80257 .31501 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79968 .32343 m
.79976 .32583 L
s
.79968 .32343 m
.80073 .32302 L
s
.79976 .32583 m
.80089 .32782 L
s
.80498 .2946 m
.80708 .29612 L
s
.80073 .32302 m
.80081 .32542 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80089 .32782 m
.80307 .32941 L
s
.80257 .31501 m
.80876 .31488 L
s
.80708 .29612 m
.80924 .30004 L
s
.80307 .32941 m
.80717 .32776 L
s
.24014 .32122 m
.24108 .32404 L
s
.241 .32645 m
.24108 .32404 L
s
.22933 .28956 m
.23605 .29269 L
s
.23989 .32844 m
.241 .32645 L
s
.23904 .32321 m
.24014 .32122 L
s
.80924 .30004 m
.81006 .2948 L
s
.80924 .30004 m
.81001 .32167 L
s
.81006 .2948 m
.81192 .29152 L
s
.23904 .32321 m
.23997 .32603 L
s
.23685 .32719 m
.23989 .32844 L
s
.81023 .2996 m
.81103 .29436 L
s
.81023 .2996 m
.81082 .31643 L
s
.81103 .29436 m
.81192 .29152 L
s
.81417 .27339 m
.82059 .27012 L
s
.81192 .29152 m
.81288 .29107 L
s
.80876 .31488 m
.80984 .31686 L
s
.23192 .32507 m
.23313 .29136 L
s
.80717 .32776 m
.8091 .32451 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23096 .32465 m
.23217 .29091 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23494 .32394 m
.23685 .32719 L
s
.8091 .32451 m
.81001 .32167 L
s
.81001 .32167 m
.81082 .31643 L
s
.81697 .272 m
.81882 .32264 L
s
.23315 .31826 m
.23494 .32394 L
s
0 0 0 r
.82575 .27732 m
.82741 .27645 L
s
.255 .412 .882 r
.81789 .27153 m
.81974 .3222 L
s
.23244 .31059 m
.23315 .31826 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2281 .32335 m
.23192 .32507 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81877 .29558 m
.82041 .28984 L
s
.82041 .28984 m
.82211 .28651 L
s
.816 .32394 m
.81974 .3222 L
s
.82211 .28651 m
.82386 .28557 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22359 .29405 m
.2243 .29934 L
s
.2243 .29934 m
.22494 .30705 L
s
.222 .28829 m
.22359 .29405 L
s
.22449 .31917 m
.22494 .30705 L
s
.81947 .31492 m
.82148 .31889 L
s
.2227 .29359 m
.22341 .29888 L
s
.22341 .29888 m
.22404 .3066 L
s
.22113 .28782 m
.2227 .29359 L
s
.21949 .28446 m
.222 .28829 L
s
.82386 .28557 m
.82568 .28705 L
s
.82386 .28557 m
.82653 .28658 L
s
.22359 .31873 m
.22404 .3066 L
s
.21949 .28446 m
.22113 .28782 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22332 .32603 m
.22449 .31917 L
s
.82148 .31889 m
.82336 .32043 L
s
.22242 .32559 m
.22359 .31873 L
s
.21135 .27966 m
.21949 .28446 L
s
.22224 .33046 m
.22332 .32603 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82653 .28658 m
.8284 .29049 L
s
.82568 .28705 m
.82756 .29096 L
s
.82336 .32043 m
.82513 .31954 L
s
.22135 .33002 m
.22242 .32559 L
s
.82756 .29096 m
.82867 .29778 L
s
.22028 .33447 m
.22224 .33046 L
s
.8284 .29049 m
.8295 .29731 L
s
.82513 .31954 m
.82677 .3162 L
s
.82513 .31954 m
.82763 .31575 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2194 .33403 m
.22135 .33002 L
s
.82867 .29778 m
.82886 .30264 L
s
.82677 .3162 m
.82829 .31041 L
s
.21255 .33292 m
.21451 .2816 L
s
.21757 .33559 m
.22028 .33447 L
s
.82829 .31041 m
.82886 .30264 L
s
.8295 .29731 m
.82969 .30218 L
s
.82763 .31575 m
.82913 .30995 L
s
.21174 .33247 m
.21371 .28112 L
s
.21757 .33559 m
.2194 .33403 L
s
.82913 .30995 m
.82969 .30218 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20936 .3311 m
.21757 .33559 L
s
.83376 .27983 m
.83901 .27638 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83606 .27836 m
.83806 .32989 L
s
.83681 .27787 m
.83882 .32943 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83786 .3048 m
.83953 .30876 L
s
.83574 .33127 m
.83882 .32943 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84757 .2667 m
.84771 .26692 L
s
.84753 .26564 m
.84837 .2664 L
s
.255 .412 .882 r
.84183 .27438 m
.84644 .27081 L
s
.83953 .30876 m
.84179 .30979 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84386 .27286 m
.84494 .29996 L
s
.84451 .27235 m
.8456 .29946 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84179 .30979 m
.84319 .30883 L
s
.84319 .30883 m
.84446 .30539 L
s
.84319 .30883 m
.84513 .3049 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84446 .30539 m
.84494 .29996 L
s
0 0 0 r
.8493 .30957 m
.84941 .30916 L
s
.85054 .28689 m
.85067 .28999 L
s
.255 .412 .882 r
.84513 .3049 m
.8456 .29946 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85064 .29161 m
.85067 .28999 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84888 .26875 m
.85282 .26508 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85119 .26666 m
.85261 .30145 L
s
.85063 .26718 m
.85204 .30195 L
s
.85029 .30344 m
.85261 .30145 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85207 .31743 m
.85255 .31444 L
s
.85207 .31743 m
.85275 .31944 L
s
.85255 .31444 m
.85322 .31645 L
s
.85275 .31944 m
.85322 .31645 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85568 .26989 m
.85642 .26385 L
s
.85549 .2779 m
.85568 .26989 L
s
.85549 .2779 m
.8557 .28289 L
s
.85616 .26936 m
.85689 .26331 L
s
.85599 .27738 m
.85616 .26936 L
s
.8557 .28289 m
.8565 .28988 L
s
.85642 .26385 m
.85768 .25974 L
s
.85599 .27738 m
.85619 .28237 L
s
0 0 0 r
.86212 .24911 m
.86358 .2472 L
s
.255 .412 .882 r
.85619 .28237 m
.85699 .28936 L
s
.85689 .26331 m
.85768 .25974 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8565 .28988 m
.85767 .29386 L
s
.85768 .25974 m
.85854 .25866 L
s
.85699 .28936 m
.85813 .29334 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85854 .25866 m
.85987 .25953 L
s
.85767 .29386 m
.85914 .29483 L
s
.85813 .29334 m
.85914 .29483 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85987 .25953 m
.86085 .26346 L
s
.85914 .29483 m
.86043 .29327 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86043 .29327 m
.86113 .28971 L
s
.86082 .28214 m
.8611 .27909 L
s
.86082 .28214 m
.86131 .28413 L
s
.8611 .27909 m
.86159 .28108 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86395 .27361 m
.86422 .27685 L
s
.86421 .27122 m
.86461 .27597 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86113 .28971 m
.86169 .28361 L
s
.86159 .28108 m
.86169 .28361 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86291 .25208 m
.86342 .25657 L
s
.86291 .25208 m
.86333 .26217 L
s
.86333 .26217 m
.86342 .25657 L
s
.18157 .25582 m
.18197 .25385 L
s
.18179 .25077 m
.18197 .25385 L
s
.86342 .25657 m
.86361 .2535 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86612 .29958 m
.86677 .3073 L
s
.5 Mabswid
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1814 .25274 m
.18179 .25077 L
s
.86361 .2535 m
.86405 .24986 L
s
.1814 .25274 m
.18157 .25582 L
s
.86405 .24986 m
.86504 .24762 L
s
.86398 .27735 m
.86417 .27427 L
s
.86398 .27735 m
.86419 .28242 L
s
.86408 .27988 m
.86428 .27681 L
s
.86417 .27427 m
.86464 .27066 L
s
.86419 .28242 m
.8646 .28442 L
s
.86428 .27681 m
.86475 .27319 L
s
.18003 .29951 m
.18104 .26847 L
s
.17946 .29846 m
.18104 .26847 L
s
.86464 .27066 m
.86568 .26284 L
s
.8646 .28442 m
.86528 .2859 L
s
.86475 .27319 m
.86579 .26539 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17974 .29899 m
.18039 .2837 L
s
.86504 .24762 m
.86558 .24904 L
s
.86528 .2859 m
.86632 .28377 L
s
.17953 .3041 m
.18003 .29951 L
s
.86558 .24904 m
.86589 .25102 L
s
.86568 .26284 m
.86601 .2592 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86579 .26539 m
.86612 .26174 L
s
.17954 .24828 m
.17963 .25138 L
s
.17931 .259 m
.17963 .25138 L
s
.17946 .29846 m
.17953 .3041 L
s
.17929 .24461 m
.17954 .24828 L
s
.86589 .25102 m
.86621 .25864 L
s
.17911 .25845 m
.17941 .25646 L
s
.86601 .2592 m
.8661 .2561 L
s
.179 .26099 m
.17931 .259 L
s
.86612 .26174 m
.86621 .25864 L
s
.86632 .28377 m
.86667 .28014 L
s
0 0 0 r
.17528 .2339 m
.1745 .23041 L
s
.255 .412 .882 r
.17868 .24235 m
.17929 .24461 L
s
.17863 .25989 m
.17911 .25845 L
s
.17852 .26244 m
.179 .26099 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86667 .28014 m
.86677 .27704 L
s
.17834 .27631 m
.17876 .27174 L
s
.17833 .28196 m
.17876 .27174 L
s
.86675 .27139 m
.86677 .27704 L
s
.86677 .27704 m
.86719 .28162 L
s
.86675 .27139 m
.86719 .28162 L
s
.17768 .26223 m
.17863 .25989 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17833 .28196 m
.17834 .27631 L
s
.17757 .26479 m
.17852 .26244 L
s
.17805 .27832 m
.17834 .27631 L
s
.17833 .24376 m
.17868 .24235 L
s
.17759 .2798 m
.17805 .27832 L
s
.8669 .24453 m
.86691 .24141 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86691 .24141 m
.86713 .2434 L
s
.8669 .24453 m
.86713 .24652 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17811 .24575 m
.17833 .24376 L
s
.86713 .2434 m
.86713 .24652 L
s
.17702 .27763 m
.17759 .2798 L
s
0 0 0 r
.17377 .25344 m
.17312 .24832 L
s
.255 .412 .882 r
.17811 .24575 m
.17824 .24007 L
s
.1778 .2503 m
.17811 .24575 L
s
.1778 .2503 m
.17824 .24007 L
s
.17734 .26369 m
.17768 .26223 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17723 .26625 m
.17757 .26479 L
s
.17714 .2657 m
.17734 .26369 L
s
.1769 .27397 m
.17702 .27763 L
s
.17703 .26827 m
.17723 .26625 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86834 .27471 m
.869 .29017 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86768 .25931 m
.86911 .28964 L
s
.86768 .25931 m
.86888 .29071 L
s
0 0 0 r
.1741 .2269 m
.17408 .22337 L
s
.255 .412 .882 r
.17692 .27085 m
.17714 .2657 L
s
.1769 .27397 m
.17692 .27085 L
s
.86888 .29071 m
.86922 .29534 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17089 .306 m
.17498 .23274 L
s
.255 .412 .882 r
.86911 .28964 m
.86922 .29534 L
s
0 0 0 r
.17138 .29486 m
.17404 .22514 L
s
.17528 .19655 m
.17591 .19229 L
s
.17269 .25974 m
.17405 .22455 L
s
.17089 .306 m
.17269 .25974 L
s
.255 .412 .882 r
.17754 .24378 m
.17775 .23749 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17792 .2332 m
.17775 .23749 L
s
0 0 0 r
.17211 .27231 m
.17548 .19472 L
s
.255 .412 .882 r
.17665 .26441 m
.17676 .26182 L
s
.17676 .26182 m
.17686 .25868 L
s
.17641 .26848 m
.17665 .26441 L
s
.17675 .26071 m
.17686 .25868 L
s
0 0 0 r
.1722 .27176 m
.17557 .19411 L
s
.255 .412 .882 r
.17802 .23205 m
.17792 .2332 L
s
.17664 .26385 m
.17675 .26071 L
s
.17804 .23348 m
.17802 .23205 L
s
.17813 .2329 m
.17802 .23205 L
s
.17641 .26848 m
.17633 .26997 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.178 .2375 m
.17804 .23348 L
s
.17633 .26997 m
.17646 .26832 L
s
.17811 .23693 m
.17813 .2329 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17451 .22234 m
.17397 .2309 L
s
.17492 .21746 m
.17451 .22234 L
s
.255 .412 .882 r
.17778 .24472 m
.178 .2375 L
s
.17646 .26832 m
.17671 .26461 L
s
.17646 .26832 m
.17679 .26406 L
s
0 0 0 r
.17522 .21627 m
.17492 .21746 L
s
.255 .412 .882 r
.17789 .24415 m
.17811 .23693 L
s
0 0 0 r
.17191 .27398 m
.1722 .27176 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17755 .24992 m
.17778 .24472 L
s
.17671 .26461 m
.17711 .25829 L
s
0 0 0 r
.1754 .2188 m
.17522 .21627 L
s
.17559 .21821 m
.17522 .21627 L
s
.255 .412 .882 r
.17711 .25829 m
.17755 .24992 L
s
.17767 .24936 m
.17789 .24415 L
s
.17679 .26406 m
.17722 .25773 L
s
0 0 0 r
.17268 .26057 m
.17257 .26691 L
s
.255 .412 .882 r
.17722 .25773 m
.17767 .24936 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17547 .22505 m
.1754 .2188 L
s
.17568 .22446 m
.17559 .21821 L
s
.17257 .26691 m
.17266 .26953 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17519 .23565 m
.17547 .22505 L
s
.17266 .26953 m
.17296 .26842 L
s
.17542 .23507 m
.17568 .22446 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17296 .26842 m
.17346 .26355 L
s
.17296 .26842 m
.17365 .26299 L
s
.17487 .24312 m
.17519 .23565 L
s
.17509 .24255 m
.17542 .23507 L
s
.17417 .25493 m
.17487 .24312 L
s
.17346 .26355 m
.17417 .25493 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17438 .25436 m
.17509 .24255 L
s
.17365 .26299 m
.17438 .25436 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17808 .21919 m
.17906 .21053 L
s
.17728 .23102 m
.17808 .21919 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17906 .21053 m
.18029 .205 L
s
.17696 .23854 m
.17728 .23102 L
s
.1784 .21861 m
.1794 .20993 L
s
.17759 .23045 m
.1784 .21861 L
s
.1794 .20993 m
.18029 .205 L
s
.17727 .23797 m
.17759 .23045 L
s
.17678 .24927 m
.17696 .23854 L
s
.18029 .205 m
.18106 .20382 L
s
.17711 .24871 m
.17727 .23797 L
s
.17678 .24927 m
.17712 .25571 L
s
.18106 .20382 m
.18172 .2064 L
s
.18106 .20382 m
.18214 .20581 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17711 .24871 m
.17746 .25515 L
s
.18172 .2064 m
.18226 .21276 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17712 .25571 m
.17803 .25783 L
s
.18214 .20581 m
.18271 .21218 L
s
.17746 .25515 m
.17803 .25783 L
s
.18223 .22352 m
.18226 .21276 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17803 .25783 m
.1788 .25671 L
s
.18269 .22295 m
.18271 .21218 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1819 .2311 m
.18223 .22352 L
s
.1788 .25671 m
.17978 .25179 L
s
.1788 .25671 m
.18021 .25124 L
s
.255 .412 .882 r
.18551 .24129 m
.18557 .24096 L
s
0 0 0 r
.18237 .23053 m
.18269 .22295 L
s
.18097 .24307 m
.1819 .2311 L
s
.17978 .25179 m
.18097 .24307 L
s
.18612 .19733 m
.19006 .19323 L
s
.18142 .2425 m
.18237 .23053 L
s
.18021 .25124 m
.18142 .2425 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85651 .22788 m
.85725 .24562 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18445 .26765 m
.18445 .26751 L
s
.18591 .23283 m
.18591 .23275 L
s
.18632 .23329 m
.18635 .23238 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18445 .26765 m
.18481 .26723 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85605 .22956 m
.85606 .22904 L
s
.85596 .22657 m
.85608 .22958 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18437 .27592 m
.18774 .19557 L
s
.18494 .27539 m
.1883 .19498 L
s
.19257 .19089 m
.1974 .18684 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18274 .27752 m
.18494 .27539 L
s
.19124 .27009 m
.19457 .18915 L
s
.19194 .26956 m
.19526 .18858 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20569 .1966 m
.20598 .19691 L
s
0 0 0 r
.18923 .27167 m
.19194 .26956 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20153 .19494 m
.20346 .18612 L
s
.20027 .20707 m
.20153 .19494 L
s
.255 .412 .882 r
.20501 .22124 m
.20519 .21682 L
s
0 0 0 r
.20346 .18612 m
.20614 .18057 L
s
.20234 .19438 m
.20429 .18555 L
s
.20107 .20651 m
.20234 .19438 L
s
.19996 .21479 m
.20027 .20707 L
s
.255 .412 .882 r
.2056 .22613 m
.20599 .21639 L
s
0 0 0 r
.20429 .18555 m
.20614 .18057 L
s
.20075 .21424 m
.20107 .20651 L
s
.19996 .21479 m
.20029 .22587 L
s
.20614 .18057 m
.20788 .17944 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20075 .21424 m
.2011 .22532 L
s
.255 .412 .882 r
.2056 .22613 m
.20501 .22124 L
s
.83684 .21378 m
.83705 .21907 L
s
0 0 0 r
.20788 .17944 m
.20951 .18219 L
s
.20788 .17944 m
.21042 .18163 L
s
.255 .412 .882 r
.20582 .2207 m
.20674 .21745 L
s
0 0 0 r
.20029 .22587 m
.20161 .23256 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2011 .22532 m
.20244 .23202 L
s
.20951 .18219 m
.21104 .18882 L
s
.255 .412 .882 r
.83705 .21907 m
.83808 .22491 L
s
0 0 0 r
.21042 .18163 m
.21197 .18827 L
s
.20161 .23256 m
.20398 .23486 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20244 .23202 m
.20398 .23486 L
s
.21104 .18882 m
.21152 .19992 L
s
.21197 .18827 m
.21246 .19938 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20398 .23486 m
.20573 .2338 L
s
.21121 .20771 m
.21152 .19992 L
s
.20573 .2338 m
.20768 .22883 L
s
.20573 .2338 m
.20859 .2283 L
s
.21216 .20718 m
.21246 .19938 L
s
.20982 .21995 m
.21121 .20771 L
s
.21825 .17334 m
.22557 .16954 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20768 .22883 m
.20982 .21995 L
s
.21076 .21942 m
.21216 .20718 L
s
.20859 .2283 m
.21076 .21942 L
s
.21925 .22652 m
.22132 .1717 L
s
.82327 .17893 m
.82417 .17557 L
s
.82298 .17114 m
.82417 .17557 L
s
.2203 .22601 m
.22237 .17116 L
s
.82206 .17449 m
.82298 .17114 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82206 .17449 m
.82327 .17893 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82401 .19847 m
.82684 .24626 L
s
.82401 .19847 m
.82472 .24526 L
s
.21616 .22806 m
.2203 .22601 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23 .16741 m
.23818 .16374 L
s
.22075 .21419 m
.22259 .22104 L
s
.8132 .17024 m
.81449 .17468 L
s
.81449 .17468 m
.81492 .18645 L
s
.81073 .16528 m
.8132 .17024 L
s
.8249 .22204 m
.82579 .24576 L
s
.81377 .18593 m
.81478 .18252 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80594 .1632 m
.81073 .16528 L
s
.81391 .18986 m
.81492 .18645 L
s
.22259 .22104 m
.22573 .22348 L
s
.81158 .18884 m
.81377 .18593 L
s
.82609 .25369 m
.82684 .24626 L
s
.81172 .19278 m
.81391 .18986 L
s
.80362 .1661 m
.80594 .1632 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23187 .2091 m
.23344 .16582 L
s
.23304 .2086 m
.23461 .1653 L
s
.82472 .24526 m
.82609 .25369 L
s
.81478 .21354 m
.81564 .20614 L
s
.81564 .20614 m
.81622 .22196 L
s
.22573 .22348 m
.22798 .22248 L
s
.255 .412 .882 r
.80493 .19615 m
.80518 .19761 L
s
0 0 0 r
.2431 .16168 m
.25211 .15816 L
s
.22798 .22248 m
.23042 .21752 L
s
.22798 .22248 m
.23158 .21702 L
s
.81376 .217 m
.81478 .21354 L
s
.81478 .21354 m
.81622 .22196 L
s
.23042 .21752 m
.23187 .2091 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80518 .19761 m
.80524 .1993 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80584 .19422 m
.81158 .18884 L
s
.80598 .19818 m
.81172 .19278 L
s
.80252 .16953 m
.80362 .1661 L
s
.80098 .16115 m
.80252 .16953 L
s
.80098 .16115 m
.80153 .17691 L
s
.80153 .17691 m
.80252 .16953 L
s
.23158 .21702 m
.23304 .2086 L
s
.81154 .21998 m
.81376 .217 L
s
.24497 .21566 m
.2469 .16016 L
s
.24627 .21519 m
.24819 .15966 L
s
.80349 .19719 m
.80584 .19422 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80363 .20116 m
.80598 .19818 L
s
.78919 .15666 m
.79454 .15864 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80251 .20465 m
.80363 .20116 L
s
.80237 .20067 m
.80349 .19719 L
s
.80668 .21804 m
.81154 .21998 L
s
.79055 .15715 m
.79242 .21283 L
s
.80237 .20067 m
.80264 .20863 L
s
.80405 .21309 m
.80668 .21804 L
s
.78919 .15666 m
.79106 .21237 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80264 .20863 m
.80405 .21309 L
s
.24115 .21709 m
.24627 .21519 L
s
.78659 .15965 m
.78959 .16854 L
s
.78227 .15425 m
.78659 .15965 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77943 .1533 m
.78227 .15425 L
s
.26293 .15823 m
.26733 .15284 L
s
.26126 .16664 m
.26293 .15823 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25982 .21057 m
.26126 .16664 L
s
.26434 .15775 m
.26733 .15284 L
s
.26267 .16617 m
.26434 .15775 L
s
.77668 .15633 m
.77943 .1533 L
s
.77522 .15586 m
.77943 .1533 L
s
.26123 .21012 m
.26267 .16617 L
s
.26733 .15284 m
.27023 .15191 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24285 .24015 m
.24428 .23567 L
s
.24285 .24015 m
.244 .2437 L
s
.24428 .23567 m
.24544 .23923 L
s
.77548 .16382 m
.77668 .15633 L
s
.27023 .15191 m
.27453 .1545 L
s
.77401 .16336 m
.77522 .15586 L
s
.244 .2437 m
.24544 .23923 L
s
.78691 .211 m
.79242 .21283 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77548 .16382 m
.77688 .20788 L
s
.25564 .21193 m
.26123 .21012 L
s
.77401 .16336 m
.7754 .20744 L
s
.27453 .1545 m
.27729 .16157 L
s
.27766 .14961 m
.28378 .14781 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27593 .20574 m
.27766 .14961 L
s
.27745 .20531 m
.27918 .14916 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75367 .14561 m
.76309 .14824 L
s
.77091 .20615 m
.77688 .20788 L
s
.29165 .14563 m
.29302 .15321 L
s
.29118 .16166 m
.29165 .14563 L
s
.27141 .20703 m
.27745 .20531 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29302 .15321 m
.29475 .14878 L
s
.29475 .14878 m
.29811 .14394 L
s
.29118 .16166 m
.29302 .15321 L
s
.29811 .14394 m
.30473 .14229 L
s
.73723 .14146 m
.74721 .14392 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74214 .19883 m
.75842 .14692 L
s
.74382 .19922 m
.75999 .14735 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30473 .14229 m
.30798 .1455 L
s
.74059 .14227 m
.76167 .20362 L
s
.75531 .20198 m
.76479 .20445 L
s
.29221 .18136 m
.29557 .17651 L
s
.29048 .18581 m
.29221 .18136 L
s
.29024 .19389 m
.29048 .18581 L
s
.30798 .1455 m
.30957 .14912 L
s
.29557 .17651 m
.30406 .16643 L
s
.29209 .1854 m
.29545 .18055 L
s
.29036 .18985 m
.29209 .1854 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29545 .18055 m
.30395 .17047 L
s
.29024 .19389 m
.29174 .19754 L
s
.30924 .16121 m
.30957 .14912 L
s
.30406 .16643 m
.30754 .1616 L
s
.29174 .19754 m
.29488 .2008 L
s
.30754 .1616 m
.30935 .15718 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30395 .17047 m
.30744 .16564 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30744 .16564 m
.30924 .16121 L
s
.29488 .2008 m
.3015 .19923 L
s
.32365 .13799 m
.32532 .14165 L
s
.32178 .1424 m
.32365 .13799 L
s
.32178 .1424 m
.32344 .14606 L
s
.72353 .14238 m
.72724 .1512 L
s
.71812 .13724 m
.72353 .14238 L
s
.255 .412 .882 r
.31605 .17722 m
.31757 .17649 L
s
0 0 0 r
.73876 .19807 m
.7488 .20038 L
s
.72724 .1512 m
.7293 .16371 L
s
.72177 .14201 m
.7255 .15083 L
s
.71812 .13724 m
.72177 .14201 L
s
.7255 .15083 m
.72756 .16333 L
s
.71453 .13651 m
.71812 .13724 L
s
.32344 .14606 m
.32532 .14165 L
s
.7293 .16371 m
.72951 .17181 L
s
.30678 .18995 m
.3087 .18145 L
s
.30826 .19771 m
.3087 .18145 L
s
.3015 .19923 m
.30497 .1944 L
s
.71101 .13984 m
.71453 .13651 L
s
.72756 .16333 m
.72777 .17144 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30497 .1944 m
.30678 .18995 L
s
.30678 .18995 m
.30826 .19771 L
s
.72808 .18363 m
.72951 .17181 L
s
.72632 .18327 m
.72777 .17144 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70755 .14724 m
.71101 .13984 L
s
.70919 .13949 m
.71453 .13651 L
s
.70571 .1469 m
.70919 .13949 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72477 .19106 m
.72808 .18363 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72299 .19071 m
.72632 .18327 L
s
.70599 .15908 m
.70755 .14724 L
s
.70414 .15875 m
.70571 .1469 L
s
.68666 .13148 m
.69426 .13275 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32294 .1663 m
.32349 .21495 L
s
.31993 .21564 m
.32294 .1663 L
s
.32171 .2153 m
.32232 .19072 L
s
.70599 .15908 m
.70618 .16722 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70618 .16722 m
.70831 .1798 L
s
.70414 .15875 m
.70433 .16689 L
s
.71952 .1941 m
.72299 .19071 L
s
.71952 .1941 m
.72477 .19106 L
s
.71591 .19341 m
.71952 .1941 L
s
.70433 .16689 m
.70646 .17947 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6829 .13493 m
.68691 .14367 L
s
.67895 .13027 m
.6829 .13493 L
s
.71217 .18865 m
.71591 .19341 L
s
.71034 .18831 m
.71591 .19341 L
s
.67505 .12968 m
.67895 .13027 L
s
.70831 .1798 m
.71217 .18865 L
s
.31993 .21564 m
.3215 .22352 L
s
.70646 .17947 m
.71034 .18831 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67121 .13318 m
.67505 .12968 L
s
.66923 .1329 m
.67505 .12968 L
s
.3215 .22352 m
.32349 .21495 L
s
.6674 .14078 m
.67121 .13318 L
s
.66542 .14051 m
.66923 .1329 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68666 .13148 m
.68844 .21759 L
s
.68857 .13179 m
.69037 .21787 L
s
.64504 .12577 m
.65317 .12673 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68389 .18398 m
.68759 .17635 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66364 .15252 m
.66542 .14051 L
s
.66564 .15278 m
.6674 .14078 L
s
.66564 .15278 m
.66579 .16098 L
s
.66364 .15252 m
.66379 .16072 L
s
.68008 .18754 m
.68389 .18398 L
s
.641 .12939 m
.64523 .13803 L
s
.63476 .12465 m
.641 .12939 L
s
.66579 .16098 m
.668 .17356 L
s
.63061 .12423 m
.63476 .12465 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66379 .16072 m
.66601 .17331 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62649 .12792 m
.63061 .12423 L
s
.6244 .12773 m
.63061 .12423 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67615 .18699 m
.68008 .18754 L
s
.668 .17356 m
.67213 .18233 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62451 .13592 m
.62649 .12792 L
s
.67213 .18233 m
.67615 .18699 L
s
.67014 .18206 m
.67615 .18699 L
s
.66601 .17331 m
.67014 .18206 L
s
.62241 .13573 m
.6244 .12773 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68261 .21676 m
.69037 .21787 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62241 .13573 m
.62298 .18112 L
s
.62451 .13592 m
.62509 .1813 L
s
.64504 .12577 m
.64593 .1833 L
s
.64708 .126 m
.64799 .18353 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60991 .1668 m
.61144 .16034 L
s
0 0 0 r
.60107 .12174 m
.60346 .14655 L
s
.56869 .11996 m
.60321 .1219 L
s
.60321 .1219 m
.60346 .14655 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63973 .18266 m
.64799 .18353 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61662 .1806 m
.62509 .1813 L
s
.255 .412 .882 r
.56725 .17021 m
.56817 .169 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5906 .14985 m
.59088 .18302 L
s
.5777 .16573 m
.59074 .1664 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60194 .20872 m
.60384 .18382 L
s
.60384 .18382 m
.60409 .20886 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56919 .20709 m
.60409 .20886 L
s
.57521 .12024 m
.57579 .20735 L
s
.57738 .12034 m
.57799 .20744 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4Bl0[Jf]2@00000=0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV
4@l0[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00T0ojD@00@000000?nU
40000000ojD@0P2][Jd9000000T0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV
4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00T0ojD@00<000000?nU
400000002P3oYA02000000@0ojD@00<0[Jf]0?nS403oXa000P3oXa040:f][@<000000P2][Jd>0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01/0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40090?nU40030000003oYA00000000X0
ojD@0P0000040?nU40030:f][@3oXa00oj<@00@0oj<@0P0000030?nS408000000P2][Jd5000000<0
[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh0303/UPh30:f][F<0/>3V0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@
0000000:0?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS408000001P3oXa0010000000oj<@
0000000000060?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0
k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA01D0ojHA1`2][JdH0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU40090?nU40030000003oYA00000000X0ojD@0P0000040?nU40030:f]
[@3oXa00oj<@00<0oj<@0P0000060?nS40040000003oXa000000000000X0oj<@00<0[Jf]0?bP4000
00000`0000030:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0
[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0@0?nV4@D0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40090?nU40030000003oYA00000000X0ojD@
0P0000040?nU40030:f][@3oXa00oj<@0080oj<@0P0000080?nS40<000002P3oXa03000000<0o:0@
00<000000?bP403lX1001@00000=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]1`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU40090?nU40030000003oYA00000000X0ojD@0P0000040?nU40030:f][@3o
Xa00oj<@0080oj<@0P0000080?nS40<000002@3oXa02000000H0o:0@00@000000?bP400000000000
0`3lX1050:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA002@3oYA000`000000ojD@0000000;0?nU40030000003oYA00ojD@0080ojD@00<0
[Jf]0?nS403oXa000P3oXa02000000T0oj<@0P0000090?nS408000001P3lX10010000000o:0@0000
000000080?bP40<0[Jf]100000000`3lX100[Jf]0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ400000
102][JdB0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@00T0ojD@00<000000?nU400000002`3oYA000`000000ojD@
0?nU40020?nU40030:f][@3oXa00oj<@0080oj<@0P0000090?nS40800000203oXa02000000030:f]
[@3lX100o:0@00D0o:0@0`0000090?bP40<000000P3lX10200000080[Jf]5@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A0`2][Jd2000001H0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA002@3oYA000`000000ojD@0000000;0?nU40030000003oYA00ojD@0080ojD@00<0
[Jf]0?nS403oXa000P3oXa02000000T0oj<@0P0000080?nS4080000000<0[Jf]0?bP403lX1001@3l
X103000000P0o:0@00<000000?bP40000000103lX1000`000000[Jf]0?JL3`040:f][@030?JL3`00
0000000000h0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`
h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=
0?nT4@800000102][Jd01P3oY140[Jf]0?nV4@000000ojHA000001D0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
2@3oYA000`000000ojD@0000000;0?nU40030000003oYA00ojD@0080ojD@00<0[Jf]0?nS403oXa00
0P3oXa02000000T0oj<@0P0000080?nS4080000000<0[Jf]0?bP403lX1001P3lX102000000P0o:0@
0P0000050?bP408000001@3fW0l30:f][@800000303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00/0oj@A0P0000020:f][@030000003oY140oj@A0080oj@A00@0
[Jf]0?nV4@00000000005P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40090?nU40030000003oYA00000000/0ojD@
00<000000?nU403oYA000P3oYA000`2][Jd0oj<@0?nS40020?nS408000002@3oXa02000000P0oj<@
0P0000000`2][Jd0o:0@0?bP40060?bP408000001`3lX1000`000000o:0@000000050?bP40800000
203fW0l01@000000[Jf]000000000000[Jf]00T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A00@000000:f][@2][Jd0
0000103oY1400`000000oj@A0?nT4@020?nT4@040:f][@3oYQ40ojHA000001H0ojHA00<0[Jf]0?nV
4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA002@3oYA000`000000ojD@0000000;0?nU40030000003oYA00ojD@0080ojD@00<0[Jf]0?nS
403oXa000P3oXa02000000T0oj<@0P0000070?nS4080000000<0oj<@0:f][@3lX1001`3lX1020000
00L0o:0@0P0000070?bP40800000203fW0l01@000000mY`?0?JL3`3fW0l0[Jf]00@00000103fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3P
iP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40040:f][@3oY140oj@A0?nT4@<000000`2][Jd0
0`000000oj@A000000060?nT4@050000003oY140oj@A0?nT4@2][Jd06@3oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
40090?nU40030000003oYA0000000100ojD@00<0[Jf]0?nS403oXa000P3oXa02000000T0oj<@0P00
00070?nS408000000P3oXa000`2][Jd0o:0@0?bP40050?bP408000001`3lX102000000L0o:0@0P00
00080?JL3`030000003fW0l0mY`?00D0mY`?0`0000000`2][Jd0mY`?0:f][@0B0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd00P0000000`2][Jd0oj@A0?nT4@02
0?nT4@8000001`3oY1401@000000oj@A0?nT4@3oY140[Jf]01T0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3o
YA000`000000ojD@000000050?nU40030000003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa000P3o
Xa02000000T0oj<@0P0000070?nS408000000P3oXa000`2][Jd0o:0@0?bP40050?bP408000001`3l
X102000000L0o:0@00<0[Jf]0000000000001`3fW0l00`000000mY`?0?JL3`040?JL3`030000003f
W0l0mY`?0080mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]
C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00d0o:0@
0`000000102][Jd0oj@A0000000000050?nT4@8000001`3oY1401@000000oj@A0?nT4@3oY140[Jf]
01T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@000000050?nU40030000003oYA00ojD@
00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000T0oj<@0P0000070?nS408000000P3oXa000`2]
[Jd0o:0@0?bP40050?bP408000001`3lX102000000L0o:0@00<0[Jf]000000000000203fW0l00`00
0000mY`?0?JL3`030?JL3`030000003fW0l0mY`?00<0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd00`00
0000k9H>0>bF3P0;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>
0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400<
0?bP4080000000<0o:0@0:f][@0000000`0000050?nT4@8000001`3oY1401@000000oj@A0?nT4@3o
Y140[Jf]01T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@000000050?nU40030000003o
YA00ojD@00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000T0oj<@0P0000070?nS408000000P3o
Xa000`2][Jd0o:0@0?bP40050?bP408000001`3lX102000000L0o:0@00<0[Jf]000000000000203f
W0l00`000000mY`?0?JL3`030?JL3`030000003fW0l0mY`?00<0mY`?00H0[Jf]0>bF3P3/UPh0k9H>
0000002][Jd2000000/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80
[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1002@3lX1030:f][@050000003lX100o:0@0:f][@3oY1400`0000050?nT4@80
00001`3oY1401@000000oj@A0?nT4@3oY140[Jf]01T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]103oYA000`000000ojD@000000050?nU40030000003oYA00ojD@
00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000X0oj<@0P0000060?nS408000000P3oXa000`2]
[Jd0o:0@0?bP40050?bP408000001`3lX102000000L0o:0@00<0[Jf]000000000000203fW0l00`00
0000mY`?0?JL3`020?JL3`030000003fW0l0mY`?00@0mY`?00<0[Jf]0>bF3P3/UPh00P0000020>bF
3P030:f][@000000[Jf]008000001`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001@3lX10200000080[Jf]0P3lX10200000080
o:0@00<0[Jf]0?nT4@3oY1400P0000050?nT4@030000003oY140oj@A00D0oj@A0P0000020?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00
[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@102][Jd00`000000
[Jf]000000050:f][@040000002][Jd0[Jf]0:f][@L0ojD@00<0[Jf]0?nS403oXa000P3oXa020000
00X0oj<@0P0000070?nS4080000000<0oj<@0:f][@3lX1001P3lX102000000L0o:0@0P0000070?bP
40040:f][@3fW0l00000000000P0mY`?00D000000?JL3`3fW0l0mY`?000000060?JL3`030:f][@3/
UPh0k9H>008000000`3/UPh00`000000k9H>00000003000000D0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]
0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00<0o:0@0P000002
0:f][@@0o:0@0P0000020?bP40030:f][@3oY140oj@A008000001@3oY1400`000000oj@A0?nT4@05
0?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01D0ojHA302][JdG
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@00000005
0?nU40040000003oYA00ojD@0?nU40`0[Jf]0P00000:0?nS408000001`3oXa02000000030?nS402]
[Jd0o:0@00H0o:0@0P0000070?bP408000001`3lX100102][Jd0mY`?0000000000080?JL3`050000
003fW0l0mY`?0?JL3`0000001P3fW0l0102][Jd0k9H>0000000000050>bF3P<0000000D0k9H>0:f]
[@2][Jd0k9H>000000020>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0
0`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH
403_V1002`3_V100102][Jd0o:0@0?bP403lX104000000D0o:0@0P0000030?bP40030:f][@3oY140
oj@A008000001@3oY1400`000000oj@A0?nT4@040?nT4@030000003oY14000000080oj@A00<0[Jf]
0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002@3oYA000`000000ojD@00000005
0?nU40030000003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000P0[Jf]0P3oXa02
000000L0oj<@0P0000000`3oXa00[Jf]0?bP40060?bP408000001`3lX102000000L0o:0@00@0[Jf]
0?JL3`0000000000203fW0l01@000000mY`?0?JL3`3fW0l0000000H0mY`?00@0[Jf]0>bF3P000000
00001@3/UPh3000000<0k9H>00<0[Jf]0000002][Jd00P00000=0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>73P060=>73P030:f]
[@3_V100kiP@00/0kiP@0`0000000`2][Jd0o:0@0?bP4002000000D0o:0@0P0000030?bP40030:f]
[@3oY140oj@A00800000303oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@020?nV4@X0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA002P3oYA02000000D0ojD@00<000000?nU403oYA00203oYA000`2][Jd0oj<@
0?nS40020?nS40800000203oXa020:f][@8000001P2][Jd01@3oXa0000000000003oXa00[Jf]00L0
o:0@0P0000070?bP408000001`3lX100102][Jd0mY`?0000000000090?JL3`030000003fW0l00000
00L0mY`?00@0[Jf]0>bF3P00000000001@3/UPh3000000@0k9H>0P0000020:f][@8000002`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH
403_V1002@3_V103000000030:f][@3lX100o:0@0080o:0@0P0000050?bP408000000`3lX1000`2]
[Jd0oj@A0?nT4@02000000/0oj@A00<000000?nT4@0000000`3oY1401@2][Jd0ojHA0?nV4@3oYQ40
000001@0ojHA1`2][JdG0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400:0?nU40P000002P3oYA000`2][Jd0oj<@0?nS40020?nS408000002P3oXa02
000000H0oj<@00<0[Jf]0000000000001@2][Jd40?bP408000001`3lX102000000L0o:0@00@0[Jf]
0?JL3`00000000002@3fW0l00`000000mY`?000000070?JL3`040:f][@3/UPh00000000000H0k9H>
0P0000040>bF3P80000000@0k9H>0:f][@2][Jd000002`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1001P3_V10010000000kiP@
0>nH402][Jd2000000D0o:0@0P0000050?bP408000000`3lX1000`2][Jd0oj@A0?nT4@02000000X0
oj@A00<000000?nT4@000000103oY1401@2][Jd0ojHA0?nV4@3oYQ40000000h0ojHA1P2][Jd20?nV
4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@00H0ojD@00@0@FWQ0?nU403oYA00ojD@0P0000050?nU40030000003oYA00
ojD@00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000X0oj<@0P0000080?nS4080000000@0[Jf]
0?bP403lX100o:0@102][Jd2000000L0o:0@0P0000070?bP40040:f][@3fW0l00000000000T0mY`?
00<000000?JL3`0000001`3fW0l0102][Jd0k9H>0000000000060>bF3P800000103/UPh200000006
0>bF3P2][Jd0fhX=0=^:3@000000[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40040>nH
4080000000@0kiP@0:f][@2][Jd0kiP@0P0000050?bP408000001@3lX102000000<0o:0@00<0[Jf]
0?nT4@3oY1400P0000090?nT4@030000003oY140000000D0oj@A00D0[Jf]0?nV4@3oYQ40ojHA0000
00090?nV4@D0[Jf]203oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400:0?nU408000001@3oYA000`000000ojD@0?nU
40080?nU40030:f][@3oXa00oj<@0080oj<@0P00000:0?nS40800000203oXa02000000030:f][@3l
X100o:0@00D0o:0@0P0000070:f][@8000001`3lX100102][Jd0mY`?00000000000:0?JL3`030000
003fW0l0mY`?00H0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2000000@0k9H>0P0000001P3/UPh0
[Jf]0=^:3@3KRPd000000=^:3@80[Jf]00<0fhX=0000003KRPd0103KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h0
0`2][Jd0kiP@0>nH40030>nH40<0000000@0[Jf]0>nH403_V100kiP@0P0000050?bP408000001@3l
X102000000<0o:0@00<0[Jf]0?nT4@3oY1400P0000090?nT4@8000001P3oY1401@2][Jd0ojHA0?nV
4@3oYQ40000000@0ojHA1@2][Jd=0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00X0ojD@0P0000050?nU40030000
003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000X0oj<@0P0000080?nS40800000
00<0[Jf]0?bP403lX1001@3lX102000000L0o:0@0P0000040:f][@<0o:0@00@0[Jf]0?JL3`000000
00002P3fW0l00`000000mY`?0?JL3`060?JL3`040:f][@3/UPh00000000000H0k9H>0P0000040>bF
3P040000003/UPh0k9H>0:f][@80fhX=00@000000=^:3@3KRPd0fhX=0P0000050=^:3@030:f][@2i
M@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP
2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@0P0000040>nH408000001@3lX102000000D0o:0@
0P0000030?bP40030:f][@3oY140oj@A00800000203oY142000000L0oj@A00D0[Jf]0?nV4@3oYQ40
[Jf]000000040:f][A80ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002P3oYA02000000D0ojD@00<000000?nU403o
YA00203oYA000`2][Jd0oj<@0?nS40020?nS408000002P3oXa02000000P0oj<@0P0000000`2][Jd0
o:0@0?bP40050?bP40800000203lX102000000<0o:0@1@2][Jd2000000X0mY`?00<000000?JL3`3f
W0l01P3fW0l0102][Jd0k9H>0000000000060>bF3P800000103/UPh010000000k9H>0>bF3P2][Jd3
0=^:3@030000003KRPd0fhX=0080000000<0[Jf]0=^:3@3KRPd00P3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P3_V1020:f][@800000103_V102000000D0o:0@0P00
00050?bP408000000`3lX100102][Jd0oj@A0?nT4@0000080?nT4@030000003oY140000000H0oj@A
102][Jd00`3oYQ4000000?nV4@0E0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00X0ojD@0P0000050?nU40030000
003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000X0oj<@0P0000090?nS40800000
1`3lX103000000L0o:0@0P0000060?bP40040:f][@3fW0l0000000000080[Jf]1`3fW0l00`000000
mY`?000000070?JL3`040:f][@3/UPh00000000000H0k9H>0P0000040>bF3P040000003/UPh0k9H>
0:f][@<0fhX=00<000000=^:3@3KRPd00P0000000`3KRPd0[Jf]0:f][@020=^:3@030:f][@2iM@/0
^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd0203CQ`h00`2][Jd000000>nH40020:f][@80kiP@0P0000040>nH408000001@3l
X102000000D0o:0@0P0000030?bP40040:f][@3oY1400000000000L0oj@A00<000000?nT4@000000
0`3oY1440:f][@040?nT4@2][Jd0ojHA0?nV4@8000005P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400:0?nU4080
00001@3oYA000`000000ojD@0?nU40080?nU40030:f][@3oXa00oj<@0080oj<@0P00000:0?nS4080
00002@3oXa02000000L0o:0@0`0000070?bP408000001P3lX100102][Jd0mY`?0000000000020?JL
3`@0[Jf]0`3fW0l00`000000mY`?000000070?JL3`040:f][@3/UPh00000000000H0k9H>0P000007
0>bF3P050:f][@3KRPd0fhX=0=^:3@0000000`3KRPd010000000fhX=0=^:3@3KRPd30:f][@T0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2G
H0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h3000000@0kiP@0P0000040>nH408000001@3l
X102000000D0o:0@0P0000030?bP40040:f][@3oY1400000000000L0oj@A0P0000040:f][@80oj@A
00@000000?nT4@3oY140[Jf]0P3oYQ42000001H0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002P3oYA02000000D0
ojD@00<000000?nU403oYA00203oYA000`2][Jd0oj<@00000004000000X0oj<@0P00000:0?nS4080
00001@3lX10010000000o:0@0000000000070?bP408000001P3lX100102][Jd0mY`?000000000006
0?JL3`<0[Jf]00<000000?JL3`0000001`3fW0l0102][Jd0k9H>0000000000060>bF3P8000001`3/
UPh01@2][Jd0fhX=0=^:3@3KRPd0000000T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@080=>73P040000002][Jd00000000000@0kiP@0P0000040>nH408000001@3lX102000000D0
o:0@0P0000030?bP40040:f][@3oY1400000000000H0oj@A00<0[Jf]0000002][Jd01P3oY1401000
0000oj@A0?nT4@2][Jd20?nV4@8000005P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400:0?nU408000001@3oYA00
0`000000ojD@0?nU40080?nU40030:f][@3oXa00oj<@00/0oj<@1@00000:0?nS408000001@3lX100
10000000o:0@0000000000080?bP40030000003lX100o:0@00@0o:0@00@0[Jf]0?JL3`0000000000
203fW0l01P000000mY`?0:f][@2][Jd000000:f][@D0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2
000000L0k9H>00D0[Jf]0=^:3@3KRPd0fhX=000000090=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@080=>73P040000002][Jd00000000000@0kiP@0P0000040>nH408000001@3lX102000000D0o:0@
0P0000030?bP40040:f][@3oY140000000000080oj@A102][Jd2000000L0oj@A00@000000?nT4@3o
Y140[Jf]0P3oYQ42000001H0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002P3oYA02000000`0ojD@00D000000?nU
403oYA00ojD@0:f][@0L0?nS40030:f][@000000000000@0o:0@00@000000?bP400000000000203l
X102000000D0o:0@00<0[Jf]0000000000002@3fW0l01P000000mY`?0?JL3`3fW0l000000?JL3`@0
[Jf]00<0mY`?0:f][@3/UPh00P0000060>bF3P8000001`3/UPh00`2][Jd0fhX=0=^:3@02000000T0
fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V
0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P030000003CQ`h0[Jf]
0080000000@0[Jf]0>nH4000000000000`3_V102000000@0kiP@00<000000?bP403lX100103lX102
000000D0o:0@0P0000030?bP40040:f][@3oY140000000000080[Jf]103oY142000000H0oj@A0P00
00020?nT4@030:f][@3oYQ40ojHA008000005@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400:0?nU40800000303o
YA001@000000ojD@0?nU403oYA00[Jf]01`0oj<@00<0[Jf]0?bP403lX100100000020?bP40800000
2@3lX1000`000000o:0@0?bP40030?bP40030:f][@000000000000T0mY`?00D000000?JL3`3fW0l0
mY`?000000050?JL3`<0[Jf]00<0k9H>0000003/UPh01P3/UPh2000000H0k9H>00<0[Jf]0=^:3@3K
RPd00P0000090=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF
1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>7
3P040000003CQ`h0[Jf]0=>73P80000000@0[Jf]0>nH4000000000000`3_V102000000@0kiP@00<0
00000?bP403lX1000`3lX102000000D0o:0@0P0000030?bP40<0[Jf]0P0000060?nT4@030000003o
Y140oj@A00D0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA008000005@3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400:0?nU40800000303oYA001@000000ojD@0?nU403oYA00[Jf]01`0oj<@00<0[Jf]0?bP403lX100
1P3lX102000000T0o:0@0P0000040?bP408000002P3fW0l00`000000mY`?0?JL3`020?JL3`030000
003fW0l0mY`?00<0mY`?00<0[Jf]0>bF3P2][Jd00P0000060>bF3P8000001P3/UPh0102][Jd0fhX=
00000000000:0=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0
R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]0080
dhL>0P0000001`2][Jd0dhL>000000000000dhL>0:f][@3_V1000P0000030>nH40800000103_V100
0`000000o:0@0?bP40030?bP408000001@3lX102000000<0[Jf]00<0o:0@0:f][@3oY1400P000006
0?nT4@030000003oY140oj@A00D0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA008000005@3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400:0?nU40800000303oYA001@000000ojD@0?nU403oYA00[Jf]01`0oj<@00<0
[Jf]0?bP403lX1001P3lX102000000X0o:0@00<000000?bP403lX1000P3lX102000000T0mY`?00<0
00000?JL3`3fW0l00`3fW0l00`000000mY`?0?JL3`030?JL3`030:f][@3/UPh0k9H>008000000P2]
[Jd40>bF3P8000001P3/UPh0102][Jd000000=^:3@00000:0=^:3@030:f][@2iM@/0^GD;00<0^GD;
00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F02`h>H00`000000[Jf]
09MP2`0209MP2`050:f][@3CQ`h000000=>73P0000000P3CQ`h2000000030=>73P2][Jd0kiP@0080
00000`3_V102000000@0kiP@00<000000?bP403lX1000`3lX102000000D0o:0@0P0000040?bP4004
0:f][@3oY1400000000000H0oj@A00<000000?nT4@3oY140103oY14300000080oj@A00<0[Jf]0?nV
4@3oYQ400P00000E0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00X0ojD@0P00000<0?nU40050000003oYA00ojD@
0?nU402][Jd0703oXa000`2][Jd0o:0@0?bP40060?bP408000002`3lX1000`000000o:0@0?bP4002
000000X0mY`?00<000000?JL3`3fW0l00`3fW0l00`000000mY`?0?JL3`030?JL3`030:f][@3/UPh0
k9H>008000000P3/UPh30:f][@030>bF3P000000000000H0k9H>00<000000=^:3@0000002`3KRPd0
0`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f][D80/>3V0@3oool0
05L0/>3V0P0000001P2][Jd0Uf0;09MP2`2GH0/0[Jf]00000080[Jf]00<000000=>73P3CQ`h00P00
00000`3CQ`h0[Jf]0>nH4002000000<0kiP@0P0000040>nH40030000003lX100o:0@00<0o:0@0P00
00020?bP40<0[Jf]0P0000040?bP40040:f][@3oY1400000000000H0oj@A00<000000?nT4@3oY140
103oY1400`000000oj@A000000020?nT4@030:f][@3oYQ40ojHA008000005@3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][Jd50?nU40800000303oYA001@000000ojD@
0?nU403oYA00[Jf]01`0oj<@00<0[Jf]0?bP403lX1001P3lX102000000`0o:0@0P0000020?bP4003
0:f][@3fW0l0mY`?00L0mY`?00<000000?JL3`3fW0l0103fW0l00`000000mY`?0?JL3`020?JL3`03
0:f][@3/UPh0k9H>008000001@3/UPh00`2][Jd00000000000050>bF3P030000002][Jd0000000`0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H70P2][Je20;3PiP40oooo001G0;3PiP800000
00@0[Jf]09MP2`2GH0/0Uf0;0P0000020=>73P030000003CQ`h0dhL>0080000000<0dhL>0:f][@3_
V1000P0000030>nH40800000103_V1000`000000o:0@0?bP40030?bP408000000P2][Jd30?bP4080
0000103lX100102][Jd0oj@A0000000000060?nT4@030000003oY140oj@A00<0oj@A00@000000?nT
4@3oY14000000P3oY1400`2][Jd0ojHA0?nV4@02000001D0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@00D0ojD@1@2][Jd2000000T0[Jf]0P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP40060?bP40800000403lX1000`2][Jd0mY`?0?JL3`060?JL3`030000003fW0l0
mY`?00D0mY`?00<000000?JL3`3fW0l00P3fW0l00`2][Jd0k9H>0>bF3P02000000H0k9H>0P000002
0:f][@80k9H>00<00000045Yh@0000003@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00E`2`h>H2000000060:f][@2GH0/0Uf0;
09MP2`2][Jd000000P3CQ`h00`000000dhL>0=>73P02000000030=>73P2][Jd0kiP@008000000`3_
V1000`000000kiP@0>nH40030>nH40030000003lX100o:0@0080o:0@00<0[Jf]0000000000001@3l
X102000000@0o:0@00@0[Jf]0?nT4@00000000001`3oY1400`000000oj@A0?nT4@02000000H0oj@A
00<0[Jf]0?nV4@3oYQ400P00000E0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdG0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002P3oYA02000000T0ojD@0P2][Jd2000000P0[Jf]
603oXa000`2][Jd0o:0@0?bP40060?bP40800000403lX1000`2][Jd0mY`?0?JL3`040?JL3`<00000
1`3fW0l00`000000mY`?0?JL3`020?JL3`030:f][@3/UPh0k9H>008000001P3/UPh200000080k9H>
0P2][Jd2000000030:f][@3KRPd0fhX=00D0fhX=00<000000=^:3@3KRPd0103KRPd00`2][Jd0^GD;
0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001G0;3PiP80000000<0
[Jf]09MP2`2GH0/00P2][Jd010000000dhL>0=>73P0000020=>73P030000003CQ`h0[Jf]0080kiP@
0P0000020>nH408000001@3_V1000`000000o:0@0:f][@020:f][@030?bP40000000000000D0o:0@
0P0000040?bP40040:f][@3oY1400000000000P0oj@A0P0000080?nT4@030:f][@3oYQ40ojHA0080
00005@3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002P3oYA02000000/0ojD@0P0000030?nU4003
0:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@00H0o:0@0P00000@0?bP4003
0:f][@3fW0l0mY`?00L0mY`?0`0000050?JL3`050000003fW0l0mY`?0?JL3`2][Jd00P3/UPh20000
00H0k9H>0P0000040>bF3P040000002][Jd0[Jf]0:f][@H0fhX=00<000000=^:3@3KRPd0103KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001G0;3P
iP80000000<0[Jf]09MP2`2GH0/00P2][Jd010000000dhL>0=>73P0000020=>73P030000003CQ`h0
[Jf]0080kiP@0P0000020>nH408000001@3_V1000`000000[Jf]0?bP40030?bP408000001@3lX102
000000@0o:0@00@0[Jf]0?nT4@00000000004P3oY1400`2][Jd0ojHA00000002000001D0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@00X0ojD@0P00000;0?nU408000000`3oYA000`2][Jd0oj<@0?nS
400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP40060?bP40800000403lX1000`2][Jd0mY`?0?JL
3`0<0?JL3`@000000`3fW0l00`2][Jd0k9H>0>bF3P02000000H0k9H>0P0000040>bF3P040000003/
UPh0[Jf]0=^:3@80[Jf]103KRPd00`000000fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00H0^GD;
00<0[Jf]08QF1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001G0;3PiP80000000H0
[Jf]0000002][Jd0Uf0;0:f][@0000020=>73P060000003CQ`h0dhL>0000003CQ`h0[Jf]0P3_V102
00000080kiP@0P0000030>nH4080[Jf]00<000000?bP403lX1000`3lX102000000D0o:0@0P000004
0?bP40040:f][@3oY140000000000180oj@A00<0[Jf]0?nV4@0000000P00000B0?nV4@P0[Jf]603o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002P3o
YA02000000/0ojD@0P0000030?nU40030:f][@3oXa00oj<@01H0oj<@202][Jd50?bP40800000403l
X1000`2][Jd0mY`?0?JL3`0?0?JL3`<0000000@0mY`?0:f][@3/UPh0k9H>0P0000060>bF3P800000
103/UPh00`000000k9H>0:f][@030=^:3@80[Jf]0P3KRPd00`000000fhX=0=^:3@040=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40
oooo001G0;3PiP80000000H0[Jf]000000000000Uf0;0:f][@0000020=>73P060000003CQ`h0dhL>
0000003CQ`h0[Jf]0P3_V10200000080kiP@0P0000000`3_V100[Jf]0:f][@020>nH40030000003l
X100o:0@00<0o:0@0P0000050?bP408000000`3lX1000`2][Jd000000000000D0?nT4@030:f][@3o
YQ40000000800000303oYQ460:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001P3oYA09000000P0ojD@0P00
00030?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1@2][Jd200000100o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l4000000H0k9H>0P0000040>bF3P030000003/UPh0[Jf]00<0fhX=
00D000000=^:3@2][Jd0[Jf]000000060=^:3@030:f][@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28
EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005L0/>3V0`0000001@2][Jd0000009MP2`2][Jd0
00000080dhL>00H000000=>73P3CQ`h000000=>73P2][Jd20>nH408000000P3_V102000000030:f]
[@3_V100kiP@0080kiP@00<000000?bP403lX1000`3lX102000000D0o:0@0P0000030?bP40030:f]
[@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@0000000P0000050?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400?0?nU40X000000`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00H0o:0@
0P0000060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0102][Jd0k9H>0000000000060>bF3P80
0000103/UPh00`000000k9H>0:f][@030=^:3@060000003KRPd0fhX=0=^:3@000000[Jf]1@3KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H708QF1`2][Jd0R5H70:f][@120;3PiP40oooo
001G0;3PiP<0000000H0[Jf]0000002GH0/0[Jf]0000003CQ`h200000080dhL>00<000000=>73P2]
[Jd00P3_V102000000040>nH402][Jd00000000000D0kiP@00<000000?bP403lX1000`3lX1020000
00D0o:0@0P0000030?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@0000000P0000050:f]
[A00ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
00H0o:0@0P0000060?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00D0k9H>100000040>bF3P030000003/UPh0[Jf]00<0fhX=00H000000=^:3@3KRPd0fhX=0000003K
RPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`
h>H10?ooo`00E`2`h>H30000000609MP2`000000Uf0;0:f][@000000dhL>0P0000020=>73P030000
003CQ`h0[Jf]0080kiP@00@000000:f][@2][Jd0kiP@0P0000040>nH40030000002][Jd0o:0@00@0
o:0@0P0000030?bP408000001@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@<0[Jf]0`00000E0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40060?bP4080
00003@3lX1060:f][A@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh2000000@0k9H>00<000000>bF3P2]
[Jd00`3KRPd010000000fhX=0=^:3@3KRPd200000080fhX=0P2][Jd00`3KRPd0@FWQ0;Ue2`070;Ue
2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00E`2`h>H01`000000
[Jf]0000002GH0/0000009MP2`0000000P3CQ`h200000080dhL>00H000000=>73P2][Jd0kiP@0:f]
[@0000030>nH40800000103_V1000`000000[Jf]0?bP40040?bP408000002P3lX1000`2][Jd0oj@A
0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ400`00000E0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40060?bP40800000403lX1000`2][Jd0mY`?
0?JL3`040:f][A00mY`?00<0[Jf]0>bF3P3/UPh03P3/UPh010000000[Jf]0=^:3@3KRPd2000000<0
fhX=0P0000040=^:3@80[Jf]2@2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00
E`2`h>H01`000000[Jf]0000002GH0/0000009MP2`0000000P3CQ`h200000080dhL>00H000000=>7
3P2][Jd0[Jf]0>nH400000030>nH40800000103_V1000`000000[Jf]0?bP40020?bP40800000303l
X1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1401@2][Jd0ojHA0000003oYQ40000001D0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00<0o:0@
0P0000000`3lX10000000000000@0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd;0?JL3`030:f]
[@3/UPh0k9H>00h0k9H>00@000000:f][@3KRPd0fhX=0P0000030=^:3@8000001@3KRPd20:f][@P0
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V0`000000102GH0/00000
09MP2`0000020=>73P8000000P3CQ`h00`000000[Jf]0:f][@020>nH40040000003_V100kiP@0>nH
40<000000`3_V1000`000000[Jf]0?bP400@0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT
4@040:f][@3oYQ400000000001H0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@00D0o:0@0`00000@0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd6
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00D000000=^:3@000000fhX=000000030=^:3@8000001@3K
RPd0102][Jd0^GD;0:f][@2][Jd60;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo
001G0;3PiP<0000000@0Uf0;0000002GH0/000000P3CQ`h200000080dhL>00<000000=>73P2][Jd0
0P3_V10010000000kiP@0>nH403_V10300000080kiP@00<000000>nH402][Jd04@3lX1000`2][Jd0
oj@A0?nT4@030?nT4@@0[Jf]3@3oY140102][Jd0ojHA0?nV4@00000F0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00h0mY`?102][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>0P0000000`3KRPd000000=^:3@020=^:
3@8000001@3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL2
0:f][D40/>3V0@3oool005L0/>3V0`000000102GH0/0000009MP2`0000020=>73P80000000H0dhL>
0:f][@000000dhL>0:f][@3_V102000000<0kiP@0P0000001P3_V1000000000000000000kiP@0:f]
[A40o:0@00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@040:f][@3oYQ40ojHA000001H0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l04P3fW0l40:f][A40k9H>00@0[Jf]0=^:3@3KRPd00000103KRPd00`000000fhX=0=^:
3@030=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF
1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;00000080dhL>0P00
00001`2][Jd0dhL>0000003CQ`h0[Jf]0>nH40000000103_V102000000D0kiP@00<0[Jf]0?bP403l
X1003P3lX1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@050=^:3@030000003KRPd0fhX=00<0
fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je10;3P
iP40oooo001G0;3PiP<0000000@0Uf0;0000002GH0/000000P3CQ`h200000080dhL>00<000000=>7
3P2][Jd00P0000040>nH408000001@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f]
[@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd00`000000fhX=0=^:3@030=^:
3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80[Jf]@@2`h>H10?oo
o`00E`2`h>H30000000709MP2`000000Uf0;0000003CQ`h0[Jf]000000030=>73P030000003CQ`h0
[Jf]008000000`3_V102000000H0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0o:0@00<0[Jf]
0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd00`000000fhX=0=^:3@03
0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000
000709MP2`000000Uf0;0000002][Jd0dhL>000000030=>73P80000000<0[Jf]0000003_V1002`3_
V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/
UPh00`2][Jd0fhX=0=^:3@050=^:3@030000003KRPd0fhX=00<0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000409MP2`000000
Uf0;00000080dhL>00@000000=>73P3CQ`h0dhL>0P0000000`2][Jd000000>nH400;0>nH40030:f]
[@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00D0fhX=00<000000=^:3@3KRPd0
0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL20:f][D40/>3V0@3oool005H0/>3V0`00
000209MP2`030000002][Jd000000080dhL>00<000000=>73P3CQ`h00P3CQ`h2000000d0kiP@00@0
[Jf]0?bP403lX100o:0@0P2][Jd00`000000o:0@0?bP40090?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA
402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0
1P3KRPd00`000000fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd308QF1`80[Jf]
@@2`h>H10?ooo`00EP2`h>H30000000509MP2`000000Uf0;0:f][@0000000P3CQ`h00`000000dhL>
0=>73P020=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP402][Jd0[Jf]0P3lX1000`000000
o:0@0?bP40090?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd60=^:3@8000001@3KRPd00`2][Jd0
^GD;0;Ue2`060;Ue2`030:f][@28EPL0[Jf]0080R5H70P2][Je10;3PiP40oooo001F0;3PiP<00000
00D0Uf0;0000002][Jd0Uf0;000000020=>73P030000003CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_
V1002`3_V1030:f][@<0o:0@0P00000;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2]
[Jd0[Jf]103KRPd2000000D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF
1`80[Jf]@@2`h>H10?ooo`00EP2`h>H30000000509MP2`000000Uf0;045Yh@0000000P3CQ`h00`00
0000dhL>0=>73P020=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP40030?bP
408000002`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV
4@3oYQ400P3oYQ4:0:f][H40/>3V2P2][JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@80fhX=0P0000050=^:3@030:f][@2iM@/0
^GD;00H0^GD;00D0[Jf]08QF1`28EPL0[Jf]08QF1`020:f][D40/>3V0@3oool005H0/>3V0`000000
1@2GH0/0000009MP2`2GH0/000000080dhL>00<000000=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH
40070>nH4080[Jf]0`3_V1000`2][Jd0o:0@0?bP40030?bP40030000003lX100o:0@00T0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0
[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2]
[Jd2000000D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL30:f][D40/>3V
0@3oool005H0/>3V0`0000001@2][Jd0000009MP2`2GH0/000000080dhL>00<000000=>73P3CQ`h0
0P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f]
[@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@800000
1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H708QF1`<0[Jf]@@2`h>H10?ooo`00
EP2`h>H3000000050:f][@000000Uf0;09MP2`0000000P3CQ`h00`000000dhL>0=>73P020=>73P03
0:f][@3_V100kiP@00<0kiP@0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3f
W0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P0000020:f][@<0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00
EP2`h>H30000000509MP2`000000Uf0;09MP2`0000000P3CQ`h00`000000dhL>0=>73P020=>73P04
0:f][@3_V100kiP@0>nH4080[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd200000080fhX=0P2][Jd0
0`3KRPd0[Jf]0;Ue2`080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H3
0000000609MP2`000000Uf0;0:f][@000000dhL>0P0000040=>73P040:f][@3_V100[Jf]0:f][@/0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@030000003KRPd0fhX=00<0
fhX=0P2][Jd90;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H300000006
09MP2`000000Uf0;0:f][@000000dhL>0P0000040=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00D0fhX=00<000000=^:3@3KRPd0103KRPd30:f][@L0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP@000000P2GH0/00`000000dhL>0=>73P02
000000<0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY144
0:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0
102][Jd0^GD;0;Ue2`2][Jd60;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`
h>H2000000050:f][@000000Uf0;09MP2`0000000P3CQ`h2000000050=>73P2][Jd0[Jf]0=>73P2]
[Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0
[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2i
M@/0^GD;0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H20000
00050:f][@2GH0/0Uf0;09MP2`0000000P3CQ`h2000000050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_
V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2]
[Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000050:f][@2G
H0/0Uf0;09MP2`0000000P3CQ`h2000000@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`040;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H70P2][Je10;3PiP40oooo001F0;3PiP800000
00L0[Jf]09MP2`2GH0/0Uf0;0000003CQ`h0[Jf]00800000103CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00D0^GD;0`2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H200000007
0:f][@2GH0/0Uf0;09MP2`000000[Jf]0=>73P02000000@0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2]
[Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/0
0`000000dhL>0=>73P02000000@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP4007
0?bP40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool0
05H0/>3V00<000000:f][@2GH0/00P2GH0/0102][Jd000000=>73P3CQ`h2000000@0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH3
0:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00L0^GD;0P2][Jd308QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00<000000:f]
[@2GH0/00P2GH0/00`2][Jd000000=>73P02000000D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f]
[@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd0/>3V0;3PiP0o0;3P
iP40oooo001F0;3PiP070000002][Jd0Uf0;09MP2`2][Jd0Uf0;000000080=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]
0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL0
0`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<00000
0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]
08QF1`28EPL0[Jf]08QF1`2][Je10;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;0:f][@2GH0/0
00000:f][@080=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0
R5H708QF1`28EPL20:f][D40/>3V0@3oool005D0/>3V0P0000020:f][@<0Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00L0_[Vh00@0@FWQ0:f][@2][Jd0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00E@2`h>H200000080[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid2
0:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H5
0:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00D0_[Vh0P2][Jd01011JN40_[Vh0;ji^02n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H2000000030:f][@2GH0/0
Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@80@FWQ0P2T
WXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0
_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@80_[Vh00H0
@FWQ0;ji^02n^KP0_[Vh0:f][@2d/;420:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
R5H708QF1`0208QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2]
[Jd02@3CQ`h01@2][Jd0kiP@0:f][@2][Jd0Y9j?0080@FWQ00@0Y9j?045Yh@2TWXl0[Jf]1P2aZid2
0:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd40;ji^005045Yh@2n^KP0_[Vh045Yh@2][Jd0
0`2d/;420:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40
oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@<0Y9j?
0P11JN420:BNS`03045Yh@2][Jd0/J^M00L0/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@H0
_[Vh00@0@FWQ0;ji^011JN40_[Vh0P11JN430;B`/@03045Yh@2][Jd0[Jf]00X0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>7
3P3CQ`h01P3CQ`h00`2][Jd0Y9j?0:BNS`030:BNS`80@FWQ0P2TWXl2045Yh@80/J^M00<0@FWQ0;6[
W@2aZid01@2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd80;ji^080@FWQ0P2n^KP2045Y
h@<0];2a0P11JN400`2d/;40[Jf]0:f][@080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H1
0?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd60:BN
S`80@FWQ0`2TWXl01011JN40/J^M0;6[W@2aZid2045Yh@L0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2]
[Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01@2n^KP2045Yh@030;ji^011JN40@FWQ0080_[Vh00<0
[Jf]045Yh@2d/;400P2d/;42045Yh@<0];2a00<0[Jf]0;Ue2`2iM@/01@2iM@/0102][Jd0R5H708QF
1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>7
3P030=>73P<0[Jf]1P2TWXl2045Yh@80Y9j?00<0[Jf]045Yh@2aZid00`2aZid3045Yh@H0/J^M00<0
[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n
^KP0_[Vh00<0_[Vh0P11JN420;ji^080@FWQ0`2n^KP01011JN40];2a0;B`/@2d/;42045Yh@<0];2a
00<0@FWQ0:f][@2][Jd01@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V
00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P020=>73P040:f][@2:QGD0RXEe0:f][@H0
Y9j?0P11JN420:BNS`030:f][@11JN40/J^M00<0/J^M00<0@FWQ0;6[W@2aZid01P2aZid00`2][Jd0
^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0
_[Vh045Yh@05045Yh@80_[Vh0P11JN430;ji^0040:f][@11JN40];2a0;B`/@80@FWQ0`2d/;400`11
JN40[Jf]0:f][@020:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3P
iP030000002`h>H0[Jf]00<0Uf0;00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0308Z5M@<0[Jf]102TWXl2
045Yh@80Y9j?00<0[Jf]045Yh@11JN400`2aZid00`11JN40/J^M0;6[W@060;6[W@030:f][@2i/ZH0
^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]045Yh@2n^KP00P2n^KP2045Yh@<0_[Vh0P11JN43
0;ji^0040:f][@11JN40];2a0;B`/@80@FWQ0P2d/;40102][Jd0@FWQ0;B`/@2][Jd2045Yh@040:f]
[@2iM@/0^GD;0:f][@<0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;
00@0[Jf]0=>73P2][Jd0[Jf]102:QGD0102][Jd0Y9j?0:BNS`2][Jd30:BNS`80@FWQ0P2TWXl00`2]
[Jd0@FWQ045Yh@030;6[W@03045Yh@2aZid0/J^M00H0/J^M00<0[Jf]045Yh@2i/ZH02@2i/ZH40:f]
[@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@h0`kfk00<0[Jf]045Y
h@2n^KP00`2n^KP00`11JN40_[Vh0;ji^0020;ji^006045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ0P2d
/;42045Yh@80[Jf]00@0];2a045Yh@2d/;40[Jf]0P11JN40102OVj00[Jf]0:f][@2][Jd408QF1`03
0:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00`2GH0/20:f][@H0RXEe
00@0[Jf]0:BNS`2TWXl0Y9j?0P2][Jd00`2TWXl0@FWQ045Yh@020:BNS`030:f][@11JN40@FWQ00<0
/J^M00<0@FWQ0;6[W@2aZid01P2aZid01011JN40^K:V045Yh@11JN4<0;VbYP<0[Jf]4@2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f]
[@33_K/03P33_K/00`2][Jd0@FWQ0;ji^0030;ji^003045Yh@2n^KP0_[Vh0080_[Vh00H0@FWQ0;ji
^02n^KP0_[Vh0:f][@11JN420;B`/@80@FWQ0`2d/;400`11JN40];2a0:f][@02045Yh@<0Wi^P00<0
[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001E0;3PiP030000002][Jd0
Uf0;00<0Uf0;00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`030:f][@11JN40
@FWQ0080Y9j?00<0[Jf]045Yh@11JN400`2aZid00`11JN40/J^M0;6[W@050;6[W@80@FWQ0P2i/ZH0
1@11JN40^K:V0;VbYP2i/ZH0@FWQ00T0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36
`;`0a/2l00L0a/2l102][Jd50<K0_0030:f][@33_K/0`kfk00@0`kfk0`11JN460<>m^`80@FWQ102n
^KP00`11JN40_[Vh0;ji^0020;ji^008045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ0;B`/@2][Jd2045Y
h@80];2a0P11JN400`2d/;40@FWQ045Yh@0509nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H1
0?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`040:BN
S`80@FWQ0P2TWXl00`2][Jd0/J^M045Yh@030;6[W@03045Yh@2aZid0/J^M00D0/J^M0P11JN430;Vb
YP05045Yh@2i/ZH0@FWQ0;VbYP11JN40202i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`0
0`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`0
0`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`020<>m^`<0@FWQ2033_K/2
045Yh@@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP01`11JN40_[Vh0;ji^02n^KP0[Jf]045Yh@2][Jd0
0P2d/;42045Yh@050;B`/@11JN40@FWQ0;B`/@2][Jd01P2OVj001@2][Jd0R5H708QF1`28EPL0[Jf]
0400/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd708Z5M@030:f][@2TWXl0Y9j?
00@0Y9j?00<0@FWQ0:BNS`2][Jd00P2][Jd00`2aZid0@FWQ0;6[W@020;6[W@03045Yh@2aZid0/J^M
00D0/J^M0P11JN430;VbYP<0@FWQ1P2i/ZH01@11JN40^K:V0;VbYP2i/ZH0[Jf]00T0_[N/102][Jd5
0;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A
0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0@FWQ0<>m^`040<>m^`03045Yh@33_K/0
`kfk00H0`kfk0P11JN440;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0P11
JN430;B`/@80@FWQ00D0];2a045Yh@2d/;40];2a0:f][@0709nKX0040:f][@28EPL0R5H70:f][D00
/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd708Z5M@030:f][@2TWXl0Y9j?00@0Y9j?
00@0@FWQ0:BNS`2TWXl0Y9j?0P2][Jd00`11JN40/J^M0;6[W@02045Yh@L0/J^M0P11JN440;VbYP80
@FWQ1P2i/ZH01@11JN40^K:V0;VbYP2i/ZH0[Jf]00d0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][@l0a/2l00@0@FWQ0<K0
_02][Jd0@FWQ1@33_K/00`11JN40`kfk0<>m^`060<>m^`80@FWQ102n^KP2045Yh@<0_[Vh00@0@FWQ
0:f][@2][Jd0_[Vh0P11JN430;B`/@@0@FWQ0P2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]00<0
R5H70:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0
[Jf]0:BNS`2TWXl01@2TWXl02@11JN40Y9j?0:BNS`2TWXl0[Jf]0;6[W@11JN40[Jf]0;6[W@02045Y
h@L0/J^M0P11JN440;VbYP80@FWQ1P2i/ZH01P11JN40^K:V0;VbYP2i/ZH0[Jf]045YhA00_[N/102]
[JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo
]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0
[Jf]0<K0_036`;`03036`;`2045Yh@040<K0_011JN40@FWQ045Yh@D0`kfk00<0@FWQ0<>m^`33_K/0
1P33_K/2045Yh@@0_[Vh0P11JN420;ji^0030:f][@11JN40_[Vh0080_[Vh0P11JN430;B`/@80@FWQ
102d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V
0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl01@11JN40Y9j?
0:BNS`2TWXl0[Jf]0080@FWQ00@0/J^M0:f][@11JN40@FWQ202aZid00`11JN40^K:V0;VbYP020;Vb
YP80@FWQ1@2i/ZH2045Yh@<0^K:V00<0[Jf]045Yh@2n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f]
[@`0`KZ`00<0[Jf]0<>m/`33_K<02033_K<3045Yh@P0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f]
[@L0al6l00<0[Jf]0<K0_036`;`02`36`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ1@33_K/00`11
JN40`kfk0<>m^`070<>m^`80@FWQ0`2n^KP2045Yh@80[Jf]00<0_[Vh045Yh@2n^KP00P2n^KP00`11
JN40];2a0;B`/@020;B`/@80@FWQ102d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00<0L6ii0:f]
[@2][Jd0@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f][@2TWXl0Y9j?00D0
Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?0:f][@02045Yh@80/J^M0P11JN420:f][@H0/J^M00<0@FWQ0;Vb
YP2i/ZH00P2i/ZH2045Yh@D0^K:V0P11JN430;VbYP030:f][@11JN40_[N/0100_[N/00<0[Jf]0<6j
/031^[001@31^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<02P33_K<4045Yh@D0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00X0a/2l0P11JN440<K0_0030:f][@11JN40`kfk
00@0`kfk00<0@FWQ0<>m^`33_K/01`33_K/00`2][Jd0@FWQ045Yh@04045Yh@<0_[Vh00D0@FWQ0;ji
^02n^KP0_[Vh045Yh@040;B`/@80@FWQ102d/;400`2][Jd0@FWQ09nKX00309nKX0030:f][@2OVj00
[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5
M@2][Jd0102:QGD00`2][Jd0Y9j?0:BNS`050:BNS`05045Yh@2TWXl0Y9j?0:BNS`2][Jd00P11JN42
0;6[W@80@FWQ0P2aZid30:f][@<0/J^M00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045Yh@D0^K:V0`11JN40
102i/ZH0[Jf]045Yh@11JN490;jg[0@0@FWQ102n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31
^[000`2][Jd0`kfc0<>m/`0:0<>m/`80@FWQ1`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00D0[Jf]0<K0_036`;`0a/2l
045Yh@080<K0_003045Yh@36`;`0a/2l00<0a/2l00<0[Jf]045Yh@33_K/01033_K/00`11JN40`kfk
0<>m^`070<>m^`050:f][@2n^KP0[Jf]0:f][@2n^KP00P11JN430;ji^005045Yh@2n^KP0_[Vh045Y
h@2][Jd0102d/;42045Yh@@0];2a00<0[Jf]045Yh@11JN400P2OVj00102][Jd0Wi^P09nKX02][Jd2
071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe
0:f][@<0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl01@11JN40Y9j?0:BNS`2TWXl0[Jf]0080@FWQ0P2a
Zid2045Yh@D0/J^M0P2][Jd00`2aZid0[Jf]045Yh@030;VbYP80@FWQ1@2i/ZH3045Yh@040;VbYP2]
[Jd0@FWQ045Yh@P0_[N/0`11JN420;jg[005045Yh@2n]j`0@FWQ045Yh@2][Jd04@31^[080:f][@L0
`kfc0P11JN470<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00?0<O1_003045Yh@37`K`0[Jf]00<0
a/2l00<0@FWQ0<K0_036`;`01@36`;`2045Yh@D0a/2l00<0[Jf]045Yh@11JN401033_K/00`11JN40
`kfk0<>m^`060<>m^`<0[Jf]0`2n^KP00`11JN40_[Vh0;ji^0020;ji^080@FWQ00<0_[Vh045Yh@2]
[Jd0102d/;42045Yh@@0];2a00<0[Jf]09nKX011JN400P2][Jd309nKX0030:f][@1`KWT0L6ii0080
[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe08Z5M@2]
[Jd00P2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`05045Yh@2TWXl0Y9j?0:BNS`2][Jd00P11JN420;6[
W@<0@FWQ0P2aZid01011JN40/J^M0;6[W@2aZid30:f][@80@FWQ00<0^K:V045Yh@11JN401@2i/ZH0
1@11JN40^K:V045Yh@2i/ZH0[Jf]00<0@FWQ1P2n]j`2045Yh@D0_[N/0`11JN400`2][Jd0`KZ`0<6j
/004045Yh@d0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<70:f][@80@FWQ0P2][Jd50<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k
00<0[Jf]0<O1_037`K`02037`K`2045Yh@D0al6l00<0@FWQ0<O1_02][Jd00`36`;`00`11JN40a/2l
0<K0_0050<K0_003045Yh@36`;`0a/2l00@0a/2l00<0[Jf]045Yh@11JN401033_K/2045Yh@@0`kfk
0`2][Jd00`33_K/0[Jf]0;ji^0030;ji^003045Yh@2n^KP0_[Vh0080_[Vh00D0@FWQ0;ji^011JN40
_[Vh0:f][@040;B`/@80@FWQ102d/;400`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080
[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe
00<0[Jf]08Z5M@2][Jd01`2TWXl01P11JN40Y9j?0:BNS`2TWXl0[Jf]045Yh@80/J^M1011JN400`2a
Zid0@FWQ045Yh@040;6[W@040:f][@2i/ZH0[Jf]0:f][@<0@FWQ102i/ZH2045Yh@040;VbYP11JN40
^K:V0:f][@<0@FWQ1P2n]j`2045Yh@D0_[N/0`11JN400`2][Jd0`KZ`0<6j/0020<6j/0@0@FWQ2`31
^[000`2][Jd0`kfc0<>m/`0:0<>m/`80@FWQ0P33_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38
`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`00`37`K`01011JN40al6l0<O1_037`K`2045Yh@H0al6l
00<0@FWQ0<O1_02][Jd00P36`;`3045Yh@H0a/2l00<0@FWQ0<K0_036`;`01036`;`00`2][Jd0@FWQ
045Yh@040<>m^`80@FWQ00@0`kfk0:f][@2][Jd0[Jf]1033_K/2045Yh@<0_[Vh00<0@FWQ0;ji^02n
^KP00`11JN430;ji^0030:f][@2d/;40];2a0080];2a0P11JN440;B`/@80[Jf]1P2OVj000`2][Jd0
L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe
08Z5M@0308Z5M@80[Jf]1`2TWXl01P11JN40Y9j?0:BNS`2TWXl0[Jf]045Yh@<0/J^M0`11JN420;6[
W@04045Yh@2aZid0/J^M0;6[W@80@FWQ0`2i/ZH3045Yh@040:f][@2i/ZH0^K:V0;VbYP80@FWQ00L0
^K:V045Yh@2i/ZH0[Jf]045Yh@2n]j`0@FWQ00D0_[N/0P11JN470;jg[080@FWQ00<0[Jf]0<6j/031
^[000P31^[02045Yh@d0`KZ`00<0[Jf]0<>m/`33_K<02P33_K<2045Yh@L0`kfc00<0[Jf]0<Fn]@35
_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/0102][Jd0al6l0<O1_037`K`2045Yh@040<O1_011JN40@FWQ0<O1_080@FWQ1P37`K`2
045Yh@030:f][@36`;`0a/2l00<0@FWQ1P36`;`00`11JN40a/2l0<K0_0040<K0_0030:f][@11JN40
@FWQ0080@FWQ0P33_K/2045Yh@030:f][@33_K/0`kfk00D0`kfk0P11JN430;ji^003045Yh@2n^KP0
_[Vh00H0_[Vh00<0[Jf]0;B`/@2d/;400P2d/;42045Yh@@0];2a00<0[Jf]09nKX02OVj001@2OVj00
1@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0
0`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00D0Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?0P11
JN460;6[W@03045Yh@2aZid0@FWQ00<0/J^M0P11JN440;VbYP80@FWQ00@0^K:V0:f][@2][Jd0[Jf]
0P11JN400`2i/ZH0@FWQ0;VbYP02045Yh@030;jg[011JN40_[N/00@0_[N/0P11JN470;jg[080@FWQ
1@31^[02045Yh@d0`KZ`1011JN490<>m/`80@FWQ1`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]
3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_011JN40@FWQ1037`K`3045Yh@L0al6l0P11JN400`2][Jd0
a/2l0<K0_003045Yh@H0a/2l00<0@FWQ0<K0_036`;`00`36`;`4045Yh@80`kfk0P2][Jd2045Yh@<0
`kfk00<0@FWQ0<>m^`33_K/00P33_K/01@2][Jd0@FWQ0;ji^02n^KP0@FWQ00T0_[Vh00<0[Jf]0;B`
/@2d/;400P2d/;42045Yh@80];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H1
0?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd50:BNS`04045Yh@2TWXl0
Y9j?0:BNS`80@FWQ1`2aZid2045Yh@@0/J^M00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;Vb
YP030;VbYP80@FWQ00<0[Jf]045Yh@2i/ZH00P11JN400`2n]j`0@FWQ0;jg[0040;jg[080@FWQ1`2n
]j`2045Yh@D0`KZ`0P11JN4;0<6j/0<0@FWQ0P33_K<00`11JN40`kfc0<>m/`020<>m/`80@FWQ0`33
_K<2045Yh@L0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00D0b<6k1`11JN470<S1^`040:f][@37
`K`0@FWQ045Yh@D0al6l0P11JN460<O1_0<0@FWQ00<0[Jf]0<K0_036`;`00`11JN450<K0_080@FWQ
1P36`;`00`2][Jd0`kfk0:f][@020:f][@80`kfk0P11JN430<>m^`80@FWQ0`33_K/0102][Jd0_[Vh
045Yh@11JN4:0;ji^0030:f][@2d/;40];2a0080];2a0P11JN401@2d/;40[Jf]0;B`/@2d/;40[Jf]
00L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@040:BNS`11JN40Y9j?045Yh@80Y9j?00<0
@FWQ0:f][@11JN403@2aZid00`11JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V00<0^K:V0P11
JN400`2i/ZH0@FWQ0:f][@02045Yh@030;jg[011JN40_[N/00@0_[N/00<0@FWQ0;jg[02n]j`01P2n
]j`2045Yh@D0`KZ`0P11JN4;0<6j/003045Yh@31^[00[Jf]00<0`kfc00@0@FWQ0<>m/`33_K<0@FWQ
1@33_K<2045Yh@80`kfc0P11JN430<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
4@38`K/4045Yh@T0b<6k0P11JN4:0<S1^`030:f][@11JN40@FWQ00H0al6l0P11JN460<O1_0<0@FWQ
00H0[Jf]0<K0_036`;`0@FWQ0<K0_011JN450<K0_080@FWQ1036`;`40:f][@D0`kfk0`11JN420<>m
^`80@FWQ0`33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0;B`/@80@FWQ0P2][Jd3
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G
0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl0102][Jd0Y9j?045Y
h@11JN420:BNS`80@FWQ3P2aZid01@2][Jd0@FWQ0;VbYP2i/ZH0@FWQ00H0^K:V00@0@FWQ0;VbYP2i
/ZH0^K:V0`11JN40102][Jd0@FWQ0:f][@2][Jd30;jg[003045Yh@2n]j`0_[N/00H0_[N/0P11JN45
0<6j/080@FWQ2`31^[000`11JN40`KZ`0:f][@040<>m/`80@FWQ1P33_K<4045Yh@80`kfc00@0@FWQ
0<>m/`33_K<0[Jf]1@35_[D3045Yh@h0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03038`K/5045Yh@<0b<6k00<0
[Jf]045Yh@11JN401`38`K/2045Yh@X0b<6k00<0[Jf]045Yh@11JN401P37`K`2045Yh@H0al6l0`11
JN40102][Jd0a/2l0<K0_011JN420<K0_003045Yh@36`;`0a/2l0080a/2l0P11JN440:f][@80a/2l
00<0[Jf]0<>m^`33_K/01033_K/2045Yh@040<>m^`11JN40`kfk045Yh@@0`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP0102][Jd0];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102]
[Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl00`2TWXl20:f][@030:BNS`11JN40@FWQ0080@FWQ3P2aZid0102][Jd0^K:V045Yh@11
JN460;VbYP80@FWQ0`2i/ZH3045Yh@040;jg[011JN40_[N/0;jg[0<0[Jf]00<0@FWQ0;jg[02n]j`0
1P2n]j`2045Yh@D0`KZ`0P11JN4:0<6j/080@FWQ00<0`KZ`0:f][@33_K<01033_K<00`11JN40`kfc
0<>m/`040<>m/`80@FWQ1@33_K<00`11JN40`kfc0:f][@070<Fn]@@0@FWQ0P35_[D7045Yh@80aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00@0[Jf]0<S1^`11JN40@FWQ1P38`K/2045Yh@X0
b<6k00<0[Jf]045Yh@11JN401P37`K`2045Yh@H0al6l0`11JN40102][Jd0a/2l045Yh@11JN420<K0
_003045Yh@36`;`0[Jf]0080[Jf]0P11JN460<K0_0030:f][@33_K/0`kfk00@0`kfk0P11JN420<>m
^`03045Yh@33_K/0`kfk00<0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][Jd7
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H0
0`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0
/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH01011JN40^K:V045Yh@11JN430;VbYP80@FWQ0`2n
]j`00`11JN40_[N/0;jg[0020;jg[003045Yh@2][Jd0[Jf]0080[Jf]0P2n]j`4045Yh@D0`KZ`0P11
JN4:0<6j/080@FWQ00<0`KZ`0:f][@33_K<01033_K<00`11JN40`kfc0<>m/`040<>m/`80@FWQ1@33
_K<2045Yh@030:f][@35_[D0aKje00D0aKje0P11JN470<Fn]@03045Yh@35_[D0aKje00<0aKje1`11
JN470<Jo]`<0@FWQ1`36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/00P11JN450<S1^`80@FWQ2P38
`K/00`2][Jd0@FWQ045Yh@060<O1_080@FWQ1P37`K`2045Yh@030<O1_011JN40a/2l0080@FWQ0P2]
[Jd00`11JN40[Jf]0<K0_0020<K0_080@FWQ1P36`;`00`2][Jd0`kfk0<>m^`040<>m^`80@FWQ2033
_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`
KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`07
0:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP070;VbYP<0@FWQ0`2i/ZH2045Yh@<0_[N/00<0@FWQ
0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0020;jg[0@0[Jf]00@0_[N/045Yh@11JN40@FWQ0`31
^[02045Yh@X0`KZ`0P11JN400`31^[00[Jf]0<>m/`040<>m/`03045Yh@33_K<0`kfc00<0`kfc0P11
JN470<>m/`80@FWQ1`35_[D2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D00`35_[D0102][Jd0a[ng0<Jo
]`11JN480<Jo]`80@FWQ0`36_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@37`KP0@FWQ0080al6h
1011JN480<O1^003045Yh@37`KP0al6h00<0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0>0<S1^`80@FWQ1038`K/00`2][Jd0b<6k0<S1^`02045Yh@D0b<6k0P11JN4:0<S1^`030:f]
[@11JN40@FWQ00H0al6l0P11JN460<O1_005045Yh@2][Jd0[Jf]045Yh@2][Jd00P11JN420<K0_003
045Yh@36`;`0a/2l0080a/2l0P11JN460<K0_0030:f][@33_K/0`kfk00<0`kfk0P11JN490<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2]
[Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@`0/J^M
00<0[Jf]0;VbYP2i/ZH02@2i/ZH2045Yh@80^K:V0P11JN430;jg[003045Yh@2n]j`0_[N/0080_[N/
00<0@FWQ0;jg[02n]j`01P2n]j`50:f][@80`KZ`0P11JN4;0<6j/080@FWQ00<0[Jf]0<>m/`33_K<0
0`33_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ1`33_K<2045Yh@L0aKje0P11JN470<Fn]@03045Y
h@35_[D0aKje00<0aKje00@0[Jf]0<Jo]`36_kL0@FWQ1`36_kL00`11JN40a[ng0<Jo]`040<Jo]`03
045Yh@36_kL0a[ng00<0a[ng00<0[Jf]0<O1^011JN400P11JN440<O1^080@FWQ1@37`KP00`11JN40
al6h045Yh@040<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0
b<6k00D0[Jf]0<S1^`38`K/0b<6k045Yh@050<S1^`80@FWQ2P38`K/0102][Jd0al6l045Yh@11JN46
0<O1_003045Yh@37`K`0al6l00@0[Jf]00D0@FWQ0<O1_037`K`0@FWQ0<K0_002045Yh@80a/2l00<0
@FWQ0<K0_036`;`00P36`;`2045Yh@H0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`
h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@02
0:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`11JN40_[N/045Yh@02045Yh@@0_[N/00<0@FWQ
0;jg[02n]j`01`2n]j`0102][Jd0`KZ`0<6j/031^[020:f][@80@FWQ0`2][Jd80<6j/080@FWQ00<0
[Jf]0<>m/`33_K<00`33_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ2033_K<00`11JN40aKje0<Fn
]@050<Fn]@80@FWQ1`35_[D00`11JN40aKje0<Fn]@030<Fn]@040:f][@36_kL0a[ng045Yh@H0a[ng
0P11JN470<Jo]`03045Yh@36_kL0a[ng0080a[ng00<0[Jf]045Yh@11JN402037`KP00`11JN40al6h
0<O1^0030<O1^003045Yh@37`KP0al6h00<0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0>0<S1^`80@FWQ1038`K/01@2][Jd0b<6k0<S1^`38`K/0@FWQ00D0b<6k0P11JN4:0<S1^`03
0:f][@37`K`0al6l00P0@FWQ0P2][Jd40<O1_006045Yh@37`K`0al6l045Yh@36`;`0@FWQ1036`;`0
1011JN40a/2l0<K0_036`;`2045Yh@H0a/2l00<0[Jf]0<>m^`11JN403P33_K/00`2][Jd0_[Vh0;ji
^0060;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2]
[Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl0
0`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP040:f][@2n]j`0
_[N/0;jg[0<0@FWQ0P2n]j`00`11JN40_[N/0;jg[0070;jg[0030:f][@31^[00`KZ`00<0`KZ`0P11
JN430<6j/0L0[Jf]0P31^[03045Yh@@0`kfc00<0@FWQ0<>m/`33_K<00`33_K<2045Yh@P0`kfc0P11
JN460<Fn]@80@FWQ1`35_[D00`11JN40aKje0<Fn]@030<Fn]@040:f][@36_kL0a[ng045Yh@H0a[ng
0P11JN480<Jo]`06045Yh@36_kL0a[ng0<Jo]`2][Jd0@FWQ2@37`KP00`11JN40al6h0<O1^00:0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@@0b<6k00D0[Jf]0<S1
^`38`K/0b<6k045Yh@050<S1^`80@FWQ2P38`K/00`2][Jd0al6l0<O1_0050:f][@030<O1_011JN40
@FWQ00D0al6l0P11JN420<O1_003045Yh@36`;`0@FWQ00@0a/2l00@0@FWQ0<K0_036`;`0a/2l0P11
JN460<K0_0030:f][@33_K/0@FWQ00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP30:f][@D0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3o
ool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00@0/J^M0`2][Jd40;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01P2n]j`0
0`11JN40_[N/0;jg[0070;jg[0030:f][@31^[00`KZ`00<0`KZ`0P11JN4:0<6j/0D0[Jf]0P11JN42
0<>m/`03045Yh@33_K<0`kfc00<0`kfc0P11JN480<>m/`80@FWQ1P35_[D2045Yh@L0aKje00<0@FWQ
0<Fn]@35_[D00`35_[D0102][Jd0a[ng0<Jo]`11JN450<Jo]`80@FWQ3@36_kL00`2][Jd0@FWQ0<O1
^0080<O1^003045Yh@37`KP0al6h00X0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0>0<S1^`80@FWQ1038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@D0b<6k0P11JN460<S1^`H0[Jf]
1`37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ0P37`K`00`2][Jd0@FWQ045Yh@040<K0_0<0@FWQ
0P36`;`2045Yh@H0a/2l0P11JN4>0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00
G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
1`2aZid30:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`01P2n]j`2045Yh@P0_[N/
00<0[Jf]0<6j/031^[000`31^[03045Yh@<0`KZ`00<0@FWQ0<6j/031^[001P31^[00102][Jd0`kfc
0<>m/`33_K<3045Yh@@0[Jf]00<0`kfc045Yh@11JN402033_K<2045Yh@H0aKje0P11JN470<Fn]@03
045Yh@35_[D0aKje00<0aKje00@0[Jf]0<Jo]`36_kL0@FWQ1@36_kL2045Yh@d0a[ng00<0[Jf]0<O1
^037`KP01`37`KP2045Yh@`0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0>0<S1
^`80@FWQ1038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@D0b<6k0P11JN460:f][@<0b<6k00<0[Jf]
0<O1_037`K`01`37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ0P37`K`00`2][Jd0@FWQ045Yh@02
0<K0_0<0@FWQ1036`;`2045Yh@H0a/2l0P11JN4>0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V0@3o
ool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/00H0_[N/0P11JN480;jg[0030:f][@31^[00
`KZ`00<0`KZ`0`11JN430<6j/080@FWQ1@31^[02045Yh@030:f][@33_K<0`kfc00<0`kfc00<0@FWQ
0<>m/`33_K<00P33_K<00`2][Jd0@FWQ045Yh@050:f][@<0`kfc0P11JN460<Fn]@80@FWQ1`35_[D0
0`11JN40aKje0<Fn]@030<Fn]@040:f][@36_kL0a[ng045Yh@D0a[ng0P11JN4=0<Jo]`030:f][@37
`KP0al6h00D0al6h0`11JN4=0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03P38
`K/2045Yh@@0b<6k00@0[Jf]0<S1^`38`K/0b<6k0P11JN450:f][@80@FWQ2@38`K/0102][Jd0al6l
045Yh@11JN460<O1_003045Yh@37`K`0al6l00<0al6l1011JN400`2][Jd0@FWQ0<K0_0090<K0_080
@FWQ1P36`;`2045Yh@d0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02O
Vj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/00H0_[N/
0P11JN480;jg[004045Yh@31^[00`KZ`0<6j/0@0@FWQ00@0`KZ`045Yh@31^[00`KZ`0P11JN450<6j
/080@FWQ00<0[Jf]0<>m/`33_K<00`33_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ1@33_K<30:f]
[@80@FWQ102][Jd20<Fn]@80@FWQ1`35_[D00`11JN40aKje0<Fn]@030<Fn]@040:f][@36_kL0@FWQ
045Yh@D0a[ng0P11JN4=0<Jo]`030:f][@37`KP0al6h00@0al6h0`11JN470<O1^003045Yh@37`KP0
al6h00@0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ202][Jd2
045Yh@D0b<6k0P11JN450<S1^`06045Yh@38`K/0b<6k0<S1^`2][Jd0al6l0P11JN450<O1_003045Y
h@37`K`0al6l0080al6l1011JN420<O1_0030:f][@36`;`0a/2l00X0a/2l0P11JN440<K0_0<0@FWQ
2P33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P
0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2a
Zid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[0070;jg[003045Yh@2n
]j`0_[N/00H0_[N/00<0@FWQ0<6j/031^[001`31^[03045Yh@H0`KZ`00<0@FWQ0<6j/02][Jd01@33
_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ1`33_K<2045Yh@D0aKje0P2][Jd2045Yh@L0[Jf]00<0
@FWQ0<Fn]@35_[D00`35_[D0102][Jd0a[ng045Yh@11JN450<Jo]`80@FWQ3@36_kL00`2][Jd0al6h
0<O1^0020<O1^0<0@FWQ2@37`KP00`11JN40al6h0<O1^0040<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/00`38`K/;0:f][@80@FWQ1038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@D0
b<6k0`11JN430<S1^`80@FWQ0`38`K/0102][Jd0al6l0<O1_011JN420<O1_0<0@FWQ3037`K`00`2]
[Jd0a/2l0<K0_0090<K0_080@FWQ1036`;`00`11JN40[Jf]045Yh@070<>m^`<0[Jf]1033_K/00`2]
[Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80
[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP03
0:f][@2n]j`0_[N/00L0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`2045YhA<0`KZ`00<0@FWQ0:f][@33
_K<00`33_K<00`11JN40`kfc0<>m/`040<>m/`<0@FWQ1P33_K<2045Yh@L0aKje0P11JN470<Fn]@03
045Yh@2][Jd0[Jf]00D0[Jf]0P11JN450:f][@80@FWQ00<0[Jf]0<Jo]`36_kL02P36_kL0102][Jd0
al6h0<O1^037`KP3045Yh@X0al6h00<0@FWQ0<O1^037`KP01037`KP00`2][Jd0al6j0<O1^P090<O1
^Q40[Jf]2`38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/00P38`K/00`11JN40b<6k0<S1^`030<S1
^`<0@FWQ1038`K/01@11JN40b<6k0<S1^`38`K/0[Jf]00<0al6l0P11JN4?0<O1_0030:f][@36`;`0
a/2l00T0a/2l00<0@FWQ0<K0_011JN400P36`;`01011JN40a/2l0:f][@11JN430<>m^`@0[Jf]1`33
_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`
h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/00P0_[N/0P11JN460;jg[080@FWQ5031^[05
045Yh@L0`kfc0`11JN450<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D01@35_[D2045Yh@L0aKje00<0@FWQ
0<Fn]@35_[D00`35_[D0102][Jd0a[ng045Yh@11JN460<Jo]`03045Yh@36_kL0[Jf]00H0[Jf]00<0
@FWQ0:f][@2][Jd0102][Jd3045Yh@`0[Jf]00<0@FWQ0:f][@2][Jd0402][Jd;0<O1^P030:f][@38
`K/0b<6k00l0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0b<6k0<S1^`020<S1^`03045Yh@38
`K/0b<6k00<0b<6k0P11JN400`38`K/0@FWQ045Yh@03045Yh@<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00:0<K0_0@0@FWQ0P36`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0
[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H2
0:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]2@2n]j`0
0`11JN40_[N/0;jg[0040;jg[003045Yh@2][Jd0`KZ`01<0`KZ`00<0[Jf]0<>m/`33_K<01`33_K<4
045Yh@030<>m/`11JN40`kfc0080`kfc0P11JN400`33_K<0[Jf]0<Fn]@060<Fn]@80@FWQ1`35_[D0
0`11JN40aKje0<Fn]@030<Fn]@040:f][@36_kL0@FWQ045Yh@H0a[ng0P11JN460<Jo]`03045Yh@36
_kL0@FWQ00<0a[ng00@0[Jf]045Yh@11JN40@FWQ1`37`KP00`11JN40al6h0<O1^0030<O1^003045Y
h@37`KP0al6h00@0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0?0<S1^`03045Y
h@38`K/0b<6k0080b<6k00<0[Jf]0<S1^`38`K/00P38`K/00`11JN40b<6k0<S1^`05045Yh@T0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh
0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`
h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0[Jf]00<0[Jf]1P2n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`090<>m/`80@FWQ0P33_K<4045Yh@80`kfc00<0[Jf]0<Fn]@35_[D01@35
_[D00`11JN40aKje045Yh@050<Fn]@80@FWQ1@35_[D0102][Jd0a[ng045Yh@11JN460<Jo]`80@FWQ
1`36_kL2045Yh@<0a[ng00<0[Jf]045Yh@37`KP01`37`KP2045Yh@D0al6h00<0@FWQ0<O1^037`KP0
1037`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00l0b<6k00<0@FWQ0<S1^`38`K/0
0P38`K/00`2][Jd0b<6k0<S1^`020<S1^`03045Yh@38`K/0b<6k00h0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f]
[@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2]
[Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0030;jg[0@0[Jf]0`2n]j`4045Yh@030;jg[011JN40[Jf]01@0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@050<Fn]@04045Yh@35_[D0aKje045Yh@@0aKje0P11JN450<Fn]@040:f]
[@36_kL0@FWQ045Yh@L0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40a[ng0<Jo]`020<Jo]`03
0:f][@11JN40al6h00L0al6h0P11JN450<O1^003045Yh@37`KP0al6h00@0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0?0<S1^`03045Yh@38`K/0b<6k0080b<6k00@0[Jf]0<S1^`38
`K/0b<6k0P11JN4@0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@36`;`40:f]
[@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a
0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd40;jg[003045Yh@2][Jd0`KZ`
01<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@050<Fn]@04045Yh@35_[D0aKje
0<Fn]@@0@FWQ1`35_[D4045Yh@L0a[ng0P11JN450<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0[Jf]
0<O1^011JN401P37`KP3045Yh@@0al6h0P11JN460<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/03`38`K/00`11JN40b<6k0<S1^`020<S1^`040:f][@38`K/0b<6k0<S1^`80@FWQ4038
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`
h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0
_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00D0aKje00<0
@FWQ0<Fn]@35_[D03035_[D0102][Jd0a[ng045Yh@11JN490<Jo]`D0@FWQ1P36_kL00`2][Jd0al6h
0<O1^006045Yh@80al6h00<0@FWQ0<O1^037`KP00P37`KP3045Yh@D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0?0<S1^`03045Yh@38`K/0b<6k0080b<6k00D0[Jf]0<S1^`38`K/0
b<6k045Yh@0A0<S1^`030:f][@37`K`0al6l0100al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`50:f][A40`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@050<Fn]@03045Yh@35_[D0aKje00`0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00=0<O1^0<0@FWQ1@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k00l0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0b<6k0<S1^`02045YhA40b<6k
00<0[Jf]0<O1_037`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`
1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01@35_[D00`11JN40aKje
0<Fn]@0<0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03@37`KP3045Yh@D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0?0<S1^`03045Yh@38`K/0b<6k0080b<6k
00@0[Jf]0<S1^`38`K/0@FWQ4P38`K/00`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0
/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D03035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h00d0al6h0`11JN450<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
3`38`K/00`11JN40b<6k0<S1^`020<S1^`040:f][@38`K/0@FWQ045YhA80b<6k00<0[Jf]0<O1_037
`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f]
[@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D03035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h00d0al6h0`11JN450<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
3`38`K/00`11JN40b<6k0<S1^`020<S1^`030:f][@38`K/0@FWQ0100b<6k1P2][JdB0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]
G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`030:f]
[@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D03035_[D00`2][Jd0a[ng045Yh@0E0<Jo]`030:f]
[@37`KP0al6h00d0al6h0`11JN450<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
3`38`K/00`11JN40b<6k045Yh@04045Yh@X0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]
G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35
_[D0aKje0080aKje1011JN4>0<Fn]@040:f][@36_kL0@FWQ045YhA@0a[ng00<0[Jf]0<O1^037`KP0
3@37`KP3045Yh@D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0<0<S1^`D0@FWQ
0`38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]
3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4033_K<90:f][A40aKje00<0[Jf]0<Jo]`11JN405@36_kL00`2][Jd0al6h0<O1^00=0<O1^080@FWQ
1P37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]
I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00>0<O1^003045Yh@37`KP0al6h00@0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA
0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00`33_K/3
0:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;VbYP2][Jd0_[N/0140
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102][Jd@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`4
0:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`h>H10?oo
o`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0
[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0[Jf]V@2`
h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][JfW
0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`h>H10?oo
o`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44742 .3284 m
.45458 .3288 L
s
.255 .412 .882 r
.52298 .33862 m
.52794 .34086 L
s
.51966 .33861 m
.52298 .33862 L
s
.51635 .34085 m
.51966 .33861 L
s
.51469 .34084 m
.51966 .33861 L
s
.49155 .3382 m
.50311 .33845 L
s
.54284 .33844 m
.5445 .34292 L
s
.54284 .33844 m
.54286 .34746 L
s
.52794 .34086 m
.53126 .34535 L
s
.51303 .34534 m
.51635 .34085 L
s
.51138 .34532 m
.51469 .34084 L
s
.54615 .34063 m
.54945 .33831 L
s
.54945 .33831 m
.55605 .33813 L
s
.5445 .34292 m
.54615 .34063 L
s
.55605 .33813 m
.55936 .34029 L
s
.54286 .34746 m
.5445 .34292 L
s
.51137 .3521 m
.51303 .34534 L
s
.50971 .35208 m
.51138 .34532 L
s
.47344 .33756 m
.48495 .338 L
s
.55936 .34029 m
.56102 .34249 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56102 .34249 m
.56105 .34926 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57415 .33746 m
.5758 .33964 L
s
.57252 .33979 m
.57415 .33746 L
s
.51136 .35662 m
.51137 .3521 L
s
.5097 .3566 m
.50971 .35208 L
s
.57252 .33979 m
.57418 .34197 L
s
.45545 .33663 m
.46688 .33725 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49806 .37002 m
.49815 .33836 L
s
.4964 .36998 m
.4965 .33832 L
s
.47988 .3627 m
.48001 .33782 L
s
.47823 .36264 m
.47837 .33776 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5594 .34932 m
.56104 .347 L
s
.57418 .34197 m
.5758 .33964 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55611 .35168 m
.5594 .34932 L
s
.51136 .35662 m
.51301 .36343 L
s
.5097 .3566 m
.51135 .36341 L
s
.55941 .35158 m
.56105 .34926 L
s
.54785 .35641 m
.55611 .35168 L
s
.46162 .38468 m
.46197 .337 L
s
.52962 .35892 m
.53128 .36117 L
s
.52796 .36119 m
.52962 .35892 L
s
.55611 .35394 m
.55941 .35158 L
s
.45997 .38459 m
.46034 .33691 L
s
.54454 .35873 m
.54785 .35641 L
s
.54786 .35867 m
.55611 .35394 L
s
.52796 .36119 m
.52962 .36344 L
s
.54289 .36103 m
.54454 .35873 L
s
.53128 .36117 m
.53128 .36343 L
s
.54455 .361 m
.54786 .35867 L
s
.54289 .36103 m
.5429 .36556 L
s
.5429 .36329 m
.54455 .361 L
s
.52796 .36799 m
.53128 .36343 L
s
.51301 .36343 m
.51633 .36798 L
s
.51135 .36341 m
.51467 .36797 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5429 .36556 m
.54457 .3678 L
s
.52464 .37027 m
.52796 .36799 L
s
.42019 .31809 m
.43136 .3191 L
s
.51633 .36798 m
.51965 .37026 L
s
.51467 .36797 m
.51965 .37026 L
s
.55947 .36517 m
.5611 .36058 L
s
.5611 .36058 m
.56114 .36966 L
s
.51965 .37026 m
.52464 .37027 L
s
.54457 .3678 m
.54789 .37 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55783 .36749 m
.55947 .36517 L
s
.55947 .36517 m
.56114 .36966 L
s
.47821 .36718 m
.47988 .3627 L
s
.49143 .36986 m
.49806 .37002 L
s
.54789 .37 m
.55452 .36985 L
s
.47656 .36711 m
.47823 .36264 L
s
.55452 .36985 m
.55783 .36749 L
s
.436 .3353 m
.44082 .33792 L
s
.44082 .33792 m
.44401 .34268 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42599 .36633 m
.42656 .31868 L
s
.42439 .3662 m
.42496 .31854 L
s
.436 .3353 m
.43921 .33781 L
s
.43921 .33781 m
.44239 .34257 L
s
.47325 .36925 m
.47821 .36718 L
s
.44401 .34268 m
.44557 .34959 L
s
.43279 .33504 m
.436 .3353 L
s
.47325 .36925 m
.47656 .36711 L
s
.44239 .34257 m
.44395 .34948 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57277 .38061 m
.57425 .35328 L
s
.57425 .35328 m
.57607 .38047 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57433 .36689 m
.57442 .38054 L
s
.42955 .33704 m
.43279 .33504 L
s
.46995 .36911 m
.47325 .36925 L
s
.46179 .3619 m
.46504 .36661 L
s
.44553 .35413 m
.44557 .34959 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46504 .36661 m
.46995 .36911 L
s
.49636 .38135 m
.49802 .38366 L
s
.49469 .38359 m
.49636 .38135 L
s
.4439 .35402 m
.44395 .34948 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49635 .3859 m
.49802 .38366 L
s
.42629 .3413 m
.42955 .33704 L
s
.49469 .38359 m
.49635 .3859 L
s
.44384 .36083 m
.44553 .35413 L
s
.44221 .36072 m
.4439 .35402 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57277 .38061 m
.57445 .3851 L
s
.57445 .3851 m
.57607 .38047 L
s
.44055 .36516 m
.44384 .36083 L
s
.43893 .36505 m
.44221 .36072 L
s
.41522 .33347 m
.41681 .33362 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41202 .33542 m
.41522 .33347 L
s
.41361 .33558 m
.41522 .33347 L
s
.43566 .36709 m
.44055 .36516 L
s
.41196 .33996 m
.41361 .33558 L
s
.43566 .36709 m
.43893 .36505 L
s
.45505 .38433 m
.46162 .38468 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41038 .3398 m
.41202 .33542 L
s
.43243 .36685 m
.43566 .36709 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41174 .3559 m
.41196 .33996 L
s
.40729 .33493 m
.41038 .3398 L
s
.40417 .33232 m
.40729 .33493 L
s
.42607 .35949 m
.42924 .36431 L
s
.42924 .36431 m
.43243 .36685 L
s
.4101 .36031 m
.41038 .3398 L
s
.39948 .33179 m
.40417 .33232 L
s
.41958 .36578 m
.42599 .36633 L
s
.39632 .3337 m
.39948 .33179 L
s
.39476 .33352 m
.39948 .33179 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4101 .36031 m
.41174 .3559 L
s
.39469 .33807 m
.39632 .3337 L
s
.3992 .35002 m
.40861 .35331 L
s
.40861 .35331 m
.41016 .35575 L
s
.39314 .33789 m
.39476 .33352 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40848 .36244 m
.4101 .36031 L
s
.39462 .34263 m
.39469 .33807 L
s
.39306 .34245 m
.39314 .33789 L
s
.40529 .36441 m
.40848 .36244 L
s
.39462 .34263 m
.39611 .34738 L
s
.39611 .34738 m
.3992 .35002 L
s
.39455 .3472 m
.3992 .35002 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39306 .34245 m
.39455 .3472 L
s
0 0 0 r
.36197 .31898 m
.36436 .31934 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39899 .36374 m
.40529 .36441 L
s
.66193 .32981 m
.67713 .32767 L
s
.3944 .35634 m
.39597 .35652 L
s
.39593 .35881 m
.39597 .35652 L
s
.39437 .35863 m
.3944 .35634 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39589 .3611 m
.39899 .36374 L
s
.39437 .35863 m
.39589 .3611 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66805 .32898 m
.66891 .37719 L
s
.66652 .32919 m
.66737 .37738 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36277 .32682 m
.3733 .32841 L
s
.36816 .35987 m
.36877 .32774 L
s
.67713 .32767 m
.68018 .3295 L
s
.67713 .32767 m
.68168 .32927 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36665 .35965 m
.36726 .32752 L
s
.38047 .35463 m
.38197 .35713 L
s
.38193 .35942 m
.38197 .35713 L
s
.3789 .35673 m
.38047 .35463 L
s
.38035 .36152 m
.38193 .35942 L
s
.68018 .3295 m
.68326 .33362 L
s
.3789 .35673 m
.38039 .35923 L
s
.37576 .36092 m
.38035 .36152 L
s
.68168 .32927 m
.68475 .33338 L
s
.36842 .34607 m
.3698 .35318 L
s
.37275 .35821 m
.37576 .36092 L
s
.68326 .33362 m
.68485 .33797 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3698 .35318 m
.37275 .35821 L
s
.68475 .33338 m
.68633 .33774 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66275 .37796 m
.67805 .37596 L
s
.68485 .33797 m
.68647 .34463 L
s
.35349 .34376 m
.35387 .32538 L
s
.35201 .34352 m
.3524 .32513 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68633 .33774 m
.68796 .3444 L
s
.36213 .35899 m
.36816 .35987 L
s
.69349 .32504 m
.70367 .32323 L
s
.68647 .34463 m
.68671 .35615 L
s
.34761 .34278 m
.35793 .34448 L
s
.34942 .32692 m
.35225 .33201 L
s
.68796 .3444 m
.6882 .35592 L
s
.3451 .32385 m
.34942 .32692 L
s
.3422 .32332 m
.3451 .32385 L
s
.68535 .36331 m
.68671 .35615 L
s
.67805 .37596 m
.68103 .37322 L
s
.67805 .37596 m
.68253 .373 L
s
.68685 .36308 m
.6882 .35592 L
s
.68395 .36815 m
.68535 .36331 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68103 .37322 m
.68395 .36815 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33927 .32509 m
.3422 .32332 L
s
.33784 .32482 m
.3422 .32332 L
s
.68544 .36793 m
.68685 .36308 L
s
.68253 .373 m
.68544 .36793 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69933 .32402 m
.70003 .35631 L
s
.69788 .32428 m
.69857 .35656 L
s
.3363 .32915 m
.33927 .32509 L
s
.35286 .37382 m
.35315 .35992 L
s
.35153 .36663 m
.35315 .35992 L
s
.69973 .34244 m
.70134 .34912 L
s
.69417 .35729 m
.70003 .35631 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33487 .32888 m
.33784 .32482 L
s
.34848 .37079 m
.35153 .36663 L
s
.35153 .36663 m
.35286 .37382 L
s
.33477 .3335 m
.3363 .32915 L
s
.70134 .34912 m
.70434 .35324 L
s
.33334 .33322 m
.33487 .32888 L
s
.33318 .34016 m
.33477 .3335 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3211 .3118 m
.32111 .3114 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34403 .37239 m
.34848 .37079 L
s
.70434 .35324 m
.70728 .35504 L
s
.33176 .33989 m
.33334 .33322 L
s
.33291 .35175 m
.33318 .34016 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70728 .35504 m
.71159 .35425 L
s
.33149 .35149 m
.33176 .33989 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71005 .34988 m
.71154 .35193 L
s
.71005 .34988 m
.71143 .34729 L
s
.34112 .3719 m
.34403 .37239 L
s
.71143 .34729 m
.71291 .34934 L
s
.71291 .34934 m
.71296 .35166 L
s
.33828 .36907 m
.34112 .3719 L
s
.33683 .36881 m
.34112 .3719 L
s
.33291 .35175 m
.33418 .35899 L
s
.71159 .35425 m
.71296 .35166 L
s
.72353 .32159 m
.72761 .31838 L
s
.72226 .32652 m
.72353 .32159 L
s
.72226 .32652 m
.72237 .33115 L
s
.3355 .3639 m
.33828 .36907 L
s
.33149 .35149 m
.33275 .35873 L
s
.33418 .35899 m
.3355 .3639 L
s
.72492 .32129 m
.72761 .31838 L
s
.72365 .32622 m
.72492 .32129 L
s
.72365 .32622 m
.72376 .33086 L
s
.33407 .36364 m
.33683 .36881 L
s
.72237 .33115 m
.72388 .3355 L
s
.33275 .35873 m
.33407 .36364 L
s
.72761 .31838 m
.73171 .31745 L
s
.72376 .33086 m
.72527 .3352 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32036 .34187 m
.32039 .34048 L
s
.5 Mabswid
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31687 .31818 m
.32158 .35187 L
s
.31058 .34954 m
.31687 .31818 L
s
.31194 .34984 m
.31669 .32513 L
s
.31742 .35101 m
.32578 .35272 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72964 .33804 m
.72968 .33949 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72388 .3355 m
.72808 .33694 L
s
.72527 .3352 m
.72808 .33694 L
s
.73171 .31745 m
.73448 .31915 L
s
.72411 .34479 m
.72417 .34712 L
s
.72411 .34479 m
.7255 .3445 L
s
.72417 .34712 m
.72561 .34916 L
s
.7255 .3445 m
.72556 .34683 L
s
.73448 .31915 m
.7373 .32317 L
s
.72561 .34916 m
.72844 .35091 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3196 .37216 m
.31964 .37076 L
s
.5 Mabswid
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73851 .3182 m
.74111 .31523 L
s
.7373 .32317 m
.73851 .3182 L
s
.30606 .31566 m
.31058 .34954 L
s
.29987 .34707 m
.30606 .31566 L
s
.73985 .31788 m
.74111 .31523 L
s
.73864 .32285 m
.73985 .31788 L
s
.74111 .31523 m
.74244 .3149 L
s
.30119 .34738 m
.30587 .32264 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73864 .32285 m
.73907 .33917 L
s
.7373 .32317 m
.73785 .34415 L
s
.72844 .35091 m
.73391 .34973 L
s
.72808 .33694 m
.73632 .33745 L
s
.73632 .33745 m
.73773 .33948 L
s
.73391 .34973 m
.73656 .34679 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73656 .34679 m
.73785 .34415 L
s
.73785 .34415 m
.73907 .33917 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29593 .34611 m
.30518 .34832 L
s
.29297 .31233 m
.29425 .31267 L
s
.29034 .31397 m
.29297 .31233 L
s
.29162 .31432 m
.29297 .31233 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75413 .31187 m
.76016 .34334 L
s
.7499 .346 m
.75413 .31187 L
s
.29021 .31865 m
.29162 .31432 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74597 .34696 m
.75507 .34469 L
s
.28894 .3183 m
.29034 .31397 L
s
.7512 .34567 m
.75433 .31888 L
s
.28974 .33506 m
.29021 .31865 L
s
.28654 .31292 m
.28894 .3183 L
s
.28833 .33942 m
.28894 .3183 L
s
.28411 .30987 m
.28654 .31292 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28039 .30878 m
.28411 .30987 L
s
.28833 .33942 m
.28974 .33506 L
s
.28726 .33203 m
.28846 .33472 L
s
.76016 .34334 m
.76418 .30902 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27983 .32758 m
.28726 .33203 L
s
.28699 .34144 m
.28833 .33942 L
s
.27787 .3104 m
.28039 .30878 L
s
.27665 .31003 m
.28039 .30878 L
s
.76142 .343 m
.76439 .31606 L
s
.28439 .34312 m
.28699 .34144 L
s
.27651 .31473 m
.27787 .3104 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27529 .31436 m
.27665 .31003 L
s
.2794 .34174 m
.28439 .34312 L
s
.27744 .32451 m
.27983 .32758 L
s
.27622 .32415 m
.27983 .32758 L
s
.27636 .31944 m
.27651 .31473 L
s
.27515 .31907 m
.27529 .31436 L
s
.27636 .31944 m
.27744 .32451 L
s
.27515 .31907 m
.27622 .32415 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27701 .33867 m
.2794 .34174 L
s
.27593 .33359 m
.27716 .33395 L
s
.27708 .33631 m
.27716 .33395 L
s
.27586 .33595 m
.27593 .33359 L
s
.27586 .33595 m
.27701 .33867 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7664 .34162 m
.77371 .33949 L
s
.76418 .30902 m
.77008 .34057 L
s
.77999 .31121 m
.78215 .30571 L
s
.77897 .31632 m
.77999 .31121 L
s
.77803 .3238 m
.77897 .31632 L
s
.77803 .3238 m
.7784 .33566 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78215 .30571 m
.7855 .30216 L
s
.78115 .31083 m
.7833 .30532 L
s
.78014 .31594 m
.78115 .31083 L
s
.7792 .32342 m
.78014 .31594 L
s
.7792 .32342 m
.77957 .33529 L
s
.7833 .30532 m
.7855 .30216 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2525 .29946 m
.26028 .30229 L
s
.7784 .33566 m
.7798 .34242 L
s
.26519 .33029 m
.26629 .33304 L
s
.26621 .33541 m
.26629 .33304 L
s
.7855 .30216 m
.78775 .30136 L
s
.26395 .33229 m
.26519 .33029 L
s
.26497 .33742 m
.26621 .33541 L
s
.77957 .33529 m
.78097 .34205 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26395 .33229 m
.26504 .33504 L
s
.26149 .33629 m
.26497 .33742 L
s
.78775 .30136 m
.79115 .30251 L
s
.7798 .34242 m
.78112 .34681 L
s
.25581 .33438 m
.2569 .30109 L
s
.78097 .34205 m
.78229 .34645 L
s
.25469 .33399 m
.25579 .30068 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78112 .34681 m
.7836 .35085 L
s
.25928 .33315 m
.26149 .33629 L
s
.78229 .34645 m
.78475 .35048 L
s
.79115 .30251 m
.7935 .30644 L
s
.25717 .32761 m
.25928 .33315 L
s
.25628 .32008 m
.25717 .32761 L
s
.79326 .29932 m
.7939 .31835 L
s
.7836 .35085 m
.78712 .35213 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79435 .2989 m
.79499 .31795 L
s
.7906 .31955 m
.79821 .31673 L
s
.78475 .35048 m
.78712 .35213 L
s
.25138 .33282 m
.25581 .33438 L
s
.78712 .35213 m
.78938 .35138 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78938 .35138 m
.79266 .34784 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80072 .29638 m
.80785 .29335 L
s
.24583 .3041 m
.24672 .30929 L
s
.24672 .30929 m
.24754 .31687 L
s
.2439 .29848 m
.24583 .3041 L
s
.24714 .32883 m
.24754 .31687 L
s
.79266 .34784 m
.7947 .34227 L
s
.24478 .30368 m
.24567 .30887 L
s
.24567 .30887 m
.24648 .31645 L
s
.24287 .29806 m
.24478 .30368 L
s
.2409 .29481 m
.2439 .29848 L
s
.79555 .33469 m
.79603 .34909 L
s
.7947 .34227 m
.79555 .33469 L
s
.24607 .32843 m
.24648 .31645 L
s
.7947 .34227 m
.79603 .34909 L
s
.2409 .29481 m
.24287 .29806 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24582 .33563 m
.24714 .32883 L
s
.23107 .29039 m
.2409 .29481 L
s
.24476 .33523 m
.24607 .32843 L
s
.2446 .34004 m
.24582 .33563 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80483 .29466 m
.806 .32823 L
s
.80381 .29509 m
.80498 .32865 L
s
.24355 .33964 m
.24476 .33523 L
s
.80187 .32988 m
.806 .32823 L
s
.24233 .34406 m
.2446 .34004 L
s
.8055 .31381 m
.80677 .3206 L
s
.24129 .34365 m
.24355 .33964 L
s
.23312 .34281 m
.23492 .29218 L
s
.80677 .3206 m
.80895 .32457 L
s
.23914 .34526 m
.24233 .34406 L
s
.23214 .34239 m
.23395 .29174 L
s
.23914 .34526 m
.24129 .34365 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80895 .32457 m
.81102 .32614 L
s
.22924 .34114 m
.23914 .34526 L
s
.81102 .32614 m
.81394 .32486 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8128 .32046 m
.81386 .32245 L
s
.8128 .32046 m
.81368 .31761 L
s
.81368 .31761 m
.81473 .3196 L
s
.81394 .32486 m
.81482 .32202 L
s
.81473 .3196 m
.81482 .32202 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82045 .29474 m
.82117 .28945 L
s
.82045 .29474 m
.82063 .29957 L
s
.82117 .28945 m
.82373 .28564 L
s
.82063 .29957 m
.8217 .30396 L
s
.82135 .29428 m
.82206 .28899 L
s
.82135 .29428 m
.82153 .29912 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82206 .28899 m
.82373 .28564 L
s
.82153 .29912 m
.8226 .3035 L
s
.82373 .28564 m
.82631 .28423 L
s
.8217 .30396 m
.82445 .30502 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8226 .3035 m
.82445 .30502 L
s
.82206 .31365 m
.82215 .31608 L
s
.82206 .31365 m
.82296 .31321 L
s
.82215 .31608 m
.82314 .31807 L
s
.82296 .31321 m
.82305 .31564 L
s
.82314 .31807 m
.825 .31961 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82445 .30502 m
.82966 .30468 L
s
.82631 .28423 m
.82809 .28571 L
s
.82809 .28571 m
.82993 .28961 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82993 .28961 m
.83056 .28427 L
s
.83056 .28427 m
.83207 .28088 L
s
.83074 .28913 m
.83136 .28379 L
s
.83136 .28379 m
.83207 .28088 L
s
.83376 .26241 m
.83895 .25888 L
s
.83207 .28088 m
.83286 .28039 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82966 .30468 m
.83057 .30666 L
s
.83074 .28913 m
.83139 .30619 L
s
.82993 .28961 m
.83076 .31154 L
s
.825 .31961 m
.82844 .3178 L
s
.82844 .3178 m
.83003 .31445 L
s
.83003 .31445 m
.83076 .31154 L
s
.83076 .31154 m
.83139 .30619 L
s
.83603 .26091 m
.83803 .31224 L
s
.83677 .2604 m
.83878 .31177 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83773 .28478 m
.839 .2789 L
s
.83574 .31365 m
.83878 .31177 L
s
.839 .2789 m
.84033 .27546 L
s
.84033 .27546 m
.84173 .27445 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83849 .30439 m
.84015 .30836 L
s
.84173 .27445 m
.84318 .2759 L
s
.84173 .27445 m
.84385 .27539 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84015 .30836 m
.84168 .30986 L
s
.84318 .2759 m
.84471 .2798 L
s
.84385 .27539 m
.84536 .2793 L
s
.84168 .30986 m
.84309 .3089 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84471 .2798 m
.84566 .28669 L
s
.84309 .3089 m
.84436 .30546 L
s
.84309 .3089 m
.84503 .30498 L
s
.84536 .2793 m
.8463 .28619 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84566 .28669 m
.84585 .29163 L
s
.84436 .30546 m
.8455 .29954 L
s
.8455 .29954 m
.84585 .29163 L
s
.8463 .28619 m
.8465 .29113 L
s
.84503 .30498 m
.84615 .29905 L
s
.84615 .29905 m
.8465 .29113 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84938 .26831 m
.85327 .26463 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85277 .29354 m
.85407 .29751 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8515 .32049 m
.8538 .31854 L
s
.85166 .26622 m
.8538 .31854 L
s
.8511 .26674 m
.85323 .31903 L
s
.19055 .26819 m
.19116 .26624 L
s
.19076 .26322 m
.19116 .26624 L
s
.19016 .26518 m
.19076 .26322 L
s
.19016 .26518 m
.19055 .26819 L
s
.85529 .26251 m
.85848 .25874 L
s
.85407 .29751 m
.85574 .29849 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18931 .31121 m
.19004 .28065 L
s
.1883 .3102 m
.19004 .28065 L
s
.85671 .2609 m
.85786 .2884 L
s
.85574 .29849 m
.85674 .29747 L
s
.85717 .26036 m
.85831 .28788 L
s
.1888 .31071 m
.18942 .29565 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18859 .31574 m
.18931 .31121 L
s
.85674 .29747 m
.8576 .29394 L
s
.85674 .29747 m
.85806 .29342 L
s
0 0 0 r
.86285 .26649 m
.86319 .27038 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18653 .26088 m
.18684 .26392 L
s
.18653 .27143 m
.18684 .26392 L
s
.8576 .29394 m
.85786 .2884 L
s
.1883 .3102 m
.18859 .31574 L
s
.18582 .2573 m
.18653 .26088 L
s
.18611 .2709 m
.18664 .26893 L
s
.85806 .29342 m
.85831 .28788 L
s
.186 .27341 m
.18653 .27143 L
s
.18431 .25511 m
.18582 .2573 L
s
.18519 .27234 m
.18611 .2709 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18508 .27485 m
.186 .27341 L
s
0 0 0 r
.8635 .27769 m
.8635 .28186 L
s
.255 .412 .882 r
.18538 .28849 m
.18601 .28398 L
s
.18559 .29404 m
.18601 .28398 L
s
.86009 .25657 m
.86255 .25272 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1831 .2747 m
.18519 .27234 L
s
.18538 .28849 m
.18559 .29404 L
s
.183 .27722 m
.18508 .27485 L
s
.18486 .29048 m
.18538 .28849 L
s
.1835 .25652 m
.18431 .25511 L
s
.8612 .25492 m
.86269 .29022 L
s
.18395 .29196 m
.18486 .29048 L
s
.86155 .25437 m
.86304 .28969 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18306 .25849 m
.1835 .25652 L
s
.18247 .28987 m
.18395 .29196 L
s
.86157 .29179 m
.86304 .28969 L
s
.18295 .25291 m
.18306 .25849 L
s
.18252 .26298 m
.18306 .25849 L
s
.18252 .26298 m
.18295 .25291 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18232 .27615 m
.1831 .2747 L
s
.18221 .27868 m
.183 .27722 L
s
0 0 0 r
.86664 .295 m
.86681 .29597 L
s
.255 .412 .882 r
.18188 .27815 m
.18232 .27615 L
s
.18189 .28628 m
.18247 .28987 L
s
.18177 .28068 m
.18221 .27868 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86296 .30595 m
.86322 .30289 L
s
.86296 .30595 m
.86344 .30798 L
s
0 0 0 r
.17619 .2367 m
.17669 .23789 L
s
.255 .412 .882 r
.18167 .28321 m
.18188 .27815 L
s
.86322 .30289 m
.86368 .30492 L
s
.18167 .28321 m
.18189 .28628 L
s
.86344 .30798 m
.86368 .30492 L
s
.86433 .25753 m
.86463 .25136 L
s
.86433 .25753 m
.86438 .26567 L
s
.86438 .26567 m
.8646 .27074 L
s
.86459 .25697 m
.86488 .2508 L
s
.86459 .25697 m
.86465 .26512 L
s
0 0 0 r
.17688 .21029 m
.17581 .20611 L
s
.255 .412 .882 r
.8646 .27074 m
.86519 .27782 L
s
.86463 .25136 m
.86522 .24715 L
s
.86465 .26512 m
.86487 .27019 L
s
0 0 0 r
.17659 .24026 m
.17663 .23784 L
s
.8691 .23687 m
.87002 .23419 L
s
.255 .412 .882 r
.18036 .25043 m
.18062 .25661 L
s
.86487 .27019 m
.86546 .27728 L
s
.86488 .2508 m
.86522 .24715 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17982 .24621 m
.18036 .25043 L
s
.86519 .27782 m
.86593 .28183 L
s
.86522 .24715 m
.86564 .24602 L
s
.86546 .27728 m
.86617 .2813 L
s
.17976 .27692 m
.17987 .27438 L
s
.17973 .27129 m
.17987 .27438 L
s
.17906 .28094 m
.17976 .27692 L
s
.17938 .27329 m
.17973 .27129 L
s
.17944 .24509 m
.17982 .24621 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86564 .24602 m
.86629 .24687 L
s
.17938 .27329 m
.17951 .27638 L
s
.86593 .28183 m
.86674 .28277 L
s
.86617 .2813 m
.86674 .28277 L
s
.17899 .2465 m
.17944 .24509 L
s
.17883 .24594 m
.17944 .24509 L
s
.1785 .28242 m
.17906 .28094 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86629 .24687 m
.86683 .25084 L
s
.86674 .28277 m
.86736 .28116 L
s
.17847 .25047 m
.17899 .2465 L
s
0 0 0 r
.87197 .25146 m
.87079 .25656 L
s
.255 .412 .882 r
.17791 .2808 m
.1785 .28242 L
s
.17833 .24991 m
.17883 .24594 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17467 .2357 m
.17463 .24413 L
s
.17459 .2309 m
.17467 .2357 L
s
.255 .412 .882 r
.178 .25758 m
.17847 .25047 L
s
.86736 .28116 m
.8676 .27751 L
s
.86728 .26983 m
.86733 .26673 L
s
.86728 .26983 m
.86755 .27185 L
s
.17767 .27716 m
.17791 .2808 L
s
.17752 .27661 m
.17791 .2808 L
s
0 0 0 r
.1744 .22973 m
.17459 .2309 L
s
.255 .412 .882 r
.86733 .26673 m
.86759 .26874 L
s
.17788 .25702 m
.17833 .24991 L
s
0 0 0 r
.87127 .2272 m
.87083 .2307 L
s
.17358 .28652 m
.17289 .28435 L
s
.255 .412 .882 r
.8676 .27751 m
.8677 .2713 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86927 .2365 m
.86978 .2447 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17759 .27094 m
.17767 .27716 L
s
.17778 .2627 m
.178 .25758 L
s
.86759 .26874 m
.8677 .2713 L
s
0 0 0 r
.17409 .23222 m
.1744 .22973 L
s
.17403 .23163 m
.1744 .22973 L
s
.255 .412 .882 r
.17759 .27094 m
.17778 .2627 L
s
.17745 .27039 m
.17752 .27661 L
s
.17766 .26214 m
.17788 .25702 L
s
0 0 0 r
.17337 .27334 m
.17277 .27958 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17305 .28489 m
.17636 .20851 L
s
.17289 .28435 m
.1762 .20791 L
s
.255 .412 .882 r
.17745 .27039 m
.17766 .26214 L
s
.17786 .23541 m
.17814 .23941 L
s
.86727 .23922 m
.86756 .24377 L
s
.86727 .23922 m
.86771 .24946 L
s
0 0 0 r
.17366 .23837 m
.17409 .23222 L
s
.17362 .23779 m
.17403 .23163 L
s
.17277 .27958 m
.17237 .28216 L
s
.255 .412 .882 r
.86756 .24377 m
.86771 .24946 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87116 .22837 m
.87381 .30945 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86947 .23592 m
.87333 .29836 L
s
.86978 .2447 m
.87381 .30945 L
s
.255 .412 .882 r
.86751 .24064 m
.86756 .24377 L
s
.86748 .23693 m
.86751 .24064 L
s
.17641 .27373 m
.17796 .2377 L
s
0 0 0 r
.17314 .2488 m
.17366 .23837 L
s
.255 .412 .882 r
.17637 .27318 m
.17792 .23713 L
s
.86748 .23693 m
.86753 .23464 L
s
0 0 0 r
.17237 .28216 m
.17217 .28107 L
s
.255 .412 .882 r
.86833 .26175 m
.86837 .26488 L
s
.86837 .26488 m
.86859 .27003 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17311 .24823 m
.17362 .23779 L
s
.255 .412 .882 r
.86844 .26432 m
.86848 .26745 L
s
.86833 .25806 m
.86833 .26175 L
s
.86859 .27003 m
.86877 .27206 L
s
.86844 .26064 m
.86844 .26432 L
s
0 0 0 r
.17217 .28107 m
.17217 .27627 L
s
.17217 .28107 m
.17211 .27572 L
s
.255 .412 .882 r
.86819 .2501 m
.86833 .25806 L
s
0 0 0 r
.17282 .25616 m
.17314 .2488 L
s
.255 .412 .882 r
.8683 .25268 m
.86844 .26064 L
s
0 0 0 r
.17279 .25559 m
.17311 .24823 L
s
.17238 .26778 m
.17282 .25616 L
s
.17217 .27627 m
.17238 .26778 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86877 .27206 m
.86899 .27355 L
s
.86753 .23464 m
.8676 .23607 L
s
.1763 .27154 m
.17641 .27373 L
s
0 0 0 r
.17234 .26722 m
.17279 .25559 L
s
.17211 .27572 m
.17234 .26722 L
s
.255 .412 .882 r
.86899 .27355 m
.86909 .27135 L
s
.8676 .23607 m
.86767 .23807 L
s
.86804 .24639 m
.86819 .2501 L
s
.17793 .23311 m
.17846 .22907 L
s
.86815 .24897 m
.8683 .25268 L
s
.17574 .28927 m
.17559 .29133 L
s
.17581 .28614 m
.17574 .28927 L
s
.17567 .2882 m
.17581 .28614 L
s
.86767 .23807 m
.868 .24582 L
s
.86789 .24323 m
.86804 .24639 L
s
.868 .24582 m
.86815 .24897 L
s
.17559 .29133 m
.17567 .2882 L
s
.86896 .26766 m
.86909 .27135 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17687 .25988 m
.17809 .23138 L
s
0 0 0 r
.17375 .23256 m
.17422 .22401 L
s
.17321 .24422 m
.17375 .23256 L
s
.17422 .22401 m
.17468 .21855 L
s
.17289 .25161 m
.17321 .24422 L
s
.255 .412 .882 r
.86882 .26451 m
.86896 .26766 L
s
.17694 .25932 m
.17817 .2308 L
s
0 0 0 r
.17382 .23198 m
.17431 .22342 L
s
.17327 .24364 m
.17382 .23198 L
s
.255 .412 .882 r
.86856 .25876 m
.86882 .26451 L
s
.86882 .26451 m
.86901 .26915 L
s
.86856 .25876 m
.86901 .26915 L
s
0 0 0 r
.17431 .22342 m
.17468 .21855 L
s
.17295 .25104 m
.17327 .24364 L
s
.17246 .26218 m
.17289 .25161 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17253 .26161 m
.17295 .25104 L
s
.17468 .21855 m
.17494 .21737 L
s
.255 .412 .882 r
.17672 .26453 m
.17687 .25988 L
s
.86676 .2283 m
.867 .23147 L
s
.86699 .23348 m
.867 .23147 L
s
0 0 0 r
.17228 .2685 m
.17246 .26218 L
s
.17494 .21737 m
.17508 .21989 L
s
.17494 .21737 m
.17525 .2193 L
s
.255 .412 .882 r
.86674 .23031 m
.86676 .2283 L
s
.1768 .26397 m
.17694 .25932 L
s
0 0 0 r
.17237 .26794 m
.17253 .26161 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86674 .23031 m
.86699 .23348 L
s
.17672 .26453 m
.1769 .26547 L
s
.1768 .26397 m
.1769 .26547 L
s
0 0 0 r
.17508 .21989 m
.17511 .22613 L
s
.17242 .27056 m
.17228 .2685 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17525 .2193 m
.1753 .22555 L
s
.17242 .27056 m
.17237 .26794 L
s
.255 .412 .882 r
.1769 .26547 m
.17715 .26437 L
s
.86822 .26212 m
.86889 .27783 L
s
0 0 0 r
.17511 .22613 m
.17481 .23672 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86754 .24648 m
.86901 .27837 L
s
.86754 .24648 m
.86876 .27728 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17268 .26945 m
.17242 .27056 L
s
.1753 .22555 m
.17502 .23614 L
s
.255 .412 .882 r
.86901 .27837 m
.86911 .28308 L
s
0 0 0 r
.17314 .26459 m
.17268 .26945 L
s
.17331 .26403 m
.17268 .26945 L
s
.17481 .23672 m
.17449 .24418 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86876 .27728 m
.86911 .28308 L
s
0 0 0 r
.17502 .23614 m
.17469 .24361 L
s
.17449 .24418 m
.17381 .25597 L
s
.17381 .25597 m
.17314 .26459 L
s
.17469 .24361 m
.174 .25541 L
s
.17716 .21085 m
.17927 .20669 L
s
.174 .25541 m
.17331 .26403 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17459 .28819 m
.17799 .20907 L
s
.17489 .28765 m
.1783 .20847 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18073 .20432 m
.18372 .20018 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17375 .28981 m
.17489 .28765 L
s
.17854 .28227 m
.18194 .20255 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17897 .28173 m
.18237 .20196 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1853 .24886 m
.18598 .2327 L
s
.18742 .19843 m
.18742 .19823 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17733 .28388 m
.17897 .28173 L
s
.18625 .20802 m
.18767 .19927 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18524 .21999 m
.18625 .20802 L
s
.18767 .19927 m
.18956 .19372 L
s
.18492 .2276 m
.18524 .21999 L
s
.18679 .20744 m
.18823 .19868 L
s
.18577 .21942 m
.18679 .20744 L
s
.18823 .19868 m
.18956 .19372 L
s
.18545 .22703 m
.18577 .21942 L
s
.18492 .2276 m
.18497 .23849 L
s
.18956 .19372 m
.19077 .19255 L
s
.18545 .22703 m
.18551 .23793 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85635 .25896 m
.85651 .26287 L
s
.85548 .22544 m
.85564 .22924 L
s
.85693 .26031 m
.85706 .2634 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19077 .19255 m
.19187 .1952 L
s
.19077 .19255 m
.19251 .19462 L
s
.18497 .23849 m
.18575 .24503 L
s
.18551 .23793 m
.18631 .24448 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19187 .1952 m
.19285 .20167 L
s
.18575 .24503 m
.18732 .24722 L
s
.19251 .19462 m
.19352 .2011 L
s
.18631 .24448 m
.18732 .24722 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19285 .20167 m
.19305 .21259 L
s
.19352 .2011 m
.19373 .21203 L
s
.18732 .24722 m
.18854 .24612 L
s
.19273 .22027 m
.19305 .21259 L
s
.18854 .24612 m
.18996 .24117 L
s
.18854 .24612 m
.19061 .24062 L
s
.19342 .21971 m
.19373 .21203 L
s
.19159 .23236 m
.19273 .22027 L
s
.18996 .24117 m
.19159 .23236 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19825 .18618 m
.20374 .18218 L
s
.19226 .23181 m
.19342 .21971 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19061 .24062 m
.19226 .23181 L
s
.19835 .23852 m
.20054 .18446 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19914 .23798 m
.20132 .18389 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19606 .24013 m
.19914 .23798 L
s
.255 .412 .882 r
.20427 .23232 m
.2047 .23202 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20713 .17992 m
.21351 .17601 L
s
.19961 .22633 m
.20091 .23301 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20812 .22094 m
.2098 .17824 L
s
.20904 .2204 m
.21071 .17768 L
s
.20091 .23301 m
.20326 .23531 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20326 .23531 m
.20498 .23425 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20498 .23425 m
.20691 .22928 L
s
.20498 .23425 m
.20782 .22875 L
s
.20691 .22928 m
.20812 .22094 L
s
.21741 .1738 m
.22466 .17 L
s
.20782 .22875 m
.20904 .2204 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21837 .22695 m
.22045 .17216 L
s
.21941 .22644 m
.22148 .17162 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21531 .22849 m
.21941 .22644 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23348 .16966 m
.23716 .16418 L
s
.23203 .17802 m
.23348 .16966 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23465 .16914 m
.23716 .16418 L
s
.23319 .1775 m
.23465 .16914 L
s
.255 .412 .882 r
.23287 .21434 m
.23332 .20199 L
s
0 0 0 r
.21643 .25116 m
.21762 .2467 L
s
.21643 .25116 m
.21732 .25463 L
s
.21762 .2467 m
.21851 .25016 L
s
.23716 .16418 m
.23958 .16314 L
s
.21732 .25463 m
.21851 .25016 L
s
.255 .412 .882 r
.23275 .21507 m
.23287 .21434 L
s
0 0 0 r
.23958 .16314 m
.24315 .16554 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23441 .20277 m
.23445 .20158 L
s
0 0 0 r
.23161 .22091 m
.23319 .1775 L
s
.23045 .22141 m
.23203 .17802 L
s
.5 Mabswid
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22702 .2229 m
.23161 .22091 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24315 .16554 m
.2454 .17241 L
s
.24581 .16059 m
.25099 .15858 L
s
.24388 .21606 m
.24581 .16059 L
s
.24517 .21559 m
.24709 .16008 L
s
.79632 .1671 m
.79748 .16365 L
s
.79605 .15921 m
.79748 .16365 L
s
.79487 .16266 m
.79605 .15921 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79487 .16266 m
.79632 .1671 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24009 .2175 m
.24517 .21559 L
s
.25771 .15612 m
.25882 .16356 L
s
.25718 .17197 m
.25771 .15612 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25718 .17197 m
.25882 .16356 L
s
.25882 .16356 m
.26034 .15911 L
s
.26034 .15911 m
.26327 .15419 L
s
.78402 .15876 m
.78555 .1632 L
s
.78555 .1632 m
.78594 .17512 L
s
.78107 .15384 m
.78402 .15876 L
s
.26327 .15419 m
.269 .1523 L
s
.77532 .15196 m
.78107 .15384 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79782 .21078 m
.79865 .2348 L
s
.797 .18689 m
.79733 .23434 L
s
.797 .18689 m
.79996 .23526 L
s
.78454 .17464 m
.78581 .17114 L
s
.78467 .17863 m
.78594 .17512 L
s
.78185 .17769 m
.78454 .17464 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.269 .1523 m
.2718 .15535 L
s
.78198 .18168 m
.78467 .17863 L
s
.7725 .15501 m
.77532 .15196 L
s
.25639 .19586 m
.2579 .1914 L
s
.25612 .20385 m
.25639 .19586 L
s
.2579 .1914 m
.26082 .18648 L
s
.79892 .24284 m
.79996 .23526 L
s
.25625 .19985 m
.25777 .19539 L
s
.25777 .19539 m
.26069 .19047 L
s
.77486 .18341 m
.78185 .17769 L
s
.26082 .18648 m
.26823 .17619 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78546 .2026 m
.7866 .19505 L
s
.7866 .19505 m
.78713 .21107 L
s
.25612 .20385 m
.25737 .2074 L
s
.2718 .15535 m
.27315 .15887 L
s
.77499 .18741 m
.78198 .18168 L
s
.26069 .19047 m
.26811 .18019 L
s
.79733 .23434 m
.79892 .24284 L
s
.77114 .15853 m
.7725 .15501 L
s
.25737 .2074 m
.26003 .2105 L
s
.7694 .15011 m
.77114 .15853 L
s
.7694 .15011 m
.7699 .16606 L
s
.27277 .17084 m
.27315 .15887 L
s
.26823 .17619 m
.27129 .17129 L
s
.7699 .16606 m
.77114 .15853 L
s
.78418 .20615 m
.78546 .2026 L
s
.78546 .2026 m
.78713 .21107 L
s
.26811 .18019 m
.27117 .17528 L
s
.27129 .17129 m
.2729 .16684 L
s
.27117 .17528 m
.27277 .17084 L
s
.78146 .20927 m
.78418 .20615 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26003 .2105 m
.26575 .20871 L
s
.77202 .18653 m
.77486 .18341 L
s
.77214 .19054 m
.77499 .18741 L
s
.77563 .20751 m
.78146 .20927 L
s
.2839 .15174 m
.28557 .14731 L
s
.2839 .15174 m
.28533 .15529 L
s
.28557 .14731 m
.28702 .15086 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75551 .14611 m
.76178 .14786 L
s
.26575 .20871 m
.2688 .20381 L
s
.77064 .1901 m
.77202 .18653 L
s
.27041 .19934 m
.27214 .19086 L
s
.27164 .20696 m
.27214 .19086 L
s
.28533 .15529 m
.28702 .15086 L
s
.77077 .19412 m
.77214 .19054 L
s
.2688 .20381 m
.27041 .19934 L
s
.27041 .19934 m
.27164 .20696 L
s
.77064 .1901 m
.77089 .19815 L
s
.77252 .20261 m
.77563 .20751 L
s
.77089 .19815 m
.77252 .20261 L
s
.75243 .14925 m
.75586 .15812 L
s
.74745 .14398 m
.75243 .14925 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28473 .17534 m
.28486 .22345 L
s
.28172 .22426 m
.28473 .17534 L
s
.74417 .14315 m
.74745 .14398 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75551 .14611 m
.75716 .20245 L
s
.75709 .14655 m
.75875 .20285 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74096 .14634 m
.74417 .14315 L
s
.73928 .14594 m
.74417 .14315 L
s
.7395 .15398 m
.74096 .14634 L
s
.28329 .22386 m
.28401 .19952 L
s
.73781 .15359 m
.73928 .14594 L
s
.7395 .15398 m
.74071 .19851 L
s
.75232 .20124 m
.75875 .20285 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73781 .15359 m
.73902 .19813 L
s
.28172 .22426 m
.28304 .232 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71481 .13657 m
.72545 .13879 L
s
.28304 .232 m
.28486 .22345 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31879 .17823 m
.31923 .17619 L
s
.31957 .17865 m
.31963 .17612 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73388 .19701 m
.74071 .19851 L
s
.255 .412 .882 r
.72291 .182 m
.72376 .1835 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69642 .13312 m
.70755 .13515 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70016 .13378 m
.72336 .19485 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71619 .19346 m
.7269 .19556 L
s
.70144 .19085 m
.72017 .13766 L
s
.70331 .19116 m
.72194 .13803 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68126 .13467 m
.68528 .14341 L
s
.67535 .12973 m
.68126 .13467 L
s
.68528 .14341 m
.68745 .15594 L
s
.67932 .13437 m
.68336 .14311 L
s
.67535 .12973 m
.67932 .13437 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66839 .1285 m
.66841 .12929 L
s
.5 Mabswid
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67143 .12916 m
.67535 .12973 L
s
.68336 .14311 m
.68553 .15564 L
s
.66756 .13267 m
.67143 .12916 L
s
.66557 .1324 m
.67143 .12916 L
s
.69767 .19022 m
.70888 .19213 L
s
.68745 .15594 m
.68762 .16411 L
s
.68553 .15564 m
.6857 .16381 L
s
.66373 .14029 m
.66756 .13267 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68595 .1761 m
.68762 .16411 L
s
.66173 .14003 m
.66557 .1324 L
s
.68402 .17581 m
.6857 .16381 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68224 .18374 m
.68595 .1761 L
s
.68029 .18346 m
.68402 .17581 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66908 .16561 m
.66909 .16641 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64125 .12535 m
.64943 .12628 L
s
.65994 .15204 m
.66173 .14003 L
s
.66195 .1523 m
.66373 .14029 L
s
.66195 .1523 m
.66209 .1605 L
s
.65994 .15204 m
.66008 .16025 L
s
.67645 .18703 m
.68224 .18374 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.633 .12447 m
.6372 .12899 L
s
.62884 .12406 m
.633 .12447 L
s
.67645 .18703 m
.68029 .18346 L
s
.6372 .12899 m
.64144 .13761 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66209 .1605 m
.66431 .17309 L
s
.62472 .12776 m
.62884 .12406 L
s
.62262 .12756 m
.62884 .12406 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66008 .16025 m
.66231 .17283 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67251 .18649 m
.67645 .18703 L
s
.62062 .13557 m
.62472 .12776 L
s
.66431 .17309 m
.66846 .18184 L
s
.61852 .13539 m
.62262 .12756 L
s
.66846 .18184 m
.67251 .18649 L
s
.66646 .18158 m
.67251 .18649 L
s
.66231 .17283 m
.66646 .18158 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59712 .12147 m
.60566 .12208 L
s
.61867 .14772 m
.62062 .13557 L
s
.61655 .14755 m
.61852 .13539 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58637 .12081 m
.59286 .1253 L
s
.58205 .12058 m
.58637 .12081 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61867 .14772 m
.61877 .15596 L
s
.63791 .17835 m
.64193 .1705 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57557 .12436 m
.58205 .12058 L
s
.57774 .12446 m
.58205 .12058 L
s
.59286 .1253 m
.59724 .13379 L
s
.61655 .14755 m
.61665 .15579 L
s
.57563 .13258 m
.57774 .12446 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57345 .13249 m
.57557 .12436 L
s
.55373 .11945 m
.55383 .14417 L
s
.51858 .11904 m
.55373 .11945 L
s
.61877 .15596 m
.62103 .16853 L
s
.55154 .1194 m
.55383 .14417 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61665 .15579 m
.61892 .16836 L
s
.6338 .18209 m
.63791 .17835 L
s
.62103 .16853 m
.62536 .17718 L
s
.62961 .1817 m
.6338 .18209 L
s
.61892 .16836 m
.62325 .177 L
s
.62536 .17718 m
.62961 .1817 L
s
.62325 .177 m
.62961 .1817 L
s
.255 .412 .882 r
.55889 .16412 m
.55915 .16308 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64125 .12535 m
.64255 .212 L
s
.6433 .12557 m
.64462 .21221 L
s
.255 .412 .882 r
.51241 .15741 m
.51317 .15781 L
s
.51695 .1574 m
.51753 .15779 L
s
.53714 .15786 m
.53497 .16074 L
s
.53932 .16079 m
.53714 .15786 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49575 .16227 m
.49576 .16098 L
s
.49576 .16098 m
.49639 .16265 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57345 .13249 m
.57374 .17802 L
s
.57563 .13258 m
.57593 .17812 L
s
.59712 .12147 m
.59766 .17926 L
s
.59926 .12162 m
.59982 .1794 L
s
.6363 .2114 m
.64462 .21221 L
s
.54064 .14803 m
.54071 .18126 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59117 .17888 m
.59982 .1794 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52741 .16449 m
.54067 .16461 L
s
.56716 .17777 m
.57593 .17812 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52738 .11904 m
.52743 .20626 L
s
.52518 .11903 m
.52521 .20625 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55397 .18153 m
.55407 .20663 L
s
.55186 .20658 m
.55397 .18153 L
s
.53082 .20639 m
.55407 .20663 L
s
.51854 .20626 m
.53082 .20639 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00303o
YQ09000000L0ojH@00<0[Jf]0000003oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40503oYQ4J0:f][@8000000`2][Jd:
000000d0[Jf]0`00000<0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3P
iP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@l0[Jf]1`3oYQ400`2][Jd0ojH@0?nV400@0?nV
408000002P3oYQ000`2][Jd000000000000;0?nU408000000`2][Jd200000080[Jf]1P0000070:f]
[AL0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00L0k9H>0`2][JeX0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AH0ojHA00<0[Jf]0?nV403o
YQ00403oYQ02000000X0ojH@00<0[Jf]0000000000002P3oYA02000000H0ojD@00@000000?nU4000
000000001P3oYA000`2][Jd0oj<@0?nS40020?nS40<0[Jf]0`0000030:f][@800000303oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f]
[FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@0100ojH@0P00000:0?nV40030:f][@000000000000X0ojD@0P0000060?nU4004
0000003oYA000000000000H0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000<0oj<@00<000000?nS
403oXa001@0000050:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400@0?nV408000002P3oYQ000`2][Jd0
0000000000090?nU40800000203oYA03000000H0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000D0
oj<@00@000000?nS400000000000203oXa050:f][@030000002][Jd0o:0@01L0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0
ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@0100ojH@0P00000:0?nV40030:f][@000000000000T0
ojD@0P0000080?nU40<000001P3oYA00102][Jd0oj<@0?nS403oXa02000000H0oj<@00@000000?nS
4000000000002`3oXa02000000030?bP40000000000000D0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1@2][Jd20?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400@0?nV408000002P3oYQ000`2]
[Jd0ojD@000000090?nU408000002@3oYA02000000H0ojD@00@0[Jf]0?nS403oXa00oj<@0P000007
0?nS40<000002P3oXa02000000040:f][@3lX100o:0@0?bP408000000`3lX1050:f][@<000002P3l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2]
[JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@0100ojH@0P00000:0?nV40030:f][@3oYA00
000000T0ojD@0P0000090?nU408000001P3oYA000`2][Jd0oj<@0?nS4002000000P0oj<@0`00000:
0?nS40030000003oXa00[Jf]00@0o:0@0P0000070?bP4080[Jf]100000070?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H1
0?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA00D0ojHA1P2][Jd<0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400@0?nV408000002P3oYQ000`2][Jd0ojD@000000090?nU
408000002@3oYA02000000H0ojD@00<0[Jf]0?nS403oXa000P0000090?nS408000002@3oXa020000
00030?nS402][Jd0o:0@00<0o:0@0P0000090?bP40030000003lX100o:0@00@0[Jf]0`0000000`3l
X100[Jf]0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f]
[ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@2][JdB0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400@0?nV408000002P3oYQ000`2][Jd0
ojD@000000090?nU408000002@3oYA02000000H0ojD@00<0[Jf]0?nS403oXa000P0000090?nS4080
00002@3oXa0010000000oj<@0?nS402][Jd50?bP408000002@3lX1000`000000o:0@0?bP40050?bP
40040:f][@0000000000000001D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@06
0=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@@0[Jf]5`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01/0ojHA00<0[Jf]0?nV403oYQ00403oYQ02000000X0ojH@00<0[Jf]0?nU400000002@3oYA020000
00T0ojD@0P0000060?nU40030:f][@3oXa00oj<@008000002@3oXa02000000T0oj<@00@000000?nS
403oXa00[Jf]1@3lX102000000T0o:0@00<000000?bP403lX1001P3lX1000`000000[Jf]0?JL3`04
0:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H1
0?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT
4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00403oYQ02000000X0ojH@00<0[Jf]0?nU400000002@3oYA020000
00T0ojD@0P0000060?nU40040:f][@3oXa000000000000X0oj<@0P0000090?nS40040000003oXa00
oj<@0:f][@H0o:0@0P0000080?bP40030000003lX100o:0@00D0o:0@00<000000?bP402][Jd01@3f
W0l40:f][@030?JL3`000000mY`?00X0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400@0?nV408000002P3oYQ00
0`2][Jd0ojD@000000090?nU408000002@3oYA02000000H0ojD@00@0[Jf]0?nS4000000000002P3o
Xa02000000T0oj<@00@000000?nS403oXa00[Jf]1P3lX102000000T0o:0@00<000000?bP403lX100
103lX1000`000000o:0@0:f][@080?JL3`80000000<0[Jf]0000002][Jd02@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`
h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140103o
Y1400`000000oj@A0?nT4@040:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00403oYQ02000000X0ojH@00<0
[Jf]0?nU403oYA002@3oYA02000000T0ojD@0P0000060?nU40040:f][@3oXa000000000000X0oj<@
0P0000080?nS408000000P3oXa000`2][Jd0o:0@0?bP40040?bP408000002@3lX1000`000000o:0@
0?bP40030?bP4080000000<0o:0@0:f][@3fW0l01P3fW0l2000000<0mY`?0P0000000`2][Jd00000
000000050?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V
0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3o
Y140102][Jd000000:f][@2][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0100ojH@0P0000050?nV40030000
003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA002@3oYA02000000T0ojD@0P0000060?nU40040:f]
[@3oXa000000000000X0oj<@0P0000080?nS408000000`3oXa000`2][Jd0o:0@0?bP40030?bP4080
00002P3lX1000`000000o:0@0?bP40020?bP40040000003lX100o:0@0:f][@L0mY`?0P0000050?JL
3`D000000P2][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd00`000000oj@A0000000>0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0100
ojH@0P0000050?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA002@3oYA02000000T0
ojD@0P0000060?nU40040:f][@3oXa000000000000X0oj<@0P0000080?nS408000000`3oXa000`2]
[Jd0o:0@0?bP40040?bP408000002@3lX1000`000000o:0@0?bP40020?bP40040000003lX100o:0@
0:f][@H0mY`?0P0000060?JL3`<00000103fW0l00`2][Jd000000:f][@0A0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2]
[Jd=0>nH40030:f][@3lX100o:0@00d0o:0@0P0000020:f][@@0oj@A0P00000?0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@0100ojH@0P0000050?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA002@3o
YA02000000X0ojD@0P0000050?nU40040:f][@3oXa000000000000X0oj<@0P0000080?nS40800000
0`3oXa000`2][Jd0o:0@0?bP40040?bP408000002@3lX10010000000o:0@0?bP403lX10200000080
o:0@00<0[Jf]0?JL3`3fW0l0103fW0l2000000H0mY`?0`0000050?JL3`030000003/UPh0[Jf]0080
00003P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?oo
o`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1002`3lX1020000
00030:f][@3lX100000000H0oj@A00<000000?nT4@3oY1403@3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400@0?nV
408000001@3oYQ000`000000ojH@0?nV40020?nV40030:f][@3oYA00ojD@00T0ojD@0P00000:0?nU
408000001@3oYA00102][Jd0oj<@00000000000:0?nS40800000203oXa02000000<0oj<@00<0[Jf]
0?bP403lX100103lX102000000X0o:0@00@000000?bP403lX10000000`3lX1000`2][Jd0mY`?0?JL
3`040?JL3`8000001`3fW0l2000000D0mY`?00<000000>bF3P0000000P3/UPh2000000`0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H0
0`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100203lX100
10000000[Jf]0000002][Jd30?bP40030000003oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01D0ojHA6P2][Jd2000000D0[Jf]00<0
00000:f][@2][Jd02P2][Jd40?nU408000002P3oYA02000000D0ojD@00@0[Jf]0?nS400000000000
2P3oXa02000000P0oj<@0P0000030?nS40030:f][@3lX100o:0@00@0o:0@0P00000:0?bP40040000
003lX100o:0@000000<0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l2000000L0mY`?0P0000050?JL3`80
0000103/UPh010000000[Jf]0:f][@2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP4080000000D0o:0@0:f][@00
0000o:0@000000040?bP40030:f][@000000oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@
0100ojH@0P0000050?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA001@3oYA040:f]
[@8000002P2][Jd2000000D0ojD@00@0[Jf]0?nS4000000000002P3oXa02000000P0oj<@0P000003
0?nS40030:f][@3lX100o:0@00@0o:0@0P00000:0?bP40040000003lX1000000000000<0o:0@00<0
[Jf]0?JL3`3fW0l0103fW0l2000000L0mY`?0P0000050?JL3`8000001@3/UPh00`000000k9H>0>bF
3P030:f][@030000003/UPh0k9H>00<0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P0000030:f][@030?bP40000000
000000D0o:0@00<0[Jf]0000003oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40
ojHA01D0ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@0100ojH@0P0000050?nV40030000003oYQ00
ojH@0080ojH@00<0[Jf]0?nU403oYA002@3oYA02000000X0ojD@0P0000070:f][@80000000<0[Jf]
0?nS403oXa001`3oXa02000000P0oj<@0P0000030?nS40030:f][@3lX100o:0@00@0o:0@0P00000;
0?bP40800000103lX1000`2][Jd0mY`?0?JL3`040?JL3`8000001`3fW0l2000000D0mY`?0P000005
0>bF3P030000003/UPh0k9H>00<0k9H>00<000000:f][@3/UPh00`3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2]
[Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00D0[Jf]0?bP40000000o:0@0:f][@02
000000@0o:0@0P0000050?bP40030:f][@000000oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@050:f][@3oYQ00
ojH@0?nV4011JN403P3oYQ02000000D0ojH@00<000000?nV403oYQ000P3oYQ000`2][Jd0ojD@0?nU
40090?nU408000002P3oYA02000000D0ojD@00D0[Jf]0?nS4000000000000?nS40090:f][@800000
203oXa02000000<0oj<@00<0[Jf]0?bP403lX100103lX102000000/0o:0@0P0000040?bP40030:f]
[@3fW0l0mY`?00@0mY`?0P0000070?JL3`8000001@3fW0l00`000000k9H>0>bF3P050>bF3P030000
003/UPh0k9H>0080k9H>0P0000030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd000000:f][@04000000@0o:0@0P0000050?bP40030:f][@00
0000oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0100ojH@200000040?nV40030:f][@3o
YA00ojD@00T0ojD@0P00000:0?nU408000001@3oYA000`2][Jd0oj<@0?nS4002000000T0oj<@0P00
00080:f][@8000000P3oXa000`11JN40[Jf]0?bP40050?bP408000002`3lX1000`000000o:0@0?bP
40030?bP40030:f][@3fW0l0mY`?00@0mY`?0P0000070?JL3`8000001@3fW0l00`000000k9H>0>bF
3P050>bF3P030000003/UPh0k9H>0080k9H>0P0000030>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V100
10000000[Jf]0?bP403lX103000000@0o:0@0P0000050?bP40030:f][@000000oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ405P3oYQ470:f][AL0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400@0?nV408000001@3oYQ000`000000ojH@0?nV40020?nV40030:f][@3oYA00ojD@00T0ojD@0P00
000:0?nU408000001@3oYA000`2][Jd0oj<@0?nS4002000000T0oj<@0P0000080?nS408000001`2]
[Jd30?bP408000002`3lX102000000@0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l2000000L0mY`?0P00
00050?JL3`030000003/UPh0k9H>00D0k9H>00<000000>bF3P3/UPh00P3/UPh00`000000k9H>0>bF
3P030>bF3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H2
0:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@040000003lX100o:0@0?bP40<00000103l
X1000`000000o:0@0?bP40040?bP40800000503oY1400`2][Jd0ojHA0?nV4@0@0?nV4@H0[Jf]0P3o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00403o
YQ02000000D0ojH@00<000000?nV403oYQ000P3oYQ000`2][Jd0ojD@0?nU40090?nU408000002P3o
YA02000000D0ojD@00<0[Jf]0?nS403oXa000P0000090?nS408000002@3oXa0200000080oj<@00@0
[Jf]0?bP403lX100o:0@0`2][Jd2000000030:f][@3lX100o:0@00L0o:0@0`0000040?bP40030:f]
[@3fW0l0mY`?00@0mY`?0P0000070?JL3`8000001@3fW0l00`2][Jd0k9H>0>bF3P050>bF3P030000
003/UPh0k9H>00P0k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;
00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_
V100kiP@00@0kiP@00<000000>nH400000000P2][Jd00`3_V1000000000000040?bP40800000103l
X1000`000000o:0@0?bP40040?bP40800000503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00403o
YQ02000000D0ojH@00<000000?nV403oYQ000P3oYQ000`2][Jd0ojD@0?nU40090?nU408000002P3o
YA02000000D0ojD@00<0[Jf]0?nS403oXa000P00000:0?nS40800000203oXa0200000080oj<@00<0
[Jf]0?bP403lX100103lX102000000030?bP402][Jd0[Jf]00D0[Jf]0P3lX10010000000o:0@0?bP
400000030?bP40030:f][@3fW0l0mY`?00@0mY`?0P0000070?JL3`8000001@3fW0l00`2][Jd0k9H>
0>bF3P050>bF3P030000003/UPh0k9H>00P0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][@L0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2G
H0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V102000000060:f][@3_V100kiP@0>nH4000
0000[Jf]103lX102000000@0o:0@00<000000?bP403lX100103lX1000`000000oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA00H0ojHA1@2][Jd=0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400@0?nV408000001@3oYQ000`000000ojH@0?nV40020?nV
40030:f][@3oYA00ojD@00T0ojD@0P00000:0?nU408000001@3oYA00102][Jd0oj<@0?nS403oXa02
000000P0oj<@0`0000080?nS408000000P3oXa000`2][Jd0o:0@0?bP40040?bP40800000203lX100
0`2][Jd00000000000020:f][@050000003lX100o:0@0?bP402][Jd01P3fW0l2000000L0mY`?0P00
00050?JL3`030:f][@3/UPh0k9H>00D0k9H>00<000000>bF3P3/UPh0203/UPh00`2][Jd0fhX=0=^:
3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF
1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100
0P3_V103000000D0kiP@00<000000:f][@3lX1000`3lX102000000X0o:0@0P0000060?nT4@030000
003oY140oj@A00`0oj@A00<0[Jf]0?nV4@3oYQ401P2][JdB0?nV4@030:f][@3oYQ40ojHA01T0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400@0?nV408000001@3oYQ000`000000ojH@
0?nV40020?nV40030:f][@3oYA00ojD@00T0ojD@0P00000:0?nU408000001@3oYA00102][Jd0oj<@
0?nS403oXa02000000P0oj<@0`0000080?nS408000000P3oXa000`2][Jd0o:0@0?bP40040?bP4080
00002@3lX10200000080o:0@00<000000:f][@2][Jd00`2][Jd50?JL3`8000001`3fW0l2000000D0
mY`?00<0[Jf]0>bF3P3/UPh01@3/UPh00`000000k9H>0>bF3P080>bF3P030:f][@3KRPd0fhX=00D0
fhX=0P2][Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3P
iP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h01@2][Jd0kiP@0>nH40000000
kiP@0080[Jf]00<000000>nH403_V1000`3_V1000`000000[Jf]0?bP40030?bP408000002P3lX102
000000H0oj@A00<000000?nT4@3oY1402`3oY1440:f][AP0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0100ojH@0P0000050?nV40030000003oYQ00
ojH@0080ojH@00<0[Jf]0?nU403oYA002@3oYA02000000X0ojD@0P0000050?nU40030:f][@3oXa00
oj<@0080oj<@0P0000060?nS40040000003oXa000000000000T0oj<@0P0000000`3oXa00[Jf]0?bP
40050?bP408000002@3lX1000`000000o:0@0?bP40020?bP40050000003lX100o:0@0:f][@3fW0l0
102][Jd00`3fW0l00000000000080?JL3`800000103fW0l00`2][Jd0k9H>0>bF3P040>bF3P800000
2P3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f]
[@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0
dhL>00<0[Jf]0000000000000P2][Jd20>nH40030000003_V100kiP@00<0kiP@00<000000:f][@3l
X1000`3lX102000000T0o:0@0P0000000`2][Jd0oj@A0?nT4@040?nT4@030000003oY140oj@A00L0
oj@A102][Jd00`3oY140[Jf]0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400@0?nV408000001@3oYQ000`000000ojH@0?nV40020?nV4003
0:f][@3oYA00ojD@00D0ojD@1P0000060?nU40H000001@3oYA000`2][Jd0oj<@0?nS40030?nS4080
00001@3oXa0010000000oj<@0000000000090?nS4080000000<0oj<@0:f][@3lX100103lX1020000
00T0o:0@0P0000040?bP40040000003lX100o:0@0:f][@D0mY`?0P2][Jd2000000L0mY`?0P000004
0?JL3`030:f][@3/UPh0k9H>00<0k9H>00<000000>bF3P0000002P3/UPh00`2][Jd0fhX=0=^:3@09
0=^:3@<0[Jf]2@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool0
05T0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030000002][Jd00000
00@0kiP@00<000000>nH403_V1000`3_V1000`000000[Jf]0?bP40030?bP40800000203lX1001000
0000o:0@0000002][Jd60?nT4@030000003oY140oj@A00<0oj@A102][Jd50?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@0100ojH@0P0000050?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU40000000703oYA00
0`2][Jd0oj<@0?nS40040?nS408000000`3oXa000`000000oj<@0?nS4002000000X0oj<@0P000000
0`2][Jd0o:0@0?bP40030?bP408000002@3lX102000000@0o:0@00@000000?bP403lX100[Jf]1`3f
W0l2000000@0[Jf]0`3fW0l2000000@0mY`?00@0[Jf]0>bF3P3/UPh0k9H>1000000;0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040000
002][Jd0kiP@000000@0kiP@00<000000>nH403_V1000`3_V1000`000000[Jf]0?bP40030?bP4080
0000203lX102000000030?bP402][Jd0oj@A00D0oj@A00<000000?nT4@3oY1400`2][Jd90?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@0100ojH@0P00000:0?nV40030:f][@3oYA00000001`0ojD@00<0[Jf]0?nS403o
Xa001P3oXa03000000<0oj<@0P00000;0?nS40030000002][Jd0o:0@00<0o:0@0P00000:0?bP4003
0000003lX100o:0@00@0o:0@00<000000?bP402][Jd01`3fW0l2000000@0mY`?0`2][Jd2000000@0
mY`?00H0[Jf]0>bF3P3/UPh000000>bF3P00000=0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd8
0;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P0000020:f][@030>nH40000000kiP@00<0kiP@00<00000
0>nH403_V1000`3_V1000`000000o:0@0?bP40030?bP408000001`3lX10200000080o:0@00<0[Jf]
0?nT4@3oY1400`3oY140102][Jd000000:f][@2][Jd<0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@0100ojH@0P00
000:0?nV40030:f][@3oYA00000001`0ojD@00<0[Jf]0?nS403oXa00303oXa02000000`0oj<@00@0
00000?bP403lX100o:0@0`0000090?bP408000001P3lX1000`000000o:0@0:f][@070?JL3`800000
1`3fW0l2000000<0[Jf]00H0mY`?0:f][@3/UPh000000>bF3P00000>0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0
/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80000000D0[Jf]
0=>73P2][Jd0kiP@000000040>nH40030000003_V100kiP@00<0kiP@00<000000?bP403lX1000`3l
X102000000H0o:0@00<000000?bP400000000P3lX1000`2][Jd0oj@A0:f][@030:f][@030?nT4@00
0000oj@A00d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00403oYQ02000000X0ojH@00<0[Jf]0?nU40000000703o
YA000`2][Jd0oj<@0?nS400<0?nS40800000303oXa000`2][Jd0000000000002000000/0o:0@0P00
00070?bP40030000002][Jd0mY`?00H0mY`?0P0000070?JL3`8000000`3fW0l20:f][@030000003/
UPh0000000X0k9H>00<000000>bF3P3/UPh00P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2i
M@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P070:f][@000000dhL>0=>73P2]
[Jd0kiP@000000040>nH40030000003_V100kiP@00<0kiP@00<000000?bP403lX1000`3lX1000`00
0000o:0@0?bP40040?bP40030000003lX10000000080o:0@0`2][Jd40?nT4@8000003P3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400@0?nV408000002P3oYQ000`2][Jd0ojD@0000000L0?nU40030:f][@3oXa00oj<@
00`0oj<@0P00000<0?nS40030:f][@3lX100o:0@00`0o:0@0P0000080?bP40030000002][Jd0mY`?
00H0mY`?0P0000070?JL3`800000103fW0l00`2][Jd00000000000020:f][@T0k9H>00<000000>bF
3P3/UPh00P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue
2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;09MP2`2GH0/0[Jf]00@0dhL>00<0[Jf]0=>73P0000000P3CQ`h00`2][Jd0kiP@000000040>nH
40030000003_V100kiP@00<0kiP@00<000000?bP403lX1000`3lX1000`000000o:0@0?bP40030?bP
40030000003lX100000000<0[Jf]00<0o:0@0:f][@000000103oY142000000h0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00403oYQ02000000X0ojH@00<0[Jf]0?nU40000000703oYA000`2][Jd0oj<@0?nS400<0?nS
40800000303oXa000`2][Jd0o:0@0?bP400:0?bP40@00000203lX1000`000000[Jf]0?JL3`060?JL
3`8000001`3fW0l2000000@0mY`?00<0[Jf]0000003/UPh00P3/UPh20:f][@L0k9H>00<000000>bF
3P3/UPh00P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0[Jf]0;Ue
2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]0080000000D0dhL>0:f][@3CQ`h0dhL>000000020=>73P030:f][@3_V100000000@0kiP@00<0
00000>nH403_V1000`3_V1000`000000o:0@0?bP40030?bP40030000003lX100o:0@00<0o:0@0P00
00000`2][Jd0o:0@0?bP40020?bP40030:f][@000000oj@A00<0oj@A0P00000>0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@0100ojH@0P00000:0?nV40030:f][@3oYA00000001`0ojD@00<0[Jf]0?nS403oXa00303o
Xa02000000`0oj<@00<0[Jf]0?bP403lX1003@3lX104000000<0o:0@100000070?JL3`8000001`3f
W0l2000000@0mY`?00<0[Jf]0000003/UPh0103/UPh30:f][@@0k9H>00<000000>bF3P3/UPh00P3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF
1`0308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0202][Jd0Uf0;09MP2`2GH0/0[Jf]0000002][Jd0
00000`3CQ`h01P000000dhL>0=>73P2][Jd0kiP@000000@0kiP@00<000000>nH403_V1000`3_V100
0`000000o:0@0?bP40030?bP40040000003lX100o:0@0?bP4080[Jf]00<000000?bP403lX100103l
X102000000@0oj@A0P00000>0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0E0?nV4AX0[Jf]0P00000;0:f][@8000001@2][JdG0?nU40030:f][@3o
Xa00oj<@00`0oj<@0P00000<0?nS40030:f][@3lX100o:0@01L0o:0@0`0000050?JL3`8000001`3f
W0l2000000@0mY`?00<0[Jf]0000003/UPh01P3/UPh01P000000[Jf]0:f][@2][Jd0k9H>000000@0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL20:f][D80
/>3V0@3oool005T0/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@000000dhL>000000<0dhL>00H00000
0=>73P3CQ`h0[Jf]0>nH400000040>nH40030000003_V100kiP@00<0kiP@00<000000?bP403lX100
0`3lX10010000000[Jf]0:f][@2][Jd20?bP40030000003lX100o:0@00@0o:0@0P0000040?nT4@80
00003P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ00403oYQ02000000X0ojH@00<0[Jf]00000000
00001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa00303oXa02000000`0oj<@00<0[Jf]0?bP403l
X100603lX100102][Jd0mY`?0?JL3`3fW0l2000000030?JL3`000000000000L0mY`?0P0000040?JL
3`030:f][@000000k9H>00H0k9H>00H000000>bF3P3/UPh0k9H>0:f][@0000040>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`
h>H0/>3V0400/>3V0@3oool005T0/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@000000dhL>000000<0
dhL>00H000000=>73P3CQ`h0[Jf]0>nH400000030>nH40800000103_V102000000@0o:0@00<0[Jf]
0000003lX100103lX1000`000000o:0@0?bP40040?bP40030000003oY140oj@A00<0oj@A0P00000>
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AL0ojHA00<0[Jf]
0?nV403oYQ00403oYQ02000000X0ojH@00<0[Jf]0000000000005@3oYA0<0:f][@X0oj<@0P00000<
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l3000000L0mY`?0P000004
0?JL3`030:f][@000000k9H>00D0k9H>0P0000040>bF3P060000002][Jd0[Jf]0:f][@3/UPh0[Jf]
3P3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo
001I0;3PiP080:f][@2GH0/0Uf0;0000002][Jd000000=>73P0000030=>73P050000003CQ`h0[Jf]
0>nH40000000103_V1000`000000kiP@0>nH40030>nH40030000002][Jd0@FWQ00<0[Jf]00<0o:0@
0000003lX100103lX1000`000000o:0@0?bP40040?bP40030000003oY140oj@A00<0oj@A0P00000>
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400@0?nV408000002P3oYQ000`2][Jd000000000000L
0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd2000000`0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0;0?JL3`@00000103fW0l00`2][Jd000000>bF3P050>bF3P800000103/UPh0
10000000k9H>0>bF3P3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;0000002][Jd2000000030=>73P00
0000dhL>0080dhL>00D000000=>73P2][Jd0kiP@000000040>nH40030000003_V100kiP@00<0kiP@
00<000000:f][@2][Jd0103lX1000`000000o:0@0?bP40030?bP40030000003lX100o:0@00<0o:0@
0P0000050?nT4@8000003P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA
2P2][Jd>0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00403oYQ02000000X0ojH@
00<0[Jf]000000000000703oYA000`2][Jd0oj<@0?nS400<0?nS40800000202][Jd40?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03@3fW0l2000000@0mY`?00<0[Jf]0>bF3P000000
1@3/UPh2000000@0k9H>00<000000>bF3P3/UPh00P3/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@03
0:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40
oooo001I0;3PiP050:f][@000000000009MP2`0000000P3CQ`h02@000000dhL>0=>73P3CQ`h00000
0=>73P2][Jd0kiP@000000040>nH40030000003_V100kiP@0080kiP@00<0[Jf]0000002][Jd01@3l
X1000`000000o:0@0?bP40030?bP40030000003lX100o:0@00<0o:0@0P0000050?nT4@8000003P3o
Y1400`2][Jd0ojHA0?nV4@0D0?nV4@P0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@0100ojH@0P00000:0?nV40030:f][@000000000001`0ojD@00<0[Jf]0?nS403oXa00303o
Xa02000000P0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P000000103/
UPh3000000@0k9H>00<000000>bF3P3/UPh00P3/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`2][Jd208QF1`030:f][@2`h>H0/>3V0400
/>3V0@3oool005P0/>3V0P000000102GH0/0000009MP2`0000020=>73P090000003CQ`h0dhL>0=>7
3P000000dhL>0:f][@3_V100000000@0kiP@00<000000>nH403_V1000P2][Jd00`3_V10000000:f]
[@050?bP40030000003lX100o:0@00<0o:0@00<000000?bP403lX1000P3lX1000`000000[Jf]0000
00050?nT4@8000003P3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00303oYQ0C000001`0ojD@00<0
[Jf]0?nS403oXa00303oXa02000000`0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00@0[Jf]0>bF3P00000000000P3/UPh3000000@0k9H>00<000000>bF3P3/
UPh00P3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`07
0:f][@28EPL0R5H708QF1`2][Jd0R5H70:f][@120;3PiP40oooo001H0;3PiP80000000@0[Jf]0000
002GH0/000000P3CQ`h200000080dhL>00D000000=>73P2][Jd0kiP@000000040>nH40030000002]
[Jd0[Jf]00<0kiP@00<000000:f][@3lX100103lX1000`000000o:0@0?bP40040?bP40060000003l
X100o:0@0000003lX100[Jf]1P3oY142000000h0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40800000303oXa000`2][Jd0
o:0@0?bP40080?bP40H0[Jf]2P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`040:f][@3/UPh0k9H>0>bF
3P8000000P3/UPh00`000000k9H>0>bF3P020>bF3P030000003/UPh0k9H>0080k9H>00<0[Jf]0=^:
3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0R5H708QF1`28EPL0
[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F02`h>H2000000040:f][@000000Uf0;00000080dhL>0P00
00020=>73P050000003CQ`h0[Jf]0>nH400000000`3_V1000`2][Jd000000>nH40040>nH40030000
002][Jd0o:0@00@0o:0@00<000000?bP403lX1001@3lX10200000080o:0@00<0[Jf]0?nT4@3oY140
103oY142000000h0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa002@3oXa02000000030?nS40000000000000`0oj<@00<0[Jf]0?bP403l
X1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P050>bF3P03
0000003/UPh0k9H>0080k9H>00<000000>bF3P3/UPh00P3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80
[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40
oooo001H0;3PiP80000000@0Uf0;0000002GH0/000000P3CQ`h2000000080=>73P000000dhL>0=>7
3P2][Jd0kiP@0000003_V1020:f][@030>nH40000000kiP@00@0kiP@00<000000:f][@3lX100103l
X1000`000000o:0@0?bP40090?bP40030:f][@3oY140oj@A00<0oj@A0`00000=0?nT4@D0[Jf]5P3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@0`00000<0?nS40030:f][@3l
X100o:0@01D0o:0@1P2][JdD0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P0000030>bF3P030:f][@3K
RPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`070;Ue2`030:f][@28EPL0R5H700<0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F02`h>H20000000409MP2`000000000000000080dhL>0P00
0000203CQ`h000000=>73P3CQ`h0[Jf]0>nH40000000[Jf]0`3_V1000`000000kiP@0>nH40030>nH
40030000002][Jd0o:0@00@0o:0@00<000000?bP403lX1002@3lX1000`2][Jd0oj@A0?nT4@030?nT
4@<000002@3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0102][Jd@0?JL
3`030:f][@3/UPh0k9H>00X0k9H>0P0000030>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000@0Uf0;00000000
000000000P3CQ`h010000000dhL>0=>73P0000020=>73P80[Jf]00<000000>nH403_V1000P3_V100
0`000000kiP@0>nH40030>nH40030000002][Jd0o:0@0080o:0@0`00000;0?bP40030:f][@3oY140
oj@A00<0oj@A0`0000050?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?00@0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P0000030>bF3P030:f][@3KRPd0
fhX=00`0fhX=0P2][Jd80;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3P
iP<0000000@0Uf0;00000000000000000P3CQ`h01@000000dhL>0=>73P000000dhL>0080[Jf]00<0
kiP@0000003_V1000`3_V1000`000000kiP@0>nH40030>nH40030000002][Jd0o:0@0100o:0@00<0
[Jf]0?nT4@3oY1400`3oY143000000030?nT4@2][Jd0[Jf]0080[Jf]2@3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>00X0k9H>0P00
00030>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H7
08QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000409MP2`000000000000000080dhL>
00T000000=>73P3CQ`h000000:f][@3CQ`h0[Jf]0>nH40000000103_V1000`000000kiP@0>nH4003
0>nH40030000002][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1400`3oY143000000030:f][@3oY140
oj@A00/0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`@0[Jf]0P3fW0l0
0`2][Jd0k9H>0>bF3P0:0>bF3P800000103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0
^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H4
0000000309MP2`000000[Jf]0080dhL>00@000000=>73P3CQ`h000000P3CQ`h00`2][Jd0kiP@0000
00040>nH40040000003_V100kiP@0>nH4080000000<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A
0:f][@030:f][@<000003P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?
102][Jd;0>bF3P800000103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;
00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H40000000309MP2`000000[Jf]0080dhL>00@000000:f][@2][Jd000000P3CQ`h00`2][Jd00000
000000040>nH40030000003_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][@@0oj@A
00<000000?nT4@0000003P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P2][Jd00P2][Jd80>bF3P800000103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00<0^GD;00D0[Jf]0;Ue2`2iM@/0@FWQ0:f][@0408QF1`80[Jf]@@2`h>H10?ooo`00
E`2`h>H40000000409MP2`000000[Jf]0=>73P8000000P3CQ`h010000000dhL>0=>73P2][Jd20000
00@0kiP@00<000000>nH403_V100103_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f]
[@3oY140103oY1400`000000oj@A0000000>0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]1P3/UPh2000000@0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f]
[@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V0P0000001P2][Jd0000009MP2`000000[Jf]
0=>73P8000000P3CQ`h010000000dhL>0=>73P2][Jd200000080kiP@0P0000070>nH40030:f][@3l
X100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A00<0oj@A0P00000?0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]0`3/
UPh2000000@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028
EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V0P000000102][Jd0000009MP2`00
00020:f][@8000000P3CQ`h2000000030=>73P2][Jd0000000`0kiP@00<0[Jf]0?bP403lX1001`3l
X1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140103oY1400`000000oj@A0?nT4@0=0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]0P00
00040>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF
1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H20000000609MP2`000000
Uf0;0000002][Jd0dhL>0P0000020=>73P80000000<0dhL>000000000000303_V1000`2][Jd0o:0@
0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@040?nT4@030000003oY140oj@A00`0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA
;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P0000040>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo
001G0;3PiP80000000H0Uf0;0000002GH0/000000:f][@3CQ`h200000080dhL>00@000000=>73P00
000000003@3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@
0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P0000030:f][@030>bF3P2][Jd0
fhX=00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@<0R5H700<0[Jf]000000000000@02`h>H1
0?ooo`00E`2`h>H20000000709MP2`000000Uf0;0000002][Jd0dhL>000000030=>73P030000003C
Q`h0[Jf]00h0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P800000
0`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f]
[@00000000000400/>3V0@3oool005H0/>3V0`0000001`2GH0/000000:f][@000000[Jf]0=>73P00
00000`3CQ`h00`000000dhL>0:f][@0=0>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80
0000103/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF
1`2][Jd00P28EPL00`2][Jd00000000000100;3PiP40oooo001F0;3PiP<0000000L0Uf0;0000002G
H0/000000:f][@3CQ`h000000080dhL>00@000000=>73P3CQ`h0[Jf]2`3_V1020:f][@030>nH402]
[Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3o
YQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00/0k9H>00<000000>bF3P3/UPh00P3/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/01P2][Jd0R5H708QF1`2][Jd0R5H70:f][@800000@02`h>H10?oo
o`00EP2`h>H30000000709MP2`000000Uf0;045Yh@000000dhL>000000050=>73P030:f][@3_V100
kiP@00L0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l0
0`2][Jd0k9H>0>bF3P0:0>bF3P030000003/UPh0k9H>0080k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2
0:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000@02`
h>H10?ooo`00EP2`h>H3000000040:f][@000000Uf0;045Yh@8000001P3CQ`h00`2][Jd0kiP@0>nH
40050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P0000100;3PiP40oooo001F0;3PiP<0000000@0
[Jf]0000002GH0/0@FWQ0P0000060=>73P030:f][@3_V100kiP@00<0kiP@00<0[Jf]0000003_V100
1P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f]
[@28EPL0R5H70080R5H700<0[Jf]000000000000@02`h>H10?ooo`00EP2`h>H30000000509MP2`00
0000Uf0;045Yh@2][Jd01`3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@030>nH40000000kiP@00H0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV
4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`080;Ue2`050:f][@28EPL0R5H7
08QF1`2][Jd00P0000100;3PiP40oooo001F0;3PiP<0000000@0Uf0;0000002GH0/0[Jf]203CQ`h0
102][Jd0kiP@0:f][@2][Jd30>nH408000001P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00/0fhX=0P2][Jd90;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P0000100;3PiP40oooo
001F0;3PiP<0000000@0Uf0;0000002GH0/0[Jf]203CQ`h20:f][@D0kiP@00<000000>nH403_V100
1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]
403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd70;Ue2`050:f]
[@28EPL0R5H708QF1`2][Jd00P0000100;3PiP40oooo001F0;3PiP<0000000@0Uf0;0000002GH0/0
[Jf]1`3CQ`h20:f][@H0kiP@00<000000>nH403_V1001@3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2iM@/01@2][Jd0R5H708QF1`28EPL0
[Jf]00800000@02`h>H10?ooo`00EP2`h>H30000000409MP2`000000Uf0;0:f][@D0dhL>0P2][Jd0
0`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY145
0:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
1@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@0200000400/>3V
0@3oool005H0/>3V0`000000102GH0/0000009MP2`2][Jd40=>73P050:f][@3CQ`h0dhL>0=>73P2]
[Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080
^GD;0P2][Jd30;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P0000100;3PiP40oooo001F0;3PiP<0
000000@0Uf0;0000002GH0/0[Jf]0`3CQ`h00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/0102][Jd0^GD;0;Ue2`2][Jd308QF1`030:f][@000000
00000400/>3V0@3oool005H0/>3V1000000209MP2`040:f][@3CQ`h0[Jf]0:f][@D0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0[Jf]0`28EPL00`2][Jd0@FWQ00000010
0;3PiP40oooo001F0;3PiP@000000P2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`02
08QF1`030:f][@000000/>3V03l0/>3V0@3oool005H0/>3V00@000000:f][@00000000000P2GH0/0
0`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX103
0:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd000000;3PiP0o0;3PiP40oooo001F0;3P
iP80000000<0Uf0;0000002GH0/00P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f]
[@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2]
[Jd000000;3PiP0o0;3PiP40oooo001F0;3PiP80000000<0Uf0;0000002GH0/00P2][Jd80=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i
/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0
[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080
R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H20000000509MP2`000000[Jf]09MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0
^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`03
0:f][@28EPL0[Jf]0080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H20000000509MP
2`000000Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000001@2G
H0/0000009MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001F0;3PiP80000000D0[Jf]
0000002GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H2000000050:f][@00
0000Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2aZid0
/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0
/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V1000000209MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080
/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f][@2][Jd30=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000000000o0;3P
iP40oooo001F0;3PiP8000000`2GH0/00`2][Jd0dhL>0=>73P070=>73P040:f][@3_V100[Jf]0:f]
[@H0Y9j?00<0[Jf]0;6[W@2aZid0102aZid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd7
0;ji^0<0@FWQ00H0];2a045Yh@2][Jd0[Jf]0=^:3@2][Jd:0;Ue2`050:f][@28EPL0R5H708QF1`2]
[Jd00P00000o0;3PiP40oooo001G0;3PiP050000002GH0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@P0
Y9j?00<0[Jf]0;6[W@2aZid01P2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]202n^KP00`11
JN40_[Vh0:f][@03045Yh@80];2a0P2][Jd:0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P00000o
0;3PiP40oooo001G0;3PiP050000002GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0Y9j?0:BNS`08
0:BNS`030:f][@2aZid0/J^M00P0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]2P2n^KP0
1011JN40_[Vh0:f][@2d/;42045Yh@80];2a0P11JN420:f][@P0^GD;00D0[Jf]08QF1`28EPL0R5H7
0:f][@02000003l0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]
2`2TWXl0102][Jd0/J^M0;6[W@2aZid3045Yh@H0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m
^`<0[Jf]00<0`kfk0:f][@2n^KP02P2n^KP01011JN40_[Vh0:f][@2d/;42045Yh@80];2a0P11JN42
0;B`/@030:f][@2iM@/0^GD;00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3P
iP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h30:f][@X0Y9j?00<0
[Jf]0;6[W@2aZid0102aZid2045Yh@H0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`
h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh0080_[Vh00<0@FWQ0;ji^02n^KP0102n
^KP01011JN40_[Vh0;ji^02][Jd2045Yh@80];2a0P11JN420;B`/@03045Yh@2][Jd0[Jf]00D0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0RXEe08Z5M@2][Jd:0:BNS`030:f][@2aZid0/J^M
00@0/J^M00@0@FWQ0;6[W@11JN40@FWQ102aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<9
0:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^002045Yh@L0_[Vh00@0@FWQ
0;ji^02n^KP0[Jf]0P11JN420;B`/@80@FWQ0P2d/;400`11JN40[Jf]0:f][@020:f][@<0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd00`3CQ`h0102][Jd0RXEe08Z5M@2:QGD30:f][@P0Y9j?00<0[Jf]0;6[W@2a
Zid0102aZid01@11JN40/J^M0;6[W@2aZid0@FWQ00<0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f]
[@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k
0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]
0080[Jf]2`33_K/00`2][Jd0_[Vh045Yh@02045Yh@L0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0P11JN42
0;B`/@80@FWQ00P0];2a0:f][@11JN40];2a0:f][@2OVj00@FWQ0:f][@80^GD;00@0[Jf]08QF1`28
EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP
2`2][Jd0dhL>0P2][Jd408Z5M@040:f][@2TWXl0Y9j?0:f][@L0Y9j?00<0[Jf]0;6[W@2aZid0102a
Zid01011JN40/J^M0;6[W@2aZid2045Yh@80/J^M00<0[Jf]045Yh@2i/ZH02@2i/ZH40:f][@030;Vb
YP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@`0`kfk0P11JN400`2][Jd0_[Vh
0;ji^002045Yh@L0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0P11JN420;B`/@80@FWQ00H0[Jf]0;B`/@11
JN40];2a0:f][@2OVj02045Yh@<0[Jf]1028EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001F0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd00`2:QGD0@FWQ08Z5M@0308Z5M@040:f][@2TWXl0Y9j?
0:BNS`80[Jf]1@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@03045Yh@2aZid0/J^M0080/J^M00D0@FWQ
0;6[W@2aZid0[Jf]0;VbYP02045Yh@`0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2]
[Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`080<>m^`80@FWQ0P33
_K/2045Yh@030:f][@2n^KP0_[Vh0080@FWQ1`2n^KP02011JN40_[Vh0;ji^02][Jd0];2a045Yh@2d
/;40[Jf]0P11JN420;B`/@05045Yh@2d/;40[Jf]09nKX011JN400`2OVj000`2][Jd0R5H708QF1`02
08QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/0102]
[Jd0RXEe08Z5M@11JN4408Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd30:BNS`030:f][@2aZid0
/J^M00@0/J^M00<0@FWQ0;6[W@2aZid00P2aZid01@11JN40/J^M0;6[W@2][Jd0^K:V00@0@FWQ2`2i
/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0
[Jf]0<>m^`33_K/01P33_K/00`11JN40`kfk0<>m^`04045Yh@030:f][@2n^KP0_[Vh0080@FWQ1`2n
^KP2045Yh@060;ji^02][Jd0];2a045Yh@2][Jd0];2a0P11JN401`2d/;40@FWQ045Yh@2d/;40[Jf]
09nKX011JN40102OVj001P2][Jd0R5H708QF1`28EPL0[Jf]000003l0/>3V0@3oool005H0/>3V00@0
[Jf]09MP2`2GH0/0Uf0;0P2][Jd208Z5M@03045Yh@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl0
1@2TWXl0102][Jd0Y9j?0:BNS`2][Jd60;6[W@03045Yh@2aZid0/J^M0080/J^M00D0@FWQ0;6[W@2a
Zid0[Jf]0;VbYP02045Yh@d0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j
/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/01@33_K/2045Yh@<0`kfk0`11JN400`33
_K/0[Jf]0;ji^002045Yh@P0_[Vh1@11JN420;B`/@80@FWQ00L0];2a045Yh@11JN40];2a0:f][@2O
Vj00@FWQ00@0Wi^P00H0[Jf]08QF1`28EPL0R5H70:f][@00000o0;3PiP40oooo001F0;3PiP040:f]
[@2GH0/0Uf0;09MP2`80[Jf]0P2:QGD00`11JN40RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00H0
Y9j?0`2][Jd60;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN400`2aZid0[Jf]0;VbYP02045Yh@d0
^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0
`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_003
0:f][@33_K/0`kfk00D0`kfk0P11JN440<>m^`80@FWQ00<0`kfk0:f][@2n^KP00P11JN490;ji^080
[Jf]00@0];2a045Yh@2d/;40];2a0P11JN401`2d/;40@FWQ0;B`/@2d/;40[Jf]09nKX011JN40102O
Vj001P11JN40[Jf]08QF1`28EPL0[Jf]000003l0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/0
0`2][Jd208Z5M@03045Yh@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl0202TWXl20:f][@D0/J^M
00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@030;6[W@2][Jd0^K:V0080@FWQ2@2i/ZH5045Yh@d0_[N/
102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
3`37`K`40:f][A00a/2l00<0@FWQ0:f][@33_K/01@33_K/2045Yh@D0`kfk0P11JN400`33_K/0[Jf]
0;ji^002045Yh@L0_[Vh0P2][Jd0102n^KP0[Jf]0;B`/@11JN420;B`/@@0@FWQ0P2d/;400`2][Jd0
Wi^P045Yh@0509nKX080[Jf]00<0R5H70:f][@000000?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;
0:f][@1SH5<20:f][@80RXEe00D0@FWQ08Z5M@2:QGD0RXEe0:f][@0;0:BNS`040:f][@2aZid0[Jf]
0:f][@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@030;6[W@2][Jd0^K:V0080@FWQ2@2i/ZH2
045Yh@80^K:V00<0@FWQ0;jg[02n]j`03`2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00:0<K0_003045Yh@36`;`0
a/2l0080a/2l00<0@FWQ0:f][@33_K/01@33_K/2045Yh@D0`kfk0P11JN400`33_K/0[Jf]0;ji^002
045Yh@D0_[Vh0P2][Jd30;ji^0030:f][@2d/;40@FWQ0080];2a0P11JN440;B`/@030:f][@2OVj00
@FWQ00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00@0[Jf]
08Z5M@2:QGD0@FWQ0`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`040:f][@2aZid0/J^M0;6[W@<0[Jf]
00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@030;6[W@2][Jd0^K:V0080@FWQ202i/ZH2045Yh@<0^K:V
00<0[Jf]045Yh@2n]j`00`11JN4=0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00X0a/2l
00<0@FWQ0<K0_036`;`00P36`;`00`11JN40[Jf]0<>m^`050<>m^`03045Yh@33_K/0`kfk00@0`kfk
0P11JN401@33_K/0[Jf]0;ji^02n^KP0@FWQ0080_[Vh0`2][Jd20;ji^080@FWQ00<0_[Vh0:f][@11
JN400P2d/;42045Yh@D0];2a00<0[Jf]09nKX011JN40102OVj020:f][@03071^N@2][Jd0[Jf]0400
/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]00<0RXEe045Yh@2:QGD00P2:QGD00`2][Jd0Y9j?
0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M00<0@FWQ0:f][@2aZid00`2aZid01011JN40/J^M
0:f][@2i/ZH2045Yh@P0^K:V0P11JN430;VbYP040:f][@11JN40@FWQ045Yh@H0_[N/00<0@FWQ0;jg
[02n]j`01P2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0_0040<K0_080@FWQ1036`;`00`11
JN40a/2l0<K0_0020<K0_080@FWQ1P33_K/00`11JN40`kfk0<>m^`040<>m^`80@FWQ00D0`kfk0:f]
[@2n^KP0_[Vh045Yh@020:f][@D0_[Vh0P11JN400`2n^KP0[Jf]045Yh@090;B`/@030:f][@2OVj00
@FWQ00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=P
D`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[
W@2aZid00`2aZid00`11JN40/J^M0;6[W@030:f][@050;6[W@11JN40/J^M0:f][@2i/ZH00P11JN48
0;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[002045Yh@H0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`0
1011JN40_[N/0;jg[02][Jd<0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00<0aKje0`11JN4>0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038
`K/60:f][A40al6l00<0[Jf]0<K0_011JN400`36`;`00`11JN40a/2l0<K0_0040<K0_080@FWQ0`36
`;`2045Yh@H0`kfk00<0@FWQ0<>m^`33_K/01033_K/3045Yh@040:f][@2n^KP0[Jf]045Yh@<0_[Vh
00<0@FWQ0;ji^02n^KP00P2n^KP00`11JN40_[Vh045Yh@0:0;B`/@030:f][@2OVj00@FWQ0080Wi^P
00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<0
0P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2a
Zid00`2aZid00`11JN40/J^M0;6[W@030;6[W@050:f][@11JN40/J^M0:f][@2i/ZH00P11JN480;Vb
YP80@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[002045Yh@H0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`01011
JN40_[N/0;jg[02][JdA0<6j/0P0[Jf]4033_K<00`2][Jd0aKje0<Fn]@060<Fn]@@0@FWQ2P35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0
al6l0140al6l0P11JN401@36`;`0@FWQ045Yh@36`;`0@FWQ00H0a/2l0P11JN420<K0_003045Yh@36
`;`0@FWQ00H0`kfk00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@050<>m^`2][Jd0[Jf]0:f][@2n^KP0
0P11JN420;ji^080@FWQ102n^KP00`11JN40[Jf]0;B`/@090;B`/@030:f][@2OVj00@FWQ0080[Jf]
0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1S
H5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@030;6[W@03045Yh@2aZid0/J^M00@0/J^M00@0@FWQ0:f][@2][Jd0[Jf]0P11JN480;VbYP80
@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[002045Yh@D0_[N/00<0@FWQ0;jg[011JN40102n]j`01011JN40
_[N/0;jg[02][JdC0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje
00H0aKje00<0@FWQ0<Fn]@35_[D02`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k
0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00?0<O1_080@FWQ00@0[Jf]0<K0_036`;`0a/2l0`11
JN450<K0_003045Yh@36`;`0@FWQ0080a/2l00<0@FWQ0<K0_011JN401@33_K/2045Yh@D0`kfk0`2]
[Jd01033_K/0[Jf]0;ji^02n^KP2045Yh@80_[Vh0P11JN450;ji^0030:f][@2d/;40];2a00P0];2a
00<0[Jf]045Yh@2][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00<0
[Jf]0;6[W@2aZid00`2aZid00`11JN40/J^M0;6[W@040;6[W@04045Yh@2aZid0[Jf]0;VbYP80@FWQ
00<0[Jf]0;VbYP2i/ZH01P2i/ZH01011JN40^K:V0;VbYP2][Jd20;jg[080@FWQ1@2n]j`3045Yh@<0
_[N/0P11JN420;jg[0030:f][@31^[00`KZ`00H0`KZ`0`11JN480<6j/0030:f][@33_K<0`kfc00h0
`kfc2`2][Jd30<Fn]@03045Yh@35_[D0aKje00/0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80
b<6k00<0[Jf]0<O1_037`K`00P37`K`4045Yh@T0al6l00<0@FWQ0<O1_02][Jd01036`;`2045Yh@D0
a/2l00<0@FWQ0<K0_011JN400P36`;`3045Yh@D0`kfk0P11JN420<>m^`<0[Jf]1033_K/00`2][Jd0
_[Vh0;ji^002045Yh@80_[Vh00<0@FWQ0;ji^02n^KP0102n^KP00`2][Jd0];2a0;B`/@080;B`/@80
[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<0
0P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]2`2TWXl00`2][Jd0/J^M0;6[W@030;6[W@03045Y
h@2aZid0/J^M00@0/J^M00@0@FWQ0;6[W@2][Jd0^K:V0P11JN40102i/ZH0[Jf]0:f][@2][Jd50;Vb
YP04045Yh@2i/ZH0^K:V0:f][@80_[N/0P11JN450;jg[0<0@FWQ0`2n]j`2045Yh@80_[N/00<0[Jf]
0<6j/031^[001031^[02045Yh@<0`KZ`00@0@FWQ0<6j/031^[00@FWQ1031^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje00<0aKje0`2][Jd00`11JN40[Jf]0:f][@060:f][@D0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_004045Yh@/0al6l00<0@FWQ0<O1_02][Jd01036`;`2045Yh@D0a/2l00<0@FWQ0<K0_011JN400P36
`;`3045Yh@D0`kfk0P11JN420:f][@L0`kfk00D0[Jf]0;ji^02n^KP0@FWQ0;ji^003045Yh@H0_[Vh
00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2]
[Jd0?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@030;6[W@03045Yh@2aZid0/J^M00@0/J^M
00@0@FWQ0;6[W@2][Jd0^K:V0P11JN440;VbYP@0[Jf]0P2i/ZH00`11JN40^K:V0:f][@020;jg[003
045Yh@2n]j`0_[N/00@0_[N/0`11JN430;jg[0<0@FWQ00<0[Jf]0<6j/031^[001031^[02045Yh@D0
`KZ`00<0@FWQ0<6j/011JN401031^[04045YhA80`kfc00<0[Jf]0<Fn]@35_[D01P35_[D00`11JN40
aKje0<Fn]@060<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0
al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00/0b<6k1011JN440<S1^`030:f][@37`K`0al6l0080
al6l0P11JN4;0<O1_003045Yh@37`K`0[Jf]00@0a/2l0P11JN450<K0_0<0@FWQ0P36`;`2045Yh@03
0:f][@11JN40`kfk0080`kfk00<0[Jf]045Yh@11JN402@33_K/0102][Jd0_[Vh0;ji^011JN4:0;ji
^0030:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H1
0?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0
/J^M00<0/J^M00<0@FWQ0;6[W@2aZid0102aZid01011JN40/J^M0:f][@2i/ZH2045Yh@<0^K:V00<0
@FWQ0;VbYP2i/ZH00P2i/ZH30:f][@80@FWQ0P2n]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@2n
]j`0@FWQ00<0_[N/00@0@FWQ0;jg[011JN40[Jf]1P31^[02045Yh@D0`KZ`00<0@FWQ0<6j/011JN40
1031^[000`2][Jd0`kfc045Yh@03045YhA00`kfc00<0[Jf]0<Fn]@35_[D01P35_[D00`11JN40aKje
0<Fn]@0;0<Fn]@030:f][@36_kL0a[ng00T0a[ng<02][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/01`38`K/4045Yh@@0b<6k0P11JN420<S1^`030:f][@37`K`0al6l0080al6l
0P11JN4;0<O1_003045Yh@37`K`0[Jf]00@0a/2l0P11JN450<K0_080@FWQ00<0a/2l045Yh@36`;`0
0P11JN400`2][Jd0@FWQ0:f][@020:f][@030<>m^`11JN40@FWQ00T0`kfk00@0[Jf]045Yh@11JN40
@FWQ2P2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f][@L0Wi^P00D0[Jf]071^
N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD0
0`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid00`2aZid00`11JN40/J^M0;6[W@04
0;6[W@07045Yh@2aZid0[Jf]0;VbYP11JN40^K:V045Yh@020;VbYP03045Yh@2i/ZH0^K:V00D0^K:V
0P2][Jd3045Yh@D0_[N/0P11JN400`2n]j`0@FWQ0;jg[0020;jg[004045Yh@2n]j`0@FWQ0:f][@D0
`KZ`0P11JN470<6j/080@FWQ1031^[00102][Jd0`kfc045Yh@11JN4>0<>m/`<0@FWQ00<0`kfc0:f]
[@35_[D01`35_[D00`11JN40aKje0<Fn]@0;0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/02@38`K/2045Yh@D0b<6k0P11JN400`38`K/0[Jf]0<O1_0030<O1_080@FWQ2`37`K`00`11
JN40al6l0:f][@040<K0_080@FWQ1@36`;`2045Yh@030<K0_011JN40a/2l0080@FWQ00<0[Jf]045Y
h@33_K/01033_K/00`11JN40`kfk0<>m^`070<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`
/@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0
[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`02
0:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid00`2aZid00`11JN40/J^M0;6[W@03
0;6[W@08045Yh@2aZid0/J^M0:f][@2i/ZH0@FWQ0;VbYP11JN420;VbYP80@FWQ0`2i/ZH2045Yh@80
^K:V00@0[Jf]0;jg[011JN40@FWQ0P2][Jd30;jg[080@FWQ0P2n]j`01`11JN40_[N/045Yh@11JN40
_[N/045Yh@2][Jd01@31^[02045Yh@P0`KZ`00<0@FWQ0<6j/031^[000P31^[00102][Jd0`kfc045Y
h@11JN4<0<>m/`80@FWQ0`33_K<00`11JN40[Jf]0<Fn]@020<Fn]@80@FWQ0`35_[D00`11JN40aKje
0<Fn]@0;0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@H0b<6k
0P11JN400`2][Jd0al6l0<O1_0020<O1_080@FWQ2`37`K`00`11JN40al6l0:f][@040<K0_080@FWQ
1@36`;`2045Yh@030:f][@11JN40[Jf]0080@FWQ00<0[Jf]045Yh@33_K/01033_K/00`11JN40`kfk
0<>m^`070<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0
Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M
00<0/J^M00<0@FWQ0;6[W@2aZid00`2aZid01011JN40/J^M0;6[W@2][Jd2045Yh@80^K:V00@0@FWQ
0;VbYP11JN40@FWQ0`2i/ZH2045Yh@80^K:V00@0[Jf]0;jg[02n]j`0@FWQ0P2n]j`30:f][@80@FWQ
0P2n]j`01`11JN40_[N/045Yh@11JN40_[N/045Yh@2][Jd01@31^[02045Yh@L0`KZ`0P11JN440<6j
/0040:f][@33_K<0@FWQ045Yh@/0`kfc0P11JN450<>m/`04045Yh@35_[D0@FWQ045Yh@D0aKje00@0
@FWQ0<Fn]@35_[D0aKje0`11JN470<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
2@38`K/2045Yh@H0b<6k0P11JN400`2][Jd0al6l0<O1_0020<O1_080@FWQ2`37`K`2045Yh@030:f]
[@36`;`0a/2l0080a/2l0P11JN400`36`;`0[Jf]0:f][@020:f][@80@FWQ00L0a/2l045Yh@11JN40
a/2l045Yh@2][Jd0@FWQ00D0`kfk00<0@FWQ0<>m^`33_K/01@33_K/00`11JN40`kfk0:f][@0=0;ji
^0040:f][@2d/;40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2]
[Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl2
0:f][@80Y9j?00<0[Jf]0;6[W@2aZid00`2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ00<0/J^M
0:f][@2i/ZH01@2i/ZH2045Yh@@0^K:V00D0@FWQ0;VbYP2i/ZH0^K:V0:f][@020;jg[003045Yh@2n
]j`0_[N/00<0_[N/0P11JN420:f][@03045Yh@2n]j`0@FWQ0080_[N/00<0@FWQ0:f][@31^[000`31
^[02045Yh@P0`KZ`0P11JN440<6j/0040:f][@33_K<0@FWQ045Yh@/0`kfc0P11JN450<>m/`<0@FWQ
1P35_[D01011JN40aKje045Yh@11JN420<Fn]@<0@FWQ1@35_[D00`2][Jd0@FWQ045Yh@05045Yh@80
a[ng1`11JN420<Jo]`@0@FWQ00<0a[ng0:f][@37`KP05@37`KP00`2][Jd0@FWQ045Yh@02045Yh@P0
al6j00<0@FWQ0<O1^P37`KX02037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0
b<6k0P11JN470<S1^`80@FWQ1037`K`2045Yh@d0al6l1`11JN40202][Jd0a/2l0<K0_036`;`0@FWQ
0<K0_011JN40a/2l0`11JN401036`;`0[Jf]0<>m^`11JN440<>m^`03045Yh@33_K/0`kfk00D0`kfk
00<0@FWQ0<>m^`2][Jd03@2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii
0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2T
WXl30:f][@D0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@030;6[W@2][Jd0^K:V00`0^K:V00@0
@FWQ0;VbYP2i/ZH0[Jf]0P2n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ0P2n]j`00`11JN40[Jf]
045Yh@020:f][@03045Yh@2][Jd0`KZ`00<0`KZ`0P11JN480<6j/080@FWQ1031^[00102][Jd0`kfc
045Yh@11JN4;0<>m/`80@FWQ1@33_K<00`2][Jd0@FWQ045Yh@060<Fn]@80@FWQ1@35_[D2045Yh@D0
aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ1`36_kL5045Yh@H0al6h1011JN480<O1^004
045Yh@37`KP0al6h045Yh@@0al6j0P11JN450<O1^P03045Yh@37`KX0@FWQ00T0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ1`38`K/2045Yh@@0al6l0P11JN4;0<O1
_0D0[Jf]0P36`;`2045Yh@@0a/2l0P11JN430<K0_080@FWQ00<0a/2l0:f][@33_K/00`11JN420<>m
^`80@FWQ1P33_K/00`11JN40`kfk0:f][@0<0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nK
X0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?0P2][Jd20;6[W@<0@FWQ0`2aZid2045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH2045Yh@03
0:f][@2n]j`0@FWQ00H0_[N/00L0@FWQ0;jg[02n]j`0_[N/045Yh@2n]j`0@FWQ0080_[N/00<0@FWQ
0:f][@2][Jd00P2][Jd00`31^[00@FWQ045Yh@080<6j/080@FWQ1031^[00102][Jd0`kfc045Yh@11
JN4;0<>m/`80@FWQ1@33_K<00`2][Jd0@FWQ045Yh@060<Fn]@03045Yh@35_[D0aKje00D0aKje0P11
JN440<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@L0a[ng0P11JN400`36_kL0[Jf]0<O1
^0040<O1^0<0@FWQ0`37`KP2045Yh@H0al6h00@0@FWQ0<O1^011JN40[Jf]1@37`KX00`11JN40al6j
0<O1^P040<O1^P03045Yh@37`KX0al6j00P0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`090<S1^`80@FWQ1`38`K/00`11JN40[Jf]045Yh@040<O1_080@FWQ1@37`K`50:f][@80al6l
00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ0`36`;`2045Yh@040<K0
_02][Jd0@FWQ045Yh@@0`kfk0P11JN460<>m^`03045Yh@33_K/0[Jf]00X0_[Vh0P2][Jd00`2n^KP0
[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]
1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]00<0/J^M045Yh@11JN40
0P2aZid2045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH2045Yh@H0_[N/0P11JN430;jg[003045Y
h@2n]j`0@FWQ00<0_[N/00D0@FWQ0<6j/031^[00`KZ`0:f][@02045Yh@@0[Jf]0P31^[04045Yh@@0
`KZ`00<0[Jf]0<>m/`11JN403033_K<2045Yh@D0`kfc00<0[Jf]045Yh@11JN401@35_[D2045Yh@L0
aKje0P11JN440<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@L0a[ng0P11JN400`36_kL0
[Jf]0<O1^0030<O1^080@FWQ1`37`KP00`11JN40al6h0<O1^0030<O1^080@FWQ00<0al6h0:f][@37
`KX01037`KX00`11JN40al6j0<O1^P0?0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/02@38`K/2045Yh@P0b<6k0P11JN440<O1_080@FWQ1@2][Jd70<O1_0030:f][@36`;`0a/2l0080
a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@<0a/2l0P11JN400`36`;`0[Jf]0<>m^`050<>m^`80
@FWQ1P33_K/00`11JN40`kfk0:f][@080;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@03
0:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]00@0/J^M045Yh@11JN40
@FWQ0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/1011JN440;jg[003
045Yh@2n]j`0_[N/0080_[N/00<0@FWQ0<6j/031^[000P31^[02045Yh@@0`KZ`1@2][Jd3045Yh@80
`KZ`00@0[Jf]0<>m/`11JN40@FWQ2`33_K<2045Yh@D0`kfc00<0[Jf]045Yh@11JN401@35_[D2045Y
h@L0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@L0a[ng0P11JN400`36
_kL0[Jf]0<O1^0030<O1^003045Yh@37`KP0al6h00L0al6h00<0@FWQ0<O1^037`KP00P37`KP01@11
JN40al6h0<O1^037`KP0[Jf]00@0al6j00<0@FWQ0<O1^P37`KX03`37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00T0b<6k0P11JN480<S1^`80@FWQ00@0al6l0:f][@2][Jd0[Jf]0P11
JN4;0<O1_003045Yh@2][Jd0a/2l00<0a/2l00<0@FWQ0<K0_036`;`00`36`;`4045Yh@@0a/2l00<0
[Jf]0<>m^`33_K/01033_K/00`11JN40`kfk045Yh@040<>m^`80@FWQ00<0`kfk0:f][@2n^KP0102n
^KP30:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`
h>H0/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`01@2n]j`4045Yh@80_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40`KZ`0<6j/002
0<6j/080@FWQ2`31^[050:f][@80@FWQ3033_K<00`11JN40`kfc0<>m/`030<>m/`030:f][@11JN40
@FWQ00D0aKje0P11JN480<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`02045Yh@L0a[ng0P11JN47
0<Jo]`80@FWQ00<0a[ng0:f][@37`KP00`37`KP00`11JN40al6h0<O1^00<0<O1^005045Yh@37`KP0
al6h0<O1^02][Jd01037`KX00`11JN40al6j0<O1^P0?0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/02@38`K/2045Yh@D0b<6k0`2][Jd2045Yh@040:f][@37`K`0al6l0<O1_080@FWQ
1037`K`00`11JN40al6l0<O1_0040<O1_003045Yh@2][Jd0a/2l00<0a/2l00@0@FWQ0<K0_036`;`0
a/2l0`11JN480<K0_0030:f][@33_K/0`kfk00@0`kfk0P11JN440<>m^`80@FWQ00<0`kfk0:f][@2n
^KP00P2n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX003
0:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?
0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f]
[@2n]j`0_[N/00/0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40`KZ`0<6j/0020<6j/080@FWQ
3P31^[00102][Jd0`kfc045Yh@11JN470:f][@H0`kfc0`11JN420<>m/`030:f][@11JN40@FWQ00D0
aKje0P11JN480<Fn]@80@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`02045Yh@L0a[ng0P11JN470<Jo]`80
@FWQ00<0a[ng0:f][@37`KP00P37`KP2045YhA80al6h00<0[Jf]0<O1^P37`KX00P37`KX00`11JN40
al6j0<O1^P0?0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@D0
[Jf]0`38`K/2045Yh@@0al6l0P11JN440<O1_080@FWQ1@37`K`01011JN40[Jf]0<K0_036`;`2045Y
h@l0a/2l00<0[Jf]0<>m^`33_K/01033_K/2045Yh@<0`kfk00H0@FWQ0<>m^`11JN40`kfk0:f][@2n
^KP20:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`
h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/00h0_[N/0`11JN44
0<6j/080@FWQ3P31^[00102][Jd0`kfc045Yh@11JN470<>m/`P0[Jf]00@0`kfc045Yh@11JN40[Jf]
0P11JN450<Fn]@80@FWQ2035_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ
1`36_kL2045Yh@030<Jo]`2][Jd0al6h0080al6h0P11JN4B0<O1^0030:f][@37`KX0al6j00<0@FWQ
4@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]0P11JN480<S1^`80
@FWQ1037`K`3045Yh@<0al6l0P11JN460<O1_0<0@FWQ4@36`;`00`2][Jd0`kfk0<>m^`050<>m^`@0
@FWQ0`33_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0
/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
2`2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`3045Yh@80`KZ`
0P11JN4>0<6j/0040:f][@33_K<0@FWQ045Yh@l0`kfc0`2][Jd3045Yh@<0[Jf]0P35_[D2045Yh@P0
aKje0P11JN430<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@L0a[ng0P11JN400`36_kL0
[Jf]0<O1^0020<O1^080@FWQ4P37`KP00`2][Jd0@FWQ045Yh@02045Yh@L0al6j00<0@FWQ0<O1^P37
`KX02037`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]2038`K/2045Yh@P0b<6k0P11JN440<O1_080
@FWQ00D0al6l045Yh@37`K`0al6l045Yh@070<O1_0030:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m
^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2]
[Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2a
Zid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0080`KZ`0P11JN4>0<6j/0050:f][@33_K<0@FWQ0<>m/`11JN401033_K<00`11
JN40`kfc0<>m/`030<>m/`03045Yh@33_K<0`kfc00@0`kfc00<0[Jf]045Yh@11JN400`35_[D20:f]
[@80@FWQ202][Jd2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ1`36_kL2045Y
h@030<Jo]`2][Jd0al6h0080al6h0P11JN4A0<O1^080@FWQ00<0al6j045Yh@37`KX02037`KX00`11
JN40al6j0<O1^P080<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k
00T0b<6k0P11JN480<S1^`80@FWQ1037`K`2045Yh@80al6l0P11JN490<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2]
[Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[003031^[000`2][Jd0`kfc045Yh@020<>m/`03
045Yh@33_K<0`kfc0080@FWQ1@33_K<2045Yh@D0`kfc00<0[Jf]045Yh@35_[D01@35_[D2045Yh@L0
aKje0P11JN470:f][@80@FWQ1`2][Jd2045Yh@L0a[ng0P11JN400`36_kL0[Jf]0<O1^0020<O1^080
@FWQ4037`KP01011JN40al6h045Yh@11JN4:0<O1^P03045Yh@2][Jd0[Jf]00h0[Jf]4@38`K/00`2]
[Jd0b<6k0<S1^`090<S1^`80@FWQ2038`K/2045Yh@80al6l0`11JN4>0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2]
[Jd0];2a0;B`/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2T
WXl0202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0
[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[001`31^[001011JN40
`KZ`0<6j/031^[04045Yh@80`kfc00<0@FWQ0<>m/`33_K<00P11JN450<>m/`80@FWQ1@33_K<00`2]
[Jd0@FWQ0<Fn]@050<Fn]@80@FWQ1`35_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo
]`80@FWQ1`2][Jd2045Yh@D0[Jf]0P11JN480:f][@03045Yh@2][Jd0[Jf]00@0[Jf]00<0@FWQ0:f]
[@11JN40302][Jd00`11JN40al6j0<O1^P080<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/02@38`K/2045Yh@L0b<6k0P11JN4D0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f]
[D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[000`31^[000`11JN40`KZ`0<6j/0070<6j/003
045Yh@31^[00`KZ`0080`KZ`00<0[Jf]0<>m/`33_K<00`33_K<3045Yh@L0`kfc00<0@FWQ0<>m/`33
_K<00`33_K<00`11JN40aKje0<Fn]@050<Fn]@<0@FWQ1P35_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36
_kL00P11JN470<Jo]`80@FWQ1`36_kL2045Yh@030<Jo]`2][Jd0al6h00<0al6h00<0@FWQ0<O1^037
`KP01@37`KP00`11JN40al6h045Yh@040<O1^0<0@FWQ00<0al6h0:f][@37`KX00`37`KX00`11JN40
al6j0<O1^P040<O1^P03045Yh@37`KX0al6j00P0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`090<S1^`80@FWQ1`38`K/2045YhA@0al6l00<0[Jf]0<K0_036`;`03P36`;`40:f][@h0
`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0
/>3V0@3oool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[000`31^[02045Yh@L0`KZ`
0P11JN440<6j/0030:f][@33_K<0`kfc00h0`kfc1@11JN400`2][Jd0aKje0<Fn]@050<Fn]@80@FWQ
00<0aKje045Yh@35_[D00`35_[D2045Yh@D0aKje00<0[Jf]0<Jo]`36_kL00`11JN460<Jo]`80@FWQ
1`36_kL2045Yh@030<Jo]`2][Jd0al6h00<0al6h00<0@FWQ0<O1^037`KP01P37`KP2045Yh@@0al6h
00D0@FWQ0<O1^037`KP0al6h0:f][@040<O1^P03045Yh@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37
`KX02037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k0P11JN470<S1^`80
@FWQ5037`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`03
0:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V
0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/0040<6j/080@FWQ1P31^[02045Yh@@0`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@@0@FWQ00<0aKje045Yh@35_[D0
0`35_[D00`11JN40aKje0<Fn]@040<Fn]@030:f][@36_kL0a[ng00<0@FWQ1@36_kL2045Yh@P0a[ng
0P11JN400`36_kL0[Jf]0<O1^0030<O1^080@FWQ1`37`KP00`11JN40al6h0<O1^0030<O1^005045Y
h@37`KP0al6h0<O1^02][Jd01037`KX00`11JN40al6j0<O1^P040<O1^P03045Yh@37`KX0al6j00P0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ1`38`K/00`11JN40
[Jf]0<O1_00C0<O1_0030:f][@36`;`0a/2l00D0a/2l102][Jd70<K0_0030:f][@33_K/0`kfk00d0
`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`/@2d/;420:f][E00/>3V0@3oool006T0
/>3V0P2][Jd20:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/0040<6j/080@FWQ1P31^[02045Yh@@0
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@090<Fn]@@0@FWQ1`35_[D00`2][Jd0
a[ng0<Jo]`02045Yh@030<Jo]`11JN40a[ng00<0a[ng0P11JN480<Jo]`80@FWQ00<0a[ng0:f][@37
`KP01037`KP2045Yh@D0al6h00<0@FWQ0<O1^037`KP01@37`KP01011JN40al6h0<O1^02][Jd30<O1
^P80@FWQ1@37`KX3045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1
^`80@FWQ1`38`K/00`11JN40[Jf]0<O1_00C0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H1
0?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg
[0@0[Jf]00<0_[N/0:f][@31^[001P31^[02045Yh@@0`KZ`0`11JN440<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`02045Yh@80a[ng1@11JN470<Jo
]`@0@FWQ00<0a[ng0:f][@37`KP01P37`KP5045Yh@T0al6h1P11JN400`37`KX0@FWQ0<O1^P040<O1
^P<0@FWQ2@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k0P11JN460<S1
^`80@FWQ00<0[Jf]0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]1@31^[06045Yh@030<6j/011JN40`KZ`00<0
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080
@FWQ4`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00P0al6j0`11JN490<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`2]
[Jd03@37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd50<6j/003
045Yh@31^[00`KZ`0080`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng0080@FWQ4`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00P0
al6j0`11JN490<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@D0
b<6k0P11JN400`38`K/0[Jf]0<O1_0060<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V
0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL00P11JN4C0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
2037`KX3045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ
00<0b<6k045Yh@11JN400`11JN420<S1^`030:f][@37`K`0al6l00D0[Jf]3@37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V
0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng0080@FWQ4`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00P0al6j0`11
JN490<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01`38`K/5045Yh@@0b<6k1P2]
[JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2]
[Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL00P11JN4C0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02037`KX3045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3o
ool007T0/>3V0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng0080@FWQ4036_kL01011JN40a[ng0<Jo]`2][JdG0<O1^0030:f][@37
`KX0al6j00P0al6j00<0@FWQ0<O1^P11JN402@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38
`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35
_[D00`2][Jd0@FWQ045Yh@02045Yh@l0a[ng00D0@FWQ0<Jo]`11JN40a[ng0:f][@0G0<O1^0030:f]
[@37`KX0al6j00P0al6j0P11JN4:0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]
I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0
[Jf]0<Jo]`36_kL00P11JN4@0<Jo]`04045Yh@36_kL0a[ng0:f][AL0al6h00<0[Jf]0<O1^P37`KX0
2@37`KX00`11JN40al6j0<O1^P080<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`030<>m^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f]
[@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00L0a/2l102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_0030<K0_0@0[Jf]OP2`h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf2
0;3PiP40oooo002N0;3PiPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00l0al6l1@2][Jf60;3PiP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l00P0al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`040:f][@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k
1`2][JfI0;3PiP40oooo002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd3
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38
`K/80:f][JL0/>3V0@3oool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_
0;3PiP40oooo003A0;3PiP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51186 .33085 m
.48517 .33029 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51113 .33856 m
.52272 .33862 L
s
.45696 .32094 m
.46838 .32156 L
s
.52935 .3386 m
.54093 .33847 L
s
.49295 .33823 m
.50451 .33847 L
s
.55416 .34044 m
.55745 .33809 L
s
.55745 .33809 m
.56074 .33799 L
s
.55251 .34048 m
.55745 .33809 L
s
.54922 .34508 m
.55251 .34048 L
s
.55087 .34504 m
.55416 .34044 L
s
.56074 .33799 m
.5657 .34007 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45043 .33037 m
.45045 .3286 L
s
.45208 .32946 m
.45209 .32871 L
s
.5 Mabswid
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54759 .35189 m
.54922 .34508 L
s
.47319 .33755 m
.47811 .34001 L
s
.47811 .34001 m
.48137 .34464 L
s
.47319 .33755 m
.47646 .33994 L
s
.46991 .3374 m
.47319 .33755 L
s
.47646 .33994 m
.47973 .34458 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5657 .34007 m
.56901 .34445 L
s
.54924 .35185 m
.55087 .34504 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46662 .3395 m
.46991 .3374 L
s
.48137 .34464 m
.48299 .35148 L
s
.47973 .34458 m
.48134 .35142 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49505 .36306 m
.49507 .35896 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49942 .38597 m
.49955 .33838 L
s
.46313 .36879 m
.46347 .32131 L
s
.49776 .38593 m
.4979 .33835 L
s
.46149 .36871 m
.46184 .32122 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54759 .35189 m
.5476 .35641 L
s
.54924 .35185 m
.54926 .35637 L
s
.58045 .33716 m
.58212 .34159 L
s
.58045 .33716 m
.58051 .34619 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51774 .36345 m
.51776 .33861 L
s
.51608 .36345 m
.5161 .3386 L
s
.53431 .33856 m
.53436 .37021 L
s
.53597 .33854 m
.53602 .37019 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46331 .34385 m
.46662 .3395 L
s
.5476 .35641 m
.54928 .36317 L
s
.54926 .35637 m
.55093 .36313 L
s
.48297 .356 m
.48299 .35148 L
s
.58374 .33924 m
.58699 .3368 L
s
.58699 .3368 m
.5935 .33641 L
s
.58212 .34159 m
.58374 .33924 L
s
.48132 .35595 m
.48134 .35142 L
s
.58051 .34619 m
.58212 .34159 L
s
.51608 .36798 m
.51774 .36345 L
s
.51441 .36797 m
.51608 .36345 L
s
.45194 .33642 m
.45357 .33652 L
s
.48128 .36275 m
.48297 .356 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44867 .33847 m
.45194 .33642 L
s
.4503 .33857 m
.45194 .33642 L
s
.5935 .33641 m
.59677 .33847 L
s
.47963 .36269 m
.48132 .35595 L
s
.49948 .36324 m
.50279 .36783 L
s
.54928 .36317 m
.55261 .36763 L
s
.55093 .36313 m
.55426 .36758 L
s
.51109 .37021 m
.51608 .36798 L
s
.51109 .37021 m
.51441 .36797 L
s
.44863 .34299 m
.4503 .33857 L
s
.56744 .35809 m
.5691 .36029 L
s
.5658 .36042 m
.56744 .35809 L
s
.50279 .36783 m
.50777 .37017 L
s
.44701 .34289 m
.44867 .33847 L
s
.59677 .33847 m
.59841 .34062 L
s
.52937 .37025 m
.53602 .37019 L
s
.50777 .37017 m
.51109 .37021 L
s
.5658 .36042 m
.56746 .36262 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47796 .36717 m
.48128 .36275 L
s
.5691 .36029 m
.56911 .36256 L
s
.55261 .36763 m
.55758 .36976 L
s
.55426 .36758 m
.55758 .36976 L
s
.47631 .3671 m
.47963 .36269 L
s
.59841 .34062 m
.59848 .34741 L
s
.44381 .33814 m
.44701 .34289 L
s
.4406 .33564 m
.44381 .33814 L
s
.56584 .36722 m
.56911 .36256 L
s
.43576 .33528 m
.4406 .33564 L
s
.55758 .36976 m
.56255 .36961 L
s
.58549 .35499 m
.59362 .34999 L
s
.58224 .35743 m
.58549 .35499 L
s
.56255 .36961 m
.56584 .36722 L
s
.58061 .35978 m
.58224 .35743 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45183 .35883 m
.45184 .35723 L
s
.45017 .35976 m
.45019 .3571 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44849 .35887 m
.44863 .34299 L
s
.44682 .36331 m
.44701 .34289 L
s
.59685 .34752 m
.59846 .34515 L
s
.473 .36924 m
.47796 .36717 L
s
.59362 .34999 m
.59685 .34752 L
s
.473 .36924 m
.47631 .3671 L
s
.43252 .33728 m
.43576 .33528 L
s
.43091 .33715 m
.43576 .33528 L
s
.58551 .35726 m
.59364 .35226 L
s
.58225 .3597 m
.58551 .35726 L
s
.58063 .36205 m
.58225 .3597 L
s
.59687 .34978 m
.59848 .34741 L
s
.60971 .33754 m
.6113 .33515 L
s
.59364 .35226 m
.59687 .34978 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58061 .35978 m
.58064 .36432 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60971 .33754 m
.61135 .33967 L
s
.6113 .33515 m
.61293 .33728 L
s
.53437 .38157 m
.53604 .38383 L
s
.53271 .38387 m
.53437 .38157 L
s
.46318 .36198 m
.46643 .36668 L
s
.4697 .3691 m
.473 .36924 L
s
.58064 .36432 m
.5823 .36652 L
s
.53271 .38387 m
.53438 .38613 L
s
.53438 .38613 m
.53604 .38383 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43086 .34169 m
.43252 .33728 L
s
.46643 .36668 m
.4697 .3691 L
s
.61135 .33967 m
.61293 .33728 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42925 .34155 m
.43091 .33715 L
s
.5823 .36652 m
.5856 .36862 L
s
.49277 .38582 m
.49942 .38597 L
s
.45657 .36845 m
.46313 .36879 L
s
.44682 .36331 m
.44849 .35887 L
s
.43081 .34622 m
.43086 .34169 L
s
.43556 .35342 m
.44526 .35638 L
s
.44526 .35638 m
.44686 .35876 L
s
.5856 .36862 m
.59214 .36826 L
s
.597 .36341 m
.59858 .35876 L
s
.59858 .35876 m
.59867 .36786 L
s
.4292 .34609 m
.42925 .34155 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59539 .36579 m
.597 .36341 L
s
.597 .36341 m
.59867 .36786 L
s
.43081 .34622 m
.43236 .35089 L
s
.59214 .36826 m
.59539 .36579 L
s
.44517 .36548 m
.44682 .36331 L
s
.4292 .34609 m
.43076 .35076 L
s
.43236 .35089 m
.43556 .35342 L
s
.43076 .35076 m
.43556 .35342 L
s
.4419 .36754 m
.44517 .36548 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43542 .36707 m
.4419 .36754 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43065 .35986 m
.43226 .35999 L
s
.43224 .36227 m
.43226 .35999 L
s
.43063 .36214 m
.43065 .35986 L
s
.39768 .33158 m
.40866 .3328 L
s
.43221 .36455 m
.43542 .36707 L
s
.43063 .36214 m
.43221 .36455 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61162 .36467 m
.61177 .37837 L
s
.61015 .37849 m
.61147 .35102 L
s
.61147 .35102 m
.61338 .37824 L
s
.61015 .37849 m
.61182 .38294 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40347 .36422 m
.40394 .33229 L
s
.40189 .36405 m
.40237 .33212 L
s
.41462 .36075 m
.41624 .35862 L
s
.41624 .35862 m
.4178 .36105 L
s
.41777 .36333 m
.4178 .36105 L
s
.61182 .38294 m
.61338 .37824 L
s
.41615 .36547 m
.41777 .36333 L
s
.41462 .36075 m
.41618 .36318 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41138 .36502 m
.41615 .36547 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40367 .3505 m
.40515 .35752 L
s
.40824 .36242 m
.41138 .36502 L
s
.38806 .34871 m
.38837 .33045 L
s
.40515 .35752 m
.40824 .36242 L
s
.38652 .34852 m
.38682 .33025 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38371 .33213 m
.38671 .33709 L
s
.37915 .32923 m
.38371 .33213 L
s
.39719 .36354 m
.40347 .36422 L
s
.3819 .34793 m
.39272 .34927 L
s
.3761 .32881 m
.37915 .32923 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36325 .31918 m
.36435 .32014 L
s
.36325 .31918 m
.36434 .32054 L
s
.255 .412 .882 r
.37303 .33066 m
.3761 .32881 L
s
.37151 .33044 m
.3761 .32881 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36992 .33479 m
.37303 .33066 L
s
.36841 .33457 m
.37151 .33044 L
s
.38757 .37856 m
.3878 .36475 L
s
.38613 .37146 m
.3878 .36475 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36832 .33915 m
.36992 .33479 L
s
.36681 .33893 m
.36841 .33457 L
s
.38296 .37569 m
.38613 .37146 L
s
.38613 .37146 m
.38757 .37856 L
s
.36668 .34582 m
.36832 .33915 L
s
.36518 .34559 m
.36681 .33893 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3783 .37742 m
.38296 .37569 L
s
.36646 .35732 m
.36668 .34582 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36496 .3571 m
.36518 .34559 L
s
.37523 .37702 m
.3783 .37742 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36646 .35732 m
.36784 .36445 L
s
.37222 .37431 m
.37523 .37702 L
s
.3707 .3741 m
.37523 .37702 L
s
.36496 .3571 m
.36633 .36423 L
s
.36784 .36445 m
.36927 .36928 L
s
.34924 .32458 m
.35445 .35781 L
s
.34271 .35586 m
.34924 .32458 L
s
.69619 .32457 m
.71062 .32191 L
s
.36927 .36928 m
.37222 .37431 L
s
.36633 .36423 m
.36775 .36906 L
s
.36775 .36906 m
.3707 .3741 L
s
.34417 .35611 m
.3491 .33148 L
s
.35002 .35709 m
.35892 .3585 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33767 .32247 m
.34271 .35586 L
s
.33122 .35377 m
.33767 .32247 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71062 .32191 m
.71351 .32366 L
s
.71062 .32191 m
.71493 .32338 L
s
.33264 .35404 m
.33751 .32938 L
s
.71351 .32366 m
.71645 .32771 L
s
.71493 .32338 m
.71785 .32743 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71645 .32771 m
.71797 .33205 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69723 .37307 m
.71175 .37058 L
s
.70201 .32354 m
.70308 .3721 L
s
.70056 .3238 m
.70163 .37234 L
s
.32356 .31963 m
.32495 .31993 L
s
.71785 .32743 m
.71937 .33177 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32697 .35295 m
.33693 .35483 L
s
.32073 .32135 m
.32356 .31963 L
s
.32211 .32165 m
.32356 .31963 L
s
.71797 .33205 m
.71954 .33872 L
s
.71937 .33177 m
.72094 .33844 L
s
.32061 .32598 m
.32211 .32165 L
s
.31923 .32568 m
.32073 .32135 L
s
.71954 .33872 m
.71982 .35034 L
s
.72094 .33844 m
.72122 .35006 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32021 .34223 m
.32061 .32598 L
s
.3166 .32045 m
.31923 .32568 L
s
.31871 .3466 m
.31923 .32568 L
s
.31393 .31751 m
.3166 .32045 L
s
.71175 .37058 m
.71455 .36773 L
s
.71175 .37058 m
.71597 .36746 L
s
.71858 .3576 m
.71982 .35034 L
s
.30987 .31657 m
.31393 .31751 L
s
.71455 .36773 m
.71728 .36253 L
s
.71999 .35732 m
.72122 .35006 L
s
.71728 .36253 m
.71858 .3576 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73014 .31781 m
.73098 .35037 L
s
.73151 .3175 m
.73234 .35008 L
s
.72603 .31873 m
.73556 .31656 L
s
.71597 .36746 m
.71869 .36226 L
s
.71869 .36226 m
.71999 .35732 L
s
.31871 .3466 m
.32021 .34223 L
s
.3175 .33932 m
.31882 .34194 L
s
.30938 .33518 m
.3175 .33932 L
s
.30713 .31826 m
.30987 .31657 L
s
.30579 .31794 m
.30987 .31657 L
s
.31727 .34864 m
.31871 .3466 L
s
.72685 .35125 m
.73234 .35008 L
s
.73198 .33608 m
.73353 .34277 L
s
.31446 .35038 m
.31727 .34864 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30567 .32259 m
.30713 .31826 L
s
.30434 .32227 m
.30579 .31794 L
s
.30901 .34919 m
.31446 .35038 L
s
.30554 .32725 m
.30567 .32259 L
s
.30675 .33222 m
.30938 .33518 L
s
.30542 .33191 m
.30938 .33518 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73353 .34277 m
.73636 .34684 L
s
.30421 .32693 m
.30434 .32227 L
s
.30554 .32725 m
.30675 .33222 L
s
.30421 .32693 m
.30542 .33191 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73636 .34684 m
.73912 .34857 L
s
.30638 .34624 m
.30901 .34919 L
s
.30517 .34125 m
.30651 .34156 L
s
.30644 .3439 m
.30651 .34156 L
s
.3051 .34359 m
.30517 .34125 L
s
.3051 .34359 m
.30638 .34624 L
s
.73912 .34857 m
.74312 .34764 L
s
.74166 .34327 m
.74306 .34529 L
s
.74166 .34327 m
.74293 .34061 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74293 .34061 m
.74432 .34264 L
s
.74432 .34264 m
.74438 .34498 L
s
.74312 .34764 m
.74438 .34498 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75401 .31425 m
.75775 .31087 L
s
.75286 .31927 m
.75401 .31425 L
s
.75286 .31927 m
.75299 .32395 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76477 .30213 m
.76578 .30091 L
s
.255 .412 .882 r
.75528 .31391 m
.75775 .31087 L
s
.75414 .31893 m
.75528 .31391 L
s
.75414 .31893 m
.75427 .32361 L
s
.75299 .32395 m
.75441 .32829 L
s
.75427 .32361 m
.75569 .32795 L
s
.27897 .30836 m
.28768 .31088 L
s
.75775 .31087 m
.76151 .3098 L
s
.29333 .33836 m
.29456 .34104 L
s
.2945 .34338 m
.29456 .34104 L
s
.75441 .32829 m
.75829 .32962 L
s
.29198 .34038 m
.29333 .33836 L
s
.29313 .34541 m
.2945 .34338 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75569 .32795 m
.75829 .32962 L
s
.29198 .34038 m
.2932 .34306 L
s
.28927 .34442 m
.29313 .34541 L
s
.76151 .3098 m
.76407 .31142 L
s
.75468 .33768 m
.75474 .34003 L
s
.75468 .33768 m
.75596 .33735 L
s
.75474 .34003 m
.75609 .34205 L
s
.75596 .33735 m
.75602 .3397 L
s
.75609 .34205 m
.7587 .34373 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28295 .34273 m
.28392 .30981 L
s
.2817 .34238 m
.28267 .30945 L
s
.76407 .31142 m
.76667 .31539 L
s
.2868 .34139 m
.28927 .34442 L
s
.28441 .336 m
.2868 .34139 L
s
.28336 .32859 m
.28441 .336 L
s
.7587 .34373 m
.76373 .34237 L
s
.76667 .31539 m
.76775 .31033 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75829 .32962 m
.76586 .32987 L
s
.76667 .31539 m
.76731 .3366 L
s
.76775 .31033 m
.77011 .30724 L
s
.76897 .30996 m
.77011 .30724 L
s
.76789 .31503 m
.76897 .30996 L
s
.76789 .31503 m
.76839 .33152 L
s
.77011 .30724 m
.77131 .30687 L
s
.27798 .34134 m
.28295 .34273 L
s
.76586 .32987 m
.76716 .33188 L
s
.76373 .34237 m
.76615 .33931 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76615 .33931 m
.76731 .3366 L
s
.76731 .3366 m
.76839 .33152 L
s
.26928 .30772 m
.27151 .31319 L
s
.27151 .31319 m
.27256 .31828 L
s
.27256 .31828 m
.27354 .32573 L
s
.27318 .33755 m
.27354 .32573 L
s
.26584 .3042 m
.26928 .30772 L
s
.2681 .30733 m
.27032 .31281 L
s
.27032 .31281 m
.27136 .3179 L
s
.27136 .3179 m
.27234 .32536 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27197 .33719 m
.27234 .32536 L
s
.26584 .3042 m
.2681 .30733 L
s
.27175 .3443 m
.27318 .33755 L
s
.25452 .30021 m
.26584 .3042 L
s
.27055 .34394 m
.27197 .33719 L
s
.7819 .30341 m
.78754 .33508 L
s
.77829 .33809 m
.7819 .30341 L
s
.77473 .33918 m
.78296 .3366 L
s
.27041 .3487 m
.27175 .3443 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26921 .34834 m
.27055 .34394 L
s
.77947 .33772 m
.78213 .3105 L
s
.26787 .35274 m
.27041 .3487 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26669 .35238 m
.26921 .34834 L
s
.25735 .35183 m
.25898 .30183 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25622 .35145 m
.25785 .30143 L
s
.26426 .35404 m
.26787 .35274 L
s
.26426 .35404 m
.26669 .35238 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79091 .3002 m
.79639 .33195 L
s
.78754 .33508 m
.79091 .3002 L
s
.25286 .35031 m
.26426 .35404 L
s
.78866 .3347 m
.79114 .30732 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79903 .32347 m
.79934 .31903 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79311 .33314 m
.7996 .33075 L
s
.5 Mabswid
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80407 .30711 m
.80493 .3019 L
s
.80329 .31472 m
.80407 .30711 L
s
.80493 .3019 m
.80678 .29625 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80329 .31472 m
.80371 .32672 L
s
.80509 .30669 m
.80594 .30147 L
s
.80432 .3143 m
.80509 .30669 L
s
.80594 .30147 m
.80778 .29581 L
s
.80678 .29625 m
.80967 .29254 L
s
.80432 .3143 m
.80474 .32631 L
s
.80778 .29581 m
.80967 .29254 L
s
.80371 .32672 m
.80499 .33353 L
s
.80967 .29254 m
.81162 .29165 L
s
.80474 .32631 m
.80601 .33312 L
s
.80499 .33353 m
.80618 .33794 L
s
.81162 .29165 m
.81458 .29271 L
s
.80601 .33312 m
.8072 .33753 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80618 .33794 m
.80838 .34195 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8072 .33753 m
.80939 .34154 L
s
.81458 .29271 m
.81664 .29662 L
s
.80838 .34195 m
.81147 .34314 L
s
.81637 .2894 m
.81707 .30868 L
s
.80939 .34154 m
.81147 .34314 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81424 .31001 m
.82076 .3069 L
s
.8173 .28895 m
.818 .30824 L
s
.81147 .34314 m
.81343 .34231 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81343 .34231 m
.81624 .33863 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82736 .30627 m
.82769 .31509 L
s
.5 Mabswid
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81624 .33863 m
.81795 .33291 L
s
.81862 .3252 m
.81916 .33979 L
s
.81795 .33291 m
.81862 .3252 L
s
.81795 .33291 m
.81916 .33979 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82533 .28478 m
.8266 .31878 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82618 .2843 m
.82746 .31833 L
s
.82272 .28618 m
.8287 .28288 L
s
.82398 .32012 m
.82746 .31833 L
s
.82691 .30371 m
.82804 .31055 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82804 .31055 m
.8299 .31452 L
s
.8299 .31452 m
.83164 .31604 L
s
.83164 .31604 m
.83405 .31466 L
s
.83307 .31022 m
.83396 .31221 L
s
.83307 .31022 m
.83377 .30731 L
s
.83377 .30731 m
.83465 .30929 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83405 .31466 m
.83475 .31174 L
s
.83465 .30929 m
.83475 .31174 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83908 .28387 m
.83961 .27848 L
s
.83908 .28387 m
.83927 .28877 L
s
.83961 .27848 m
.84162 .27453 L
s
.83927 .28877 m
.84018 .29319 L
s
.8398 .28338 m
.84032 .27798 L
s
.8398 .28338 m
.83999 .28828 L
s
.20429 .27995 m
.20509 .278 L
s
.20449 .27505 m
.20509 .278 L
s
.84032 .27798 m
.84162 .27453 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2037 .277 m
.20449 .27505 L
s
.83999 .28828 m
.8409 .2927 L
s
.2037 .277 m
.20429 .27995 L
s
.84162 .27453 m
.84365 .27301 L
s
.84018 .29319 m
.8424 .29418 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8409 .2927 m
.8424 .29418 L
s
.84057 .30302 m
.84067 .30549 L
s
.84057 .30302 m
.84129 .30254 L
s
.20335 .32231 m
.20381 .29223 L
s
.20194 .32137 m
.20381 .29223 L
s
.84067 .30549 m
.84148 .30747 L
s
.84129 .30254 m
.84138 .305 L
s
.84365 .27301 m
.84507 .27445 L
s
.8424 .29418 m
.8465 .29368 L
s
.84148 .30747 m
.84298 .30898 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20264 .32184 m
.20323 .30701 L
s
.84507 .27445 m
.84654 .27836 L
s
.84298 .30898 m
.84569 .30704 L
s
.20245 .3268 m
.20335 .32231 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19844 .27294 m
.19896 .27591 L
s
.19867 .28331 m
.19896 .27591 L
s
.20194 .32137 m
.20245 .3268 L
s
.84654 .27836 m
.84697 .27292 L
s
.84654 .27836 m
.84744 .30061 L
s
.19731 .26944 m
.19844 .27294 L
s
.84697 .27292 m
.8481 .26942 L
s
.19804 .28281 m
.19877 .28084 L
s
.19794 .28528 m
.19867 .28331 L
s
.84717 .27785 m
.84759 .27241 L
s
.84717 .27785 m
.84787 .29516 L
s
.84759 .27241 m
.8481 .26942 L
s
.8465 .29368 m
.84724 .29565 L
s
.19496 .26736 m
.19731 .26944 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8481 .26942 m
.8487 .26891 L
s
.84918 .25061 m
.853 .24685 L
s
.84569 .30704 m
.8469 .30358 L
s
.19671 .28426 m
.19804 .28281 L
s
.19661 .28674 m
.19794 .28528 L
s
.19734 .30013 m
.19817 .29567 L
s
.19777 .30559 m
.19817 .29567 L
s
.8469 .30358 m
.84744 .30061 L
s
.84744 .30061 m
.84787 .29516 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19358 .28668 m
.19671 .28426 L
s
.19348 .28916 m
.19661 .28674 L
s
.19734 .30013 m
.19777 .30559 L
s
.19662 .30212 m
.19734 .30013 L
s
.19373 .26879 m
.19496 .26736 L
s
.1953 .30361 m
.19662 .30212 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85142 .24847 m
.85355 .30059 L
s
.85087 .24901 m
.853 .3011 L
s
.19308 .27074 m
.19373 .26879 L
s
.19297 .30162 m
.1953 .30361 L
s
.19275 .26526 m
.19308 .27074 L
s
.19234 .27519 m
.19308 .27074 L
s
.19234 .27519 m
.19275 .26526 L
s
.85243 .27321 m
.85329 .26719 L
s
.19237 .28814 m
.19358 .28668 L
s
.19227 .29063 m
.19348 .28916 L
s
.85129 .3026 m
.85355 .30059 L
s
.85329 .26719 m
.85422 .26365 L
s
.19173 .29012 m
.19237 .28814 L
s
.19196 .29811 m
.19297 .30162 L
s
.85422 .26365 m
.85522 .26259 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19162 .29261 m
.19227 .29063 L
s
0 0 0 r
.18361 .24961 m
.18459 .25077 L
s
.255 .412 .882 r
.85324 .29311 m
.85452 .29708 L
s
.19152 .29511 m
.19173 .29012 L
s
.19152 .29511 m
.19196 .29811 L
s
.85522 .26259 m
.85628 .26401 L
s
.85522 .26259 m
.85675 .26347 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85452 .29708 m
.85566 .29857 L
s
.85628 .26401 m
.85741 .26793 L
s
0 0 0 r
.1845 .25072 m
.18451 .25259 L
s
.86212 .24909 m
.86385 .24681 L
s
.255 .412 .882 r
.1882 .26296 m
.18892 .26901 L
s
.85675 .26347 m
.85786 .2674 L
s
.85566 .29857 m
.85666 .29755 L
s
.18699 .25884 m
.1882 .26296 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85741 .26793 m
.85817 .2749 L
s
.85666 .29755 m
.85752 .29402 L
s
.85666 .29755 m
.85799 .2935 L
s
.18809 .28902 m
.18819 .28651 L
s
.18783 .28349 m
.18819 .28651 L
s
.85786 .2674 m
.85861 .27437 L
s
.18695 .293 m
.18809 .28902 L
s
.18726 .28547 m
.18783 .28349 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18616 .25776 m
.18699 .25884 L
s
.85752 .29402 m
.85824 .28796 L
s
.85817 .2749 m
.85838 .27991 L
s
.18726 .28547 m
.18762 .2885 L
s
.85824 .28796 m
.85838 .27991 L
s
.85799 .2935 m
.85869 .28744 L
s
.85861 .27437 m
.85882 .27939 L
s
.18526 .25917 m
.18616 .25776 L
s
.18488 .25863 m
.18616 .25776 L
s
.85869 .28744 m
.85882 .27939 L
s
.18596 .29448 m
.18695 .293 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1843 .26311 m
.18526 .25917 L
s
0 0 0 r
.86382 .28934 m
.86389 .2884 L
s
.255 .412 .882 r
.18469 .29293 m
.18596 .29448 L
s
.86042 .2561 m
.86281 .25225 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18393 .26256 m
.18488 .25863 L
s
.18362 .27011 m
.1843 .26311 L
s
.184 .28936 m
.18469 .29293 L
s
.18361 .28883 m
.18469 .29293 L
s
.18326 .26957 m
.18393 .26256 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86345 .2781 m
.86347 .27857 L
s
.86484 .31097 m
.86541 .32452 L
s
.86377 .27519 m
.86388 .27764 L
s
.86516 .30808 m
.86584 .32401 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8615 .25446 m
.86374 .30754 L
s
.86184 .25391 m
.86408 .30703 L
s
.18345 .28326 m
.184 .28936 L
s
.18341 .27515 m
.18362 .27011 L
s
.18341 .27515 m
.18345 .28326 L
s
.18309 .28273 m
.18361 .28883 L
s
.18305 .27462 m
.18326 .26957 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18305 .27462 m
.18309 .28273 L
s
.18066 .24837 m
.18259 .25227 L
s
.86301 .28164 m
.86389 .28565 L
s
.86264 .30908 m
.86408 .30703 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1802 .28608 m
.1817 .25061 L
s
.17992 .28555 m
.18143 .25005 L
s
.86397 .25003 m
.86561 .24611 L
s
.86389 .28565 m
.86491 .2866 L
s
.86473 .24835 m
.86592 .27628 L
s
0 0 0 r
.86948 .24557 m
.86971 .24744 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86491 .2866 m
.86548 .28553 L
s
.86497 .24779 m
.86616 .27574 L
s
.17915 .28395 m
.1802 .28608 L
s
0 0 0 r
.86975 .25185 m
.87018 .25833 L
s
.255 .412 .882 r
.86548 .28553 m
.86589 .28191 L
s
.86548 .28553 m
.86614 .28138 L
s
0 0 0 r
.86971 .24744 m
.87038 .25777 L
s
.255 .412 .882 r
.17864 .24217 m
.17979 .24613 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17916 .30342 m
.17955 .30138 L
s
.17938 .29831 m
.17955 .30138 L
s
.86589 .28191 m
.86592 .27628 L
s
.179 .30034 m
.17938 .29831 L
s
.86614 .28138 m
.86616 .27574 L
s
0 0 0 r
.87018 .25833 m
.87049 .2656 L
s
.255 .412 .882 r
.179 .30034 m
.17916 .30342 L
s
0 0 0 r
.87038 .25777 m
.8707 .26505 L
s
.1751 .24576 m
.17508 .23735 L
s
.17482 .25723 m
.1751 .24576 L
s
.87049 .2656 m
.87065 .27281 L
s
.255 .412 .882 r
.17803 .27249 m
.17923 .24444 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1745 .26451 m
.17482 .25723 L
s
.17508 .23735 m
.17481 .23198 L
s
.17493 .24518 m
.17493 .23677 L
s
.17463 .25666 m
.17493 .24518 L
s
.87093 .27912 m
.87096 .27654 L
s
.8707 .26505 m
.87096 .27654 L
s
.255 .412 .882 r
.17787 .27195 m
.17907 .24387 L
s
0 0 0 r
.17432 .26395 m
.17463 .25666 L
s
.17493 .23677 m
.17481 .23198 L
s
.17384 .27491 m
.1745 .26451 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17367 .27436 m
.17432 .26395 L
s
.17481 .23198 m
.17458 .23081 L
s
.17318 .28114 m
.17384 .27491 L
s
.255 .412 .882 r
.17765 .27707 m
.17803 .27249 L
s
0 0 0 r
.17458 .23081 m
.17423 .23329 L
s
.17458 .23081 m
.17415 .23271 L
s
.17303 .28059 m
.17367 .27436 L
s
.255 .412 .882 r
.17749 .27653 m
.17787 .27195 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86687 .24158 m
.86841 .27745 L
s
.86675 .24215 m
.86829 .27799 L
s
.86632 .24385 m
.86718 .23988 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1771 .27801 m
.17765 .27707 L
s
.86785 .27962 m
.86841 .27745 L
s
0 0 0 r
.87134 .22552 m
.87101 .22963 L
s
.255 .412 .882 r
.1771 .27801 m
.17749 .27653 L
s
0 0 0 r
.17423 .23329 m
.17376 .23944 L
s
.17259 .28317 m
.17318 .28114 L
s
.255 .412 .882 r
.17786 .23589 m
.17821 .2399 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87221 .2769 m
.87219 .27268 L
s
.87237 .28057 m
.87221 .2769 L
s
.17415 .23271 m
.1737 .23886 L
s
.87219 .27268 m
.87249 .2758 L
s
.17259 .28317 m
.17303 .28059 L
s
.87267 .2837 m
.87237 .28057 L
s
.87249 .2758 m
.87251 .28002 L
s
.255 .412 .882 r
.17687 .27693 m
.1771 .27801 L
s
0 0 0 r
.87304 .28206 m
.87267 .2837 L
s
.17376 .23944 m
.17322 .24986 L
s
.255 .412 .882 r
.17567 .29232 m
.178 .23819 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17235 .28208 m
.17259 .28317 L
s
.255 .412 .882 r
.86881 .29398 m
.86884 .29087 L
s
.86881 .29398 m
.86906 .29603 L
s
0 0 0 r
.1737 .23886 m
.17317 .24929 L
s
.255 .412 .882 r
.1767 .27271 m
.17687 .27693 L
s
.17562 .29179 m
.17795 .23761 L
s
.86884 .29087 m
.86907 .29292 L
s
.86906 .29603 m
.86907 .29292 L
s
0 0 0 r
.17232 .27729 m
.17235 .28208 L
s
.17223 .27674 m
.17235 .28208 L
s
.87308 .27727 m
.87304 .28206 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17322 .24986 m
.1729 .25721 L
s
.255 .412 .882 r
.86764 .23844 m
.86781 .24472 L
s
.86781 .24472 m
.8681 .253 L
s
.17679 .26645 m
.1767 .27271 L
s
.8681 .253 m
.86832 .25815 L
s
0 0 0 r
.17317 .24929 m
.17285 .25664 L
s
.1729 .25721 m
.17248 .26881 L
s
.17248 .26881 m
.17232 .27729 L
s
.87249 .25719 m
.87291 .26879 L
s
.87291 .26879 m
.87308 .27727 L
s
.255 .412 .882 r
.86764 .23787 m
.86784 .24415 L
s
.86784 .24415 m
.86814 .25244 L
s
.86752 .23415 m
.86764 .23844 L
s
.86814 .25244 m
.86836 .25759 L
s
0 0 0 r
.17285 .25664 m
.17242 .26826 L
s
.17242 .26826 m
.17223 .27674 L
s
.17405 .22437 m
.17439 .22024 L
s
.87107 .22081 m
.87134 .22435 L
s
.255 .412 .882 r
.86752 .23415 m
.86764 .23787 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86836 .25759 m
.86872 .26477 L
s
.86832 .25815 m
.8687 .26533 L
s
0 0 0 r
.87121 .22787 m
.87345 .27931 L
s
.87126 .22728 m
.8735 .27876 L
s
.255 .412 .882 r
.8687 .26533 m
.86897 .26939 L
s
.86745 .233 m
.86752 .23415 L
s
0 0 0 r
.87358 .27711 m
.87345 .27931 L
s
.255 .412 .882 r
.86872 .26477 m
.86897 .26884 L
s
0 0 0 r
.17074 .3005 m
.17413 .2226 L
s
.255 .412 .882 r
.17553 .29018 m
.17567 .29232 L
s
.8674 .23386 m
.86745 .233 L
s
0 0 0 r
.17079 .29996 m
.17418 .22201 L
s
.255 .412 .882 r
.86897 .26939 m
.86907 .27034 L
s
.86897 .26884 m
.86907 .27034 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87125 .22258 m
.87371 .28599 L
s
.87129 .22317 m
.8742 .29725 L
s
.255 .412 .882 r
.1777 .23962 m
.17807 .2333 L
s
.17731 .24794 m
.1777 .23962 L
s
.8674 .23386 m
.86745 .23788 L
s
.17709 .25312 m
.17731 .24794 L
s
.86897 .26868 m
.86907 .27034 L
s
.17777 .23905 m
.17816 .23273 L
s
.17737 .24738 m
.17777 .23905 L
s
.17807 .2333 m
.17848 .22899 L
s
.17681 .26035 m
.17709 .25312 L
s
.17714 .25256 m
.17737 .24738 L
s
0 0 0 r
.87108 .23834 m
.87211 .24353 L
s
.255 .412 .882 r
.17816 .23273 m
.17848 .22899 L
s
.17688 .25979 m
.17714 .25256 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17673 .26444 m
.17681 .26035 L
s
.17848 .22899 m
.17873 .22783 L
s
.86873 .26498 m
.86897 .26868 L
s
0 0 0 r
.17483 .21787 m
.17601 .21372 L
s
.255 .412 .882 r
.86821 .25402 m
.8684 .25717 L
s
.8684 .25717 m
.86843 .25922 L
s
.17682 .26389 m
.17688 .25979 L
s
.86821 .25402 m
.86823 .25605 L
s
0 0 0 r
.86937 .2137 m
.87042 .21726 L
s
.255 .412 .882 r
.86834 .25866 m
.86873 .26498 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17067 .3021 m
.17079 .29996 L
s
.255 .412 .882 r
.86823 .25605 m
.86834 .25866 L
s
.17673 .26444 m
.17692 .26539 L
s
.17682 .26389 m
.17692 .26539 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86619 .22607 m
.86623 .2307 L
s
.86619 .22607 m
.86663 .23648 L
s
0 0 0 r
.86976 .21489 m
.8742 .29725 L
s
.255 .412 .882 r
.17692 .26539 m
.17717 .26428 L
s
.86623 .2307 m
.86663 .23648 L
s
.86594 .22752 m
.86623 .2307 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17758 .26056 m
.17717 .26428 L
s
.86702 .24896 m
.8673 .25213 L
s
.8673 .25213 m
.86753 .25736 L
s
.86713 .25157 m
.86742 .25475 L
s
.86652 .24521 m
.86702 .24896 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86746 .25943 m
.86753 .25736 L
s
.86663 .24783 m
.86713 .25157 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17142 .2962 m
.17203 .29404 L
s
.17698 .22136 m
.17788 .21271 L
s
.17623 .23316 m
.17698 .22136 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17203 .29404 m
.17544 .2155 L
s
.17186 .29458 m
.17527 .21609 L
s
.17788 .21271 m
.17899 .2072 L
s
.1759 .24066 m
.17623 .23316 L
s
.17726 .22077 m
.17818 .21212 L
s
.1765 .23258 m
.17726 .22077 L
s
.17818 .21212 m
.17899 .2072 L
s
.17617 .24008 m
.1765 .23258 L
s
.17569 .25136 m
.1759 .24066 L
s
.17597 .2508 m
.17617 .24008 L
s
.17899 .2072 m
.17967 .20601 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17569 .25136 m
.17594 .25778 L
s
.17967 .20601 m
.18024 .20858 L
s
.17967 .20601 m
.18063 .20799 L
s
.17597 .2508 m
.17624 .25722 L
s
.18024 .20858 m
.1807 .21492 L
s
.17594 .25778 m
.17672 .25989 L
s
.18063 .20799 m
.18111 .21433 L
s
.17624 .25722 m
.17672 .25989 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18062 .22565 m
.1807 .21492 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17672 .25989 m
.17741 .25877 L
s
.18104 .22507 m
.18111 .21433 L
s
.1803 .23321 m
.18062 .22565 L
s
.17741 .25877 m
.17831 .25386 L
s
.17741 .25877 m
.17869 .2533 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18072 .23264 m
.18104 .22507 L
s
.17941 .24515 m
.1803 .23321 L
s
.17831 .25386 m
.17941 .24515 L
s
.17982 .24458 m
.18072 .23264 L
s
.17869 .2533 m
.17982 .24458 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18427 .1995 m
.18791 .19539 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18351 .251 m
.18576 .19774 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18404 .25044 m
.18628 .19715 L
s
.18201 .25266 m
.18404 .25044 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19025 .19305 m
.19478 .18898 L
s
.18452 .23896 m
.18528 .2455 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19038 .23339 m
.19212 .1913 L
s
.18528 .2455 m
.18682 .24769 L
s
.19103 .23283 m
.19277 .19072 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18682 .24769 m
.18802 .24659 L
s
.18802 .24659 m
.18942 .24164 L
s
.18802 .24659 m
.19006 .24109 L
s
.18942 .24164 m
.19038 .23339 L
s
.19763 .18667 m
.20305 .18267 L
s
.19006 .24109 m
.19103 .23283 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19769 .23897 m
.19988 .18495 L
s
.19847 .23843 m
.20065 .18438 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20577 .19444 m
.20633 .19405 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19543 .24059 m
.19847 .23843 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20978 .18202 m
.21271 .17648 L
s
.20858 .19031 m
.20978 .18202 L
s
.19598 .26287 m
.19691 .25844 L
s
.19598 .26287 m
.19659 .26626 L
s
.20689 .23311 m
.20858 .19031 L
s
.19691 .25844 m
.19753 .26183 L
s
.2107 .18146 m
.21271 .17648 L
s
.20948 .18975 m
.2107 .18146 L
s
.2078 .23258 m
.20948 .18975 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19659 .26626 m
.19753 .26183 L
s
.21271 .17648 m
.21461 .17537 L
s
.21461 .17537 m
.21741 .1776 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20425 .2347 m
.2078 .23258 L
s
.21741 .1776 m
.21913 .1843 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21958 .17262 m
.22375 .17045 L
s
.21749 .22738 m
.21958 .17262 L
s
.21852 .22687 m
.2206 .17208 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21446 .22893 m
.21852 .22687 L
s
.22922 .16778 m
.23006 .17507 L
s
.22864 .18343 m
.22922 .16778 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22864 .18343 m
.23006 .17507 L
s
.23006 .17507 m
.23134 .17063 L
s
.23134 .17063 m
.2338 .16566 L
s
.2338 .16566 m
.23855 .16358 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22777 .20702 m
.22905 .20257 L
s
.22748 .21491 m
.22777 .20702 L
s
.23855 .16358 m
.24085 .16648 L
s
.22905 .20257 m
.23149 .19761 L
s
.22763 .21096 m
.2289 .20651 L
s
.2289 .20651 m
.23135 .20155 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23149 .19761 m
.23771 .18719 L
s
.22748 .21491 m
.22847 .21837 L
s
.23135 .20155 m
.23757 .19113 L
s
.24085 .16648 m
.24195 .1699 L
s
.22847 .21837 m
.23063 .22133 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24154 .18173 m
.24195 .1699 L
s
.23771 .18719 m
.24029 .18223 L
s
.23757 .19113 m
.24016 .18618 L
s
.24029 .18223 m
.24167 .17778 L
s
.23063 .22133 m
.23536 .21937 L
s
.24016 .18618 m
.24154 .18173 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23536 .21937 m
.23794 .21442 L
s
.25106 .16245 m
.25252 .15801 L
s
.25106 .16245 m
.25225 .16591 L
s
.25252 .15801 m
.25372 .16147 L
s
.23931 .20995 m
.24084 .20152 L
s
.24028 .21743 m
.24084 .20152 L
s
.23794 .21442 m
.23931 .20995 L
s
.23931 .20995 m
.24028 .21743 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25225 .16591 m
.25372 .16147 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25129 .23324 m
.25158 .18573 L
s
.24861 .23415 m
.25158 .18573 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24995 .2337 m
.25076 .20964 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24861 .23415 m
.24967 .24175 L
s
.24967 .24175 m
.25129 .23324 L
s
.255 .412 .882 r
.27032 .19556 m
.27056 .19506 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7638 .15636 m
.76521 .15281 L
s
.76356 .14838 m
.76521 .15281 L
s
.76213 .15192 m
.76356 .14838 L
s
.76213 .15192 m
.7638 .15636 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74607 .14363 m
.74945 .14847 L
s
.74945 .14847 m
.75118 .1529 L
s
.75118 .1529 m
.75153 .16494 L
s
.73943 .14199 m
.74607 .14363 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76441 .17638 m
.76742 .22525 L
s
.76432 .22443 m
.76441 .17638 L
s
.7499 .16453 m
.75141 .16093 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76514 .20054 m
.76588 .22484 L
s
.75002 .16855 m
.75153 .16494 L
s
.74674 .16774 m
.7499 .16453 L
s
.73616 .1452 m
.73943 .14199 L
s
.74686 .17177 m
.75002 .16855 L
s
.73862 .17383 m
.74674 .16774 L
s
.73457 .14883 m
.73616 .1452 L
s
.73873 .17788 m
.74686 .17177 L
s
.75071 .19279 m
.75211 .1851 L
s
.75211 .1851 m
.75257 .2013 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73264 .14039 m
.73457 .14883 L
s
.73264 .14039 m
.73307 .1565 L
s
.73307 .1565 m
.73457 .14883 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76432 .22443 m
.76612 .23298 L
s
.76612 .23298 m
.76742 .22525 L
s
.74919 .19644 m
.75071 .19279 L
s
.75071 .19279 m
.75257 .2013 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71687 .13698 m
.72397 .13847 L
s
.746 .19972 m
.74919 .19644 L
s
.73532 .17711 m
.73862 .17383 L
s
.73543 .18117 m
.73873 .17788 L
s
.73928 .19819 m
.746 .19972 L
s
.73371 .18079 m
.73532 .17711 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31814 .17788 m
.31818 .17638 L
s
.31646 .17697 m
.31647 .17668 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73382 .18485 m
.73543 .18117 L
s
.73371 .18079 m
.73393 .18892 L
s
.71338 .1403 m
.71717 .1491 L
s
.70782 .1352 m
.71338 .1403 L
s
.73575 .19336 m
.73928 .19819 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70415 .13451 m
.70782 .1352 L
s
.73393 .18892 m
.73575 .19336 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70053 .13788 m
.70415 .13451 L
s
.69867 .13755 m
.70415 .13451 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69885 .14566 m
.70053 .13788 L
s
.69698 .14534 m
.69867 .13755 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69698 .14534 m
.69796 .19027 L
s
.69885 .14566 m
.69985 .19058 L
s
.71687 .13698 m
.71827 .19386 L
s
.71866 .13735 m
.72006 .1942 L
s
.71282 .19284 m
.72006 .1942 L
s
.67173 .1292 m
.6834 .13096 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65176 .12656 m
.66381 .1281 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69226 .18936 m
.69985 .19058 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66145 .1605 m
.66159 .16007 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6558 .12706 m
.68067 .18762 L
s
.67281 .18653 m
.68456 .18819 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63544 .1288 m
.63969 .13742 L
s
.62916 .12409 m
.63544 .1288 L
s
.62916 .12409 m
.63337 .12859 L
s
.62498 .12369 m
.62916 .12409 L
s
.63337 .12859 m
.63763 .1372 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63969 .13742 m
.64193 .14995 L
s
.62084 .1274 m
.62498 .12369 L
s
.61874 .12722 m
.62498 .12369 L
s
.63763 .1372 m
.63987 .14973 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61673 .13524 m
.62084 .1274 L
s
.61461 .13506 m
.61874 .12722 L
s
.64193 .14995 m
.64206 .15817 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63987 .14973 m
.63999 .15795 L
s
.59316 .12122 m
.60172 .12179 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64018 .17032 m
.64206 .15817 L
s
.6527 .18405 m
.66484 .1855 L
s
.6588 .18476 m
.67954 .13036 L
s
.65677 .18452 m
.67759 .13006 L
s
.61476 .1474 m
.61673 .13524 L
s
.6381 .17011 m
.63999 .15795 L
s
.61264 .14723 m
.61461 .13506 L
s
.255 .412 .882 r
.56985 .13275 m
.56992 .13275 L
s
0 0 0 r
.58454 .12071 m
.58889 .12506 L
s
.58021 .12048 m
.58454 .12071 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46858 .12032 m
.50353 .11919 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57373 .12428 m
.58021 .12048 L
s
.5759 .12438 m
.58021 .12048 L
s
.58889 .12506 m
.59326 .13353 L
s
.63615 .17817 m
.64018 .17032 L
s
.61476 .1474 m
.61485 .15564 L
s
.63406 .17797 m
.6381 .17011 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43012 .16072 m
.43023 .16304 L
s
.42938 .16256 m
.42951 .16075 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61264 .14723 m
.61273 .15548 L
s
.5716 .13241 m
.5759 .12438 L
s
.56942 .13232 m
.57373 .12428 L
s
.54749 .1193 m
.55625 .11952 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55269 .15883 m
.55271 .16395 L
s
.55487 .16026 m
.55488 .16401 L
s
0 0 0 r
.50134 .11923 m
.50347 .14391 L
s
.50347 .14391 m
.50353 .11919 L
s
.53651 .11912 m
.54311 .12332 L
s
.53211 .11907 m
.53651 .11912 L
s
.61485 .15564 m
.61712 .16821 L
s
.52772 .12315 m
.53211 .11907 L
s
.52552 .12315 m
.53211 .11907 L
s
.61273 .15548 m
.615 .16804 L
s
.62993 .18173 m
.63615 .17817 L
s
.54311 .12332 m
.54753 .13164 L
s
.5695 .14469 m
.5716 .13241 L
s
.56731 .1446 m
.56942 .13232 L
s
.52552 .13138 m
.52772 .12315 L
s
.62993 .18173 m
.63406 .17797 L
s
.52332 .13138 m
.52552 .12315 L
s
.61712 .16821 m
.62146 .17684 L
s
.615 .16804 m
.61934 .17667 L
s
.62573 .18135 m
.62993 .18173 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62146 .17684 m
.62573 .18135 L
s
.61934 .17667 m
.62573 .18135 L
s
.5695 .14469 m
.56955 .15295 L
s
.56731 .1446 m
.56736 .15287 L
s
.255 .412 .882 r
.48778 .15877 m
.48958 .16113 L
s
.48776 .1636 m
.48958 .16113 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54968 .11935 m
.54988 .17726 L
s
.54749 .1193 m
.54767 .17722 L
s
.52552 .13138 m
.52554 .17697 L
s
.52332 .13138 m
.52332 .17696 L
s
.49012 .18156 m
.49026 .14833 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5893 .17462 m
.59356 .16656 L
s
.56736 .15287 m
.56962 .16539 L
s
.56955 .15295 m
.57181 .16547 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47457 .20715 m
.4751 .12002 L
s
.47677 .20707 m
.47727 .11993 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57181 .16547 m
.57623 .17397 L
s
.58499 .17854 m
.5893 .17462 L
s
.56962 .16539 m
.57405 .17388 L
s
.47701 .16534 m
.49019 .16491 L
s
.57623 .17397 m
.58063 .17833 L
s
.58063 .17833 m
.58499 .17854 L
s
.57405 .17388 m
.58063 .17833 L
s
.54104 .1771 m
.54988 .17726 L
s
.51668 .17698 m
.52554 .17697 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5011 .20643 m
.50338 .18128 L
s
.50332 .2064 m
.50338 .18128 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59316 .12122 m
.59393 .20824 L
s
.5953 .12135 m
.5961 .20837 L
s
.5874 .20789 m
.5961 .20837 L
s
.46798 .20742 m
.50332 .2064 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA2@00000=0?nV40<000001@3o
YQ02000001h0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd4
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA0140ojHA2P0000070:f][@8000002`2][Jd2000000<0[Jf]0P000003
0:f][@D000002`2][Jd3000000<0ojD@0`0000070?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[
0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@l0[Jf]00<0ojHA0000
00000000103oYQ400`2][Jd0ojH@0?nV40040?nV408000002P3oYQ02000000H0ojH@00<000000?nV
403oYQ000P00000<0?nU4080000000@0ojD@0:f][@2][Jd000000P2][Jd2000000040:f][@000000
0000000000T0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]403oYQ42
000000@0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000X0ojH@0P0000070?nV40040000003oYQ00
0000000000/0ojD@0P0000050?nU40040000003oYA000000000000P0ojD@00<0[Jf]0?nS403oXa00
0P3oXa04000000D0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103o
YQ400`2][Jd0ojHA0?nV4@0E0?nV4@800000103oYQ400`2][Jd0ojH@0?nV40040?nV408000002@3o
YQ02000000P0ojH@00@000000?nV4000000000002P3oYA02000000H0ojD@00@000000?nU40000000
0000203oYA000`2][Jd0oj<@0?nS4003000000<0oj<@0P0000030?nS40H0[Jf]0`0000000`2][Jd0
oj<@0?nS40020?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00@0ojH@0P0000090?nV40800000
2@3oYQ03000000X0ojD@0P0000070?nU40<00000203oYA00102][Jd0oj<@0000000000060?nS4080
00002P3oXa0500000080[Jf]0`00000G0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh20:f][F40/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ405@3oYQ470:f][AP0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ42000000@0ojHA
00<0[Jf]0?nV403oYQ00103oYQ02000000T0ojH@0P0000090?nV40<000002@3oYA02000000P0ojD@
0`0000080?nU40040:f][@3oXa000000000000L0oj<@0P00000:0?nS40030000003oXa00oj<@0080
oj<@00@0[Jf]0?bP403lX100[Jf]100000000`2][Jd0o:0@0?bP400@0?bP40030:f][@3fW0l0mY`?
01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ450:f][@80ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@800000103oYQ400`2][Jd0ojH@0?nV40050?nV4003
0000003oYQ00ojH@00L0ojH@0P00000:0?nV408000002@3oYA02000000T0ojD@0P0000080?nU4003
0:f][@000000000000P0oj<@0P00000:0?nS40030000003oXa00oj<@0080oj<@00@0[Jf]0?bP403l
X100o:0@0P0000030?bP40D0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@800000103oYQ400`2][Jd0
ojH@0?nV40050?nV40030000003oYQ00ojH@00L0ojH@0P00000:0?nV408000002@3oYA02000000T0
ojD@0P0000080?nU40030:f][@000000000000T0oj<@0P00000:0?nS40050000003oXa00oj<@0?nS
402][Jd00P3lX102000000T0o:0@102][Jd2000000L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80
[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3o
YQ401@3oYQ460:f][@`0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@80
0000103oYQ400`2][Jd0ojH@0?nV40050?nV40030000003oYQ00ojH@00L0ojH@0P00000:0?nV4080
00002@3oYA02000000T0ojD@0P0000080?nU40030:f][@000000000000X0oj<@0P0000090?nS4005
0000003oXa00oj<@0?nS402][Jd00P3lX102000000/0o:0@0P0000000`3lX100[Jf]000000030:f]
[@80000000<0o:0@0:f][@3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00D0
ojH@00<000000?nV403oYQ001`3oYQ02000000X0ojH@0P0000080?nU408000002P3oYA02000000P0
ojD@00<0[Jf]0000000000002P3oXa02000000T0oj<@00D000000?nS403oXa00oj<@0:f][@020?bP
408000002P3lX102000000@0o:0@00<000000?bP403lX100100000000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0
/>3V0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1440:f][AL0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@800000103oYQ400`2][Jd0
ojH@0?nV40050?nV40030000003oYQ00ojH@00L0ojH@0P00000:0?nV40800000203oYA02000000X0
ojD@0P0000080?nU408000002`3oXa02000000X0oj<@00D000000?nS403oXa00[Jf]0?bP40020000
00/0o:0@0P0000050?bP40070000003lX10000000000003lX100[Jf]0?JL3`030:f][@030000003f
W0l0mY`?00l0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`
h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?
0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40
ojHA01H0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00D0ojH@00<000000?nV403oYQ001`3oYQ02
000000X0ojH@0P0000080?nU408000002P3oYA02000000P0ojD@0P00000;0?nS408000002P3oXa00
1@000000oj<@0?nS402][Jd0o:0@008000002P3lX102000000H0o:0@00H000000?bP400000000000
0?bP402][Jd40?JL3`030000002][Jd0[Jf]008000003@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@800000103oYQ400`2][Jd0ojH@
0?nV40050?nV40030000003oYQ00ojH@00L0ojH@0P00000:0?nV40800000203oYA02000000X0ojD@
0P0000080?nU40800000303oXa02000000X0oj<@00<000000?nS402][Jd00P00000;0?bP40800000
1`3lX103000000030?bP402][Jd0mY`?00<0mY`?00<000000?JL3`0000000P3fW0l200000080[Jf]
2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0
D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA01H0ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00l0ojH@0P00
000:0?nV40800000203oYA02000000X0ojD@0P0000080?nU40800000303oXa02000000X0oj<@00<0
00000?nS402][Jd00P00000;0?bP408000001`3lX103000000030?bP402][Jd0mY`?00<0mY`?0P00
00050?JL3`030000003fW0l0[Jf]00<0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@800000103oYQ400`2][Jd000000?nV400?
0?nV408000002P3oYQ02000000P0ojD@0P00000:0?nU40800000203oYA02000000`0oj<@0P00000:
0?nS40030000003oXa00oj<@008000002`3lX102000000P0o:0@0P0000000`3lX100[Jf]0?JL3`03
0?JL3`8000001P3fW0l00`000000mY`?0?JL3`020?JL3`80[Jf]00@000000:f][@3fW0l0[Jf]4P3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]
0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ42
000000@0ojHA00<0[Jf]0000003oYQ003`3oYQ02000000X0ojH@0P0000080?nU408000002P3oYA02
000000P0ojD@0P00000<0?nS408000002`3oXa03000000`0o:0@0P0000080?bP4080000000<0o:0@
0:f][@3fW0l00`3fW0l2000000H0mY`?00<000000?JL3`3fW0l00`3fW0l2000000040?JL3`2][Jd0
[Jf]0:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo
001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01H0ojHA
0P0000040?nV4@030:f][@000000ojH@00l0ojH@0P00000:0?nV40800000203oYA02000000X0ojD@
0P0000080?nU40800000303oXa02000000/0oj<@0`00000<0?bP40800000203lX102000000030?bP
402][Jd0mY`?00<0mY`?00<000000?JL3`3fW0l01P3fW0l00`000000mY`?0?JL3`020?JL3`060000
003fW0l000000?JL3`2][Jd0k9H>0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue
2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V100
0`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ42000000@0ojHA00<0[Jf]
0000003oYQ003`3oYQ02000000X0ojH@0P0000080?nU408000002P3oYA02000000P0ojD@0P00000<
0?nS40800000303oXa02000000`0o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l00`3fW0l0
0`000000mY`?0?JL3`060?JL3`030000003fW0l0mY`?0080mY`?0P0000020?JL3`030:f][@3/UPh0
k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/2
0:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01D0ojHA00<0[Jf]0000
000000001@2][Jd00`000000[Jf]0:f][@0>0:f][@8000002P2][Jd00`000000[Jf]0:f][@060:f]
[@030?nU40000000000000X0ojD@0P0000080?nU40800000303oXa02000000/0oj<@0P0000000`2]
[Jd0o:0@0?bP400:0?bP40800000203lX102000000030?bP402][Jd0mY`?00<0mY`?00<000000?JL
3`3fW0l01P3fW0l00`000000mY`?0?JL3`030?JL3`040000003fW0l0mY`?0:f][@H0k9H>0`2][Jd9
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP19
0;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP40060?bP40030000002][Jd0[Jf]00H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f]
[@030?nV4@000000000000@0ojHA00<0[Jf]0000003oYQ003`3oYQ02000000X0ojH@00<000000:f]
[@3oYA001P3oYA000`2][Jd000000000000:0:f][@80000000<0[Jf]0?nU403oYA001@3oYA020000
00`0oj<@0P00000;0?nS4080000000<0[Jf]0?bP403lX1002P3lX102000000P0o:0@0P0000000`3l
X100[Jf]0?JL3`0<0?JL3`030000003fW0l0mY`?00H0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V
04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00@0o:0@00<0[Jf]000000000000203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4<0:f][A40ojHA0P0000040?nV4@03
0:f][@000000ojH@00l0ojH@0P00000:0?nV40030000002][Jd0ojD@00P0ojD@0P0000090?nU4080
000000<0ojD@0:f][@2][Jd01@2][Jd2000000<0[Jf]2@3oXa02000000X0oj<@0P0000000`3oXa00
00000?bP400;0?bP40800000203lX102000000030?bP402][Jd0mY`?00`0mY`?00<000000?JL3`3f
W0l01P3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>
0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP40000000o:0@0`2][Jd00`3lX100
0000000000080?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@800000103oYQ400`2][Jd0
00000?nV400?0?nV408000002P3oYQ000`000000[Jf]0?nU40080?nU408000002@3oYA02000000P0
ojD@00<0[Jf]0000003oXa000P3oXa090:f][@8000002P3oXa02000000030?nS40000000o:0@00/0
o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l02`3fW0l2000000P0mY`?00<0[Jf]0>bF3P3/
UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
2`3_V103000000030:f][@3lX100o:0@0080o:0@0P0000080?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3@3oYQ400`2][Jd0ojHA
0?nV4@0E0?nV4@T00000403oYQ02000000X0ojH@00<000000:f][@3oYA00203oYA02000000T0ojD@
0P0000080?nU40030:f][@000000000000X0oj<@0P00000:0:f][@060?nS4000000000000?nS402]
[Jd000002`3lX102000000P0o:0@0P0000000`3lX100[Jf]0?JL3`0;0?JL3`800000203fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?oo
o`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V1001@000000[Jf]0:f][@3lX1000000
00D0o:0@00<000000?bP403lX1001P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01H0ojHA1`2][JdG0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@000000ojH@
00l0ojH@0P00000:0?nV40030000002][Jd0ojD@00P0ojD@0P00000:0?nU408000001`3oYA000`2]
[Jd000000000000:0?nS408000002P3oXa02000000<0[Jf]00<000000:f][@2][Jd02@3lX1020000
00T0o:0@0P0000000`2][Jd0mY`?0?JL3`090?JL3`8000002@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0
dhL>00<0[Jf]0>nH403_V100203_V10200000080[Jf]0P3lX1000`000000o:0@0?bP400<0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ460:f][@80ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@8000001@3oYQ400`2][Jd000000?nV400?0?nV4080
00002P3oYQ000`000000[Jf]0?nU40090?nU40800000203oYA03000000L0ojD@00<0[Jf]00000000
00002P3oXa02000000X0oj<@0P0000020?nS40040:f][@000000o:0@0?bP40H0[Jf]103lX1000`00
0000o:0@0?bP40070?bP4080000000<0[Jf]0?JL3`3fW0l02@3fW0l2000000T0mY`?00<0[Jf]0>bF
3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2]
[Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_
V1001@3_V1000`000000kiP@0:f][@02000000030>nH402][Jd0o:0@0080o:0@00<000000?bP403l
X1002`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd80?nV4@03
0:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ42000000D0ojHA00<0[Jf]0000003o
YQ003`3oYQ02000000X0ojH@00<000000:f][@3oYA002@3oYA02000000L0ojD@00@000000?nU4000
000000001`3oYA000`2][Jd000000000000:0?nS408000002P3oXa0200000080oj<@00<0[Jf]0?bP
400000001`3lX1040:f][@030000002][Jd0[Jf]00L0o:0@0P0000000`2][Jd0mY`?0?JL3`080?JL
3`8000002P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][Jd70=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0
Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00<0kiP@0P0000020:f][@050>nH400000000000
0>nH402][Jd00`3lX1000`000000o:0@0?bP400;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0E
0?nV4@8000001@3oYQ400`2][Jd000000?nV400?0?nV408000002P3oYQ000`000000[Jf]0?nU400:
0?nU408000001P3oYA0010000000ojD@0000000000070?nU40040:f][@3oXa000000000000P0oj<@
0P00000:0?nS408000000`3oXa000`2][Jd0o:0@0000000;0?bP40030000003lX100o:0@00H0[Jf]
00@0o:0@000000000000[Jf]203fW0l2000000030?JL3`000000mY`?00T0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f]
[@P0dhL>00H0[Jf]0>nH403_V100kiP@0000003_V102000000<0kiP@0P0000000`3_V100[Jf]0?bP
40020?bP40030000003lX100o:0@00/0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@060:f][A80ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@8000001@3o
YQ400`2][Jd000000?nV400?0?nV408000002P3oYQ000`000000[Jf]0?nU400:0?nU408000001@3o
YA000`000000ojD@0?nU4002000000L0ojD@00@0[Jf]0?nS400000000000203oXa02000000X0oj<@
0P0000030?nS40040:f][@3lX100o:0@000000X0o:0@00<000000?bP403lX1001P3lX1000`2][Jd0
0000000000020:f][@H0mY`?00@000000?JL3`3fW0l000002`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF
1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0
1@2][Jd0kiP@0>nH40000000kiP@00<000000`3_V102000000050>nH402][Jd0o:0@0?bP40000000
3P3lX1000`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@000000ojH@00/0ojH@1P0000060?nV40H00000
303oYA02000000<0ojD@00@000000?nU403oYA00ojD@0P0000070?nU40030:f][@3oXa00oj<@0080
00001P3oXa02000000X0oj<@0P0000040?nS40040:f][@3lX100o:0@000000X0o:0@00<000000?bP
403lX1001`3lX102000000030:f][@3fW0l0[Jf]00<0[Jf]0P0000000`3fW0l000000000000:0?JL
3`030000003fW0l0[Jf]0180k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@80fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@080=>73P050:f][@3_V10000000000002][Jd00`0000030>nH40040000003_
V100kiP@0:f][@80o:0@00<000000?bP403lX100303lX1000`2][Jd0oj@A0?nT4@0>0?nT4@@0[Jf]
00<0oj@A0:f][@11JN406@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01D0ojHA
0P0000050?nV4@030:f][@000000ojH@01`0ojH@00<0[Jf]0?nU403oYA00303oYA03000000@0ojD@
0P0000070?nU40040:f][@3oXa00oj<@0?nS40<00000103oXa02000000X0oj<@0P0000040?nS4004
0:f][@3lX100o:0@000000X0o:0@00<000000?bP403lX1001`3lX102000000030:f][@3fW0l0mY`?
0080mY`?00D000000:f][@2][Jd000000:f][@0;0?JL3`030000003fW0l0[Jf]0180k9H>00<0[Jf]
0=^:3@3KRPd02@3KRPd30:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP11
0;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f]
[@030000003_V100kiP@00<000000`3_V10010000000kiP@0>nH402][Jd20?bP40030000003lX100
o:0@00`0o:0@00<0[Jf]0?nT4@3oY1402P3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@000000
ojH@00D0ojH@00<000000?nV403oYQ00503oYQ000`2][Jd0ojD@0?nU400C0?nU408000001`3oYA00
0`2][Jd0oj<@0?nS40030?nS408000000P3oXa02000000/0oj<@0P0000040?nS40050:f][@3lX100
o:0@0?bP400000002@3lX1000`000000o:0@0?bP40070?bP4080000000<0[Jf]0?JL3`3fW0l00P3f
W0l300000080mY`?102][Jd70?JL3`030000003fW0l0[Jf]0180k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00L0dhL>00D000000=>73P2][Jd0kiP@
000000030>nH408000000`3_V10010000000kiP@0>nH402][Jd20?bP40030000003lX100o:0@00`0
o:0@00<0[Jf]0?nT4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@00D0
ojH@00<000000?nV403oYQ00503oYQ000`2][Jd0ojD@0?nU400C0?nU408000001`3oYA000`2][Jd0
oj<@0?nS40050?nS40800000303oXa02000000D0oj<@00D0[Jf]0?bP403lX100o:0@000000090?bP
40030000003lX100o:0@00L0o:0@0P0000000`2][Jd0mY`?0?JL3`020?JL3`030000003fW0l0mY`?
00H0mY`?102][Jd30?JL3`030000003fW0l0[Jf]0180k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f]
[@P0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h2000000050=>73P2][Jd0[Jf]0>nH400000000`3_V102
000000D0kiP@00<0[Jf]0?bP403lX1000P00000>0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd<
0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0E
0?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV40050?nV40030000003oYQ00ojH@01@0ojH@00<0[Jf]
0?nU403oYA004`3oYA02000000L0ojD@00<0[Jf]0?nS403oXa004@3oXa0700000080oj<@00<0[Jf]
0?bP403lX1000P3lX1000`000000o:0@0?bP40060?bP40030000003lX100o:0@00L0o:0@0P000000
0`2][Jd0mY`?0?JL3`020?JL3`030000003fW0l0mY`?00H0mY`?00@000000?JL3`3fW0l0mY`?0`2]
[Jd00`000000mY`?0:f][@0B0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]
1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P070000003CQ`h000000:f][@3CQ`h0[Jf]000000040>nH
408000001@3_V1001@2][Jd0o:0@0000003lX100000000@0o:0@00<000000?bP403lX1001`3lX100
0`2][Jd0oj@A0:f][@030:f][A00oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@00D0ojH@00<00000
0?nV403oYQ00503oYQ000`2][Jd0ojD@0?nU400C0?nU408000001`3oYA000`2][Jd0oj<@0?nS400J
0?nS40060:f][@00000000000000003lX1000000203lX1000`000000o:0@0?bP40070?bP40800000
00<0[Jf]0?JL3`3fW0l00P3fW0l00`000000mY`?0?JL3`060?JL3`030000003fW0l0mY`?00@0mY`?
00@000000:f][@2][Jd0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue
2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P040000003CQ`h0[Jf]00000080dhL>00<0[Jf]
0000003_V1000`3_V102000000D0kiP@00@0[Jf]0000003lX10000001@3lX1000`000000o:0@0?bP
40060?bP40<0[Jf]503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ405@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ001@3oYQ000`000000ojH@0?nV
400D0?nV40030:f][@3oYA00ojD@01<0ojD@0P0000070?nU40030:f][@3oXa00oj<@01X0oj<@00@0
[Jf]0?bP403lX100o:0@100000030?bP4080000000<0o:0@0000003lX100203lX102000000030:f]
[@3fW0l0mY`?0080mY`?00<000000?JL3`3fW0l01P3fW0l00`000000mY`?0?JL3`040?JL3`040000
003fW0l0[Jf]0>bF3P<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080
^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00
F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]0080dhL>00D000000=>73P2][Jd0dhL>000000020=>7
3P030:f][@000000kiP@00<0kiP@0P0000050>nH40030:f][@000000000000H0o:0@00<000000?bP
403lX1000`3lX1030:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@
00D0ojH@00<000000?nV403oYQ00503oYQ000`2][Jd0ojD@0?nU400C0?nU408000001`3oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@0P0000090?bP4080000000<0[Jf]0?JL
3`3fW0l00P3fW0l00`000000mY`?0?JL3`060?JL3`030000003fW0l0mY`?00@0mY`?00<000000?JL
3`2][Jd0103/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue
2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP
2`2GH0/0Uf0;0:f][@3CQ`h2000000040:f][@3CQ`h0dhL>00000080dhL>00<0[Jf]0000003_V100
0`3_V102000000D0kiP@0P0000070?bP40040000003lX100o:0@0?bP4080[Jf]103lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0E0?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV40050?nV40030000003oYQ00ojH@01@0
ojH@00<0[Jf]0?nU403oYA004`3oYA02000000L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400B0?bP4080000000@0o:0@000000000000[Jf]1@3fW0l00`000000mY`?0?JL3`050?JL
3`030000003fW0l0mY`?00@0mY`?00<000000?JL3`2][Jd01P3/UPh30:f][@T0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f]
[D80/>3V0@3oool005T0/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@000000[Jf]000000<0dhL>00D0
00000=>73P3CQ`h0[Jf]000000040>nH408000001@3_V102000000L0o:0@00@000000:f][@2][Jd0
[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@800000302][Jd2000001h0[Jf]3P3oYA02000000L0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400D0?bP40<0000000<0o:0@0:f][@3f
W0l0103fW0l00`000000mY`?0?JL3`030?JL3`<000001@3fW0l00`000000mY`?0:f][@090>bF3P<0
[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80
[Jf]@P2`h>H10?ooo`00F@2`h>H0202][Jd0Uf0;09MP2`2GH0/000000:f][@3CQ`h000000`3CQ`h0
1@000000dhL>0=>73P2][Jd0000000@0kiP@0P0000040>nH408000001P3lX1020:f][@030000003l
X100o:0@00L0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@8000001@3oYQ400`2][Jd0ojH@0?nV
40040?nV408000005P3oYQ000`2][Jd0ojD@0?nU40050?nU40h0[Jf]0P0000070?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`030?JL3`030000003f
W0l0mY`?00<0mY`?0`0000050?JL3`030000003fW0l0[Jf]00`0k9H>0P2][Jd40>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`
h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P0000020=>73P050000003CQ`h0
dhL>0=>73P0000000P3CQ`h00`2][Jd000000>nH40030>nH40800000103_V102000000@0o:0@0P2]
[Jd20?bP40030000003lX100o:0@00L0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Jd@0?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV
40040?nV408000005P3oYQ000`2][Jd0ojD@0?nU400C0?nU40800000302][JdH0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l500000080mY`?00<000000?JL3`3fW0l00`3f
W0l00`000000mY`?0:f][@0>0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0
Uf0;0:f][@0000000P3CQ`h02@000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@000000030>nH
40800000103_V102000000050:f][@3lX100[Jf]0:f][@000000103lX1000`000000o:0@0?bP4007
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<
0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV4004
0?nV408000005P3oYQ000`2][Jd0ojD@0?nU400C0?nU408000001`3oYA000`2][Jd0oj<@0?nS4002
0?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?00<00000
0?JL3`3fW0l00`3fW0l00`000000mY`?0:f][@0A0>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
0:f][@0000000P3CQ`h02@000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@000000030>nH4080
0000103_V10200000080[Jf]0P3lX1000`000000o:0@0?bP40020?bP40030000003lX100o:0@00L0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080
ojHA2P2][Jd>0?nV4@030:f][@3oYQ40ojHA01D0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@00@0
ojH@0P00000F0?nV40030:f][@3oYA00ojD@01<0ojD@0P0000070?nU40030:f][@3oXa00oj<@00`0
oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04@3fW0l200000003
0:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`030:f][@28EPL0[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0
Uf0;0:f][@2GH0/000000080dhL>00T000000=>73P3CQ`h0dhL>0000003CQ`h0[Jf]0>nH40000000
0`3_V102000000<0kiP@0P0000020:f][@<0o:0@00<000000?bP403lX1000P3lX1000`000000o:0@
0?bP40070?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ480:f][AP0ojHA
00<0[Jf]0?nV4@3oYQ405@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000001H0ojH@
00<0[Jf]0?nU403oYA004`3oYA02000000L0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AL0o:0@
00<0[Jf]0?JL3`3fW0l04@3fW0l2000000030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0
fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2]
[Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP80000000<0[Jf]09MP2`0000000P3CQ`h02@000000
dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@000000030>nH408000000P3_V1001@2][Jd000000000
003_V100[Jf]0080o:0@0P0000040?bP40030000003lX100o:0@00H0o:0@00<0[Jf]0?nT4@3oY140
503oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA0180ojHA4`00000F0?nV40030:f][@3oYA00ojD@01<0ojD@0P0000070?nU40030:f]
[@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?0140
mY`?0P0000000`3fW0l0[Jf]0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@03
0:f][@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool0
05T0/>3V0P00000209MP2`040000003CQ`h0dhL>000000<0dhL>00D000000=>73P2][Jd0kiP@0000
00030>nH408000000P2][Jd01@3_V10000000>nH403_V100[Jf]0080o:0@0P0000040?bP40030000
003lX100o:0@00H0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]
2@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400@0?nU40D000001`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00P0o:0@1P2][Jd:0?bP40030:f][@3fW0l0mY`?0140mY`?0P0000000`3fW0l0[Jf]
0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;
00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005T0/>3V0P0000000`2GH0/0
0000000000020=>73P090000003CQ`h0dhL>0=>73P000000dhL>0:f][@3_V100000000<0kiP@0P00
00030>nH40040000003_V100kiP@0:f][@80o:0@0P0000030?bP40800000203lX1000`2][Jd0oj@A
0?nT4@0D0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]403oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3f
W0l04@3fW0l2000000030?JL3`2][Jd0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00
F02`h>H30000000509MP2`00000000000=>73P0000000`3CQ`h010000000dhL>0=>73P2][Jd20000
00030>nH402][Jd0[Jf]008000000`3_V10010000000kiP@0>nH402][Jd20?bP408000000`3lX102
000000P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][JdA0?JL3`80000000<0mY`?
0:f][@3/UPh0403/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/01`2iM@/0
0`2][Jd0R5H708QF1`0308QF1`030:f][@000000/>3V0400/>3V0@3oool005L0/>3V100000001@2G
H0/000000000003CQ`h0000000<0dhL>00@000000=>73P3CQ`h0[Jf]0P0000000`2][Jd0kiP@0>nH
4002000000<0kiP@00@000000>nH403_V100[Jf]0P3lX102000000<0o:0@0P0000080?bP40030:f]
[@3oY140oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0[Jf]
3@3fW0l2000000030?JL3`2][Jd0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@T0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000;3PiP100;3PiP40oooo001G0;3PiP80000000<0
[Jf]0000002GH0/00P0000000`3CQ`h000000=>73P020=>73P040000003CQ`h0dhL>0:f][@800000
0`3_V102000000<0kiP@00P000000>nH403_V100[Jf]0?bP40000000o:0@000000<0o:0@0P000008
0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l0103fW0l50:f][@P0mY`?0P0000000`3fW0l0[Jf]0>bF3P0@0>bF3P030:f][@3KRPd0
fhX=00`0fhX=0P2][Jd80;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0000002`h>H0@02`h>H1
0?ooo`00E`2`h>H2000000030:f][@000000Uf0;0080000000<0dhL>0000003CQ`h00P3CQ`h01000
0000dhL>0:f][@2][Jd2000000<0kiP@0P0000040>nH40040000003_V100[Jf]000000H0o:0@0P00
00080?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l02@3fW0l50:f][@<0mY`?0P0000000`3fW0l0[Jf]0>bF3P0@0>bF3P030:f][@3K
RPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@000000/>3V0400/>3V0@3oool005L0/>3V0P0000000`2][Jd0000009MP2`02000000030=>73P00
0000dhL>0080dhL>00@000000:f][@3CQ`h0[Jf]0P0000030>nH408000001@3_V102000000L0o:0@
0P0000080?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l03P3fW0l30:f][@80000000<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`03
0:f][@00000000000400/>3V0@3oool005L0/>3V0P0000000`2][Jd0000009MP2`02000000030=>7
3P000000dhL>0080dhL>00@000000=>73P3CQ`h0[Jf]0P0000030>nH408000001P3_V1000`2][Jd0
o:0@0?bP40050?bP40800000203lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0A0?JL3`8000000`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080
R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H2000000080:f][@000000Uf0;0000002]
[Jd0dhL>0000003CQ`h20:f][@040000003CQ`h0dhL>0:f][@8000000`3_V102000000H0kiP@00<0
[Jf]0?bP403lX1001@3lX102000000L0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l04@3fW0l2000000030?JL3`2][Jd0k9H>00<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`030:f]
[@00000000000400/>3V0@3oool005L0/>3V0P000000202][Jd0000009MP2`000000[Jf]0=>73P00
0000[Jf]0P3CQ`h010000000dhL>0=>73P2][Jd2000000<0kiP@0P0000060>nH40030:f][@3lX100
o:0@00D0o:0@0P0000050?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?0140mY`?0P0000000`3fW0l0[Jf]0>bF3P030>bF3P80[Jf]303/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`03
08QF1`030:f][@00000000000400/>3V0@3oool005L0/>3V0P0000001`2][Jd0000009MP2`000000
[Jf]0=>73P0000000`3CQ`h010000000dhL>0=>73P2][Jd200000080kiP@0P0000070>nH40030:f]
[@3lX100o:0@00D0o:0@0P0000020?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04@3fW0l010000000mY`?0?JL3`2][Jd60>bF3P<0
[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`03
0:f][@00000000000400/>3V0@3oool005L0/>3V0P000000102][Jd0000009MP2`0000020:f][@05
0000003CQ`h0dhL>0=>73P0000000P3CQ`h00`2][Jd000000000000;0>nH40030:f][@3lX100o:0@
00D0o:0@0P0000020:f][@H0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?0140mY`?00@000000?JL3`3fW0l0[Jf]2@3/UPh30:f][@H0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]
000000000000@02`h>H10?ooo`00E`2`h>H20000000709MP2`000000Uf0;0000002][Jd0dhL>0000
00030=>73P040000003CQ`h0dhL>0:f][@8000002`3_V1000`2][Jd0o:0@0?bP40040?bP40030:f]
[@000000000000P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0140mY`?00@000000?JL3`3fW0l0
[Jf]303/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]0`28EPL00`2][Jd00000000000100;3PiP40oooo001G0;3PiP80000000L0Uf0;0000002GH0/0
00000:f][@3CQ`h0000000<0dhL>00<000000=>73P2][Jd00P00000<0>nH40040:f][@3lX100o:0@
0?bP40<0[Jf]00<0o:0@000000000000203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@
0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]
0;Ue2`2iM@/01P2iM@/20:f][@<0R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H20000
000509MP2`000000Uf0;0000002][Jd00P0000030=>73P030000003CQ`h0[Jf]00h0kiP@00@0[Jf]
0?bP402][Jd0[Jf]103lX1000`000000o:0@0?bP40070?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2]
[Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P28EPL20:f][@030000002`
h>H0/>3V03h0/>3V0@3oool005L0/>3V1P0000000`2][Jd00000000000030=>73P030000003CQ`h0
[Jf]00d0kiP@0`2][Jd60?bP40030000003lX100o:0@00L0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P28
EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V1P000000102][Jd000000000003C
Q`h200000080dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH402][Jd0o:0@00H0o:0@00<0
00000?bP403lX1001`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V2P2][JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/01@2][Jd0R5H708QF1`2][Jd0R5H70080[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00
EP2`h>H7000000030:f][@000000000000D0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA
202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H7
08QF1`28EPL30:f][@030000002`h>H0/>3V03h0/>3V0@3oool005H0/>3V1`0000000`2][Jd00000
0=>73P050=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd50>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@
00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=
0P2][Jd50=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70`2][Jd00`000000
/>3V0;3PiP0n0;3PiP40oooo001F0;3PiPT000001P3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]
1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f]
[@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP@0000000@0
Uf0;000000000000[Jf]1`3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f]
[@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<00000
0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H40000000309MP2`000000000000P0dhL>00@0[Jf]0>nH
402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg7
0;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd9
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H4
0000000309MP2`000000[Jf]00P0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0303KRPd30:f][@L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3P
iP0n0;3PiP40oooo001F0;3PiP@000000P2GH0/00`2][Jd0dhL>0=>73P050=>73P80[Jf]3P3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2i
M@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0000
000309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3l
X100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/
UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V00<000000:f][@000000
0`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@000000dhL>0=>73P2][Jd03@3_V1000`2][Jd0
o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Jd30;Ue2`04
0:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00<0
Uf0;00L0[Jf]0=>73P3CQ`h0dhL>0:f][@3CQ`h000000080dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`040;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H70P2][Jd2000003l0/>3V0@3o
ool005H0/>3V00<000000:f][@2][Jd00`2GH0/0102][Jd0dhL>0:f][@2][Jd20=>73P040000003C
Q`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0R5H700@0[Jf]045Yh@000000
0000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`80[Jf]103CQ`h010000000dhL>
0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@04
0<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0R5H70080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H00`000000
[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00<0dhL>00@000000=>73P3CQ`h0[Jf]3@3_V1000`2]
[Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@0000000000
03l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0
/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;0P2][Jd308QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/0
0P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]
102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk
00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;
00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3PiP070000002]
[Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402]
[Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0
[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd000000000000o0;3PiP40
oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0
kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0
_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0
_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2][Jd2
000003l0/>3V0@3oool005H0/>3V00@000000:f][@2GH0/0[Jf]0P2GH0/00`2][Jd0dhL>0=>73P06
0=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28
EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001E0;3PiP8000000P2][Jd309MP2`030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37
`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n
^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28
EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005D0/>3V0P0000000`2][Jd0Uf0;09MP2`02
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2a
Zid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f]
[@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000
002`h>H0/>3V03d0/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>
00@0[Jf]0>nH402][Jd0[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@040;6[W@80[Jf]1@2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0
/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0
_[Vh0;ji^02n^KP20:f][@P0_[Vh0P11JN420;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005D0/>3V0P0000001@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd80:BNS`030:f][@2aZid0/J^M00H0/J^M0P2][Jd3
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;
0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=
0<>m^`040:f][@2n^KP0[Jf]0:f][@T0_[Vh0P11JN450;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF
1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00P0dhL>00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@080;6[W@80[Jf]
00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`
1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03033_K/30:f][@L0_[Vh0P11JN430;ji^003045Yh@2d/;40];2a00@0];2a
00<0@FWQ0:f][@2][Jd0202iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0
/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd;0:BNS`03
0:f][@2aZid0/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f]
[@2n^KP01@2n^KP01011JN40_[Vh045Yh@11JN430;ji^003045Yh@2d/;40];2a00@0];2a00@0@FWQ
0;B`/@2d/;40[Jf]1`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V
0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>0`2][Jd20:BNS`03045Y
h@2TWXl0Y9j?00D0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc
202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP00`11JN40_[Vh
045Yh@02045Yh@<0_[Vh00<0@FWQ0:f][@2d/;40102d/;44045Yh@80[Jf]1@2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00@0dhL>00@0[Jf]08Z5M@2:QGD0@FWQ0P2TWXl00`11JN40Y9j?0:BNS`050:BN
S`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3P
iPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP01011JN40_[Vh0;ji^02n^KP2
045Yh@<0_[Vh00<0@FWQ0:f][@2d/;401`2d/;400`2][Jd0@FWQ0:f][@020:f][@<0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001E0;3PiP030000002`h>H0
[Jf]00<0Uf0;00L0[Jf]0=>73P3CQ`h0dhL>0:f][@11JN40RXEe0080@FWQ0P2][Jd00`11JN40Y9j?
0:BNS`050:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]
2`33_K/00`2][Jd0_[Vh0;ji^0020;ji^004045Yh@2n^KP0_[Vh0;ji^080@FWQ0`2n^KP00`11JN40
[Jf]0;B`/@060;B`/@070:f][@2d/;40@FWQ0:f][@2OVj00@FWQ0:f][@020;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@03
09MP2`070:f][@3CQ`h0[Jf]0:f][@2:QGD0@FWQ08Z5M@02045Yh@80Y9j?00<0@FWQ0:BNS`2TWXl0
1@2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@040:f][@2i/ZH0@FWQ045Yh@P0^K:V102][Jd00`2i/ZH0
[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd;0<>m^`04045Yh@33_K/0`kfk0:f]
[@<0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP2045Yh@<0_[Vh00<0@FWQ0:f][@2d/;40102d/;420:f]
[@80];2a00<0@FWQ0:f][@2OVj000P11JN430:f][@@0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?oo
o`00E@2`h>H00`000000[Jf]09MP2`0309MP2`80[Jf]0`2:QGD01011JN40RXEe045Yh@11JN420:BN
S`03045Yh@2][Jd0[Jf]00D0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP03045Y
h@X0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`0;0<>m^`04045Yh@33_K/0`kfk0:f][@<0_[Vh00<0@FWQ
0;ji^02n^KP00`2n^KP01P11JN40_[Vh0;ji^02n^KP0@FWQ0:f][@<0];2a0P2][Jd40;B`/@04045Y
h@2][Jd0Wi^P045Yh@<0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40
oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD00`11JN40RXEe
045Yh@020:BNS`03045Yh@2TWXl0Y9j?0080[Jf]0`2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V0080@FWQ00<0^K:V045Yh@11JN402@2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l
00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/01@33_K/00`11JN40`kfk
0<>m^`020<>m^`04045Yh@33_K/0`kfk0:f][@<0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP00`11JN40
_[Vh0;ji^0020;ji^004045Yh@2d/;40];2a0:f][@<0];2a00H0@FWQ0;B`/@2d/;40@FWQ0:f][@11
JN4509nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP
2`2GH0/20:f][@L0RXEe00@0@FWQ0:BNS`2TWXl0@FWQ102TWXl0102][Jd0Y9j?0:BNS`2][Jd>0;6[
W@030:f][@2i/ZH0^K:V0080@FWQ0`2i/ZH00`11JN40^K:V0;VbYP060;VbYP030:f][@2n]j`0_[N/
00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk
00D0`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@80`kfk00@0[Jf]0;ji^011JN40@FWQ1@2n^KP0
0`11JN40_[Vh0;ji^0020;ji^003045Yh@2][Jd0[Jf]00@0];2a00D0@FWQ0;B`/@11JN40];2a0:f]
[@0609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP
2`2GH0/20:f][@L0RXEe00<0[Jf]0:BNS`11JN401P2TWXl30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH0
0P11JN440;VbYP03045Yh@2i/ZH0^K:V00D0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/
00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l
00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0040:f][@33_K/0@FWQ045Yh@@0`kfk00<0@FWQ0<>m^`33
_K/00P33_K/2045Yh@80`kfk00@0[Jf]0;ji^011JN40@FWQ1@2n^KP3045Yh@030;ji^02][Jd0@FWQ
0080];2a00T0@FWQ0;B`/@2d/;40];2a045Yh@2d/;40@FWQ0;B`/@2][Jd01P2OVj001@11JN40[Jf]
08QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd708Z5M@030:f]
[@2TWXl0@FWQ00P0Y9j?0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V0080@FWQ102i/ZH00`11JN40^K:V
0;VbYP020;VbYP<0@FWQ00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]3`36`;`00`11JN40a/2l
0:f][@02045Yh@D0`kfk0P11JN420<>m^`<0@FWQ0P33_K/0102][Jd0_[Vh045Yh@11JN430;ji^0<0
@FWQ00D0_[Vh0:f][@2][Jd0_[Vh045Yh@020;B`/@80@FWQ0`2d/;401011JN40];2a0;B`/@2][Jd6
09nKX005045Yh@2][Jd0[Jf]08QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1S
H5<20:f][@H0RXEe00@0[Jf]0:BNS`2TWXl0@FWQ202TWXl0102][Jd0/J^M0:f][@2][Jd;0;6[W@03
0:f][@2i/ZH0^K:V0080@FWQ1@2i/ZH00`11JN40^K:V0;VbYP030;VbYP<0@FWQ402n]j`40:f][A40
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0
a/2l0<K0_00<0<K0_080@FWQ00<0a/2l045Yh@2][Jd00P11JN450<>m^`80@FWQ0P33_K/3045Yh@80
`kfk00<0[Jf]0;ji^011JN401P2n^KP20:f][@<0_[Vh00<0@FWQ0;B`/@2d/;400P11JN460;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0
Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD0102][Jd0Y9j?0:BNS`11JN480:BNS`040:f][@2aZid0/J^M
0;6[W@<0[Jf]202aZid00`2][Jd0^K:V0;VbYP02045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH0
0`11JN40[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00X0a/2l0P11JN44
0<K0_080@FWQ1P33_K/2045Yh@80`kfk0`11JN420<>m^`030:f][@2n^KP0@FWQ00<0_[Vh0`2][Jd5
0;ji^004045Yh@2d/;40];2a045Yh@L0];2a00<0[Jf]09nKX02OVj00102OVj020:f][@03071^N@2]
[Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]1@2:QGD0102][Jd0Y9j?0:BNS`11
JN480:BNS`030:f][@2aZid0/J^M00@0/J^M0P2][Jd60;6[W@030:f][@2i/ZH0^K:V0080@FWQ1@2i
/ZH00`11JN40^K:V0;VbYP030;VbYP03045Yh@2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[001@31
^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0
[Jf]0<K0_036`;`02P36`;`2045Yh@@0a/2l00<0[Jf]045Yh@33_K/01@33_K/2045Yh@80`kfk0`11
JN420<>m^`040:f][@2n^KP0@FWQ0;ji^080[Jf]202n^KP4045Yh@L0];2a00<0[Jf]09nKX02OVj00
0`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`030:f][@2:QGD0[Jf]00@0RXEe00@0[Jf]0:BNS`2TWXl0@FWQ202TWXl00`2][Jd0/J^M
0;6[W@060;6[W@<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP02045Yh@D0^K:V0P11JN440;VbYP03045Y
h@2n]j`0_[N/00P0_[N/1@11JN440;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k0100b<6k1P2][JdA0<O1_0030:f][@36`;`0@FWQ0080@FWQ2036`;`2045Yh@@0a/2l
00<0[Jf]045Yh@33_K/01@33_K/2045Yh@80`kfk0P11JN401`33_K/0@FWQ0<>m^`2][Jd0_[Vh045Y
h@2][Jd02P2n^KP00`11JN40];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P0080Wi^P00@0[Jf]09nK
X02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102]
[Jd0RXEe08Z5M@2][Jd308Z5M@040:f][@2TWXl0Y9j?045Yh@P0Y9j?00<0[Jf]0;6[W@2aZid02@2a
Zid20:f][@040;6[W@2][Jd0^K:V0;VbYP80@FWQ1@2i/ZH2045Yh@@0^K:V00<0@FWQ0;jg[02n]j`0
202n]j`2045Yh@<0_[N/00@0@FWQ0;jg[02n]j`0_[N/0P11JN4@0<6j/0P0[Jf]4033_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0
b<6k00<0[Jf]0<O1_037`K`04@37`K`3045Yh@X0a/2l0P11JN440<K0_0030:f][@11JN40`kfk00D0
`kfk0P11JN420<>m^`80@FWQ00<0`kfk045Yh@2][Jd00P2][Jd00`11JN40_[Vh0;ji^0070;ji^0<0
@FWQ2P2d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40
oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@04
0:f][@2TWXl0Y9j?045Yh@P0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid30:f][@030;VbYP11JN40@FWQ
00D0^K:V0P11JN440;VbYP03045Yh@2n]j`0_[N/00P0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`01011
JN40_[N/045Yh@2][JdC0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`11JN401@11JN4@0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38
`K/00`2][Jd0al6l0<O1_0080<O1_080@FWQ1`37`K`00`2][Jd0a/2l045Yh@0:0<K0_080@FWQ1036
`;`00`2][Jd0@FWQ0<>m^`040<>m^`80@FWQ00@0`kfk045Yh@33_K/0@FWQ0P2][Jd01011JN40`kfk
0:f][@2n^KP2045Yh@X0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P0:f][@0509nKX003
0:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f]
[@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd00P2TWXl00`11JN40Y9j?0:BNS`060:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2][Jd00P11JN460;VbYP03045Yh@2i/ZH0^K:V0080^K:V
00<0@FWQ0;jg[02n]j`0202n]j`00`11JN40_[N/0;jg[0030;jg[0<0@FWQ00<0[Jf]0<6j/031^[00
1031^[000`11JN40`KZ`0<6j/00:0<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@040:f]
[@36_kL0a[ng0<Jo]`80@FWQ4P36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`01037`K`4045Yh@80
al6l0P11JN450<O1_0030:f][@36`;`0@FWQ00X0a/2l0P11JN440<K0_0030:f][@11JN40`kfk00@0
`kfk0P11JN401033_K/0@FWQ0:f][@11JN420<>m^`04045Yh@33_K/0[Jf]0;ji^080@FWQ2P2n^KP0
0`2][Jd0];2a0;B`/@080;B`/@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]0P2TWXl00`11
JN40Y9j?0:BNS`060:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH00P11JN430:f]
[@<0^K:V00@0@FWQ0;VbYP2i/ZH0^K:V0P11JN4:0;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN40
0`2][Jd0`KZ`0<6j/0040<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[001031^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@040:f][@36_kL0
a[ng0<Jo]`80@FWQ4P36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_0020<O1_0@0@FWQ1@37`K`00`11JN40al6l0<O1_0030<O1_0030:f][@36`;`0@FWQ00X0a/2l0P11
JN440<K0_0030:f][@11JN40@FWQ00@0`kfk00H0@FWQ0:f][@2][Jd0@FWQ0<>m^`11JN420<>m^`04
045Yh@33_K/0[Jf]0;ji^080@FWQ1P2n^KP01@11JN40_[Vh0;ji^02n^KP0[Jf]00X0];2a00<0[Jf]
09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@040:f][@2TWXl0Y9j?045Yh@P0Y9j?00<0
[Jf]0;6[W@2aZid0302aZid0102][Jd0^K:V0;VbYP11JN440;VbYP<0[Jf]00@0@FWQ0;VbYP2i/ZH0
^K:V0P11JN4:0;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN470<6j/003045Yh@31^[00`KZ`00<0
`KZ`00<0@FWQ0<6j/031^[001031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0
aKje2@2][Jd2045Yh@H0[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0
al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037`K`2045Yh@H0
al6l00<0@FWQ0<O1_037`K`00P37`K`00`2][Jd0a/2l045Yh@0;0<K0_003045Yh@36`;`0a/2l0080
a/2l00<0[Jf]045Yh@11JN400P33_K/20:f][@03045Yh@33_K/0`kfk00<0@FWQ0`33_K/00`11JN40
[Jf]0;ji^002045Yh@H0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh0:f][@080;B`/@<0[Jf]1`2OVj001@2]
[Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@07
08Z5M@<0[Jf]2@2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@040:f][@2i/ZH0^K:V045Yh@L0^K:V00@0
@FWQ0:f][@2][Jd0[Jf]0P11JN4:0;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN460<6j/0<0@FWQ
1031^[000`11JN40`KZ`0<6j/0040<6j/0030:f][@33_K<0`kfc00<0`kfc0`11JN430<>m/`03045Y
h@33_K<0`kfc00L0`kfc00<0[Jf]0<Fn]@35_[D04`35_[D00`000000[Jf]0<Jo]`020<Jo]`80@FWQ
1P36_kL`0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00@0al6l0P11JN460<O1_003045Yh@37`K`0al6l0080al6l00<0[Jf]0<K0_011JN40
3036`;`7045Yh@80[Jf]0P33_K/00`11JN40`kfk0<>m^`03045Yh@<0`kfk00<0@FWQ0:f][@2n^KP0
0P11JN450;ji^080@FWQ0`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f][@L0
Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=P
D`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0102]
[Jd0^K:V0;VbYP11JN460;VbYP80@FWQ0`2i/ZH2045Yh@030:f][@2n]j`0_[N/00L0_[N/0P11JN45
0;jg[080@FWQ1P31^[03045Yh@<0`KZ`0`11JN450<6j/0040:f][@33_K<0`kfc0<>m/`80@FWQ0`33
_K<2045Yh@030<>m/`11JN40`kfc00<0`kfc1011JN400`33_K<0[Jf]0<Fn]@0C0<Fn]@0300000035
_[D0[Jf]00<0a[ng0P11JN4B0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037
`K`2045Yh@H0al6l0P11JN430<O1_0030:f][@36`;`0@FWQ00h0a/2l0`2][Jd2045Yh@@0`kfk00@0
@FWQ0<>m^`33_K/0`kfk0P11JN430<>m^`80@FWQ0P2n^KP00`11JN40_[Vh0;ji^0030;ji^080@FWQ
0`2n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f]
[@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@03
0:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@04
0:f][@2i/ZH0^K:V045Yh@H0^K:V0P11JN430;VbYP<0@FWQ102][Jd60;jg[003045Yh@2n]j`0_[N/
00<0_[N/0P11JN460<6j/0<0@FWQ0`31^[03045Yh@D0`KZ`00<0[Jf]0<>m/`33_K<00P11JN460<>m
/`80@FWQ1P33_K<5045YhAD0aKje00@0[Jf]0<Jo]`36_kL0a[ng0P11JN4B0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037`K`2045Yh@H0al6l0P11JN430<O1_0030:f][@36`;`0
@FWQ00T0a/2l1@2][Jd20<K0_0030:f][@11JN40@FWQ00@0`kfk00@0@FWQ0<>m^`33_K/0`kfk0P11
JN401@33_K/0@FWQ045Yh@33_K/0[Jf]0080_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP2045Yh@<0_[Vh
00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`
KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?
00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00@0[Jf]0;VbYP2i/ZH0@FWQ1P2i/ZH2
045Yh@<0^K:V0`11JN440;jg[0@0[Jf]0`2n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ1P31^[00
0`11JN40`KZ`045Yh@030<6j/003045Yh@31^[00@FWQ00D0`KZ`00@0[Jf]0<>m/`33_K<0@FWQ1`33
_K<2045Yh@H0`kfc0P11JN400`33_K<0[Jf]0<Fn]@0<0<Fn]@<0@FWQ1P35_[D0102][Jd0a[ng0<Jo
]`36_kL2045YhA80a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/03@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00@0al6l0P11JN460<O1_080@FWQ0`37`K`0102][Jd0a/2l045Yh@11JN440<K0_0@0
[Jf]1`36`;`00`2][Jd0@FWQ0<>m^`040<>m^`04045Yh@33_K/0`kfk0<>m^`80@FWQ1033_K/0102]
[Jd0_[Vh0;ji^011JN450;ji^080@FWQ0`2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f]
[@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M00/0/J^M00D0
[Jf]0;VbYP2i/ZH0^K:V045Yh@060;VbYP80@FWQ0`2i/ZH3045Yh@<0_[N/00<0@FWQ0;jg[02n]j`0
0P2n]j`40:f][@80@FWQ0P2n]j`2045Yh@H0`KZ`00<0@FWQ0<6j/011JN400`31^[000`11JN40`KZ`
045Yh@050<6j/0030:f][@33_K<0@FWQ00T0`kfc00<0@FWQ0<>m/`33_K<01033_K<2045Yh@030<>m
/`2][Jd0aKje00X0aKje0P11JN430<Fn]@80@FWQ0`35_[D2045Yh@<0a[ng0P11JN420<Jo]`<0@FWQ
2036_kL5045Yh@030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX00P37`KX3045Yh@P0al6j
00<0@FWQ0<O1^P37`KX01@11JN400`2][Jd0b<6k0<S1^`040<S1^`80@FWQ3P38`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00@0al6l0P11JN470<O1_080@FWQ0P37`K`0102][Jd0a/2l
045Yh@11JN440:f][@H0a/2l00<0@FWQ0<K0_036`;`00P36`;`00`2][Jd0@FWQ0<>m^`040<>m^`<0
@FWQ1`33_K/00`2][Jd0_[Vh0;ji^002045Yh@<0_[Vh00<0@FWQ0;ji^011JN400`2n^KP30:f][@P0
];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f]
[@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@d0/J^M00D0[Jf]0;VbYP2i/ZH0
^K:V045Yh@060;VbYP80@FWQ0`2i/ZH2045Yh@030;jg[011JN40_[N/0080@FWQ202n]j`20:f][@@0
@FWQ1@31^[02045Yh@030<6j/011JN40`KZ`0080`KZ`00<0@FWQ0<6j/011JN401@31^[000`2][Jd0
`kfc045Yh@090<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN400`33_K<0[Jf]0<Fn]@090<Fn]@80
@FWQ1P35_[D3045Yh@030<Fn]@2][Jd0a[ng0080a[ng1011JN430<Jo]`80@FWQ2@36_kL4045Yh@<0
al6h1P11JN430<O1^0H0@FWQ0`37`KP00`2][Jd0al6j0<O1^P02045Yh@<0al6j0P11JN460<O1^P03
045Yh@37`KX0@FWQ00D0al6j00<0@FWQ0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`0=0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037`K`2045Yh@L0al6l0P11JN440:f][@80
@FWQ2P36`;`00`11JN40a/2l0<K0_0020<K0_003045Yh@33_K/0`kfk0080`kfk0`11JN490<>m^`03
0:f][@2n^KP0_[Vh0080@FWQ0`2n^KP00`11JN40_[Vh045Yh@020;ji^080[Jf]2P2d/;400`2][Jd0
Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f]
[@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@050:f][@2i/ZH0^K:V0;VbYP11JN401P2i/ZH00`11JN40
^K:V0;VbYP04045Yh@060;jg[011JN40_[N/045Yh@2n]j`0@FWQ102n]j`2045Yh@D0_[N/0P11JN43
0:f][@80`KZ`0P11JN420<6j/006045Yh@31^[00@FWQ045Yh@31^[00@FWQ1@31^[000`2][Jd0`kfc
045Yh@090<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN400`33_K<0[Jf]0<Fn]@090<Fn]@80@FWQ
1P35_[D2045Yh@80aKje00@0[Jf]0<Jo]`36_kL0a[ng0P11JN460<Jo]`80@FWQ2036_kL2045Yh@03
0:f][@37`KP0al6h00@0al6h0P11JN470<O1^080@FWQ1@37`KP0102][Jd0al6j045Yh@11JN450<O1
^P03045Yh@37`KX0al6j00@0al6j0P11JN460<O1^P030:f][@11JN40b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ1037`K`30:f][@80@FWQ0P37`K`0102]
[Jd0a/2l045Yh@11JN440<K0_003045Yh@36`;`0a/2l00<0a/2l00H0@FWQ0<K0_036`;`0a/2l045Y
h@2][Jd@0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ00<0_[Vh045Yh@2n^KP00P2n^KP20:f][@03
0;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V
0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd90;6[W@050:f]
[@2i/ZH0^K:V0;VbYP11JN401P2i/ZH00`11JN40^K:V0;VbYP020;VbYP80@FWQ0P2n]j`01011JN40
_[N/045Yh@11JN440;jg[080@FWQ1@2n]j`2045Yh@<0`KZ`0P2][Jd2045Yh@80[Jf]00<0@FWQ0<6j
/011JN400`31^[000`11JN40`KZ`0<6j/0020<6j/0030:f][@11JN40@FWQ00T0`kfc00<0@FWQ0<>m
/`33_K<01033_K<2045Yh@030<>m/`2][Jd0aKje00T0aKje0P11JN470<Fn]@04045Yh@35_[D0aKje
0:f][@<0a[ng0P11JN460<Jo]`80@FWQ2036_kL2045Yh@030:f][@37`KP0al6h00@0al6h0P11JN47
0<O1^080@FWQ1@37`KP00`2][Jd0@FWQ045Yh@070<O1^P03045Yh@37`KX0al6j00<0al6j00<0@FWQ
0<O1^P37`KX01@37`KX00`2][Jd0@FWQ0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`01037`K`2045Yh@@0[Jf]0`37`K`2045Yh@80al6l00@0[Jf]0<K0_011JN40@FWQ0`36
`;`00`11JN40a/2l045Yh@050<K0_0<0@FWQ00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji
^0020;ji^080@FWQ0P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nK
X00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00D0[Jf]0;VbYP2i/ZH0^K:V045Y
h@050;VbYP80@FWQ1@2i/ZH0102][Jd0_[N/0;jg[02n]j`2045Yh@H0_[N/00<0@FWQ0;jg[02n]j`0
0`2n]j`00`11JN40[Jf]0<6j/0040<6j/080@FWQ0P31^[000`11JN40[Jf]045Yh@030:f][@03045Y
h@2][Jd0`KZ`0080`KZ`00<0[Jf]045Yh@11JN402@33_K<00`11JN40`kfc0<>m/`040<>m/`80@FWQ
00<0`kfc0:f][@35_[D02@35_[D2045Yh@L0aKje00@0@FWQ0<Fn]@35_[D0[Jf]0`36_kL2045Yh@L0
a[ng0P11JN470<Jo]`80@FWQ00<0[Jf]0<O1^037`KP01037`KP2045Yh@L0al6h0P11JN460<O1^003
045Yh@37`KX0al6j00H0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`11JN40al6j0<O1^P050<O1^P03
0:f][@11JN40b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040:f][@80
@FWQ1`37`K`2045Yh@80al6l00<0[Jf]0<K0_011JN400P11JN430<K0_080@FWQ2@36`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0
];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f]
[@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]
102aZid01@2][Jd0^K:V0;VbYP2i/ZH0@FWQ00D0^K:V0P11JN450;VbYP030:f][@2n]j`0_[N/00T0
_[N/00<0@FWQ0;jg[02n]j`00`2n]j`00`11JN40[Jf]0<6j/0040<6j/007045Yh@31^[00`KZ`0<6j
/011JN40`KZ`045Yh@030<6j/003045Yh@31^[00[Jf]00<0[Jf]0P11JN400`2][Jd0`kfc0<>m/`03
0<>m/`@0@FWQ1P33_K<2045Yh@030<>m/`2][Jd0aKje00T0aKje0P11JN470<Fn]@04045Yh@35_[D0
aKje0:f][@<0a[ng0P11JN470<Jo]`80@FWQ1`36_kL2045Yh@030:f][@37`KP0al6h00@0al6h0P11
JN470<O1^080@FWQ1P37`KP00`11JN40al6j0<O1^P0D0<O1^P80@FWQ5@38`K/00`2][Jd0b<6k0<S1
^`0@0<S1^`H0[Jf]1037`K`2045Yh@L0al6l0P11JN420<O1_0060:f][@36`;`0@FWQ045Yh@36`;`0
@FWQ0P36`;`00`11JN40a/2l0<K0_0090<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n
^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2]
[Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH00`11JN440;VbYP03
045Yh@2i/ZH0@FWQ00D0^K:V00<0[Jf]0;jg[02n]j`02P2n]j`5045Yh@030;jg[02][Jd0`KZ`00<0
`KZ`0P11JN430<6j/003045Yh@31^[00@FWQ00<0`KZ`00<0@FWQ0<6j/031^[000P31^[00102][Jd0
@FWQ045Yh@33_K<70:f][@030<>m/`11JN40@FWQ0080@FWQ0`33_K<2045Yh@030<>m/`2][Jd0aKje
00X0aKje00<0@FWQ0<Fn]@35_[D01@35_[D01011JN40aKje0<Fn]@2][Jd30<Jo]`80@FWQ2036_kL2
045Yh@H0a[ng0P11JN400`2][Jd0al6h0<O1^0040<O1^080@FWQ1`37`KP2045Yh@D0al6h0P11JN4E
0<O1^P80@FWQ5P38`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_004
0<O1_080@FWQ1`37`K`2045Yh@80al6l00@0[Jf]0<K0_011JN40@FWQ0P36`;`2045Yh@`0a/2l00<0
[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a
00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:
QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]0P2i
/ZH3045Yh@80^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[000P31
^[02045Yh@@0`KZ`00<0@FWQ0<6j/031^[000P31^[000`11JN40`KZ`0<6j/0020<6j/0030:f][@11
JN40@FWQ00P0`kfc202][Jd2045Yh@030<>m/`2][Jd0aKje00X0aKje00<0@FWQ0<Fn]@35_[D01@35
_[D01011JN40aKje0<Fn]@2][Jd30<Jo]`80@FWQ2036_kL2045Yh@H0a[ng0P11JN400`2][Jd0al6h
0<O1^0040<O1^080@FWQ1`37`KP2045Yh@D0al6h0P11JN4D0<O1^P80@FWQ00<0[Jf]0<S1^`38`K/0
1038`K/00`11JN40b<6k0<S1^`0=0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0
al6l0<O1_0040<O1_080@FWQ1`37`K`2045Yh@80al6l0P11JN4B0<K0_0030:f][@33_K/0`kfk00`0
`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40
oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M
00<0[Jf]0;VbYP2][Jd00`2][Jd0102i/ZH0@FWQ045Yh@11JN470;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[001011JN440<6j/003045Yh@31^[00`KZ`00<0`KZ`00D0@FWQ0<6j/031
^[00`KZ`0:f][@02045YhA00`kfc0P11JN470:f][@L0aKje1011JN430<Fn]@04045Yh@35_[D0aKje
0:f][@<0a[ng0P11JN480<Jo]`80@FWQ1P36_kL2045Yh@030:f][@37`KP0al6h00@0al6h0P11JN47
0<O1^080@FWQ1@37`KP2045YhA80al6j0`11JN400`37`KX0[Jf]0<S1^`050<S1^`03045Yh@38`K/0
b<6k00P0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00@0al6l0P11JN470<O1_080@FWQ0P37`K`0
0`2][Jd0a/2l0<K0_00A0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<
0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2]
[Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f]
[@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0030<6j/0<0@FWQ0P31^[000`11
JN40`KZ`0<6j/0030<6j/005045Yh@31^[00`KZ`0<6j/02][Jd00P11JN4@0<>m/`<0@FWQ00<0[Jf]
0<Fn]@35_[D00`35_[D;0:f][@@0@FWQ0P35_[D0102][Jd0a[ng0<Jo]`36_kL2045Yh@P0a[ng0P11
JN460<Jo]`80@FWQ00<0[Jf]0<O1^037`KP01037`KP2045Yh@L0al6h0P11JN450<O1^080@FWQ4@37
`KX3045Yh@80al6j00<0[Jf]0<S1^`38`K/00`38`K/00`2][Jd0@FWQ0:f][@090:f][@D0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ1`37`K`2045Yh@<0al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[04045Yh@<0`KZ`00<0[Jf]045Yh@11JN404033_K<3
045Yh@030:f][@35_[D0aKje00l0aKje00<0[Jf]045Yh@11JN401P2][Jd2045Yh@H0[Jf]0P36_kL2
045Yh@H0a[ng0P11JN400`2][Jd0al6h0<O1^0040<O1^080@FWQ1`37`KP2045Yh@D0al6h0P11JN48
0<O1^P03045Yh@37`KX0al6j00@0[Jf]0`11JN4:0:f][@030<S1^`11JN40b<6k00h0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ1`37`K`2045Yh@<0al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2]
[Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f]
[@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[003P31^[03045Yh@040<6j/02][Jd0@FWQ
045YhA00`kfc0`11JN401@2][Jd0aKje0<Fn]@35_[D0@FWQ00H0aKje0P11JN470<Fn]@04045Yh@35
_[D000000:f][@<0a[ng0P11JN460<Jo]`030:f][@11JN40@FWQ00L0[Jf]0P11JN470:f][@80@FWQ
1`2][Jd2045Yh@D0[Jf]0P11JN470:f][@80@FWQ0P2][Jd30<O1^P<0@FWQ1@37`KX00`2][Jd0@FWQ
0<S1^`040<S1^`03045Yh@38`K/0b<6k00d0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_0040<O1_080@FWQ1`37`K`00`11JN40al6l0<O1_0020<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40
1P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0
[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0@FWQ045Y
h@0@0<>m/`80@FWQ00<0`kfc045Yh@35_[D00P35_[D2045Yh@D0aKje0P11JN470<Fn]@04045Yh@35
_[D0aKje0:f][@<0a[ng0P11JN470<Jo]`80@FWQ1`36_kL2045Yh@030:f][@37`KP0al6h00@0al6h
0P11JN470<O1^080@FWQ1P37`KP00`11JN40al6j0<O1^P050<O1^P80@FWQ1@37`KX00`11JN40al6j
0<O1^P050<O1^P80@FWQ1@38`K/00`11JN40b<6k0<S1^`0=0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`01037`K`2045Yh@H0al6l0P11JN440<O1_0030:f][@36`;`0a/2l00h0a/2l
102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V
0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]045Yh@11JN403P33_K<4045Yh@030<>m/`2][Jd0@FWQ0080aKje0P11JN450<Fn]@03045Yh@35
_[D0aKje00H0aKje00@0@FWQ0<Fn]@35_[D0[Jf]0`36_kL2045Yh@L0a[ng0P11JN460<Jo]`040000
0011JN40@FWQ0:f][@H0al6h0P11JN470<O1^080@FWQ1P37`KP00`11JN40al6j0<O1^P060<O1^P03
045Yh@37`KX0al6j00<0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@D0b<6k00<0@FWQ0<S1^`38
`K/03@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00@0al6l0P11JN460<O1_080
@FWQ1037`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`03
0:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V
0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@11JN40@FWQ00T0`kfc
00<0@FWQ0<>m/`33_K<01`33_K<00`2][Jd0aKje045Yh@02045Yh@L0aKje00<0@FWQ0<Fn]@35_[D0
1035_[D01@11JN40aKje0<Fn]@35_[D0[Jf]00<0a[ng0`11JN450<Jo]`80@FWQ2036_kL2045Yh@03
0:f][@37`KP0al6h00<0al6h0P11JN480<O1^080@FWQ1P37`KP2045Yh@H0al6j00<0@FWQ0<O1^P37
`KX01@37`KX00`11JN40al6j0<O1^P030<O1^P<0@FWQ1@38`K/2045Yh@h0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ1@37`K`2045Yh@D0al6l00<0[Jf]0<K0_036
`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^004
0:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[003
0:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`11JN40@FWQ2033_K<00`11JN40`kfc0<>m/`070<>m
/`030:f][@35_[D0aKje00X0aKje1P11JN440<Fn]@040:f][@11JN40@FWQ0<Jo]`<0@FWQ1036_kL2
045Yh@T0a[ng1011JN440<O1^080@FWQ2037`KP2045Yh@H0al6h00<0[Jf]045Yh@11JN401@37`KX0
0`11JN40al6j0<O1^P060<O1^P03045Yh@37`KX0al6j0080@FWQ00<0al6j0:f][@11JN401@38`K/2
045Yh@h0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ1@37`K`2
045Yh@D0al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00C
0<6j/0040:f][@33_K<0@FWQ045Yh@L0`kfc0P11JN490<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL00`11JN400`36_kL0@FWQ045Yh@03045Yh@X0a[ng0P11JN400`2][Jd0al6h045Y
h@04045Yh@L0al6h1011JN460<O1^0030:f][@37`KX0al6j00D0@FWQ2P37`KX2045Yh@<0al6j00<0
[Jf]0<S1^`38`K/01038`K/2045Yh@h0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_0040<O1_080@FWQ1037`K`2045Yh@@0al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP02`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`50:f][A40`KZ`00@0[Jf]0<>m/`33_K<0@FWQ1`33
_K<2045Yh@T0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0C0<Jo]`80@FWQ00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00@0b<6k0P11
JN4>0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01037`K`6045Yh@030<O1_02]
[Jd0[Jf]00<0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00D0
[Jf]0<>m/`33_K<0`kfc045Yh@050<>m/`<0@FWQ2@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01<0a[ng0P11JN400`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/01038`K/2045Yh@h0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_0020<O1_0@0@FWQ1@2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2]
[Jd30<6j/0030:f][@33_K<0`kfc0080`kfc00@0@FWQ0<>m/`33_K<0`kfc0P11JN400`33_K<0@FWQ
0<>m/`080<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04`36_kL2045Yh@030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ
3P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]3@37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V
0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]0P33_K<3045Yh@<0`kfc00<0@FWQ0<>m/`33_K<01`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01<0a[ng0P11JN400`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/01038`K/2045Yh@h0b<6k00<0
[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00
102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0C0<Jo]`80@FWQ00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k00@0b<6k0P11JN4>0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd3
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04`36_kL2045Yh@030:f][@37`KP0
al6h00d0al6h00<0@FWQ0<O1^037`KP01@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k00D0b<6k00<0@FWQ0<S1^`38`K/03038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2]
[JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0[Jf]0<Jo]`36_kL04`36_kL2
045Yh@030:f][@37`KP0al6h00`0al6h00<0@FWQ0<O1^011JN401P37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k00D0b<6k00<0@FWQ0<S1^`38`K/01`38`K/90:f][A80b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU
0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2]
[Jd0a[ng0<Jo]`0@0<Jo]`D0@FWQ00<0[Jf]0<O1^037`KP03@37`KP00`11JN40al6h0<O1^0050<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0
aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0
`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg
[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0
a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V
0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37
`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f]
[IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0
[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V
0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55003 .33058 m
.52331 .3309 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50492 .33397 m
.50158 .33071 L
s
.50158 .33071 m
.49825 .33064 L
s
.50659 .334 m
.50158 .33071 L
s
.49825 .33064 m
.49323 .33373 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4944 .32253 m
.50595 .32276 L
s
.5 Mabswid
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53075 .33859 m
.54233 .33845 L
s
.51088 .33856 m
.51419 .34084 L
s
.50757 .33852 m
.51088 .33856 L
s
.51088 .33856 m
.51585 .34085 L
s
.50426 .34072 m
.50757 .33852 L
s
.51585 .34085 m
.51916 .34537 L
s
.51419 .34084 m
.5175 .34537 L
s
.54895 .33832 m
.56049 .33799 L
s
.50094 .34518 m
.50426 .34072 L
s
.4894 .33813 m
.49105 .33818 L
s
.48609 .34029 m
.4894 .33813 L
s
.48774 .34034 m
.4894 .33813 L
s
.51916 .34537 m
.52081 .35215 L
s
.5175 .34537 m
.51915 .35215 L
s
.48607 .3448 m
.48774 .34034 L
s
.48442 .34475 m
.48609 .34029 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47787 .33774 m
.48115 .34012 L
s
.47294 .33754 m
.47787 .33774 L
s
.48115 .34012 m
.48442 .34475 L
s
.46964 .33964 m
.47294 .33754 L
s
.46801 .33957 m
.47294 .33754 L
s
.52081 .35667 m
.52081 .35215 L
s
.51915 .35667 m
.51915 .35215 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56708 .33776 m
.57857 .33725 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50087 .37007 m
.501 .32268 L
s
.49921 .37004 m
.49935 .32264 L
s
.486 .36063 m
.48607 .3448 L
s
.48432 .36512 m
.48442 .34475 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5378 .36622 m
.54345 .36614 L
s
.255 .412 .882 r
.46797 .34408 m
.46964 .33964 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51749 .36345 m
.51915 .35667 L
s
.51915 .36346 m
.52081 .35667 L
s
.53572 .33854 m
.53579 .38612 L
s
.53737 .33852 m
.53746 .3861 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5539 .33819 m
.55399 .36305 L
s
.55555 .33815 m
.55565 .36301 L
s
.46634 .344 m
.46801 .33957 L
s
.46794 .34861 m
.46797 .34408 L
s
.4663 .34853 m
.46634 .344 L
s
.51582 .36798 m
.51915 .36346 L
s
.51416 .36797 m
.51749 .36345 L
s
.53742 .36337 m
.54075 .36786 L
s
.59002 .33889 m
.59488 .33633 L
s
.58679 .3436 m
.59002 .33889 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46794 .34861 m
.46956 .35321 L
s
.50089 .36327 m
.5042 .36786 L
s
.59165 .33879 m
.59488 .33633 L
s
.58842 .3435 m
.59165 .33879 L
s
.59488 .33633 m
.59813 .33611 L
s
.4663 .34853 m
.46791 .35313 L
s
.58521 .35048 m
.58679 .3436 L
s
.47283 .35562 m
.4827 .35826 L
s
.4827 .35826 m
.48434 .36058 L
s
.51084 .37021 m
.51582 .36798 L
s
.51084 .37021 m
.51416 .36797 L
s
.48432 .36512 m
.486 .36063 L
s
.58684 .35039 m
.58842 .3435 L
s
.55235 .36763 m
.55399 .36305 L
s
.55401 .36759 m
.55565 .36301 L
s
.59813 .33611 m
.60301 .33804 L
s
.46956 .35321 m
.47283 .35562 L
s
.54075 .36786 m
.54573 .37005 L
s
.5042 .36786 m
.50751 .37017 L
s
.46791 .35313 m
.47283 .35562 L
s
.50751 .37017 m
.51084 .37021 L
s
.4339 .33513 m
.44521 .33597 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54905 .36998 m
.55235 .36763 L
s
.49424 .36993 m
.50087 .37007 L
s
.54573 .37005 m
.54905 .36998 L
s
.58521 .35048 m
.58524 .35501 L
s
.54905 .36998 m
.55401 .36759 L
s
.48266 .36733 m
.48432 .36512 L
s
.58684 .35039 m
.58688 .35492 L
s
.47934 .36949 m
.48266 .36733 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44003 .36741 m
.44035 .33563 L
s
.43841 .36729 m
.43874 .33551 L
s
.46785 .3622 m
.4695 .36228 L
s
.46948 .36455 m
.4695 .36228 L
s
.46784 .36447 m
.46785 .3622 L
s
.47275 .36923 m
.47934 .36949 L
s
.46784 .36447 m
.46947 .36682 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56725 .36944 m
.57385 .36918 L
s
.58688 .35492 m
.58857 .36164 L
s
.58524 .35501 m
.58693 .36173 L
s
.57365 .33748 m
.57385 .36918 L
s
.57201 .33756 m
.5722 .36925 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60301 .33804 m
.60629 .34233 L
s
.46947 .36682 m
.47275 .36923 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58693 .36173 m
.59024 .36609 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5308 .38616 m
.53746 .3861 L
s
.58857 .36164 m
.59188 .366 L
s
.61747 .33464 m
.61913 .33903 L
s
.61747 .33464 m
.61758 .3437 L
s
.45146 .3636 m
.45311 .36142 L
s
.45311 .36142 m
.45473 .36379 L
s
.45471 .36607 m
.45473 .36379 L
s
.42407 .35248 m
.42429 .33432 L
s
.59024 .36609 m
.59516 .36808 L
s
.45305 .36825 m
.45471 .36607 L
s
.45146 .3636 m
.45307 .36597 L
s
.42247 .35234 m
.42269 .33417 L
s
.61913 .33903 m
.6207 .33662 L
s
.6207 .33662 m
.62386 .33407 L
s
.44017 .35376 m
.44172 .36069 L
s
.61758 .3437 m
.61913 .33903 L
s
.59188 .366 m
.59516 .36808 L
s
.62386 .33407 m
.63022 .33346 L
s
.57227 .38063 m
.57393 .38284 L
s
.57063 .38298 m
.57227 .38063 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60481 .35606 m
.60645 .35822 L
s
.60321 .35845 m
.60481 .35606 L
s
.57063 .38298 m
.5723 .38519 L
s
.60321 .35845 m
.60485 .36061 L
s
.44816 .36795 m
.45305 .36825 L
s
.5723 .38519 m
.57393 .38284 L
s
.59516 .36808 m
.60005 .36777 L
s
.44172 .36069 m
.44492 .36546 L
s
.41947 .33615 m
.42261 .34098 L
s
.41474 .33342 m
.41947 .33615 L
s
.60645 .35822 m
.60647 .36049 L
s
.44492 .36546 m
.44816 .36795 L
s
.60328 .36527 m
.60647 .36049 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63022 .33346 m
.63342 .33541 L
s
.41157 .3331 m
.41474 .33342 L
s
.60005 .36777 m
.60328 .36527 L
s
.41768 .35191 m
.42888 .35289 L
s
.40838 .33504 m
.41157 .3331 L
s
.40681 .33488 m
.41157 .3331 L
s
.43356 .36693 m
.44003 .36741 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63342 .33541 m
.63503 .33752 L
s
.61932 .35493 m
.62249 .35238 L
s
.61774 .35734 m
.61932 .35493 L
s
.62249 .35238 m
.6304 .34709 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61774 .35734 m
.61779 .3619 L
s
.61934 .35721 m
.62252 .35465 L
s
.61776 .35962 m
.61934 .35721 L
s
.63503 .33752 m
.63513 .34435 L
s
.40517 .33926 m
.40838 .33504 L
s
.62252 .35465 m
.63043 .34937 L
s
.4036 .33909 m
.40681 .33488 L
s
.61779 .3619 m
.61942 .36404 L
s
.6304 .34709 m
.63355 .34451 L
s
.63355 .34451 m
.6351 .34207 L
s
.63043 .34937 m
.63358 .34678 L
s
.61942 .36404 m
.62266 .36606 L
s
.63358 .34678 m
.63513 .34435 L
s
.40353 .34364 m
.40517 .33926 L
s
.40196 .34347 m
.4036 .33909 L
s
.64753 .3316 m
.64912 .3337 L
s
.646 .33406 m
.64753 .3316 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40534 .35528 m
.40567 .35345 L
s
.40714 .3543 m
.40726 .35365 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.646 .33406 m
.6476 .33615 L
s
.62266 .36606 m
.62905 .36549 L
s
.42371 .38217 m
.42387 .36844 L
s
.42218 .37516 m
.42387 .36844 L
s
.40186 .35031 m
.40353 .34364 L
s
.6476 .33615 m
.64912 .3337 L
s
.40029 .35014 m
.40196 .34347 L
s
.63376 .36046 m
.63529 .35574 L
s
.63529 .35574 m
.63541 .36488 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62905 .36549 m
.63221 .3629 L
s
.63221 .3629 m
.63376 .36046 L
s
.63376 .36046 m
.63541 .36488 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41892 .37947 m
.42218 .37516 L
s
.42218 .37516 m
.42371 .38217 L
s
.40169 .36174 m
.40186 .35031 L
s
.40012 .36157 m
.40029 .35014 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4141 .38133 m
.41892 .37947 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38351 .32982 m
.38915 .36261 L
s
.37682 .36106 m
.38351 .32982 L
s
.40169 .36174 m
.40316 .36878 L
s
.41092 .38103 m
.4141 .38133 L
s
.40012 .36157 m
.40159 .36861 L
s
.40316 .36878 m
.40467 .37352 L
s
.37835 .36126 m
.3834 .33666 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40777 .37843 m
.41092 .38103 L
s
.40619 .37827 m
.41092 .38103 L
s
.40159 .36861 m
.4031 .37336 L
s
.40467 .37352 m
.40777 .37843 L
s
.4031 .37336 m
.40619 .37827 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64798 .36127 m
.6482 .37504 L
s
.64663 .3752 m
.64777 .34755 L
s
.64777 .34755 m
.64976 .37486 L
s
.38451 .36205 m
.39382 .36316 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64663 .3752 m
.64827 .37963 L
s
.37133 .32812 m
.37682 .36106 L
s
.36468 .35937 m
.37133 .32812 L
s
.64827 .37963 m
.64976 .37486 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36619 .35959 m
.3712 .33498 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35637 .32579 m
.35785 .32604 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35337 .32759 m
.35637 .32579 L
s
.35485 .32784 m
.35637 .32579 L
s
.36018 .3587 m
.37073 .36023 L
s
.35328 .33219 m
.35485 .32784 L
s
.35181 .33194 m
.35337 .32759 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35294 .3483 m
.35328 .33219 L
s
.34897 .32684 m
.35181 .33194 L
s
.35137 .35267 m
.35181 .33194 L
s
.34611 .32403 m
.34897 .32684 L
s
.34176 .32324 m
.34611 .32403 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35137 .35267 m
.35294 .3483 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33883 .325 m
.34176 .32324 L
s
.3374 .32473 m
.34176 .32324 L
s
.35005 .34551 m
.35147 .34806 L
s
.34135 .34168 m
.35005 .34551 L
s
.34985 .35474 m
.35137 .35267 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3373 .32934 m
.33883 .325 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34687 .35657 m
.34985 .35474 L
s
.33587 .32907 m
.3374 .32473 L
s
.33719 .33396 m
.3373 .32934 L
s
.33852 .33884 m
.34135 .34168 L
s
.33709 .33858 m
.34135 .34168 L
s
.34104 .35556 m
.34687 .35657 L
s
.33576 .33369 m
.33587 .32907 L
s
.33719 .33396 m
.33852 .33884 L
s
.33576 .33369 m
.33709 .33858 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33687 .34783 m
.33831 .3481 L
s
.33826 .35041 m
.33831 .3481 L
s
.33821 .35273 m
.34104 .35556 L
s
.33682 .35015 m
.33687 .34783 L
s
.33682 .35015 m
.33821 .35273 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30832 .31621 m
.31782 .31839 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32412 .34537 m
.32546 .34798 L
s
.32541 .3503 m
.32546 .34798 L
s
.32266 .34741 m
.32412 .34537 L
s
.32395 .35235 m
.32541 .3503 L
s
.31288 .35004 m
.31372 .31747 L
s
.32266 .34741 m
.324 .35002 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72857 .31816 m
.74204 .315 L
s
.31152 .34974 m
.31237 .31715 L
s
.31977 .3515 m
.32395 .35235 L
s
.31706 .34859 m
.31977 .3515 L
s
.31324 .33605 m
.31443 .34334 L
s
.31443 .34334 m
.31706 .34859 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74204 .315 m
.74474 .31667 L
s
.74204 .315 m
.74605 .31634 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73266 .31724 m
.73393 .36622 L
s
.73401 .31692 m
.73529 .36592 L
s
.30746 .34884 m
.31288 .35004 L
s
.74474 .31667 m
.74748 .32067 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74605 .31634 m
.74879 .32034 L
s
.29768 .31591 m
.30017 .32124 L
s
.30017 .32124 m
.30136 .32623 L
s
.30136 .32623 m
.30249 .33356 L
s
.29386 .31257 m
.29768 .31591 L
s
.30217 .34526 m
.30249 .33356 L
s
.29638 .31558 m
.29886 .32091 L
s
.29886 .32091 m
.30004 .32591 L
s
.30004 .32591 m
.30117 .33324 L
s
.74748 .32067 m
.74892 .32501 L
s
.29386 .31257 m
.29638 .31558 L
s
.30085 .34494 m
.30117 .33324 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74879 .32034 m
.75021 .32467 L
s
.74892 .32501 m
.75041 .33169 L
s
.30066 .35198 m
.30217 .34526 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72981 .36708 m
.74336 .36413 L
s
.29934 .35167 m
.30085 .34494 L
s
.75021 .32467 m
.75171 .33136 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28125 .30904 m
.29386 .31257 L
s
.29921 .35637 m
.30066 .35198 L
s
.75041 .33169 m
.75074 .34342 L
s
.29789 .35605 m
.29934 .35167 L
s
.75171 .33136 m
.75204 .3431 L
s
.74336 .36413 m
.74595 .36116 L
s
.74336 .36413 m
.74727 .36085 L
s
.29645 .36045 m
.29921 .35637 L
s
.28479 .3599 m
.28623 .31047 L
s
.74964 .3508 m
.75074 .34342 L
s
.74595 .36116 m
.74846 .35582 L
s
.29514 .36013 m
.29789 .35605 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75629 .31127 m
.76504 .30877 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76007 .31021 m
.76104 .34311 L
s
.74846 .35582 m
.74964 .3508 L
s
.75094 .35048 m
.75204 .3431 L
s
.74727 .36085 m
.74977 .3555 L
s
.76132 .30986 m
.76229 .34277 L
s
.74977 .3555 m
.75094 .35048 L
s
.29247 .36185 m
.29645 .36045 L
s
.29247 .36185 m
.29514 .36013 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28353 .35957 m
.28498 .31012 L
s
.75724 .34412 m
.76229 .34277 L
s
.76188 .32863 m
.76333 .33534 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76333 .33534 m
.76596 .33937 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27977 .35856 m
.29247 .36185 L
s
.76596 .33937 m
.76849 .34103 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76849 .34103 m
.77214 .33996 L
s
.77079 .33558 m
.77207 .33759 L
s
.77079 .33558 m
.77192 .33286 L
s
.77192 .33286 m
.7732 .33486 L
s
.7732 .33486 m
.77327 .33723 L
s
.77214 .33996 m
.77327 .33723 L
s
.7818 .30583 m
.78515 .30228 L
s
.7808 .31094 m
.7818 .30583 L
s
.7808 .31094 m
.78095 .31567 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78295 .30544 m
.78515 .30228 L
s
.78195 .31056 m
.78295 .30544 L
s
.78195 .31056 m
.7821 .31529 L
s
.78095 .31567 m
.78226 .32003 L
s
.7821 .31529 m
.78341 .31964 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78515 .30228 m
.78852 .30108 L
s
.78226 .32003 m
.78577 .32124 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78341 .31964 m
.78577 .32124 L
s
.78256 .32952 m
.78263 .3319 L
s
.78256 .32952 m
.78371 .32914 L
s
.78852 .30108 m
.79082 .30263 L
s
.78263 .3319 m
.78386 .3339 L
s
0 0 0 r
.79799 .29287 m
.79851 .2932 L
s
.255 .412 .882 r
.78371 .32914 m
.78379 .33152 L
s
.78577 .32124 m
.79255 .32126 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78386 .3339 m
.78623 .33552 L
s
.79082 .30263 m
.79317 .30657 L
s
.78623 .33552 m
.79073 .33398 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80099 .31634 m
.80149 .31616 L
s
.5 Mabswid
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79317 .30657 m
.7941 .3014 L
s
.79317 .30657 m
.79389 .32802 L
s
.7941 .3014 m
.79617 .2982 L
s
.79426 .30616 m
.79518 .30099 L
s
.79426 .30616 m
.79482 .32284 L
s
.79518 .30099 m
.79617 .2982 L
s
.79617 .2982 m
.79724 .29778 L
s
.79255 .32126 m
.79373 .32325 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79073 .33398 m
.79287 .33081 L
s
.79287 .33081 m
.79389 .32802 L
s
0 0 0 r
.80147 .31554 m
.80149 .31616 L
s
.255 .412 .882 r
.79389 .32802 m
.79482 .32284 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80132 .31867 m
.80149 .31616 L
s
.5 Mabswid
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80363 .32918 m
.80654 .29393 L
s
.80654 .29393 m
.8117 .32585 L
s
.8005 .33041 m
.80772 .32753 L
s
.80467 .32877 m
.80679 .3011 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81435 .29038 m
.81932 .3224 L
s
.8117 .32585 m
.81435 .29038 L
s
.81268 .32542 m
.81461 .29759 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81652 .3237 m
.82206 .32108 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22239 .29096 m
.22336 .28901 L
s
.22257 .28613 m
.22336 .28901 L
s
.2216 .28808 m
.22257 .28613 L
s
.2216 .28808 m
.22239 .29096 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22174 .3327 m
.22194 .30306 L
s
.82565 .29696 m
.82633 .29164 L
s
.82506 .3047 m
.82565 .29696 L
s
.82506 .3047 m
.82551 .31686 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82893 .30383 m
.82901 .30599 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82633 .29164 m
.82783 .28585 L
s
.22085 .33226 m
.22139 .31764 L
s
.82651 .29649 m
.82718 .29117 L
s
.82592 .30424 m
.82651 .29649 L
s
.82718 .29117 m
.82867 .28537 L
s
.82783 .28585 m
.83022 .28199 L
s
.82592 .30424 m
.82638 .31641 L
s
.82867 .28537 m
.83022 .28199 L
s
.82551 .31686 m
.82665 .32373 L
s
.22067 .33715 m
.22174 .3327 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21997 .33182 m
.22194 .30306 L
s
.82638 .31641 m
.82752 .32328 L
s
.83022 .28199 m
.83183 .28103 L
s
.21486 .28429 m
.21558 .2872 L
s
.21531 .29449 m
.21558 .2872 L
s
.21335 .2809 m
.21486 .28429 L
s
.21997 .33182 m
.22067 .33715 L
s
.21449 .29402 m
.2154 .29206 L
s
.82665 .32373 m
.8277 .32817 L
s
.2144 .29645 m
.21531 .29449 L
s
.83183 .28103 m
.83428 .282 L
s
.21023 .27895 m
.21335 .2809 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82752 .32328 m
.82855 .32772 L
s
.21279 .29551 m
.21449 .29402 L
s
.21269 .29795 m
.2144 .29645 L
s
.8277 .32817 m
.82958 .33217 L
s
.21384 .3111 m
.21484 .30668 L
s
.21447 .31645 m
.21484 .30668 L
s
.82855 .32772 m
.83042 .33172 L
s
.20871 .29801 m
.21279 .29551 L
s
.20861 .30046 m
.21269 .29795 L
s
.83428 .282 m
.836 .28591 L
s
.21384 .3111 m
.21447 .31645 L
s
.21293 .31308 m
.21384 .3111 L
s
.20862 .2804 m
.21023 .27895 L
s
.83572 .27859 m
.83647 .29814 L
s
.21124 .3146 m
.21293 .31308 L
s
.83416 .29957 m
.83945 .29621 L
s
.83647 .2781 m
.83723 .29766 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83042 .33172 m
.83217 .33328 L
s
.82958 .33217 m
.83217 .33328 L
s
.20778 .28235 m
.20862 .2804 L
s
.83217 .33328 m
.83379 .33238 L
s
.20814 .31273 m
.21124 .3146 L
s
.20724 .27697 m
.20778 .28235 L
s
.20686 .28675 m
.20778 .28235 L
s
.20686 .28675 m
.20724 .27697 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20712 .2995 m
.20871 .29801 L
s
.20702 .30195 m
.20861 .30046 L
s
.83379 .33238 m
.83607 .32855 L
s
.20628 .30147 m
.20712 .2995 L
s
.20673 .30933 m
.20814 .31273 L
s
.20619 .30393 m
.20702 .30195 L
s
.83607 .32855 m
.83743 .3227 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84082 .27511 m
.84551 .27156 L
s
.8379 .31485 m
.83847 .32964 L
s
.83743 .3227 m
.8379 .31485 L
s
.20609 .30639 m
.20628 .30147 L
s
.83743 .3227 m
.83847 .32964 L
s
.20609 .30639 m
.20673 .30933 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19874 .29509 m
.19881 .29793 L
s
.255 .412 .882 r
.84288 .2736 m
.84425 .30808 L
s
0 0 0 r
.19805 .29445 m
.19839 .30829 L
s
.255 .412 .882 r
.84355 .27309 m
.84493 .3076 L
s
.2009 .2749 m
.20203 .28083 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19907 .27091 m
.2009 .2749 L
s
.84218 .30953 m
.84493 .3076 L
s
.84434 .29277 m
.8453 .29969 L
s
.20125 .30054 m
.20135 .29807 L
s
.20077 .29511 m
.20135 .29807 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19972 .3045 m
.20125 .30054 L
s
.20001 .29708 m
.20077 .29511 L
s
.19782 .26988 m
.19907 .27091 L
s
.20001 .29708 m
.20058 .30005 L
s
.8453 .29969 m
.8468 .30366 L
s
.19652 .27131 m
.19782 .26988 L
s
.19592 .2708 m
.19782 .26988 L
s
.19832 .306 m
.19972 .3045 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8468 .30366 m
.84817 .30515 L
s
.19514 .27522 m
.19652 .27131 L
s
.19643 .30453 m
.19832 .306 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19457 .27471 m
.19592 .2708 L
s
.19426 .28214 m
.19514 .27522 L
s
.84921 .2992 m
.84991 .30118 L
s
.84921 .2992 m
.84971 .29621 L
s
.19531 .30105 m
.19643 .30453 L
s
.19472 .30055 m
.19643 .30453 L
s
.1937 .28163 m
.19457 .27471 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84971 .29621 m
.85041 .2982 L
s
.84817 .30515 m
.85001 .30367 L
s
.19406 .28711 m
.19426 .28214 L
s
.19433 .29507 m
.19531 .30105 L
s
.85001 .30367 m
.85051 .30068 L
s
.85041 .2982 m
.85051 .30068 L
s
.19406 .28711 m
.19433 .29507 L
s
.1935 .2866 m
.1937 .28163 L
s
.19376 .29457 m
.19472 .30055 L
s
.1935 .2866 m
.19376 .29457 L
s
.18869 .26092 m
.19214 .26465 L
s
.85342 .27224 m
.85374 .26675 L
s
.85342 .27224 m
.85362 .27721 L
s
.85374 .26675 m
.85515 .26267 L
s
.85362 .27721 m
.85435 .28167 L
s
.85394 .27172 m
.85425 .26622 L
s
.85394 .27172 m
.85414 .27669 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85425 .26622 m
.85515 .26267 L
s
.85414 .27669 m
.85486 .28115 L
s
.18916 .298 m
.1906 .26306 L
s
.85435 .28167 m
.85597 .28261 L
s
.85515 .26267 m
.85657 .26106 L
s
.18867 .29749 m
.19011 .26253 L
s
.85486 .28115 m
.85597 .28261 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85476 .29165 m
.85486 .29415 L
s
.85476 .29165 m
.85527 .29114 L
s
.85486 .29415 m
.85548 .29614 L
s
.85527 .29114 m
.85538 .29364 L
s
.85657 .26106 m
.85758 .26248 L
s
.85597 .28261 m
.85886 .28197 L
s
.85548 .29614 m
.85659 .29763 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18724 .29595 m
.18916 .298 L
s
.85758 .26248 m
.85866 .26641 L
s
.85659 .29763 m
.85849 .29558 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1842 .25494 m
.18692 .25876 L
s
.18794 .31509 m
.18854 .31307 L
s
.18815 .31005 m
.18854 .31307 L
s
.85866 .26641 m
.85887 .26086 L
s
.85866 .26641 m
.8596 .28899 L
s
.18756 .31207 m
.18815 .31005 L
s
.85887 .26086 m
.85958 .25728 L
s
.18756 .31207 m
.18794 .31509 L
s
.85908 .26587 m
.85929 .26032 L
s
.85908 .26587 m
.85982 .28344 L
s
.85929 .26032 m
.85958 .25728 L
s
.85886 .28197 m
.85939 .28396 L
s
.85849 .29558 m
.85928 .29203 L
s
.85958 .25728 m
.85998 .25673 L
s
.18454 .28476 m
.1857 .25713 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86372 .27563 m
.8647 .29876 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85999 .23812 m
.86233 .23418 L
s
0 0 0 r
.18148 .27703 m
.18149 .27688 L
s
.255 .412 .882 r
.18415 .28423 m
.18531 .25659 L
s
.85928 .29203 m
.8596 .28899 L
s
.8596 .28899 m
.85982 .28344 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86105 .23644 m
.86328 .28932 L
s
.18394 .28928 m
.18454 .28476 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86404 .27277 m
.86422 .27687 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86139 .23588 m
.86362 .2888 L
s
.18356 .28875 m
.18415 .28423 L
s
.18271 .29023 m
.18394 .28928 L
s
.18271 .29023 m
.18356 .28875 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18087 .24885 m
.18285 .25274 L
s
.86245 .26099 m
.86287 .25485 L
s
0 0 0 r
.86562 .32046 m
.86619 .32358 L
s
.86562 .32046 m
.86589 .31632 L
s
.255 .412 .882 r
.86221 .2909 m
.86362 .2888 L
s
0 0 0 r
.86589 .31632 m
.86645 .31944 L
s
.255 .412 .882 r
.86287 .25485 m
.86337 .25123 L
s
.18201 .28918 m
.18271 .29023 L
s
0 0 0 r
.86619 .32358 m
.86645 .31944 L
s
.255 .412 .882 r
.86337 .25123 m
.86393 .25011 L
s
.17968 .30438 m
.18194 .25108 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8633 .28119 m
.86416 .2852 L
s
.18115 .28506 m
.18201 .28918 L
s
.1794 .30386 m
.18166 .25052 L
s
.86393 .25011 m
.86456 .25153 L
s
.86393 .25011 m
.8648 .25097 L
s
.86416 .2852 m
.86487 .28668 L
s
.18076 .27891 m
.18115 .28506 L
s
.86456 .25153 m
.86525 .25548 L
s
0 0 0 r
.8691 .23684 m
.87013 .23379 L
s
.17521 .23363 m
.17656 .23767 L
s
.255 .412 .882 r
.8648 .25097 m
.86548 .25492 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86487 .28668 m
.86543 .28561 L
s
.86525 .25548 m
.86581 .26254 L
s
.86543 .28561 m
.86585 .282 L
s
.86543 .28561 m
.8661 .28146 L
s
.86548 .25492 m
.86602 .26199 L
s
.1786 .3023 m
.17968 .30438 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86585 .282 m
.86612 .27582 L
s
.86581 .26254 m
.86602 .26763 L
s
.86602 .26763 m
.86612 .27582 L
s
.8661 .28146 m
.86635 .27528 L
s
.86602 .26199 m
.86624 .26709 L
s
.86624 .26709 m
.86635 .27528 L
s
.17894 .24633 m
.17905 .25254 L
s
.17891 .26074 m
.17905 .25254 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17869 .26584 m
.17891 .26074 L
s
.17878 .24577 m
.17888 .25198 L
s
.17873 .26019 m
.17888 .25198 L
s
.17818 .27296 m
.17869 .26584 L
s
.17862 .24209 m
.17894 .24633 L
s
0 0 0 r
.87106 .28222 m
.87114 .27607 L
s
.255 .412 .882 r
.17851 .26529 m
.17873 .26019 L
s
.17801 .27241 m
.17851 .26529 L
s
.17862 .24209 m
.17878 .24577 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17763 .27699 m
.17818 .27296 L
s
.17839 .24095 m
.17862 .24209 L
s
.17865 .21846 m
.17905 .22254 L
s
0 0 0 r
.17467 .23131 m
.17412 .22722 L
s
.255 .412 .882 r
.17747 .27645 m
.17801 .27241 L
s
0 0 0 r
.17241 .3121 m
.17326 .31419 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86645 .24337 m
.86725 .23939 L
s
0 0 0 r
.86961 .23552 m
.87292 .31224 L
s
.86941 .2361 m
.87273 .31276 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17809 .24237 m
.17839 .24095 L
s
.17709 .27793 m
.17763 .27699 L
s
.1765 .27466 m
.17882 .22079 L
s
.17709 .27793 m
.17747 .27645 L
s
0 0 0 r
.87123 .23278 m
.87138 .24124 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17241 .3121 m
.17573 .23537 L
s
.17261 .31262 m
.17592 .23594 L
s
.255 .412 .882 r
.17644 .27411 m
.17876 .22021 L
s
0 0 0 r
.87273 .31276 m
.87346 .31066 L
s
.87125 .22737 m
.87123 .23278 L
s
.255 .412 .882 r
.17809 .24237 m
.17772 .24635 L
s
.17685 .27684 m
.17709 .27793 L
s
0 0 0 r
.87132 .2262 m
.87125 .22737 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86876 .29718 m
.86928 .29505 L
s
.86818 .26927 m
.8686 .27332 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86697 .2411 m
.86928 .29505 L
s
.86686 .24167 m
.86917 .29558 L
s
0 0 0 r
.87249 .26687 m
.87265 .27055 L
s
.87242 .26264 m
.87249 .26687 L
s
.255 .412 .882 r
.17677 .27317 m
.17685 .27684 L
s
0 0 0 r
.87267 .26575 m
.87242 .26264 L
s
.87265 .27055 m
.87315 .27681 L
s
.255 .412 .882 r
.86746 .23309 m
.86747 .23711 L
s
0 0 0 r
.8715 .22869 m
.87132 .2262 L
s
.8715 .2281 m
.87132 .2262 L
s
.255 .412 .882 r
.8686 .27332 m
.86893 .27426 L
s
0 0 0 r
.87274 .26999 m
.87267 .26575 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17102 .30682 m
.17437 .22956 L
s
.17093 .30629 m
.17429 .22897 L
s
.255 .412 .882 r
.17684 .26692 m
.17677 .27317 L
s
0 0 0 r
.8718 .23487 m
.8715 .22869 L
s
.87315 .27681 m
.87344 .2794 L
s
.255 .412 .882 r
.17633 .27247 m
.1765 .27466 L
s
.17786 .23466 m
.17786 .23523 L
s
0 0 0 r
.87178 .23429 m
.8715 .2281 L
s
.17132 .30841 m
.17093 .30629 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86753 .23481 m
.86875 .26319 L
s
.86893 .27426 m
.86902 .27317 L
s
.86753 .23539 m
.86875 .26375 L
s
.17779 .23609 m
.17786 .23466 L
s
.17776 .23666 m
.17786 .23466 L
s
0 0 0 r
.87344 .2794 m
.87356 .27775 L
s
.255 .412 .882 r
.17757 .24124 m
.17776 .23666 L
s
.86896 .26948 m
.86902 .27317 L
s
.86897 .26893 m
.86902 .27317 L
s
0 0 0 r
.87226 .24534 m
.8718 .23487 L
s
.17359 .23471 m
.17398 .22619 L
s
.17309 .24634 m
.17359 .23471 L
s
.255 .412 .882 r
.17761 .24067 m
.17779 .23609 L
s
0 0 0 r
.87222 .24477 m
.87178 .23429 L
s
.17398 .22619 m
.17432 .22074 L
s
.17277 .25372 m
.17309 .24634 L
s
.17362 .23413 m
.17403 .2256 L
s
.17311 .24576 m
.17362 .23413 L
s
.255 .412 .882 r
.17679 .25934 m
.17757 .24124 L
s
.86875 .26375 m
.86896 .26948 L
s
0 0 0 r
.17403 .2256 m
.17432 .22074 L
s
.17279 .25315 m
.17311 .24576 L
s
.17231 .26425 m
.17277 .25372 L
s
.255 .412 .882 r
.17761 .24067 m
.17793 .23436 L
s
.1766 .26397 m
.17761 .24067 L
s
.86875 .26319 m
.86897 .26893 L
s
0 0 0 r
.87356 .27775 m
.87343 .27293 L
s
.87356 .27775 m
.87342 .27238 L
s
.87258 .25273 m
.87226 .24534 L
s
.17233 .26369 m
.17279 .25315 L
s
.17432 .22074 m
.1745 .21956 L
s
.255 .412 .882 r
.17793 .23436 m
.17819 .23063 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87254 .25216 m
.87222 .24477 L
s
.87309 .2644 m
.87258 .25273 L
s
.87343 .27293 m
.87309 .2644 L
s
.255 .412 .882 r
.1766 .26397 m
.17679 .25934 L
s
.86638 .22674 m
.86722 .23078 L
s
0 0 0 r
.87306 .26384 m
.87254 .25216 L
s
.87342 .27238 m
.87306 .26384 L
s
.17205 .27056 m
.17231 .26425 L
s
.255 .412 .882 r
.17819 .23063 m
.1785 .2289 L
s
0 0 0 r
.1745 .21956 m
.17456 .22207 L
s
.1745 .21956 m
.17469 .22148 L
s
.255 .412 .882 r
.17683 .25878 m
.17699 .25563 L
s
.17699 .25563 m
.1776 .24966 L
s
0 0 0 r
.1721 .27 m
.17233 .26369 L
s
.255 .412 .882 r
.17654 .26602 m
.1766 .26397 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17655 .26752 m
.17654 .26602 L
s
.86692 .22905 m
.86849 .26545 L
s
0 0 0 r
.17456 .22207 m
.1745 .22829 L
s
.255 .412 .882 r
.17864 .23033 m
.1785 .2289 L
s
.17879 .22976 m
.1785 .2289 L
s
0 0 0 r
.17207 .27261 m
.17205 .27056 L
s
.255 .412 .882 r
.8668 .22847 m
.86837 .2649 L
s
0 0 0 r
.17469 .22148 m
.17465 .22771 L
s
.17207 .27261 m
.1721 .27 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17693 .26531 m
.17655 .26752 L
s
.86837 .2649 m
.86878 .26711 L
s
0 0 0 r
.86873 .21201 m
.87014 .21616 L
s
.1745 .22829 m
.17417 .23885 L
s
.17224 .2715 m
.17207 .27261 L
s
.17465 .22771 m
.17433 .23828 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1776 .24966 m
.17806 .24581 L
s
.1776 .24966 m
.17797 .24597 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87285 .26419 m
.87259 .2599 L
s
.87301 .26792 m
.87285 .26419 L
s
.87259 .2599 m
.87264 .26307 L
s
.87307 .2711 m
.87301 .26792 L
s
.17262 .26665 m
.17224 .2715 L
s
.17275 .26609 m
.17224 .2715 L
s
.17417 .23885 m
.17384 .2463 L
s
.87264 .26307 m
.87291 .26736 L
s
.255 .412 .882 r
.17693 .26531 m
.1773 .26158 L
s
0 0 0 r
.8727 .26943 m
.87307 .2711 L
s
.255 .412 .882 r
.17753 .25636 m
.17767 .2558 L
s
.17741 .25897 m
.17753 .25636 L
s
0 0 0 r
.17433 .23828 m
.174 .24573 L
s
.17384 .2463 m
.17321 .25806 L
s
.17321 .25806 m
.17262 .26665 L
s
.255 .412 .882 r
.86905 .27854 m
.86927 .2817 L
s
.86927 .2817 m
.86927 .28378 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17756 .25841 m
.1773 .26158 L
s
.17767 .2558 m
.17756 .25841 L
s
.86904 .28061 m
.86905 .27854 L
s
0 0 0 r
.174 .24573 m
.17336 .2575 L
s
.17336 .2575 m
.17275 .26609 L
s
.17626 .21304 m
.17809 .20888 L
s
.255 .412 .882 r
.86904 .28061 m
.86927 .28378 L
s
0 0 0 r
.87224 .26457 m
.8727 .26943 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86613 .237 m
.86633 .24007 L
s
.86633 .24007 m
.86655 .2453 L
s
.86589 .23601 m
.86612 .2395 L
s
0 0 0 r
.87089 .24416 m
.87157 .25595 L
s
.87157 .25595 m
.87224 .26457 L
s
.255 .412 .882 r
.86612 .2395 m
.86634 .24473 L
s
0 0 0 r
.17471 .2637 m
.17698 .21126 L
s
.17497 .26315 m
.17724 .21067 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8694 .21379 m
.87166 .26609 L
s
.8696 .21438 m
.87186 .26664 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86644 .20726 m
.86822 .21082 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.174 .26538 m
.17497 .26315 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87099 .26441 m
.87186 .26664 L
s
.5 Mabswid
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86767 .20964 m
.86826 .24863 L
s
.17546 .25184 m
.17569 .25825 L
s
.17938 .20651 m
.18207 .20237 L
s
.86439 .22514 m
.86773 .23034 L
s
.17869 .24619 m
.18046 .20473 L
s
.17569 .25825 m
.17644 .26036 L
s
.17907 .24563 m
.18085 .20414 L
s
.86165 .20016 m
.86425 .20371 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86738 .20904 m
.86831 .27349 L
s
.86826 .24863 m
.8688 .28494 L
s
.17644 .26036 m
.17711 .25924 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86256 .20134 m
.8688 .28494 L
s
.17711 .25924 m
.17799 .25433 L
s
.17711 .25924 m
.17836 .25378 L
s
.17799 .25433 m
.17869 .24619 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17836 .25378 m
.17907 .24563 L
s
.255 .412 .882 r
.85562 .20825 m
.85691 .20975 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18585 .23313 m
.18668 .23211 L
s
.18611 .23273 m
.18611 .23258 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18386 .2 m
.18744 .19589 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8575 .23023 m
.85781 .23115 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85768 .24609 m
.85847 .24698 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18465 .2674 m
.18465 .26735 L
s
0 0 0 r
.18359 .25091 m
.18584 .19765 L
s
.18308 .25146 m
.18533 .19824 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18465 .2674 m
.18466 .26735 L
s
0 0 0 r
.18161 .25313 m
.18359 .25091 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1816 .27503 m
.18227 .27065 L
s
.1816 .27503 m
.18194 .27835 L
s
.18227 .27065 m
.18262 .27396 L
s
.19206 .19502 m
.1942 .18947 L
s
.19111 .20322 m
.19206 .19502 L
s
.18936 .24541 m
.19111 .20322 L
s
.19271 .19444 m
.1942 .18947 L
s
.19175 .20265 m
.19271 .19444 L
s
.18194 .27835 m
.18262 .27396 L
s
.19 .24486 m
.19175 .20265 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1942 .18947 m
.19558 .18831 L
s
.19558 .18831 m
.19758 .19041 L
s
.18751 .24705 m
.19 .24486 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19758 .19041 m
.19877 .19694 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19923 .18543 m
.20236 .18315 L
s
.19704 .23943 m
.19923 .18543 L
s
.19781 .23889 m
.2 .18486 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19481 .24105 m
.19781 .23889 L
s
.255 .412 .882 r
.20433 .23088 m
.20605 .21636 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20653 .18031 m
.20709 .18747 L
s
.20592 .19575 m
.20653 .18031 L
s
.20592 .19575 m
.20709 .18747 L
s
.20709 .18747 m
.20813 .18305 L
s
.20813 .18305 m
.21007 .17807 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21007 .17807 m
.2138 .17584 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.205 .21903 m
.20602 .2146 L
s
.20469 .22681 m
.205 .21903 L
s
.20602 .2146 m
.20795 .20962 L
s
.20484 .22292 m
.20587 .21849 L
s
.2138 .17584 m
.21558 .17861 L
s
.20587 .21849 m
.2078 .21351 L
s
.20469 .22681 m
.2054 .23018 L
s
.20795 .20962 m
.2129 .19914 L
s
.2078 .21351 m
.21275 .20303 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2054 .23018 m
.20703 .23303 L
s
.21558 .17861 m
.21642 .18195 L
s
.2129 .19914 m
.21498 .19416 L
s
.21597 .19362 m
.21642 .18195 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21275 .20303 m
.21483 .19806 L
s
.20703 .23303 m
.21073 .23093 L
s
.21498 .19416 m
.21612 .18973 L
s
.21483 .19806 m
.21597 .19362 L
s
.21073 .23093 m
.2128 .22596 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21393 .22152 m
.21522 .21316 L
s
.21461 .22885 m
.21522 .21316 L
s
.2128 .22596 m
.21393 .22152 L
s
.22377 .17427 m
.22499 .16983 L
s
.22377 .17427 m
.22469 .17763 L
s
.21393 .22152 m
.21461 .22885 L
s
.22499 .16983 m
.22592 .1732 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22469 .17763 m
.22592 .1732 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22328 .24407 m
.22396 .1972 L
s
.22111 .24506 m
.22396 .1972 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22219 .24456 m
.22308 .22081 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80453 .19734 m
.8047 .19586 L
s
0 0 0 r
.22111 .24506 m
.22189 .25251 L
s
.22189 .25251 m
.22328 .24407 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76535 .1839 m
.76654 .1835 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76535 .1839 m
.76631 .18326 L
s
.77006 .19363 m
.77015 .19643 L
s
.76858 .19319 m
.77006 .19363 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72598 .1389 m
.72783 .14331 L
s
.72434 .14255 m
.72598 .1389 L
s
.72619 .14696 m
.72783 .14331 L
s
.72434 .14255 m
.72619 .14696 L
s
.255 .412 .882 r
.72232 .17448 m
.72372 .18203 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72671 .16718 m
.72972 .21649 L
s
.7262 .21579 m
.72671 .16718 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70627 .13491 m
.71002 .13965 L
s
.71002 .13965 m
.71194 .14404 L
s
.71194 .14404 m
.71223 .1562 L
s
.69886 .13355 m
.70627 .13491 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71041 .15585 m
.71213 .15214 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7105 .15991 m
.71223 .1562 L
s
.6952 .13695 m
.69886 .13355 L
s
.70683 .15923 m
.71041 .15585 L
s
.72733 .19158 m
.72796 .21613 L
s
.70693 .1633 m
.7105 .15991 L
s
.6934 .14068 m
.6952 .13695 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69134 .13225 m
.6934 .14068 L
s
.69134 .13225 m
.69168 .1485 L
s
.69771 .16575 m
.70683 .15923 L
s
.69168 .1485 m
.6934 .14068 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71271 .17654 m
.7131 .19289 L
s
.71108 .18437 m
.71271 .17654 L
s
.6978 .16983 m
.70693 .1633 L
s
.72818 .22435 m
.72972 .21649 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67399 .12953 m
.68177 .1307 L
s
.70934 .18813 m
.71108 .18437 L
s
.71108 .18437 m
.7131 .19289 L
s
.7262 .21579 m
.72818 .22435 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67594 .12981 m
.67705 .18711 L
s
.69402 .1692 m
.69771 .16575 L
s
.67399 .12953 m
.67508 .18684 L
s
.70574 .19158 m
.70934 .18813 L
s
.69411 .1733 m
.6978 .16983 L
s
.6922 .17299 m
.69402 .1692 L
s
.67013 .13303 m
.67422 .14174 L
s
.66412 .12814 m
.67013 .13303 L
s
.255 .412 .882 r
.66573 .16392 m
.66704 .1641 L
s
0 0 0 r
.69825 .19032 m
.70574 .19158 L
s
.66013 .12761 m
.66412 .12814 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69229 .17709 m
.69411 .1733 L
s
.6922 .17299 m
.69238 .18119 L
s
.65618 .13117 m
.66013 .12761 L
s
.65416 .13092 m
.66013 .12761 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69437 .1856 m
.69825 .19032 L
s
.69238 .18119 m
.69437 .1856 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65227 .13884 m
.65416 .13092 L
s
.6543 .13909 m
.65618 .13117 L
s
.6253 .12372 m
.63776 .12497 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41982 .12375 m
.44589 .12173 L
s
.44589 .12173 m
.45378 .12112 L
s
.66914 .18605 m
.67705 .18711 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63341 .12507 m
.63363 .12454 L
s
.60418 .12197 m
.6169 .12297 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6342 .1816 m
.63444 .18215 L
s
.65227 .13884 m
.65301 .18408 L
s
.6543 .13909 m
.65505 .18432 L
s
.45163 .12126 m
.45356 .14579 L
s
.45356 .14579 m
.45378 .12112 L
s
.58054 .1205 m
.5849 .12483 L
s
.58054 .1205 m
.58706 .12495 L
s
.5762 .12029 m
.58054 .1205 L
s
.64687 .1834 m
.65505 .18432 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5849 .12483 m
.58928 .13329 L
s
.56971 .1241 m
.5762 .12029 L
s
.57188 .1242 m
.5762 .12029 L
s
.58706 .12495 m
.59144 .13342 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47758 .12403 m
.48197 .11976 L
s
.48197 .11976 m
.48633 .11961 L
s
.4754 .12412 m
.48197 .11976 L
s
.59144 .13342 m
.5937 .14591 L
s
.56757 .13224 m
.57188 .1242 L
s
.48633 .11961 m
.49288 .12353 L
s
.58928 .13329 m
.59155 .14578 L
s
.47317 .13243 m
.4754 .12412 L
s
.56539 .13216 m
.56971 .1241 L
s
.47535 .13234 m
.47758 .12403 L
s
.54343 .11922 m
.55221 .11941 L
s
.49728 .11931 m
.50606 .11915 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57473 .17332 m
.57473 .17341 L
s
0 0 0 r
.60844 .12229 m
.6342 .1816 L
s
.53465 .11909 m
.53905 .12326 L
s
.53025 .11906 m
.53465 .11909 L
s
.52585 .12315 m
.53025 .11906 L
s
.52365 .12314 m
.53025 .11906 L
s
.49288 .12353 m
.49724 .13165 L
s
.44029 .1839 m
.44063 .15076 L
s
.47289 .17797 m
.47317 .13243 L
s
.53905 .12326 m
.54347 .13156 L
s
.47508 .17788 m
.47535 .13234 L
s
.62605 .18138 m
.6386 .18255 L
s
.52145 .13138 m
.52585 .12315 L
s
.51925 .13138 m
.52365 .12314 L
s
.56546 .14453 m
.56757 .13224 L
s
.5937 .14591 m
.59378 .15417 L
s
.56327 .14445 m
.56539 .13216 L
s
.59155 .14578 m
.59162 .15404 L
s
.42767 .16826 m
.44046 .1673 L
s
.51704 .14377 m
.51925 .13138 L
s
.51924 .14376 m
.52145 .13138 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55156 .15809 m
.55304 .16396 L
s
.54921 .1573 m
.55087 .16391 L
s
0 0 0 r
.56546 .14453 m
.5655 .1528 L
s
.56327 .14445 m
.56331 .15272 L
s
.255 .412 .882 r
.57473 .17341 m
.57488 .17342 L
s
0 0 0 r
.51703 .15205 m
.51704 .14377 L
s
.51924 .15204 m
.51924 .14376 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4971 .17723 m
.49728 .11931 L
s
.49931 .17719 m
.49948 .11927 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56331 .15272 m
.56557 .16524 L
s
.5655 .1528 m
.56776 .16532 L
s
.60478 .17973 m
.61759 .18067 L
s
.58956 .16633 m
.59162 .15404 L
s
.59173 .16646 m
.59378 .15417 L
s
.60906 .18003 m
.63155 .12433 L
s
.6112 .18018 m
.63341 .12507 L
s
.58746 .17452 m
.59173 .16646 L
s
.58529 .1744 m
.58956 .16633 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42505 .21003 m
.42611 .12318 L
s
.42718 .20986 m
.42821 .123 L
s
.51703 .15205 m
.51923 .16448 L
s
.51924 .15204 m
.52145 .16448 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58096 .17835 m
.58746 .17452 L
s
.56776 .16532 m
.57219 .1738 L
s
.56557 .16524 m
.57 .17371 L
s
.58096 .17835 m
.58529 .1744 L
s
.45085 .20828 m
.45324 .18309 L
s
.45302 .20815 m
.45324 .18309 L
s
.53915 .17291 m
.54355 .16466 L
s
.41869 .21055 m
.44504 .20871 L
s
.44504 .20871 m
.45302 .20815 L
s
.57219 .1738 m
.57659 .17815 L
s
.57659 .17815 m
.58096 .17835 L
s
.57 .17371 m
.57659 .17815 L
s
.51923 .16448 m
.52366 .1728 L
s
.52145 .16448 m
.52587 .1728 L
s
.46633 .17826 m
.47508 .17788 L
s
.53473 .17702 m
.53915 .17291 L
s
.52587 .1728 m
.53031 .17699 L
s
.52366 .1728 m
.53031 .17699 L
s
.49048 .17738 m
.49931 .17719 L
s
.53031 .17699 m
.53473 .17702 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54563 .11926 m
.54588 .20646 L
s
.54343 .11922 m
.54366 .20642 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.537 .20633 m
.54588 .20646 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P3o
YQ05000000/0ojH@0`0000040?nV40D000007@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ42000000T0ojHA102][Jd3
000000D0[Jf]0P00000<0:f][@8000000`2][Jd010000000[Jf]0:f][@2][Jd2000000h0[Jf]0`00
000?0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42
00000080ojHA2`0000090:f][@80ojHA0P0000030?nV4@8000000`3oYQ02000000/0ojH@0P000005
0?nV40030000003oYQ00ojH@0080000000<0ojH@0:f][@3oYA002@3oYA02000000<0ojD@0P000009
0:f][@L000000P2][JdG0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?ooo`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA1`0000050:f]
[@@0ojHA0P00000:0?nV4@800000103oYQ400`2][Jd0ojH@000000020?nV408000002P3oYQ020000
00L0ojH@00H000000?nV4000000000000?nV402][Jd90?nU408000001@3oYA02000000X0ojD@00<0
00000?nU402][Jd0103oXa000`2][Jd0000000000006000000h0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40oooo001j
0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ40303oYQ4:0:f][@<0ojHA0P00000;0?nV4@8000002P3oYQ42000000@0ojHA00D0[Jf]
0?nV403oYQ0000000?nV4002000000X0ojH@0P0000070?nV40060000003oYQ0000000000003oYQ00
[Jf]203oYA02000000H0ojD@00<000000?nU400000002P3oYA000`000000[Jf]0?nS40070?nS4080
00000`3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`03
0:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@d0ojHA
0P00000;0?nV4@8000002@3oYQ42000000D0ojHA00D0[Jf]0?nV403oYQ0000000?nV4002000000T0
ojH@0P0000090?nV40<0000000<0ojH@0:f][@3oYA001`3oYA02000000L0ojD@0P00000:0?nU4003
0000002][Jd0oj<@00H0oj<@0P00000=0?nS40@00000102][JdH0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][F40/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ470:f][AL0ojHA0P00000;0?nV4@800000
2@3oYQ42000000D0ojHA00@0[Jf]0?nV403oYQ00ojH@0`0000090?nV408000002@3oYQ0300000003
0?nV402][Jd0ojD@00H0ojD@0P0000080?nU40030000003oYA00000000X0ojD@00<000000?nS403o
Xa001@3oXa02000000/0oj<@0`0000030?nS408000000P3lX10400000080[Jf]4P3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]
4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1@2][Jd20?nV4@030:f]
[@3oYQ40ojHA01T0ojHA0P00000;0?nV4@8000002@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ00
0P3oYQ02000000T0ojH@0P00000:0?nV4080000000<0ojH@0:f][@3oYA001P3oYA02000000T0ojD@
00<000000?nU400000002@3oYA000`000000oj<@0?nS40040?nS40800000303oXa02000000D0oj<@
00<0[Jf]0000003lX1000P0000040?bP4080[Jf]00<000000:f][@2][Jd03@3lX1000`2][Jd0mY`?
0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo
001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0
[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000`0ojHA00<0
00000?nV4@3oYQ401`3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000P0ojH@00<0
00000?nV400000002P3oYQ02000000030?nV402][Jd0ojD@00H0ojD@0P0000090?nU40030000003o
YA00000000T0ojD@00<0[Jf]0000003oXa00103oXa02000000/0oj<@0P0000060?nS40030:f][@00
0000o:0@008000001P3lX10010000000o:0@0?bP402][Jd5000000L0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo
001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0
[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000`0ojHA00<0
00000?nV4@3oYQ401`3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000P0ojH@00<0
00000?nV400000002P3oYQ02000000030?nV402][Jd0ojD@00D0ojD@00<000000?nU400000002P3o
YA02000000T0ojD@00<0[Jf]0000003oXa00103oXa02000000/0oj<@0P0000060?nS40030:f][@3l
X1000000008000001P3lX10010000000o:0@0000000000040?bP40030:f][@000000[Jf]00<0[Jf]
0P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@2][JdB0?nV4@030:f][@3o
YQ40ojHA01T0ojHA0P00000<0?nV4@030000003oYQ40ojHA00L0ojHA0P0000050?nV4@030:f][@3o
YQ00ojH@0080ojH@0P0000080?nV408000002`3oYQ02000000030?nV402][Jd0ojD@00D0ojD@0P00
000;0?nU408000002@3oYA000`2][Jd0oj<@000000030?nS40800000303oXa02000000H0oj<@00<0
[Jf]0?bP400000000P0000060?bP408000001`3lX1000`000000o:0@0?bP40020?bP40<0[Jf]00<0
00000?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2]
[JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01<0oj@A102][JdG0?nV4@030:f][@3oYQ40ojHA01T0ojHA0P00000<0?nV4@030000003oYQ40
ojHA00L0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@0P0000080?nV408000002`3oYQ02
000000030?nV402][Jd0ojD@00D0ojD@0P00000;0?nU40030000003oYA00000000P0ojD@00<0[Jf]
0?nS400000000`3oXa02000000`0oj<@0P0000060?nS40030:f][@3lX100o:0@008000001P3lX102
000000P0o:0@00<000000?bP403lX1000`3lX1000`2][Jd000000:f][@030:f][A40mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f]
[@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f]
[@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@800000303oYQ400`000000ojHA0?nV4@070?nV
4@8000001@3oYQ400`2][Jd0ojH@0?nV40020?nV408000001`3oYQ000`000000ojH@0000000;0?nV
4080000000<0ojH@0:f][@3oYA00103oYA000`000000ojD@0000000;0?nU40030000003oYA000000
00P0ojD@00<0[Jf]0?nS400000000P3oXa02000000d0oj<@0P0000060?nS40030:f][@3lX100o:0@
008000001P3lX102000000P0o:0@00<000000?bP403lX1000`3lX1000`2][Jd00000000000030?JL
3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3P
iP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0
oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000`0
ojHA00<000000?nV4@3oYQ401`3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000L0
ojH@00<000000?nV400000002`3oYQ02000000030?nV402][Jd0ojD@00@0ojD@00<000000?nU4000
0000303oYA02000000P0ojD@00D0[Jf]0?nS403oXa0000000?nS4002000000d0oj<@0P0000060?nS
40030:f][@3lX100o:0@008000001P3lX1000`000000o:0@0?bP40070?bP40030000003lX100o:0@
00<0o:0@00<0[Jf]0000000000001`3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000`0ojHA00<000000?nV4@3o
YQ401`3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000L0ojH@00<000000?nV4000
00002`3oYQ02000000030?nV402][Jd0ojD@00@0ojD@00<000000?nU40000000303oYA02000000P0
ojD@00D0[Jf]0?nS403oXa0000000?nS4002000000d0oj<@0P0000060?nS40030:f][@3lX100o:0@
008000001P3lX1000`000000o:0@0?bP40070?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?JL
3`0000002`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:
3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0
ojHA0P00000F0?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV40020?nV408000001`3oYQ000`000000
ojH@0000000;0?nV4080000000<0ojH@0:f][@3oYA00103oYA000`000000ojD@0000000<0?nU4080
0000203oYA00102][Jd0oj<@0?nS403oXa02000000h0oj<@0P0000070?nS40040:f][@3lX1000000
000000H0o:0@00<000000?bP403lX1001`3lX1000`000000o:0@0?bP40030?bP40030:f][@3fW0l0
mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406@3oYQ42000000D0ojHA00<000000?nV4@3oYQ403P3oYQ42000000D0ojHA00<0[Jf]0?nV
403oYQ000P3oYQ02000000L0ojH@00<000000?nV400000002`3oYQ02000000030?nV402][Jd0ojD@
00D0ojD@0P00000<0?nU40800000203oYA00102][Jd0oj<@0?nS403oXa02000000h0oj<@0P000007
0?nS40040:f][@3lX100000000000100o:0@00<000000?bP403lX1000`3lX1000`2][Jd0mY`?0?JL
3`0C0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V
0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]
5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA0P0000050?nV4@030000
003oYQ40ojHA00h0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@0P0000070?nV40030000
003oYQ00000000/0ojH@0P0000000`3oYQ00[Jf]0?nU40050?nU40800000303oYA02000000P0ojD@
00<0[Jf]0?nS403oXa000`00000>0?nS408000001`3oXa00102][Jd0o:0@00000000000A0?bP4003
0000003lX100o:0@0080o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@h0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0
/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3l
X100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ420000
00D0ojHA00<000000?nV4@3oYQ403P3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ020000
00L0ojH@00<000000?nV400000002`3oYQ02000000030?nV402][Jd0ojD@00D0ojD@0P00000<0?nU
40800000203oYA000`2][Jd0oj<@0?nS4003000000h0oj<@0P0000070?nS40040:f][@3lX1000000
00000100o:0@0P0000040?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh2
0:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H1
0?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01T0ojHA0P0000050?nV4@030000003oYQ40ojHA00h0ojHA0P00000:0:f]
[@800000202][Jd2000000/0[Jf]0P0000080:f][@800000303oYA02000000P0ojD@00<0[Jf]0?nS
403oXa000P0000000`3oXa0000000?nS400<0?nS408000001`3oXa00102][Jd0o:0@00000000000@
0?bP40800000103lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd9
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP19
0;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000D0ojHA00<000000:f][@2][Jd03P2][Jd20000
00D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000P0ojH@0P00000;0?nV4080000000<0ojH@0:f]
[@3oYA001@3oYA02000000`0[Jf]0P0000000`2][Jd0ojD@0?nU40050?nU40040:f][@3oXa000000
00000080oj<@00<000000?nS403oXa002`3oXa02000000L0oj<@00@0[Jf]0?bP4000000000003P3l
X103000000D0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`
h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H
0?nV4@030:f][@3oYQ40ojHA01D0ojHA102][Jd2000000D0[Jf]00<000000?nV4@3oYQ403P3oYQ42
000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000P0ojH@00<000000?nV400000002P3oYQ02
000000030?nV402][Jd0ojD@00H0ojD@0P00000:0?nU408000000P3oYA090:f][@80000000@0[Jf]
0?nS403oXa000000303oXa02000000L0oj<@00@0[Jf]0?bP4000000000003@3lX10010000000o:0@
0?bP400000050?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0
/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f]
[@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0
ojHA00<0[Jf]0?nV4@3oYQ40303oYQ490:f][@@0ojHA0P0000050?nV4@030000003oYQ40ojHA00h0
ojHA0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@0P0000090?nV408000002P3oYQ0200000003
0?nV402][Jd0ojD@00H0ojD@0P00000:0?nU408000002@3oYA001@2][Jd0oj<@000000000000oj<@
0080[Jf]00<000000:f][@2][Jd01@2][Jd50?nS408000001`3oXa00102][Jd0o:0@00000000000;
0?bP4080000000<0o:0@0000000000001P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]
0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00/0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@d0ojHA0P0000050?nV4@030000003oYQ40
ojHA00h0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@0080ojH@0P0000090?nV408000002P3oYQ02
000000030?nV402][Jd0ojD@00H0ojD@0P00000:0?nU408000002@3oYA000`2][Jd0000000000004
0?nS40030000003oXa00oj<@00D0oj<@1@2][Jd2000000<0[Jf]103oXa00102][Jd0o:0@00000000
000:0?bP40040000003lX100o:0@000000P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`
h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]5`3oYQ42000000<0ojHA0`00000@0?nV4@8000001@3o
YQ400`2][Jd0ojH@0?nV40020?nV408000002@3oYQ02000000T0ojH@0`0000000`3oYQ00[Jf]0?nU
40060?nU408000002P3oYA02000000T0ojD@00<0[Jf]0000000000001@3oXa000`000000oj<@0?nS
40090?nS408000000`3oXa060:f][@8000002@3lX10010000000o:0@0000000000090?bP40030:f]
[@3fW0l0000001@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`2]
[JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ460:f][@80ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ4500000080ojHA00<000000?nV4@3oYQ403P3oYQ42000000D0ojHA00<0
[Jf]0?nV403oYQ000P3oYQ02000000X0ojH@0P0000070?nV40060000003oYQ0000000000003oYQ00
[Jf]203oYA02000000P0ojD@0P00000:0?nU408000001P3oXa000`000000oj<@0?nS40090?nS4080
00001`3oXa00102][Jd0o:0@0000000000060:f][@80o:0@00<000000?bP400000002`3lX1000`2]
[Jd0mY`?0000000D0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd90=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0
Uf0;0:f][@080=>73P030:f][@3_V100kiP@00H0kiP@00<000000:f][@2][Jd00P3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@P0
ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000D0ojHA00<000000?nV4@3oYQ403P3oYQ42000000D0
ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000X0ojH@0P0000070?nV40060000003oYQ0000000000
003oYQ00[Jf]203oYA02000000L0ojD@00<000000?nU400000002P3oYA02000000L0oj<@00<00000
0?nS403oXa00203oXa02000000L0oj<@00@0[Jf]0?bP4000000000001P3lX100102][Jd000000:f]
[@0000030:f][@T0o:0@00<0[Jf]0?JL3`000000503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=0080fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0
AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00D0kiP@
00<0[Jf]0000000000000`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000D0ojHA
00<000000?nV4@3oYQ403P3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000/0ojH@
0P0000050?nV40030000003oYQ00ojH@0080000000<0ojH@0:f][@3oYA00203oYA0200000003045Y
h@3oYA00ojD@00<0ojD@0P00000;0?nU408000001`3oXa000`000000oj<@0?nS40080?nS40800000
1`3oXa00102][Jd0o:0@0000000000070?bP40800000103lX1060:f][@<0o:0@00<0[Jf]0?JL3`00
0000503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0=^:3@3K
RPd0103KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0
/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40040>nH40030:f][@3_V1000000
00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
00H0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@8000001@3oYQ400`000000ojHA0?nV4@0>0?nV
4@8000001@3oYQ400`2][Jd0ojH@0?nV40020?nV40800000303oYQ02000000<0ojH@00@000000?nV
403oYQ00ojH@0P0000000`3oYQ00[Jf]0?nU40080?nU408000001@3oYA000`000000ojD@0000000:
0?nU408000002@3oXa000`000000oj<@0?nS40070?nS408000001`3oXa00102][Jd0o:0@00000000
00070?bP40030000003lX100o:0@00T0o:0@1@2][Jd00`000000mY`?0?JL3`0B0?JL3`030:f][@3/
UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@@0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@080=>73P050:f][@3_V100kiP@0>nH400000000P2][Jd20>nH40030000003_V100kiP@0080
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]603oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@8000001@3oYQ400`000000ojHA0?nV4@0>0?nV4@8000001@3oYQ400`2][Jd0
000000000004000000h0ojH@0`0000040?nV4080000000<0ojH@0:f][@3oYA002@3oYA02000000<0
ojD@0`00000;0?nU408000002@3oXa000`000000oj<@0?nS40070?nS408000001`3oXa00102][Jd0
o:0@0000000000070?bP40030000003lX100o:0@00L0o:0@00<000000?bP403lX1000P3lX1000`2]
[Jd0mY`?000000030:f][A40mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@070=^:
3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H1
0?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH400000000P000009
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403P3oY1440:f][@030?nT4@2][Jd0
ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000D0ojHA00<000000?nV4@3oYQ402P3oYQ46
000000D0ojHA00<0[Jf]0?nV403oYQ006@3oYQ02000000030?nV402][Jd0ojD@00/0ojD@1000000<
0?nU4080000000<0[Jf]0?nS403oXa00203oXa000`000000oj<@0?nS40060?nS408000001`3oXa00
102][Jd0o:0@0000000000070?bP40030000003lX100o:0@00L0o:0@00<000000?bP403lX1000P3l
X1000`2][Jd0mY`?000000030?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3K
RPd0fhX=00T0fhX=0`2][Jd90;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0P000000
0`2][Jd0kiP@000000090>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402P3oY144
0:f][@D0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@8000001@3oYQ40
0`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU400I
0?nU40P000000`3oXa03000000030?nS40000000oj<@00L0oj<@0P0000070?nS40040:f][@3lX100
0000000000L0o:0@00<000000?bP403lX1001P3lX102000000@0o:0@00<0[Jf]0?JL3`0000001`3f
W0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01`3CQ`h010000000dhL>0000000000030>nH40030000
003_V100kiP@00H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@<0[Jf]
2@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA0P0000050?nV4@030000
003oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ403P3oYQ400`2][Jd0ojH@0?nV400I0?nV40800000
00<0ojH@0:f][@3oYA007@3oYA000`2][Jd0oj<@0?nS40070?nS40@000000`3oXa02000000030?nS
40000000000000L0oj<@00@0[Jf]0?bP4000000000001`3lX1000`000000o:0@0?bP40060?bP4080
0000103lX1000`2][Jd0mY`?0000000;0?JL3`@0[Jf]103fW0l00`11JN40[Jf]0>bF3P0A0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=0P2][Jd80;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>0P0000000`3CQ`h0
[Jf]000000040>nH40030000003_V100kiP@00D0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0
oj@A0?nT4@030?nT4@@0[Jf]303oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0
ojHA0P0000050?nV4@030000003oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ403P3oYQ400`2][Jd0
ojH@0?nV400I0?nV4080000000<0ojH@0:f][@3oYA007@3oYA000`2][Jd0oj<@0?nS400@0?nS40<0
00001`3oXa00102][Jd0o:0@0000000000080?bP40030000003lX100o:0@00D0o:0@0P0000040?bP
40030:f][@3fW0l0000000l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0
/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80000000<0[Jf]
0=>73P000000103_V1000`000000kiP@0>nH40050>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]
0?nT4@2][Jd00`2][Jd@0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ42
000000`0ojHA00<000000?nV4@3oYQ403P3oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@
0:f][@3oYA007@3oYA000`2][Jd0oj<@0?nS400I0?nS40D000002@3lX1000`000000o:0@0?bP4003
0?bP40<00000103lX1000`2][Jd0mY`?0000000C0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`
h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P040000003C
Q`h0000000000080dhL>00<000000>nH403_V1000P3_V1000`000000kiP@0>nH40050>nH40030:f]
[@3lX100o:0@00l0o:0@0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ42000000`0ojHA00<000000?nV4@3oYQ403P3oYQ400`2][Jd0ojH@0?nV400I0?nV40800000
00<0ojH@0:f][@3oYA007@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@
00<000000?bP403lX1000`3lX103000000@0o:0@00<0[Jf]0?JL3`000000503fW0l00`2][Jd0k9H>
0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030:f]
[@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P@000000P3CQ`h00`000000kiP@0>nH40020>nH40030000
003_V100kiP@00D0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402][Jd0oj@A01@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@800000303oYQ400`000000ojHA
0?nV4@0>0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU400M0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1002`3lX10500000080o:0@00<000000?bP403lX100
0P3lX1000`2][Jd0mY`?0000000D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0
R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h00`000000
[Jf]0000000200000080dhL>00@000000>nH403_V100kiP@0P0000070>nH40030:f][@3lX100o:0@
00X0o:0@0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@800000303oYQ400`000000ojHA0?nV4@0>0?nV4@030:f][@3oYQ00ojH@
01T0ojH@0P0000000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX1004P3lX1000`000000o:0@0?bP40020?bP40040:f][@3fW0l00000000001<0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`04
0;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f][D80/>3V0@3oool005T0/>3V00P0[Jf]09MP
2`2GH0/0Uf0;0:f][@3CQ`h0[Jf]00000080dhL>0P0000020=>73P040000003_V100kiP@0>nH4080
00001`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ42000000`0ojHA00<000000?nV4@3o
YQ401`3oYQ4S0:f][@8000002@2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd000000000000C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H70P2][Je20;3PiP40
oooo001I0;3PiP080:f][@2GH0/0Uf0;09MP2`000000[Jf]0=>73P0000020=>73P8000000P3CQ`h0
0`2][Jd0kiP@0>nH4002000000@0kiP@00D000000>nH403_V100kiP@0:f][@060?bP40<0[Jf]2@3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ42000000H0ojHA1@2][Jd2000000T0[Jf]1`3oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0
ojH@0:f][@3oYA001P3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@000000000001<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@<0k9H>00<0
@FWQ0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H700<0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`02000000030=>73P000000
00000080dhL>0P0000020=>73P030:f][@3_V100kiP@00800000103_V1001@000000kiP@0>nH403_
V100[Jf]00@0o:0@0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0F0?nV4@@0[Jf]0P0000060:f][@D0ojHA0P00000@0?nV4@030:f][@3o
YQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU400F0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@000000000001<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2]
[Jd0fhX=00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H700<0[Jf]0;3PiP2`h>H0@02`
h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`02000000030=>73P00000000000080dhL>0P000000
0`3CQ`h0[Jf]0>nH40020>nH40030000003_V100kiP@00<0kiP@00H000000>nH403_V100kiP@0:f]
[@3lX1030:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@8000002`3oYQ4200000100ojHA00<0[Jf]0?nV403oYQ00
6@3oYQ02000000030?nV402][Jd0ojD@01d0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@h0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd000000000000C0?JL3`030:f][@3/UPh0k9H>00l0k9H>
0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd01@28EPL0000008QF1`28EPL0[Jf]0480
/>3V0@3oool005T0/>3V00<0[Jf]09MP2`0000000P0000000`3CQ`h00000000000020=>73P800000
00@0dhL>0:f][@3_V100kiP@0P0000050>nH40040000003_V100kiP@0>nH4080[Jf]4@3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f]
[@h0ojHA0P00000;0?nV4@800000403oYQ400`2][Jd0ojH@0?nV400I0?nV4080000000<0ojH@0:f]
[@3oYA007@3oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@000000000001<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;
0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P0000000`28EPL0[Jf]0;3PiP11
0;3PiP40oooo001I0;3PiP030:f][@000000[Jf]0080000000<0dhL>0000000000000P3CQ`h20000
00040=>73P2][Jd0kiP@0>nH408000001@3_V1000`000000kiP@0:f][@020:f][A80o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0D0?nV4@P0[Jf]603oYQ42000000/0ojHA0P00000@
0?nV4@030:f][@3oYQ00ojH@01T0ojH@0P0000000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00
oj<@01H0oj<@202][JdG0?bP40030:f][@000000000001<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF
1`00000208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V0P000000102][Jd000000000
003CQ`h200000080dhL>0P0000000`3CQ`h0[Jf]0>nH4002000000H0kiP@00D000000:f][@3_V100
kiP@0:f][@0A0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ460:f][@<0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ42000000/0ojHA0P00000@0?nV4@030:f][@3oYQ00ojH@01D0
ojH@1P0000000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403l
X100o:0@1`2][Jd@0?bP40030:f][@000000000001@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H7
0000002][Jd000000:f][@120;3PiP40oooo001I0;3PiP80000000@0Uf0;000000000000dhL>0P00
00020=>73P80000000<0dhL>0:f][@3_V1000P0000040>nH40030:f][@000000000000<0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA1`2]
[Jd90?nV4@030:f][@3oYQ40ojHA01X0ojHA0P0000020?nV4@/00000403oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
40080?bP40H0[Jf]2P3lX1000`2][Jd000000000000D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0@FWQ08QF
1`000000[Jf]00800000@P2`h>H10?ooo`00F02`h>H010000000[Jf]0000002GH0/2000000030=>7
3P00000000000080dhL>0P000000103CQ`h0[Jf]0>nH400000030>nH4080[Jf]00<0kiP@00000000
00000`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3o
YQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA01L0ojHA1`00000K0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
00h0o:0@1`2][Jd30?bP40030:f][@000000000001@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H7
00000028EPL0[Jf]000000120;3PiP40oooo001H0;3PiP040000002][Jd0000009MP2`80000000@0
dhL>000000000000dhL>0P0000020=>73P060:f][@00000000000>nH402][Jd000000`3_V1020000
00<0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@D0[Jf]5P3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1040:f]
[@800000503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3K
RPd0[Jf]0;Ue2`070;Ue2`060:f][@28EPL0R5H708QF1`000000R5H70P0000110;3PiP40oooo001H
0;3PiP040000002][Jd0000009MP2`80000000@0dhL>000000000000dhL>0P0000020=>73P060:f]
[@00000000000:f][@3_V10000000`3_V102000000<0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd00000000000040:f]
[A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/01@2]
[Jd0R5H708QF1`000000R5H700800000@@2`h>H10?ooo`00F02`h>H010000000[Jf]0000002GH0/2
000000040=>73P00000000000=>73P8000000P3CQ`h2000000<0kiP@00@000000>nH403_V100kiP@
0P0000030>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd00000000000040?JL3`D0[Jf]2`3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][Jd80;Ue2`050:f][@28EPL0R5H700000028
EPL00P0000110;3PiP40oooo001G0;3PiP80000000<0[Jf]0000002GH0/00P000000103CQ`h00000
0000003CQ`h2000000040=>73P2][Jd00000000000<0kiP@00@000000>nH403_V100kiP@0P000003
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@T0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd00000000000090?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/01@2][Jd0R5H708QF
1`000000R5H700800000@@2`h>H10?ooo`00E`2`h>H2000000030:f][@000000Uf0;0080000000@0
dhL>000000000000dhL>0P0000000`2][Jd0dhL>000000040>nH40050000003_V100kiP@0>nH4000
0000103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`0000003P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/01@2]
[Jd0R5H708QF1`000000R5H700800000@@2`h>H10?ooo`00E`2`h>H2000000030:f][@000000Uf0;
0080000000@0dhL>000000000000dhL>0P0000020=>73P030000003_V100kiP@0080kiP@00D00000
0>nH403_V100kiP@000000040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd00`2]
[JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`0000004P3fW0l40:f][A40k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;00D0
[Jf]08QF1`28EPL0000008QF1`0200000440/>3V0@3oool005L0/>3V1P0000001@2][Jd000000000
003CQ`h0[Jf]008000000P3CQ`h010000000kiP@0>nH403_V102000000<0kiP@00<000000>nH403_
V1000P3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0000001@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]0080R5H700@0000008QF
1`0000000000@@2`h>H10?ooo`00E`2`h>H30000000409MP2`00000000000:f][@80000000@0[Jf]
0=>73P00000000000P3CQ`h010000000kiP@0>nH403_V102000000<0kiP@00<000000>nH403_V100
0P3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00@0^GD;0:f][@28EPL0
R5H71@0000100;3PiP40oooo001G0;3PiP<0000000@0Uf0;000000000000[Jf]0P0000020=>73P80
00000P3CQ`h01P000000kiP@0>nH40000000kiP@000000<0kiP@00<000000>nH403_V1000P3_V100
0`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd208QF1`D00000@02`h>H1
0?ooo`00E`2`h>H30000000409MP2`00000000000:f][@8000000P3CQ`h200000080dhL>00@00000
0>nH403_V10000001@3_V1000`000000kiP@0>nH40020>nH40030:f][@3lX100o:0@00L0o:0@0P2]
[Jd60?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`000000R5H700<00000@02`h>H10?ooo`00E`2`
h>H30000000409MP2`00000000000:f][@8000000P3CQ`h200000080dhL>00<0[Jf]000000000000
1@3_V102000000@0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
5@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0P28EPL400000400/>3V0@3oool005L0/>3V0`00
0000102GH0/000000000002][Jd200000080dhL>0P0000000`3CQ`h0[Jf]0>nH40070>nH40800000
103_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0
/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@03
0:f][@2iM@/0^GD;00H0^GD;0P2][Jd208QF1`@00000@02`h>H10?ooo`00E`2`h>H010000000[Jf]
0000002GH0/2000000030:f][@00000000000080dhL>0P0000000`3CQ`h0[Jf]0>nH40070>nH4080
0000103_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:
3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`2][Jd0R5H7100000100;3PiP40oooo001G0;3P
iP040000002][Jd0000009MP2`80000000<0[Jf]0000000000000P3CQ`h2000000030=>73P2][Jd0
kiP@00L0kiP@0P0000030>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0
[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H70:f][@28EPL400000400/>3V
0@3oool005H0/>3V0P0000000`2][Jd000000:f][@02000000040:f][@00000000000=>73P800000
0P3CQ`h00`2][Jd0kiP@0>nH40060>nH4080000000D0kiP@0:f][@2][Jd0kiP@0:f][@0A0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P04
0:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H7
0:f][@@00000@02`h>H10?ooo`00EP2`h>H2000000030:f][@000000[Jf]0080000000<0[Jf]0000
000000001@3CQ`h00`2][Jd0kiP@0>nH40060>nH4080000000D0[Jf]0>nH403_V100kiP@0:f][@0A
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB
0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@03
0=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H708QF1`@00000@02`
h>H10?ooo`00EP2`h>H2000000030:f][@000000Uf0;0080000000<0[Jf]0000000000001@3CQ`h0
0`2][Jd0kiP@0>nH40050>nH40030:f][@000000000000@0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX100
0`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd2
0:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL400000400/>3V0@3o
ool005H0/>3V0P0000000`2][Jd0000009MP2`04000000H0dhL>00<0[Jf]0>nH403_V1000`3_V102
0:f][@030>nH40000000000000@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00<0[Jf]
0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL400000400/>3V0@3oool005H0/>3V0P000000
0`2][Jd0000009MP2`02000000030:f][@3CQ`h0dhL>00D0dhL>00@0[Jf]0>nH403_V100kiP@0P2]
[Jd30>nH40800000103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00@0
[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;
00<0[Jf]08QF1`28EPL0100000100;3PiP40oooo001F0;3PiP80000000<0[Jf]0000002GH0/00P00
00080=>73P040:f][@3_V100[Jf]0:f][@H0kiP@00<000000>nH403_V1000P3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue2`030:f][@28EPL0R5H700800000
00<0@FWQ0000002`h>H0?`2`h>H10?ooo`00EP2`h>H2000000050:f][@000000Uf0;0000002][Jd0
203CQ`h20:f][@P0kiP@00<000000>nH403_V1000P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=0`2][Jd70;Ue2`030:f][@28EPL0R5H70080000000<0@FWQ0000002`h>H0
?`2`h>H10?ooo`00EP2`h>H2000000050:f][@000000Uf0;09MP2`2][Jd01`3CQ`h20:f][@h0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@H0
^GD;00L0[Jf]08QF1`28EPL0R5H700000011JN4000000400/>3V0@3oool005H0/>3V0`00000309MP
2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@
0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>
0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00L0[Jf]
08QF1`28EPL0R5H700000011JN4000000400/>3V0@3oool005H0/>3V0`00000309MP2`030:f][@3C
Q`h0dhL>0080dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@0100o:0@
00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00H0[Jf]08QF1`28EPL0
R5H700000011JN42000003l0/>3V0@3oool005H0/>3V0`00000309MP2`050:f][@3CQ`h0dhL>0=>7
3P2][Jd0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3P
iP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00@0[Jf]0;Ue
2`2iM@/0[Jf]0`28EPL010000000@FWQ00000000000o0;3PiP40oooo001F0;3PiP80000000H0[Jf]
09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`050;Ue2`<0[Jf]0`28EPL010000000@FWQ00000000000o0;3PiP40oooo001F0;3PiP800000
00H0[Jf]09MP2`2GH0/0Uf0;045Yh@2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0R5H70000
002][Jd2000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2]
[Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`80[Jf]0P28EPL010000000[Jf]00000000000o0;3PiP40oooo001F0;3PiP030000002]
[Jd0Uf0;0080Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103l
X1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0P28EPL4000003l0/>3V0@3o
ool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`000000[Jf]0=>73P070=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH3
0:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>
0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0[Jf]08QF1`@00000?`2`
h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2GH0/0[Jf]0000002][Jd0203CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f]
[@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0[Jf]08QF1`@0
0000?`2`h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2][Jd0Uf0;0000002][Jd0203CQ`h00`2]
[Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0[Jf]08QF1`03
000003l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0[Jf]09MP2`000000[Jf]00P0dhL>00<0
[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0
0`00000o0;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]0080Uf0;00<000000:f][@3CQ`h01`3C
Q`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H7
0:f][@03000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l
00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh
0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H7
00<000000:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3C
Q`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080/J^M
0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]1P2n^KP0102][Jd0@FWQ0:f][@2][Jd30=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`000000[Jf]0;3PiP0o0;3PiP40
oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h0102][Jd0kiP@
0:f][@2][Jd20:BNS`05045Yh@2TWXl0Y9j?0:BNS`11JN401P2aZid20:f][@D0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3P
iPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji
^02n^KP0_[Vh0P2][Jd80;ji^0040:f][@11JN40@FWQ0;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2i
M@/01P2][Jd0R5H708QF1`28EPL000000:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2GH0/0
0P2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@020:BNS`80
@FWQ202aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0@FWQ045Yh@020;B`
/@03045Yh@2][Jd0[Jf]00X0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3P
iP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0Y9j?0:BNS`040:BN
S`03045Yh@2TWXl0Y9j?0080@FWQ2P2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji
^080@FWQ0`2d/;42045Yh@030;B`/@2][Jd0[Jf]00P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je0
0;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h20:f]
[@L0Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@0<0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33
_K/30:f][@030<>m^`2][Jd0_[Vh00H0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP2045Yh@<0];2a0P11
JN420;B`/@03045Yh@2][Jd0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo
001E0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P<0[Jf]1`2TWXl01011JN40Y9j?
0:BNS`2][Jd>0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0
[Jf]1033_K/00`2][Jd0_[Vh0;ji^0020;ji^004045Yh@2n^KP0_[Vh045Yh@D0_[Vh0P11JN430;B`
/@80@FWQ0P2d/;42045Yh@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0
/>3V03d0/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00D0[Jf]
045Yh@2:QGD0[Jf]045Yh@050:BNS`80@FWQ0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n
^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0@FWQ1@2n^KP2045Yh@<0];2a0P11JN420;B`/@80@FWQ
102][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00
E@2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h01`2][Jd0RXEe045Yh@2:QGD0[Jf]
045Yh@2][Jd00P2TWXl4045Yh@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP06
0;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]
0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`2][Jd00P2][Jd:0<>m^`80@FWQ102n^KP00`11JN40_[Vh0;ji^002045Yh@@0_[Vh0P11JN43
0;B`/@<0@FWQ00D0];2a045Yh@11JN40];2a045Yh@0209nKX0040:f][@2iM@/0^GD;0:f][@<0R5H7
0P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001E0;3PiP80000000H0[Jf]09MP2`2GH0/0Uf0;
0:f][@3CQ`h20:f][@80RXEe00T0@FWQ08Z5M@2][Jd0@FWQ0:BNS`2][Jd0@FWQ0:BNS`11JN40102T
WXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg
[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd<0<>m^`80@FWQ00<0[Jf]0;ji^02n^KP00P2n
^KP00`11JN40_[Vh0;ji^002045Yh@@0_[Vh0P11JN420;B`/@80@FWQ00<0];2a0:f][@2][Jd00P11
JN400`2d/;40@FWQ09nKX00209nKX0<0[Jf]1028EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001E
0;3PiP030000002][Jd0Uf0;00<0Uf0;0P2][Jd408Z5M@04045Yh@2:QGD0[Jf]045Yh@80Y9j?0P11
JN450:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0_02]
[Jd0`kfk00X0`kfk00D0@FWQ0<>m^`11JN40@FWQ0:f][@040;ji^003045Yh@2n^KP0_[Vh0080@FWQ
102n^KP00`11JN40[Jf]0;B`/@020;B`/@80[Jf]0P2d/;42045Yh@030;B`/@11JN40Wi^P00@0Wi^P
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001E0;3PiP030000002]
[Jd0Uf0;00<0Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD01011JN40RXEe0:f][@11JN420:BNS`04045Y
h@2TWXl0[Jf]0:f][@<0Y9j?00<0[Jf]045Yh@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0
`kfk0<>m^`070<>m^`80@FWQ00D0`kfk045Yh@11JN40`kfk0:f][@030;ji^0<0@FWQ00<0_[Vh045Y
h@11JN40102n^KP01@11JN40[Jf]0;B`/@2d/;40[Jf]00@0];2a1011JN4609nKX0060:f][@28EPL0
R5H708QF1`2][Jd00000?`2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1P2:
QGD3045Yh@80Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?0:f][@020:BNS`030:f][@11JN40/J^M00`0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`
0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l
0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ0`33_K/2045Yh@80`kfk
00<0[Jf]0;ji^02n^KP00`11JN400`2n^KP0@FWQ045Yh@040;ji^004045Yh@2][Jd0[Jf]0:f][@D0
];2a0`11JN400`2][Jd0Wi^P09nKX00409nKX0060:f][@28EPL0R5H708QF1`2][Jd00000?`2`h>H1
0?ooo`00E@2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1`2:QGD01@2][Jd0Y9j?0:BNS`2TWXl0
@FWQ00<0Y9j?00D0@FWQ0:f][@2][Jd0[Jf]045Yh@0=0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m
/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@33
_K/0`kfk00D0`kfk0P11JN440<>m^`04045Yh@33_K/0`kfk0:f][@80_[Vh0`11JN400`2n^KP0@FWQ
045Yh@040;ji^003045Yh@2][Jd0];2a00H0];2a0P11JN400`2d/;40[Jf]09nKX00609nKX0050:f]
[@28EPL0R5H70:f][@000000?`2`h>H10?ooo`00E@2`h>H010000000[Jf]09MP2`2GH0/30:f][@80
RXEe00<0@FWQ08Z5M@2:QGD00P2:QGD01@2][Jd0Y9j?0:BNS`2TWXl0@FWQ00<0Y9j?00D0@FWQ0:BN
S`2TWXl0[Jf]045Yh@0=0;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`11JN4=0;jg[0@0[Jf]00<0_[N/
0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]
0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][Jd>
0<K0_0@0@FWQ1`33_K/00`11JN40`kfk0<>m^`030<>m^`04045Yh@33_K/0`kfk0:f][@80_[Vh1011
JN40102n^KP0@FWQ045Yh@2n^KP20:f][@03045Yh@2][Jd0];2a00D0];2a0P11JN420;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P0P2][Jd00`28EPL0[Jf]0000000o0;3PiP40oooo001F0;3PiP040:f][@2G
H0/0[Jf]06=PD`80[Jf]00<0RXEe045Yh@11JN400`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`05045Y
h@2TWXl0Y9j?0:BNS`11JN400P2TWXl0102][Jd0@FWQ0:f][@2][Jd;0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V0`11JN4?0;jg[0@0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l00`0a/2l0`11JN400`36`;`0[Jf]0<>m^`060<>m
^`03045Yh@33_K/0`kfk00<0`kfk00@0@FWQ0<>m^`33_K/0[Jf]0P2n^KP5045Yh@030;ji^011JN40
[Jf]0080_[Vh00<0@FWQ0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0
[Jf]0:f][@000000?`2`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00@0[Jf]08Z5M@11JN40@FWQ0`2:
QGD00`2][Jd0Y9j?0:BNS`030:BNS`04045Yh@2TWXl0@FWQ045Yh@80Y9j?00@0[Jf]045Yh@2aZid0
/J^M0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V0P11JN400`2n]j`0@FWQ045Yh@0>0;jg[003
0:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0
al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00d0a/2l0P11JN400`36`;`0[Jf]0<>m^`060<>m^`03
045Yh@33_K/0`kfk00<0`kfk00@0@FWQ0<>m^`33_K/0[Jf]0P2n^KP5045Yh@030:f][@11JN40_[Vh
0080_[Vh00<0@FWQ0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00@0L6ii0:f]
[@2][Jd00000?`2`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd00`2:QGD0@FWQ08Z5M@0208Z5
M@030:f][@2TWXl0Y9j?00@0Y9j?00<0@FWQ0:BNS`11JN400P2TWXl00`2][Jd0@FWQ0;6[W@040;6[
W@80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP80@FWQ0`2n]j`2045Yh@D0_[N/00<0@FWQ0;jg
[02n]j`0102n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0_0020<K0_0<0@FWQ2036`;`2045Y
h@030<K0_02][Jd0`kfk00H0`kfk00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@060<>m^`2][Jd00000
0;ji^011JN40[Jf]0`11JN400`2n^KP0@FWQ0;ji^0020;ji^003045Yh@2][Jd0];2a00<0];2a00<0
@FWQ0;B`/@2d/;400`2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD0
0`2][Jd0Y9j?0:BNS`060:BNS`03045Yh@2TWXl0Y9j?0080@FWQ1`2aZid30:f][@<0/J^M00<0[Jf]
0;VbYP2i/ZH03@2i/ZH00`2][Jd0@FWQ045Yh@040;jg[080@FWQ1@2n]j`2045Yh@@0_[N/00<0[Jf]
0<6j/031^[002P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]
045Yh@11JN400P11JN430<K0_080@FWQ1P36`;`2045Yh@030<K0_02][Jd0`kfk00H0`kfk00<0@FWQ
0<>m^`33_K/00`33_K/2045Yh@060<>m^`2][Jd0_[Vh0:f][@11JN40_[Vh0`11JN400`2n^KP0@FWQ
0;ji^0020;ji^003045Yh@2][Jd0];2a00<0];2a00<0@FWQ0;B`/@2d/;400`2d/;400`2][Jd0Wi^P
09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f]
[@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03
045Yh@2aZid0/J^M00T0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0>0;VbYP030:f][@11JN40@FWQ00D0
_[N/00<0@FWQ0;jg[02n]j`0102n]j`3045Yh@80_[N/00<0[Jf]0<6j/031^[003`31^[080:f][A00
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0
b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0140al6l00@0[Jf]0<K0_036`;`0@FWQ1@36`;`2045Y
h@D0a/2l0P11JN400`36`;`0[Jf]0<>m^`060<>m^`80@FWQ1033_K/2045Yh@<0[Jf]00@0_[Vh045Y
h@2n^KP0_[Vh0P11JN420;ji^005045Yh@2n^KP0_[Vh045Yh@2][Jd0102d/;400`11JN40];2a0;B`
/@030;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl00`11JN40/J^M0;6[W@0;0;6[W@<0[Jf]3P2i/ZH00`2][Jd0@FWQ045Y
h@050;jg[080@FWQ1@2n]j`00`11JN40_[N/0;jg[0020;jg[0030:f][@31^[00`KZ`0140`KZ`00<0
[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00A0<O1_0040:f]
[@36`;`0a/2l045Yh@H0a/2l0P11JN440<K0_080@FWQ00<0a/2l0:f][@33_K/01`33_K/7045Yh@03
0<>m^`2][Jd0_[Vh0080@FWQ0P2n^KP2045Yh@80_[Vh0P11JN420;ji^003045Yh@2d/;40];2a0080
];2a00<0@FWQ0;B`/@2d/;400`2d/;400`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080
[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe
00<0[Jf]08Z5M@2][Jd02`2TWXl00`11JN40/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0[Jf]0080[Jf]
2`2i/ZH00`2][Jd0@FWQ045Yh@050;jg[080@FWQ1@2n]j`00`11JN40_[N/0;jg[0020;jg[0030:f]
[@31^[00`KZ`00H0`KZ`0`11JN480<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f]
[@36_kL0a[ng0140a[ng1`11JN4D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
3`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04@37`K`0102][Jd0a/2l0<K0_011JN460<K0_080
@FWQ1036`;`2045Yh@030<K0_02][Jd0`kfk00P0`kfk0`2][Jd01P33_K/0@FWQ045Yh@33_K/0[Jf]
0;ji^080@FWQ0P2n^KP2045Yh@030;ji^011JN40@FWQ00<0_[Vh00<0@FWQ0;B`/@2d/;400P2d/;40
0`11JN40];2a0;B`/@030;B`/@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]2`2TWXl00`11
JN40/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V0080^K:V0`2][Jd80;VbYP030:f][@11JN40@FWQ
00D0_[N/0P11JN450;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]0<6j/031^[001031^[02045Y
h@<0`KZ`00<0@FWQ0<6j/031^[000P31^[001011JN40`KZ`0<6j/02][JdE0<>m/`030:f][@35_[D0
aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0@FWQ0:f][@37`KP05@37`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`0102][Jd0a/2l0<K0_011JN470<K0_080@FWQ0`36
`;`2045Yh@030<K0_02][Jd0`kfk00H0`kfk0P2][Jd40<>m^`05045Yh@33_K/0`kfk0:f][@2n^KP0
0P11JN420;ji^080@FWQ1P2n^KP00`11JN40];2a0;B`/@020;B`/@03045Yh@2d/;40];2a00<0];2a
00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0@FWQ0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP050;VbYP@0[Jf]102i/ZH00`2][Jd0@FWQ
045Yh@050;jg[080@FWQ1@2n]j`01@11JN40_[N/0;jg[02n]j`0[Jf]00H0`KZ`0P11JN450<6j/004
045Yh@31^[00@FWQ045Yh@<0`KZ`00D0[Jf]0<>m/`33_K<0`kfc045Yh@0A0<>m/`030:f][@35_[D0
aKje00l0aKje4@2][Jd;0<Jo]`03045Yh@2][Jd0al6h01D0al6h00<0[Jf]0<O1^P37`KX02P37`KXA
0:f][A40b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0040:f][@36`;`0
a/2l045Yh@L0a/2l0P11JN440<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P33_K/30:f][@H0`kfk00D0
@FWQ0<>m^`33_K/0[Jf]0;ji^003045Yh@T0_[Vh0P11JN420;B`/@80@FWQ0`2d/;430:f][@L0Wi^P
00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2]
[Jd01`2:QGD30:f][@T0Y9j?00<0@FWQ0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP<0
[Jf]00@0^K:V0:f][@11JN40@FWQ1@2n]j`2045Yh@D0_[N/00D0@FWQ0;jg[02n]j`0_[N/0:f][@06
0<6j/080@FWQ1@31^[03045Yh@@0`KZ`00D0[Jf]0<>m/`33_K<0`kfc045Yh@050<>m/`03045Yh@33
_K<0`kfc00T0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]`/0[Jf]00<0
@FWQ0:f][@2][Jd08P2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00A0<O1_0040:f][@36`;`0a/2l045Yh@P0a/2l00<0@FWQ0<K0_036`;`0
0P36`;`2045Yh@030:f][@33_K/0[Jf]0080[Jf]1033_K/00`11JN40`kfk0<>m^`020<>m^`05045Y
h@33_K/0`kfk0:f][@2n^KP00P11JN4:0;ji^080@FWQ0P2d/;42045Yh@80];2a00@0[Jf]0;B`/@2d
/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=P
D`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`11JN40/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00`0^K:V0P2][Jd2045Yh@H0_[N/0P11JN440;jg[005045Yh@2n]j`0
_[N/0;jg[02][Jd01P31^[02045Yh@H0`KZ`0P11JN440<6j/0050:f][@33_K<0`kfc0<>m/`11JN40
1@33_K<00`11JN40`kfc0<>m/`090<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5036_kL00`11JN40[Jf]0<O1^00E0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k045Yh@0C0<S1^`030:f][@37`K`0al6l0140al6l00@0[Jf]0<K0_036`;`0
@FWQ2036`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ0P2][Jd70<>m^`03045Yh@33_K/0`kfk0080
`kfk00D0@FWQ0<>m^`33_K/0[Jf]045Yh@0<0;ji^0040:f][@11JN40];2a045Yh@80];2a0P2][Jd3
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G
0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BN
S`040:BNS`03045Yh@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0@FWQ045Y
h@030:f][@<0_[N/0P11JN430;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/0040<6j/080@FWQ1P31
^[02045Yh@@0`KZ`00H0[Jf]0<>m/`33_K<0@FWQ0<>m/`11JN440<>m/`03045Yh@33_K<0`kfc00T0
`kfc00<0[Jf]0<Fn]@11JN400P11JN430<Fn]@03045Yh@35_[D0aKje00`0aKje00<0[Jf]0<Jo]`36
_kL05036_kL00`11JN40[Jf]0<O1^00E0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/02`38`K/4045Yh@D0b<6k00@0[Jf]0<S1^`11JN40@FWQ4P38`K/00`2][Jd0al6l0<O1_00A0<O1
_0040:f][@36`;`0a/2l045Yh@P0a/2l00<0@FWQ0:f][@2][Jd00P2][Jd2045Yh@040:f][@33_K/0
`kfk045Yh@D0`kfk00<0@FWQ0<>m^`33_K/00P11JN430<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0
[Jf]0;B`/@11JN40@FWQ0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0
[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0
Y9j?0P2][Jd40:BNS`03045Yh@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH2045Yh@@0
_[N/0`2][Jd2045Yh@<0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`00@0`KZ`0P11JN460<6j/080
@FWQ1031^[000`2][Jd0`kfc0<>m/`03045Yh@<0`kfc00<0@FWQ0<>m/`11JN402P33_K<2045Yh@<0
aKje0P11JN400`35_[D0@FWQ0<Fn]@030<Fn]@L0@FWQ0`35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`03
045Yh@2][Jd0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX3045Yh@P0b<6k00@0@FWQ0<S1^`38
`K/0@FWQ1038`K/00`11JN40b<6k0<S1^`020<S1^`030:f][@38`K/0@FWQ01<0b<6k00<0[Jf]0<O1
_037`K`04@37`K`0102][Jd0a/2l0<K0_011JN440<K0_0@0[Jf]00<0@FWQ0<K0_036`;`00P36`;`2
045Yh@030:f][@33_K/0`kfk0080@FWQ1@33_K/2045Yh@D0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0
102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]
@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2]
[Jd20:BNS`03045Yh@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH2045Yh@L0_[N/0P11
JN430:f][@80@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/0050<6j/080@FWQ1@31^[02045Yh@@0`KZ`00<0
[Jf]0<>m/`33_K<00`11JN430<>m/`<0@FWQ2@33_K<00`11JN40[Jf]0<Fn]@040<Fn]@03045Yh@35
_[D0@FWQ00L0aKje00<0@FWQ0<Fn]@35_[D01035_[D00`2][Jd0a[ng0<Jo]`060<Jo]`@0@FWQ1@36
_kL2045Yh@<0a[ng00<0@FWQ0:f][@37`KP05@37`KP7045Yh@80al6j1`11JN460<O1^P04045Yh@37
`KX0[Jf]0<S1^`80@FWQ1P38`K/00`11JN40b<6k045Yh@060<S1^`05045Yh@38`K/0b<6k0<S1^`2]
[Jd05@38`K/00`2][Jd0al6l0<O1_00A0<O1_0040:f][@36`;`0a/2l045Yh@@0[Jf]1036`;`00`11
JN40a/2l0<K0_0020<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P11JN4<0<>m^`030:f][@2n^KP0_[Vh
00/0_[Vh0`2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?oo
o`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd=0;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V0P11JN470;jg[080@FWQ0`2n]j`2045Yh@80[Jf]00<0_[N/0:f][@31
^[001P31^[02045Yh@D0`KZ`0P11JN440<6j/0060:f][@33_K<0`kfc045Yh@33_K<0@FWQ0`33_K<3
045Yh@P0`kfc0P11JN400`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ1`35_[D00`11JN40aKje0<Fn]@04
0<Fn]@030:f][@36_kL0a[ng00@0a[ng0`11JN430<Jo]`80@FWQ00<0a[ng045Yh@11JN401@36_kL0
1011JN40[Jf]0<O1^037`KP3045Yh@P0al6h1`11JN420<O1^0030:f][@37`KX0al6j0080@FWQ1`37
`KX2045Yh@L0al6j0P11JN400`37`KX0[Jf]0<S1^`020<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11
JN470<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd05@38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]
00<0@FWQ0<K0_036`;`01P36`;`00`11JN40a/2l0<K0_0020<K0_0<0@FWQ0P33_K/00`11JN40`kfk
0<>m^`0;0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl20:f][@`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH2045Yh@L0_[N/0P11JN430;jg[0<0@FWQ00<0
_[N/0:f][@2][Jd00`2][Jd50<6j/080@FWQ1031^[02045Yh@@0`KZ`00H0[Jf]0<>m/`33_K<0@FWQ
0<>m/`11JN430<>m/`03045Yh@33_K<0@FWQ00L0`kfc0P11JN400`33_K<0[Jf]0<Fn]@050<Fn]@80
@FWQ1`35_[D00`11JN40aKje0<Fn]@040<Fn]@030:f][@36_kL0a[ng00<0a[ng0P11JN460<Jo]`04
045Yh@36_kL0@FWQ045Yh@D0a[ng00@0@FWQ0:f][@11JN40@FWQ0P37`KP3045Yh@T0al6h0P11JN44
0<O1^0030:f][@37`KX0al6j0080@FWQ1`37`KX2045Yh@H0al6j0P11JN420<O1^P030:f][@38`K/0
b<6k0080b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`050<S1^`05045Yh@38`K/0
b<6k0<S1^`2][Jd05@38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`0102][Jd0a/2l0<K0
_011JN480<K0_003045Yh@36`;`0a/2l0080a/2l0P11JN400`2][Jd0@FWQ045Yh@0>0<>m^`030:f]
[@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P
0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2a
Zid0[Jf]0080[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP80@FWQ1`2n]j`2045Yh@<0_[N/0`11
JN420;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]0P11JN420<6j/080@FWQ1031^[001P2][Jd0`kfc
045Yh@11JN40`kfc045Yh@<0`kfc00<0@FWQ0<>m/`11JN401`33_K<2045Yh@030<>m/`2][Jd0aKje
00D0aKje0P11JN470<Fn]@03045Yh@35_[D0aKje00@0aKje00<0[Jf]0<Jo]`36_kL00`36_kL2045Y
h@L0a[ng0P11JN460<Jo]`80@FWQ1P37`KP2045Yh@P0al6h0P11JN440<O1^0030:f][@37`KX0al6j
0080@FWQ1`37`KX2045Yh@D0al6j0P11JN430<O1^P030:f][@38`K/0b<6k00P0b<6k00<0@FWQ0<S1
^`38`K/01038`K/2045Yh@<0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1
_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0_002045Yh@L0a/2l00<0@FWQ0<K0_036`;`01011JN400`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a
00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:
QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V0P11JN470;jg[080@FWQ0`2n]j`3045Yh@80_[N/00<0[Jf]045Yh@31
^[002031^[020:f][@@0@FWQ00H0[Jf]0<6j/031^[00`KZ`0:f][@33_K<2045Yh@80`kfc00H0@FWQ
0<>m/`11JN40@FWQ0<>m/`11JN470<>m/`80@FWQ00<0`kfc0:f][@35_[D01@35_[D2045Yh@L0aKje
00<0@FWQ0<Fn]@35_[D01035_[D00`2][Jd0a[ng0<Jo]`030<Jo]`80@FWQ1`36_kL2045Yh@H0a[ng
00<0@FWQ0:f][@37`KP01P37`KP2045Yh@L0al6h0P11JN450<O1^0040:f][@37`KX0@FWQ045Yh@L0
al6j0P11JN450<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`03045Yh@38`K/0b<6k0080
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0_036
`;`00P11JN470<K0_003045Yh@36`;`0a/2l00@0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0
Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f]
[@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH2045Yh@L0_[N/0P11JN430;jg[080@FWQ00@0_[N/045Yh@2n]j`0[Jf]0P11JN450<6j/080
@FWQ1@31^[02045Yh@030<6j/02][Jd0[Jf]00<0[Jf]00H0@FWQ0:f][@33_K<0`kfc045Yh@33_K<2
045Yh@80`kfc00<0@FWQ0<>m/`33_K<00`33_K<2045Yh@80`kfc00<0[Jf]0<Fn]@35_[D01035_[D2
045Yh@L0aKje00<0@FWQ0<Fn]@35_[D01035_[D00`2][Jd0a[ng0<Jo]`030<Jo]`80@FWQ1`36_kL2
045Yh@H0a[ng00<0@FWQ0:f][@37`KP01P37`KP2045Yh@L0al6h0P11JN450<O1^0040:f][@37`KX0
@FWQ045Yh@L0al6j0P11JN440<O1^P80@FWQ1037`KX00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ1038
`K/0102][Jd0b<6k0<S1^`11JN4?0<S1^`H0[Jf]4@37`K`00`2][Jd0a/2l0<K0_002045Yh@H0a/2l
0P11JN470<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^003
0:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40
oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH2045Yh@H0_[N/0P11JN420;jg[0@0@FWQ
00@0_[N/045Yh@2n]j`0[Jf]0P11JN450<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN440<6j/004
0:f][@33_K<0@FWQ0<>m/`80[Jf]00<0@FWQ0:f][@11JN400P2][Jd00`33_K<0@FWQ0<>m/`040<>m
/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn]@040<Fn]@80@FWQ1`35_[D00`11JN40aKje0<Fn]@040<Fn
]@030:f][@36_kL0a[ng00<0a[ng0P11JN470<Jo]`80@FWQ1P36_kL00`11JN40[Jf]0<O1^0070<O1
^003045Yh@37`KP0al6h00D0al6h0P11JN450<O1^0040:f][@37`KX0@FWQ045Yh@L0al6j0P11JN44
0<O1^P80@FWQ1037`KX00`2][Jd0b<6k0<S1^`0<0<S1^`<0@FWQ1@38`K/0102][Jd0b<6k0<S1^`11
JN480<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l0080@FWQ1P36
`;`2045Yh@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo
001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@0:0;6[W@<0[Jf]3`2i/ZH2045Yh@H0_[N/0P11JN480;jg[0<0@FWQ1P31^[000`11JN40`KZ`0<6j
/0040<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0[Jf]0<>m/`11JN400`33_K<00`11JN40`kfc045Y
h@020<>m/`030:f][@11JN40[Jf]00@0[Jf]0P11JN420<>m/`030:f][@35_[D0aKje0080aKje1011
JN460<Fn]@80@FWQ1P35_[D00`2][Jd0a[ng0<Jo]`030<Jo]`80@FWQ1`36_kL2045Yh@H0a[ng00<0
@FWQ0:f][@37`KP01`37`KP00`11JN40al6h0<O1^0050<O1^080@FWQ1@37`KP0102][Jd0al6j045Y
h@11JN470<O1^P80@FWQ1037`KX2045Yh@@0al6j00<0[Jf]0<S1^`38`K/02P38`K/2045Yh@030<S1
^`11JN40b<6k00D0b<6k00@0[Jf]0<S1^`38`K/0@FWQ202][Jd:0<S1^`030:f][@37`K`0al6l0140
al6l00<0[Jf]0<K0_036`;`00P11JN460<K0_080@FWQ1`36`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0
[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00
GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f]
[@2i/ZH0[Jf]00<0[Jf]2`2i/ZH2045Yh@D0_[N/0P11JN4:0;jg[0030:f][@31^[00`KZ`00D0`KZ`
00<0@FWQ0<6j/031^[001031^[000`11JN40`KZ`0<6j/0030<6j/0030:f][@33_K<0@FWQ00<0`kfc
00<0@FWQ0<>m/`11JN400`33_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ202][Jd20<Fn]@@0@FWQ
0`35_[D2045Yh@H0aKje00<0[Jf]0<Jo]`36_kL01036_kL2045Yh@H0a[ng0P11JN460<Jo]`03045Y
h@2][Jd0al6h00L0al6h00<0@FWQ0<O1^037`KP01@37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40
@FWQ1`37`KX2045Yh@@0al6j0P11JN440<O1^P030:f][@38`K/0b<6k00T0b<6k00@0@FWQ0<S1^`11
JN40@FWQ0P38`K/80:f][@03045Yh@38`K/0b<6k0100b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2]
[Jd0a/2l0<K0_002045Yh@H0a/2l00<0@FWQ0<K0_036`;`01P36`;`00`2][Jd0`kfk0<>m^`090<>m
^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]
04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@03
0:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP80@FWQ1@2n]j`2045Yh@X0_[N/00<0[Jf]0<6j/031
^[001P31^[03045Yh@80`KZ`00<0@FWQ0<6j/031^[001031^[000`2][Jd0@FWQ0<>m/`030<>m/`03
045Yh@33_K<0@FWQ00<0`kfc00<0@FWQ0<>m/`33_K<00`33_K<2045Yh@030<>m/`000000[Jf]00D0
aKje2@2][Jd2045Yh@030:f][@35_[D0aKje00<0aKje00<0[Jf]0<Jo]`36_kL01@36_kL4045Yh@<0
a[ng0P11JN460<Jo]`03045Yh@2][Jd0al6h00L0al6h00<0@FWQ0<O1^037`KP01@37`KP2045Yh@D0
al6h00@0[Jf]0<O1^P11JN40@FWQ1`37`KX2045Yh@@0al6j0P11JN440<O1^P060:f][@38`K/0b<6k
0<S1^`11JN40b<6k1@2][Jd00`11JN40[Jf]045Yh@040:f][@030<S1^`11JN40b<6k0080b<6k00@0
[Jf]0<S1^`38`K/0@FWQ4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0@FWQ045Yh@H0
a/2l00<0@FWQ0<K0_036`;`01P36`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0
_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]
2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP80@FWQ
102n]j`2045Yh@/0_[N/00<0[Jf]0<6j/031^[002@31^[02045Yh@L0`KZ`00<0[Jf]045Yh@33_K<0
1033_K<00`11JN40`kfc0<>m/`020<>m/`03045Yh@33_K<0`kfc00<0`kfc0P11JN420<>m/`030:f]
[@35_[D0aKje00`0aKje0P11JN400`35_[D0[Jf]0:f][@0?0:f][@D0@FWQ1P36_kL00`11JN40[Jf]
0<O1^0070<O1^003045Yh@37`KP0al6h00D0al6h0P11JN450<O1^0040:f][@37`KX0@FWQ045Yh@L0
al6j0P11JN440:f][@80@FWQ1`2][Jd00`11JN40[Jf]045Yh@050<S1^`80@FWQ1P38`K/01@11JN40
b<6k0<S1^`38`K/0[Jf]0080b<6k00<0@FWQ0<S1^`38`K/04038`K/00`2][Jd0al6l0<O1_00B0<O1
_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN480<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd7
0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP18
0;3PiP40oooo001R0;3PiP030:f][@2TWXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP090;VbYP<0[Jf]1011JN440;jg[080@FWQ2`2n]j`00`2][Jd0`KZ`0<6j/00@0<6j
/0L0@FWQ0P33_K<00`11JN40`kfc0<>m/`030<>m/`03045Yh@33_K<0`kfc0080`kfc0P11JN420<>m
/`030:f][@35_[D0aKje00`0aKje0`11JN450<Fn]@030:f][@36_kL0a[ng00T0a[ng0P2][Jd3045Y
h@H0[Jf]00<0@FWQ0:f][@2][Jd01`2][Jd00`11JN40[Jf]0:f][@050:f][@80@FWQ1`2][Jd2045Y
h@L0[Jf]0P11JN450<O1^P80@FWQ0`37`KX01P2][Jd0b<6k0<S1^`11JN40b<6k045Yh@D0b<6k00<0
@FWQ0<S1^`38`K/01@38`K/01@11JN40b<6k0<S1^`38`K/0[Jf]0080b<6k00<0@FWQ0<S1^`38`K/0
4038`K/00`2][Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l00<0@FWQ0<K0_036
`;`01`36`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0
];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0
302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]1@11JN4<0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<01033_K<01011JN40`kfc0<>m/`33_K<3045Yh@@0`kfc0P11JN420<>m/`03
0:f][@35_[D0aKje00`0aKje0`11JN450<Fn]@03045Yh@36_kL0a[ng00@0a[ng0P11JN460<Jo]`80
@FWQ1P36_kL00`11JN40[Jf]0<O1^0060<O1^080@FWQ1`37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11
JN40@FWQ1`37`KX2045Yh@D0al6j0P11JN430<O1^P050:f][@38`K/0b<6k0<S1^`11JN401P38`K/0
0`11JN40b<6k0<S1^`040<S1^`80@FWQ0`38`K/0102][Jd0b<6k045Yh@11JN4B0<S1^`030:f][@37
`K`0al6l0180al6l00@0[Jf]0<K0_011JN40@FWQ1036`;`2045Yh@L0a/2l102][Jd>0<>m^`030:f]
[@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo
001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02P33
_K<3045Yh@80`kfc0P11JN420<>m/`030:f][@35_[D0aKje00`0aKje0P11JN400`35_[D0@FWQ0<Fn
]@020<Fn]@80@FWQ1P36_kL2045Yh@H0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40[Jf]0<O1
^0060<O1^080@FWQ1`37`KP2045Yh@D0al6h00@0[Jf]0<O1^P11JN40@FWQ1`37`KX2045Yh@H0al6j
0P11JN420<O1^P050:f][@38`K/0b<6k0<S1^`11JN401P38`K/00`11JN40b<6k0<S1^`040<S1^`80
@FWQ0`38`K/00`2][Jd0b<6k045Yh@02045YhA40b<6k00<0[Jf]0<O1_037`K`04P37`K`0102][Jd0
a/2l045Yh@11JN420<K0_0<0@FWQ0`36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2]
[Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80
[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0?0<>m/`80
@FWQ0P33_K<00`2][Jd0aKje0<Fn]@0<0<Fn]@80@FWQ0P35_[D01@11JN40aKje0<Fn]@35_[D0@FWQ
00H0a[ng0P11JN460<Jo]`03045Yh@36_kL0a[ng00D0a[ng0P11JN460<O1^080@FWQ2037`KP2045Y
h@0300000037`KP0al6h0080al6h00<0[Jf]045Yh@11JN402037`KX2045Yh@L0al6j0P11JN401@37
`KX0[Jf]0<S1^`38`K/0@FWQ00P0b<6k1P11JN400`38`K/0@FWQ0<S1^`020<S1^`030:f][@38`K/0
@FWQ0080@FWQ4@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0@FWQ00<0@FWQ0P36`;`4
0:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40
];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<2045Yh@030<>m/`2][Jd0aKje00H0aKje00<0@FWQ
0<Fn]@35_[D00P35_[D4045Yh@<0aKje1011JN470<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ
0<Jo]`36_kL01P36_kL00`11JN40[Jf]045Yh@040<O1^080@FWQ2@37`KP4045Yh@<0al6h00<0[Jf]
045Yh@11JN402037`KX2045Yh@P0al6j1@11JN4D0<S1^`030:f][@38`K/0@FWQ0080@FWQ4@38`K/0
0`2][Jd0al6l0<O1_00B0<O1_080@FWQ00<0a/2l0:f][@2][Jd00`2][Jd;0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[
0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd0
0`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33_K<0`kfc0100`kfc0P11JN400`33_K<0[Jf]0<Fn]@06
0<Fn]@03045Yh@35_[D0aKje00`0aKje00<0[Jf]0<Jo]`36_kL01P36_kL5045Yh@H0a[ng1011JN40
0`2][Jd0al6h045Yh@03045Yh@/0al6h0P11JN420<O1^0@0@FWQ1`37`KX5045Yh@X0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k045Yh@02045YhA40b<6k00<0[Jf]0<O1_037`K`04037`K`5
0:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H1
0?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg
[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0@0<>m/`80@FWQ00<0`kfc0:f][@35_[D01@35_[D2045Y
h@h0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00>0<O1^080@FWQ1@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`11JN400P11JN4A0<S1
^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j
/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0A0<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D01035_[D2045Y
h@h0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00>0<O1^080@FWQ1@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`11JN400P11JN4A0<S1
^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0
`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc0140`kfc0P11JN400`2][Jd0aKje0<Fn]@040<Fn]@80
@FWQ3P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00h0al6h0P11JN450<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k045Yh@02045YhA40
b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`
1`2][JdA0<>m/`80@FWQ1@35_[D3045Yh@h0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00>0<O1^080@FWQ1@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00@0[Jf]0<S1^`11JN40@FWQ3`38`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]
0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc0P11JN430<Fn]@80@FWQ00<0aKje045Yh@35
_[D03@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00h0al6h0P11JN450<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`11JN480<S1
^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0
[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje045Yh@02045Yh@<0aKje00<0@FWQ0<Fn]@35
_[D03035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00h0al6h0P11JN450<O1^003
0:f][@37`KX0al6j00P0al6j00<0@FWQ0<O1^P37`KX02@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`04
0:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0
[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00h0al6h0P11JN450<O1^003
0:f][@37`KX0al6j00L0al6j00<0@FWQ0<O1^P11JN402P37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0
[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje
302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02`37`KP5045Yh@D0al6h
00<0[Jf]0<O1^P37`KX02037`KX00`11JN40al6j0<O1^P090<O1^P030:f][@38`K/0b<6k00<0b<6k
302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3P
iP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?oo
o`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V
1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3PiP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]
0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00
/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3o
ool00<00/>3V202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0
/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52807 .33089 m
.52138 .3309 L
s
.53642 .33082 m
.53141 .33408 L
s
.53976 .33078 m
.53642 .33082 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54311 .33393 m
.53976 .33078 L
s
.54478 .3339 m
.53976 .33078 L
s
.508 .33402 m
.50467 .33076 L
s
.50467 .33076 m
.50133 .3307 L
s
.50967 .33404 m
.50467 .33076 L
s
.50133 .3307 m
.49631 .33381 L
s
.255 .412 .882 r
.53214 .32285 m
.5437 .32269 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45323 .32878 m
.45458 .32886 L
s
.255 .412 .882 r
.52719 .33861 m
.52884 .3386 L
s
.52388 .34087 m
.52719 .33861 L
s
.52553 .34087 m
.52719 .33861 L
s
.5156 .3386 m
.51891 .34086 L
s
.51063 .33855 m
.5156 .3386 L
s
.50732 .34077 m
.51063 .33855 L
s
.50566 .34074 m
.51063 .33855 L
s
.52222 .34538 m
.52388 .34087 L
s
.52388 .34538 m
.52553 .34087 L
s
.51891 .34086 m
.52222 .34538 L
s
.54209 .34071 m
.54539 .33839 L
s
.54539 .33839 m
.54869 .33832 L
s
.50565 .34525 m
.50732 .34077 L
s
.54869 .33832 m
.55201 .3405 L
s
.54869 .33832 m
.55366 .34045 L
s
.504 .34523 m
.50566 .34074 L
s
.53879 .34527 m
.54209 .34071 L
s
0 0 0 r
.51298 .36628 m
.51422 .35918 L
s
.5113 .36627 m
.51254 .35919 L
s
.255 .412 .882 r
.55201 .3405 m
.55532 .34492 L
s
.55366 .34045 m
.55698 .34487 L
s
.50564 .34977 m
.50565 .34525 L
s
.47105 .33745 m
.48255 .33792 L
s
.50399 .34974 m
.504 .34523 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49456 .35953 m
.49287 .36272 L
s
.49622 .3628 m
.49456 .35953 L
s
.255 .412 .882 r
.50564 .34977 m
.50729 .35431 L
s
.50399 .34974 m
.50563 .35429 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55698 .34487 m
.55866 .3516 L
s
.55532 .34492 m
.557 .35165 L
s
.56847 .3377 m
.57995 .33718 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47744 .36942 m
.47762 .33773 L
s
.47579 .36936 m
.47597 .33766 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50729 .35431 m
.5106 .35661 L
s
.50563 .35429 m
.5106 .35661 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53709 .32279 m
.53718 .37018 L
s
.53874 .32277 m
.53884 .37016 L
s
.52222 .36573 m
.52222 .34538 L
s
.52388 .34538 m
.52388 .3612 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57166 .37369 m
.57169 .37831 L
s
.255 .412 .882 r
.52056 .35893 m
.5106 .35661 L
s
.557 .35165 m
.55702 .35617 L
s
.46109 .35506 m
.46123 .33696 L
s
.52056 .35893 m
.52222 .3612 L
s
.55866 .3516 m
.55868 .35613 L
s
.45945 .35497 m
.4596 .33687 L
s
.58649 .33683 m
.59788 .33613 L
s
.52222 .36573 m
.52388 .3612 L
s
.5554 .36302 m
.55702 .35617 L
s
.55705 .36297 m
.55868 .35613 L
s
.45631 .33894 m
.45954 .34365 L
s
.45145 .33639 m
.45631 .33894 L
s
.50561 .36334 m
.50727 .36336 L
s
.50727 .36563 m
.50727 .36336 L
s
.53882 .36336 m
.54215 .36784 L
s
.50561 .36561 m
.50561 .36334 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52056 .368 m
.52222 .36573 L
s
.4482 .33618 m
.45145 .33639 L
s
.50561 .36561 m
.50726 .3679 L
s
.47752 .35581 m
.47913 .36267 L
s
.51723 .37025 m
.52056 .368 L
s
.44494 .33822 m
.4482 .33618 L
s
.44332 .3381 m
.4482 .33618 L
s
.48903 .36526 m
.4907 .36304 L
s
.4907 .36304 m
.49234 .36535 L
s
.5521 .36764 m
.5554 .36302 L
s
.50726 .3679 m
.51058 .37021 L
s
.55376 .3676 m
.55705 .36297 L
s
.54215 .36784 m
.54548 .37005 L
s
.51058 .37021 m
.51723 .37025 L
s
.49234 .36762 m
.49234 .36535 L
s
.53219 .37023 m
.53884 .37016 L
s
.48903 .36526 m
.49068 .36757 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5488 .36999 m
.5521 .36764 L
s
.49067 .36984 m
.49234 .36762 L
s
.54548 .37005 m
.5488 .36999 L
s
.5488 .36999 m
.55376 .3676 L
s
.44165 .34251 m
.44494 .33822 L
s
.47913 .36267 m
.48241 .36732 L
s
.45455 .35469 m
.46601 .35531 L
s
.44004 .3424 m
.44332 .3381 L
s
.4857 .3697 m
.49067 .36984 L
s
.48241 .36732 m
.4857 .3697 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43999 .34693 m
.44165 .34251 L
s
.47085 .36915 m
.47744 .36942 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5752 .36231 m
.57852 .3667 L
s
.59301 .33645 m
.59322 .36137 L
s
.59138 .33655 m
.59159 .36146 L
s
.5734 .33749 m
.5737 .38513 L
s
.57504 .33742 m
.57535 .38506 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6092 .33531 m
.60953 .36711 L
s
.60436 .33568 m
.61563 .33479 L
s
.43837 .34681 m
.44004 .3424 L
s
.57852 .3667 m
.58346 .36873 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58181 .39666 m
.58182 .39742 L
s
.58347 .39555 m
.58348 .39734 L
s
.255 .412 .882 r
.4383 .35362 m
.43999 .34693 L
s
.43669 .3535 m
.43837 .34681 L
s
.58999 .3661 m
.59159 .36146 L
s
0 0 0 r
.40787 .32499 m
.40852 .32642 L
s
.255 .412 .882 r
.58346 .36873 m
.58674 .36856 L
s
.59163 .36601 m
.59322 .36137 L
s
.58674 .36856 m
.58999 .3661 L
s
.58674 .36856 m
.59163 .36601 L
s
.46087 .38464 m
.46097 .37096 L
s
.45928 .37771 m
.46097 .37096 L
s
0 0 0 r
.58069 .39741 m
.58847 .39709 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43819 .365 m
.4383 .35362 L
s
.43657 .36488 m
.43669 .3535 L
s
.41926 .33386 m
.42526 .36627 L
s
.41248 .36512 m
.41926 .33386 L
s
.56874 .38533 m
.57535 .38506 L
s
.62684 .33606 m
.63157 .33333 L
s
.62371 .34089 m
.62684 .33606 L
s
.62219 .34785 m
.62371 .34089 L
s
.45596 .3821 m
.45928 .37771 L
s
.45928 .37771 m
.46087 .38464 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62843 .33591 m
.63157 .33333 L
s
.6253 .34075 m
.62843 .33591 L
s
.62379 .34771 m
.6253 .34075 L
s
.63157 .33333 m
.63473 .33301 L
s
.41407 .36527 m
.41917 .34066 L
s
.62219 .34785 m
.62225 .3524 L
s
.43819 .365 m
.43974 .37195 L
s
.63473 .33301 m
.63949 .33478 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62379 .34771 m
.62385 .35226 L
s
.45103 .3841 m
.45596 .3821 L
s
.43657 .36488 m
.43812 .37184 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62225 .3524 m
.62393 .35909 L
s
.60468 .36745 m
.61115 .36698 L
s
.61081 .33518 m
.61115 .36698 L
s
.43974 .37195 m
.44131 .37663 L
s
.62385 .35226 m
.62553 .35895 L
s
.43812 .37184 m
.43969 .37652 L
s
.44776 .3839 m
.45103 .3841 L
s
.44131 .37663 m
.44452 .38141 L
s
.63949 .33478 m
.6427 .33899 L
s
.44452 .38141 m
.44776 .3839 L
s
.4429 .38131 m
.44776 .3839 L
s
.43969 .37652 m
.4429 .38131 L
s
.42045 .36586 m
.43009 .36666 L
s
.62393 .35909 m
.62719 .36337 L
s
.62553 .35895 m
.62878 .36322 L
s
.60966 .37852 m
.6113 .38069 L
s
.60806 .38092 m
.60966 .37852 L
s
.60806 .38092 m
.60971 .3831 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40771 .3537 m
.40772 .35398 L
s
.40539 .38671 m
.40558 .38322 L
s
.40718 .35427 m
.40722 .35364 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4066 .33258 m
.41248 .36512 L
s
.39984 .36383 m
.4066 .33258 L
s
.40142 .364 m
.4065 .3394 L
s
.60971 .3831 m
.6113 .38069 L
s
.62719 .36337 m
.63199 .36521 L
s
.62878 .36322 m
.63199 .36521 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40699 .38686 m
.40704 .38339 L
s
.255 .412 .882 r
.39099 .33078 m
.39254 .33097 L
s
.65351 .33089 m
.65513 .33525 L
s
.65351 .33089 m
.65366 .34 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38786 .33267 m
.39099 .33078 L
s
.3894 .33286 m
.39099 .33078 L
s
.63199 .36521 m
.63676 .36475 L
s
.64133 .35283 m
.64294 .35495 L
s
.63979 .35528 m
.64133 .35283 L
s
.63979 .35528 m
.64139 .3574 L
s
.38778 .33723 m
.3894 .33286 L
s
.65366 .34 m
.65513 .33525 L
s
.65513 .33525 m
.65664 .33278 L
s
.65664 .33278 m
.65969 .33011 L
s
.64294 .35495 m
.64297 .35723 L
s
.63676 .36475 m
.63988 .36214 L
s
.38624 .33703 m
.38786 .33267 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65969 .33011 m
.66582 .32929 L
s
.63988 .36214 m
.64297 .35723 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39515 .36331 m
.40615 .3645 L
s
.38752 .35323 m
.38778 .33723 L
s
.38324 .33207 m
.38624 .33703 L
s
.38589 .35762 m
.38624 .33703 L
s
.38022 .32938 m
.38324 .33207 L
s
.37564 .32874 m
.38022 .32938 L
s
.66582 .32929 m
.66892 .33115 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65388 .35371 m
.6554 .35124 L
s
.65388 .35371 m
.65395 .35829 L
s
.6554 .35124 m
.65845 .34857 L
s
.65392 .356 m
.65543 .35352 L
s
.65543 .35352 m
.65849 .35086 L
s
.37257 .33059 m
.37564 .32874 L
s
.37105 .33037 m
.37564 .32874 L
s
.66892 .33115 m
.67048 .33322 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65849 .35086 m
.66611 .34529 L
s
.65395 .35829 m
.65554 .3604 L
s
.65845 .34857 m
.66607 .343 L
s
.38589 .35762 m
.38752 .35323 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38447 .35055 m
.38597 .35304 L
s
.37531 .34705 m
.38447 .35055 L
s
.67048 .33322 m
.6706 .34008 L
s
.65554 .3604 m
.65868 .36232 L
s
.66607 .343 m
.66908 .34029 L
s
.37097 .33495 m
.37257 .33059 L
s
.66611 .34529 m
.66912 .34258 L
s
.38431 .35972 m
.38589 .35762 L
s
.66908 .34029 m
.67056 .33779 L
s
.36946 .33473 m
.37105 .33037 L
s
.66912 .34258 m
.6706 .34008 L
s
.65868 .36232 m
.66485 .36155 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38119 .36163 m
.38431 .35972 L
s
.37088 .33953 m
.37097 .33495 L
s
.36937 .33931 m
.36946 .33473 L
s
.37231 .34433 m
.37531 .34705 L
s
.3708 .34411 m
.37531 .34705 L
s
.37088 .33953 m
.37231 .34433 L
s
.37506 .36083 m
.38119 .36163 L
s
.36937 .33931 m
.3708 .34411 L
s
.681 .32937 m
.68245 .32685 L
s
.681 .32937 m
.68254 .33143 L
s
.68245 .32685 m
.68398 .32891 L
s
.66485 .36155 m
.66788 .35885 L
s
.66937 .35635 m
.67081 .35154 L
s
.67081 .35154 m
.67098 .36074 L
s
.66788 .35885 m
.66937 .35635 L
s
.66937 .35635 m
.67098 .36074 L
s
.68254 .33143 m
.68398 .32891 L
s
.37062 .3533 m
.37214 .35351 L
s
.3721 .35581 m
.37214 .35351 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37206 .35811 m
.37506 .36083 L
s
.37058 .3556 m
.37062 .3533 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37058 .3556 m
.37206 .35811 L
s
.68276 .3429 m
.68481 .37035 L
s
.6818 .37079 m
.68276 .3429 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3401 .32293 m
.35026 .32476 L
s
.68303 .35671 m
.68331 .37057 L
s
.34518 .35628 m
.34589 .32399 L
s
.35711 .35128 m
.35855 .35382 L
s
.35851 .35613 m
.35855 .35382 L
s
.35558 .35335 m
.35711 .35128 L
s
.35697 .3582 m
.35851 .35613 L
s
.34373 .35603 m
.34444 .32373 L
s
.35558 .35335 m
.35702 .35589 L
s
.6818 .37079 m
.6834 .3752 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35252 .3575 m
.35697 .3582 L
s
.6834 .3752 m
.68481 .37035 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34963 .35471 m
.35252 .3575 L
s
.34549 .34241 m
.34679 .34959 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34679 .34959 m
.34963 .35471 L
s
.33938 .35527 m
.34518 .35628 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32867 .32301 m
.33138 .3282 L
s
.33138 .3282 m
.33269 .3331 L
s
.33269 .3331 m
.33396 .34031 L
s
.32453 .31984 m
.32867 .32301 L
s
.32727 .32273 m
.32997 .32792 L
s
.32997 .32792 m
.33128 .33282 L
s
.33128 .33282 m
.33253 .34004 L
s
.33369 .3519 m
.33396 .34031 L
s
.32453 .31984 m
.32727 .32273 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33226 .35163 m
.33253 .34004 L
s
.31081 .31679 m
.32453 .31984 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3321 .3586 m
.33369 .3519 L
s
.33067 .35834 m
.33226 .35163 L
s
.33056 .36299 m
.3321 .3586 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32914 .36273 m
.33067 .35834 L
s
.32762 .36712 m
.33056 .36299 L
s
.3262 .36685 m
.32914 .36273 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32333 .36864 m
.32762 .36712 L
s
.32333 .36864 m
.3262 .36685 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31362 .36667 m
.31488 .31773 L
s
.315 .36696 m
.31624 .31804 L
s
.30953 .3658 m
.32333 .36864 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76238 .30955 m
.76384 .35904 L
s
.76362 .30919 m
.76509 .3587 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75863 .31062 m
.77095 .30698 L
s
.77095 .30698 m
.77342 .30858 L
s
.77095 .30698 m
.77461 .3082 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77342 .30858 m
.77594 .31254 L
s
.77461 .3082 m
.77712 .31216 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76007 .36004 m
.77247 .35663 L
s
.77594 .31254 m
.77727 .31688 L
s
.77712 .31216 m
.77844 .3165 L
s
.77727 .31688 m
.77866 .3236 L
s
.77844 .3165 m
.77983 .32322 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77866 .3236 m
.77904 .33545 L
s
.78384 .30274 m
.79167 .29992 L
s
.77983 .32322 m
.78021 .33508 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77247 .35663 m
.776 .35319 L
s
.77247 .35663 m
.77481 .35355 L
s
.77481 .35355 m
.77705 .34807 L
s
.77808 .34295 m
.77904 .33545 L
s
.77705 .34807 m
.77808 .34295 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.776 .35319 m
.77823 .34771 L
s
.77926 .34259 m
.78021 .33508 L
s
.78723 .30154 m
.78832 .33481 L
s
.77823 .34771 m
.77926 .34259 L
s
.78835 .30114 m
.78945 .33443 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78491 .33596 m
.78945 .33443 L
s
.78898 .32013 m
.79033 .32688 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79033 .32688 m
.7927 .33087 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7927 .33087 m
.79497 .33247 L
s
.24439 .3011 m
.24551 .29914 L
s
.24455 .29633 m
.24551 .29914 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24343 .29829 m
.24455 .29633 L
s
.79497 .33247 m
.79821 .33128 L
s
.24343 .29829 m
.24439 .3011 L
s
.79697 .32689 m
.79813 .32888 L
s
.79697 .32689 m
.79797 .32409 L
s
.79797 .32409 m
.79911 .32608 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79821 .33128 m
.79919 .32847 L
s
.79911 .32608 m
.79919 .32847 L
s
.24398 .31305 m
.24404 .34226 L
s
.24194 .34146 m
.24398 .31305 L
s
.80563 .3016 m
.80647 .29638 L
s
.80563 .3016 m
.8058 .30639 L
s
.80647 .29638 m
.80937 .29268 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24298 .34186 m
.24348 .32743 L
s
.8058 .30639 m
.80698 .31076 L
s
.80664 .30117 m
.80748 .29595 L
s
.80664 .30117 m
.80681 .30596 L
s
.80748 .29595 m
.80937 .29268 L
s
.80681 .30596 m
.80798 .31033 L
s
.24282 .34668 m
.24404 .34226 L
s
.80937 .29268 m
.81229 .29134 L
s
.80698 .31076 m
.81005 .31187 L
s
.23537 .29482 m
.23627 .29765 L
s
.23601 .30485 m
.23627 .29765 L
s
.23351 .29153 m
.23537 .29482 L
s
.80798 .31033 m
.81005 .31187 L
s
.23503 .30441 m
.2361 .30245 L
s
.24194 .34146 m
.24282 .34668 L
s
.23494 .30682 m
.23601 .30485 L
s
.80732 .32037 m
.8074 .32278 L
s
.80732 .32037 m
.80832 .31995 L
s
.2297 .28974 m
.23351 .29153 L
s
.8074 .32278 m
.80849 .32476 L
s
.23299 .30595 m
.23503 .30441 L
s
.81229 .29134 m
.81429 .29285 L
s
.80832 .31995 m
.80841 .32235 L
s
.2329 .30835 m
.23494 .30682 L
s
.81005 .31187 m
.81594 .31167 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80849 .32476 m
.81057 .32633 L
s
.23443 .32126 m
.23559 .31687 L
s
.23524 .32651 m
.23559 .31687 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22806 .30856 m
.23299 .30595 L
s
.81429 .29285 m
.81635 .29676 L
s
.22798 .31098 m
.2329 .30835 L
s
.23443 .32126 m
.23524 .32651 L
s
.23336 .32325 m
.23443 .32126 L
s
.22775 .29123 m
.2297 .28974 L
s
.81057 .32633 m
.81447 .32463 L
s
.23133 .32481 m
.23336 .32325 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81635 .29676 m
.81711 .29149 L
s
.81635 .29676 m
.81714 .31849 L
s
.81711 .29149 m
.81886 .28817 L
s
.22674 .29319 m
.22775 .29123 L
s
.81728 .29631 m
.81803 .29104 L
s
.81728 .29631 m
.8179 .31321 L
s
.81803 .29104 m
.81886 .28817 L
s
.81886 .28817 m
.81977 .28771 L
s
.22753 .32309 m
.23133 .32481 L
s
.81594 .31167 m
.81696 .31365 L
s
.22601 .28791 m
.22674 .29319 L
s
.22565 .29756 m
.22674 .29319 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81447 .32463 m
.81629 .32135 L
s
.22565 .29756 m
.22601 .28791 L
s
.22612 .31009 m
.22806 .30856 L
s
.22603 .31251 m
.22798 .31098 L
s
.81629 .32135 m
.81714 .31849 L
s
.81714 .31849 m
.8179 .31321 L
s
.22512 .31207 m
.22612 .31009 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22577 .31979 m
.22753 .32309 L
s
.22503 .31449 m
.22603 .31251 L
s
.22494 .31692 m
.22512 .31207 L
s
.22494 .31692 m
.22577 .31979 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2183 .33932 m
.21835 .34023 L
s
.5 Mabswid
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21804 .28612 m
.21956 .29191 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82547 .31936 m
.82761 .2835 L
s
.21564 .28227 m
.21804 .28612 L
s
.82634 .31891 m
.82789 .29077 L
s
.21883 .31134 m
.21892 .30891 L
s
.21815 .30602 m
.21892 .30891 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2192 .34133 m
.21938 .33994 L
s
.5 Mabswid
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21694 .31531 m
.21883 .31134 L
s
.21402 .28131 m
.21564 .28227 L
s
.21722 .30799 m
.21815 .30602 L
s
.21722 .30799 m
.21797 .31089 L
s
.21234 .28277 m
.21402 .28131 L
s
.21156 .28229 m
.21402 .28131 L
s
.21517 .31684 m
.21694 .31531 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82761 .2835 m
.83221 .31572 L
s
.82282 .3207 m
.8289 .31756 L
s
.2106 .28667 m
.21234 .28277 L
s
.21272 .31546 m
.21517 .31684 L
s
.83407 .27964 m
.83844 .31199 L
s
.83221 .31572 m
.83407 .27964 L
s
.20983 .28619 m
.21156 .28229 L
s
.83301 .31526 m
.83435 .28695 L
s
.20955 .29352 m
.2106 .28667 L
s
.21122 .31208 m
.21272 .31546 L
s
.21043 .31161 m
.21272 .31546 L
s
.20879 .29304 m
.20983 .28619 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20936 .29841 m
.20955 .29352 L
s
.20984 .30624 m
.21122 .31208 L
s
.20936 .29841 m
.20984 .30624 L
s
.20859 .29793 m
.20879 .29304 L
s
.20907 .30576 m
.21043 .31161 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20859 .29793 m
.20907 .30576 L
s
.20156 .27288 m
.2064 .2764 L
s
.83616 .3134 m
.84064 .31056 L
s
0 0 0 r
.19947 .27549 m
.19975 .27451 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20292 .30933 m
.20427 .2749 L
s
.20222 .30885 m
.20358 .2744 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84756 .26651 m
.84914 .26217 L
s
.19882 .29517 m
.19886 .29665 L
s
.255 .412 .882 r
.84327 .28596 m
.84374 .28054 L
s
.84288 .29384 m
.84327 .28596 L
s
.84374 .28054 m
.84487 .27461 L
s
.84288 .29384 m
.84337 .30617 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19812 .29451 m
.19834 .30359 L
s
.19834 .30359 m
.19853 .3049 L
s
.255 .412 .882 r
.84394 .28546 m
.84441 .28003 L
s
.84356 .29334 m
.84394 .28546 L
s
.84441 .28003 m
.84552 .2741 L
s
.84487 .27461 m
.84668 .27061 L
s
.84356 .29334 m
.84405 .30568 L
s
.20018 .30739 m
.20292 .30933 L
s
.84552 .2741 m
.84668 .27061 L
s
.84337 .30617 m
.84434 .31311 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19478 .2672 m
.19897 .27083 L
s
.84405 .30568 m
.84502 .31263 L
s
.84668 .27061 m
.84792 .26958 L
s
.20153 .32618 m
.20233 .32417 L
s
.20173 .32122 m
.20233 .32417 L
s
.20094 .32323 m
.20173 .32122 L
s
.84434 .31311 m
.84522 .31759 L
s
.20094 .32323 m
.20153 .32618 L
s
.84502 .31263 m
.84589 .31711 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84792 .26958 m
.8498 .27049 L
s
.19602 .2965 m
.19712 .26928 L
s
.84522 .31759 m
.84675 .3216 L
s
.19542 .296 m
.19652 .26877 L
s
.84589 .31711 m
.8474 .32112 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8498 .27049 m
.85115 .27441 L
s
.84675 .3216 m
.84878 .32265 L
s
.8474 .32112 m
.84878 .32265 L
s
.19522 .30097 m
.19602 .2965 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84992 .28834 m
.85385 .28476 L
s
.85085 .26698 m
.85165 .28681 L
s
.85141 .26646 m
.85222 .2863 L
s
.19463 .30047 m
.19542 .296 L
s
.84878 .32265 m
.85002 .32168 L
s
.19337 .30197 m
.19522 .30097 L
s
.19337 .30197 m
.19463 .30047 L
s
.18908 .26137 m
.19258 .2651 L
s
.19224 .30096 m
.19337 .30197 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85002 .32168 m
.85172 .31773 L
s
.18887 .31601 m
.19103 .26351 L
s
.85172 .31773 m
.85267 .31174 L
s
.85457 .26328 m
.85785 .25953 L
s
.85293 .30375 m
.85354 .31876 L
s
.85267 .31174 m
.85293 .30375 L
s
.18836 .31551 m
.19053 .26298 L
s
.19073 .29695 m
.19224 .30096 L
s
.85267 .31174 m
.85354 .31876 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85604 .26168 m
.85748 .29668 L
s
.1899 .29092 m
.19073 .29695 L
s
.8565 .26115 m
.85796 .29617 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85601 .29821 m
.85796 .29617 L
s
.85733 .28112 m
.85811 .28812 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18295 .25126 m
.18305 .24889 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1869 .31401 m
.18887 .31601 L
s
.85811 .28812 m
.85921 .29211 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86431 .2704 m
.86501 .28697 L
s
.86399 .2732 m
.8646 .2875 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18515 .25901 m
.18572 .2651 L
s
.18572 .2651 m
.18582 .27316 L
s
.18561 .27819 m
.18582 .27316 L
s
.85921 .29211 m
.86017 .29359 L
s
.18477 .25846 m
.18532 .26456 L
s
.18532 .26456 m
.18541 .27263 L
s
.18488 .28521 m
.18561 .27819 L
s
.18414 .25486 m
.18515 .25901 L
s
.1852 .27766 m
.18541 .27263 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18157 .28396 m
.18184 .27758 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18448 .28468 m
.1852 .27766 L
s
.18414 .25486 m
.18477 .25846 L
s
0 0 0 r
.86408 .29545 m
.8646 .2875 L
s
.255 .412 .882 r
.86017 .29359 m
.86139 .29203 L
s
.18388 .2892 m
.18488 .28521 L
s
.18345 .25376 m
.18414 .25486 L
s
.18184 .23167 m
.18387 .23564 L
s
.86078 .2875 m
.86129 .2895 L
s
.86078 .2875 m
.86107 .28445 L
s
.1835 .28868 m
.18448 .28468 L
s
.86107 .28445 m
.86157 .28645 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1827 .25517 m
.18345 .25376 L
s
0 0 0 r
.86652 .29604 m
.86664 .29621 L
s
.255 .412 .882 r
.86139 .29203 m
.86167 .28898 L
s
.18266 .29015 m
.18388 .2892 L
s
.86157 .28645 m
.86167 .28898 L
s
0 0 0 r
.86654 .29593 m
.86664 .29621 L
s
.255 .412 .882 r
.18069 .28698 m
.18294 .23394 L
s
.18266 .29015 m
.1835 .28868 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18018 .31693 m
.18045 .31049 L
s
.5 Mabswid
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1804 .28645 m
.18265 .23338 L
s
.18187 .25911 m
.1827 .25517 L
s
.86304 .25998 m
.86313 .25438 L
s
.86304 .25998 m
.86325 .26503 L
s
.86313 .25438 m
.86389 .2502 L
s
.18196 .2891 m
.18266 .29015 L
s
.86325 .26503 m
.86377 .26954 L
s
.86335 .25943 m
.86343 .25383 L
s
.86335 .25943 m
.86356 .26448 L
s
.86343 .25383 m
.86389 .2502 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86356 .26448 m
.86407 .26899 L
s
.18141 .28551 m
.18196 .2891 L
s
.86377 .26954 m
.86475 .27044 L
s
.86389 .2502 m
.86466 .24852 L
s
.86407 .26899 m
.86475 .27044 L
s
.18101 .27936 m
.18141 .28551 L
s
.8642 .27967 m
.86431 .28221 L
s
.8642 .27967 m
.8645 .27914 L
s
.86431 .28221 m
.86472 .28422 L
s
.8645 .27914 m
.86461 .28167 L
s
.86466 .24852 m
.86523 .24994 L
s
.86475 .27044 m
.86632 .26972 L
s
.17958 .28485 m
.18069 .28698 L
s
.86472 .28422 m
.86539 .28569 L
s
.18036 .24764 m
.18059 .2482 L
s
0 0 0 r
.8691 .23689 m
.87026 .2333 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17982 .24906 m
.18036 .24764 L
s
.18003 .24962 m
.18036 .24764 L
s
.86523 .24994 m
.86587 .2539 L
s
.86539 .28569 m
.86641 .28356 L
s
.1796 .25413 m
.18003 .24962 L
s
0 0 0 r
.17573 .23947 m
.17584 .24786 L
s
.17559 .2593 m
.17584 .24786 L
s
.86958 .23561 m
.87178 .28658 L
s
.255 .412 .882 r
.1794 .25358 m
.17982 .24906 L
s
0 0 0 r
.17528 .26656 m
.17559 .2593 L
s
.17535 .23412 m
.17573 .23947 L
s
.17554 .2389 m
.17562 .24729 L
s
.17537 .25874 m
.17562 .24729 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17884 .27195 m
.1796 .25413 L
s
0 0 0 r
.17505 .26601 m
.17537 .25874 L
s
.17535 .23412 m
.17554 .2389 L
s
.255 .412 .882 r
.86585 .24826 m
.86587 .2539 L
s
.86587 .2539 m
.86685 .27683 L
s
0 0 0 r
.17458 .27694 m
.17528 .26656 L
s
.255 .412 .882 r
.86585 .24826 m
.86611 .24459 L
s
.17925 .24737 m
.1794 .25358 L
s
.17842 .27652 m
.1794 .25358 L
s
.86604 .24769 m
.86607 .25334 L
s
.86607 .25334 m
.86683 .27118 L
s
0 0 0 r
.17437 .27639 m
.17505 .26601 L
s
.255 .412 .882 r
.86604 .24769 m
.86611 .24459 L
s
0 0 0 r
.17535 .23412 m
.17504 .23296 L
s
.255 .412 .882 r
.86632 .26972 m
.86663 .27172 L
s
.86641 .28356 m
.86675 .27993 L
s
.17902 .2437 m
.17925 .24737 L
s
.86611 .24459 m
.86627 .24402 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17842 .27652 m
.17884 .27195 L
s
0 0 0 r
.17385 .28315 m
.17458 .27694 L
s
.255 .412 .882 r
.86675 .27993 m
.86685 .27683 L
s
0 0 0 r
.17504 .23296 m
.17461 .23544 L
s
.17504 .23296 m
.17449 .23486 L
s
.255 .412 .882 r
.1786 .242 m
.17902 .2437 L
s
.17856 .26831 m
.17864 .27141 L
s
.86683 .27118 m
.86685 .27683 L
s
0 0 0 r
.17365 .28261 m
.17437 .27639 L
s
.255 .412 .882 r
.17773 .26245 m
.17856 .26831 L
s
.17812 .27854 m
.17842 .27652 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17765 .28002 m
.17812 .27854 L
s
0 0 0 r
.17461 .23544 m
.17407 .24157 L
s
.17314 .28519 m
.17385 .28315 L
s
.255 .412 .882 r
.17826 .24342 m
.1786 .242 L
s
.17816 .24285 m
.1786 .242 L
s
0 0 0 r
.87129 .22688 m
.87078 .23097 L
s
.17449 .23486 m
.17397 .24099 L
s
.17314 .28519 m
.17365 .28261 L
s
.87248 .28441 m
.87178 .28658 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86977 .23503 m
.87197 .28604 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86582 .22511 m
.86654 .22104 L
s
.17707 .27785 m
.17765 .28002 L
s
.17794 .24796 m
.17826 .24342 L
s
0 0 0 r
.17407 .24157 m
.17349 .25196 L
s
.255 .412 .882 r
.1776 .25877 m
.17773 .26245 L
s
.17751 .25821 m
.17773 .26245 L
s
.17786 .2474 m
.17816 .24285 L
s
0 0 0 r
.17282 .2841 m
.17314 .28519 L
s
.255 .412 .882 r
.86735 .24204 m
.86739 .24829 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17397 .24099 m
.17341 .25139 L
s
.255 .412 .882 r
.17773 .25309 m
.17794 .24796 L
s
0 0 0 r
.87274 .30863 m
.87309 .31179 L
s
.87274 .30863 m
.87277 .30442 L
s
.255 .412 .882 r
.86735 .24204 m
.86737 .23834 L
s
0 0 0 r
.87277 .30442 m
.87311 .30757 L
s
.255 .412 .882 r
.1776 .25877 m
.17773 .25309 L
s
.17764 .25252 m
.17786 .2474 L
s
0 0 0 r
.17271 .27933 m
.17282 .2841 L
s
.17259 .27878 m
.17282 .2841 L
s
.17349 .25196 m
.17318 .25929 L
s
.255 .412 .882 r
.17694 .27418 m
.17707 .27785 L
s
.17751 .25821 m
.17764 .25252 L
s
0 0 0 r
.87309 .31179 m
.87311 .30757 L
s
.255 .412 .882 r
.17706 .26849 m
.17716 .26904 L
s
.17705 .27161 m
.17716 .26904 L
s
0 0 0 r
.17341 .25139 m
.17309 .25873 L
s
.17318 .25929 m
.1728 .27087 L
s
.1728 .27087 m
.17271 .27933 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86827 .26881 m
.86867 .27286 L
s
0 0 0 r
.87113 .22863 m
.87289 .26896 L
s
.255 .412 .882 r
.86811 .2787 m
.8686 .27653 L
s
0 0 0 r
.87106 .22922 m
.87281 .26952 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86629 .22279 m
.8686 .27653 L
s
.86737 .23834 m
.86747 .23719 L
s
.86619 .22337 m
.86849 .27707 L
s
.17694 .27418 m
.17695 .27106 L
s
.17695 .27106 m
.17706 .26849 L
s
0 0 0 r
.17309 .25873 m
.1727 .27031 L
s
.1727 .27031 m
.17259 .27878 L
s
.17408 .22654 m
.17414 .22242 L
s
.255 .412 .882 r
.86747 .23719 m
.86763 .23862 L
s
.86747 .23719 m
.86764 .23805 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86867 .27286 m
.86892 .27434 L
s
0 0 0 r
.87321 .27634 m
.87281 .26952 L
s
.255 .412 .882 r
.86763 .23862 m
.86786 .24262 L
s
0 0 0 r
.1718 .27641 m
.17404 .22478 L
s
.87327 .27579 m
.87289 .26896 L
s
.87102 .2204 m
.87134 .22453 L
s
.255 .412 .882 r
.86764 .23805 m
.86785 .24205 L
s
0 0 0 r
.17181 .27586 m
.17405 .22419 L
s
.87353 .27838 m
.87321 .27634 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86892 .27434 m
.86902 .27325 L
s
0 0 0 r
.87353 .27838 m
.87327 .27579 L
s
.255 .412 .882 r
.86786 .24262 m
.86818 .24979 L
s
.86896 .26956 m
.86902 .27325 L
s
.86897 .26901 m
.86902 .27325 L
s
.86785 .24205 m
.86816 .24923 L
s
.86875 .26328 m
.86896 .26956 L
s
.86818 .24979 m
.86841 .25496 L
s
0 0 0 r
.87358 .27728 m
.87353 .27838 L
s
.255 .412 .882 r
.17653 .26666 m
.17664 .26352 L
s
.17642 .26925 m
.17653 .26666 L
s
.1763 .27129 m
.17642 .26925 L
s
0 0 0 r
.17184 .27806 m
.17181 .27586 L
s
.255 .412 .882 r
.17653 .26555 m
.17664 .26352 L
s
.86841 .25496 m
.86875 .26328 L
s
.86874 .26272 m
.86897 .26901 L
s
.17799 .23227 m
.17864 .22823 L
s
.86816 .24923 m
.86839 .2544 L
s
.17653 .26555 m
.17641 .2687 L
s
.86839 .2544 m
.86874 .26272 L
s
.17635 .26964 m
.1763 .27129 L
s
0 0 0 r
.87341 .27191 m
.87358 .27728 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87122 .22217 m
.87461 .3001 L
s
.87127 .22276 m
.87466 .30064 L
s
.17229 .26473 m
.17201 .27103 L
s
.17442 .22006 m
.17532 .21591 L
s
.255 .412 .882 r
.17664 .26688 m
.1782 .23054 L
s
.86624 .22625 m
.86714 .2303 L
s
0 0 0 r
.87303 .26337 m
.87341 .27191 L
s
.255 .412 .882 r
.17655 .26593 m
.17635 .26964 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17201 .27103 m
.17201 .27309 L
s
.17297 .2591 m
.17474 .21828 L
s
.255 .412 .882 r
.17655 .26593 m
.1769 .25962 L
s
0 0 0 r
.17309 .25854 m
.17487 .21769 L
s
.255 .412 .882 r
.1769 .25962 m
.17731 .25127 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17201 .27309 m
.17216 .27197 L
s
.255 .412 .882 r
.17664 .26688 m
.17707 .26467 L
s
0 0 0 r
.87016 .21937 m
.8708 .22796 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17674 .26633 m
.17758 .24661 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86943 .21388 m
.87016 .21937 L
s
.87441 .29849 m
.87466 .30064 L
s
.17216 .27197 m
.17252 .26713 L
s
.17216 .27197 m
.17264 .26657 L
s
.17252 .26713 m
.17297 .2591 L
s
.255 .412 .882 r
.86785 .26071 m
.86792 .25659 L
s
.86904 .28278 m
.86949 .28494 L
s
0 0 0 r
.869 .2127 m
.86943 .21388 L
s
.17264 .26657 m
.17309 .25854 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86729 .24182 m
.86904 .28278 L
s
.86741 .24235 m
.86917 .28332 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17608 .21354 m
.17784 .20939 L
s
.87193 .254 m
.87209 .25773 L
s
.87161 .2497 m
.87193 .254 L
s
.87161 .25286 m
.87161 .2497 L
s
.87209 .25773 m
.8721 .26409 L
s
.86868 .21523 m
.869 .2127 L
s
.86842 .21464 m
.869 .2127 L
s
.255 .412 .882 r
.86745 .26166 m
.86785 .26071 L
s
0 0 0 r
.87161 .25286 m
.87194 .25717 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1745 .26418 m
.17676 .21176 L
s
.17475 .26362 m
.17701 .21117 L
s
.8721 .26409 m
.87189 .26673 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8682 .22093 m
.86842 .21464 L
s
.86848 .22151 m
.86868 .21523 L
s
.87126 .26505 m
.87189 .26673 L
s
.86848 .22151 m
.86868 .23216 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8682 .22093 m
.86839 .23158 L
s
.17381 .26585 m
.17475 .26362 L
s
.87062 .26017 m
.87126 .26505 L
s
.87037 .25961 m
.87126 .26505 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86839 .23158 m
.86872 .23909 L
s
.86868 .23216 m
.86901 .23967 L
s
.86901 .23967 m
.86977 .25152 L
s
.86977 .25152 m
.87062 .26017 L
s
.86872 .23909 m
.86949 .25095 L
s
.86949 .25095 m
.87037 .25961 L
s
.17328 .28739 m
.17368 .28306 L
s
.17328 .28739 m
.17335 .29064 L
s
.17368 .28306 m
.17377 .28631 L
s
.18036 .2084 m
.18171 .20287 L
s
.17966 .21649 m
.18036 .2084 L
s
.17788 .25804 m
.17966 .21649 L
s
.17335 .29064 m
.17377 .28631 L
s
.18075 .20781 m
.18171 .20287 L
s
.18004 .21591 m
.18075 .20781 L
s
.17826 .25749 m
.18004 .21591 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18171 .20287 m
.18257 .20169 L
s
.86027 .19848 m
.86349 .20262 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17682 .25972 m
.17826 .25749 L
s
.18257 .20169 m
.18377 .20369 L
s
.86723 .24699 m
.86775 .25134 L
s
.86775 .25134 m
.86791 .25513 L
s
.86702 .25022 m
.86723 .24699 L
s
.86772 .25836 m
.86791 .25513 L
s
.86218 .20084 m
.86444 .25392 L
s
.86702 .25022 m
.86755 .25457 L
s
.86657 .25669 m
.86772 .25836 L
s
.86172 .20025 m
.86398 .25336 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18377 .20369 m
.18442 .21008 L
s
.255 .412 .882 r
.18518 .24907 m
.18644 .24751 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1849 .19874 m
.18698 .19638 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85682 .21214 m
.85707 .21351 L
s
0 0 0 r
.86559 .25177 m
.86657 .25669 L
s
.255 .412 .882 r
.1853 .2464 m
.18652 .23224 L
s
.85632 .21156 m
.85718 .21616 L
s
0 0 0 r
.86347 .23108 m
.8644 .24305 L
s
.8644 .24305 m
.86559 .25177 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8559 .19379 m
.85925 .19731 L
s
.255 .412 .882 r
.85815 .24405 m
.85831 .24315 L
s
.85765 .2435 m
.85819 .24048 L
s
0 0 0 r
.86252 .2517 m
.86444 .25392 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18316 .25138 m
.1854 .19815 L
s
.18265 .25193 m
.1849 .19874 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18121 .2536 m
.18316 .25138 L
s
.18983 .19345 m
.19012 .20048 L
s
.18919 .20867 m
.18983 .19345 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18919 .20867 m
.19012 .20048 L
s
.19012 .20048 m
.19089 .19609 L
s
.19089 .19609 m
.19232 .19112 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19232 .19112 m
.19499 .1888 L
s
.84796 .18682 m
.85214 .19029 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85174 .21209 m
.85744 .2172 L
s
.18824 .23161 m
.189 .22721 L
s
.18792 .23928 m
.18824 .23161 L
s
.189 .22721 m
.19041 .22226 L
s
.18808 .23544 m
.18884 .23105 L
s
.18884 .23105 m
.19025 .22609 L
s
.18792 .23928 m
.18836 .24257 L
s
.19499 .1888 m
.19624 .19147 L
s
.19041 .22226 m
.19405 .21177 L
s
.19025 .22609 m
.19389 .21561 L
s
.18836 .24257 m
.18945 .24532 L
s
.19624 .19147 m
.1968 .19473 L
s
.19405 .21177 m
.19561 .2068 L
s
.19634 .20624 m
.1968 .19473 L
s
.18945 .24532 m
.19209 .24314 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8494 .18798 m
.85742 .27271 L
s
.85694 .26109 m
.85763 .19555 L
s
.85742 .27271 m
.85818 .19613 L
s
.19389 .21561 m
.19546 .21064 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19561 .2068 m
.19649 .2024 L
s
.19546 .21064 m
.19634 .20624 L
s
.255 .412 .882 r
.20577 .19444 m
.20657 .19388 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19209 .24314 m
.19364 .23818 L
s
.19451 .23377 m
.19555 .22549 L
s
.19492 .24097 m
.19555 .22549 L
s
.19364 .23818 m
.19451 .23377 L
s
.19451 .23377 m
.19492 .24097 L
s
.20233 .1869 m
.2033 .18249 L
s
.20233 .1869 m
.20299 .19019 L
s
.2033 .18249 m
.20397 .18577 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20299 .19019 m
.20397 .18577 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19953 .25671 m
.20222 .20949 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20034 .25619 m
.20128 .23277 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19953 .25671 m
.20003 .26403 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20117 .25567 m
.20222 .20949 L
s
.5 Mabswid
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20003 .26403 m
.20117 .25567 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23381 .20239 m
.23383 .2018 L
s
.5 Mabswid
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72154 .1752 m
.72304 .1751 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68399 .13105 m
.68599 .13542 L
s
.68214 .13481 m
.68399 .13105 L
s
.68415 .13917 m
.68599 .13542 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68214 .13481 m
.68415 .13917 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36857 .16751 m
.36991 .16812 L
s
0 0 0 r
.37341 .12923 m
.40561 .12518 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66243 .12791 m
.66648 .13252 L
s
.66648 .13252 m
.66853 .13687 L
s
.6544 .12688 m
.66243 .12791 L
s
.66853 .13687 m
.66876 .14912 L
s
.255 .412 .882 r
.37279 .16697 m
.37379 .16757 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68363 .20863 m
.68457 .15956 L
s
.68457 .15956 m
.68751 .20919 L
s
.66678 .14885 m
.66868 .14503 L
s
.65042 .13047 m
.6544 .12688 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36991 .16812 m
.37066 .16858 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64628 .12591 m
.64654 .14226 L
s
.64628 .12591 m
.64845 .13431 L
s
.64845 .13431 m
.65042 .13047 L
s
.66286 .15241 m
.66678 .14885 L
s
.66685 .15294 m
.66876 .14912 L
s
.66293 .15651 m
.66685 .15294 L
s
.40356 .12541 m
.40525 .14975 L
s
.64654 .14226 m
.64845 .13431 L
s
.68507 .18416 m
.68557 .20891 L
s
.65292 .15938 m
.66286 .15241 L
s
.40525 .14975 m
.40561 .12518 L
s
.62771 .12395 m
.63601 .12478 L
s
.65298 .16349 m
.66293 .15651 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6673 .17758 m
.66914 .16961 L
s
.66914 .16961 m
.66944 .18609 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39236 .18822 m
.3929 .15523 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38051 .17316 m
.39263 .17169 L
s
.62358 .12765 m
.62787 .13623 L
s
.61722 .123 m
.62358 .12765 L
s
.66537 .18145 m
.6673 .17758 L
s
.6673 .17758 m
.66944 .18609 L
s
.64891 .16303 m
.65292 .15938 L
s
.613 .12265 m
.61722 .123 L
s
.68574 .2172 m
.68751 .20919 L
s
.42638 .12724 m
.43276 .12262 L
s
.42417 .13563 m
.42638 .12724 L
s
.60881 .12641 m
.613 .12265 L
s
.60668 .12625 m
.613 .12265 L
s
.42849 .12706 m
.43276 .12262 L
s
.43276 .12262 m
.437 .12228 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37777 .21479 m
.37933 .1284 L
s
.37977 .21454 m
.38132 .12813 L
s
.42628 .13544 m
.42849 .12706 L
s
.437 .12228 m
.44335 .12591 L
s
.68363 .20863 m
.68574 .2172 L
s
.42361 .18101 m
.42417 .13563 L
s
.60677 .13445 m
.60881 .12641 L
s
.60463 .1343 m
.60668 .12625 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64692 .16692 m
.64891 .16303 L
s
.66143 .18507 m
.66537 .18145 L
s
.64897 .16714 m
.65298 .16349 L
s
.62771 .12395 m
.62847 .18159 L
s
.62979 .12415 m
.63057 .18178 L
s
.64699 .17104 m
.64897 .16714 L
s
.44767 .12151 m
.45626 .12097 L
s
.64692 .16692 m
.64705 .17517 L
s
.44335 .12591 m
.44755 .13383 L
s
.65332 .18412 m
.66143 .18507 L
s
.57653 .1203 m
.58951 .121 L
s
.64705 .17517 m
.64917 .17953 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64917 .17953 m
.65332 .18412 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55473 .11948 m
.56783 .11992 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42573 .18084 m
.42628 .13544 L
s
.255 .412 .882 r
.4325 .16432 m
.43254 .16058 L
s
.43042 .16315 m
.43045 .1607 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44712 .1793 m
.44767 .12151 L
s
.44928 .17917 m
.44981 .12137 L
s
.47573 .1241 m
.48012 .11982 L
s
.48012 .11982 m
.48448 .11967 L
s
.47356 .12419 m
.48012 .11982 L
s
.37178 .21554 m
.40433 .21185 L
s
.48448 .11967 m
.48884 .12364 L
s
.46915 .13261 m
.47356 .12419 L
s
.47133 .13251 m
.47573 .1241 L
s
.49323 .11941 m
.502 .11922 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48884 .12364 m
.49319 .13175 L
s
.53058 .11906 m
.53499 .12321 L
s
.53058 .11906 m
.53719 .12323 L
s
.52619 .11904 m
.53058 .11906 L
s
.52179 .12314 m
.52619 .11904 L
s
.51959 .12315 m
.52619 .11904 L
s
.46689 .14508 m
.46915 .13261 L
s
.46907 .14498 m
.47133 .13251 L
s
.255 .412 .882 r
.54466 .15731 m
.54467 .16088 L
s
0 0 0 r
.53719 .12323 m
.5416 .13153 L
s
.53499 .12321 m
.5394 .13149 L
s
.51518 .1314 m
.51959 .12315 L
s
.51738 .13139 m
.52179 .12314 L
s
.40225 .21206 m
.4047 .1869 L
s
.40433 .21185 m
.4047 .1869 L
s
.5416 .13153 m
.54383 .14395 L
s
.5394 .13149 m
.54163 .14391 L
s
.62215 .18105 m
.63057 .18178 L
s
.51296 .1438 m
.51518 .1314 L
s
.51517 .14378 m
.51738 .13139 L
s
.46683 .15334 m
.46689 .14508 L
s
.255 .412 .882 r
.54901 .15807 m
.55096 .15769 L
s
0 0 0 r
.46901 .15324 m
.46907 .14498 L
s
.41728 .18156 m
.42573 .18084 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54684 .16092 m
.54901 .15807 L
s
0 0 0 r
.46683 .15334 m
.46893 .16567 L
s
.46901 .15324 m
.47111 .16558 L
s
.255 .412 .882 r
.56641 .17018 m
.56759 .16862 L
s
0 0 0 r
.54383 .14395 m
.54386 .15222 L
s
.54163 .14391 m
.54165 .15218 L
s
.51295 .15207 m
.51296 .1438 L
s
.51516 .15206 m
.51517 .14378 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60463 .1343 m
.6051 .17975 L
s
.55937 .17751 m
.58303 .12063 L
s
.56157 .17758 m
.58519 .12075 L
s
.60677 .13445 m
.60725 .1799 L
s
.5591 .11961 m
.58565 .17858 L
s
.59865 .17932 m
.60725 .1799 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54168 .16463 m
.54386 .15222 L
s
.44066 .17972 m
.44928 .17917 L
s
.53947 .16459 m
.54165 .15218 L
s
.51295 .15207 m
.51515 .1645 L
s
.51516 .15206 m
.51736 .16449 L
s
.46893 .16567 m
.47325 .1738 L
s
.47111 .16558 m
.47544 .17371 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57693 .17816 m
.58999 .17881 L
s
.48862 .17327 m
.49306 .16484 L
s
.53728 .17288 m
.54168 .16463 L
s
.47325 .1738 m
.4798 .17771 L
s
.53506 .17286 m
.53947 .16459 L
s
.47544 .17371 m
.4798 .17771 L
s
.51515 .1645 m
.51957 .1728 L
s
.51736 .16449 m
.52178 .1728 L
s
.4842 .17756 m
.48862 .17327 L
s
.55496 .17739 m
.56817 .1778 L
s
.4798 .17771 m
.4842 .17756 L
s
.53064 .17699 m
.53728 .17288 L
s
.53064 .17699 m
.53506 .17286 L
s
.51957 .1728 m
.52621 .17697 L
s
.52178 .1728 m
.52621 .17697 L
s
.52621 .17697 m
.53064 .17699 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49291 .20659 m
.49323 .11941 L
s
.49512 .20654 m
.49542 .11936 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48627 .20677 m
.49512 .20654 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ001@00
000;0?nV40<000002@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2]
[Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@080?nV4@040000003oYQ40
0000000000P0ojHA0`2][Jd3000000@0[Jf]0P00000<0:f][@8000000`2][Jd2000000T0[Jf]2000
00030:f][@P000002P3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H3
0:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ400`0000020?nV4@80[Jf]0`00000:0:f][@030?nV4@000000
000000<0ojHA00@000000:f][@3oYQ00ojH@0P00000;0?nV408000001@3oYQ03000000D0ojH@00D0
[Jf]0?nU403oYA00ojD@0000000;0?nU408000003@2][Jd300000080[Jf]5`3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V
0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0<0?nV4@@000001P3oYQ450:f][@8000000`2][Jd200000080ojHA0P00
000;0?nV4@8000001@3oYQ400`000000ojH@0?nV4002000000X0ojH@0P0000070?nV408000001@3o
YQ000`2][Jd0ojD@0?nU40020?nU40030000003oYA00ojD@00L0ojD@0P00000<0?nU4080000000D0
[Jf]0?nS403oXa0000000?nS40030:f][@D0000000<0[Jf]0?nS403oXa00303oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V
0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@040?nV4@P000000P2][Jd2000000H0[Jf]0`3oYQ42000000L0ojHA00@0
00000?nV4@00000000002P3oYQ42000000H0ojHA00<0[Jf]0000003oYQ000P00000:0?nV40800000
1`3oYQ000`000000ojH@000000040?nV40030:f][@3oYA00ojD@0080ojD@00<000000?nU403oYA00
1`3oYA02000000/0ojD@0P0000000`3oYA00[Jf]0?nS40020?nS408000000P3oXa02000000@0oj<@
0`2][Jd010000000[Jf]0:f][@2][Jd2000000030:f][@3oXa00oj<@0080oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40
oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@000000100000080:f][@80ojHA0P0000090?nV4@8000001`3oYQ4010000000ojHA
00000000000:0?nV4@8000001P3oYQ400`2][Jd000000?nV4002000000T0ojH@0P0000090?nV4080
0000103oYQ000`2][Jd0ojD@0?nU40030?nU40030000003oYA00ojD@00D0ojD@0P00000<0?nU4080
000000<0ojD@0:f][@3oXa00103oXa0010000000oj<@0000000000070?nS40040000003oXa00oj<@
00000080oj<@0`0000050:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0E0?nV4@L0[Jf]0P00000:0?nV4@8000002@3oYQ400`000000[Jf]0?nV4@070?nV
4@<000002@3oYQ42000000L0ojHA00<0[Jf]0?nV400000000P0000090?nV408000002@3oYQ000`00
0000ojH@000000030?nV40030:f][@3oYA00ojD@00<0ojD@00<000000?nU403oYA001@3oYA020000
00/0ojD@0P0000020?nU40030:f][@3oXa00oj<@00<0oj<@00@000000?nS4000000000001`3oXa00
0`000000oj<@000000060?nS40030000003oXa00[Jf]0080o:0@1@2][Jd00`000000o:0@0?bP400@
0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool0
07<0/>3V0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ450:f]
[@80ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000000X0ojHA0P0000080?nV4@80000000<0[Jf]0?nV
4@3oYQ401P3oYQ43000000T0ojHA0P0000070?nV4@030:f][@3oYQ00ojH@008000002@3oYQ020000
00X0ojH@0P0000030?nV40030:f][@3oYA00ojD@00@0ojD@00<000000?nU403oYA00103oYA020000
00/0ojD@0P0000020?nU40030:f][@3oXa00oj<@00@0oj<@0`0000070?nS40800000203oXa000`00
0000[Jf]0?bP40050?bP408000001@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF
3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0
[Jf]1`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002P3oYQ42000000P0ojHA0P0000000`2][Jd0
ojHA0?nV4@070?nV4@8000002@3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ000P0000080?nV4003
0000003oYQ00000000X0ojH@0P0000030?nV40030:f][@3oYA00ojD@00@0ojD@00<000000?nU403o
YA000`3oYA02000000`0ojD@0P0000020?nU40030:f][@3oXa00oj<@00@0oj<@0`0000070?nS4080
0000203oXa000`000000[Jf]0?bP40050?bP40030000003lX100000000@0o:0@1@2][Jd80?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80
[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A
0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0ojHA1P2][Jd<0?nV4@030:f][@3oYQ40ojHA0080ojHA
0P00000:0?nV4@800000203oYQ42000000030:f][@3oYQ40ojHA00L0ojHA0P0000090?nV4@800000
1`3oYQ400`2][Jd0ojH@0?nV4002000000P0ojH@00<000000?nV400000002P3oYQ02000000<0ojH@
00<0[Jf]0?nU403oYA001@3oYA000`000000ojD@0?nU40020?nU40800000303oYA0200000080ojD@
00<0[Jf]0?nS403oXa001@3oXa02000000L0oj<@0P0000090?nS40030000003lX100o:0@00@0o:0@
0P00000:0?bP40H0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@2]
[JdB0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000;0?nV4@030000003oYQ40ojHA00H0ojHA0P00
00000`2][Jd0ojHA0?nV4@070?nV4@800000203oYQ42000000P0ojHA00<0[Jf]0?nV403oYQ000P00
00080?nV408000002`3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA001@3oYA0010000000ojD@0?nU
403oYA02000000d0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000070?nS40030000
003oXa00oj<@00P0oj<@00<000000?bP403lX1001@3lX1000`000000o:0@0?bP400>0?bP40@0[Jf]
5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo
001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A102]
[JdG0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000;0?nV4@030000003oYQ40ojHA00H0ojHA0P00
00000`2][Jd0ojHA0?nV4@070?nV4@800000203oYQ42000000P0ojHA00<0[Jf]0?nV403oYQ000P00
00080?nV40800000303oYQ0200000080ojH@00<0[Jf]0?nU403oYA001P3oYA000`000000ojD@0?nU
4002000000d0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000070?nS40030000003o
Xa00oj<@00P0oj<@00<000000?bP403lX100603lX1000`2][Jd0mY`?0:f][@030:f][A40mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H2
0:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A
0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002`3oYQ400`000000ojHA0?nV4@06
0?nV4@8000002P3oYQ42000000P0ojHA0P0000080?nV4@030:f][@3oYQ00ojH@008000001`3oYQ00
0`000000ojH@0000000<0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40060?nU40030000003oYA00
ojD@008000003@3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa02000000L0oj<@00<00000
0?nS403oXa00203oXa000`000000o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool0
06P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f]
[@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002`3oYQ400`00
0000ojHA0?nV4@060?nV4@8000002P3oYQ42000000P0ojHA0P0000080?nV4@030:f][@3oYQ00ojH@
008000001`3oYQ000`000000ojH@0000000<0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40070?nU
40<000003P3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa0200000180oj<@00<000000?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1440:f][@T0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002`3oYQ400`000000
ojHA0?nV4@060?nV4@8000002P3oYQ42000000P0ojHA0P0000080?nV4@030:f][@3oYQ00ojH@0080
00001`3oYQ000`000000ojH@0000000<0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40070?nU40<0
00003P3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa0200000140oj<@0P00000J0?bP4003
0:f][@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@020?nV4@8000002`3oYQ400`000000ojHA0?nV4@060?nV4@8000002P3oYQ42000000L0ojHA
00<000000?nV4@000000203oYQ400`2][Jd0ojH@0?nV4002000000L0ojH@00<000000?nV40000000
303oYQ0200000080ojH@00<0[Jf]0?nU403oYA001`3oYA02000000l0ojD@0P0000020?nU40030:f]
[@3oXa00oj<@00D0oj<@0P00000A0?nS4080000000<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA0080ojHA0P00000;0?nV4@030000003oYQ40ojHA00H0ojHA0P00000:0?nV4@8000001`3o
YQ400`000000ojHA000000080?nV4@030:f][@3oYQ00ojH@008000001`3oYQ000`000000ojH@0000
000<0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40070?nU408000003`3oYA0200000080ojD@00<0
[Jf]0?nS403oXa001@3oXa0200000100oj<@0P0000000`3oXa00[Jf]0?bP400H0?bP40030:f][@3f
W0l0mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]
C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00h0o:0@
0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000001@0ojHA
0P00000:0?nV4@8000001`3oYQ400`000000ojHA000000080?nV4@030:f][@3oYQ00ojH@00800000
1`3oYQ000`000000ojH@0000000<0?nV408000000P3oYQ000`2][Jd0ojD@0?nU40070?nU40<00000
3P3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa02000000l0oj<@00D000000?nS40000000
oj<@0:f][@0I0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP05
0:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f]
[@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000050?nV
4@030000003oYQ40ojHA00`0ojHA0P00000:0?nV4@8000001`3oYQ400`000000ojHA000000080?nV
4@030:f][@3oYQ00ojH@008000001`3oYQ000`000000ojH@0000000<0?nV408000000P3oYQ000`2]
[Jd0ojD@0?nU40060?nU4080000000<0ojD@0000003oYA003@3oYA0200000080ojD@00<0[Jf]0?nS
403oXa001@3oXa02000000d0oj<@0P0000001@3oXa0000000?nS403oXa00[Jf]01T0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>
0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2]
[Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ420000
00D0ojHA00<000000?nV4@3oYQ40303oYQ42000000X0ojHA0P0000080?nV4@80000000<0ojHA0:f]
[@2][Jd0202][Jd2000000P0[Jf]0P00000<0:f][@8000002P2][Jd00`3oYA000000000000020?nU
40030000003oYA00ojD@00/0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P00000;0?nS
408000000P3oXa001@000000oj<@0?nS403oXa00[Jf]01T0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000050?nV
4@030000003oYQ40ojHA00`0ojHA0P0000070?nV4@<0[Jf]0P0000080:f][@80000000<0[Jf]0?nV
4@3oYQ401@3oYQ400`2][Jd0ojH@0?nV4002000000P0ojH@0P00000;0?nV408000000`3oYQ000`2]
[Jd0ojD@0?nU40050?nU40030:f][@00000000000080[Jf]00<000000:f][@2][Jd0202][Jd30?nU
408000000P3oYA000`2][Jd0oj<@0?nS40050?nS408000002P3oXa000`000000oj<@0?nS40020000
00@0oj<@00<0[Jf]0?bP403lX100103lX1000`000000o:0@0?bP400@0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3C
Q`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@80
00001@3oYQ400`000000ojHA0?nV4@090?nV4@<0[Jf]00<000000:f][@2][Jd01P2][Jd30?nV4@80
0000203oYQ400`000000ojHA000000070?nV4@030:f][@3oYQ00ojH@00800000203oYQ000`000000
ojH@0000000:0?nV408000000`3oYQ000`2][Jd0ojD@0?nU40050?nU40800000103oYA000`000000
ojD@0?nU40070?nU40<0[Jf]0P0000070:f][@<0oj<@0P0000090?nS40040000003oXa0000000000
00H0oj<@00<0[Jf]0?bP403lX100103lX1000`000000o:0@0?bP400@0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3C
Q`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ420000
00D0ojHA00<000000?nV4@3oYQ402@2][Jd30?nV4@8000002P3oYQ42000000P0ojHA00<000000?nV
4@0000001`3oYQ401@2][Jd0ojH@0000003oYQ00000000T0ojH@0P00000:0?nV408000000`3oYQ00
0`2][Jd0ojD@0?nU40050?nU40800000103oYA000`000000ojD@0?nU400:0?nU408000000P3oYA00
0`2][Jd0oj<@0?nS40020?nS40<0[Jf]0P0000050:f][@<0oj<@00<000000?nS40000000203oXa00
0`2][Jd0o:0@0?bP40040?bP40030000003lX100o:0@0100o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000050:f][@030000002][Jd0
[Jf]00`0ojHA0P0000020?nV4@03045Yh@3oYQ40ojHA00D0ojHA0P0000090?nV4@8000001`3oYQ40
0`2][Jd0ojH@00000002000000T0ojH@0P00000:0?nV408000000`3oYQ000`2][Jd0ojD@0?nU4004
0?nU408000001P3oYA000`000000ojD@0?nU40090?nU408000000P3oYA000`2][Jd0oj<@0?nS4005
0?nS408000001@3oXa020:f][@030000002][Jd0000000D0[Jf]103oXa000`2][Jd0o:0@0?bP4004
0?bP40030000003lX100o:0@0100o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P80[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f]
[@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0F0?nV4@L0[Jf]0P0000050?nV4@030000003oYQ40ojHA00`0ojHA0P00000:0?nV
4@8000002@3oYQ42000000L0ojHA00D0[Jf]0?nV40000000ojH@000000090?nV408000002@3oYQ02
000000@0ojH@00<0[Jf]0?nU403oYA00103oYA02000000H0ojD@00<000000?nU403oYA002@3oYA02
00000080ojD@00<0[Jf]0?nS403oXa001@3oXa02000000L0oj<@0P0000060?nS40P0[Jf]0`3lX100
0`000000o:0@0?bP400@0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh3
0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>7
3P030:f][@3_V100kiP@00T0kiP@0`2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40403oYQ460:f][@80ojHA0P11JN430?nV4@8000001@3oYQ400`000000ojHA0?nV4@0<0?nV
4@8000002P3oYQ42000000T0ojHA00<000000?nV4@0000001P3oYQ401@2][Jd000000000003oYQ00
000000X0ojH@0P0000070?nV40030000003oYQ00000000@0ojH@00<0[Jf]0?nU403oYA00103oYA02
00000003045Yh@3oYA00ojD@00@0ojD@00<000000?nU403oYA00203oYA0200000080ojD@00<0[Jf]
0?nS403oXa001@3oXa02000000L0oj<@00<000000?nS403oXa00203oXa000`000000[Jf]0?bP4002
0?bP40<0[Jf]00<000000:f][@2][Jd0403lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]
08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@
00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000001@3oYQ400`00
0000ojHA0?nV4@0<0?nV4@8000002P3oYQ42000000X0ojHA0P0000060?nV4@050:f][@0000000000
0?nV400000002P3oYQ02000000L0ojH@0P0000050?nV40030:f][@3oYA00ojD@00<0ojD@0P000008
0?nU40030000003oYA00ojD@00P0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P000007
0?nS40030000003oXa00oj<@00P0oj<@00<000000:f][@3lX1001@3lX1000`000000o:0@0?bP4007
0:f][@T0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0
fhX=0080fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H1
0?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd4
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@06
0?nV4@D0[Jf]3@3oYQ40102][Jd0ojHA0?nV4@3oYQ49000000h0ojHA0P00000:0?nV4@8000002P3o
YQ400`000000ojHA000000050?nV4@050000003oYQ0000000?nV400000002`3oYQ02000000D0ojH@
00<000000?nV400000001@3oYQ000`2][Jd0ojD@0?nU40030?nU408000002@3oYA000`000000ojD@
0?nU40070?nU408000000P3oYA000`2][Jd0oj<@0?nS40050?nS408000001`3oXa000`000000oj<@
0?nS40070?nS4080000000<0[Jf]0?bP403lX100103lX1000`000000o:0@0?bP40070?bP40H0[Jf]
0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0
103KRPd00`2][Jd0fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0
[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0
kiP@00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ401P2][JdB0?nV4@040:f][@3oYQ40ojHA0?nV4@8000001@3oYQ400`00
0000ojHA0?nV4@0=0?nV4@8000002P3oYQ42000000/0ojHA0P0000040?nV4@060000002][Jd0ojH@
0000003oYQ000000303oYQ02000000<0ojH@0`0000060?nV40030:f][@3oYA00ojD@0080ojD@0P00
000:0?nU40030000003oYA00ojD@00L0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P00
00070?nS40030000003oXa00oj<@00L0oj<@0P0000000`2][Jd0o:0@0?bP40040?bP40030000003l
X100o:0@00d0o:0@1@2][JdE0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01@3K
RPd20:f][@@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V
0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080kiP@
0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404P3oY1440:f][AP0ojHA
00@0[Jf]0?nV4@3oYQ40ojHA0P0000050?nV4@030000003oYQ40ojHA00d0ojHA0P00000:0?nV4@80
0000303oYQ4200000080ojHA00L000000?nV4@2][Jd0ojH@0000003oYQ00000000h0ojH@10000008
0?nV40030:f][@3oYA00000000@000002`3oYA000`000000ojD@0?nU40060?nU408000000P3oYA00
0`2][Jd0oj<@0?nS40050?nS408000001`3oXa000`000000oj<@0?nS40070?nS4080000000<0[Jf]
0?bP403lX100103lX1000`000000o:0@0?bP400@0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd20=^:3@030:f][@2iM@/0
^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0>0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ406@3oYQ40102][Jd0ojHA0?nV
4@3oYQ42000000D0ojHA00<000000?nV4@3oYQ403@3oYQ42000000T0ojHA0`00000>0?nV4@800000
0P3oYQ401@2][Jd0ojH@0000003oYQ00000001X0ojH@00<0[Jf]0?nU403oYA000`3oYA04000000<0
ojD@200000030?nU4080000000<0ojD@0000000000000P3oYA000`2][Jd0oj<@0?nS40050?nS4080
0000203oXa000`000000oj<@0?nS40050?nS40<0000000<0[Jf]0?bP403lX100103lX1000`000000
o:0@0?bP400@0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd30:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0
/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h30:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@@0[Jf]
1@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@040:f][@3oYQ40ojHA0?nV4@8000001@3oYQ400`000000
ojHA0?nV4@0:0?nV4@D000001P3oYQ43000001D0ojHA00D0[Jf]0?nV40000000ojH@0000000J0?nV
40030:f][@3oYA00ojD@01L0ojD@0`0000020?nU40030:f][@3oXa00oj<@0080oj<@0P0000000`3o
Xa000000000000090?nS40030000003oXa00oj<@00@0oj<@0`0000000`2][Jd0o:0@0?bP40040?bP
40030000003lX100o:0@0100o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0[Jf]0>bF
3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd01`3CQ`h00`000000dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40102][Jd0ojHA0?nV4@3oYQ42
000000D0ojHA00<000000?nV4@3oYQ403P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@050:f][@3oYQ00
00000?nV400000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00@0oj<@0`00
00090?nS40030000003oXa00oj<@00<0oj<@00D000000?nS403oXa0000000:f][@060?bP40030000
003lX100o:0@0100o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@070=>73P030000
002][Jd0[Jf]00`0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]
303oY1400`2][Jd0ojHA0?nV4@0H0?nV4@040:f][@3oYQ40ojHA0?nV4@8000001@3oYQ400`000000
ojHA0?nV4@0>0?nV4@030:f][@3oYQ40ojHA01`0ojHA00D0[Jf]0?nV40000000ojH@0000000J0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004@3oXa05000000<0oj<@00<000000:f]
[@3lX100103lX10300000140o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL3`2][Jd0k9H>
0140k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0:f][@2][Jd60;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00H0dhL>00@0[Jf]000000000000[Jf]303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3o
Y140[Jf]00<0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00
00050?nV4@030000003oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ401`3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@050:f][@3oYQ0000000?nV400000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01T0oj<@00<000000:f][@3lX100103lX10300000140o:0@00<0[Jf]0?JL3`3fW0l0
4`3fW0l30:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01`2][Jd0^GD;0;Ue2`2iM@/0[Jf]0;Ue
2`0000000`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P070000003CQ`h0[Jf]0=>73P000000dhL>0:f]
[@0<0>nH40030:f][@3lX100o:0@00l0o:0@0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ42000000D0ojHA00<000000?nV4@3oYQ40103oYQ400`000000ojHA0?nV
4@070?nV4@030:f][@3oYQ40ojHA01`0ojHA00D0[Jf]0?nV40000000ojH@0000000J0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40030?bP40<00000
4@3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue2`0000000P2iM@/00`2][Jd0R5H7
08QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]0080dhL>
00<000000=>73P0000000P3CQ`h00`000000dhL>0:f][@0<0>nH40030:f][@3lX100o:0@00`0o:0@
0`2][Jd00`3lX100[Jf]0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ42000000`0ojHA00<000000?nV4@3oYQ401`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@050:f]
[@3oYQ0000000?nV400000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1000`3lX10300000140o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0
^GD;00D0[Jf]000000000000^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01P2][Jd0
Uf0;09MP2`2GH0/0[Jf]0=>73P80000000<0[Jf]0000003CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400:
0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000303oYQ400`000000ojHA0?nV4@07
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00D0[Jf]0?nV40000000ojH@0000000J0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40030?bP40<000004@3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/010000000[Jf]0;Ue2`2][Jd408QF1`80[Jf]
@P2`h>H10?ooo`00F@2`h>H02P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P000000[Jf]0=>73P000004
0=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@H0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000;
0?nV4@8000002@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@T0[Jf]00<000000:f][@0000008P2][JdG
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1000`3lX10300000180o:0@00<0[Jf]
0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<000000;Ue2`2][Jd00P00000308QF1`80[Jf]@P2`h>H1
0?ooo`00F@2`h>H01`2][Jd0Uf0;09MP2`2GH0/000000:f][@0000000P3CQ`h00`000000dhL>0=>7
3P020=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@T0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00
000;0?nV4@8000002@3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ401@2][Jd0ojH@0000
003oYQ00000001X0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP40030?bP40<000004P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
102iM@/010000000^GD;0;Ue2`2][Jd2000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00
F@2`h>H01`2][Jd0Uf0;09MP2`000000[Jf]0=>73P0000000P3CQ`h00`000000dhL>0=>73P020=>7
3P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@`0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000;0?nV
4@8000001@3oYQ4<0:f][AL0ojHA00D0[Jf]0?nV40000000ojH@0000000J0?nV40030:f][@3oYA00
ojD@01D0ojD@302][JdH0?nS40030:f][@3lX100o:0@00<0o:0@0`00000B0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]
0;Ue2`2iM@/00`2iM@/010000000^GD;0;Ue2`2][Jd2000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`
h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;000000000000[Jf]008000000P3CQ`h01@000000dhL>0=>7
3P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP402][Jd00P2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000203oYQ430:f][@030000
002][Jd0[Jf]00@0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@050:f][@3oYQ0000000?nV4000
00006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS4003
0:f][@3lX100o:0@00<0o:0@0`00000B0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/01P000000^GD;0:f][@000000R5H7
00000080R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;000000000000
[Jf]008000000P3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00d0kiP@0P2][JdA0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000202]
[Jd30?nV4@030000003oYQ40ojHA00P0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ401@2][Jd0ojH@0000
003oYQ00000001X0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]
103oXa000`2][Jd0o:0@0?bP40030?bP40<000004P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`05
0000002iM@/0[Jf]0000002][Jd00P0000000`28EPL0[Jf]0;3PiP110;3PiP40oooo001I0;3PiP06
0:f][@2GH0/000000000002][Jd000000P3CQ`h2000000<0dhL>00<0[Jf]0>nH403_V1002@3_V103
0:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0D0?nV4@P0[Jf]0P00000;
0?nV4@030000003oYQ40ojHA00P0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ401@2][Jd0ojH@0000003o
YQ00000001X0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]0P3l
X10300000180o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3K
RPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`060000002iM@/0[Jf]00000028
EPL000000P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP060:f][@000000[Jf]0000
002][Jd000000P3CQ`h2000000<0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd3
0?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000002P3oYQ400`2][Jd0ojHA0?nV4@0K
0?nV4@H000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]
0?bP403lX100o:0@0P2][Jd300000080[Jf]403lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/0102i
M@/02@000000^GD;0:f][@000000R5H70000002][Jd0R5H70:f][@120;3PiP40oooo001I0;3PiP80
000000@0Uf0;0000002][Jd000000P3CQ`h01P000000dhL>0=>73P3CQ`h000000:f][@L0kiP@0P2]
[Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV
4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000002P3oYQ42000000X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40030?bP40<000000P3lX1060:f][@X0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2]
[Jd50=^:3@030:f][@2iM@/0^GD;00@0^GD;00T000000;Ue2`2][Jd0000008QF1`000000[Jf]08QF
1`2][Jd0@P2`h>H10?ooo`00F02`h>H01P000000[Jf]0000002GH0/000000:f][@<0dhL>00H00000
0=>73P3CQ`h0dhL>0000002][Jd50>nH4080[Jf]1P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA0080
ojHA0P00000:0?nV4@8000002P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00<0
o:0@00<000000?bP40000000203lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00@0
^GD;00L000000;Ue2`2][Jd0000008QF1`000000R5H70080[Jf]@P2`h>H10?ooo`00F02`h>H01P00
0000[Jf]0000002GH0/000000:f][@<0dhL>00H000000=>73P3CQ`h0dhL>0000002][Jd30>nH4080
[Jf]203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A1@2][JdF0?nV4@03
0:f][@3oYQ40ojHA0080ojHA0P0000040?nV4@P000002P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@00<0o:0@0P00000@0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`050;Ue2`060000002iM@/0[Jf]0000
0028EPL000000P28EPL00`2][Jd000000;3PiP100;3PiP40oooo001H0;3PiP060000002][Jd00000
09MP2`000000[Jf]0P3CQ`h2000000<0dhL>00<000000:f][@3_V1000P2][Jd:0>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0
[Jf]0?nV4@0000002000000B0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100103l
X1000`000000o:0@0?bP400A0?bP40030:f][@3fW0l0mY`?00@0[Jf]403fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd60;Ue2`@0000000@0R5H700000028EPL0R5H7
0P0000110;3PiP40oooo001G0;3PiP80000000D0[Jf]0000002GH0/000000:f][@020=>73P800000
0`3CQ`h00`000000[Jf]0:f][@0<0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
2`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100103lX1000`000000o:0@0?bP400A0?bP40030:f]
[@3fW0l0mY`?00@0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
303KRPd20:f][@D0^GD;00H000000;Ue2`2iM@/0000008QF1`00000208QF1`800000@@2`h>H10?oo
o`00E`2`h>H2000000050:f][@000000Uf0;0000002][Jd00P3CQ`h00`000000dhL>0=>73P020=>7
3P030000002][Jd0kiP@00`0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT
4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0:f][@2][Jd3
0;Ue2`060000002iM@/0^GD;00000028EPL000000P28EPL200000440/>3V0@3oool005L0/>3V0P00
00001P2][Jd0000009MP2`000000[Jf]0=>73P8000000`3CQ`h2000000030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00h0mY`?102][Jd20?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00<0^GD;00D000000;Ue
2`000000R5H70000000208QF1`<00000@02`h>H10?ooo`00E`2`h>H2000000060:f][@000000Uf0;
0000002][Jd0dhL>0P0000020=>73P040:f][@00000000000:f][@d0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0B0?JL3`@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;
00P0[Jf]0;Ue2`2iM@/000000;Ue2`000000R5H700000080R5H70`0000100;3PiP40oooo001G0;3P
iP80000000D0[Jf]000000000000Uf0;0:f][@02000000040=>73P000000[Jf]0=>73P80000000<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01`2][Jd0^GD;0000002iM@/0000008QF1`00
00000P28EPL00`000000[Jf]000000100;3PiP40oooo001G0;3PiP80000000D0[Jf]000000000000
Uf0;0:f][@02000000040:f][@000000dhL>0=>73P80000000<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`060:f][@000000^GD;00000028EPL000000P28
EPL00`000000[Jf]000000100;3PiP40oooo001G0;3PiP80000000T0[Jf]000000000000Uf0;0:f]
[@000000[Jf]0=>73P0000000P3CQ`h2000000030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030000002][Jd000000080R5H700<0000008QF1`00
00000P0000100;3PiP40oooo001G0;3PiP80000000H0[Jf]000000000000Uf0;0:f][@0000020=>7
3P030000003CQ`h0dhL>0080000000<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP
4080[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00D0^GD;00<000000;Ue2`0000000P28EPL00`000000R5H7000000020000
0400/>3V0@3oool005L0/>3V0P0000001P2GH0/000000000002GH0/0[Jf]00000080dhL>00H00000
0=>73P3CQ`h000000=>73P2][Jd=0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/01`000000^GD;0000002][Jd0R5H70000
0028EPL00`0000100;3PiP40oooo001G0;3PiP80000000<0Uf0;0000000000000P2][Jd010000000
dhL>0=>73P0000020=>73P030000002][Jd0kiP@00d0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<
0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`070000002iM@/0
00000:f][@28EPL0000008QF1`0300000400/>3V0@3oool005L0/>3V1@0000020:f][@040000003C
Q`h0dhL>00000080dhL>00<000000:f][@3_V1003@3_V100102][Jd0o:0@0:f][@2][Jd>0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0
[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00@0^GD;00P000000;Ue2`00
0000R5H70:f][@000000R5H70:f][@800000@02`h>H10?ooo`00EP2`h>H2000000070:f][@000000
Uf0;0000002GH0/0[Jf]000000020=>73P050000003CQ`h0dhL>0000002][Jd03@3_V1030:f][A00
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0
ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;
00@0^GD;00P000000;Ue2`000000R5H70:f][@000000R5H70:f][@800000@02`h>H10?ooo`00EP2`
h>H2000000080:f][@000000[Jf]00000011JN40[Jf]0000003CQ`h200000080dhL>00<000000:f]
[@3_V1002P3_V1020:f][@030>nH402][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd9
0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<000000;Ue2`0000000P28EPL00`000000R5H7045Yh@02
00000400/>3V0@3oool005H0/>3V0P0000002@2][Jd000000:f][@000000@FWQ0:f][@000000dhL>
000000030=>73P030000002][Jd0kiP@00P0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@
00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=
0P2][Jd70=^:3@030:f][@2iM@/0^GD;00D0^GD;0P00000208QF1`030000002][Jd0@FWQ00800000
@02`h>H10?ooo`00EP2`h>H2000000060:f][@000000Uf0;00000011JN40[Jf]0P0000030=>73P80
000000<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0
mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0
fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/200000080R5H700<000000:f][@11JN400P0000100;3PiP40
oooo001F0;3PiP80000000H0[Jf]0000002GH0/00000045Yh@2][Jd50=>73P80000000<0[Jf]0>nH
403_V1000`3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00<0[Jf]0;Ue
2`2iM@/01@2iM@/200000080R5H700<0000008QF1`0000000P0000100;3PiP40oooo001F0;3PiP80
000000H0[Jf]0000002GH0/00000045Yh@2][Jd50=>73P80000000@0[Jf]0>nH403_V100kiP@0P2]
[Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV
4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/01P2iM@/2000000030:f]
[@28EPL0000000@00000@02`h>H10?ooo`00EP2`h>H2000000050:f][@000000Uf0;0000002][Jd0
1P3CQ`h2000000040:f][@3_V100[Jf]0:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@80[Jf]1`2iM@/2000000030:f][@000000000000D00000?`2`h>H10?ooo`00
EP2`h>H2000000050:f][@000000000009MP2`2][Jd01P3CQ`h200000080[Jf]3@3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd50;Ue2`80000000<0[Jf]08QF1`00
00001@00000o0;3PiP40oooo001F0;3PiP80000000D0[Jf]0000002GH0/0Uf0;0:f][@060=>73P80
000000<0[Jf]0>nH403_V100303_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0
oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0
fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]102iM@/2000000030:f][@28EPL0R5H700D00000?`2`h>H10?oo
o`00EP2`h>H2000000050:f][@000000Uf0;09MP2`2][Jd01@3CQ`h0102][Jd000000000002][Jd=
0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd7
0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2i
M@/0[Jf]00<0^GD;0P0000000`2][Jd0R5H708QF1`05000003l0/>3V0@3oool005H0/>3V10000002
09MP2`030:f][@3CQ`h0dhL>0080dhL>00D0[Jf]0=>73P00000000000:f][@0=0>nH40030:f][@3l
X100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@040;Ue2`00
000000000:f][@<0R5H71000000o0;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;
0:f][@030=>73P060:f][@3CQ`h0dhL>0=>73P000000[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP
40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue
2`040:f][@00000000000:f][@<0R5H700@0[Jf]0000000000000000?`2`h>H10?ooo`00EP2`h>H2
000000060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd40=>73P030000002][Jd0kiP@00`0kiP@
00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd000000:f][@0308QF1`040:f][@0000000000000003l0
/>3V0@3oool005H0/>3V0P000000102][Jd0Uf0;09MP2`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0
[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`00
0000[Jf]08QF1`0308QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00<000000:f][@2G
H0/00`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030000002][Jd0[Jf]00<0R5H700<0[Jf]00000000
0000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]203CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]
kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/00`000000[Jf]0:f][@0308QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00<0
00000:f][@2GH0/00P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP
40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02]
[Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2i
M@/0^GD;00H0^GD;00@000000:f][@28EPL0[Jf]0P28EPL00`2][Jd000000000000o0;3PiP40oooo
001F0;3PiP070000002][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02]
[Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;00@000000:f][@28EPL0[Jf]0P28EPL00`2]
[Jd000000000000o0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>7
3P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF
1`28EPL0[Jf]08QF1`2][Jd2000003l0/>3V0@3oool005H0/>3V00@000000:f][@2GH0/0[Jf]0P2G
H0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f]
[@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001F0;3PiP030000002]
[Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0
Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
3`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`
h>H2000000@0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@05045Y
h@2TWXl0Y9j?0:BNS`2][Jd0102aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036
`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^004
0:f][@11JN40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF
1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`h>H2000000<0Uf0;00<0[Jf]0=>73P3C
Q`h01`3CQ`h01@2][Jd0kiP@0:f][@2][Jd0@FWQ0080Y9j?0P11JN400`2TWXl0[Jf]0;6[W@050;6[
W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00@0[Jf]045Yh@2d/;40];2a0P2]
[Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0
?@2`h>H10?ooo`00EP2`h>H2000000<0Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@80Y9j?00T0
@FWQ0:BNS`2TWXl0Y9j?045Yh@2TWXl0[Jf]0;6[W@11JN401P2aZid20:f][@<0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3P
iPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji
^02][Jd0[Jf]1`2n^KP01@11JN40_[Vh0;ji^02][Jd0@FWQ0080];2a00@0@FWQ0;B`/@2][Jd0[Jf]
2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005H0/>3V
00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@11JN40@FWQ0080Y9j?
00P0@FWQ0:BNS`2TWXl0Y9j?045Yh@2TWXl0[Jf]0;6[W@80@FWQ1`2aZid20:f][@030;6[W@2][Jd0
^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H5
0:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00`0`kfk0`2][Jd90;ji^005045Yh@2n^KP0_[Vh0:f][@11JN400P2d/;42045Yh@80];2a0P2]
[Jd80;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00EP2`
h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd01@2TWXl0@FWQ045Y
h@2TWXl0@FWQ00@0Y9j?00H0@FWQ0:BNS`2][Jd0/J^M045Yh@2aZid2045Yh@L0/J^M0`2][Jd?0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<7
0:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01@2n^KP01011JN40_[Vh0;ji^011
JN430;ji^0040:f][@11JN40];2a0;B`/@80@FWQ0`2d/;400`11JN40[Jf]0;Ue2`060;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]045Yh@2][Jd0Y9j?045Yh@020:BNS`03045Yh@2TWXl0Y9j?
00<0Y9j?00@0[Jf]0;6[W@11JN40@FWQ0P2aZid00`11JN40/J^M0;6[W@060;6[W@030:f][@2i/ZH0
[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^003
0;ji^005045Yh@2n^KP0@FWQ0;ji^011JN40102n^KP2045Yh@030;B`/@11JN40@FWQ00<0];2a00@0
@FWQ0;B`/@2][Jd0[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0
/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P060:f][@11JN40@FWQ0:f]
[@2TWXl0@FWQ0P2TWXl00`11JN40Y9j?0:BNS`030:BNS`030:f][@2aZid0@FWQ00@0/J^M00<0@FWQ
0;6[W@2aZid01@2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`02
0<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^0020;ji^003045Yh@2n^KP0_[Vh00<0@FWQ102n^KP2
045Yh@030;B`/@11JN40@FWQ00<0];2a00<0@FWQ0:f][@2][Jd00`2][Jd30;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00<0dhL>00@0[Jf]08Z5M@11JN40@FWQ0P2][Jd01011JN40Y9j?0:BNS`11JN450:BNS`03
0:f][@2aZid0@FWQ00D0/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@020;6[W@030:f][@2i/ZH0^K:V
00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2]
[Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP01011JN40_[Vh0;ji^02n^KP2
045Yh@@0_[Vh1@11JN430;B`/@04045Yh@2d/;40];2a0:f][@80Wi^P00@0[Jf]0;Ue2`2iM@/0[Jf]
0`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0Uf0;
0:f][@3CQ`h20:f][@0:045Yh@2:QGD0@FWQ08Z5M@2][Jd0Y9j?045Yh@2][Jd0Y9j?045Yh@D0Y9j?
00<0[Jf]0;6[W@2aZid01@2aZid00`11JN40/J^M0;6[W@02045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH0
2@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k
0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@/0`kfk
00@0@FWQ0<>m^`33_K/0[Jf]0`2n^KP2045Yh@<0_[Vh0P11JN440;ji^0D0@FWQ00@0];2a0:f][@2]
[Jd0@FWQ0P2d/;40102][Jd0Wi^P09nKX02OVj030:f][@@0R5H700<0[Jf]0000002`h>H0?P2`h>H1
0?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]00<0RXEe045Yh@2:QGD00P11JN401`2:
QGD0[Jf]0:BNS`11JN40Y9j?0:f][@11JN401@2TWXl00`2][Jd0/J^M0;6[W@050;6[W@05045Yh@2a
Zid0/J^M0;6[W@11JN400P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/0
2@33_K/2045Yh@<0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P11JN430;ji^080@FWQ0`2n^KP6045Yh@04
0:f][@2d/;40];2a045Yh@80];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0R5H708QF1`0208QF
1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/0102][Jd0
RXEe08Z5M@11JN4408Z5M@030:f][@2TWXl0@FWQ0080Y9j?0P11JN401@2][Jd0Y9j?0:BNS`2TWXl0
[Jf]00L0/J^M00<0@FWQ0;6[W@2aZid0102aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`06
0<>m^`@0@FWQ0`33_K/0102][Jd0_[Vh0;ji^02n^KP2045Yh@<0_[Vh0P11JN430;ji^0H0@FWQ0`2d
/;401P11JN40];2a0;B`/@2][Jd0Wi^P045Yh@@0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3P
iP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]0P2:QGD00`11JN40RXEe08Z5M@0208Z5
M@030:f][@2TWXl0@FWQ0080Y9j?0P11JN401@2TWXl0[Jf]0:BNS`11JN40[Jf]00D0/J^M0`11JN46
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]
0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]
0<K0_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/02033_K/2045Yh@@0`kfk00<0[Jf]
0;ji^02n^KP00P11JN430;ji^080@FWQ0`2n^KP00`11JN40[Jf]045Yh@02045Yh@050;B`/@11JN40
];2a0;B`/@11JN400P2d/;400`2][Jd0Wi^P045Yh@0409nKX0060:f][@28EPL0R5H708QF1`2][Jd0
0000?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@80RXEe00<0@FWQ08Z5M@2:
QGD00P2:QGD00`2][Jd0@FWQ045Yh@020:BNS`80@FWQ0P2TWXl2045Yh@030:f][@2aZid0/J^M0080
/J^M00<0@FWQ0;6[W@11JN401`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0
_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk045Yh@03045Yh@D0
`kfk0P11JN440<>m^`030:f][@2n^KP0_[Vh0080@FWQ0`2n^KP2045Yh@<0_[Vh00<0@FWQ0:f][@11
JN400P11JN401@2d/;40@FWQ0;B`/@2d/;40@FWQ0080];2a00<0[Jf]09nKX011JN401@2OVj001@2]
[Jd0R5H708QF1`2][Jd0000003l0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd208Z5
M@03045Yh@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`11JN400`2TWXl00`11JN40Y9j?0:BNS`02045Y
h@80[Jf]00D0/J^M045Yh@11JN40/J^M045Yh@080;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]4036`;`3045Yh@80`kfk0P11JN450<>m^`80@FWQ1033_K/0
0`2][Jd0_[Vh0;ji^002045Yh@@0_[Vh00L0@FWQ0;ji^02][Jd0[Jf]045Yh@2][Jd0];2a0080@FWQ
00D0];2a045Yh@2d/;40];2a045Yh@020;B`/@030:f][@2OVj00@FWQ00D0Wi^P0P2][Jd00`28EPL0
[Jf]0000000o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]0P2:QGD01@11JN40
RXEe08Z5M@2:QGD0[Jf]00H0Y9j?00T0@FWQ0:BNS`2TWXl0Y9j?045Yh@2][Jd0/J^M045Yh@2][Jd0
0P11JN490;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][A40`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l
0<K0_00=0<K0_0<0@FWQ00L0[Jf]0<>m^`33_K/0`kfk045Yh@33_K/0@FWQ00@0`kfk0P11JN440<>m
^`040:f][@2n^KP0_[Vh0;ji^0H0@FWQ00H0[Jf]0;ji^02n^KP0@FWQ0:f][@2d/;42045Yh@030;B`
/@11JN40@FWQ00<0@FWQ00@0];2a0:f][@2OVj00@FWQ1@2OVj001@2][Jd0L6ii0:f][@2][Jd00000
03l0/>3V0@3oool005H0/>3V0P2][Jd306=PD`040:f][@2:QGD0@FWQ045Yh@<0RXEe00<0[Jf]0:BN
S`2TWXl0102TWXl01`11JN40Y9j?0:BNS`11JN40Y9j?0:f][@2aZid00P11JN430:f][@D0/J^M00@0
@FWQ0;6[W@2aZid0[Jf]402i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]
3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f]
[@36`;`0a/2l00l0a/2l00<0@FWQ0:f][@33_K/00`33_K/2045Yh@@0`kfk0P11JN440<>m^`030:f]
[@2n^KP0_[Vh00<0_[Vh0`2][Jd01`11JN40_[Vh0;ji^02n^KP0@FWQ0:f][@2d/;401011JN420;B`
/@80@FWQ00@0];2a0:f][@2OVj00@FWQ102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool0
05H0/>3V0P2][Jd306=PD`80[Jf]00<0RXEe045Yh@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`050:BN
S`07045Yh@2TWXl0@FWQ0:BNS`2][Jd0/J^M045Yh@040;6[W@80[Jf]0`2aZid01011JN40/J^M0;6[
W@2][Jd@0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0_036`;`0
3`36`;`00`11JN40[Jf]0<>m^`030<>m^`03045Yh@33_K/0@FWQ00<0`kfk0P11JN440<>m^`040:f]
[@2n^KP0_[Vh0;ji^080[Jf]0`2n^KP01`11JN40_[Vh0;ji^02n^KP0@FWQ0:f][@2d/;400P11JN44
0;B`/@80@FWQ00@0];2a0:f][@11JN40@FWQ0`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]?`2`
h>H10?ooo`00EP2`h>H0202][Jd0Hf1C06=PD`1SH5<000000:f][@2:QGD0[Jf]102:QGD00`2][Jd0
Y9j?0:BNS`060:BNS`06045Yh@2TWXl0Y9j?0:f][@2aZid0@FWQ102aZid00`11JN40/J^M0:f][@02
0:f][@04045Yh@2aZid0/J^M0:f][@l0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`4045Yh@80_[N/00<0
[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0
[Jf]0<K0_036`;`03`36`;`00`11JN40[Jf]0<>m^`040<>m^`80@FWQ0`33_K/2045Yh@@0`kfk00@0
[Jf]0;ji^02][Jd0[Jf]1@2n^KP01`11JN40_[Vh0;ji^02n^KP0@FWQ0:f][@11JN401`2d/;400`11
JN40];2a0:f][@02045Yh@80Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00@0[Jf]0;6[W@2aZid0@FWQ0`2aZid00`11JN40/J^M0;6[W@020;6[W@04045Yh@2]
[Jd0/J^M0:f][@l0^K:V00<0[Jf]0;jg[02n]j`03@2n]j`6045YhA00`KZ`202][Jd@0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]
0`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00l0a/2l00<0@FWQ0:f][@33_K/0
1033_K/2045Yh@@0`kfk00@0@FWQ0<>m^`33_K/0`kfk0`2][Jd20;ji^003045Yh@2n^KP0_[Vh0080
_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN480;B`/@05045Yh@2d/;40@FWQ09nKX011JN400P2][Jd3
09nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=P
D`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD0102][Jd0Y9j?0:BNS`11JN480:BNS`040:f][@2a
Zid0/J^M045Yh@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`11JN40/J^M0:f][@020:f][@h0^K:V
00<0[Jf]0;jg[02n]j`03@2n]j`2045Yh@80_[N/00<0[Jf]045Yh@11JN404@31^[000`2][Jd0`kfc
0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036
`;`03`36`;`00`11JN40[Jf]0<>m^`050<>m^`03045Yh@33_K/0`kfk0080`kfk00H0@FWQ0:f][@2]
[Jd0[Jf]0<>m^`2][Jd30;ji^005045Yh@2n^KP0_[Vh0;ji^011JN400`2n^KP00`11JN40_[Vh0:f]
[@090;B`/@80@FWQ00<0Wi^P0:f][@2OVj00102OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@040:f][@2:QGD0
[Jf]0:BNS`80@FWQ202TWXl0102][Jd0/J^M0;6[W@11JN420;6[W@80@FWQ102aZid01@11JN40/J^M
0;6[W@2][Jd0^K:V00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00=0;jg[080@FWQ0P2n]j`0102][Jd0
`KZ`045Yh@11JN440<6j/0@0@FWQ2031^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0[Jf]4@35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00`0al6h1`11JN400`37`KP0[Jf]0<O1^P0F0<O1
^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`03`36`;`00`11JN40[Jf]0<>m^`050<>m^`03045Yh@33_K/0`kfk0080[Jf]00H0@FWQ0<>m
^`33_K/0`kfk045Yh@2][Jd30;ji^080@FWQ0P2n^KP00`11JN40_[Vh0;ji^0030;ji^0030:f][@2d
/;40];2a00P0];2a00<0@FWQ0:f][@2OVj001@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]00<0Y9j?
045Yh@2TWXl0202TWXl0102][Jd0/J^M0;6[W@2aZid2045Yh@030;6[W@11JN40/J^M00<0/J^M00@0
@FWQ0;6[W@2aZid0[Jf]102i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`03@2n]j`2045Yh@80_[N/
00@0[Jf]0<6j/011JN40@FWQ1`31^[03045Yh@H0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00h0
al6h0P11JN440<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00l0
a/2l00<0@FWQ0:f][@33_K/01@33_K/00`11JN40[Jf]0:f][@020<>m^`80@FWQ0P33_K/2045Yh@@0
_[Vh1011JN450;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0
L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0
RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid01011JN40
/J^M0;6[W@2aZid2045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH40:f][@@0^K:V00<0[Jf]0;jg
[02n]j`03@2n]j`2045Yh@030;jg[02][Jd0`KZ`0080`KZ`0P11JN460<6j/003045Yh@31^[00`KZ`
00H0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2]
[Jd0al6h0<O1^00>0<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2]
[Jd0b<6k0<S1^`0A0<S1^`03045Yh@38`K/0[Jf]01<0al6l00<0[Jf]0<K0_036`;`03`36`;`00`11
JN40[Jf]0<>m^`030<>m^`80[Jf]00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@80`kfk0P11JN4=0;ji
^0030:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H1
0?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0
/J^M00P0/J^M0P11JN420;6[W@030:f][@2i/ZH0^K:V00T0^K:V0`2][Jd00`2i/ZH0[Jf]0;jg[00>
0;jg[080@FWQ00<0_[N/0:f][@31^[000P31^[02045Yh@H0`KZ`00<0@FWQ0<6j/031^[001P31^[00
0`2][Jd0`kfc0<>m/`030<>m/`<0@FWQ3@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng00T0a[ng7@2][Jd2045YhA40[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k00D0b<6k1@11JN460<S1^`04045Yh@38`K/0@FWQ0:f][A<0al6l00<0[Jf]0<K0_036`;`03`36
`;`00`11JN40[Jf]0<>m^`030:f][@80`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@80`kfk0P11
JN4=0;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d/;40[Jf]1`2OVj001@2][Jd0L6ii
071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@03
0:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@080;6[W@80@FWQ0P2aZid00`2][Jd0
^K:V0;VbYP0<0;VbYP<0[Jf]3P2n]j`2045Yh@030;jg[02][Jd0`KZ`00<0`KZ`0P11JN450<6j/003
045Yh@31^[00`KZ`00H0`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN430<>m/`80@FWQ0`33_K<2045Y
h@H0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
00h0al6h0P11JN440<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`020<S1^`03045Yh@38`K/0@FWQ00D0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11
JN40b<6k0:f][@0C0<O1_0030:f][@36`;`0a/2l00h0a/2l00@0[Jf]045Yh@2][Jd0[Jf]1@33_K/0
0`11JN40`kfk0<>m^`020<>m^`06045Yh@33_K/0@FWQ0<>m^`11JN40[Jf]3@2n^KP00`2][Jd0];2a
0;B`/@030;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2]
[Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080
Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@080;6[W@80@FWQ0P2aZid00`2][Jd0
^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]2P2n]j`2045Yh@030;jg[02][Jd0`KZ`00<0
`KZ`0P11JN450<6j/003045Yh@31^[00`KZ`00H0`KZ`00<0[Jf]0<>m/`33_K<00P11JN450<>m/`04
045Yh@33_K<0@FWQ045Yh@P0`kfc00<0@FWQ0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@0>0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03P37`KP2045Yh@@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0>0<S1^`<0@FWQ0`38`K/00`2][Jd0b<6k0<S1^`020<S1
^`03045Yh@38`K/0@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`2][Jd0al6l0<O1_00A0<O1
_0030:f][@36`;`0a/2l00T0a/2l1@2][Jd00`36`;`0@FWQ0:f][@060<>m^`03045Yh@33_K/0`kfk
0080`kfk00H0@FWQ0<>m^`33_K/0@FWQ0<>m^`2][Jd=0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]
1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V
00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0
/J^M0;6[W@080;6[W@80@FWQ0P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0_[N/00<0
_[N/102][Jd60;jg[080@FWQ00<0_[N/0:f][@31^[000`31^[02045Yh@D0`KZ`00<0@FWQ0<6j/031
^[001P31^[000`2][Jd0`kfc0<>m/`02045Yh@H0`kfc0P11JN490<>m/`03045Yh@35_[D0aKje00<0
aKje00<0@FWQ0<Fn]@35_[D02`35_[D01011JN40aKje0<Fn]@2][JdG0<Jo]`030:f][@37`KP0al6h
00h0al6h0P11JN440<O1^0030:f][@37`KX0al6j01@0al6j0`11JN420<S1^`L0@FWQ1038`K/2045Y
h@<0b<6k0P11JN400`38`K/0[Jf]0<S1^`030<S1^`80@FWQ1`38`K/00`11JN40b<6k0<S1^`050<S1
^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@H0a/2l00<0@FWQ0:f]
[@33_K/01@33_K/00`11JN40`kfk0<>m^`03045Yh@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102]
[Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`
h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd2
0:BNS`030:f][@2aZid0/J^M00P0/J^M0P11JN400`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0
_[N/00L0_[N/102][Jd20;jg[080@FWQ00<0_[N/0:f][@31^[001031^[000`11JN40`KZ`0<6j/003
0<6j/003045Yh@31^[00`KZ`00H0`KZ`00<0[Jf]0<>m/`33_K<00P11JN460<>m/`80@FWQ2033_K<2
045Yh@@0aKje0P11JN4;0<Fn]@80@FWQ00@0aKje045Yh@11JN40[Jf]0P36_kL2045Yh@@0a[ng1P11
JN490<Jo]`030:f][@37`KP0al6h00h0al6h0P11JN430<O1^080@FWQ2@37`KX7045Yh@80al6j1011
JN400`37`KX0[Jf]0<S1^`040<S1^`80@FWQ1`38`K/00`11JN40b<6k0<S1^`040<S1^`03045Yh@2]
[Jd0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`050<S1^`030:f][@37
`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01@2][Jd:0<K0_003045Yh@2][Jd0`kfk00D0`kfk00<0
@FWQ0<>m^`33_K/01`33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nK
X00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD0
0`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]2P2aZid2045Yh@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]
0;jg[02n]j`02`2n]j`20:f][@80@FWQ00<0_[N/0:f][@31^[001031^[000`11JN40`KZ`0<6j/002
0<6j/080@FWQ2031^[000`2][Jd0`kfc0<>m/`02045Yh@H0`kfc0P11JN480<>m/`80@FWQ1035_[D0
0`11JN40aKje045Yh@090<Fn]@80@FWQ1035_[D2045Yh@030<Jo]`11JN40@FWQ00H0a[ng0P11JN4;
0<Jo]`040:f][@37`KP0al6h0<O1^0@0@FWQ1@37`KP01011JN40al6h0<O1^037`KP2045Yh@80al6h
00<0@FWQ0<O1^02][Jd00P11JN4:0<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN400`37`KX0[Jf]
0<S1^`040<S1^`80@FWQ1P38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`11JN40b<6k
0<S1^`050<S1^`80@FWQ1`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]3`36`;`00`11JN40[Jf]
0<>m^`040<>m^`80@FWQ2@33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P
09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2T
WXl0Y9j?00T0Y9j?0P2][Jd90;6[W@80@FWQ00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg
[00=0;jg[080@FWQ1@2][Jd20<6j/003045Yh@31^[00`KZ`0080`KZ`0P11JN480<6j/0030:f][@33
_K<0`kfc0080@FWQ1P33_K<2045Yh@P0`kfc0P11JN440<Fn]@<0@FWQ2035_[D00`11JN40aKje045Y
h@040<Fn]@030:f][@36_kL0@FWQ0080@FWQ1P36_kL2045Yh@/0a[ng00@0[Jf]0<O1^011JN40@FWQ
1037`KP00`11JN40al6h0<O1^002045Yh@@0al6h0P11JN401P37`KP0@FWQ0<O1^037`KP0[Jf]0<O1
^P80@FWQ2@37`KX00`11JN40al6j0<O1^P050<O1^P80@FWQ00<0al6j0:f][@38`K/01038`K/2045Y
h@H0b<6k00<0@FWQ0<S1^`38`K/01P38`K/00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ2038`K/00`2]
[Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_003045Yh@2][Jd0`kfk
00@0`kfk0P11JN490<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`
/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]1P2aZid2045Yh@030;6[W@2][Jd0^K:V00l0
^K:V00<0[Jf]0;jg[02n]j`0302n]j`2045Yh@80_[N/00@0[Jf]0<6j/031^[00`KZ`0P2][Jd00`11
JN40[Jf]0:f][@020:f][@80@FWQ2031^[001@2][Jd0`kfc0<>m/`33_K<0@FWQ00H0`kfc0P11JN48
0<>m/`03045Yh@2][Jd0@FWQ00<0aKje0`11JN480<Fn]@80@FWQ1@35_[D00`2][Jd0a[ng0<Jo]`02
045Yh@H0a[ng0P11JN4;0<Jo]`030:f][@11JN40@FWQ00H0al6h0`11JN450<O1^0<0@FWQ0`37`KP0
102][Jd0al6j0<O1^P11JN490<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN400`37`KX0[Jf]0<S1
^`040<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`060<S1^`030:f][@38`K/0b<6k00T0b<6k0P11
JN460<S1^`03045Yh@38`K/0[Jf]00L0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0
@FWQ0:f][@33_K/01033_K/2045Yh@T0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H0
0`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2
0:f][@@0/J^M00@0@FWQ0;6[W@2aZid0[Jf]402i/ZH00`2][Jd0_[N/0;jg[00<0;jg[080@FWQ0P2n
]j`00`2][Jd0`KZ`0<6j/0030<6j/003045Yh@31^[00`KZ`0080`KZ`0P11JN450:f][@<0`KZ`00<0
[Jf]0<>m/`33_K<00P33_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ1`33_K<01011JN40`kfc0:f]
[@11JN420<Fn]@80@FWQ00<0aKje045Yh@35_[D01P35_[D2045Yh@H0aKje00<0[Jf]0<Jo]`36_kL0
0P11JN460<Jo]`80@FWQ2`36_kL00`2][Jd0@FWQ045Yh@070<O1^080@FWQ1@37`KP2045Yh@D0al6h
00@0[Jf]0<O1^P37`KX0@FWQ2037`KX00`11JN40al6j0<O1^P050<O1^P80@FWQ00<0al6j0:f][@38
`K/01038`K/2045Yh@D0b<6k0P11JN480<S1^`030:f][@38`K/0b<6k00P0b<6k0P11JN470<S1^`03
045Yh@38`K/0[Jf]0080al6l1@2][Jd<0<O1_0030:f][@36`;`0a/2l00l0a/2l00<0@FWQ0:f][@33
_K/01033_K/00`11JN40`kfk0<>m^`080<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^003
0:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40
oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@040;6[W@<0[Jf]00D0/J^M045Yh@2aZid0/J^M0:f][@0@0;VbYP030:f][@2n]j`0_[N/00`0
_[N/0P11JN420;jg[0030:f][@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[000P31^[03045Yh@@0
`KZ`1`2][Jd20<>m/`03045Yh@33_K<0`kfc0080`kfc0P11JN470<>m/`04045Yh@33_K<0[Jf]045Y
h@80aKje0P11JN400`35_[D0@FWQ0<Fn]@060<Fn]@80@FWQ1P35_[D00`2][Jd0a[ng0<Jo]`02045Y
h@H0a[ng0P11JN4;0<Jo]`030:f][@11JN40@FWQ00L0al6h0P11JN460<O1^003045Yh@37`KP0al6h
00<0al6h00@0[Jf]0<O1^P37`KX0@FWQ2037`KX00`11JN40al6j0<O1^P050<O1^P80@FWQ00<0al6j
0:f][@38`K/01038`K/2045Yh@D0b<6k0P11JN480<S1^`030:f][@38`K/0b<6k00H0b<6k0`11JN47
0<S1^`030:f][@11JN40[Jf]00<0[Jf]4@37`K`00`2][Jd0a/2l0<K0_00?0<K0_080@FWQ00<0[Jf]
0<>m^`33_K/00P33_K/00`11JN40`kfk0<>m^`080<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n
^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`
h>H10?ooo`00G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]
0;6[W@2aZid01`2aZid30:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0302n]j`2
045Yh@80_[N/00<0[Jf]0<6j/031^[000`31^[000`11JN40`KZ`0<6j/0020<6j/0<0@FWQ1`31^[00
102][Jd0`kfc0<>m/`33_K<30:f][@80@FWQ0P2][Jd2045Yh@L0`kfc00@0@FWQ0<>m/`2][Jd0@FWQ
0P35_[D2045Yh@030<Fn]@11JN40aKje00H0aKje0P11JN460<Fn]@030:f][@36_kL0a[ng0080@FWQ
1P36_kL2045Yh@/0a[ng00<0[Jf]045Yh@11JN401`37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP0
0`37`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@030<O1
^P2][Jd0b<6k00@0b<6k0P11JN450<S1^`80@FWQ2038`K/00`2][Jd0b<6k0<S1^`050<S1^`<0@FWQ
00<0b<6k0:f][@2][Jd01@2][Jd01038`K/0@FWQ0<S1^`2][JdC0<O1_0030:f][@36`;`0a/2l00l0
a/2l0P11JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33_K/0`kfk00P0`kfk00@0[Jf]0;ji^02]
[Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3P
iP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0302n]j`2045Yh@80
_[N/00<0[Jf]0<6j/031^[000`31^[000`11JN40`KZ`0<6j/0020<6j/0<0@FWQ1031^[001011JN40
`KZ`0<6j/02][Jd80<>m/`@0@FWQ1P2][Jd01@33_K<0@FWQ0<>m/`2][Jd0@FWQ0080aKje0P11JN42
0<Fn]@03045Yh@35_[D0aKje00<0aKje0P11JN470<Fn]@030:f][@36_kL0a[ng0080@FWQ1P36_kL2
045Yh@/0a[ng00<0[Jf]045Yh@11JN401`37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP00`37`KP0
0`2][Jd0al6j0<O1^P02045Yh@L0al6j00<0@FWQ0<O1^P37`KX01P37`KX00`11JN40al6j0:f][@05
0<S1^`80@FWQ1@38`K/2045Yh@P0b<6k00@0[Jf]0<S1^`38`K/0b<6k0P2][Jd3045Yh@<0[Jf]0P38
`K/00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0[Jf]01<0al6l00<0[Jf]0<K0_036`;`03`36
`;`2045Yh@050:f][@33_K/0`kfk0<>m^`11JN402P33_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2T
WXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0
[Jf]0;jg[02n]j`0302n]j`2045Yh@80_[N/00<0[Jf]0<6j/031^[000`31^[000`11JN40`KZ`0<6j
/0020<6j/080@FWQ00T0`KZ`045Yh@31^[00`KZ`045Yh@31^[00@FWQ0<6j/02][Jd00`33_K<00`11
JN40`kfc0<>m/`040<>m/`80@FWQ1P33_K<2045Yh@80[Jf]00D0@FWQ0:f][@11JN40@FWQ0:f][@02
0<Fn]@03045Yh@35_[D0aKje00<0aKje0P11JN470<Fn]@030:f][@36_kL0a[ng0080@FWQ1P36_kL2
045Yh@/0a[ng00@0[Jf]0<O1^011JN40@FWQ1P37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP00`37
`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j00<0@FWQ0<O1^P37`KX01P37`KX00`11JN40al6j0:f]
[@060<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN430<S1^`@0[Jf]00<0@FWQ0:f][@2][Jd00P2]
[Jd20<S1^`80@FWQ1@38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`2][Jd04`37`K`00`2][Jd0a/2l0<K0
_00?0<K0_080@FWQ00D0[Jf]0<>m^`33_K/0`kfk045Yh@070<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0
302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0
[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2]
[Jd80;VbYP030:f][@2n]j`0_[N/00`0_[N/0P11JN420;jg[0030:f][@31^[00`KZ`0080`KZ`00@0
@FWQ0<6j/031^[00`KZ`1011JN400`31^[00@FWQ0<6j/0020<6j/080@FWQ00<0`KZ`0:f][@33_K<0
0P33_K<00`11JN40`kfc0<>m/`040<>m/`03045Yh@33_K<0`kfc00D0`kfc0P11JN401033_K<0[Jf]
045Yh@35_[D2045Yh@040<Fn]@2][Jd0[Jf]045Yh@D0[Jf]0P11JN420:f][@D0aKje1`11JN440<Jo
]`80@FWQ2`36_kL0102][Jd0al6h0<O1^011JN460<O1^080@FWQ1P37`KP00`11JN40al6h0<O1^003
0<O1^0030:f][@37`KX0al6j0080@FWQ1`37`KX00`11JN40al6j0<O1^P060<O1^P03045Yh@37`KX0
[Jf]00D0b<6k00<0[Jf]045Yh@2][Jd0102][Jd2045Yh@<0[Jf]1038`K/2045Yh@D0b<6k00<0@FWQ
0<S1^`38`K/01038`K/2045Yh@D0b<6k00<0@FWQ0<S1^`2][Jd05037`K`00`2][Jd0a/2l0<K0_00>
0<K0_080@FWQ00@0[Jf]0<>m^`33_K/0@FWQ1@33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00<
0;jg[080@FWQ0P2n]j`00`2][Jd0`KZ`0<6j/0020<6j/003045Yh@31^[00`KZ`00L0`KZ`1011JN42
0<6j/0050:f][@33_K<0`kfc0<>m/`11JN401P33_K<00`11JN40`kfc0<>m/`050<>m/`06045Yh@33
_K<0`kfc0:f][@11JN40aKje0P11JN430<Fn]@03045Yh@35_[D0aKje00<0aKje0P11JN420<Fn]A00
[Jf]0P11JN4;0<Jo]`040:f][@37`KP0al6h0<O1^0<0@FWQ0`37`KP2045Yh@H0al6h00<0@FWQ0<O1
^037`KP00`37`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j00<0@FWQ0:f][@2][Jd01P2][Jd00`11
JN40[Jf]0:f][@050:f][@030<S1^`11JN40b<6k00D0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Y
h@D0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@@0b<6k0`11JN400`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l00h0a/2l1P11JN400`33_K/0[Jf]0:f][@020:f][@L0`kfk00<0[Jf]0;ji
^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680
/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0
^K:V102][Jd00`2i/ZH0[Jf]0;jg[00=0;jg[080@FWQ0P2n]j`00`2][Jd0`KZ`0<6j/0020<6j/003
045Yh@31^[00`KZ`00d0`KZ`00<0[Jf]0<>m/`33_K<00P33_K<00`11JN40`kfc0<>m/`020<>m/`03
045Yh@33_K<0`kfc00H0`kfc00D0@FWQ0<>m/`33_K<0[Jf]0<Fn]@03045Yh@<0aKje00<0@FWQ0<Fn
]@35_[D00`35_[D2045Yh@L0aKje00<0[Jf]0<Jo]`36_kL02036_kL2045YhA80[Jf]1@11JN460:f]
[@03045Yh@2][Jd0[Jf]00H0[Jf]00<0@FWQ0:f][@2][Jd01P2][Jd00`11JN40al6j0<O1^P060<O1
^P03045Yh@37`KX0[Jf]00H0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`050<S1
^`03045Yh@2][Jd0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@@0b<6k0`11JN400`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00`0a/2l1011JN400`2][Jd0`kfk0:f][@020:f]
[@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?oo
o`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0
[Jf]3@2n]j`2045Yh@80_[N/00@0[Jf]0<6j/031^[00`KZ`0P11JN4?0<6j/0030:f][@33_K<0`kfc
00<0`kfc1011JN480<>m/`80@FWQ0P33_K<0102][Jd0aKje045Yh@11JN450<Fn]@03045Yh@35_[D0
aKje0080aKje0P11JN470<Fn]@030:f][@36_kL0a[ng00P0a[ng0`11JN4:0<Jo]`030:f][@37`KP0
al6h00L0al6h0P11JN460<O1^003045Yh@37`KP0al6h00<0al6h00@0[Jf]0<O1^P37`KX0@FWQ2037
`KX00`11JN40al6j0<O1^P060<O1^P03045Yh@37`KX0[Jf]00H0b<6k00<0@FWQ0<S1^`38`K/01038
`K/2045Yh@H0b<6k00<0@FWQ0:f][@38`K/01@38`K/6045Yh@030<S1^`11JN40b<6k00<0b<6k0`11
JN400`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00h0a/2l102][Jd>0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U
0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd90;jg[080@FWQ0P2n]j`0102][Jd0`KZ`0<6j/031^[02045Yh@l0`KZ`00<0
[Jf]0<>m/`33_K<03@33_K<6045Yh@040:f][@35_[D0@FWQ045Yh@D0aKje00<0@FWQ0<Fn]@35_[D0
0P35_[D2045Yh@L0aKje00<0[Jf]0<Jo]`36_kL02036_kL3045Yh@@0a[ng00<0@FWQ0<Jo]`36_kL0
0`36_kL0102][Jd0al6h045Yh@11JN460<O1^003045Yh@37`KP0al6h00D0al6h00<0@FWQ0<O1^037
`KP00`37`KP0102][Jd0al6j0<O1^P11JN480<O1^P80@FWQ1P37`KX2045Yh@030<O1^P2][Jd0b<6k
00D0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@@0b<6k00<0@FWQ0<S1^`2][Jd04P38`K/3045Y
h@030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m
^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3P
iP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@<0_[N/1011JN420;jg[0030:f][@31^[00`KZ`0080
@FWQ4031^[000`2][Jd0`kfc0<>m/`0C0<>m/`040:f][@35_[D0@FWQ045Yh@80aKje1011JN440<Fn
]@80@FWQ1`35_[D00`2][Jd0a[ng0<Jo]`080<Jo]`<0@FWQ1036_kL2045Yh@@0a[ng00@0[Jf]0<O1
^011JN40@FWQ1P37`KP00`11JN40al6h0<O1^0050<O1^080@FWQ1037`KP00`2][Jd0al6j045Yh@09
0<O1^P80@FWQ1P37`KX2045Yh@030<O1^P2][Jd0b<6k00D0b<6k00<0@FWQ0<S1^`38`K/01`38`K/4
045Yh@80b<6k00<0[Jf]0<S1^`38`K/04038`K/3045Yh@030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd0
0`2n]j`0@FWQ045Yh@02045Yh@040:f][@31^[00@FWQ045YhA40`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@060<Fn]@<0@FWQ0P35_[D2045Yh@L0aKje00<0[Jf]0<Jo]`36_kL02036
_kL2045Yh@030<Jo]`11JN40a[ng0080a[ng0P11JN440<Jo]`040:f][@37`KP0al6h045Yh@D0al6h
00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6h045Yh@030<O1^0030:f][@11JN40@FWQ00T0al6j
1011JN430<O1^P80@FWQ0P37`KX0102][Jd0b<6k0<S1^`38`K/4045Yh@l0b<6k00<0[Jf]0<S1^`38
`K/04038`K/3045Yh@030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3P
iP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0
_[N/102][Jd0102n]j`0@FWQ045Yh@11JN4B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D03035_[D2045Yh@H0aKje00<0[Jf]0<Jo]`36_kL01@36_kL5045Yh@80a[ng1011JN450<Jo
]`040:f][@37`KP0al6h0<O1^0D0@FWQ1P37`KP4045Yh@80al6h1011JN4;0<O1^P80@FWQ0P37`KX3
045Yh@@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`<0@FWQ00<0[Jf]
0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
00`0aKje0P11JN460<Fn]@050:f][@36_kL0a[ng0<Jo]`11JN404`36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j00T0al6j0P11JN490<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04038`K/3045Yh@030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H1
0?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00`0aKje0P11JN460<Fn]@050:f][@36_kL0a[ng0<Jo]`11JN404`36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j00T0al6j0P11JN490<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04038`K/2045Yh@030<S1^`2][Jd0al6l00H0al6l1P2][Jd70<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`
h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D03@35_[D2045Yh@D0aKje00<0[Jf]0<Jo]`36_kL00P11JN4C0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37`KX2045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0A0<S1^`03045Yh@38`K/0[Jf]0080al6l1@2][Jd=0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H1
0?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f][@35_[D0aKje00h0aKje00<0@FWQ0<Fn
]@35_[D00`35_[D00`2][Jd0a[ng0<Jo]`02045YhA<0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P090<O1^P80@FWQ2@37`KX00`2][Jd0b<6k0<S1^`040<S1^`03045Yh@38`K/0b<6k
00d0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0
[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D03P35_[D00`11
JN40aKje0<Fn]@030<Fn]@030:f][@36_kL0@FWQ0080@FWQ4`36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j00T0al6j0P11JN490<O1^P030:f][@38`K/0b<6k00<0b<6k0P11JN4?0<S1
^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]G`2`h>H10?oo
o`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35_[D0aKje00l0
aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0@FWQ0<Jo]`02045YhA<0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^P80@FWQ2@37`KX00`2][Jd0b<6k0<S1^`030<S1^`80
@FWQ3`38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0
[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04033_K<90:f][@d0aKje1@11JN430<Jo]`03045Yh@36_kL0a[ng0140a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^P80@FWQ2@37`KX00`2][Jd0b<6k0<S1^`040<S1^`03
045Yh@38`K/0b<6k00P0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00D0[Jf]0<Jo]`36_kL0a[ng045Yh@0C0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01P37`KX5045Yh@T0al6j00<0[Jf]0<S1^`38
`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V
0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h
:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3o
ool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec
0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?oo
o`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V
102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0<0<O1^P0300000037`KX0al6j00D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][Gh0/>3V
0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`h>H10?ooo`00WP2`h>H6
0:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]QP2`h>H1
0?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0080<O1
_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0
al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0[Jf]V@2`h>H10?ooo`00
^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][JfW0;3PiP40oooo
00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`h>H10?ooo`00d@2`h>H<
0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52113 .3309 m
.50943 .33083 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53951 .33078 m
.5345 .33405 L
s
.54285 .33073 m
.53951 .33078 L
s
.50274 .33073 m
.49107 .33047 L
s
.5462 .33387 m
.54285 .33073 L
s
.54786 .33384 m
.54285 .33073 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49606 .33322 m
.49607 .33059 L
s
.49773 .33225 m
.49774 .33063 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56977 .32189 m
.58123 .32135 L
s
.50872 .33853 m
.52031 .33862 L
s
0 0 0 r
.58228 .33704 m
.5828 .33897 L
s
.5837 .33609 m
.58445 .33888 L
s
.255 .412 .882 r
.49875 .35643 m
.4988 .33837 L
s
.49709 .3564 m
.49715 .33833 L
s
.54514 .34065 m
.54844 .33833 L
s
.54844 .33833 m
.5534 .33821 L
s
.54349 .34068 m
.54844 .33833 L
s
.54185 .34522 m
.54349 .34068 L
s
.5435 .34519 m
.54514 .34065 L
s
.5534 .33821 m
.55671 .34037 L
s
.48889 .33812 m
.49384 .34051 L
s
.4856 .33802 m
.48889 .33812 L
s
.49384 .34051 m
.49713 .3451 L
s
.48229 .34016 m
.4856 .33802 L
s
.48065 .3401 m
.4856 .33802 L
s
.54185 .34522 m
.54186 .34974 L
s
.5435 .34519 m
.54351 .34971 L
s
0 0 0 r
.53286 .35982 m
.53119 .36306 L
s
.53454 .36303 m
.53286 .35982 L
s
.255 .412 .882 r
.56493 .33784 m
.56658 .33778 L
s
.56165 .34021 m
.56493 .33784 L
s
.5633 .34015 m
.56493 .33784 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47898 .34455 m
.48229 .34016 L
s
.47733 .34449 m
.48065 .3401 L
s
0 0 0 r
.53119 .36306 m
.53119 .36629 L
s
.53287 .36628 m
.53454 .36303 L
s
.255 .412 .882 r
.54186 .34974 m
.54352 .35423 L
s
.54351 .34971 m
.54518 .3542 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56167 .34472 m
.5633 .34015 L
s
.56002 .34478 m
.56165 .34021 L
s
.55671 .34037 m
.56002 .34478 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49764 .36155 m
.49765 .35906 L
s
.49597 .36253 m
.49598 .359 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47731 .34901 m
.47898 .34455 L
s
.47566 .34894 m
.47733 .34449 L
s
.54352 .35423 m
.5485 .35639 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51532 .37024 m
.51534 .33859 L
s
.51365 .37023 m
.51369 .33858 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56167 .34472 m
.56175 .36056 L
s
.56002 .34478 m
.56012 .36515 L
s
.51533 .35665 m
.51698 .36345 L
s
.5485 .35639 m
.54518 .3542 L
s
.57972 .33945 m
.58298 .33703 L
s
.58298 .33703 m
.58624 .33685 L
s
.57647 .34413 m
.57972 .33945 L
s
.49213 .35628 m
.50372 .35652 L
s
.5485 .35639 m
.55843 .3584 L
s
.58624 .33685 m
.58952 .33892 L
s
.58624 .33685 m
.59115 .33882 L
s
.47562 .35573 m
.47731 .34901 L
s
.47397 .35567 m
.47566 .34894 L
s
.45609 .33667 m
.46238 .36875 L
s
.51698 .36345 m
.5203 .368 L
s
.52695 .36572 m
.52861 .36345 L
s
.52861 .36345 m
.53027 .36571 L
s
.58952 .33892 m
.59282 .34324 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55843 .3584 m
.5601 .36061 L
s
.54355 .36328 m
.54355 .36555 L
s
.54355 .36328 m
.54521 .36325 L
s
.52695 .36572 m
.52861 .36798 L
s
.53027 .36571 m
.53027 .36797 L
s
.59115 .33882 m
.59444 .34314 L
s
.54521 .36325 m
.54521 .36552 L
s
.5203 .368 m
.52363 .37027 L
s
.54355 .36555 m
.54522 .36779 L
s
.52861 .37025 m
.53027 .36797 L
s
.47555 .36707 m
.47562 .35573 L
s
.56012 .36515 m
.56175 .36056 L
s
.47391 .36701 m
.47397 .35567 L
s
.52363 .37027 m
.52861 .37025 L
s
.50867 .37019 m
.51532 .37024 L
s
.54522 .36779 m
.54854 .36999 L
s
.59282 .34324 m
.5945 .34993 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56949 .37514 m
.57142 .37507 L
s
.255 .412 .882 r
.59444 .34314 m
.59613 .34983 L
s
.55847 .36747 m
.56012 .36515 L
s
.54854 .36999 m
.55517 .36983 L
s
.55517 .36983 m
.55847 .36747 L
s
.49866 .38595 m
.4987 .3723 L
s
.49702 .37909 m
.4987 .3723 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44929 .36802 m
.45609 .33667 L
s
.45092 .36812 m
.45603 .34345 L
s
.44309 .33583 m
.44929 .36802 L
s
.4363 .36714 m
.44309 .33583 L
s
.43792 .36726 m
.44303 .34261 L
s
.47555 .36707 m
.47717 .37396 L
s
.5945 .34993 m
.59454 .35447 L
s
.47391 .36701 m
.47552 .37389 L
s
.59613 .34983 m
.59617 .35437 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57659 .36224 m
.57991 .36663 L
s
.57632 .32159 m
.57664 .36906 L
s
.57469 .32167 m
.57499 .36913 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60573 .33558 m
.61699 .33468 L
s
.57005 .36934 m
.57664 .36906 L
s
.49368 .38357 m
.49702 .37909 L
s
.49702 .37909 m
.49866 .38595 L
s
.59297 .36138 m
.59454 .35447 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57991 .36663 m
.58321 .36874 L
s
.5946 .36128 m
.59617 .35437 L
s
.47717 .37396 m
.47879 .37857 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.427 .33456 m
.4286 .33469 L
s
.45746 .3685 m
.46731 .36899 L
s
.47552 .37389 m
.47714 .37851 L
s
.42377 .33654 m
.427 .33456 L
s
.42537 .33668 m
.427 .33456 L
s
.4887 .38572 m
.49368 .38357 L
s
.47879 .37857 m
.48208 .38324 L
s
.58321 .36874 m
.58649 .36857 L
s
.58975 .36612 m
.59297 .36138 L
s
.47714 .37851 m
.48042 .38318 L
s
.59138 .36602 m
.5946 .36128 L
s
.58649 .36857 m
.58975 .36612 L
s
.58649 .36857 m
.59138 .36602 L
s
.48538 .38562 m
.4887 .38572 L
s
.42372 .34108 m
.42537 .33668 L
s
.48208 .38324 m
.48538 .38562 L
s
.48042 .38318 m
.48538 .38562 L
s
.62338 .33411 m
.63449 .33303 L
s
.42212 .34093 m
.42377 .33654 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42352 .35699 m
.42372 .34108 L
s
.41899 .3361 m
.42212 .34093 L
s
.41584 .33353 m
.41899 .3361 L
s
.42187 .36141 m
.42212 .34093 L
s
.41109 .33305 m
.41584 .33353 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43145 .36677 m
.44278 .3676 L
s
.4079 .33499 m
.41109 .33305 L
s
.40633 .33483 m
.41109 .33305 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5997 .38451 m
.59972 .38643 L
s
.60031 .38407 m
.60052 .38637 L
s
.5 Mabswid
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61056 .3352 m
.61108 .383 L
s
.61245 .36004 m
.61572 .36435 L
s
.62974 .33351 m
.63007 .35853 L
s
.62815 .33366 m
.62848 .35868 L
s
.61217 .33508 m
.6127 .38288 L
s
.40626 .33937 m
.4079 .33499 L
s
.42187 .36141 m
.42352 .35699 L
s
.61572 .36435 m
.62057 .36623 L
s
.40469 .3392 m
.40633 .33483 L
s
.64079 .33236 m
.65172 .33111 L
s
.41084 .35125 m
.42035 .35443 L
s
.42035 .35443 m
.42192 .35685 L
s
.4062 .34393 m
.40626 .33937 L
s
.42024 .36355 m
.42187 .36141 L
s
.40462 .34376 m
.40469 .3392 L
s
.62057 .36623 m
.62377 .36596 L
s
.60621 .38334 m
.6127 .38288 L
s
.62694 .36339 m
.62848 .35868 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4062 .34393 m
.40771 .34865 L
s
.40771 .34865 m
.41084 .35125 L
s
.40613 .34848 m
.41084 .35125 L
s
.41702 .36555 m
.42024 .36355 L
s
.62377 .36596 m
.62694 .36339 L
s
.62377 .36596 m
.62854 .36325 L
s
.62854 .36325 m
.63007 .35853 L
s
.40462 .34376 m
.40613 .34848 L
s
.41065 .36495 m
.41702 .36555 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64549 .33184 m
.64597 .36379 L
s
.64705 .33166 m
.64754 .36361 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.406 .35761 m
.40758 .35777 L
s
.40755 .36006 m
.40758 .35777 L
s
.40597 .3599 m
.406 .35761 L
s
.40752 .36234 m
.41065 .36495 L
s
.40597 .3599 m
.40752 .36234 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37389 .32849 m
.38458 .32996 L
s
.64126 .36429 m
.64754 .36361 L
s
.65957 .33698 m
.66257 .33201 L
s
.65814 .34402 m
.65957 .33698 L
s
.66257 .33201 m
.66712 .32911 L
s
.66111 .33678 m
.6641 .33181 L
s
.65969 .34383 m
.66111 .33678 L
s
.37942 .3614 m
.37998 .32935 L
s
.6641 .33181 m
.66712 .32911 L
s
.65814 .34402 m
.65822 .3486 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37789 .3612 m
.37846 .32914 L
s
.66712 .32911 m
.67016 .32868 L
s
.65969 .34383 m
.65976 .3484 L
s
.3919 .35605 m
.39342 .35852 L
s
.39338 .36081 m
.39342 .35852 L
s
.39031 .35816 m
.3919 .35605 L
s
.67016 .32868 m
.67475 .33031 L
s
.39179 .36293 m
.39338 .36081 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65976 .3484 m
.66142 .35508 L
s
.65822 .3486 m
.65988 .35528 L
s
.39031 .35816 m
.39183 .36063 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38713 .36237 m
.39179 .36293 L
s
.64615 .37526 m
.64775 .37739 L
s
.64461 .37772 m
.64615 .37526 L
s
.64461 .37772 m
.64622 .37985 L
s
.65988 .35528 m
.66304 .35948 L
s
.64622 .37985 m
.64775 .37739 L
s
.66142 .35508 m
.66458 .35928 L
s
.67475 .33031 m
.67785 .33444 L
s
.37966 .34763 m
.38108 .35471 L
s
.38408 .35969 m
.38713 .36237 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38108 .35471 m
.38408 .35969 L
s
.66304 .35948 m
.66769 .36118 L
s
.66458 .35928 m
.66769 .36118 L
s
.3733 .36059 m
.37942 .3614 L
s
.36182 .32897 m
.36472 .33402 L
s
.36472 .33402 m
.36613 .33883 L
s
.3574 .32596 m
.36182 .32897 L
s
.66769 .36118 m
.67227 .36056 L
s
.36613 .33883 m
.3675 .34594 L
s
.36033 .32873 m
.36322 .33379 L
s
.36322 .33379 m
.36463 .3386 L
s
.3574 .32596 m
.36033 .32873 L
s
.36463 .3386 m
.366 .34571 L
s
.67514 .35094 m
.67661 .34843 L
s
.67514 .35094 m
.67669 .35302 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67661 .34843 m
.67816 .3505 L
s
.36728 .35743 m
.3675 .34594 L
s
.34277 .32342 m
.3574 .32596 L
s
.68817 .32593 m
.68974 .33028 L
s
.68817 .32593 m
.68836 .33511 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36577 .35722 m
.366 .34571 L
s
.67227 .36056 m
.67527 .35784 L
s
.67816 .3505 m
.6782 .3528 L
s
.67527 .35784 m
.6782 .3528 L
s
.68836 .33511 m
.68974 .33028 L
s
.68974 .33028 m
.69117 .32774 L
s
.36564 .36413 m
.36728 .35743 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69117 .32774 m
.69406 .32494 L
s
.69406 .32494 m
.6999 .32392 L
s
.36413 .36391 m
.36577 .35722 L
s
.36404 .36853 m
.36564 .36413 L
s
.36254 .36831 m
.36413 .36391 L
s
.68864 .34891 m
.69007 .34637 L
s
.68864 .34891 m
.68873 .35352 L
s
.69007 .34637 m
.69298 .34359 L
s
.6999 .32392 m
.70285 .32569 L
s
.68868 .35122 m
.69012 .34868 L
s
.69012 .34868 m
.69303 .34589 L
s
.69298 .34359 m
.7002 .33773 L
s
.68873 .35352 m
.69026 .3556 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35945 .3725 m
.36254 .36831 L
s
.36095 .37272 m
.36404 .36853 L
s
.34607 .37273 m
.34712 .32421 L
s
.34754 .37297 m
.34858 .32447 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70285 .32569 m
.70434 .32773 L
s
.35642 .37437 m
.36095 .37272 L
s
.7002 .33773 m
.70305 .3349 L
s
.70434 .32773 m
.7045 .33464 L
s
.35642 .37437 m
.35945 .3725 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69026 .3556 m
.69327 .35743 L
s
.69303 .34589 m
.70025 .34003 L
s
.70025 .34003 m
.7031 .33721 L
s
.69327 .35743 m
.69915 .35646 L
s
.70305 .3349 m
.70445 .33234 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7031 .33721 m
.7045 .33464 L
s
.34169 .372 m
.35642 .37437 L
s
.69915 .35646 m
.70201 .35365 L
s
.70341 .35108 m
.70476 .34619 L
s
.70476 .34619 m
.70496 .35545 L
s
.70201 .35365 m
.70341 .35108 L
s
.70341 .35108 m
.70496 .35545 L
s
.71428 .3235 m
.71564 .32091 L
s
.71428 .3235 m
.71575 .32553 L
s
.71564 .32091 m
.7171 .32294 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71575 .32553 m
.7171 .32294 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71603 .33709 m
.7181 .36471 L
s
.71527 .36525 m
.71603 .33709 L
s
.71636 .35102 m
.71669 .36498 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71527 .36525 m
.7168 .36965 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7168 .36965 m
.7181 .36471 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26985 .31028 m
.27111 .30831 L
s
.27 .30557 m
.27111 .30831 L
s
.26874 .30754 m
.27 .30557 L
s
.26874 .30754 m
.26985 .31028 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26948 .32208 m
.26979 .35091 L
s
.26741 .35019 m
.26948 .32208 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26859 .35055 m
.26904 .33629 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26844 .35532 m
.26979 .35091 L
s
.25951 .30442 m
.26057 .30718 L
s
.26034 .31429 m
.26057 .30718 L
s
.78594 .302 m
.79691 .29791 L
s
.25734 .30125 m
.25951 .30442 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2592 .3139 m
.26041 .31192 L
s
.25913 .31627 m
.26034 .31429 L
s
.26741 .35019 m
.26844 .35532 L
s
.25292 .29962 m
.25734 .30125 L
s
.25688 .31548 m
.2592 .3139 L
s
.2568 .31786 m
.25913 .31627 L
s
.7893 .30079 m
.79095 .35085 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25866 .33053 m
.25995 .32616 L
s
.25965 .33568 m
.25995 .32616 L
s
.7904 .30039 m
.79206 .35047 L
s
.2512 .31824 m
.25688 .31548 L
s
.25112 .32063 m
.2568 .31786 L
s
.25067 .30117 m
.25292 .29962 L
s
.25745 .33253 m
.25866 .33053 L
s
.25866 .33053 m
.25965 .33568 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25513 .33415 m
.25745 .33253 L
s
.24952 .30313 m
.25067 .30117 L
s
.24861 .29796 m
.24952 .30313 L
s
.24828 .30748 m
.24952 .30313 L
s
.24828 .30748 m
.24861 .29796 L
s
.25072 .33258 m
.25513 .33415 L
s
.79691 .29791 m
.79911 .29944 L
s
.79691 .29791 m
.80016 .29902 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78756 .35198 m
.79862 .34816 L
s
.24895 .31982 m
.2512 .31824 L
s
.24887 .32221 m
.25112 .32063 L
s
.2478 .32181 m
.24895 .31982 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80016 .29902 m
.80241 .30295 L
s
.79911 .29944 m
.80137 .30337 L
s
.24863 .32939 m
.25072 .33258 L
s
.24772 .3242 m
.24887 .32221 L
s
.24764 .32659 m
.2478 .32181 L
s
.24764 .32659 m
.24863 .32939 L
s
.80137 .30337 m
.80257 .30773 L
s
.80241 .30295 m
.8036 .3073 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23919 .2965 m
.24105 .30215 L
s
.23629 .2928 m
.23919 .2965 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8036 .3073 m
.80488 .31407 L
s
.80257 .30773 m
.80385 .31449 L
s
.80385 .31449 m
.80427 .32649 L
s
.79862 .34816 m
.80067 .34496 L
s
.79862 .34816 m
.80172 .34456 L
s
.80488 .31407 m
.8053 .32608 L
s
.80823 .29318 m
.81501 .29006 L
s
.80067 .34496 m
.80261 .33934 L
s
.24038 .32132 m
.24047 .31892 L
s
.23953 .3161 m
.24047 .31892 L
s
.23433 .29191 m
.23629 .2928 L
s
.23818 .3253 m
.24038 .32132 L
s
.23843 .31808 m
.23953 .3161 L
s
.80348 .33412 m
.80427 .32649 L
s
.80172 .34456 m
.80365 .33894 L
s
.80261 .33934 m
.80348 .33412 L
s
.23843 .31808 m
.23936 .3209 L
s
.80452 .33371 m
.8053 .32608 L
s
.80365 .33894 m
.80452 .33371 L
s
.23231 .29342 m
.23433 .29191 L
s
.23136 .29297 m
.23433 .29191 L
s
.81118 .29186 m
.81238 .32555 L
s
.81215 .29141 m
.81335 .32512 L
s
.23609 .32687 m
.23818 .3253 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23024 .29733 m
.23231 .29342 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22929 .29688 m
.23136 .29297 L
s
.23313 .3256 m
.23609 .32687 L
s
.80942 .32682 m
.81335 .32512 L
s
0 0 0 r
.22236 .27877 m
.22257 .27888 L
s
.255 .412 .882 r
.81284 .31064 m
.81406 .31744 L
s
.22903 .30411 m
.23024 .29733 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2281 .30367 m
.22929 .29688 L
s
.23127 .32233 m
.23313 .3256 L
s
.23031 .3219 m
.23313 .3256 L
s
.81406 .31744 m
.81614 .32141 L
s
.22886 .30894 m
.22903 .30411 L
s
.22954 .31663 m
.23127 .32233 L
s
.22886 .30894 m
.22954 .31663 L
s
.22792 .3085 m
.2281 .30367 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22859 .31619 m
.23031 .3219 L
s
0 0 0 r
.826 .28384 m
.82611 .28417 L
s
.255 .412 .882 r
.22792 .3085 m
.22859 .31619 L
s
.21885 .2841 m
.22496 .28738 L
s
.81614 .32141 m
.81811 .32297 L
s
0 0 0 r
.82611 .28417 m
.82674 .27681 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81811 .32297 m
.82088 .32165 L
s
0 0 0 r
.82691 .30822 m
.82702 .30836 L
s
.255 .412 .882 r
.81978 .31724 m
.82079 .31922 L
s
.81978 .31724 m
.82061 .31437 L
s
0 0 0 r
.82704 .31169 m
.82715 .31183 L
s
.255 .412 .882 r
.82061 .31437 m
.8216 .31635 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22104 .31993 m
.2223 .28598 L
s
.22016 .31949 m
.22142 .28552 L
s
.82088 .32165 m
.82169 .31878 L
s
.8216 .31635 m
.82169 .31878 L
s
0 0 0 r
.82702 .30836 m
.82804 .31137 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82692 .29131 m
.82758 .28599 L
s
.82692 .29131 m
.8271 .29617 L
s
.82758 .28599 m
.82997 .28214 L
s
.21757 .31813 m
.22104 .31993 L
s
.8271 .29617 m
.82813 .30056 L
s
.82776 .29084 m
.82841 .28552 L
s
.82776 .29084 m
.82795 .2957 L
s
.82841 .28552 m
.82997 .28214 L
s
.82795 .2957 m
.82897 .3001 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21 .2788 m
.21552 .2822 L
s
.82997 .28214 m
.83238 .28069 L
s
.21952 .33658 m
.22049 .33457 L
s
.2197 .33169 m
.22049 .33457 L
s
.21874 .33369 m
.2197 .33169 L
s
.8285 .3103 m
.82859 .31274 L
s
.21874 .33369 m
.21952 .33658 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82859 .31274 m
.82952 .31473 L
s
.8285 .3103 m
.82933 .30984 L
s
.82897 .3001 m
.83071 .3016 L
s
.82813 .30056 m
.83071 .3016 L
s
.21208 .30758 m
.2131 .28075 L
s
.82933 .30984 m
.82943 .31228 L
s
.83238 .28069 m
.83404 .28215 L
s
.83071 .3016 m
.83557 .30121 L
s
.82952 .31473 m
.83127 .31625 L
s
.21128 .30711 m
.21232 .28026 L
s
.83404 .28215 m
.83577 .28606 L
s
.83127 .31625 m
.83448 .3144 L
s
.2111 .31201 m
.21208 .30758 L
s
.83577 .28606 m
.83634 .28069 L
s
.83577 .28606 m
.83662 .30809 L
s
.83634 .28069 m
.83773 .27726 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21031 .31154 m
.21128 .30711 L
s
.83653 .28557 m
.83708 .28019 L
s
.83653 .28557 m
.83719 .30271 L
s
.83708 .28019 m
.83773 .27726 L
s
.20867 .31306 m
.2111 .31201 L
s
.83557 .30121 m
.83643 .30318 L
s
.83773 .27726 m
.83846 .27676 L
s
.83448 .3144 m
.83595 .31101 L
s
.20867 .31306 m
.21031 .31154 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20212 .27331 m
.20702 .27682 L
s
.83595 .31101 m
.83662 .30809 L
s
.83662 .30809 m
.83719 .30271 L
s
.20715 .31212 m
.20867 .31306 L
s
.20283 .32705 m
.20487 .27532 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84744 .2635 m
.84839 .26277 L
s
.255 .412 .882 r
.20212 .32658 m
.20417 .27482 L
s
.20504 .30823 m
.20715 .31212 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2038 .30234 m
.20504 .30823 L
s
.84125 .31016 m
.84605 .30677 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84467 .27223 m
.84861 .30481 L
s
.84336 .30871 m
.84467 .27223 L
s
.84404 .30823 m
.84497 .27961 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20006 .32517 m
.20283 .32705 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84891 .2927 m
.84894 .29332 L
s
.85021 .32495 m
.85072 .33746 L
s
.84951 .29057 m
.84959 .29266 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19633 .27116 m
.19734 .27712 L
s
.19734 .27712 m
.19766 .28505 L
s
.19746 .28999 m
.19766 .28505 L
s
.19575 .27064 m
.19673 .27661 L
s
.19673 .27661 m
.19704 .28454 L
s
.1947 .26712 m
.19633 .27116 L
s
.19654 .29693 m
.19746 .28999 L
s
.19684 .28949 m
.19704 .28454 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84861 .30481 m
.84961 .2681 L
s
.1947 .26712 m
.19575 .27064 L
s
.19593 .29643 m
.19684 .28949 L
s
.84922 .30432 m
.84991 .27552 L
s
.19513 .3009 m
.19654 .29693 L
s
.1902 .24444 m
.19375 .24824 L
s
.19358 .26607 m
.1947 .26712 L
s
.19454 .3004 m
.19593 .29643 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85081 .32284 m
.8509 .32494 L
s
.5 Mabswid
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84961 .2681 m
.8533 .30082 L
s
.1924 .2675 m
.19358 .26607 L
s
.19328 .30189 m
.19513 .3009 L
s
.19002 .29886 m
.19217 .24662 L
s
.19328 .30189 m
.19454 .3004 L
s
.18951 .29836 m
.19167 .24608 L
s
.19115 .27141 m
.1924 .2675 L
s
.8516 .30233 m
.85491 .29931 L
s
.19216 .30089 m
.19328 .30189 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19118 .29738 m
.19216 .30089 L
s
.19033 .29136 m
.19118 .29738 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18803 .29682 m
.19002 .29886 L
s
.1881 .26022 m
.18855 .26076 L
s
.85648 .27423 m
.85674 .26871 L
s
.85631 .28225 m
.85648 .27423 L
s
.85674 .26871 m
.85745 .26265 L
s
.85631 .28225 m
.85683 .29476 L
s
0 0 0 r
.86212 .24916 m
.86245 .24874 L
s
.255 .412 .882 r
.18712 .26164 m
.1881 .26022 L
s
.18755 .26217 m
.1881 .26022 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85695 .2737 m
.8572 .26817 L
s
.85679 .28172 m
.85695 .2737 L
s
.8572 .26817 m
.85789 .26211 L
s
.85679 .28172 m
.85731 .29425 L
s
.85745 .26265 m
.85864 .25853 L
s
.18691 .26664 m
.18755 .26217 L
s
0 0 0 r
.18284 .25237 m
.1834 .2606 L
s
.1834 .27185 m
.1834 .2606 L
s
.255 .412 .882 r
.85789 .26211 m
.85864 .25853 L
s
.85683 .29476 m
.85762 .30178 L
s
0 0 0 r
.86245 .24874 m
.86343 .25119 L
s
.86245 .24874 m
.86382 .25064 L
s
.255 .412 .882 r
.18648 .2661 m
.18712 .26164 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85731 .29425 m
.85809 .30127 L
s
.85864 .25853 m
.85946 .25744 L
s
.18618 .28419 m
.18691 .26664 L
s
0 0 0 r
.18219 .28923 m
.18301 .27992 L
s
.255 .412 .882 r
.85762 .30178 m
.8583 .30631 L
s
.18587 .26001 m
.18648 .2661 L
s
.18554 .28869 m
.18648 .2661 L
s
0 0 0 r
.18175 .2887 m
.18259 .27908 L
s
.255 .412 .882 r
.85809 .30127 m
.85877 .3058 L
s
.85946 .25744 m
.86072 .25831 L
s
.18519 .25642 m
.18587 .26001 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8583 .30631 m
.85943 .31034 L
s
.18554 .28869 m
.18618 .28419 L
s
.85877 .3058 m
.85988 .30983 L
s
.18409 .25478 m
.18519 .25642 L
s
.18544 .28062 m
.18575 .28366 L
s
0 0 0 r
.86424 .29931 m
.86457 .29892 L
s
.86505 .26372 m
.86535 .26745 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18324 .27491 m
.18544 .28062 L
s
.18502 .29069 m
.18554 .28869 L
s
.86072 .25831 m
.86166 .26225 L
s
.85943 .31034 m
.86085 .31135 L
s
.1841 .29217 m
.18502 .29069 L
s
.85988 .30983 m
.86085 .31135 L
s
.1833 .25619 m
.18409 .25478 L
s
.18297 .25564 m
.18409 .25478 L
s
.86134 .25471 m
.86219 .27484 L
s
.86169 .25416 m
.86254 .27431 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86354 .27726 m
.86464 .2759 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86109 .27645 m
.86352 .27269 L
s
.1826 .29007 m
.1841 .29217 L
s
.86085 .31135 m
.86168 .31033 L
s
.18276 .26068 m
.1833 .25619 L
s
.18266 .27131 m
.18324 .27491 L
s
.18233 .27077 m
.18324 .27491 L
s
.18244 .26013 m
.18297 .25564 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86168 .31033 m
.86274 .30626 L
s
.18254 .26572 m
.18276 .26068 L
s
.18254 .26572 m
.18266 .27131 L
s
.18222 .26518 m
.18244 .26013 L
s
.18202 .28649 m
.1826 .29007 L
s
.18222 .26518 m
.18233 .27077 L
s
.86274 .30626 m
.86325 .30015 L
s
.1819 .28089 m
.18223 .28142 L
s
.18213 .28395 m
.18223 .28142 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86357 .25084 m
.86531 .24693 L
s
.86328 .29202 m
.86393 .30726 L
s
.86325 .30015 m
.86328 .29202 L
s
.18179 .28342 m
.18202 .28649 L
s
.18179 .28342 m
.1819 .28089 L
s
.86325 .30015 m
.86393 .30726 L
s
0 0 0 r
.17586 .23577 m
.17669 .23784 L
s
.255 .412 .882 r
.86437 .24917 m
.86588 .28471 L
s
.86462 .24861 m
.86613 .28417 L
s
0 0 0 r
.1743 .28836 m
.17649 .2375 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86914 .23685 m
.87039 .2328 L
s
.255 .412 .882 r
.86507 .28631 m
.86613 .28417 L
s
.86548 .26889 m
.86605 .27598 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86974 .23512 m
.87147 .27514 L
s
.255 .412 .882 r
.17937 .27605 m
.1795 .27914 L
s
.17939 .28169 m
.1795 .27914 L
s
0 0 0 r
.1743 .28836 m
.1745 .28879 L
s
.255 .412 .882 r
.17904 .2837 m
.17939 .28169 L
s
.17903 .27806 m
.17937 .27605 L
s
.86605 .27598 m
.86672 .28001 L
s
.17846 .24135 m
.17951 .24531 L
s
0 0 0 r
.86992 .23454 m
.87165 .27459 L
s
.255 .412 .882 r
.17903 .27806 m
.17915 .28115 L
s
.17838 .28209 m
.17904 .2837 L
s
0 0 0 r
.17402 .28362 m
.17477 .2774 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17516 .23345 m
.17435 .22938 L
s
.8712 .28554 m
.87139 .28355 L
s
.255 .412 .882 r
.86672 .28001 m
.86724 .28149 L
s
.17809 .27845 m
.17838 .28209 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17732 .27885 m
.17885 .24305 L
s
.17747 .27939 m
.179 .24361 L
s
0 0 0 r
.17402 .28362 m
.17328 .28565 L
s
.87139 .28355 m
.87147 .27514 L
s
.255 .412 .882 r
.86724 .28149 m
.86778 .27987 L
s
.17796 .27225 m
.17809 .27845 L
s
0 0 0 r
.87147 .27514 m
.87197 .28191 L
s
.255 .412 .882 r
.86739 .27528 m
.86767 .2773 L
s
.86739 .27528 m
.86745 .27218 L
s
.17796 .27225 m
.17813 .26402 L
s
0 0 0 r
.87165 .27459 m
.87214 .28137 L
s
.255 .412 .882 r
.86745 .27218 m
.86772 .27419 L
s
0 0 0 r
.87131 .22638 m
.87087 .23048 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87261 .28395 m
.87197 .28191 L
s
.255 .412 .882 r
.86778 .27987 m
.86783 .27676 L
s
.86772 .27419 m
.86783 .27676 L
s
0 0 0 r
.17328 .28565 m
.17295 .28456 L
s
.255 .412 .882 r
.17693 .27722 m
.17747 .27939 L
s
0 0 0 r
.87261 .28395 m
.87214 .28137 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17289 .27134 m
.17463 .23113 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17301 .27189 m
.17475 .23171 L
s
.17295 .28456 m
.17282 .27979 L
s
.17295 .28456 m
.17269 .27924 L
s
.255 .412 .882 r
.86741 .24156 m
.86755 .24724 L
s
.86755 .24724 m
.86777 .25237 L
s
0 0 0 r
.87287 .28286 m
.87261 .28395 L
s
.17282 .27979 m
.17301 .27189 L
s
.255 .412 .882 r
.86747 .24099 m
.86763 .24668 L
s
0 0 0 r
.17269 .27924 m
.17289 .27134 L
s
.255 .412 .882 r
.17709 .25847 m
.17797 .23792 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86746 .23728 m
.86747 .24099 L
s
.86763 .24668 m
.86785 .25181 L
s
.86777 .25237 m
.86807 .25694 L
s
.86741 .24156 m
.86746 .23728 L
s
0 0 0 r
.17411 .22704 m
.17411 .22292 L
s
.255 .412 .882 r
.86785 .25181 m
.86814 .25639 L
s
.17697 .25623 m
.17729 .26014 L
s
0 0 0 r
.87304 .27753 m
.87287 .28286 L
s
.255 .412 .882 r
.17705 .25791 m
.17793 .23735 L
s
.86807 .25694 m
.86835 .25784 L
s
.86746 .23728 m
.86753 .23556 L
s
.86814 .25639 m
.86835 .25784 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1776 .24505 m
.17776 .23877 L
s
.86851 .26724 m
.86862 .26981 L
s
.86851 .26724 m
.86858 .26668 L
s
0 0 0 r
.87288 .26905 m
.87304 .27753 L
s
.1718 .27688 m
.17405 .22528 L
s
.255 .412 .882 r
.86862 .26981 m
.8688 .27184 L
s
.17786 .23448 m
.17776 .23877 L
s
.86858 .26668 m
.86869 .26926 L
s
.86753 .23556 m
.86763 .23699 L
s
0 0 0 r
.1718 .27632 m
.17405 .22469 L
s
.255 .412 .882 r
.86835 .25784 m
.8685 .25707 L
s
0 0 0 r
.87094 .2199 m
.87133 .22403 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8688 .27184 m
.86901 .27333 L
s
0 0 0 r
.87112 .22872 m
.87336 .28012 L
s
.87119 .22814 m
.87342 .27957 L
s
.87355 .27791 m
.87336 .28012 L
s
.255 .412 .882 r
.17791 .23333 m
.17786 .23448 L
s
.17565 .29208 m
.17632 .27653 L
s
.17594 .28376 m
.17632 .27653 L
s
.86763 .23699 m
.8678 .241 L
s
.86901 .27333 m
.86909 .27114 L
s
.17789 .23476 m
.17791 .23333 L
s
.17795 .23419 m
.17791 .23333 L
s
0 0 0 r
.87123 .22226 m
.87348 .27404 L
s
.17187 .27853 m
.1718 .27632 L
s
.255 .412 .882 r
.17594 .28376 m
.17565 .28787 L
s
.17565 .29208 m
.17594 .28376 L
s
0 0 0 r
.87117 .22167 m
.87343 .27349 L
s
.255 .412 .882 r
.86754 .23527 m
.8678 .241 L
s
.8678 .241 m
.86881 .26429 L
s
.86732 .23154 m
.86754 .23527 L
s
.86749 .23469 m
.86776 .24043 L
s
.86776 .24043 m
.86854 .25855 L
s
.1778 .23879 m
.17789 .23476 L
s
.86732 .23154 m
.86749 .23469 L
s
.8685 .25707 m
.86858 .2591 L
s
.86724 .23096 m
.86732 .23154 L
s
.86895 .26744 m
.86909 .27114 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17788 .23821 m
.17795 .23419 L
s
.17565 .28787 m
.17553 .28886 L
s
.86881 .26429 m
.86895 .26744 L
s
.86854 .25855 m
.86881 .26429 L
s
.17766 .2434 m
.1778 .23879 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17776 .24283 m
.17788 .23821 L
s
0 0 0 r
.17084 .29973 m
.17099 .29547 L
s
.17067 .30293 m
.17084 .29973 L
s
.17099 .29547 m
.17083 .29866 L
s
.255 .412 .882 r
.17553 .28886 m
.17557 .28779 L
s
.17742 .25062 m
.17766 .2434 L
s
0 0 0 r
.1746 .22189 m
.17518 .21642 L
s
.17416 .22987 m
.1746 .22189 L
s
.17083 .29866 m
.17067 .30293 L
s
.17238 .27078 m
.17416 .22987 L
s
.255 .412 .882 r
.17753 .25005 m
.17776 .24283 L
s
0 0 0 r
.86925 .21338 m
.87048 .21753 L
s
.17473 .2213 m
.17518 .21642 L
s
.17428 .22929 m
.17473 .2213 L
s
.8732 .27182 m
.87348 .27404 L
s
.255 .412 .882 r
.17557 .28779 m
.17577 .2841 L
s
.17557 .28779 m
.17583 .28355 L
s
0 0 0 r
.1725 .27022 m
.17428 .22929 L
s
.255 .412 .882 r
.17686 .26364 m
.17742 .25062 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86532 .20761 m
.86629 .21174 L
s
0 0 0 r
.17518 .21642 m
.17552 .21523 L
s
.255 .412 .882 r
.17697 .26308 m
.17753 .25005 L
s
.17577 .2841 m
.17613 .27779 L
s
.86638 .22894 m
.86691 .23528 L
s
0 0 0 r
.87002 .21575 m
.8718 .25669 L
s
.255 .412 .882 r
.17643 .27201 m
.17686 .26364 L
s
.17583 .28355 m
.17621 .27724 L
s
.17613 .27779 m
.17643 .27201 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17209 .27245 m
.1725 .27022 L
s
.255 .412 .882 r
.86814 .26396 m
.86863 .26618 L
s
0 0 0 r
.17552 .21523 m
.17595 .21717 L
s
.86985 .21516 m
.87162 .25612 L
s
.255 .412 .882 r
.86591 .22518 m
.86638 .22894 L
s
.17653 .27147 m
.17697 .26308 L
s
0 0 0 r
.87446 .29644 m
.87457 .29965 L
s
.87424 .29216 m
.87446 .29644 L
s
.255 .412 .882 r
.17621 .27724 m
.17653 .27147 L
s
0 0 0 r
.87434 .29536 m
.87424 .29216 L
s
.87457 .29965 m
.87434 .29536 L
s
.255 .412 .882 r
.86772 .26024 m
.8678 .25612 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86594 .20997 m
.866 .21148 L
s
.86731 .2419 m
.86828 .26452 L
s
.8658 .20938 m
.86588 .21128 L
s
.86717 .24132 m
.86814 .26396 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17595 .21717 m
.17608 .22343 L
s
.17656 .21227 m
.17759 .20989 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17429 .26465 m
.17656 .21227 L
s
.255 .412 .882 r
.86748 .26175 m
.86772 .26024 L
s
0 0 0 r
.87195 .26362 m
.8718 .25669 L
s
.17454 .26409 m
.1768 .21167 L
s
.87162 .25612 m
.87176 .26306 L
s
.87152 .2657 m
.87195 .26362 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86621 .20685 m
.8683 .21101 L
s
.87152 .2657 m
.87176 .26306 L
s
.17364 .26632 m
.17454 .26409 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87106 .26458 m
.87152 .2657 L
s
.87014 .25914 m
.87106 .26458 L
s
.17914 .20692 m
.17916 .21382 L
s
.17849 .22191 m
.17914 .20692 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86925 .25047 m
.87014 .25914 L
s
.17849 .22191 m
.17916 .21382 L
s
.17916 .21382 m
.17968 .20949 L
s
.17968 .20949 m
.18058 .20455 L
s
.18058 .20455 m
.1822 .20219 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86717 .20863 m
.87058 .2878 L
s
.86747 .20922 m
.87088 .28834 L
s
.17752 .2445 m
.17803 .24016 L
s
.1772 .25206 m
.17752 .2445 L
s
.17803 .24016 m
.17891 .23524 L
s
.17736 .24828 m
.17787 .24393 L
s
.17787 .24393 m
.17875 .23902 L
s
.1772 .25206 m
.17738 .25528 L
s
.1822 .20219 m
.18292 .20477 L
s
.86329 .20588 m
.86445 .21458 L
s
.17891 .23524 m
.18124 .22481 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17875 .23902 m
.18108 .2286 L
s
.86179 .20034 m
.86329 .20588 L
s
.17738 .25528 m
.17794 .25796 L
s
.86962 .28618 m
.87088 .28834 L
s
.255 .412 .882 r
.18668 .21336 m
.18702 .21401 L
s
0 0 0 r
.18292 .20477 m
.18322 .20796 L
s
.255 .412 .882 r
.1866 .21524 m
.1868 .2193 L
s
0 0 0 r
.86084 .19916 m
.86179 .20034 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18124 .22481 m
.18228 .21988 L
s
.255 .412 .882 r
.18702 .21401 m
.18726 .21873 L
s
0 0 0 r
.17794 .25796 m
.17952 .25573 L
s
.18274 .2193 m
.18322 .20796 L
s
.18108 .2286 m
.18212 .22366 L
s
.86558 .24103 m
.86574 .24482 L
s
.86501 .23667 m
.86558 .24103 L
s
.86474 .2399 m
.86501 .23667 L
s
.86 .20176 m
.86084 .19916 L
s
.85949 .20118 m
.86084 .19916 L
s
.86523 .2513 m
.86574 .24482 L
s
.18228 .21988 m
.1829 .21551 L
s
.18212 .22366 m
.18274 .2193 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18626 .24264 m
.1867 .23209 L
s
.18602 .23788 m
.18625 .23247 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86474 .2399 m
.86533 .24426 L
s
.85928 .20817 m
.86 .20176 L
s
.255 .412 .882 r
.18626 .24264 m
.18602 .23788 L
s
0 0 0 r
.17952 .25573 m
.18054 .25081 L
s
.86451 .254 m
.86523 .2513 L
s
.85874 .20759 m
.85949 .20118 L
s
.255 .412 .882 r
.18648 .23732 m
.18707 .2341 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8566 .22808 m
.857 .23769 L
s
.85713 .22936 m
.8575 .23824 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18054 .25081 m
.18115 .24644 L
s
.18115 .24644 m
.18193 .23827 L
s
.18128 .25351 m
.18193 .23827 L
s
.18115 .24644 m
.18128 .25351 L
s
.255 .412 .882 r
.18662 .24476 m
.18626 .24264 L
s
0 0 0 r
.1869 .20008 m
.18761 .19571 L
s
.1869 .20008 m
.18729 .20329 L
s
.255 .412 .882 r
.85822 .24414 m
.85837 .24465 L
s
.85773 .24358 m
.8584 .24545 L
s
0 0 0 r
.18761 .19571 m
.18801 .19891 L
s
.85922 .219 m
.85928 .20817 L
s
.86309 .25234 m
.86451 .254 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85867 .21843 m
.85874 .20759 L
s
.18729 .20329 m
.18801 .19891 L
s
.255 .412 .882 r
.8575 .23824 m
.85822 .24414 L
s
.857 .23769 m
.85773 .24358 L
s
0 0 0 r
.86193 .2474 m
.86309 .25234 L
s
.86141 .24685 m
.86309 .25234 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85867 .21843 m
.85899 .22605 L
s
.85922 .219 m
.85954 .22662 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85954 .22662 m
.86056 .23864 L
s
.86056 .23864 m
.86193 .2474 L
s
.85899 .22605 m
.86002 .23808 L
s
.86002 .23808 m
.86141 .24685 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18512 .26779 m
.18649 .22231 L
s
.18401 .26886 m
.18649 .22231 L
s
.18456 .26833 m
.18553 .24525 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84583 .18519 m
.8509 .18922 L
s
.18401 .26886 m
.18424 .27605 L
s
.85591 .23418 m
.85669 .23857 L
s
.85669 .23857 m
.85685 .24242 L
s
.85544 .23747 m
.85591 .23418 L
s
.18424 .27605 m
.18512 .26779 L
s
.85639 .24572 m
.85685 .24242 L
s
.84879 .18749 m
.851 .24136 L
s
.85544 .23747 m
.85623 .24187 L
s
.84807 .18691 m
.85027 .24082 L
s
.85446 .24408 m
.85639 .24572 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85295 .23913 m
.85446 .24408 L
s
.85005 .21818 m
.85124 .23031 L
s
.85124 .23031 m
.85295 .23913 L
s
.83935 .18064 m
.84428 .18404 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84802 .2392 m
.851 .24136 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8375 .22732 m
.83823 .22888 L
s
.83622 .21591 m
.83718 .21916 L
s
.83643 .22135 m
.83718 .21916 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83304 .19945 m
.84112 .20436 L
s
.82825 .17395 m
.834 .17727 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83949 .24901 m
.84187 .18234 L
s
.83995 .2608 m
.84268 .1829 L
s
.5 Mabswid
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83021 .17505 m
.83995 .2608 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33035 .13661 m
.36011 .13126 L
s
.255 .412 .882 r
.72223 .18186 m
.72343 .17543 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33376 .22129 m
.33578 .13554 L
s
.3356 .22097 m
.33761 .13519 L
s
.35819 .13156 m
.35961 .15567 L
s
.35961 .15567 m
.36011 .13126 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33656 .17989 m
.34774 .17796 L
s
.34738 .19437 m
.3481 .16161 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37956 .13243 m
.38561 .12756 L
s
.37743 .14086 m
.37956 .13243 L
s
.255 .412 .882 r
.36847 .17279 m
.36977 .16731 L
s
0 0 0 r
.38155 .13216 m
.38561 .12756 L
s
.37941 .14059 m
.38155 .13216 L
s
.38561 .12756 m
.38963 .12705 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32827 .22226 m
.35834 .21739 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38963 .12705 m
.39563 .13039 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3766 .186 m
.37743 .14086 L
s
.3786 .18574 m
.37941 .14059 L
s
.39563 .13039 m
.39958 .13809 L
s
.39977 .12583 m
.40799 .12493 L
s
.39888 .18337 m
.39977 .12583 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40094 .18315 m
.40182 .1256 L
s
.63839 .12503 m
.64051 .12934 L
s
.63639 .1289 m
.63839 .12503 L
s
.63851 .13321 m
.64051 .12934 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35641 .21767 m
.35885 .19259 L
s
.35834 .21739 m
.35885 .19259 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63639 .1289 m
.63851 .13321 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37065 .18679 m
.3786 .18574 L
s
.42459 .1274 m
.43097 .12276 L
s
.42029 .13597 m
.42459 .1274 L
s
.60696 .12217 m
.61544 .12285 L
s
.61544 .12285 m
.6197 .1273 L
s
.4267 .12722 m
.43097 .12276 L
s
.43097 .12276 m
.4352 .12242 L
s
.6197 .1273 m
.62185 .13159 L
s
.42239 .13578 m
.4267 .12722 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62185 .13159 m
.62201 .1439 L
s
.4352 .12242 m
.43941 .12619 L
s
.41804 .14849 m
.42029 .13597 L
s
.60274 .12596 m
.60696 .12217 L
s
.42013 .1483 m
.42239 .13578 L
s
.44371 .12179 m
.45228 .12121 L
s
.43941 .12619 m
.44359 .13409 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6199 .14372 m
.62195 .13979 L
s
.59842 .12156 m
.60064 .12991 L
s
.60064 .12991 m
.60274 .12596 L
s
.41793 .15672 m
.41804 .14849 L
s
.61995 .14783 m
.62201 .1439 L
s
.42003 .15653 m
.42013 .1483 L
s
.61572 .14748 m
.6199 .14372 L
s
.57903 .12042 m
.58768 .12089 L
s
.61577 .1516 m
.61995 .14783 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41793 .15672 m
.41987 .16892 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59858 .13798 m
.60064 .12991 L
s
.59842 .12156 m
.59858 .13798 L
s
.39273 .18404 m
.40094 .18315 L
s
.60517 .15491 m
.61572 .14748 L
s
.42003 .15653 m
.42197 .16874 L
s
.47171 .12427 m
.47609 .11998 L
s
.47609 .11998 m
.48045 .11981 L
s
.46954 .12437 m
.47609 .11998 L
s
.56817 .11994 m
.57472 .12432 L
s
.56381 .11977 m
.56817 .11994 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43073 .16332 m
.43076 .16068 L
s
.42866 .16216 m
.42867 .1608 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48045 .11981 m
.48479 .12377 L
s
.48045 .11981 m
.48698 .1237 L
s
.46514 .13281 m
.46954 .12437 L
s
.55946 .12373 m
.56381 .11977 L
s
.55727 .12366 m
.56381 .11977 L
s
.57472 .12432 m
.57912 .13275 L
s
.46731 .1327 m
.47171 .12427 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60521 .15905 m
.61577 .1516 L
s
.48479 .12377 m
.48913 .13186 L
s
.50453 .11918 m
.51772 .11904 L
s
.5573 .13189 m
.55946 .12373 L
s
.52652 .11904 m
.53971 .11916 L
s
.48698 .1237 m
.49133 .1318 L
s
.46288 .14528 m
.46514 .13281 L
s
.55511 .13183 m
.55727 .12366 L
s
.46505 .14517 m
.46731 .1327 L
s
.62025 .1726 m
.62226 .16451 L
s
.62226 .16451 m
.62247 .18107 L
s
.255 .412 .882 r
.49491 .161 m
.49492 .15746 L
s
0 0 0 r
.41987 .16892 m
.42398 .17684 L
s
.42197 .16874 m
.4261 .17666 L
s
.60093 .15875 m
.60517 .15491 L
s
.48913 .13186 m
.49128 .14417 L
s
.49133 .1318 m
.49347 .14412 L
s
.60097 .16289 m
.60521 .15905 L
s
.46282 .15354 m
.46288 .14528 L
s
.46499 .15343 m
.46505 .14517 L
s
.61819 .17658 m
.62025 .1726 L
s
.62025 .1726 m
.62247 .18107 L
s
.59882 .16275 m
.60093 .15875 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63917 .17847 m
.63954 .20338 L
s
.63745 .20318 m
.63881 .15372 L
s
.63881 .15372 m
.64161 .20359 L
s
.255 .412 .882 r
.5537 .16398 m
.55466 .16012 L
s
0 0 0 r
.42398 .17684 m
.4303 .18048 L
s
.4261 .17666 m
.4303 .18048 L
s
.59886 .16689 m
.60097 .16289 L
s
.61398 .18039 m
.61819 .17658 L
s
.255 .412 .882 r
.49926 .158 m
.50164 .15744 L
s
0 0 0 r
.46282 .15354 m
.4649 .16586 L
s
.46499 .15343 m
.46708 .16576 L
s
.255 .412 .882 r
.49708 .16095 m
.49926 .158 L
s
0 0 0 r
.43889 .17569 m
.44326 .16711 L
s
.49124 .15245 m
.49128 .14417 L
s
.49344 .15239 m
.49347 .14412 L
s
.63966 .21172 m
.64161 .20359 L
s
.4303 .18048 m
.43456 .18015 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49491 .161 m
.49528 .16198 L
s
.49707 .16306 m
.49709 .15746 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50893 .11911 m
.53541 .17703 L
s
.51104 .17702 m
.53532 .1191 L
s
.50883 .17704 m
.53312 .11908 L
s
.43456 .18015 m
.43889 .17569 L
s
.63745 .20318 m
.63966 .21172 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60543 .17977 m
.61398 .18039 L
s
.59882 .16275 m
.5989 .17104 L
s
.55511 .13183 m
.5553 .17739 L
s
.5573 .13189 m
.5575 .17745 L
s
.57903 .12042 m
.57944 .17827 L
s
.5812 .12053 m
.58163 .17838 L
s
.5989 .17104 m
.60109 .17533 L
s
.48899 .16495 m
.49124 .15245 L
s
.60109 .17533 m
.60543 .17977 L
s
.4912 .16489 m
.49344 .15239 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44285 .20876 m
.44371 .12179 L
s
.44501 .20862 m
.44585 .12164 L
s
.4649 .16586 m
.4692 .17397 L
s
.46708 .16576 m
.47139 .17387 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48456 .17339 m
.48899 .16495 L
s
.48676 .17332 m
.4912 .16489 L
s
.4692 .17397 m
.47575 .17786 L
s
.47139 .17387 m
.47575 .17786 L
s
.57288 .17799 m
.58163 .17838 L
s
.48014 .1777 m
.48456 .17339 L
s
.48014 .1777 m
.48676 .17332 L
s
.47575 .17786 m
.48014 .1777 L
s
.54868 .17724 m
.5575 .17745 L
s
.5044 .1771 m
.51769 .17697 L
s
.52655 .17697 m
.53983 .17708 L
s
.43638 .20919 m
.44501 .20862 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ001@3o
YQ08000000<0ojH@200000040?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/
UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00P0ojHA0P00000:
0?nV4@040:f][@0000000000000000d0[Jf]00<000000:f][@2][Jd02@2][Jd00`000000[Jf]0000
000=0:f][@<00000102][Jd6000000/0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3o
ool007l0/>3V0`2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ400000008000000`3oYQ43000000/0[Jf]0P000003
0?nV4@80000000<0ojHA0:f][@3oYQ002@3oYQ000`000000ojH@0?nV40070?nV40030000003oYQ00
000000L0ojH@00<0[Jf]0?nU403oYA000P3oYA02000000<0ojD@0P0000020?nU40800000202][Jd0
10000000[Jf]0:f][@2][Jd5000000<0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd9
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0?
0?nV4@8000001@3oYQ440:f][@8000000`2][Jd00`000000[Jf]0:f][@02000000/0ojHA0P000005
0?nV4@<000002P3oYQ000`000000ojH@0?nV40070?nV40030000003oYQ00000000L0ojH@00@0[Jf]
0?nU403oYA00ojD@0P0000060?nU40040000003oYA000000000000P0ojD@00@000000?nU403oYA00
00000`3oYA001@2][Jd0oj<@000000000000oj<@00P0[Jf]00<000000?nS403oXa00303oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f]
[FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@070?nV4@030000003oYQ40ojHA0080ojHA0`0000070:f][@80
ojHA0`0000050?nV4@040000003oYQ400000000000X0ojHA0P0000070?nV4@8000002`3oYQ000`00
0000ojH@0?nV40050?nV40030000003oYQ00000000P0ojH@00H0[Jf]0?nU403oYA0000000?nU4000
00060?nU40040000003oYA000000000000P0ojD@00<000000?nU40000000103oYA001@2][Jd0oj<@
0?nS403oXa00000000L0oj<@0P00000:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]
3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ430:f][@80000000<0[Jf]0000000000000P2][Jd2000000X0ojHA0P0000000`2][Jd0ojHA
0?nV4@030?nV4@040000003oYQ400000000000X0ojHA0P0000070?nV4@030000002][Jd0000000X0
ojH@00<000000?nV403oYQ001@3oYQ000`000000ojH@000000080?nV40030:f][@3oYA00ojD@0080
0000203oYA03000000P0ojD@0P0000050?nU40050:f][@3oXa00oj<@0?nS400000001`3oXa000`00
0000oj<@000000090?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA0100ojHA0`0000020?nV4@L0[Jf]00<0ojHA0000000000001@3oYQ4010000000
ojHA0000000000090?nV4@040000003oYQ4000000:f][@H0ojHA0`0000090?nV4@8000002@3oYQ42
000000/0ojH@00<000000?nV403oYQ00103oYQ02000000T0ojH@00D0[Jf]0?nU40000000ojD@0000
00080?nU40<00000203oYA02000000D0ojD@00<0[Jf]0?nS403oXa000P3oXa000`000000oj<@0?nS
40040?nS408000003P3oXa000`2][Jd0o:0@0?bP40060:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0<0?nV4@@0000000<0[Jf]0000000000000P2][Jd2
0?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000060?nV4@040000003oYQ400000000000T0ojHA0P00
00000`3oYQ40[Jf]0?nV4@050?nV4@<000002@3oYQ42000000T0ojHA00<0[Jf]0000000000002P3o
YQ000`000000ojH@0?nV40030?nV40030000003oYQ00000000T0ojH@00D0[Jf]0?nU40000000ojD@
000000090?nU40800000203oYA02000000D0ojD@00<0[Jf]0?nS403oXa000P3oXa000`000000oj<@
0?nS40050?nS40030000003oXa00oj<@00`0oj<@00<0[Jf]0?bP403lX1001P3lX1050:f][@d0o:0@
00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]
G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA1@0000040:f][@030?nV4@000000000000@0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ42000000L0ojHA0`0000080?nV4@050000003oYQ4000000?nV4@2][Jd0
1`3oYQ42000000T0ojHA0P0000090?nV4@030:f][@000000000000/0ojH@00<000000?nV403oYQ00
0P3oYQ02000000X0ojH@00D0[Jf]0?nU40000000ojD@000000090?nU40800000203oYA000`000000
ojD@0?nU40040?nU40030:f][@3oXa00oj<@0080oj<@00<000000?nS403oXa00503oXa000`2][Jd0
o:0@0?bP400;0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@040?nV4@@00000
0`2][Jd60?nV4@800000103oYQ40102][Jd0ojHA0?nV4@3oYQ42000000P0ojHA0`0000080?nV4@80
00000P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002@3oYQ42000000T0ojHA00<0[Jf]00000000
00002`3oYQ001`000000ojH@0?nV403oYQ0000000?nV400000002P3oYQ001@2][Jd0ojD@0000003o
YA00000000T0ojD@0P0000080?nU40030000003oYA00ojD@00@0ojD@00<0[Jf]0?nS403oXa000P3o
Xa000`000000oj<@0?nS400D0?nS40030:f][@3lX100o:0@0100o:0@1P2][Jd20?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]F@2`
h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@050:f][@030?nV4@000000000000T0ojHA0P000004
0?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ42000000P0ojHA0P0000020?nV4@030:f][@3o
YQ40ojHA00D0ojHA0P0000080?nV4@8000002P3oYQ400`2][Jd000000000000<0?nV40060000003o
YQ00ojH@0000003oYQ0000002P3oYQ001@2][Jd0ojD@0000003oYA00000000T0ojD@0P0000080?nU
40030000003oYA00ojD@00@0ojD@00<0[Jf]0?nS403oXa000P3oXa000`000000oj<@0?nS400D0?nS
40030:f][@3lX100o:0@01H0o:0@102][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1440:f][@H0ojHA0P0000090?nV4@800000103oYQ40102][Jd0
ojHA0?nV4@3oYQ42000000T0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@050?nV
4@800000203oYQ42000000X0ojHA00@0[Jf]0?nV4000000000002`3oYQ001@000000ojH@0000003o
YQ00000000/0ojH@00D0[Jf]0?nU40000000ojD@000000090?nU408000003`3oYA000`2][Jd0oj<@
0?nS40020?nS40030000003oXa00oj<@01@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0:f][@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]
E@2`h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ401`3oYQ42000000T0ojHA0P0000040?nV4@040:f][@3o
YQ40ojHA0?nV4@8000002@3oYQ42000000L0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00H0ojHA
0P0000080?nV4@8000002P3oYQ40102][Jd0ojH@00000000000<0?nV4080000000<0ojH@0000003o
YQ002P3oYQ001@2][Jd0ojD@0000003oYA00000000T0ojD@0P00000?0?nU40040:f][@3oXa00oj<@
0?nS408000005P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool0
06P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f]
[@D0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000T0ojHA0P0000040?nV4@040:f][@3oYQ40ojHA
0?nV4@8000002@3oYQ42000000L0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00H0ojHA0P000008
0?nV4@8000002P3oYQ40102][Jd0ojH@00000000000<0?nV40<00000303oYQ001@2][Jd0ojD@0000
003oYA00000000T0ojD@0P00000?0?nU40040:f][@3oXa00oj<@0?nS408000005P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00L0mY`?102][Jd90?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]
2@3oY1400`2][Jd0ojHA0?nV4@060?nV4@8000002P3oYQ400`000000ojHA0?nV4@020?nV4@040:f]
[@3oYQ40ojHA0?nV4@8000002@3oYQ42000000L0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00H0
ojHA0P0000080?nV4@8000002P3oYQ40102][Jd0ojH@00000000000<0?nV40<00000303oYQ001@2]
[Jd0ojD@0000003oYA00000000T0ojD@0P00000?0?nU40030:f][@3oXa000000008000005`3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV
4@3oYQ401P3oYQ42000000X0ojHA00<000000?nV4@3oYQ400P3oYQ40102][Jd0ojHA0?nV4@3oYQ42
000000T0ojHA0P0000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000001`3oYQ40
0`000000ojHA0000000:0?nV4@040:f][@3oYQ000000000000`0ojH@0P00000=0?nV40050:f][@3o
YA0000000?nU400000002@3oYA02000000l0ojD@0P0000020?nS40030000003oXa00oj<@01H0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh0
4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0
[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3o
Y1400`2][Jd0ojHA0?nV4@060?nV4@8000002P3oYQ400`000000ojHA0?nV4@020?nV4@040:f][@3o
YQ40ojHA0?nV4@8000002@3oYQ42000000L0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00H0ojHA
0P0000070?nV4@030000003oYQ40000000X0ojHA00@0[Jf]0?nV4000000000002`3oYQ0010000000
ojH@00000000000<0?nV40050:f][@3oYA0000000?nU400000002P3oYA02000000d0ojD@00D00000
0:f][@3oXa00oj<@0000000I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l30:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo
001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A
00<0[Jf]0?nV4@3oYQ401P3oYQ42000000X0ojHA00<000000?nV4@3oYQ400P3oYQ40102][Jd0ojHA
0?nV4@3oYQ42000000T0ojHA0P0000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@060?nV4@80
00001`3oYQ400`000000ojHA0000000:0?nV4@040:f][@3oYQ000000000000/0ojH@0P0000000`3o
YQ0000000?nV400;0?nV40050:f][@3oYA0000000?nU400000002P3oYA02000000/0ojD@0P000000
103oYA00[Jf]0?nS4000000J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue
2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f]
[@3lX100o:0@00`0o:0@0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA00H0ojHA
0P00000:0?nV4@030000003oYQ40ojHA0080ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000090?nV4@80
00001`3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000000L0ojHA00<000000?nV4@00
00002P3oYQ40102][Jd0ojH@00000000000;0?nV408000000P3oYQ000`000000ojH@0?nV40090?nV
40050:f][@3oYA0000000?nU400000002P3oYA02000000X0ojD@00@000000?nU403oYA00ojD@0P00
000;0?nS40030000003oXa00oj<@00d0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3oY140
oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000X0ojHA00<000000?nV4@3oYQ400P3oYQ40
102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA0P0000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV
4@060?nV4@800000203oYQ42000000<0ojHA2@2][Jd2000000X0[Jf]0P0000030:f][@030000002]
[Jd0[Jf]00`0[Jf]0P0000030:f][@L0ojD@0P0000090?nU40030000003oYA00ojD@0080000000<0
[Jf]0?nS403oXa002P3oXa000`000000oj<@0?nS400=0?nS40030:f][@3lX100o:0@01L0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H0
0`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX102
0:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@070?nV4@8000003`3oYQ40
102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA0P0000070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV
4@050?nV4@030:f][@000000000000P0[Jf]0P0000030:f][@L0ojHA00<0[Jf]0000000000002`3o
YQ02000000@0ojH@00<000000?nV403oYQ00203oYQ000`2][Jd0ojD@0?nU4002000000<0ojD@1`2]
[Jd2000000L0[Jf]00<0ojD@0000003oYA000P0000020?nU40030:f][@3oXa00oj<@00X0oj<@00<0
00000?nS403oXa003@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ42000000l0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P00
00090?nV4@8000001`3oYQ42000000X0[Jf]00<0ojHA000000000000203oYQ400`000000ojHA0000
00090?nV4@040:f][@0000000000045Yh@T0ojH@00<000000?nV40000000103oYQ000`000000ojH@
0?nV40080?nV40030:f][@3oYA00ojD@008000002P3oYA02000000L0ojD@00<000000:f][@000000
2@2][Jd80?nS40030000003oXa00oj<@00d0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3C
Q`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@070?nV4@800000103oYQ400`000000ojHA
0?nV4@080?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ42000000L0[Jf]0P0000020?nV4@03
0:f][@11JN40ojHA00H0ojHA0P0000080?nV4@030000003oYQ40000000T0ojHA00D0[Jf]00000000
0000ojH@045Yh@080?nV408000001P3oYQ000`000000ojH@0?nV40070?nV40030:f][@3oYA00ojD@
008000002P3oYA02000000L0ojD@0P0000050?nU40030:f][@3oXa00oj<@0080oj<@202][Jd00`00
0000[Jf]0?nS400=0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@070?nV4@800000103oYQ400`000000ojHA0?nV4@080?nV4@040:f][@3oYQ40ojHA
0?nV4@8000002@2][Jd2000000P0ojHA0P0000000`3oYQ40[Jf]0?nV4@070?nV4@8000002@3oYQ42
000000T0ojHA00<0[Jf]0000000000002@3oYQ000`000000ojH@000000060?nV40030000003oYQ00
ojH@00L0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU408000001`3oYA000`000000ojD@0?nU4004
0?nU40030:f][@3oXa00oj<@0080oj<@00<000000?nS403oXa001@3oXa000`000000oj<@0:f][@09
0:f][@@0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00l0k9H>0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3P
iP80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA00L0ojHA0P0000040?nV4@030000003oYQ40ojHA00H0ojHA1P2][Jd20000
00T0ojHA0P0000080?nV4@80000000<0ojHA0:f][@3oYQ401`3oYQ42000000T0ojHA0P0000090?nV
4@8000002P3oYQ02000000P0ojH@00<000000?nV403oYQ001P3oYQ000`2][Jd0ojD@0?nU40020000
00X0ojD@0P0000070?nU40030000003oYA00ojD@00@0ojD@00<0[Jf]0?nS403oXa000P3oXa000`00
0000oj<@0?nS40050?nS40030000003oXa00oj<@00T0oj<@202][JdF0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f]
[DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`2][JdA0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ42000000@0ojHA00<000000?nV4@3o
YQ401P2][Jd20?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ42000000P0ojHA0P0000000`3o
YQ40[Jf]0?nV4@070?nV4@8000002@3oYQ42000000P0ojHA0P00000;0?nV40800000203oYQ000`00
0000ojH@0?nV40060?nV40030:f][@3oYA00ojD@008000002P3oYA02000000L0ojD@00<000000?nU
403oYA00103oYA00102][Jd0oj<@0?nS403oXa02000000L0oj<@00<000000?nS403oXa003@3oXa00
102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28
EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH4007
0>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ401`3oYQ4200000080ojHA0P2][Jd00`000000[Jf]0:f][@080?nV4@040:f][@3oYQ40
ojHA0?nV4@8000002@3oYQ42000000P0ojHA0P0000000`3oYQ40[Jf]0?nV4@060?nV4@<000002P3o
YQ42000000L0ojHA0P00000:0?nV408000002P3oYQ000`000000ojH@0?nV40050?nV40030:f][@3o
YA00ojD@008000002P3oYA02000000L0ojD@00<000000?nU403oYA00103oYA00102][Jd0oj<@0?nS
403oXa02000000L0oj<@00<000000?nS403oXa003@3oXa000`2][Jd0o:0@0?bP40070?bP40L0[Jf]
2@3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0
0P3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo
001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0ojHA
00<0[Jf]0000000000000P2][Jd20?nV4@030000003oYQ40ojHA00P0ojHA00@0[Jf]0?nV4@3oYQ40
ojHA0P0000090?nV4@8000002@3oYQ42000000030:f][@3oYQ40ojHA00D0ojHA0`00000:0?nV4@80
00001P3oYQ42000000030:f][@3oYQ00ojH@00P0ojH@0P00000:0?nV40030000003oYQ00ojH@00D0
ojH@00<0[Jf]0?nU403oYA000P00000:0?nU408000001`3oYA000`000000ojD@0?nU40040?nU4004
0:f][@3oXa00oj<@0?nS408000001`3oXa000`000000oj<@0?nS400=0?nS40030:f][@3lX100o:0@
00h0o:0@1P2][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2]
[Jd0fhX=0=^:3@040=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102]
[Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]
0>nH403_V100103_V1000`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060:f][@030?nV4@000000000000@0ojHA00<00000
0?nV4@3oYQ40203oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA0P0000090?nV4@80000000<0
[Jf]0?nV4@3oYQ40103oYQ4010000000ojHA00000000000;0?nV4@800000103oYQ42000000030?nV
4@2][Jd0ojH@00P0ojH@0P00000<0?nV40030000003oYQ00ojH@00@0ojH@00<0[Jf]0?nU403oYA00
0P00000:0?nU40800000203oYA000`000000ojD@0?nU40030?nU40030:f][@3oXa00oj<@00<00000
1`3oXa000`000000oj<@0?nS400=0?nS40030:f][@3lX100o:0@01@0o:0@1@2][JdE0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@8000000P3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P3_V1020:f][@L0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]1`3oYQ42000000@0ojHA00<000000?nV4@3o
YQ40203oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA0P00000:0?nV4@8000001P3oYQ401000
0000ojHA00000000000<0?nV4@8000000`3oYQ4010000000ojHA0?nV4@2][Jd70?nV40P000000`3o
YQ08000000<0ojH@1P00000:0?nU408000002@3oYA000`000000ojD@0?nU40020?nU40030:f][@3o
Xa00oj<@00<000001`3oXa000`000000oj<@0?nS400=0?nS40030:f][@3lX100o:0@01L0o:0@00<0
[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01`3K
RPd01@2][Jd00000000000000000[Jf]00T0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40
oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@T0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0>0?nT4@@0[Jf]00<0oj@A0:f][@3o
YQ401`3oYQ42000000<0ojHA0`00000:0?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ420000
00/0ojHA0P0000030?nV4@8000000P3oYQ42000000h0ojHA0`0000030?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00203oYA06000000T0ojD@00<000000?nU403oYA000P3oYA000`2]
[Jd0oj<@000000020?nS40030000003oXa00oj<@00@0oj<@0P00000?0?nS40030:f][@3lX100o:0@
01L0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][@d0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2]
[Jd0fhX=0=^:3@080=^:3@040000002][Jd0[Jf]0:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>7
3P3CQ`h01P3CQ`h30:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:0?nT
4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@060?nV4@D000000P3oYQ400`000000ojHA0?nV4@080?nV
4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ42000000/0ojHA00<0[Jf]0?nV4@0000000P000004
0?nV4@800000503oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01P0ojD@1P000003
0?nS40030000003oXa00oj<@00@0oj<@0`00000>0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@08
0=^:3@060000003KRPd0fhX=0:f][@2iM@/000001`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@<0[Jf]
2@3oY1400`2][Jd0ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@080?nV4@040:f]
[@3oYQ40ojHA0?nV4@8000002@3oYQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000001@0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00T0
oj<@0`00000>0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@080=^:3@030000003KRPd0fhX=0080
[Jf]00<0^GD;0000000000001@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]303_V1000`2][Jd0
o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd<0?nT4@030:f][@3oYQ40ojHA00H0
ojHA0P0000050?nV4@030000003oYQ40ojHA00P0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000060?nV
4@<000003@3oYQ400`2][Jd0ojHA0?nV4@060?nV4@800000503oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002@3oXa03000000h0oj<@00<0[Jf]0?bP
403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2]
[Jd0fhX=0=^:3@090=^:3@050000003KRPd0[Jf]0;Ue2`2][Jd00`0000040;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00H0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400;0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]
0?nT4@2][Jd00`2][Jd@0?nT4@030:f][@3oYQ40ojHA00H0ojHA0P0000050?nV4@030000003oYQ40
ojHA00L0ojHA00<0[Jf]0?nV4@0000001000000F0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000D
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS4009
0?nS40<000003P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2][JdA
0>bF3P030:f][@3KRPd0fhX=00T0fhX=00<000000=^:3@2][Jd00P2iM@/2000000030;Ue2`000000
00000080^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00`0kiP@00<0
[Jf]0?bP403lX1003`3lX1030:f][A@0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000D0ojHA00<0
00000?nV4@3oYQ401`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00
000D0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
40090?nS40<000003P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00T0fhX=00<000000=^:3@2][Jd00P2i
M@/2000000060:f][@00000000000000002iM@/0[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_
V1002P3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]00<0o:0@0:f][@3oY140503oY1400`2][Jd0
ojHA0?nV4@060?nV4@8000001@3oYQ400`000000ojHA0?nV4@070?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00T0oj<@0`00000>0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0
fhX=0=^:3@090=^:3@030000003KRPd0[Jf]0080^GD;0P0000000`2iM@/00000000000020;Ue2`03
0:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00`3CQ`h00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403l
X1002P3lX1020:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060?nV4@80
00001@3oYQ400`000000ojHA0?nV4@030?nV4@050000003oYQ40ojHA0?nV4@2][Jd0703oYQ400`2]
[Jd0ojHA0?nV4@060?nV4@800000503oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa002@3oXa03000000h0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=
00T0fhX=00<000000=^:3@2][Jd00P2iM@/2000000060;Ue2`00000000000:f][@2iM@/0[Jf]1028
EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@0000020:f][@H0dhL>
00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]1P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0ojHA0P0000050?nV4@030000003oYQ40ojHA00<0ojHA
00D000000?nV4@3oYQ40ojHA0:f][@0L0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000=0?nV4Bh0
[Jf]5`3oYA000`2][Jd0oj<@0?nS40090?nS40<000003P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3K
RPd02@3KRPd00`000000fhX=0:f][@020;Ue2`80000000@0^GD;000000000000^GD;0P2][Jd408QF
1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]000000P0dhL>00<0[Jf]
0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA00H0ojHA0P00000;0?nV4@050000003oYQ40ojHA0?nV4@2][Jd0703o
YQ400`2][Jd0ojHA0?nV4@050?nV4@030:f][@000000000000d0[Jf]1`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@00T0oj<@0`00
000>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@090=^:3@030000003KRPd0[Jf]0080^GD;0P00
00000`2iM@/00000000000020;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`
h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/2000000P0dhL>00<0[Jf]0>nH403_V1002P3_
V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA00H0ojHA0P00000;0?nV4@050000003oYQ40ojHA0?nV4@2][Jd0603oYQ4<0:f][@030?nV
4@000000000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]
1`3oXa03000000h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0:0=^:3@80000000<0fhX=0:f][@2iM@/0
0P0000000`2iM@/00000000000020;Ue2`80[Jf]00D0R5H700000028EPL0R5H70:f][@120;3PiP40
oooo001I0;3PiP050:f][@2GH0/0Uf0;0:f][@000000203CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100[Jf]0080[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0
ojHA0P00000;0?nV4@050000003oYQ40ojHA0?nV4@2][Jd03P3oYQ4:0:f][@@0ojHA00<0[Jf]0?nV
4@3oYQ401P3oYQ42000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@0080oj<@1`2][Jd3000000h0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd;0=^:3@80000000D0[Jf]0;Ue
2`00000000000;Ue2`0200000080^GD;0P2][Jd200000080R5H700<0[Jf]0;3PiP2`h>H0@02`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;0000002][Jd0000000P0dhL>00<0[Jf]0>nH403_V1002`3_V102
0:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060?nV4@8000002`3oYQ40
1@000000ojHA0?nV4@3oYQ40[Jf]00@0ojHA2P2][Jd>0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00
000D0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
40090?nS40<000002P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@T0fhX=00<000000=^:3@000000
0P0000020;Ue2`8000000P2iM@/0102][Jd0R5H700000000000208QF1`030:f][@2`h>H0/>3V0400
/>3V0@3oool005T0/>3V00D0[Jf]000000000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@00T0
kiP@0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000X0
ojHA00<000000?nV4@2][Jd01`2][JdH0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000D0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40090?nS4003
0000003oXa00000000X0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@L0fhX=00D000000=^:3@2][Jd0^GD;00000002
0;Ue2`8000000P2iM@/01`2][Jd0R5H70000002][Jd0000008QF1`2][Jd0@P2`h>H10?ooo`00F@2`
h>H30000000309MP2`2][Jd0dhL>00L0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00H0ojHA0P00
00060?nV4@@0[Jf]00<000000:f][@3oYQ400P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA00H0ojHA0P00000D0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400:0?nS408000003P3oXa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=
0P2][Jd50=^:3@050000003KRPd0[Jf]0;Ue2`0000000P2iM@/200000080^GD;00@0[Jf]08QF1`00
0000R5H70P0000000`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP<0000000<0Uf0;0:f][@3C
Q`h01`3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000H0[Jf]103oYQ400`000000
ojHA0?nV4@020?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ46000001@0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00X0
oj<@0P00000>0?nS40030:f][@3lX100o:0@00P0o:0@1P2][Jd:0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]0`3KRPd01@000000
fhX=0:f][@2iM@/000000080^GD;0P0000020;Ue2`040:f][@28EPL0000008QF1`<00000@P2`h>H1
0?ooo`00F02`h>H2000000040:f][@000000Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V102
0:f][@H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@3oYQ40
ojHA0?nV4@D0[Jf]0P00000:0?nV4@030000003oYQ40ojHA0080ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400;0?nS40030000003oXa00oj<@00`0oj<@00<0[Jf]0?bP403lX1003P3l
X1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00L0fhX=0P2][Jd01P3KRPd000000=^:3@2][Jd0^GD;00000080^GD;0P0000020;Ue2`07
0:f][@28EPL0000008QF1`000000[Jf]000000120;3PiP40oooo001H0;3PiP80000000@0Uf0;0000
002GH0/0[Jf]203CQ`h0102][Jd0kiP@0>nH403_V1020:f][@P0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@D0[Jf]1@3oYQ42000000X0ojHA00<000000?nV4@3oYQ400P3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3l
X1060:f][A@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@060:f][@00
0000fhX=0:f][@2iM@/000000P2iM@/200000080^GD;00H0[Jf]08QF1`000000R5H700000028EPL2
00000440/>3V0@3oool005L0/>3V0`000000102GH0/0000009MP2`2][Jd80=>73P040:f][@3_V100
[Jf]0:f][@X0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0
oj@A0:f][@3oYQ401`3oYQ42000000X0ojHA00<000000?nV4@3oYQ400P3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`040:f][A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@050000002]
[Jd0[Jf]0;Ue2`0000000`2iM@/200000080^GD;00D0[Jf]00000028EPL0000008QF1`0200000440
/>3V0@3oool005L0/>3V0`000000102GH0/0000009MP2`2][Jd80=>73P80[Jf]303_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA00H0
ojHA0P0000080?nV4@<00000103oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=00<000000=^:3@2][Jd00P0000030;Ue2`80
00000P2iM@/00`2][Jd0000008QF1`0208QF1`800000@@2`h>H10?ooo`00E`2`h>H30000000409MP
2`000000Uf0;0:f][@L0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000@0ojHA100000070?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd01@000000[Jf]000000000000[Jf]0080^GD;0P0000020;Ue2`030:f][@000000R5H7
0080R5H70P0000110;3PiP40oooo001G0;3PiP<0000000@0Uf0;0000002GH0/0[Jf]1P3CQ`h00`2]
[Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f]
[@d0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ46000000/0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l40:f]
[@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@070000002][Jd00000
0000002iM@/0[Jf]0;Ue2`0200000080^GD;00<0[Jf]00000028EPL00P28EPL300000400/>3V0@3o
ool005L0/>3V1@0000000`2GH0/000000=>73P040=>73P040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ40103o
YQ4300000100ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02P3K
RPd010000000[Jf]0000000000020;Ue2`030:f][@00000000000080^GD;00<0[Jf]00000028EPL0
0P28EPL300000400/>3V0@3oool005L0/>3V0P0000001@2][Jd000000000002GH0/0000000<0dhL>
0P2][Jd30=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][AD0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
3P3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@040000002][Jd00000000000<0^GD;0P0000020;Ue2`03
0:f][@000000R5H70080R5H70`0000100;3PiP40oooo001G0;3PiP80000000D0[Jf]0000002GH0/0
Uf0;000000020=>73P030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3K
RPd02P3KRPd010000000[Jf]0000000000030;Ue2`80000000@0[Jf]0;Ue2`2][Jd000000`28EPL3
00000400/>3V0@3oool005L0/>3V0P0000001`2][Jd0000009MP2`2GH0/000000=>73P2][Jd01P3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3o
Y140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00X0fhX=00@000000:f][@0000000000
0`2iM@/2000000040;Ue2`2][Jd0@FWQ000000<0R5H70`0000100;3PiP40oooo001G0;3PiP@00000
0P2GH0/00`000000[Jf]0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
1`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd0
2P3KRPd010000000[Jf]0000000000030;Ue2`8000000P2iM@/00`2][Jd0000008QF1`0208QF1`<0
0000@02`h>H10?ooo`00E`2`h>H400000080Uf0;00<000000=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA
;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00X0fhX=
00@000000:f][@00000000000`2iM@/200000080^GD;00<0[Jf]00000028EPL00P28EPL300000400
/>3V0@3oool005L0/>3V0`00000209MP2`030:f][@000000dhL>00H0dhL>00<0[Jf]0>nH403_V100
303_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0
/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0;0=^:3@04
0000003KRPd00000000000<0^GD;0P000000102iM@/000000:f][@00000308QF1`<00000@02`h>H1
0?ooo`00E`2`h>H300000080Uf0;00<0[Jf]0000003CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400<0>nH
40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H
0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@`0fhX=0`000003
0;Ue2`@0000000@0[Jf]0000002][Jd0R5H7100000100;3PiP40oooo001G0;3PiP070000002][Jd0
000009MP2`000000Uf0;000000070=>73P030:f][@3_V100kiP@00/0kiP@0`2][Jd@0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]
J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2P3KRPd300000080^GD;1`0000000`2][Jd0
R5H70000000300000400/>3V0@3oool005L0/>3V00L000000:f][@000000[Jf]0000002GH0/00000
00L0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH402][Jd0o:0@0100o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3P
iPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:
3@3KRPd0fhX=0P2][Jd80=^:3@<000000`2iM@/60000000308QF1`2][Jd0000000<00000@02`h>H1
0?ooo`00E`2`h>H50000000309MP2`000000dhL>00H0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f]
[@<0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@H0fhX=0P0000060;Ue2`040000002iM@/00000
00000080R5H7100000100;3PiP40oooo001G0;3PiPL000001`3CQ`h00`2][Jd0kiP@0>nH40050>nH
4080[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]103KRPd2000000H0^GD;0P000000102]
[Jd0R5H700000028EPL400000400/>3V0@3oool005L0/>3V0P0000001@2][Jd0000009MP2`000000
[Jf]00L0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX100
0`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd2
0:f][@80fhX=0P0000080;Ue2`040:f][@28EPL0000008QF1`@00000@02`h>H10?ooo`00E`2`h>H2
0000000509MP2`000000Uf0;0000002][Jd01`3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0
[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00T0fhX=0P2][Jd2000000T0^GD;00D0[Jf]00000028EPL000000:f][@030000
03l0/>3V0@3oool005H0/>3V0`000000102GH0/0000009MP2`0000080=>73P040:f][@3_V100[Jf]
0:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H5
0:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030000002][Jd0
^GD;00P0^GD;00D0[Jf]08QF1`00000000000:f][@03000003l0/>3V0@3oool005H0/>3V1@000000
0`2GH0/000000=>73P070=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00`0fhX=00<000000:f][@2][Jd01`2iM@/01@2][Jd0R5H700000028EPL0[Jf]00<00000?`2`
h>H10?ooo`00EP2`h>H400000080Uf0;00<000000=>73P3CQ`h01@3CQ`h20:f][@h0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040000002iM@/0^GD;0:f][@H0^GD;00D0
[Jf]08QF1`28EPL0R5H70:f][@03000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0000009MP
2`2GH0/0000000D0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@
00<0[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd01@000000^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00D0[Jf]08QF1`28
EPL0R5H70:f][@03000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/00000
00@0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]
0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<000000;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00D0[Jf]08QF1`28EPL0R5H70:f]
[@03000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0000000<0dhL>00<0
[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102]
[Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030000002iM@/0^GD;00@0^GD;00@0
[Jf]0;Ue2`2iM@/0[Jf]0`28EPL0102][Jd0000000000000000o0;3PiP40oooo001F0;3PiP800000
00H0[Jf]09MP2`2GH0/0Uf0;0000003CQ`h20:f][@D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`050;Ue2`<0[Jf]0`28EPL0102][Jd0000000000000000o0;3PiP40oooo001F0;3P
iP80000000H0[Jf]09MP2`2GH0/0Uf0;0000002][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]
2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL0
0P28EPL3000003l0/>3V0@3oool005H0/>3V0P00000409MP2`030000003CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V102]
[Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2]
[Jd308QF1`<00000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@000000
dhL>00L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M
0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`<00000?`2`h>H10?ooo`00EP2`h>H00`00
0000[Jf]09MP2`0209MP2`030:f][@000000dhL>00L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f]
[@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL3000003l0/>3V0@3oool005H0
/>3V00L000000:f][@2GH0/0Uf0;0:f][@2GH0/0000000P0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@03
0:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP2
0:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`<00000?`2`h>H1
0?ooo`00EP2`h>H010000000[Jf]09MP2`2][Jd209MP2`030000003CQ`h0dhL>00H0dhL>00<0[Jf]
0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[003
0;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^005
0;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H70:f][@28EPL00`00
000o0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H7
0:f][@03000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF
1`28EPL0[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3C
Q`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]
2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]
0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
1@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL0
0P28EPL3000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/00`2][Jd0dhL>0=>7
3P060=>73P040:f][@3_V100kiP@0>nH4080[Jf]00D0@FWQ0:BNS`11JN40Y9j?0:f][@040;6[W@80
[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70`00000o0;3PiP40oooo001F0;3PiP03
0000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h01P2][Jd0kiP@0:f][@2][Jd0Y9j?
045Yh@<0Y9j?0P11JN460;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00@0
[Jf]045Yh@2d/;40];2a0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`040:f][@28EPL0R5H708QF1`80
0000@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd30:BNS`04
045Yh@2TWXl0Y9j?0:BNS`<0@FWQ1`2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP0
0`2][Jd0@FWQ0;B`/@020;B`/@03045Yh@2][Jd0[Jf]00X0^GD;00@0[Jf]08QF1`28EPL0R5H70P00
00100;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0Y9j?045Y
h@030:BNS`04045Yh@2TWXl0Y9j?0:BNS`80@FWQ2P2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk
0`2][Jd70;ji^003045Yh@2n^KP0_[Vh0080_[Vh00<0[Jf]045Yh@2d/;400P2d/;42045Yh@030;B`
/@2][Jd0[Jf]00P0^GD;00H0[Jf]08QF1`28EPL0R5H70:f][@0000100;3PiP40oooo001G0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@80Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@03
0:BNS`80@FWQ1@2aZid00`11JN40/J^M0;6[W@040;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33
_K/30:f][@030<>m^`2][Jd0_[Vh00D0_[Vh0P11JN450;ji^0030:f][@11JN40];2a0080];2a0P11
JN420;B`/@03045Yh@2][Jd0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V
0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h00`2][Jd0@FWQ
0:f][@020:BNS`05045Yh@2TWXl0Y9j?0:BNS`11JN400`2TWXl2045Yh@<0/J^M0P11JN400`2aZid0
@FWQ0;6[W@050;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0
[Jf]1033_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0@FWQ1`2n^KP01011JN40];2a0;B`/@2d/;42045Y
h@80];2a00@0@FWQ0;B`/@2][Jd0[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`
h>H0/>3V03d0/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P02
0=>73P040:f][@2:QGD0@FWQ0:f][@80Y9j?00<0@FWQ0:BNS`2TWXl00P11JN430:BNS`80@FWQ0P2a
Zid2045Yh@80/J^M00<0@FWQ0;6[W@2aZid0102aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033
_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^0040;ji^003045Yh@2n
^KP0_[Vh00D0_[Vh00@0@FWQ0;B`/@2d/;40];2a0P11JN420;B`/@04045Yh@2][Jd0@FWQ045Yh@80
[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005D0
/>3V00<000000;3PiP2][Jd00`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]0080RXEe00D0@FWQ0:f]
[@2][Jd0[Jf]045Yh@020:BNS`80@FWQ0`2TWXl2045Yh@80/J^M0P11JN430;6[W@03045Yh@2aZid0
/J^M0080/J^M00<0@FWQ0:f][@2i/ZH01`2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<
0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2P33_K/2045Yh@H0_[Vh00<0@FWQ
0;ji^02n^KP01@2n^KP00`11JN40];2a0;B`/@020;B`/@05045Yh@2d/;40];2a045Yh@2d/;400P11
JN400`2OVj00@FWQ0:f][@020;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0
?@2`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`090:f][@3CQ`h0[Jf]0:f][@11JN40
RXEe045Yh@2:QGD0[Jf]0080Y9j?00<0@FWQ0:BNS`2TWXl00P11JN430:BNS`80@FWQ0P2aZid2045Y
h@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`11JN40[Jf]045Yh@0:0;VbYP@0[Jf]00<0^K:V0:f]
[@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]2P33_K/3045Yh@030<>m^`2][Jd0@FWQ
00D0_[Vh00<0@FWQ0;ji^02n^KP01@2n^KP2045Yh@<0];2a00@0@FWQ0:f][@2][Jd0@FWQ0P2d/;40
1011JN40Wi^P045Yh@11JN430:f][@@0R5H700<0[Jf]0000002`h>H0?P2`h>H10?ooo`00E@2`h>H0
0`000000[Jf]09MP2`0309MP2`80[Jf]0`2:QGD2045Yh@0508Z5M@2][Jd0Y9j?045Yh@2TWXl00P2]
[Jd2045Yh@<0Y9j?0P11JN420;6[W@03045Yh@2aZid0/J^M00<0/J^M00@0@FWQ0;6[W@2aZid0/J^M
0P11JN400`2i/ZH0@FWQ045Yh@0<0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]
2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02033_K/4045Yh@80`kfk
00<0[Jf]045Yh@11JN40102n^KP00`11JN40_[Vh0;ji^0050;ji^0H0@FWQ0P2d/;402P11JN40];2a
0;B`/@11JN40Wi^P045Yh@2OVj00@FWQ09nKX02][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3o
ool005D0/>3V00<000000:f][@2GH0/00`2GH0/00`2][Jd0RXEe08Z5M@0508Z5M@040:f][@2TWXl0
@FWQ045Yh@80Y9j?0P11JN430:BNS`05045Yh@2aZid0/J^M0;6[W@11JN402@2aZid01@11JN40[Jf]
0;VbYP2i/ZH0@FWQ00d0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00L0
a/2l102][Jd50<K0_0030:f][@33_K/0`kfk00T0`kfk0P11JN420<>m^`040:f][@2n^KP0@FWQ045Y
h@<0_[Vh00<0@FWQ0;ji^02n^KP01@2n^KP0102][Jd0];2a0;B`/@2][Jd2045Yh@80];2a00<0@FWQ
0;B`/@2d/;400P11JN4209nKX004045Yh@2OVj00Wi^P0:f][@<0R5H700<0[Jf]0;3PiP2`h>H0?P2`
h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@L0RXEe00@0[Jf]0:BNS`11JN40@FWQ
0P2TWXl2045Yh@040:f][@2TWXl0Y9j?045Yh@<0/J^M00<0@FWQ0;6[W@2aZid01`2aZid00`11JN40
[Jf]0;VbYP020;VbYP03045Yh@2i/ZH0^K:V00<0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH00`2][Jd0
_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0
`kfk0<>m^`090<>m^`80@FWQ0`33_K/00`2][Jd0@FWQ045Yh@030;ji^003045Yh@2n^KP0_[Vh00D0
_[Vh0`2][Jd20;B`/@04045Yh@2d/;40];2a045Yh@80];2a00@0@FWQ09nKX02OVj00Wi^P0P11JN40
0`2OVj00[Jf]08QF1`0208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00@0[Jf]09MP
2`2GH0/0Uf0;0P2][Jd708Z5M@040:f][@2TWXl0@FWQ045Yh@80Y9j?0P11JN40102TWXl0[Jf]0:f]
[@11JN430;6[W@03045Yh@2aZid0/J^M00L0/J^M00<0@FWQ0:f][@2i/ZH00`2i/ZH01011JN40^K:V
0;VbYP2i/ZH2045Yh@H0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031
^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02]
[Jd00`2][Jd=0<K0_0030:f][@33_K/0`kfk00T0`kfk0P11JN430<>m^`030:f][@2n^KP0@FWQ00<0
_[Vh00<0@FWQ0;ji^02n^KP0102n^KP20:f][@@0];2a00<0@FWQ0;B`/@2d/;400P11JN400`2d/;40
[Jf]09nKX00209nKX080@FWQ00<0Wi^P045Yh@2][Jd00P28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40
oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1`2:QGD0102][Jd0Y9j?045Yh@11JN420:BNS`03
045Yh@2TWXl0Y9j?0080Y9j?00D0@FWQ0:f][@2aZid0/J^M045Yh@0:0;6[W@030:f][@2i/ZH0^K:V
0080^K:V00@0@FWQ0;VbYP2i/ZH0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd0
0`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D0
0`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`4
0:f][A40a/2l00<0[Jf]0<>m^`33_K/02@33_K/2045Yh@<0`kfk00<0[Jf]0;ji^011JN400`2n^KP2
045Yh@<0_[Vh0P2][Jd00`2n^KP0[Jf]045Yh@020;B`/@03045Yh@2d/;40];2a0080@FWQ0P2d/;40
102][Jd0Wi^P09nKX02OVj03045Yh@0509nKX02][Jd0[Jf]08QF1`2][Jd0@02`h>H10?ooo`00EP2`
h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00P0[Jf]0:BNS`2TWXl0@FWQ0:BNS`11JN40Y9j?
045Yh@@0Y9j?00D0@FWQ0;6[W@2][Jd0[Jf]045Yh@0:0;6[W@030:f][@2i/ZH0^K:V0080^K:V00D0
@FWQ0;VbYP2i/ZH0^K:V045Yh@070;VbYP030:f][@2n]j`0_[N/00l0_[N/102][JdA0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`090<>m^`80@FWQ0`33_K/0102][Jd0_[Vh045Yh@11JN420;ji^080
@FWQ00<0_[Vh0:f][@2][Jd00`2n^KP01@2][Jd0@FWQ0;B`/@2d/;40@FWQ00H0];2a00<0[Jf]09nK
X02OVj000P2OVj02045Yh@0309nKX02][Jd0L6ii0080[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0
Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD0102][Jd0Y9j?0:BNS`11JN420:BNS`03045Yh@2TWXl0Y9j?
00<0Y9j?00D0@FWQ0;6[W@2aZid0/J^M045Yh@020:f][@P0/J^M00@0[Jf]0;VbYP2i/ZH0^K:V0P11
JN4;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`090<>m^`80@FWQ0`33_K/0102][Jd0_[Vh045Yh@11JN420;ji^080@FWQ
00<0[Jf]0;ji^02n^KP00`2n^KP0102][Jd0@FWQ0;B`/@11JN470;B`/@030:f][@2OVj00Wi^P00@0
Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe
00@0[Jf]0:BNS`2TWXl0@FWQ202TWXl01@11JN40/J^M0;6[W@2aZid0@FWQ0080/J^M0P2][Jd00`11
JN40/J^M0;6[W@030;6[W@030:f][@2i/ZH0@FWQ00<0@FWQ2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/2045Y
h@<0`kfk00@0[Jf]0;ji^011JN40@FWQ0P2][Jd2045Yh@<0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0`11
JN470;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@040:f][@2TWXl0
Y9j?045Yh@H0Y9j?00<0@FWQ0:BNS`11JN400`2aZid00`11JN40/J^M0;6[W@020;6[W@03045Yh@2]
[Jd0[Jf]00<0/J^M0P11JN400`2i/ZH0@FWQ0;VbYP0;0;VbYP030:f][@2n]j`0_[N/0140_[N/00<0
[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`80@FWQ0`33_K/0102][Jd0_[Vh045Y
h@11JN420;ji^080@FWQ0P2n^KP2045Yh@80_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P
09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f]
[@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD0102][Jd0Y9j?0:BNS`11JN470:BN
S`80@FWQ0`2aZid2045Yh@<0/J^M0P11JN401@2aZid0[Jf]0:f][@11JN40[Jf]0080@FWQ3@2i/ZH0
0`2][Jd0_[N/0;jg[00A0;jg[0030:f][@31^[00`KZ`00l0`KZ`202][Jd@0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/0
0`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/2
045Yh@80`kfk0`2][Jd2045Yh@80_[Vh0P11JN430;ji^004045Yh@2n^KP0_[Vh0:f][@X0];2a00<0
[Jf]09nKX02OVj000P2][Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H0
0`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD0102][Jd0Y9j?0:BN
S`11JN480:BNS`030:f][@2aZid0/J^M0080/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN420;6[W@<0
@FWQ00<0[Jf]0;VbYP2i/ZH01@2i/ZH00`11JN40^K:V0;VbYP040;VbYP030:f][@2n]j`0_[N/0140
_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P080<O1^PH0@FWQ1`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1
^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00;0<O1_003045Yh@37`K`0al6l00<0al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`80@FWQ0P2][Jd00`33_K/0[Jf]0;ji^002045Y
h@80_[Vh0`11JN420;ji^004045Yh@2n^KP0_[Vh0:f][@X0];2a00<0[Jf]09nKX02][Jd01@2OVj00
0`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2]
[Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]0080Y9j?00<0@FWQ0:BNS`2TWXl01P2TWXl00`2]
[Jd0/J^M0;6[W@020;6[W@05045Yh@2aZid0/J^M0;6[W@11JN400`2aZid01011JN40/J^M0:f][@2i
/ZH30:f][@@0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH00`2][Jd0_[N/0;jg[00A0;jg[0030:f][@31
^[00`KZ`00L0`KZ`1011JN460<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^P80@FWQ2@37
`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0030<O1_080@FWQ1P37
`K`2045Yh@@0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`070<>m^`80[Jf]0P11
JN430<>m^`040:f][@2n^KP0@FWQ045Yh@80_[Vh0P11JN400`2n^KP0@FWQ045Yh@030;ji^0030:f]
[@2d/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd00`2TWXl0@FWQ045Y
h@080:BNS`030:f][@2aZid0/J^M00<0/J^M00@0@FWQ0;6[W@2aZid0@FWQ0`2aZid00`11JN40/J^M
0:f][@040;VbYP05045Yh@2][Jd0[Jf]0;VbYP11JN401P2i/ZH00`2][Jd0_[N/0;jg[00A0;jg[003
0:f][@31^[00`KZ`00T0`KZ`1P11JN420<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j00X0al6j0P11JN490<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`03
0:f][@38`K/0b<6k01<0b<6k00@0[Jf]045Yh@37`K`0al6l0P11JN420<O1_003045Yh@37`K`0al6l
00<0al6l00<0@FWQ0<O1_037`K`00`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00D0`kfk0P2][Jd20<>m^`80@FWQ0`33_K/0102][Jd0_[Vh045Yh@11JN420;ji^080@FWQ1P2n^KP0
0`2][Jd0];2a0;B`/@080;B`/@030:f][@000000Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f]
[@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD0
102][Jd0Y9j?0:BNS`11JN480:BNS`030:f][@2aZid0/J^M00@0/J^M0P11JN440;6[W@03045Yh@2a
Zid0[Jf]00@0^K:V00D0@FWQ0;VbYP2i/ZH0[Jf]045Yh@020:f][@@0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00:0<6j/080@FWQ0`31^[02045Yh@030<6j/02][Jd0`kfc01@0`kfc
00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0:0<O1^P80@FWQ3`2][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]045Yh@11JN40
@FWQ1@37`K`00`11JN40al6l0<O1_0080<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/00P33_K/30:f][@D0`kfk00H0@FWQ0<>m^`33_K/0`kfk0:f][@2n^KP2045Yh@030;ji^011JN40
@FWQ00L0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f]
[@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0
[Jf]0;6[W@2aZid02`2aZid00`11JN40[Jf]0;VbYP020;VbYP80@FWQ0`2i/ZH00`11JN40^K:V0;Vb
YP030:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[002P31^[02045Yh@@0`KZ`0P11
JN400`2][Jd0`kfc0<>m/`020<>m/`L0@FWQ2P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng00T0a[ng<02][Jd2045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`090<S1^`D0@FWQ1@38`K/00`2][Jd0@FWQ0<O1_0060<O1_003045Yh@37`K`0al6l00P0al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@P0`kfk00H0@FWQ0<>m^`33_K/0`kfk
0:f][@2n^KP2045Yh@X0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40102][Jd0];2a0;B`/@2][Jd709nK
X0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0
[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd60:BNS`03045Yh@2][Jd0/J^M00`0/J^M00<0@FWQ
0:f][@2i/ZH00P2i/ZH00`11JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V00<0^K:V0`2][JdA
0;jg[0030:f][@31^[00`KZ`00X0`KZ`0P11JN450<6j/080@FWQ1`33_K<00`11JN40`kfc0<>m/`0;
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j00X0al6j0P11JN490<O1^P030:f][@38`K/0b<6k01<0b<6k1`11JN44
0<S1^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`020<S1^`030:f][@11JN40al6l00H0al6l00<0@FWQ
0<O1_037`K`02037`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]2`33_K/01P11JN40`kfk0<>m^`33
_K/0[Jf]0;ji^080@FWQ2P2n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P
09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C
06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl00`2TWXl00`11JN40
[Jf]0;6[W@0=0;6[W@D0@FWQ102i/ZH00`11JN40^K:V0;VbYP040;VbYP030:f][@2n]j`0[Jf]00<0
[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00:0<6j/080@FWQ1P31^[02045Yh@H0`kfc00<0@FWQ0<>m/`33
_K<02`33_K<00`2][Jd0@FWQ045Yh@02045YhA80aKje00<0[Jf]0<Jo]`36_kL04P36_kL010000000
a[ng0<Jo]`2][JdF0<O1^0030:f][@37`KX0al6j00X0al6j0P11JN490<O1^P030:f][@38`K/0b<6k
00X0b<6k1`11JN430<S1^`030:f][@11JN40@FWQ00H0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k
0080b<6k00<0[Jf]045Yh@37`K`01@37`K`2045Yh@X0al6l00<0[Jf]0<K0_036`;`02@36`;`50:f]
[@80a/2l00<0[Jf]0<>m^`33_K/02P33_K/01P11JN40`kfk0<>m^`33_K/0[Jf]0;ji^080@FWQ2P2n
^KP0102][Jd0];2a0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii
071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2T
WXl00`2TWXl20:f][@<0Y9j?0P11JN4>0;6[W@050:f][@2i/ZH0^K:V0;VbYP11JN400`2i/ZH2045Y
h@H0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[002P31^[02045Y
h@H0`KZ`0P11JN460<>m/`03045Yh@33_K<0`kfc00X0`kfc0`11JN430<Fn]@80@FWQ0`35_[D00`11
JN40aKje0<Fn]@050<Fn]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j0P11JN430<O1^P0300000037`KX0al6j
00<0al6j00<0[Jf]0<S1^`38`K/00P38`K/6045Yh@D0b<6k0P11JN450<S1^`030:f][@11JN40@FWQ
00H0b<6k0P11JN470<S1^`06045Yh@38`K/0b<6k0<S1^`2][Jd0@FWQ1P37`K`2045Yh@X0al6l00<0
[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/02P33_K/01P11JN40`kfk0<>m
^`33_K/0[Jf]0;ji^080@FWQ2P2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P
00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5
M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd00`2TWXl0@FWQ0:f][@0=0;6[W@030:f][@2i/ZH0^K:V
00H0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`
00X0`KZ`0P11JN460<6j/0030:f][@11JN40`kfc00D0`kfc00<0@FWQ0<>m/`33_K<02P33_K<00`11
JN40[Jf]0<Fn]@040<Fn]@04045Yh@35_[D0@FWQ045Yh@P0aKje00<0@FWQ0<Fn]@35_[D00P35_[D0
0`2][Jd0@FWQ0<Jo]`0<0<Jo]`<0@FWQ1036_kL00`11JN40a[ng0:f][@0F0<O1^0@0@FWQ1037`KX2
045Yh@<0al6j0P11JN420<O1^P<0@FWQ1037`KX00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ1`38`K/2
045Yh@D0b<6k00<0[Jf]045Yh@11JN401@38`K/2045Yh@`0b<6k00<0[Jf]0<O1_037`K`01037`K`2
045Yh@H0al6l00<0@FWQ0<O1_037`K`00P37`K`00`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0[Jf]
0<>m^`33_K/02P33_K/01`11JN40`kfk0<>m^`33_K/0[Jf]0;ji^011JN402`2n^KP30:f][@P0];2a
00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1S
H5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH01P2i
/ZH2045Yh@H0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`00/0`KZ`0P11
JN460<6j/0030:f][@11JN40`kfc00D0`kfc00<0@FWQ0<>m/`33_K<02P33_K<00`11JN40[Jf]0<Fn
]@050<Fn]@80@FWQ2035_[D2045Yh@@0aKje00<0[Jf]045Yh@36_kL02P36_kL3045Yh@80a[ng0P11
JN420<Jo]`03045Yh@36_kL0[Jf]0080al6h1`11JN4<0<O1^003045Yh@2][Jd0al6j0080al6j00<0
@FWQ0<O1^P37`KX00P11JN440<O1^P80@FWQ00<0al6j045Yh@37`KX00P37`KX2045Yh@80al6j00<0
[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k0P11JN450<S1^`030:f][@11JN40@FWQ00D0b<6k0P11
JN4<0<S1^`030:f][@37`K`0al6l00<0al6l0P11JN470<O1_003045Yh@37`K`0al6l00D0[Jf]4036
`;`00`2][Jd0`kfk0<>m^`0:0<>m^`07045Yh@33_K/0`kfk0<>m^`2][Jd0_[Vh045Yh@0:0;ji^080
[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V
0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V
0P11JN460;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][Jd90<6j/080@FWQ1P31^[000`2][Jd0@FWQ
0<>m/`050<>m/`03045Yh@33_K<0`kfc00X0`kfc00<0@FWQ0:f][@35_[D01@35_[D2045Yh@P0aKje
00<0@FWQ0<Fn]@11JN400`35_[D00`2][Jd0@FWQ0<Jo]`0:0<Jo]`80@FWQ1@36_kL01@11JN40a[ng
045Yh@36_kL0[Jf]00D0al6h0P11JN4=0<O1^003045Yh@37`KP0[Jf]00@0al6j00@0@FWQ0<O1^P11
JN40@FWQ1037`KX3045Yh@D0al6j0P11JN400`37`KX0[Jf]0<S1^`050<S1^`80@FWQ1`38`K/2045Y
h@D0b<6k00<0[Jf]045Yh@11JN401@38`K/00`11JN40b<6k0<S1^`0;0<S1^`040:f][@37`K`0al6l
0<O1_0<0@FWQ1P37`K`20:f][@03045Yh@2][Jd0[Jf]0080al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`0:0<>m^`07045Yh@33_K/0`kfk0<>m^`2][Jd0_[Vh045Yh@080;ji^080[Jf]
00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`
h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M00<0
[Jf]0;VbYP2i/ZH01P2i/ZH2045Yh@H0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j
/031^[070:f][@80`KZ`0P11JN460<6j/0030:f][@11JN40@FWQ00D0`kfc00<0@FWQ0<>m/`33_K<0
2P33_K<00`11JN40[Jf]0<Fn]@050<Fn]@80@FWQ2035_[D3045Yh@<0aKje0`11JN490<Jo]`80@FWQ
1`36_kL2045Yh@030<Jo]`2][Jd0al6h00@0al6h0P11JN4<0<O1^080@FWQ00<0al6h0:f][@37`KX0
0`37`KX3045Yh@D0al6j0P11JN470<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@L0b<6k
0P11JN450<S1^`030:f][@11JN40@FWQ00D0b<6k00<0@FWQ0<S1^`38`K/02`38`K/00`2][Jd0al6l
0<O1_003045Yh@80al6l1@2][Jd20<O1_003045Yh@37`K`0al6l0080al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`0:0<>m^`06045Yh@33_K/0`kfk0<>m^`2][Jd0@FWQ1`2n^KP20:f]
[@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?oo
o`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2a
Zid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH2045Yh@H0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/080[Jf]0P11JN430:f][@<0`KZ`00<0[Jf]045Yh@11
JN401033_K<2045Yh@`0`kfc00<0@FWQ0:f][@35_[D01@35_[D2045Yh@P0aKje0`11JN430<Fn]@<0
@FWQ2@36_kL2045Yh@P0a[ng00<0@FWQ0<Jo]`2][Jd01@37`KP2045Yh@`0al6h0P11JN420<O1^003
0:f][@37`KX0al6j0080al6j0P11JN450<O1^P80@FWQ1`37`KX2045Yh@030:f][@38`K/0b<6k00@0
b<6k0P11JN470<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@050<S1^`03045Yh@38`K/0b<6k00/0
b<6k00@0[Jf]0<O1_011JN40@FWQ102][Jd00`37`K`0@FWQ0<O1_0040<O1_003045Yh@37`K`0al6l
0080al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0:0<>m^`06045Yh@33_K/0`kfk
0<>m^`2][Jd0@FWQ102n^KP30:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nK
X00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:QGD0
0`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@030:f][@2i/ZH0
^K:V00H0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002P31^[02
045Yh@<0`KZ`102][Jd2045Yh@040:f][@33_K<0`kfc0<>m/`80@FWQ3033_K<2045Yh@H0aKje0P11
JN470<Fn]@80@FWQ00<0aKje045Yh@35_[D00P35_[D3045Yh@P0a[ng0P11JN490<Jo]`03045Yh@36
_kL0[Jf]00D0al6h0P11JN4<0<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P020<O1^P80@FWQ1@37
`KX2045Yh@P0al6j0P11JN460<S1^`80@FWQ1`38`K/2045Yh@D0b<6k00<0[Jf]045Yh@11JN401@38
`K/2045Yh@L0b<6k00<0@FWQ0<S1^`2][Jd00`2][Jd2045Yh@H0al6l00<0@FWQ0<O1_037`K`00`37
`K`00`11JN40al6l0<O1_0020<O1_0030:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m^`33_K/02@33
_K/00`11JN40`kfk0<>m^`02045Yh@<0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0
[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0
RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M
0:f][@2i/ZH01`2i/ZH2045Yh@H0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/009
0<6j/080@FWQ1`31^[00102][Jd0@FWQ045Yh@33_K<30:f][@80@FWQ0P2][Jd:0<>m/`80@FWQ1P35
_[D2045Yh@L0aKje0P11JN400`35_[D0@FWQ0<Fn]@020<Fn]@03045Yh@36_kL0@FWQ00P0a[ng0P11
JN490<Jo]`03045Yh@36_kL0[Jf]00D0al6h0P11JN4<0<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1
^P020<O1^P80@FWQ1@37`KX2045Yh@P0al6j0P11JN460<S1^`80@FWQ1`38`K/2045Yh@D0b<6k00<0
[Jf]0<S1^`11JN401@38`K/2045Yh@80b<6k102][Jd2045Yh@050:f][@38`K/0b<6k0<S1^`2][Jd0
0P11JN450<O1_080@FWQ1@37`K`00`11JN40al6l0<O1_0020<O1_0030:f][@36`;`0a/2l0140a/2l
00<0[Jf]0<>m^`33_K/02@33_K/3045Yh@030<>m^`2][Jd0_[Vh0080[Jf]2P2n^KP00`2][Jd0];2a
0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`
h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2a
Zid30:f][@L0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002@31
^[02045Yh@L0`KZ`00<0[Jf]045Yh@11JN401033_K<2045Yh@80`kfc202][Jd30<>m/`040:f][@11
JN40@FWQ045Yh@<0aKje0P11JN470<Fn]@80@FWQ00<0aKje045Yh@35_[D00P35_[D00`11JN40a[ng
045Yh@080<Jo]`80@FWQ2@36_kL00`11JN40a[ng0:f][@050<O1^080@FWQ3037`KP2045Yh@80al6h
00<0[Jf]0<O1^P37`KX00P37`KX2045Yh@D0al6j0P11JN480<O1^P80@FWQ1P38`K/2045Yh@L0b<6k
0P11JN450<S1^`040:f][@38`K/0@FWQ0<S1^`@0[Jf]0P11JN420:f][@@0b<6k00<0@FWQ0<S1^`11
JN400`38`K/00`2][Jd0@FWQ0<O1_0050<O1_080@FWQ1037`K`2045Yh@@0al6l00<0[Jf]0<K0_036
`;`04@36`;`00`2][Jd0`kfk0<>m^`070<>m^`<0@FWQ0P33_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d
/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f]
[@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@@0^K:V
00<0@FWQ0;VbYP2i/ZH0102i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00T0`KZ`
0P11JN470<6j/0030:f][@11JN40@FWQ00@0`kfc0`11JN490<>m/`L0[Jf]1@11JN470<Fn]@80@FWQ
0P35_[D01P11JN40aKje045Yh@11JN40a[ng045Yh@L0a[ng0P11JN4:0<Jo]`03045Yh@36_kL0[Jf]
00D0al6h0P11JN4=0<O1^004045Yh@37`KP0al6h0:f][@@0al6j0P11JN450<O1^P80@FWQ2037`KX2
045Yh@H0b<6k0P11JN470<S1^`80@FWQ1`2][Jd00`11JN40[Jf]0<S1^`040<S1^`03045Yh@38`K/0
b<6k00D0b<6k0P11JN430<S1^`030:f][@11JN40al6l00D0al6l0P11JN440<O1_0<0@FWQ0`37`K`0
0`2][Jd0a/2l0<K0_00A0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<
0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2]
[Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f]
[@030;VbYP11JN40^K:V00D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0090<6j
/080@FWQ1`31^[000`2][Jd0@FWQ045Yh@040<>m/`<0@FWQ1033_K<00`11JN40`kfc0<>m/`050<>m
/`030:f][@35_[D0aKje00<0aKje0`11JN460:f][@80@FWQ00D0[Jf]0<Fn]@35_[D0@FWQ0<Fn]@02
045Yh@80a[ng00<0@FWQ0<Jo]`36_kL01036_kL2045Yh@L0a[ng1011JN400`36_kL0[Jf]0<O1^004
0<O1^080@FWQ3P37`KP4045Yh@<0al6j0P11JN450<O1^P80@FWQ2037`KX2045Yh@D0b<6k00<0[Jf]
045Yh@11JN401`2][Jd2045Yh@D0b<6k00<0[Jf]0<S1^`11JN401P38`K/00`11JN40b<6k0<S1^`05
0<S1^`03045Yh@38`K/0b<6k0080b<6k00<0[Jf]0<O1_011JN400P37`K`3045Yh@030<O1_011JN40
al6l00<0al6l0`11JN440<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/3
0:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H1
0?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;Vb
YP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00T0`KZ`0P11JN470<6j
/0030:f][@11JN40@FWQ00@0`kfc0`11JN430<>m/`80@FWQ1P33_K<2045Yh@H0aKje0P11JN460<Fn
]@80@FWQ00D0aKje0:f][@2][Jd0@FWQ0:f][@02045Yh@80[Jf]00<0@FWQ0:f][@2][Jd0102][Jd2
045Yh@X0a[ng1011JN440<O1^080@FWQ4037`KP00`2][Jd0al6j045Yh@04045Yh@D0al6j0P11JN48
0:f][@03045Yh@2][Jd0[Jf]00@0[Jf]00<0b<6k045Yh@11JN401`38`K/2045Yh@D0b<6k00<0[Jf]
0<S1^`11JN401P38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`2][Jd0al6l0<O1_002
045Yh@T0al6l0`11JN440<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/4
0:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`h>H0
/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`
00T0`KZ`0P11JN470<6j/0030:f][@11JN40@FWQ00@0`kfc0P11JN401`33_K<0@FWQ0<>m/`33_K<0
@FWQ0<>m/`11JN401@33_K<2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D01@35_[D2045Yh@<0aKje00@0
@FWQ0<Fn]@11JN40@FWQ0P36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ4P2][Jd2045YhA@0[Jf]
0`11JN450:f][@80@FWQ1`37`KX2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN470<S1^`80@FWQ
1@38`K/00`2][Jd0b<6k045Yh@070<S1^`80@FWQ0`38`K/00`11JN40b<6k0<S1^`040<S1^`030:f]
[@37`K`0al6l00/0al6l0`11JN440<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd0
0P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V
0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i
/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[002@31^[02045Yh@L0`KZ`0P11JN430<>m/`@0@FWQ0P33
_K<2045Yh@030<>m/`11JN40@FWQ00H0`kfc00<0@FWQ0<Fn]@35_[D01035_[D00`11JN40aKje0<Fn
]@050<Fn]@80@FWQ0`35_[D01011JN40aKje045Yh@2][Jd20<Jo]`03045Yh@36_kL0a[ng00@0a[ng
0P11JN4<0<Jo]`030:f][@37`KP0al6h00<0al6h0P11JN4@0<O1^0030:f][@37`KX0al6j0080al6j
0P11JN450<O1^P80@FWQ1`37`KX2045Yh@030:f][@38`K/0b<6k00@0b<6k0`11JN450<S1^`80@FWQ
1P38`K/00`2][Jd0b<6k045Yh@080<S1^`D0@FWQ1P38`K/00`2][Jd0al6l0<O1_00;0<O1_0<0@FWQ
1037`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f]
[@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0
[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n
]j`00`2][Jd0`KZ`0<6j/0090<6j/080@FWQ1`31^[02045Yh@/0`kfc0P11JN470<>m/`030:f][@11
JN40aKje00<0aKje00<0@FWQ0<Fn]@35_[D01@35_[D2045Yh@D0aKje0P11JN40102][Jd0a[ng0<Jo
]`11JN460<Jo]`80@FWQ2@36_kL010000000a[ng0<Jo]`2][Jd50<O1^080@FWQ1@37`KP00`11JN40
al6h0<O1^0050<O1^080@FWQ00<0al6h0:f][@37`KX00`37`KX00`11JN40al6j0<O1^P040<O1^P<0
@FWQ1@37`KX2045Yh@030<O1^P2][Jd0b<6k00D0b<6k0P11JN400`38`K/0@FWQ0<S1^`030<S1^`80
@FWQ1@38`K/4045YhA<0b<6k00<0[Jf]0<O1_037`K`02`37`K`3045Yh@@0al6l00<0[Jf]0<K0_036
`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^003
0:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M
0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/
00<0[Jf]0<6j/031^[002@31^[02045Yh@L0`KZ`00<0@FWQ0<>m/`33_K<04`33_K<00`2][Jd0aKje
045Yh@03045Yh@P0aKje0P11JN450<Fn]@80@FWQ00D0[Jf]0<Jo]`36_kL0a[ng045Yh@050<Jo]`80
@FWQ3036_kL00`2][Jd0al6h0<O1^0030<O1^0<0@FWQ0`37`KP00`11JN40al6h045Yh@060<O1^080
@FWQ00<0al6h0:f][@37`KX00`37`KX00`11JN40al6j0<O1^P040<O1^P<0@FWQ1@37`KX01011JN40
al6j0<O1^P2][Jd60<S1^`80@FWQ0P38`K/5045Yh@L0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00;0<O1_0<0@FWQ1037`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2]
[Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@
0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[002@31^[02045Y
h@L0`KZ`00<0@FWQ0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@090<Fn]@L0@FWQ0P35_[D2045Y
h@030:f][@36_kL0@FWQ0080@FWQ1@36_kL2045Yh@`0a[ng00<0[Jf]0<O1^037`KP00`37`KP2045Y
h@030<O1^011JN40al6h0080al6h0P11JN470<O1^003045Yh@37`KP0[Jf]00<0al6j00<0@FWQ0<O1
^P37`KX01@37`KX2045Yh@030<O1^P11JN40al6j0080al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@06
0<S1^`80@FWQ3P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00/0al6l0P11JN45
0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[002P31^[02
045Yh@H0`KZ`0P11JN4E0<>m/`030:f][@35_[D0aKje01@0aKje00@0[Jf]0<Jo]`36_kL0a[ng1011
JN420<Jo]`80@FWQ3036_kL00`2][Jd0al6h0<O1^005045Yh@80al6h1011JN490<O1^0D0@FWQ1P37
`KX4045Yh@80al6j0`11JN440<O1^P030:f][@38`K/0b<6k00@0b<6k0P11JN4>0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03037`K`01011JN40al6l0<O1_037`K`50:f][A00a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`
h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]1P31
^[04045Yh@D0`KZ`0P11JN400`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02036_kL2045Yh@T0a[ng00<0@FWQ0<Jo]`2][Jd05`37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k00@0b<6k0P11JN4>0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2]
[Jd00`31^[00@FWQ045Yh@07045Yh@030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`080<Jo]`80@FWQ2@36_kL00`11JN40a[ng0:f][@0G0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/01038`K/2045Yh@h0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd8
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/008
0<6j/0L0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL02036_kL2045Yh@T0a[ng00<0@FWQ0<Jo]`2][Jd05`37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k00@0b<6k0P11JN4>0<S1^`030:f][@38`K/0@FWQ01<0b<6k00<0[Jf]
0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL00`11JN40a[ng0<Jo]`070<Jo
]`03045Yh@36_kL0[Jf]01L0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`040<S1
^`80@FWQ3P38`K/0102][Jd0@FWQ0<S1^`11JN4?0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool0
07H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng00T0a[ng0P11JN480<Jo]`03045Yh@36_kL0[Jf]01L0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ3P38`K/00`2][Jd0b<6k045Yh@09
0<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2a
Zid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
00X0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL2045Yh@030<Jo]`2][Jd0al6h01H0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ3P38`K/0102][Jd0b<6k0<S1^`38`K/8
0:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0[Jf]0<Jo
]`36_kL02P36_kL2045Yh@@0a[ng0P11JN401036_kL0@FWQ0<Jo]`2][JdG0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`0000000P38`K/4045Yh@T0b<6k2@2][JdB0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H1
0?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo
]`36_kL03036_kL4045Yh@<0a[ng00<0@FWQ0<Jo]`2][Jd05`37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][JeY0;3P
iP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0
al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00
Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]
2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd0
0`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`4
0:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jej0;3P
iP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H10?ooo`00
V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0[Jf]4@31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3PiP40oooo002T
0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l1`2][Jf;
0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l
0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo002i0;3PiPL0
[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool00<P0/>3V
2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0[Jf]1@35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37
`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54092 .33076 m
.52923 .33088 L
s
.51418 .33408 m
.51084 .33084 L
s
.51084 .33084 m
.5075 .3308 L
s
.51585 .33409 m
.51084 .33084 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5075 .3308 m
.50415 .33396 L
s
.50082 .33069 m
.49415 .33055 L
s
.55926 .33032 m
.5476 .33063 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49915 .33143 m
.49915 .33066 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52006 .34087 m
.52337 .33862 L
s
.52337 .33862 m
.52668 .33861 L
s
.5184 .34086 m
.52337 .33862 L
s
.52668 .33861 m
.53165 .34084 L
s
.53496 .33855 m
.53499 .35661 L
s
.53662 .33853 m
.53665 .35659 L
s
.51674 .34536 m
.52006 .34087 L
s
.51509 .34535 m
.5184 .34086 L
s
.53165 .34084 m
.53497 .34531 L
s
0 0 0 r
.58547 .33492 m
.5875 .33871 L
s
.255 .412 .882 r
.54654 .33837 m
.55809 .33807 L
s
0 0 0 r
.58672 .33408 m
.58915 .33862 L
s
.51918 .36632 m
.52042 .35917 L
s
.5175 .36631 m
.51875 .35917 L
s
.255 .412 .882 r
.51508 .34987 m
.51674 .34536 L
s
.51342 .34986 m
.51509 .34535 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51342 .35664 m
.51508 .34987 L
s
.51176 .35662 m
.51342 .34986 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50074 .35973 m
.50075 .35918 L
s
.49907 .36072 m
.49907 .35912 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49359 .33825 m
.50011 .37006 L
s
.48686 .36974 m
.49359 .33825 L
s
.48041 .33784 m
.48686 .36974 L
s
.47364 .36927 m
.48041 .33784 L
s
.48851 .36978 m
.49357 .34501 L
s
.47529 .36934 m
.48037 .34461 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.464 .33711 m
.46564 .33719 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55149 .33826 m
.55161 .36992 L
s
.55315 .33821 m
.55326 .36988 L
s
.53001 .35665 m
.54162 .35652 L
s
.46071 .33919 m
.464 .33711 L
s
.46235 .33928 m
.464 .33711 L
s
.5134 .36796 m
.51342 .35664 L
s
.51174 .36795 m
.51176 .35662 L
s
.58111 .33938 m
.58599 .33686 L
s
.5795 .34398 m
.58111 .33938 L
s
.58274 .3393 m
.58599 .33686 L
s
.58599 .33686 m
.59088 .33658 L
s
.58114 .3439 m
.58274 .3393 L
s
.46068 .34371 m
.46235 .33928 L
s
.60693 .31967 m
.61816 .31874 L
s
.45905 .34362 m
.46071 .33919 L
s
.55321 .35628 m
.55489 .36303 L
s
.5795 .34398 m
.57953 .3485 L
s
.59088 .33658 m
.59416 .33863 L
s
.58114 .3439 m
.58117 .34842 L
s
.45582 .33891 m
.45905 .34362 L
s
.45258 .33646 m
.45582 .33891 L
s
.44771 .33614 m
.45258 .33646 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46056 .35957 m
.46068 .34371 L
s
.45889 .36402 m
.45905 .34362 L
s
.57953 .3485 m
.58121 .35295 L
s
0 0 0 r
.58771 .36457 m
.588 .36277 L
s
.255 .412 .882 r
.58117 .34842 m
.58284 .35287 L
s
.59416 .33863 m
.59745 .34295 L
s
.5134 .36796 m
.51506 .37478 L
s
.51174 .36795 m
.5134 .37477 L
s
0 0 0 r
.58936 .36448 m
.58983 .36154 L
s
.255 .412 .882 r
.44444 .33818 m
.44771 .33614 L
s
.44283 .33807 m
.44771 .33614 L
s
.55489 .36303 m
.55822 .36747 L
s
.49514 .36995 m
.50509 .37014 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59903 .33831 m
.60225 .33583 L
s
.59745 .34295 m
.59903 .33831 L
s
.58121 .35295 m
.58613 .35496 L
s
.60225 .33583 m
.60386 .33571 L
s
.60065 .3382 m
.60225 .33583 L
s
.54663 .37003 m
.55326 .36988 L
s
0 0 0 r
.57353 .37244 m
.57616 .37487 L
s
.255 .412 .882 r
.53667 .37246 m
.5367 .38611 L
s
.53502 .37929 m
.53667 .37246 L
s
.59907 .34284 m
.60065 .3382 L
s
.56482 .36499 m
.56646 .36266 L
s
.56646 .36266 m
.56812 .36487 L
s
.58284 .35287 m
.58613 .35496 L
s
.44278 .3426 m
.44444 .33818 L
s
.55822 .36747 m
.56154 .36964 L
s
.51506 .37478 m
.51672 .37934 L
s
.56482 .36499 m
.56649 .3672 L
s
.5134 .37477 m
.51505 .37933 L
s
.44116 .34248 m
.44283 .33807 L
s
0 0 0 r
.58444 .37123 m
.58771 .36457 L
s
.255 .412 .882 r
.56812 .36487 m
.56814 .36714 L
s
0 0 0 r
.5861 .37115 m
.58936 .36448 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58613 .35496 m
.59595 .35665 L
s
.56154 .36964 m
.5665 .36947 L
s
0 0 0 r
.57616 .37487 m
.58115 .37464 L
s
.255 .412 .882 r
.5665 .36947 m
.56814 .36714 L
s
.51672 .37934 m
.52005 .3839 L
s
.51505 .37933 m
.51838 .3839 L
s
.44274 .34713 m
.44278 .3426 L
s
.4687 .36906 m
.48024 .36952 L
s
.5317 .38387 m
.53502 .37929 L
s
.53502 .37929 m
.5367 .38611 L
s
0 0 0 r
.58115 .37464 m
.58444 .37123 L
s
.53601 .39221 m
.53434 .39548 L
s
.5377 .39544 m
.53601 .39221 L
s
.255 .412 .882 r
.44112 .34701 m
.44116 .34248 L
s
0 0 0 r
.58115 .37464 m
.5861 .37115 L
s
.255 .412 .882 r
.44754 .35426 m
.4573 .35712 L
s
.4573 .35712 m
.45892 .35948 L
s
.45889 .36402 m
.46056 .35957 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58127 .36202 m
.58291 .36194 L
s
.58127 .36202 m
.58129 .36429 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60406 .35154 m
.60411 .35645 L
s
.60243 .35273 m
.60247 .35659 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59745 .34295 m
.59764 .36337 L
s
.59907 .34284 m
.59922 .35872 L
s
.58291 .36194 m
.58293 .36421 L
s
.52005 .3839 m
.52338 .38618 L
s
.51838 .3839 m
.52338 .38618 L
s
.58129 .36429 m
.58294 .36648 L
s
.52671 .38618 m
.5317 .38387 L
s
.44274 .34713 m
.44431 .35177 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49898 .39022 m
.49899 .38861 L
s
.50066 .38923 m
.50067 .38867 L
s
.5 Mabswid
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44112 .34701 m
.44269 .35166 L
s
.52338 .38618 m
.52671 .38618 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44431 .35177 m
.44754 .35426 L
s
.44269 .35166 m
.44754 .35426 L
s
.58294 .36648 m
.58624 .36859 L
s
.45723 .36621 m
.45889 .36402 L
s
.59595 .35665 m
.59759 .35882 L
s
.61361 .34176 m
.61677 .33696 L
s
.61677 .33696 m
.61994 .33442 L
s
.61994 .33442 m
.62314 .33413 L
s
.45394 .3683 m
.45723 .36621 L
s
.58624 .36859 m
.59278 .36822 L
s
.59764 .36337 m
.59922 .35872 L
s
.62314 .33413 m
.62635 .33611 L
s
.62314 .33413 m
.62794 .33595 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40927 .33286 m
.42037 .33396 L
s
.44741 .3679 m
.45394 .3683 L
s
.59603 .36575 m
.59764 .36337 L
s
.4426 .36075 m
.44423 .36086 L
s
.4442 .36314 m
.44423 .36086 L
s
.59278 .36822 m
.59603 .36575 L
s
.44258 .36303 m
.4426 .36075 L
s
.62635 .33611 m
.62959 .34034 L
s
.44258 .36303 m
.44418 .36541 L
s
.44418 .36541 m
.44741 .3679 L
s
.41518 .36538 m
.4156 .3335 L
s
.62794 .33595 m
.63118 .34019 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41359 .36523 m
.41402 .33335 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62959 .34034 m
.63127 .34701 L
s
.63118 .34019 m
.63285 .34685 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60742 .36726 m
.61389 .36677 L
s
.61381 .35994 m
.61708 .36424 L
s
.61336 .31915 m
.61389 .36677 L
s
.61175 .31929 m
.61228 .3669 L
s
.42643 .3618 m
.42807 .35966 L
s
.42807 .35966 m
.42965 .36206 L
s
.42962 .36434 m
.42965 .36206 L
s
.42799 .3665 m
.42962 .36434 L
s
.42643 .3618 m
.42801 .36421 L
s
.61708 .36424 m
.62032 .36625 L
s
.63127 .34701 m
.63133 .35156 L
s
.63285 .34685 m
.63292 .35141 L
s
.42317 .36609 m
.42799 .3665 L
s
.41536 .35169 m
.41686 .35868 L
s
.62983 .35855 m
.63133 .35156 L
s
.62032 .36625 m
.62353 .36598 L
s
.63142 .3584 m
.63292 .35141 L
s
.42 .36353 m
.42317 .36609 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41686 .35868 m
.42 .36353 L
s
.62353 .36598 m
.6267 .36341 L
s
.62353 .36598 m
.6283 .36327 L
s
.6267 .36341 m
.62983 .35855 L
s
.6283 .36327 m
.63142 .3584 L
s
.39207 .33091 m
.39669 .33375 L
s
.39669 .33375 m
.39975 .33866 L
s
.39975 .33866 m
.40125 .34339 L
s
.39207 .33091 m
.39514 .33356 L
s
.39514 .33356 m
.39818 .33848 L
s
.39818 .33848 m
.39968 .34321 L
s
.40125 .34339 m
.40271 .3504 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64604 .35032 m
.64608 .35274 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64212 .33222 m
.65304 .33095 L
s
.3767 .32889 m
.39207 .33091 L
s
.39968 .34321 m
.40114 .35023 L
s
.40883 .36477 m
.41518 .36538 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40255 .36183 m
.40271 .3504 L
s
.40097 .36166 m
.40114 .35023 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65922 .33017 m
.66993 .32872 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40087 .36853 m
.40255 .36183 L
s
.38198 .37788 m
.38281 .32973 L
s
.3993 .36836 m
.40097 .36166 L
s
.38044 .37769 m
.38128 .32952 L
s
.64876 .3566 m
.65196 .36082 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39923 .37295 m
.40087 .36853 L
s
.39766 .37278 m
.3993 .36836 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64682 .33169 m
.64755 .37971 L
s
.64838 .3315 m
.64912 .37954 L
s
.65196 .36082 m
.65666 .36256 L
s
.66536 .32935 m
.6658 .35452 L
s
.66383 .32956 m
.66427 .35472 L
s
.39602 .37721 m
.39923 .37295 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64283 .38021 m
.64912 .37954 L
s
.39445 .37704 m
.39766 .37278 L
s
.65666 .36256 m
.65976 .36219 L
s
.39129 .37899 m
.39602 .37721 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67599 .32784 m
.68646 .32621 L
s
.5 Mabswid
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65976 .36219 m
.66281 .35951 L
s
.65976 .36219 m
.66435 .35931 L
s
.39129 .37899 m
.39445 .37704 L
s
.66281 .35951 m
.66427 .35472 L
s
.66435 .35931 m
.6658 .35452 L
s
.6805 .32715 m
.68112 .35931 L
s
.37583 .3771 m
.39129 .37899 L
s
.68199 .32692 m
.68262 .35908 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67659 .35996 m
.68262 .35908 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69398 .33187 m
.69682 .32677 L
s
.69266 .33902 m
.69398 .33187 L
s
.69682 .32677 m
.70113 .3237 L
s
.69545 .33162 m
.69827 .32651 L
s
.69413 .33877 m
.69545 .33162 L
s
.69266 .33902 m
.69276 .34362 L
s
.69827 .32651 m
.70113 .3237 L
s
.69413 .33877 m
.69423 .34338 L
s
.69276 .34362 m
.69437 .3503 L
s
.70113 .3237 m
.70402 .32317 L
s
.67988 .37338 m
.68134 .37085 L
s
.67988 .37338 m
.68143 .37548 L
s
.68134 .37085 m
.68289 .37295 L
s
.69423 .34338 m
.69584 .35005 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70402 .32317 m
.70838 .32466 L
s
.68143 .37548 m
.68289 .37295 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69584 .35005 m
.69887 .35418 L
s
.69437 .3503 m
.69741 .35443 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70838 .32466 m
.71134 .32872 L
s
.69741 .35443 m
.70184 .356 L
s
.69887 .35418 m
.70184 .356 L
s
.70184 .356 m
.70619 .35524 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70886 .34544 m
.71023 .34286 L
s
.70886 .34544 m
.71034 .3475 L
s
.71023 .34286 m
.71172 .34491 L
s
.70619 .35524 m
.70901 .3524 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71172 .34491 m
.71177 .34723 L
s
.70901 .3524 m
.71177 .34723 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72103 .3198 m
.72254 .32413 L
s
.72103 .3198 m
.72126 .32905 L
s
.72126 .32905 m
.72254 .32413 L
s
.72254 .32413 m
.72387 .32152 L
s
.72387 .32152 m
.72657 .31861 L
s
.72657 .31861 m
.73204 .31738 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7216 .34297 m
.72294 .34036 L
s
.7216 .34297 m
.72171 .34762 L
s
.72294 .34036 m
.72566 .33746 L
s
.72166 .34529 m
.72299 .34268 L
s
.72299 .34268 m
.72571 .33978 L
s
.72171 .34762 m
.72317 .34966 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72566 .33746 m
.7324 .33131 L
s
.73204 .31738 m
.73481 .31907 L
s
.72571 .33978 m
.73246 .33364 L
s
.72317 .34966 m
.726 .35142 L
s
.73481 .31907 m
.73621 .32108 L
s
.7324 .33131 m
.73505 .32837 L
s
.726 .35142 m
.73151 .35026 L
s
.73621 .32108 m
.7364 .32806 L
s
.73246 .33364 m
.73511 .3307 L
s
.73505 .32837 m
.73634 .32573 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73511 .3307 m
.7364 .32806 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73151 .35026 m
.73418 .34733 L
s
.73418 .34733 m
.73548 .34469 L
s
.73548 .34469 m
.7367 .33971 L
s
.7367 .33971 m
.73695 .34906 L
s
.73548 .34469 m
.73695 .34906 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74545 .31649 m
.74669 .31383 L
s
.74545 .31649 m
.74682 .31849 L
s
.29833 .31843 m
.2997 .31643 L
s
.29846 .31377 m
.2997 .31643 L
s
.74669 .31383 m
.74806 .31582 L
s
.29709 .31576 m
.29846 .31377 L
s
.74682 .31849 m
.74806 .31582 L
s
.29709 .31576 m
.29833 .31843 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74715 .33016 m
.74924 .358 L
s
.74661 .35863 m
.74715 .33016 L
s
.29801 .3301 m
.29854 .35858 L
s
.29592 .35795 m
.29801 .3301 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74753 .34422 m
.74792 .35832 L
s
.29723 .35826 m
.29762 .34416 L
s
.28685 .31301 m
.28804 .3157 L
s
.28784 .32272 m
.28804 .3157 L
s
.28441 .30995 m
.28685 .31301 L
s
.74661 .35863 m
.74805 .36303 L
s
.2971 .36297 m
.29854 .35858 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28657 .32238 m
.28791 .32038 L
s
.28651 .32472 m
.28784 .32272 L
s
.27945 .30851 m
.28441 .30995 L
s
.74805 .36303 m
.74924 .358 L
s
.28399 .32402 m
.28657 .32238 L
s
.29592 .35795 m
.2971 .36297 L
s
.2861 .33883 m
.2875 .33446 L
s
.28723 .34388 m
.2875 .33446 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28392 .32637 m
.28651 .32472 L
s
.27766 .32695 m
.28399 .32402 L
s
.27759 .32931 m
.28392 .32637 L
s
.27694 .31012 m
.27945 .30851 L
s
.28476 .34084 m
.2861 .33883 L
s
.2861 .33883 m
.28723 .34388 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28219 .34252 m
.28476 .34084 L
s
.27566 .3121 m
.27694 .31012 L
s
.27459 .30703 m
.27566 .3121 L
s
.2743 .31644 m
.27459 .30703 L
s
.2743 .31644 m
.27566 .3121 L
s
.27723 .34112 m
.28219 .34252 L
s
.27515 .32859 m
.27766 .32695 L
s
.27508 .33095 m
.27759 .32931 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27387 .33059 m
.27515 .32859 L
s
.2738 .33296 m
.27508 .33095 L
s
.27486 .33805 m
.27723 .34112 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27372 .33532 m
.27387 .33059 L
s
.27372 .33532 m
.27486 .33805 L
s
.2639 .30594 m
.26607 .31144 L
s
.26055 .30239 m
.2639 .30594 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25829 .30159 m
.26055 .30239 L
s
.26547 .33038 m
.26555 .32801 L
s
.26446 .32526 m
.26555 .32801 L
s
.26322 .32725 m
.26446 .32526 L
s
.26299 .33438 m
.26547 .33038 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26322 .32725 m
.26431 .33 L
s
.25598 .30315 m
.25829 .30159 L
s
.25487 .30275 m
.25829 .30159 L
s
.26061 .336 m
.26299 .33438 L
s
.25362 .30709 m
.25598 .30315 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25252 .30668 m
.25487 .30275 L
s
.2572 .33486 m
.26061 .336 L
s
.25228 .31382 m
.25362 .30709 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25119 .31341 m
.25252 .30668 L
s
.25504 .3317 m
.2572 .33486 L
s
.25393 .33131 m
.2572 .33486 L
s
.25212 .31858 m
.25228 .31382 L
s
.25298 .32614 m
.25504 .3317 L
s
.25212 .31858 m
.25298 .32614 L
s
.25103 .31818 m
.25119 .31341 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25188 .32574 m
.25393 .33131 L
s
.25103 .31818 m
.25188 .32574 L
s
.24013 .29448 m
.24738 .29747 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24308 .32971 m
.24423 .2962 L
s
.24204 .3293 m
.2432 .29577 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23896 .32806 m
.24308 .32971 L
s
.22941 .2896 m
.23614 .29273 L
s
.81006 .29237 m
.81949 .28785 L
s
.24146 .34616 m
.24258 .34415 L
s
.24162 .34134 m
.24258 .34415 L
s
.2405 .34335 m
.24162 .34134 L
s
.23226 .31786 m
.23321 .2914 L
s
.2405 .34335 m
.24146 .34616 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81296 .29103 m
.81478 .34173 L
s
.2313 .31743 m
.23225 .29095 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81392 .29058 m
.81574 .34131 L
s
0 0 0 r
.22209 .28213 m
.22247 .28166 L
s
.22118 .28166 m
.2225 .28074 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23113 .32226 m
.23226 .31786 L
s
.23017 .32183 m
.2313 .31743 L
s
.22819 .32339 m
.23113 .32226 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81186 .34298 m
.82136 .33876 L
s
.81949 .28785 m
.82138 .28934 L
s
.81949 .28785 m
.82227 .28888 L
s
.21957 .2845 m
.22573 .28777 L
s
.22819 .32339 m
.23017 .32183 L
s
.82138 .28934 m
.82333 .29325 L
s
.22632 .32252 m
.22819 .32339 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82227 .28888 m
.82421 .29279 L
s
.22367 .31877 m
.22632 .32252 L
s
.82333 .29325 m
.82439 .29763 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22115 .33739 m
.22304 .28638 L
s
.82421 .29279 m
.82526 .29717 L
s
.22206 .31302 m
.22367 .31877 L
s
.82439 .29763 m
.82553 .30445 L
s
.82526 .29717 m
.82639 .30399 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82136 .33876 m
.82309 .33546 L
s
.82136 .33876 m
.82398 .33502 L
s
.82553 .30445 m
.82599 .31661 L
s
.82639 .30399 m
.82685 .31616 L
s
.82902 .28269 m
.8346 .2793 L
s
.82309 .33546 m
.82469 .3297 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22027 .33695 m
.22216 .28591 L
s
.82539 .32438 m
.82599 .31661 L
s
.82398 .33502 m
.82557 .32926 L
s
.82469 .3297 m
.82539 .32438 L
s
.21765 .33563 m
.22115 .33739 L
s
.82626 .32393 m
.82685 .31616 L
s
.82557 .32926 m
.82626 .32393 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83146 .28125 m
.83277 .3154 L
s
.83226 .28076 m
.83357 .31494 L
s
.2121 .28262 m
.2135 .28846 L
s
.2135 .28846 m
.21403 .29624 L
s
.21384 .30111 m
.21403 .29624 L
s
.21132 .28214 m
.2127 .28798 L
s
.2127 .28798 m
.21322 .29576 L
s
.20988 .27872 m
.2121 .28262 L
s
.21275 .30797 m
.21384 .30111 L
s
.21303 .30064 m
.21322 .29576 L
s
.83032 .31678 m
.83357 .31494 L
s
.20988 .27872 m
.21132 .28214 L
s
.21195 .30751 m
.21303 .30064 L
s
.83301 .30026 m
.83408 .30712 L
s
.20337 .25661 m
.2083 .26019 L
s
.21098 .31194 m
.21275 .30797 L
s
.20838 .27774 m
.20988 .27872 L
s
.21019 .31147 m
.21195 .30751 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83408 .30712 m
.83583 .31109 L
s
.20681 .27919 m
.20838 .27774 L
s
.20855 .31299 m
.21098 .31194 L
s
.20412 .31014 m
.20614 .25866 L
s
.20855 .31299 m
.21019 .31147 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20341 .30966 m
.20544 .25815 L
s
.20518 .28309 m
.20681 .27919 L
s
.83583 .31109 m
.83746 .3126 L
s
.20704 .31204 m
.20855 .31299 L
s
.83746 .3126 m
.83969 .31118 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83876 .30674 m
.8396 .30872 L
s
.83876 .30674 m
.8394 .3038 L
s
.20566 .30863 m
.20704 .31204 L
s
.8394 .3038 m
.84023 .30578 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20441 .30275 m
.20566 .30863 L
s
.83969 .31118 m
.84033 .30824 L
s
.84023 .30578 m
.84033 .30824 L
s
.2007 .27221 m
.20135 .27272 L
s
.20132 .30822 m
.20412 .31014 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19931 .27365 m
.2007 .27221 L
s
.19995 .27416 m
.2007 .27221 L
s
.84421 .28019 m
.84467 .27476 L
s
.84421 .28019 m
.8444 .28511 L
s
.84467 .27476 m
.84649 .27077 L
s
.8444 .28511 m
.84526 .28954 L
s
.84487 .27968 m
.84532 .27425 L
s
.84487 .27968 m
.84506 .28461 L
s
.84532 .27425 m
.84649 .27077 L
s
.19911 .27858 m
.19995 .27416 L
s
.84506 .28461 m
.84591 .28904 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19848 .27807 m
.19931 .27365 L
s
.84649 .27077 m
.84834 .26922 L
s
.84526 .28954 m
.84729 .29051 L
s
.19842 .29587 m
.19911 .27858 L
s
.84591 .28904 m
.84729 .29051 L
s
.19745 .27211 m
.19848 .27807 L
s
.19759 .30033 m
.19848 .27807 L
s
.84565 .29942 m
.84575 .30189 L
s
.84565 .29942 m
.84631 .29893 L
s
.84575 .30189 m
.8465 .30388 L
s
.19634 .26861 m
.19745 .27211 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85073 .28995 m
.85079 .29146 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84631 .29893 m
.84641 .3014 L
s
.84834 .26922 m
.84962 .27065 L
s
.19759 .30033 m
.19842 .29587 L
s
.8465 .30388 m
.84788 .30538 L
s
.19461 .26704 m
.19634 .26861 L
s
.19726 .29239 m
.19779 .29537 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1938 .28688 m
.19726 .29239 L
s
.19686 .30231 m
.19759 .30033 L
s
.84962 .27065 m
.85098 .27456 L
s
.19554 .30381 m
.19686 .30231 L
s
.1934 .26847 m
.19461 .26704 L
s
.19285 .26795 m
.19461 .26704 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84788 .30538 m
.85034 .3034 L
s
.84729 .29051 m
.85101 .28996 L
s
.85098 .27456 m
.85134 .26909 L
s
.85098 .27456 m
.85189 .29692 L
s
.85134 .26909 m
.85233 .26556 L
s
.19319 .30181 m
.19554 .30381 L
s
.85154 .27404 m
.85189 .26857 L
s
.85154 .27404 m
.85225 .29143 L
s
.85189 .26857 m
.85233 .26556 L
s
.19265 .27291 m
.1934 .26847 L
s
.85101 .28996 m
.85168 .29194 L
s
.85233 .26556 m
.85287 .26504 L
s
.85034 .3034 m
.85141 .29991 L
s
.19212 .27238 m
.19285 .26795 L
s
.19279 .28336 m
.1938 .28688 L
s
.19224 .28285 m
.1938 .28688 L
s
.19245 .27788 m
.19265 .27291 L
s
.85141 .29991 m
.85189 .29692 L
s
.85189 .29692 m
.85225 .29143 L
s
.19245 .27788 m
.19279 .28336 L
s
.19191 .27736 m
.19212 .27238 L
s
.19191 .27736 m
.19224 .28285 L
s
.19218 .29831 m
.19319 .30181 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19184 .29281 m
.19238 .29332 L
s
.19228 .29582 m
.19238 .29332 L
s
0 0 0 r
.18292 .24872 m
.18459 .25074 L
s
.255 .412 .882 r
.19173 .29531 m
.19218 .29831 L
s
.19173 .29531 m
.19184 .29281 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85535 .29888 m
.85873 .2953 L
s
.85728 .26023 m
.86046 .29323 L
s
.85686 .29735 m
.85728 .26023 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86225 .25204 m
.86281 .24827 L
s
.255 .412 .882 r
.85734 .29684 m
.85759 .26772 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18212 .30046 m
.18299 .27986 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86281 .24827 m
.86361 .24715 L
s
.18212 .30046 m
.18248 .30086 L
s
.255 .412 .882 r
.18734 .28818 m
.1877 .29121 L
s
.18759 .29372 m
.1877 .29121 L
s
.18703 .29572 m
.18759 .29372 L
s
.18678 .29017 m
.18734 .28818 L
s
.18369 .25414 m
.18632 .25797 L
s
.18678 .29017 m
.18713 .2932 L
s
.18569 .29417 m
.18703 .29572 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18366 .29157 m
.18513 .25634 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86046 .29323 m
.86056 .25589 L
s
.18495 .29061 m
.18569 .29417 L
s
.18328 .29104 m
.18476 .25579 L
s
0 0 0 r
.86412 .2964 m
.86493 .29847 L
s
.255 .412 .882 r
.86087 .29271 m
.86088 .26342 L
s
.18436 .28452 m
.18495 .29061 L
s
0 0 0 r
.86531 .32462 m
.86558 .32432 L
s
.255 .412 .882 r
.18429 .27643 m
.18436 .28452 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86056 .25589 m
.86347 .28904 L
s
.1822 .28947 m
.18366 .29157 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86241 .29061 m
.86443 .28745 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17603 .23626 m
.17669 .23785 L
s
.255 .412 .882 r
.18096 .27105 m
.18181 .25082 L
s
.1799 .26888 m
.18185 .27268 L
s
.18068 .27051 m
.18153 .25027 L
s
.1809 .25168 m
.18121 .25785 L
s
0 0 0 r
.86911 .23698 m
.86911 .23694 L
s
.255 .412 .882 r
.18029 .24747 m
.1809 .25168 L
s
0 0 0 r
.17449 .28881 m
.17669 .23798 L
s
.255 .412 .882 r
.86487 .26191 m
.86491 .25629 L
s
.86487 .26191 m
.86493 .27006 L
s
.86491 .25629 m
.86516 .25011 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86493 .27006 m
.86547 .28278 L
s
0 0 0 r
.87034 .26551 m
.87163 .26203 L
s
.86911 .23694 m
.86952 .23579 L
s
.255 .412 .882 r
.86512 .26136 m
.86515 .25573 L
s
.86512 .26136 m
.8652 .26952 L
s
.17987 .24635 m
.18029 .24747 L
s
.86515 .25573 m
.86538 .24955 L
s
.8652 .26952 m
.86574 .28224 L
s
.86516 .25011 m
.86569 .24589 L
s
.17955 .30414 m
.1802 .28884 L
s
.1796 .29596 m
.1802 .28884 L
s
.86538 .24955 m
.86569 .24589 L
s
.86547 .28278 m
.86606 .28989 L
s
0 0 0 r
.86952 .23579 m
.87005 .23825 L
s
.86952 .23579 m
.87022 .23768 L
s
.255 .412 .882 r
.17937 .24776 m
.17987 .24635 L
s
.17919 .2472 m
.17987 .24635 L
s
0 0 0 r
.17449 .28881 m
.17449 .28881 L
s
.255 .412 .882 r
.86574 .28224 m
.86631 .28936 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17885 .30002 m
.1796 .29596 L
s
.17955 .30414 m
.1796 .29596 L
s
.86569 .24589 m
.86606 .24476 L
s
.86606 .28989 m
.86653 .29447 L
s
0 0 0 r
.87005 .23825 m
.87069 .24437 L
s
.255 .412 .882 r
.17881 .25173 m
.17937 .24776 L
s
.86631 .28936 m
.86677 .29394 L
s
.86606 .24476 m
.86664 .24561 L
s
0 0 0 r
.87022 .23768 m
.87084 .2438 L
s
.255 .412 .882 r
.17865 .25117 m
.17919 .2472 L
s
.86653 .29447 m
.86723 .29854 L
s
.17801 .30101 m
.17885 .30002 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86677 .29394 m
.86745 .29801 L
s
0 0 0 r
.8713 .28782 m
.87172 .28675 L
s
.255 .412 .882 r
.17843 .25627 m
.17881 .25173 L
s
0 0 0 r
.87131 .25473 m
.87069 .24437 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86664 .24561 m
.86713 .24959 L
s
.17828 .25571 m
.17865 .25117 L
s
.86723 .29854 m
.86798 .29953 L
s
0 0 0 r
.17355 .3108 m
.17355 .31079 L
s
.87145 .25416 m
.87084 .2438 L
s
.255 .412 .882 r
.17758 .29996 m
.17801 .30101 L
s
.17795 .26338 m
.17843 .25627 L
s
.86745 .29801 m
.86798 .29953 L
s
0 0 0 r
.17355 .3108 m
.17355 .3108 L
s
.17458 .23526 m
.17442 .22987 L
s
.17439 .24312 m
.17458 .23526 L
s
.255 .412 .882 r
.17782 .26283 m
.17828 .25571 L
s
0 0 0 r
.87172 .28675 m
.87194 .282 L
s
.87172 .28675 m
.87211 .28145 L
s
.87163 .26203 m
.87131 .25473 L
s
.17446 .23468 m
.17442 .22987 L
s
.17426 .24254 m
.17446 .23468 L
s
.255 .412 .882 r
.1773 .29633 m
.17758 .29996 L
s
.17711 .2958 m
.17758 .29996 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86692 .24136 m
.8678 .26182 L
s
.8668 .24193 m
.86768 .26238 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17741 .2762 m
.17795 .26338 L
s
0 0 0 r
.87177 .26147 m
.87145 .25416 L
s
.87194 .282 m
.87196 .27357 L
s
.87163 .26203 m
.87196 .27357 L
s
.255 .412 .882 r
.86798 .29953 m
.86835 .29847 L
s
0 0 0 r
.87133 .22588 m
.87095 .22998 L
s
.17442 .22987 m
.17426 .22871 L
s
.255 .412 .882 r
.17727 .27566 m
.17782 .26283 L
s
.17716 .29013 m
.1773 .29633 L
s
0 0 0 r
.87211 .28145 m
.87211 .27302 L
s
.87211 .27302 m
.87177 .26147 L
s
.17309 .28502 m
.17251 .28284 L
s
.255 .412 .882 r
.177 .28959 m
.17711 .2958 L
s
.17722 .28445 m
.17741 .2762 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17251 .28284 m
.17426 .24254 L
s
.17264 .28339 m
.17439 .24312 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17716 .29013 m
.17722 .28445 L
s
.86835 .29847 m
.86873 .29431 L
s
0 0 0 r
.17426 .22871 m
.17395 .23061 L
s
.255 .412 .882 r
.17708 .28391 m
.17727 .27566 L
s
.177 .28959 m
.17708 .28391 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86873 .29431 m
.86878 .28808 L
s
0 0 0 r
.87118 .22823 m
.87293 .26857 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .23794 m
.86751 .23393 L
s
.86726 .26404 m
.86809 .26016 L
s
.86857 .27981 m
.86923 .29529 L
s
.86857 .27981 m
.86878 .28808 L
s
.86878 .28808 m
.86923 .29529 L
s
0 0 0 r
.17395 .23061 m
.17358 .23677 L
s
.255 .412 .882 r
.17634 .27277 m
.1767 .27605 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17405 .22577 m
.17408 .22342 L
s
.17181 .27735 m
.17405 .22577 L
s
.255 .412 .882 r
.17648 .27441 m
.17787 .23612 L
s
.17633 .27002 m
.17787 .23612 L
s
0 0 0 r
.1718 .27679 m
.17405 .22519 L
s
.255 .412 .882 r
.17631 .27057 m
.17754 .24383 L
s
0 0 0 r
.87331 .2754 m
.87293 .26857 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86753 .23565 m
.86908 .27177 L
s
.86752 .23622 m
.86907 .27232 L
s
0 0 0 r
.87123 .22764 m
.87299 .26802 L
s
.87335 .27485 m
.87299 .26802 L
s
.255 .412 .882 r
.86896 .27396 m
.86908 .27177 L
s
0 0 0 r
.87086 .21939 m
.87131 .22353 L
s
.87357 .27745 m
.87331 .2754 L
s
.255 .412 .882 r
.86841 .25625 m
.86875 .26345 L
s
0 0 0 r
.17191 .279 m
.1718 .27679 L
s
.87357 .27745 m
.87335 .27485 L
s
.87118 .22176 m
.87295 .26241 L
s
.255 .412 .882 r
.86875 .26345 m
.86895 .26752 L
s
0 0 0 r
.87112 .22117 m
.87289 .26185 L
s
.87359 .27634 m
.87357 .27745 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17633 .27002 m
.17807 .23152 L
s
0 0 0 r
.17436 .22047 m
.17413 .22726 L
s
.17372 .23523 m
.17436 .22047 L
s
.255 .412 .882 r
.86895 .26752 m
.869 .26902 L
s
0 0 0 r
.87337 .27096 m
.87359 .27634 L
s
.17413 .22726 m
.17372 .23523 L
s
.17439 .22298 m
.17413 .22726 L
s
.17478 .2181 m
.17439 .22298 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86881 .26736 m
.869 .26902 L
s
0 0 0 r
.87295 .26241 m
.87337 .27096 L
s
.17537 .21573 m
.17478 .2181 L
s
.87321 .26929 m
.87295 .26241 L
s
.255 .412 .882 r
.86866 .26271 m
.8687 .26476 L
s
.86848 .25955 m
.86866 .26271 L
s
.86848 .25955 m
.86851 .2616 L
s
0 0 0 r
.87314 .26873 m
.87289 .26185 L
s
.255 .412 .882 r
.17651 .26782 m
.17725 .26395 L
s
0 0 0 r
.86906 .21288 m
.87036 .21703 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17275 .25747 m
.173 .25318 L
s
.17243 .26491 m
.17275 .25747 L
s
.173 .25318 m
.17337 .24833 L
s
.255 .412 .882 r
.86862 .26421 m
.86881 .26736 L
s
.86851 .2616 m
.86862 .26421 L
s
0 0 0 r
.17259 .26119 m
.17284 .2569 L
s
.87312 .27135 m
.87321 .26929 L
s
.17284 .2569 m
.17321 .25205 L
s
.17235 .26807 m
.17243 .26491 L
s
.87312 .27135 m
.87314 .26873 L
s
.17337 .24833 m
.1744 .23801 L
s
.17557 .21826 m
.17537 .21573 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17677 .26616 m
.17747 .24681 L
s
.17687 .26561 m
.17754 .24669 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17321 .25205 m
.17424 .24174 L
s
.1724 .27069 m
.17235 .26807 L
s
.255 .412 .882 r
.86623 .22845 m
.86662 .23422 L
s
.86685 .23943 m
.86662 .23422 L
s
0 0 0 r
.87289 .27024 m
.87312 .27135 L
s
.17561 .22138 m
.17557 .21826 L
s
.255 .412 .882 r
.86605 .22787 m
.86645 .23365 L
s
.86668 .23886 m
.86645 .23365 L
s
0 0 0 r
.17294 .26847 m
.1724 .27069 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86668 .2393 m
.86672 .24351 L
s
.86685 .24002 m
.8669 .24408 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1744 .23801 m
.17493 .23313 L
s
.17513 .23255 m
.17561 .22138 L
s
.17424 .24174 m
.17477 .23686 L
s
.87231 .26482 m
.87289 .27024 L
s
.255 .412 .882 r
.86644 .24499 m
.8669 .24408 L
s
0 0 0 r
.17493 .23313 m
.17529 .22882 L
s
.255 .412 .882 r
.86644 .24499 m
.86672 .24351 L
s
0 0 0 r
.17477 .23686 m
.17513 .23255 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86735 .25453 m
.86746 .25715 L
s
.86717 .25397 m
.86735 .25453 L
s
.86739 .25921 m
.86746 .25715 L
s
0 0 0 r
.87165 .25621 m
.87231 .26482 L
s
.255 .412 .882 r
.86717 .25397 m
.86728 .25659 L
s
0 0 0 r
.17345 .2636 m
.17294 .26847 L
s
.1738 .25929 m
.17345 .2636 L
s
.17432 .25123 m
.1738 .25929 L
s
.17367 .26624 m
.17432 .25123 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86969 .21466 m
.87195 .2669 L
s
.86987 .21525 m
.87214 .26745 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86592 .20635 m
.86808 .2105 L
s
.1738 .25929 m
.17367 .26624 L
s
.87133 .26522 m
.87214 .26745 L
s
.17748 .21353 m
.17792 .20921 L
s
.17748 .21353 m
.1776 .21668 L
s
.17792 .20921 m
.17806 .21235 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1776 .21668 m
.17806 .21235 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86691 .20813 m
.86918 .26076 L
s
.86722 .20872 m
.86948 .26132 L
s
.17514 .28017 m
.17679 .23541 L
s
.17455 .28126 m
.17679 .23541 L
s
.17484 .28072 m
.17582 .258 L
s
.8614 .19984 m
.86443 .20398 L
s
.86818 .25909 m
.86948 .26132 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17451 .28832 m
.17455 .28126 L
s
.8632 .2022 m
.86497 .24378 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86277 .20161 m
.86454 .24322 L
s
.17451 .28832 m
.17514 .28017 L
s
.87032 .28734 m
.87046 .28407 L
s
.86999 .27973 m
.87046 .28407 L
s
.86984 .28299 m
.86999 .27973 L
s
.86984 .28299 m
.87032 .28734 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85697 .21231 m
.85701 .21222 L
s
.85647 .21174 m
.85698 .21139 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18519 .24902 m
.18564 .24844 L
s
0 0 0 r
.86486 .25083 m
.86497 .24378 L
s
.86441 .25027 m
.86454 .24322 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85549 .19338 m
.85941 .19749 L
s
.86365 .25297 m
.86486 .25083 L
s
.255 .412 .882 r
.18564 .24844 m
.18669 .24467 L
s
0 0 0 r
.86365 .25297 m
.86441 .25027 L
s
.255 .412 .882 r
.8583 .24422 m
.85836 .24444 L
s
.8578 .24367 m
.8584 .24531 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85613 .22698 m
.85622 .22921 L
s
.85707 .23777 m
.8583 .24422 L
s
.85622 .22921 m
.85707 .23777 L
s
0 0 0 r
.86267 .25187 m
.86365 .25297 L
s
.255 .412 .882 r
.85557 .22565 m
.85569 .22865 L
s
.85656 .23722 m
.8578 .24367 L
s
.85569 .22865 m
.85656 .23722 L
s
0 0 0 r
.86096 .24638 m
.86267 .25187 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85955 .2376 m
.86096 .24638 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8578 .19572 m
.86117 .27606 L
s
.85724 .19514 m
.8606 .27553 L
s
.85047 .19255 m
.85215 .20134 L
s
.255 .412 .882 r
.20577 .19445 m
.20601 .19427 L
s
0 0 0 r
.84818 .187 m
.85047 .19255 L
s
.8467 .18585 m
.84818 .187 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85884 .27393 m
.86117 .27606 L
s
.85325 .22819 m
.85341 .23204 L
s
.85242 .22379 m
.85325 .22819 L
s
.84533 .18854 m
.8467 .18585 L
s
.84455 .18797 m
.8467 .18585 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85189 .22708 m
.85242 .22379 L
s
.85236 .23866 m
.85341 .23204 L
s
.85189 .22708 m
.85273 .23149 L
s
.84407 .19509 m
.84533 .18854 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84327 .19453 m
.84455 .18797 L
s
.85111 .24144 m
.85236 .23866 L
s
.84373 .2061 m
.84407 .19509 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84889 .23982 m
.85111 .24144 L
s
.84292 .20555 m
.84327 .19453 L
s
.84373 .2061 m
.84404 .21384 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84721 .23486 m
.84889 .23982 L
s
.84642 .23432 m
.84889 .23982 L
s
.84292 .20555 m
.84323 .21329 L
s
.84404 .21384 m
.84532 .22601 L
s
.84532 .22601 m
.84721 .23486 L
s
.84323 .21329 m
.84451 .22547 L
s
.84451 .22547 m
.84642 .23432 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82537 .17239 m
.83228 .17624 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83855 .2217 m
.83959 .22613 L
s
.83959 .22613 m
.83974 .23003 L
s
.8378 .22507 m
.83855 .2217 L
s
.83901 .23341 m
.83974 .23003 L
s
.8378 .22507 m
.83885 .2295 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83627 .23183 m
.83901 .23341 L
s
.8284 .17403 m
.8305 .22871 L
s
.82939 .17458 m
.83149 .22923 L
s
.83424 .22687 m
.83627 .23183 L
s
.83059 .20572 m
.83202 .21798 L
s
.81681 .16808 m
.8233 .1713 L
s
.83202 .21798 m
.83424 .22687 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81601 .23751 m
.8201 .16969 L
s
.81644 .24947 m
.82118 .17022 L
s
.82746 .22717 m
.83149 .22923 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80837 .18747 m
.81879 .19209 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80263 .16182 m
.80992 .16492 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8051 .16284 m
.81644 .24947 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29151 .14567 m
.3007 .14343 L
s
.5 Mabswid
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29392 .22935 m
.29634 .14439 L
s
.29556 .22897 m
.29797 .14397 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3007 .14343 m
.31823 .13916 L
s
.31649 .13955 m
.31761 .16338 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29672 .18827 m
.30674 .18592 L
s
.31761 .16338 m
.31823 .13916 L
s
.3063 .20219 m
.30718 .16972 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72053 .17295 m
.72059 .17504 L
s
.72146 .21005 m
.72146 .21012 L
s
.72231 .17447 m
.72233 .17533 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33596 .13953 m
.34156 .13445 L
s
.33395 .14797 m
.33596 .13953 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33779 .13918 m
.34156 .13445 L
s
.33577 .14763 m
.33779 .13918 L
s
.33288 .19278 m
.33395 .14797 L
s
.34156 .13445 m
.34527 .13377 L
s
.33472 .19245 m
.33577 .14763 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34527 .13377 m
.3508 .13684 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28904 .23051 m
.29832 .22847 L
s
.5 Mabswid
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29832 .22847 m
.31603 .22459 L
s
.31427 .22494 m
.31666 .19999 L
s
.31603 .22459 m
.31666 .19999 L
s
.3508 .13684 m
.35441 .14432 L
s
.35467 .13215 m
.36232 .1309 L
s
.35346 .18931 m
.35467 .13215 L
s
.35538 .18901 m
.35657 .13183 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32744 .1938 m
.33472 .19245 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37788 .13266 m
.38392 .12779 L
s
.37378 .14137 m
.37788 .13266 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37986 .13239 m
.38392 .12779 L
s
.37575 .14109 m
.37986 .13239 L
s
.37158 .1539 m
.37378 .14137 L
s
.38392 .12779 m
.38792 .12727 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37355 .15362 m
.37575 .14109 L
s
.38792 .12727 m
.39189 .13084 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34776 .19022 m
.35538 .18901 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37142 .16209 m
.37158 .1539 L
s
.37339 .16181 m
.37355 .15362 L
s
.39189 .13084 m
.39581 .13853 L
s
.39601 .12627 m
.40418 .12534 L
s
.37142 .16209 m
.37316 .17413 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37339 .16181 m
.37514 .17386 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37316 .17413 m
.37698 .18184 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42941 .12498 m
.42943 .12345 L
s
.42735 .12384 m
.42736 .12357 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37514 .17386 m
.37897 .18158 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42072 .12775 m
.42707 .12309 L
s
.41643 .13634 m
.42072 .12775 L
s
.42281 .12756 m
.42707 .12309 L
s
.42707 .12309 m
.43129 .12274 L
s
.41852 .13614 m
.42281 .12756 L
s
.43129 .12274 m
.43548 .12649 L
s
.43129 .12274 m
.4376 .12633 L
s
.37698 .18184 m
.38291 .1852 L
s
.41418 .14885 m
.41643 .13634 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39462 .21285 m
.39601 .12627 L
s
.39668 .21263 m
.39804 .12603 L
s
.41627 .14866 m
.41852 .13614 L
s
.37897 .18158 m
.38291 .1852 L
s
.43548 .12649 m
.43964 .13438 L
s
.4376 .12633 m
.44178 .13422 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41407 .15709 m
.41418 .14885 L
s
.38291 .1852 m
.38695 .18471 L
s
.41615 .15689 m
.41627 .14866 L
s
.39107 .18011 m
.39529 .17139 L
s
.45476 .12106 m
.46773 .12036 L
s
.59016 .12103 m
.59235 .12527 L
s
.58804 .12501 m
.59016 .12103 L
s
.38695 .18471 m
.39107 .18011 L
s
.43964 .13438 m
.44165 .14657 L
s
.41407 .15709 m
.41599 .16927 L
s
.44178 .13422 m
.44379 .14642 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41615 .15689 m
.41809 .16908 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58804 .12501 m
.59023 .12924 L
s
.59023 .12924 m
.59235 .12527 L
s
.255 .412 .882 r
.42638 .16814 m
.42683 .16749 L
s
0 0 0 r
.47642 .11997 m
.48952 .11951 L
s
.55758 .11956 m
.56632 .11986 L
s
.56632 .11986 m
.5707 .12415 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4269 .16117 m
.42691 .1609 L
s
.42897 .16233 m
.42899 .16078 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45907 .12081 m
.48487 .17754 L
s
.45861 .17864 m
.48296 .11972 L
s
.46078 .17853 m
.48515 .11965 L
s
.5707 .12415 m
.5729 .12835 L
s
.55322 .12355 m
.55758 .11956 L
s
.54882 .11933 m
.55104 .1276 L
s
.54882 .11933 m
.54888 .13579 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5729 .12835 m
.57298 .1407 L
s
.44157 .15482 m
.44165 .14657 L
s
.52905 .11905 m
.53785 .11913 L
s
.50926 .12322 m
.51366 .11907 L
s
.51366 .11907 m
.51806 .11904 L
s
.50706 .12325 m
.51366 .11907 L
s
.51806 .11904 m
.52466 .12314 L
s
.41599 .16927 m
.42008 .17717 L
s
.44371 .15467 m
.44379 .14642 L
s
.55104 .1276 m
.55322 .12355 L
s
.41809 .16908 m
.42219 .17699 L
s
.50484 .13151 m
.50706 .12325 L
s
.50704 .13148 m
.50926 .12322 L
s
.52466 .12314 m
.52906 .13139 L
s
.54888 .13579 m
.55104 .1276 L
s
.5708 .14061 m
.57295 .13658 L
s
.4393 .16738 m
.44157 .15482 L
s
.44144 .16723 m
.44371 .15467 L
s
.57082 .14474 m
.57298 .1407 L
s
.56645 .14457 m
.5708 .14061 L
s
.42008 .17717 m
.42637 .18079 L
s
.42219 .17699 m
.42637 .18079 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38849 .21352 m
.39668 .21263 L
s
.56648 .1487 m
.57082 .14474 L
s
.55553 .15248 m
.56645 .14457 L
s
.43493 .17598 m
.4393 .16738 L
s
.43707 .17582 m
.44144 .16723 L
s
.42637 .18079 m
.43062 .18045 L
s
.55555 .15663 m
.56648 .1487 L
s
.43062 .18045 m
.43493 .17598 L
s
.255 .412 .882 r
.48775 .16537 m
.48871 .16406 L
s
0 0 0 r
.43062 .18045 m
.43707 .17582 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53125 .11906 m
.53132 .17699 L
s
.52905 .11905 m
.5291 .17698 L
s
.50474 .17709 m
.50484 .13151 L
s
.50695 .17706 m
.50704 .13148 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55115 .15651 m
.55553 .15248 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57098 .16959 m
.57311 .16138 L
s
.57311 .16138 m
.57322 .178 L
s
.55116 .16066 m
.55555 .15663 L
s
.54896 .16061 m
.55115 .15651 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59041 .14984 m
.59301 .19982 L
s
.58866 .19958 m
.59041 .14984 L
s
.59062 .17469 m
.59083 .1997 L
s
.54897 .16476 m
.55116 .16066 L
s
.54896 .16061 m
.54899 .16892 L
s
.45426 .17887 m
.46732 .17821 L
s
.56881 .17367 m
.57098 .16959 L
s
.57098 .16959 m
.57322 .178 L
s
.56444 .17767 m
.56881 .17367 L
s
.54899 .16892 m
.55121 .17313 L
s
.47608 .17785 m
.48928 .17742 L
s
.55121 .17313 m
.55563 .1774 L
s
.55563 .1774 m
.56444 .17767 L
s
.4981 .17721 m
.50695 .17706 L
s
.52245 .17696 m
.53132 .17699 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58866 .19958 m
.5909 .20807 L
s
.5909 .20807 m
.59301 .19982 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ002P3o
YQ03000000@0ojH@1P0000040?nV40030000002][Jd0ojD@01d0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/
UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00X0ojHA20000002
0?nV4@030:f][@000000000000H000002@2][Jd2000000<0[Jf]0P0000020:f][@030000002][Jd0
000000L0[Jf]00<000000:f][@2][Jd00P2][Jd5000000L0[Jf]103oYA000`000000ojD@0?nU4008
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ430000
00D0ojHA202][Jd00`000000[Jf]0:f][@040:f][@D0ojHA0P0000000`2][Jd0ojH@0?nV40070?nV
408000001P3oYQ001@000000ojH@0000003oYQ00000000L0ojH@00<000000:f][@3oYA000P000005
0?nU40030000003oYA00ojD@00@0ojD@0`2][Jd2000000l0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool0
07`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0=0?nV4@8000001`3oYQ430:f][@040000002][Jd0[Jf]0:f][@8000000`2][Jd9
0?nV4@030000003oYQ40ojHA00L0ojHA0P0000000`3oYQ40[Jf]0?nV40080?nV408000001P3oYQ00
1@000000ojH@0000003oYQ00000000L0ojH@0`0000080?nU40030000003oYA00ojD@00H0ojD@00<0
00000?nU400000002@3oYA000`2][Jd0oj<@0?nS40020?nS40T0[Jf]3P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3o
ool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@060?nV4@040000003oYQ40ojHA0?nV4@<000002@2][Jd20?nV4@80000000@0
[Jf]0?nV4@3oYQ40ojHA0P00000;0?nV4@030000003oYQ40ojHA00L0ojHA0P0000000`3oYQ40[Jf]
0?nV40070?nV40030000003oYQ00000000L0ojH@0P0000000`3oYQ0000000?nV40060?nV40800000
2@3oYA000`000000ojD@0?nU40060?nU408000002P3oYA000`2][Jd0oj<@0?nS400;0?nS40X0[Jf]
103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0
303/UPh30:f][F<0/>3V0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@80[Jf]0P000000102][Jd000000:f]
[@2][Jd2000000/0ojHA0P0000000`3oYQ40[Jf]0?nV4@020?nV4@800000303oYQ400`000000ojHA
0?nV4@050?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40060?nV40800000203oYQ02000000030?nV
40000000ojH@00H0ojH@0P00000:0?nU40030000003oYA00ojD@00H0ojD@00<000000?nU403oYA00
203oYA000`2][Jd0oj<@0?nS400E0?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA0180ojHA0P0000000`3oYQ40[Jf]0:f][@050:f][@800000103o
YQ4010000000ojHA00000000000:0?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000
2`3oYQ400`000000ojHA0?nV4@050?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40050?nV40030000
003oYQ00000000T0ojH@00<000000?nV400000001`3oYQ02000000X0ojD@00<000000?nU403oYA00
4@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0mY`?
0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA0P0000030:f][@80ojHA00@0
[Jf]0?nV4@3oYQ40ojHA0P0000050?nV4@040000003oYQ400000000000T0ojHA0P0000030?nV4@03
0:f][@3oYQ40ojHA0080ojHA0P00000<0?nV4@030000003oYQ40ojHA00<0ojHA0P0000030?nV4@03
0:f][@3oYQ00ojH@00D0ojH@00<000000?nV400000002@3oYQ000`000000ojH@000000070?nV4003
0000002][Jd0ojD@00T0ojD@00<000000?nU403oYA004@3oYA000`2][Jd0oj<@0?nS400I0?nS4003
0:f][@3lX100o:0@00H0o:0@1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@090?nV4@@00000
0`2][Jd2000000D0ojHA00<0[Jf]0?nV4@3oYQ400P0000070?nV4@<000002@3oYQ42000000<0ojHA
00<0[Jf]0?nV4@3oYQ400`3oYQ42000000/0ojHA00<000000?nV4@3oYQ400`3oYQ42000000<0ojHA
00<0[Jf]0?nV403oYQ001@3oYQ000`000000ojH@000000090?nV40030000003oYQ00000000L0ojH@
00<000000:f][@3oYA002@3oYA000`000000ojD@0?nU400A0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1002`3lX1050:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3o
YQ430:f][@030000002][Jd0[Jf]0080ojHA0P0000000`3oYQ400000000000050?nV4@030:f][@3o
YQ40ojHA008000001`3oYQ43000000P0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00
000;0?nV4@030000003oYQ40ojHA0080ojHA0P0000040?nV4@030:f][@3oYQ00ojH@00D0ojH@00<0
00000?nV400000002@3oYQ000`000000ojH@000000070?nV40030000002][Jd0ojD@00T0ojD@00<0
00000?nU403oYA004@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@1P2]
[Jd20?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY143000000030?nV4@2][Jd0[Jf]00<0[Jf]0P3oYQ40
0`000000ojHA0?nV4@040?nV4@040000003oYQ400000000000D0ojHA00@0[Jf]0?nV4@0000000000
2@3oYQ42000000P0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00000<0?nV4@040000
003oYQ40ojHA0?nV4@800000103oYQ400`2][Jd0ojH@0?nV40050?nV40030000003oYQ00000000T0
ojH@00<000000?nV40000000203oYQ000`2][Jd0ojD@0?nU40070?nU408000004`3oYA000`2][Jd0
oj<@0?nS400I0?nS40030:f][@3lX100o:0@01H0o:0@102][JdE0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY144000000040:f][@00000000000:f][@H0
ojHA0P0000070?nV4@<000001@3oYQ40102][Jd0ojHA0000000000090?nV4@800000203oYQ420000
00@0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000`0ojHA00@000000?nV4@3oYQ40ojHA0P000004
0?nV4@030:f][@3oYQ00ojH@00D0ojH@00<000000?nV400000002@3oYQ000`000000ojH@00000008
0?nV40030:f][@3oYA00ojD@00L0ojD@0P00000C0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0:f][@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@00000102][Jd00`3oY1400000000000070?nV
4@8000001`3oYQ43000000D0ojHA00@0[Jf]0?nV4@00000000002@3oYQ42000000L0ojHA0P000004
0?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000<0?nV4@040000003oYQ400000000000D0ojHA00<0
[Jf]0?nV403oYQ001@3oYQ000`000000ojH@000000090?nV40030000003oYQ00000000P0ojH@00<0
[Jf]0?nU403oYA001P3oYA02000001@0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY142000000@0[Jf]1@3oY142000000H0ojHA0P000009
0?nV4@8000001@3oYQ40102][Jd0ojHA0000000000090?nV4@8000001`3oYQ42000000@0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ42000000`0ojHA00@000000?nV4@00000000001@3oYQ400`2][Jd0ojH@
0?nV40050?nV40030000003oYQ00000000T0ojH@00<000000?nV40000000203oYQ000`2][Jd0ojD@
0?nU40050?nU40030000003oYA00000001@0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?00L0mY`?102][Jd90?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@80000000<0
[Jf]0000003oY140203oY142000000H0ojHA0P0000090?nV4@8000001@3oYQ40102][Jd0ojHA0000
000000090?nV4@8000001`3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000d0ojHA
0P0000060?nV4@030:f][@3oYQ00ojH@00D0ojH@00<000000?nV400000002@3oYQ000`000000ojH@
000000080?nV40030:f][@3oYA00ojD@00@0ojD@00<000000?nU400000005@3oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`
h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]0`3o
Y1400`000000oj@A0?nT4@070?nT4@8000001P3oYQ42000000T0ojHA0P0000050?nV4@030:f][@00
0000000000X0ojHA0P0000070?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000003@3o
YQ42000000H0ojHA00<0[Jf]0?nV403oYQ001@3oYQ000`000000ojH@000000090?nV40030000003o
YQ00000000P0ojH@00<0[Jf]0?nU403oYA000P3oYA02000000030?nU40000000ojD@01D0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00l0mY`?102]
[Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`
h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@2][Jd00`2][Jd70?nT4@030000003oY140oj@A00L0oj@A00<000000?nV4@3oYQ401@3oYQ42
000000T0ojHA0P0000050?nV4@030:f][@000000000000X0ojHA0P0000070?nV4@800000103oYQ40
0`2][Jd0ojHA0?nV4@050?nV4@800000303oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ001@3oYQ00
0`000000ojH@000000090?nV40030000003oYQ00000000P0ojH@00D0[Jf]0?nU403oYA00ojD@0000
00020?nU40030000003oYA00ojD@00X0ojD@00<000000?nU403oYA00203oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][A40k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3C
Q`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][@/0oj@A00<000000?nT4@3oY140
1`3oY1400`000000ojHA0?nV4@050?nV4@8000002@3oYQ42000000D0ojHA00<0[Jf]000000000000
2P3oYQ42000000L0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000<0?nV4@<00000
1P3oYQ400`2][Jd0ojH@0?nV40050?nV40030000003oYQ00000000T0ojH@00<000000?nV40000000
203oYQ001@2][Jd0ojD@0?nU40000000ojD@008000003@3oYA000`000000ojD@0?nU40080?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue
2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP
403lX100303lX1020:f][@030?bP402][Jd0oj@A00/0oj@A00<000000?nT4@3oY1401`3oY1400`00
0000ojHA0?nV4@050?nV4@8000002@3oYQ42000000D0ojHA00<0[Jf]0000000000002P3oYQ420000
00L0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000;0?nV4@80000000<0ojHA0000
003oYQ401@3oYQ400`2][Jd0ojH@0?nV40050?nV408000002P3oYQ000`000000ojH@000000080?nV
40050:f][@00000000000?nU400000003`3oYA000`000000ojD@0?nU40080?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/2
0:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A00X0oj@A00<000000?nT
4@3oY1401`3oY1400`000000ojHA0?nV4@050?nV4@8000002@3oYQ42000000D0ojHA00<0[Jf]0000
000000002P3oYQ42000000L0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA00D0ojHA0P00000;0?nV
4@80000000<0ojHA0:f][@0000003@2][Jd2000000X0[Jf]00<000000:f][@000000202][Jd01000
0000[Jf]0:f][@0000040:f][@`0ojD@00<000000?nU403oYA00203oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]
0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3oY1402P3oY1400`00
0000oj@A0?nT4@060?nT4@030:f][@000000ojHA00H0ojHA0P0000090?nV4@8000001@3oYQ400`2]
[Jd000000000000:0?nV4@8000001`3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ420000
00X0[Jf]0P0000020:f][@030?nV4@000000ojHA00@0ojHA00<0[Jf]0?nV403oYQ001@3oYQ020000
00X0ojH@00<000000?nV400000001`3oYQ0010000000[Jf]0000000000050?nU40`0[Jf]00@00000
0:f][@2][Jd0[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00H02`h>H0
0`2][Jd0dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX103
0:f][@P0o:0@00<0[Jf]0?nT4@3oY1402P3oY1400`000000oj@A0?nT4@060?nT4@030:f][@000000
ojHA00H0ojHA0P0000080?nV4@8000001P3oYQ400`2][Jd000000000000:0?nV4@8000001`3oYQ42
000000/0[Jf]0P00000;0?nV4@800000103oYQ400`000000ojHA0?nV4@020?nV4@030:f][@3oYQ00
ojH@00D0ojH@0P00000:0?nV40030000003oYQ00000000L0ojH@0P00000:0?nU40030000003oYA00
ojD@00H0ojD@00@000000?nU403oYA00ojD@302][JdH0?nS40030:f][@3lX100o:0@01L0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H0
0`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0`2]
[Jd;0?bP40030:f][@3oY140oj@A00X0oj@A00<000000?nT4@3oY1401P3oY1400`2][Jd000000?nV
4@060?nV4@800000203oYQ42000000H0ojHA00<0[Jf]0000000000002P3oYQ42000000L0[Jf]0P00
00040?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00000;0?nV4@800000103oYQ400`000000ojHA0?nV
4@020?nV4@030:f][@3oYQ00ojH@00D0ojH@0P00000:0?nV40030000003oYQ00000000L0ojH@00<0
00000:f][@3oYA002@3oYA000`000000ojD@0?nU40060?nU40030000003oYA00ojD@00P0ojD@00<0
[Jf]0?nS403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>0P2][Jd2000000030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f][@3o
Y140oj@A00X0oj@A00<000000?nT4@3oY1401P3oY1400`2][Jd0ojHA0?nV4@060?nV4@800000203o
YQ42000000H0ojHA00<0[Jf]0000000000000P3oYQ480:f][@800000203oYQ42000000<0ojHA00<0
[Jf]0?nV4@3oYQ40103oYQ42000000X0ojHA0P0000050?nV4@030000003oYQ40ojHA0080ojHA00<0
[Jf]0?nV403oYQ001@3oYQ02000000X0ojH@00<000000?nV400000001`3oYQ000`000000[Jf]0?nU
40080?nU40800000203oYA000`000000ojD@0?nU40080?nU40030:f][@3oXa00oj<@00`0oj<@2P2]
[Jd40?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P<00000303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H2
0:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][A00o:0@00<0[Jf]0?nT4@3oY1402@3oY142
000000P0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ42000000P0ojHA0P0000040?nV4@<0[Jf]0P000002
0:f][@P0ojHA0P0000080?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000002P3oYQ42
000000H0ojHA00D000000?nV4@3oYQ40ojHA0:f][@070?nV408000002P3oYQ000`000000ojH@0000
00070?nV40030000002][Jd0ojD@00P0ojD@0P0000080?nU40030000003oYA00ojD@00P0ojD@00<0
[Jf]0?nS403oXa005P3oXa080:f][AH0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P040000002][Jd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V
0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`2][JdA0?bP40030:f][@3o
Y140oj@A00T0oj@A0P0000080?nT4@030:f][@3oYQ40ojHA00H0ojHA0P0000080?nV4@800000102]
[Jd20?nV4@030:f][@000000000000X0ojHA0P0000080?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV
4@040?nV4@8000002@3oYQ42000000L0ojHA00D000000?nV4@3oYQ40ojHA0:f][@070?nV40800000
2P3oYQ000`000000ojH@000000070?nV40030000002][Jd0ojD@00P0ojD@0P0000080?nU40030000
003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX1060:f][A00
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P040000002][Jd0fhX=0=^:
3@80[Jf]0P0000070=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?oo
o`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY142000000@0oj@A00D000000?nT4@3o
Y140oj@A0:f][@080?nV4@8000000`3oYQ450:f][@8000001P3oYQ40102][Jd0ojHA000000000009
0?nV4@800000203oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000X0ojHA0P000008
0?nV4@040000003oYQ40ojHA0:f][@L0ojH@0P00000:0?nV40030000003oYQ00000000L0ojH@00<0
00000:f][@3oYA00203oYA02000000P0ojD@00<000000?nU403oYA00203oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`000000fhX=0=^:3@020=^:3@040:f][@0000000000000000D0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2G
H0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@090?nT4@800000103oY1401@000000oj@A0?nT4@3oY140[Jf]00P0
ojHA0P0000030:f][@D0ojHA0P0000060?nV4@040:f][@3oYQ400000000000T0ojHA0P0000090?nV
4@8000000P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000T0ojHA00@000000?nV
4@3oYQ40[Jf]1`3oYQ02000000X0ojH@00<000000?nV40000000203oYQ000`000000ojD@0?nU4006
0?nU40<00000203oYA000`000000ojD@0?nU40080?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1003P3lX1060:f][@80o:0@00<0@FWQ0:f][@3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0@
0>bF3P030000003KRPd0fhX=00<0fhX=0P0000000`3KRPd000000=^:3@030=^:3@030:f][@2iM@/0
^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2]
[Jd80=>73P030:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00T0oj@A0P0000040?nT4@050000003oY140oj@A0?nT4@2][Jd0
0P3oYQ460:f][@800000203oYQ42000000H0ojHA00@0[Jf]0?nV4@0000000000203oYQ43000000T0
ojHA0P0000020?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000:0?nV4@8000002P3oYQ400`000000
ojHA0:f][@070?nV408000002P3oYQ000`000000ojH@000000080?nV40030:f][@000000000000H0
ojD@00<000000?nU400000001`3oYA02000000X0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400D0?bP40D0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030000003KRPd0fhX=00<0
fhX=0P0000020:f][@8000000P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF
1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH
403_V1000P3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT
4@800000103oY1400`000000oj@A0?nT4@040:f][@H0ojHA0P0000080?nV4@8000001P3oYQ401@2]
[Jd0ojHA0000003oYQ40000000L0ojHA0`00000:0?nV4@80000000<0ojHA0:f][@3oYQ400`3oYQ42
000000T0ojHA0P00000;0?nV4@@000000`3oYQ05000000L0ojH@1P0000080?nV40030:f][@3oYA00
ojD@00H000000P3oYA000`000000ojD@0?nU40050?nU40<000002@3oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0
k9H>0100k9H>00<000000=^:3@3KRPd00`3KRPd200000080fhX=0`0000000`3KRPd0[Jf]0;Ue2`08
0;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1402@3oY142000000<0oj@A00H0[Jf]0000002][Jd0[Jf]0?nT4@2][Jd80?nV4@80
0000203oYQ42000000H0ojHA00<0[Jf]0?nV4@3oYQ400P0000060?nV4@040000003oYQ4000000000
00/0ojHA0P0000000`2][Jd0ojHA0?nV4@03000000P0ojHA200000030?nV4@@000000P3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00P0ojD@00<000000?nU403oYA001@3oYA030000
00T0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?
00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>0100k9H>00<000000=^:3@3KRPd00`3KRPd20000
0080fhX=0P0000030:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3P
iP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f][@/0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@8000000`2][Jd00`3oY140
00000?nT4@020?nT4@030:f][@3oYQ40ojHA00H0ojHA0P0000080?nV4@8000001P3oYQ401P2][Jd0
ojHA0?nV4@000000ojHA000000D0ojHA00@000000?nV4@00000000003@3oYQ44000001/0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400@0?nU40<000002@3oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`000000fhX=0=^:3@030=^:3@8000000P3KRPd200000080fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3o
ool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@80[Jf]0P0000040?nT4@050000003o
Y140oj@A0?nT4@2][Jd0203oYQ42000000P0ojHA0P0000060?nV4@040:f][@3oYQ40ojHA0?nV4@<0
00000`3oYQ400`000000ojHA0?nV4@02000000d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@0100ojD@0`0000090?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]1@3fW0l00`2][Jd0
k9H>0>bF3P0@0>bF3P030000003KRPd0fhX=00<0fhX=0P0000020=^:3@8000000P3KRPd20:f][@P0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd0203CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0
oj@A0?nT4@030?nT4@@0[Jf]0P3oY142000000@0oj@A00D000000?nT4@3oY140oj@A0:f][@080?nV
4@800000203oYQ42000000H0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ44000000<0ojHA0P00000=0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400@0?nU
40<000002@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL
3`3fW0l03`3fW0l40:f][@030?JL3`2][Jd0k9H>0140k9H>00<0[Jf]0000003KRPd00`3KRPd20000
0080fhX=0P0000020=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@030=>73P2][Jd0kiP@00/0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0:f][@03
0:f][@H0oj@A00@000000?nT4@3oY140oj@A0`0000030?nT4@030:f][@3oYQ40ojHA00H0ojHA0P00
00080?nV4@8000001@3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@8000003@3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00403oYA03000000T0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2]
[JdA0>bF3P030:f][@000000fhX=00<0fhX=0P0000020=^:3@8000000P3KRPd01`2][Jd0^GD;0;Ue
2`2iM@/0[Jf]0;Ue2`0000000`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P050:f][@3CQ`h0dhL>0=>7
3P2][Jd0303_V1000`2][Jd0o:0@0?bP400?0?bP40<0[Jf]2P3oY14400000080oj@A00D000000?nT
4@3oY140oj@A0:f][@080?nV4@800000203oYQ42000000D0ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ42
000000d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@0100ojD@0`0000090?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0000000000002
0=^:3@030000003KRPd0000000<0fhX=00@000000=^:3@3KRPd0[Jf]102iM@/2000000<0^GD;00<0
[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@040=>73P030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP
400<0?bP40<0[Jf]00<0o:0@0:f][@3oY1402P3oY1400`000000oj@A0?nT4@030?nT4@050000003o
Y140oj@A0?nT4@2][Jd0203oYQ42000000D0ojHA0`0000070?nV4@030:f][@3oYQ40ojHA00/0ojHA
0P00000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400@0?nU40<000002@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd00000
0=^:3@04000000@0fhX=00@000000=^:3@3KRPd0[Jf]102iM@/00`000000[Jf]000000020;Ue2`03
0:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00`3CQ`h00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403l
X1002P3lX1020:f][@@0o:0@00<0[Jf]0?nT4@3oY1402@3oY1400`000000oj@A0?nT4@030?nT4@05
0000003oY140oj@A0?nT4@2][Jd0203oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ420000
00d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
0100ojD@0`0000090?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@000000fhX=
0080fhX=0P0000040=^:3@040000003KRPd0fhX=0:f][@<0^GD;00L000000;Ue2`2iM@/000000:f]
[@2iM@/0000000@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0
dhL>0P2][Jd60=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@H0
o:0@00<0[Jf]0?nT4@3oY1402@3oY1400`000000oj@A0?nT4@030?nT4@050000003oY140oj@A0?nT
4@2][Jd01@3oYQ4300000140ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ42000000d0ojHA00<0[Jf]0?nV
4@3oYQ405@3oYQ4^0:f][@/0ojD@0`0000090?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF
3P030:f][@000000fhX=0080fhX=0P0000040=^:3@040000003KRPd0fhX=0:f][@<0^GD;00D00000
0;Ue2`2iM@/000000;Ue2`020:f][@0400000028EPL0R5H708QF1`80[Jf]@P2`h>H10?ooo`00F@2`
h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@
0?bP40040?bP40<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@090?nT4@030000003oY140oj@A00<0oj@A
00D000000?nT4@3oY140oj@A0:f][@0I0?nV4@030:f][@3oYQ40ojHA00/0ojHA0P00000=0?nV4@03
0:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA001@3oYA0;0:f][@<000000P2][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P03
0:f][@000000fhX=0080fhX=0P0000040=^:3@040000003KRPd0fhX=0:f][@<0^GD;00@000000;Ue
2`2iM@/000000P2iM@/00`2][Jd000000000000308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool0
05T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]
0?bP403lX1000P3lX1020:f][@`0o:0@00<0[Jf]0?nT4@3oY1402@3oY1400`000000oj@A0?nT4@03
0?nT4@050000003oY140oj@A0?nT4@2][Jd06@3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@8000002@3o
YQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400@0?nU40<000000P3o
YA0<0:f][AP0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/
UPh0k9H>00`0k9H>0`2][Jd0103/UPh0[Jf]0=^:3@0000020=^:3@800000103KRPd01@000000fhX=
0=^:3@3KRPd0[Jf]0080^GD;00P000000;Ue2`2iM@/0^GD;0000002iM@/0[Jf]000000@0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@h0o:0@00<0[Jf]0?nT4@3oY1402@3oY140
0`000000oj@A0?nT4@030?nT4@060000003oY140oj@A0?nT4@2][Jd00000603oYQ400`2][Jd0ojHA
0?nV4@0;0?nV4@8000002@2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400@0?nU40030000003oYA00000000T0ojD@00<0[Jf]0?nS403oXa00
0P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>0`2][Jd00`000000fhX=0=^:3@02000000@0fhX=00D000000=^:3@3KRPd0
fhX=0:f][@020;Ue2`090000002iM@/0^GD;0;Ue2`000000^GD;0:f][@000000R5H70080000000<0
R5H70:f][@2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]
0>nH403_V1002`3_V1020:f][A40o:0@00<0[Jf]0?nT4@3oY1402@3oY1400`000000oj@A0?nT4@03
0?nT4@060000003oY140oj@A0?nT4@2][Jd00000603oYQ400`2][Jd0ojHA0?nV4@020?nV4@T0[Jf]
0P00000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400@0?nU40030000003oYA00000000T0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>
00D0[Jf]0=^:3@000000[Jf]0=^:3@02000000@0fhX=0P0000020=^:3@040:f][@2iM@/0^GD;0000
00D0^GD;00<0[Jf]0000002][Jd00P0000000`28EPL0[Jf]0;3PiP110;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4P3lX1000`2]
[Jd0oj@A0?nT4@090?nT4@030000003oY140oj@A00L0oj@A00<0[Jf]0000003oYQ40503oYQ480:f]
[@T0ojHA0P00000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400A0?nU40030000003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f]
[AL0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P050:f][@3KRPd00000
0=^:3@2][Jd00P0000040=^:3@8000000P3KRPd0102][Jd0^GD;0;Ue2`0000050;Ue2`070:f][@00
0000R5H70:f][@000000R5H70:f][@120;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00X0oj@A00<000000?nT4@3oY1401`3oY1400`2][Jd000000?nV4@0>0?nV4@H0
[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@8000003@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA004@3oYA000`000000ojD@0?nU40080?nU4003
0:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=000000020=^:3@80000000@0[Jf]0=^:
3@3KRPd0fhX=0P0000020=^:3@040:f][@2iM@/0^GD;000000D0^GD;00@0[Jf]00000028EPL0R5H7
0P0000000`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050000002][Jd0Uf0;09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00T0oj@A0P0000090?nT4@030:f][@000000ojHA00L0ojHA1`2][Jd90?nV4@030:f]
[@3oYQ40ojHA00/0ojHA0P00000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400A0?nU40030000003oYA00ojD@00P0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP40080?bP40H0[Jf]2P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@0000000P3KRPd2000000040=^:3@2][Jd0[Jf]0=^:3@80
00000P3KRPd0102][Jd0^GD;0;Ue2`0000050;Ue2`040:f][@000000R5H708QF1`<00000@P2`h>H1
0?ooo`00F02`h>H2000000040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V102
0:f][@H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@8000002@3oY140
102][Jd000000?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ42000000d0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@0000000P3KRPd2000000<0fhX=00<0
[Jf]0000000000000P3KRPd0102][Jd0^GD;0;Ue2`0000050;Ue2`070:f][@000000R5H708QF1`00
0000[Jf]000000120;3PiP40oooo001H0;3PiP8000000`2GH0/00`2][Jd0dhL>0=>73P060=>73P04
0:f][@3_V100kiP@0>nH4080[Jf]203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00T0oj@A0P0000080?nT4@030:f][@000000[Jf]0080[Jf]5P3oYQ400`2][Jd0ojHA0?nV4@070?nV
4@H000003@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][JdD0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@0000000P3KRPd2000000@0fhX=0P0000000`2]
[Jd0fhX=0:f][@020;Ue2`030000002iM@/0^GD;00<0^GD;00H0[Jf]00000028EPL0R5H700000028
EPL200000440/>3V0@3oool005L0/>3V0`00000309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]
0>nH402][Jd0[Jf]2P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A0P00
00040?nT4@@0[Jf]00<0oj@A0000003oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh01@2][Jd0fhX=0=^:3@000000fhX=00800000103KRPd2000000030=^:
3@2][Jd0[Jf]0080^GD;00<000000;Ue2`2iM@/0102iM@/01@000000R5H708QF1`000000R5H70080
0000@@2`h>H10?ooo`00E`2`h>H00`000000[Jf]0000000309MP2`030:f][@3CQ`h0dhL>00H0dhL>
0P2][Jd<0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY142000000@0[Jf]
1@3oY1400`000000ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd;0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00D0[Jf]0=^:3@3KRPd000000=^:3@02000000D0fhX=00<000000=^:3@3K
RPd00P2][Jd00`2iM@/000000;Ue2`050;Ue2`80000000<0R5H700000028EPL00P0000110;3PiP40
oooo001G0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@070=>73P80[Jf]3@3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A0P2][Jd2000000T0oj@A00<000000?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`090?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P05
0:f][@3KRPd0fhX=0000003KRPd00P0000050=^:3@070000003KRPd0fhX=0:f][@2iM@/0[Jf]0000
00060;Ue2`80000000<0R5H700000028EPL00`0000100;3PiP40oooo001G0;3PiP80000000D0[Jf]
09MP2`2GH0/0Uf0;0:f][@060=>73P030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]0P3oY142000000T0oj@A00<000000?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0>0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P060:f][@3K
RPd000000000003KRPd000001@3KRPd020000000fhX=0=^:3@2][Jd000000;Ue2`000000[Jf]1@2i
M@/20000000308QF1`000000R5H700<00000@02`h>H10?ooo`00E`2`h>H2000000050:f][@2GH0/0
Uf0;09MP2`2][Jd01@3CQ`h0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@2][Jd00`2][Jd60?nT4@8000002@3oY1400`000000ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?0180mY`?102][JdA0>bF3P060:f][@3KRPd000000000003KRPd000001@3KRPd00`00
0000fhX=0=^:3@02000000060;Ue2`00000000000:f][@2iM@/000000P2iM@/20000000308QF1`00
0000R5H700<00000@02`h>H10?ooo`00E`2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2][Jd00`3C
Q`h20:f][@<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]2P3o
Y142000000P0oj@A0P00000I0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2]
[Jd>0>bF3P060:f][@3KRPd000000000003KRPd000001@3KRPd2000000040=^:3@00000000000;Ue
2`80000000D0^GD;0:f][@000000^GD;045Yh@020000000308QF1`000000000000<00000@02`h>H1
0?ooo`00E`2`h>H00`000000[Jf]0:f][@0309MP2`040:f][@3CQ`h0dhL>0:f][@D0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1402P3oY142
000000@0oj@A100000000`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00H0[Jf]0=^:3@00000000000=^:3@0000030=^:3@050000
003KRPd000000000003KRPd00P0000000`2iM@/00000000000020;Ue2`80000000@0^GD;00000000
0000R5H71@0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P2]
[Jd01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP4003
0:f][@3oY140oj@A00T0oj@A1P0000050?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh01P2][Jd0fhX=0=^:3@000000fhX=
000000@0fhX=0`000000103KRPd0[Jf]0000002iM@/200000080^GD;0P000000102][Jd000000000
0028EPL500000400/>3V0@3oool005L0/>3V00<000000:f][@2][Jd00`2GH0/20:f][@L0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2][Jd0oj@A0?nT
4@070?nT4@<000002P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd00P0000080=^:3@030000002]
[Jd000000080^GD;00H000000;Ue2`2iM@/0^GD;0000002iM@/20000000308QF1`000000000000<0
0000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=
0=^:3@02000000T0fhX=0P0000020;Ue2`8000000P2iM@/01@000000^GD;000000000000R5H700D0
0000@02`h>H10?ooo`00E`2`h>H2000000<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@
00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00
[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00@0k9H>0:f][@3KRPd0fhX=0P00000:0=^:
3@030:f][@2iM@/0^GD;008000000P2iM@/01@000000^GD;000000000000R5H700D00000@02`h>H1
0?ooo`00E`2`h>H2000000<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP
402][Jd0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]
0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]00<0fhX=0000000000002P3KRPd0
1`2][Jd0^GD;0;Ue2`2iM@/000000;Ue2`0000000P2iM@/00`2][Jd000000:f][@02000000030:f]
[@00000000000400/>3V0@3oool005L0/>3V0P00000209MP2`030:f][@2GH0/0[Jf]00L0dhL>00<0
[Jf]0>nH403_V1002`3_V1030:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0:f]
[@02000000X0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/200000080^GD;00<0[Jf]0000002][Jd00P00
00000`11JN400000000000100;3PiP40oooo001G0;3PiP80000000D0Uf0;0:f][@2GH0/0Uf0;0:f]
[@070=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`
h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3K
RPd0fhX=0080000000<0[Jf]0=^:3@3KRPd01`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`060000002i
M@/0^GD;0:f][@000000R5H70P0000000`11JN400000000000100;3PiP40oooo001G0;3PiP800000
00D0Uf0;0:f][@2GH0/0Uf0;0:f][@070=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd30>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0
[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P06
0:f][@3KRPd0fhX=0=^:3@000000fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]
0000000000000P0000001011JN40000000000000000o0;3PiP40oooo001F0;3PiP<0000000D0[Jf]
09MP2`2GH0/0Uf0;0:f][@070=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd50>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`
h>H50:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P050:f][@3K
RPd0fhX=0=^:3@0000000`3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd00000
0000000200000004045Yh@0000000000000003l0/>3V0@3oool005H0/>3V0`0000001@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00L0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@L0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0
[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00D0[Jf]0=^:3@3K
RPd0fhX=000000050=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@0000000000
0080000000@0[Jf]0000000000000000?`2`h>H10?ooo`00EP2`h>H3000000<0Uf0;00<0@FWQ0:f]
[@3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0
[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P050:f][@3KRPd0fhX=0=^:3@000000
1`3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;10000000102][Jd0000000000000000o0;3PiP40
oooo001F0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f][@/0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/01@000000
R5H7000000000000[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H3000000<0Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0
[Jf]dP2`h>H50:f][A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@<0
[Jf]1`2iM@/01@000000R5H700000028EPL0[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H3000000<0
Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@h0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00D0000008QF1`28EPL0R5H70:f][@03
000003l0/>3V0@3oool005H0/>3V0`00000309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3C
Q`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f]
[N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2]
[Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;0P00000208QF1`040:f][@0000000000000003l0/>3V0@3o
ool005H0/>3V0`00000309MP2`030:f][@3CQ`h0dhL>0080dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f]
[@0=0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2i
M@/20:f][@<0^GD;0P00000208QF1`@00000?`2`h>H10?ooo`00EP2`h>H3000000<0Uf0;00D0[Jf]
0=>73P3CQ`h0dhL>0:f][@040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3l
X1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102i
M@/00`2][Jd0^GD;0;Ue2`0200000080R5H700@0[Jf]0000000000000000?`2`h>H10?ooo`00EP2`
h>H3000000<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00D0^GD;0P2][Jd200000080R5H700@0[Jf]045Yh@0000000000?`2`h>H10?ooo`00
EP2`h>H3000000<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
2P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P00000308QF1`030:f][@000000000003l0
/>3V0@3oool005H0/>3V0`00000309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]
1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P00000308QF1`030:f]
[@000000000003l0/>3V0@3oool005H0/>3V0P00000309MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`
h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/2000000<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H2000000<0Uf0;0P2][Jd8
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]
0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0
_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80000000@0[Jf]
08QF1`28EPL0[Jf]0P00000o0;3PiP40oooo001F0;3PiP8000000P2GH0/00`2][Jd0Uf0;0:f][@08
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0
^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P000000
102][Jd0R5H708QF1`2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000001@2GH0/0[Jf]09MP2`2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80000000@0
R5H70:f][@28EPL0[Jf]0P00000o0;3PiP40oooo001F0;3PiP80000000D0Uf0;0:f][@2GH0/0Uf0;
0:f][@080=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][@800000?`2`h>H10?ooo`00EP2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28
EPL0R5H70:f][@0200000400/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00P0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`0
0`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP2
0:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`000000[Jf]0;3PiP0o0;3PiP40oooo001F0;3PiP800000102GH0/00`2][Jd0dhL>0=>73P060=>7
3P040:f][@3_V100kiP@0>nH4080[Jf]102TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd
0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`030:f][@28EPL0R5H70080R5H700<000000:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H2
000000<0Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h01P2][Jd0kiP@0:f][@2][Jd0Y9j?045Yh@80Y9j?
0`11JN460;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00@0[Jf]0;B`/@2d
/;40@FWQ0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`060:f][@28EPL0R5H708QF1`000000[Jf]@02`
h>H10?ooo`00E`2`h>H01@000000Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd30:BNS`03045Yh@2T
WXl0Y9j?0080Y9j?0P11JN470;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd70;ji^004045Y
h@2n^KP0_[Vh0:f][@80];2a00<0@FWQ0;B`/@2d/;400P2][Jd:0;Ue2`060:f][@28EPL0R5H708QF
1`000000[Jf]@02`h>H10?ooo`00E`2`h>H01@000000Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]
045Yh@11JN400`2TWXl00`11JN40Y9j?0:BNS`020:BNS`04045Yh@2aZid0/J^M045Yh@L0/J^M0P2]
[Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004031
^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]1`2n^KP2045Yh@040;ji^011JN40_[Vh0:f][@80];2a
00<0@FWQ0;B`/@2d/;400P2d/;420:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40
oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@030:BNS`11JN40@FWQ00<0
Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl01011JN40/J^M0;6[W@2aZid2045Yh@L0/J^M0`2][Jd?0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<7
0:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01@2n^KP2045Yh@<0_[Vh00<0@FWQ
0;ji^02][Jd00P2d/;400`11JN40];2a0;B`/@040;B`/@030:f][@2iM@/0^GD;00D0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3C
Q`h0102][Jd0@FWQ045Yh@2TWXl2045Yh@<0Y9j?00H0@FWQ0:BNS`2TWXl0Y9j?0:f][@11JN440;6[
W@<0@FWQ1P2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f]
[@@0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP00`11JN40_[Vh045Yh@040;ji^005045Yh@2n^KP0[Jf]
0;B`/@11JN401`2d/;420:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01@2][Jd0RXEe045Yh@11JN40Y9j?0080@FWQ
0`2TWXl2045Yh@80Y9j?00<0[Jf]045Yh@2aZid00`2aZid01011JN40/J^M0;6[W@2aZid3045Yh@80
/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0
`kfk00<0[Jf]0;ji^02n^KP01@2n^KP00`11JN40_[Vh0;ji^0020;ji^005045Yh@2n^KP0[Jf]0;B`
/@11JN401P2d/;450:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h00`2][Jd0@FWQ08Z5M@02045Yh@030:f][@11JN40
@FWQ00<0Y9j?0P11JN420:BNS`030:f][@11JN40/J^M00<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid3
045Yh@030;6[W@2][Jd0^K:V00L0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA
0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP0
0`11JN40_[Vh0;ji^0020;ji^080@FWQ00<0[Jf]0;B`/@11JN401@2d/;401`2][Jd0];2a0;B`/@2]
[Jd0@FWQ09nKX02][Jd00P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V
00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@0608Z5M@11JN40RXEe045Yh@2][Jd0Y9j?0P11
JN430:BNS`80@FWQ0P2TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2aZid0/J^M0080/J^M0P11
JN420;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`
h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l00l0a/2l0`2][Jd>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh00<0@FWQ0;ji^02n^KP00P2n
^KP2045Yh@040:f][@2d/;40];2a045Yh@80];2a0P2][Jd01`2d/;40@FWQ0;B`/@2][Jd0@FWQ09nK
X011JN400`2][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2G
H0/00P2GH0/20:f][@<0RXEe00D0@FWQ08Z5M@11JN40[Jf]0:BNS`02045Yh@80[Jf]00<0Y9j?045Y
h@11JN400P2TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN420;6[
W@050:f][@2i/ZH0^K:V0;VbYP11JN402`2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_
0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0_02][Jd0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP01@2n^KP00`11JN40_[Vh0;ji^0020;ji^080@FWQ00@0[Jf]0;B`/@2d/;40@FWQ0P2]
[Jd30;B`/@03045Yh@2d/;40@FWQ00D0Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3P
iP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD2
045Yh@040:f][@2TWXl0@FWQ045Yh@80Y9j?00<0[Jf]045Yh@11JN400P2TWXl00`2][Jd0@FWQ0;6[
W@030;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN420;6[W@060:f][@2i/ZH0@FWQ045Yh@2i/ZH0
@FWQ2`2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0
a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^0050;ji^003045Yh@2n^KP0_[Vh00<0
_[Vh00D0@FWQ0:f][@2d/;40];2a045Yh@020;B`/@06045Yh@2d/;40];2a045Yh@2d/;40@FWQ1P2O
Vj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd708Z5M@040:f][@2TWXl0@FWQ045Yh@<0Y9j?00H0@FWQ0:f][@2TWXl0Y9j?0:f][@11JN43
0;6[W@80@FWQ102aZid2045Yh@80/J^M00<0[Jf]045Yh@11JN400`2i/ZH00`11JN40^K:V0;VbYP08
0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]
0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd9
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0102n^KP00`11JN40_[Vh0;ji^003
0;ji^005045Yh@2][Jd0[Jf]0:f][@11JN400P2d/;401P11JN40];2a0;B`/@2d/;40@FWQ0:f][@H0
Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP
2`80[Jf]1`2:QGD0102][Jd0@FWQ045Yh@11JN430:BNS`03045Yh@2TWXl0[Jf]0080[Jf]00@0@FWQ
0;6[W@2aZid0/J^M0P11JN440;6[W@80@FWQ0P2aZid00`2][Jd0@FWQ0;VbYP040;VbYP03045Yh@2i
/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n
]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37
`K`00`2][Jd0a/2l0:f][@030:f][@d0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0040;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00D0@FWQ0:f][@2d/;40];2a045Yh@020;B`/@03045Y
h@2d/;40];2a0080];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40
oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1`2:QGD0102][Jd0Y9j?045Yh@11JN420:BNS`03
045Yh@2TWXl0Y9j?0080Y9j?00<0[Jf]045Yh@2aZid00P2aZid2045Yh@@0/J^M0P11JN420;6[W@03
0:f][@11JN40^K:V00@0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH6045Yh@d0_[N/102][Jd00`2n]j`0
[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0040;ji^004045Yh@2n^KP0_[Vh0;ji
^080[Jf]00D0@FWQ0:f][@2d/;40];2a045Yh@020;B`/@03045Yh@2d/;40];2a0080];2a00<0[Jf]
09nKX02OVj001@2OVj020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP
2`2][Jd0Hf1C0P2][Jd608Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0@FWQ0:BNS`11JN40102TWXl2
045Yh@80[Jf]00<0/J^M045Yh@11JN40102aZid2045Yh@80/J^M0P11JN460;VbYP05045Yh@2i/ZH0
^K:V0;VbYP11JN40102i/ZH00`11JN40_[N/0;jg[00?0;jg[0@0[Jf]4@31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0040;ji^004045Yh@2n^KP0[Jf]0:f][@80_[Vh
0P11JN420;B`/@80@FWQ00<0];2a045Yh@2d/;400`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f]
[@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe
00<0[Jf]0:BNS`2TWXl00`2TWXl00`11JN40Y9j?0:BNS`030:BNS`80@FWQ0P2aZid00`2][Jd0@FWQ
045Yh@040;6[W@04045Yh@2aZid0/J^M0;6[W@80@FWQ2P2i/ZH00`11JN40^K:V0;VbYP020;VbYP03
0:f][@11JN40_[N/00@0_[N/00<0@FWQ0;jg[02n]j`02@2n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37`K`00`2][Jd0
a/2l0<K0_0070<K0_003045Yh@36`;`0a/2l00H0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0030;ji^0030:f][@11JN40[Jf]00@0_[Vh0P11JN420;B`/@03045Yh@2d/;40@FWQ00D0
];2a00<0[Jf]09nKX02OVj00102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V
0P2][Jd306=PD`80[Jf]1@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80@FWQ0`2aZid2045Yh@80[Jf]
0P2aZid01011JN40/J^M0;6[W@2aZid2045Yh@X0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`2][Jd0
@FWQ0;jg[0030;jg[080@FWQ2`2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0_0060<K0_080
@FWQ2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]00<0_[Vh045Y
h@2n^KP0102n^KP2045Yh@80];2a00<0@FWQ0;B`/@2d/;401@2d/;400`2][Jd0Wi^P09nKX00309nK
X0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080
Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80@FWQ0`2aZid2045Yh@80
/J^M0P2][Jd01011JN40/J^M0;6[W@2aZid2045Yh@X0^K:V00L0@FWQ0;VbYP2i/ZH0^K:V0:f][@2n
]j`0@FWQ00@0_[N/0P11JN4;0;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k0100b<6k1P2][JdA0<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN480<K0_0030:f]
[@33_K/0`kfk00h0`kfk00@0[Jf]0;ji^02][Jd0[Jf]102n^KP00`11JN40_[Vh0;ji^0020;ji^0@0
@FWQ202d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2]
[Jd0Y9j?0:BNS`090:BNS`80@FWQ0`2aZid00`11JN40/J^M0;6[W@030;6[W@04045Yh@2][Jd0[Jf]
0;6[W@80@FWQ3P2i/ZH00`2][Jd0_[N/045Yh@050;jg[003045Yh@2n]j`0_[N/00T0_[N/00<0[Jf]
0<6j/031^[003`31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`02
0<S1^`L0@FWQ2`38`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00>
0<O1_003045Yh@37`K`0al6l0080@FWQ0P36`;`00`11JN40a/2l0<K0_0030<K0_003045Yh@36`;`0
a/2l00H0a/2l00<0[Jf]0<>m^`33_K/03@33_K/30:f][@H0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP0
0`11JN40[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2OVj000`2][Jd0L6ii071^N@02
0:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0
[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`11JN40/J^M045Yh@020;6[W@03045Yh@2aZid0
/J^M00<0/J^M00@0@FWQ0;6[W@2aZid0[Jf]0P11JN4>0;VbYP030:f][@2n]j`0@FWQ0140_[N/00<0
[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k00D0b<6k00<0@FWQ0<S1^`38`K/03038`K/0102][Jd0b<6k0<S1
^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`03P37`K`3045Yh@030:f][@36`;`0a/2l0080a/2l
00<0@FWQ0<K0_036`;`02`36`;`00`2][Jd0`kfk0<>m^`0:0<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0
1P2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2][Jd0];2a00T0];2a00<0[Jf]09nKX02][Jd0
1@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1S
H5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00<0@FWQ0;6[W@2aZid00P11
JN460;6[W@04045Yh@2aZid0/J^M0;6[W@80@FWQ0`2][Jd;0;VbYP<0@FWQ4@2n]j`00`2][Jd0`KZ`
0<6j/00A0<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00D0b<6k
00<0@FWQ0<S1^`38`K/01`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`01037`K`3045Yh@L0al6l
0P11JN400`37`K`0[Jf]0<K0_0030<K0_003045Yh@36`;`0a/2l00/0a/2l00<0[Jf]0<>m^`33_K/0
1`33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Y
h@2][Jd0];2a00T0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`03045Yh@2a
Zid0/J^M00P0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN430;VbYP80[Jf]00<0@FWQ0;VbYP2i/ZH0
102i/ZH2045Yh@030:f][@2n]j`0@FWQ0140_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00<0b<6k
0P2][Jd00`11JN40[Jf]0:f][@070:f][@D0b<6k00<0[Jf]0<S1^`38`K/04@38`K/3045Yh@D0al6l
00@0@FWQ0<O1_037`K`0al6l0P11JN450<O1_080@FWQ00<0al6l0:f][@36`;`00`36`;`00`11JN40
a/2l0<K0_00;0<K0_0030:f][@33_K/0`kfk00D0`kfk0P2][Jd70<>m^`030:f][@2n^KP0_[Vh00D0
_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP00`11JN40[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080
Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03045Yh@2aZid0/J^M00H0
/J^M00<0@FWQ0;6[W@11JN400`2aZid00`2][Jd0@FWQ0;VbYP030;VbYP80@FWQ102][Jd00`2i/ZH0
@FWQ0;VbYP03045YhA40_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX02P37`KXA0:f][@80b<6k00<0@FWQ0<S1^`38`K/03038`K/00`2][Jd0b<6k0<S1^`0>0<S1^`@0
@FWQ00<0b<6k0:f][@37`K`00`37`K`2045Yh@@0al6l00<0@FWQ0<O1_037`K`00`37`K`01011JN40
al6l0<O1_02][Jd30<K0_080@FWQ3@36`;`00`2][Jd0`kfk0<>m^`020<>m^`<0[Jf]2@33_K/00`2]
[Jd0_[Vh0;ji^0050;ji^003045Yh@2n^KP0_[Vh0080_[Vh00<0@FWQ0:f][@2d/;401`2d/;430:f]
[@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C
06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0@FWQ0;6[W@2aZid01`2aZid2045Yh@<0/J^M00<0[Jf]
045Yh@11JN40102i/ZH00`11JN40^K:V0;VbYP020;VbYP<0@FWQ00<0^K:V0:f][@2n]j`01@2n]j`0
0`11JN40_[N/0;jg[0090;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01033_K<4
045Yh@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX0
0`2][Jd0b<6k0<S1^`050<S1^`03045Yh@38`K/0b<6k00`0b<6k00<0[Jf]0<S1^`38`K/01@38`K/7
045Yh@@0b<6k0P11JN400`38`K/0[Jf]0<O1_0020<O1_080@FWQ1P37`K`00`11JN40al6l0<O1_002
0<O1_004045Yh@37`K`0al6l0:f][@<0a/2l00<0@FWQ0<K0_036`;`00`36`;`00`11JN40a/2l0<K0
_0060<K0_0030:f][@33_K/0[Jf]0080[Jf]3033_K/00`2][Jd0_[Vh0;ji^0050;ji^003045Yh@2n
^KP0_[Vh0080_[Vh00<0@FWQ0:f][@2d/;401P2d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f]
[@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0
RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd70:BNS`03045Yh@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP11
JN40102i/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@80^K:V0`2][Jd50;jg[003045Yh@2n]j`0_[N/
00T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`060<>m/`L0@FWQ1P33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<000000:f][@37`KP05@37`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00D0b<6k00<0@FWQ0<S1^`38`K/03038`K/6045Y
h@D0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0al6l0080al6l00<0@FWQ0<O1
_037`K`03@37`K`00`2][Jd0a/2l0<K0_002045Yh@D0a/2l00<0@FWQ0<K0_036`;`01036`;`40:f]
[@l0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2][Jd0];2a
00@0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o
0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl0
0`2][Jd0Y9j?0:BNS`040:BNS`03045Yh@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP11JN400`2i/ZH0
0`11JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0[Jf]0;jg[02][Jd00`2][Jd0
0`2n]j`0@FWQ0;jg[00:0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01P33_K<2
045Yh@@0`kfc0`11JN440<>m/`030:f][@11JN40@FWQ00@0@FWQ4035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX04037`KX00`000000al6j0<O1^P02
0<O1^P030:f][@38`K/0b<6k00D0b<6k00<0@FWQ0<S1^`38`K/00P38`K/2045Yh@P0b<6k00@0[Jf]
0<S1^`11JN40@FWQ1`38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ00<0b<6k0:f][@37`K`00P37
`K`00`11JN40al6l0<O1_00=0<O1_0040:f][@36`;`0@FWQ045Yh@H0a/2l00<0@FWQ0<K0_02][Jd0
102][Jd20<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP01`11JN40_[Vh
0;ji^02n^KP0@FWQ0;ji^02][Jd00`2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102]
[Jd0L6ii071^N@2][Je00;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl00`2TWXl20:f][@80Y9j?00<0@FWQ0:BNS`11JN403P2aZid00`2][Jd0^K:V0;VbYP04
045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH00`2][Jd0_[N/045Yh@030;jg[0040:f][@11JN40
[Jf]0:f][@T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`060<>m/`80@FWQ1@33
_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D00P11JN4?0<Fn]@04045Yh@35_[D0aKje0:f][AL0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k0080@FWQ
0`38`K/01P11JN40b<6k0<S1^`38`K/0@FWQ0<S1^`<0@FWQ1P38`K/0102][Jd0b<6k045Yh@11JN47
0<S1^`03045Yh@38`K/0b<6k00D0b<6k0P11JN401038`K/0[Jf]0<O1_037`K`2045Yh@l0al6l0`11
JN450<K0_080[Jf]00<0@FWQ0:f][@36`;`01P36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00D0_[Vh00L0@FWQ0;ji^02n^KP0_[Vh045Yh@2n^KP0[Jf]0080];2a00<0[Jf]0;B`/@2d
/;401@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0
/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]00<0Y9j?045Yh@11
JN403@2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP07045Yh@2i/ZH0^K:V0;VbYP2][Jd0_[N/045Yh@04
0;jg[003045Yh@2n]j`0_[N/00@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc00H0`kfc0P11JN460<>m/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@02045Yh@d0aKje0P11JN40
1035_[D0@FWQ045Yh@2][Jd40<Jo]`80@FWQ1P36_kL00`11JN40a[ng0<Jo]`040<Jo]`05045Yh@36
_kL0a[ng0<Jo]`2][Jd05@37`KP7045Yh@`0al6j1011JN420<O1^P030:f][@11JN40@FWQ00D0b<6k
00@0@FWQ0<S1^`11JN40@FWQ1038`K/00`11JN40b<6k0<S1^`040<S1^`040:f][@38`K/0@FWQ045Y
h@L0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@040<S1^`2][Jd0al6l0<O1_080@FWQ3P37`K`3
045Yh@030<K0_02][Jd0[Jf]00<0[Jf]0P36`;`00`11JN40a/2l0<K0_0060<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP01011JN40_[Vh0;ji^011JN420;ji^0<0[Jf]202d
/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0:
0;VbYP07045Yh@2i/ZH0^K:V0;VbYP2][Jd0_[N/045Yh@040;jg[003045Yh@2n]j`0_[N/00@0_[N/
102][Jd00`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33_K<0`kfc00H0`kfc0P11JN460<>m/`80@FWQ
0`33_K<00`2][Jd0aKje0<Fn]@02045Yh@d0aKje00<0@FWQ0<Fn]@35_[D00P35_[D2045Yh@030<Jo
]`11JN40@FWQ00P0a[ng00<0@FWQ0<Jo]`36_kL01036_kL01@11JN40a[ng0<Jo]`36_kL0[Jf]00T0
al6h1011JN420<O1^080@FWQ1@37`KP00`2][Jd0al6j045Yh@0=0<O1^P<0@FWQ0`37`KX2045Yh@03
0:f][@11JN40@FWQ00D0b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11
JN40@FWQ1`38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ00@0b<6k0:f][@37`K`0al6l0P11JN4=
0<O1_080@FWQ0`2][Jd20<K0_003045Yh@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`01P36`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh00D0@FWQ0;ji^011JN40@FWQ0;ji
^0020:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I
0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]202aZid01@11JN40/J^M0;6[W@2a
Zid0[Jf]00d0^K:V0P11JN40102i/ZH0[Jf]045Yh@11JN440;jg[003045Yh@2n]j`0_[N/00P0_[N/
1@2][JdA0<6j/0030:f][@33_K<0`kfc00H0`kfc0P11JN460<>m/`80@FWQ0`33_K<00`2][Jd0aKje
0<Fn]@02045Yh@`0aKje0P11JN440<Fn]@040:f][@36_kL0@FWQ045Yh@T0a[ng00<0@FWQ0<Jo]`36
_kL00`36_kL2045Yh@<0a[ng00<0[Jf]0<O1^037`KP01@37`KP3045Yh@<0al6h1011JN450<O1^003
0:f][@37`KX0@FWQ00d0al6j00<0@FWQ0<O1^P37`KX01@37`KX2045Yh@H0b<6k0P11JN470<S1^`03
045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`38`K/00`11JN40b<6k0<S1^`050<S1
^`80@FWQ00@0b<6k0:f][@37`K`0al6l0P11JN480<O1_0@0[Jf]0P11JN400`37`K`0[Jf]0<K0_003
0<K0_003045Yh@36`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`01P36`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P11JN401@2n^KP0[Jf]0:f][@2n^KP0[Jf]00X0];2a00<0
[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd50;6[W@80@FWQ0P2aZid00`2][Jd0^K:V0;VbYP0=
0;VbYP80@FWQ00<0_[N/045Yh@2n]j`00P2n]j`2045Yh@/0_[N/00@0[Jf]0<6j/031^[00`KZ`1`2]
[Jd:0<6j/0030:f][@33_K<0`kfc00H0`kfc0P11JN470<>m/`80@FWQ0P33_K<00`2][Jd0aKje0<Fn
]@02045Yh@`0aKje0P11JN440<Fn]@040:f][@36_kL0a[ng045Yh@P0a[ng00<0@FWQ0<Jo]`11JN40
1036_kL00`11JN40a[ng045Yh@020<Jo]`030:f][@37`KP0al6h00@0al6h0P11JN460<O1^0<0@FWQ
1@37`KP00`2][Jd0al6j045Yh@0=0<O1^P03045Yh@37`KX0al6j00D0al6j00<0[Jf]045Yh@38`K/0
1@38`K/00`11JN40b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11JN40
@FWQ1`38`K/2045Yh@H0b<6k0P11JN401038`K/0[Jf]0<O1_037`K`2045Yh@<0al6l102][Jd00`11
JN40al6l0<O1_0020<O1_080@FWQ00<0al6l0:f][@36`;`00P36`;`2045Yh@@0a/2l00<0@FWQ0<K0
_036`;`01P36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P11JN400`2n
^KP0[Jf]0:f][@030;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f]
[D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03
0:f][@2aZid0/J^M0080/J^M0P2][Jd30;6[W@05045Yh@2aZid0/J^M0;6[W@2][Jd0402i/ZH00`2]
[Jd0_[N/0;jg[0030;jg[0<0@FWQ2P2n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2]
[Jd0`kfc0<>m/`060<>m/`80@FWQ1`33_K<2045Yh@80`kfc00<0[Jf]0<Fn]@35_[D00P11JN4<0<Fn
]@80@FWQ1035_[D0102][Jd0a[ng0<Jo]`11JN480<Jo]`<0@FWQ1036_kL3045Yh@80a[ng00<0[Jf]
0<O1^037`KP01037`KP00`11JN40al6h0<O1^0060<O1^080@FWQ1P37`KP00`2][Jd0@FWQ0<O1^P0<
0<O1^P03045Yh@37`KX0al6j00D0al6j00<0[Jf]045Yh@38`K/01@38`K/2045Yh@L0b<6k0P11JN44
0<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN460<S1^`80@FWQ00@0b<6k0:f][@37`K`0al6l
0P11JN430:f][@<0al6l0P11JN440<O1_004045Yh@37`K`0al6l0:f][@<0a/2l0P11JN440<K0_080
@FWQ1`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^003
0:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40
oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@040;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/
0`11JN4:0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][Jd50<>m/`80@FWQ2033_K<2045Yh@040<>m
/`2][Jd0aKje0<Fn]@80@FWQ3035_[D2045Yh@@0aKje00@0[Jf]0<Jo]`36_kL0@FWQ2036_kL3045Y
h@@0a[ng0`11JN420<Jo]`030:f][@37`KP0al6h00<0al6h0P11JN480<O1^080@FWQ1P37`KP00`2]
[Jd0@FWQ0<O1^P0<0<O1^P03045Yh@37`KX0al6j00D0al6j00<0[Jf]045Yh@38`K/01@38`K/2045Y
h@L0b<6k0P11JN440<S1^`040:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN460<S1^`80@FWQ102][Jd0
0`37`K`0@FWQ0<O1_0060<O1_003045Yh@37`K`0al6l0080al6l00@0@FWQ0<O1_037`K`0[Jf]0`36
`;`2045Yh@@0a/2l0P11JN480<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh
0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V
0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg
[0030;jg[0<0@FWQ2P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`D0[Jf]
0P11JN480<>m/`80@FWQ00@0`kfc0:f][@35_[D0aKje0P11JN4<0<Fn]@80@FWQ1035_[D0102][Jd0
a[ng0<Jo]`11JN480<Jo]`<0@FWQ0`36_kL2045Yh@050<Jo]`11JN40a[ng0<Jo]`2][Jd01@37`KP2
045Yh@P0al6h0P11JN460<O1^0030:f][@11JN40al6j00`0al6j00<0@FWQ0<O1^P37`KX01@37`KX0
0`2][Jd0@FWQ0<S1^`050<S1^`80@FWQ1`38`K/2045Yh@@0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`38
`K/2045Yh@H0[Jf]0P11JN400`38`K/0[Jf]0<O1_0020<O1_003045Yh@37`K`0al6l00@0al6l00<0
@FWQ0<O1_037`K`01037`K`00`11JN40al6l0:f][@03045Yh@030<K0_011JN40a/2l00<0a/2l0P11
JN480<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a
0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`
h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2a
Zid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`3045Yh@X0_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`060<>m/`80@FWQ202][Jd2045Yh@040<>m/`2][Jd0aKje0<Fn]@80@FWQ
3035_[D2045Yh@@0aKje00@0[Jf]0<Jo]`36_kL0@FWQ2036_kL00`11JN40a[ng045Yh@030<Jo]`80
@FWQ00D0a[ng045Yh@36_kL0a[ng0:f][@050<O1^080@FWQ2037`KP2045Yh@H0al6h00<0[Jf]045Y
h@37`KX03037`KX2045Yh@H0al6j00D0[Jf]045Yh@38`K/0b<6k000000030<S1^`80@FWQ1`38`K/2
045Yh@@0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`2][Jd2045Yh@H0b<6k0P11JN400`38`K/0[Jf]0<O1
_0020<O1_080@FWQ1@37`K`00`11JN40al6l0<O1_0050<O1_080@FWQ2@36`;`2045Yh@P0a/2l00<0
[Jf]0<>m^`33_K/03033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nK
X0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]
0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`3
045Yh@X0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ2@33_K<2
045Yh@@0[Jf]0P11JN400`2][Jd0aKje0<Fn]@0;0<Fn]@<0@FWQ00D0aKje0:f][@36_kL0a[ng045Y
h@070<Jo]`80@FWQ00<0a[ng045Yh@36_kL00P36_kL2045Yh@050<Jo]`11JN40a[ng0<Jo]`2][Jd0
1037`KP2045Yh@T0al6h0P11JN460<O1^0030:f][@11JN40al6j00`0al6j0P11JN460<O1^P030:f]
[@11JN40b<6k00D0b<6k0P11JN470<S1^`80@FWQ1P2][Jd2045Yh@L0b<6k0P11JN460<S1^`80@FWQ
00<0b<6k0:f][@37`K`00`37`K`2045Yh@<0al6l00<0@FWQ0<O1_037`K`01`37`K`00`2][Jd0a/2l
0<K0_0070<K0_080@FWQ2036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0
302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0
[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2]
[Jd80;VbYP030:f][@2n]j`0_[N/00<0_[N/0`11JN4:0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<01@33_K<2045Yh@T0`kfc00@0@FWQ0<>m/`33_K<0[Jf]0P35_[D2045Yh@030<Fn
]@2][Jd0[Jf]00X0[Jf]1035_[D2045Yh@80a[ng00<0@FWQ0<Jo]`36_kL01@36_kL2045Yh@80a[ng
00<0@FWQ0<Jo]`36_kL00P11JN420<Jo]`03045Yh@36_kL0[Jf]00@0al6h0P11JN490<O1^080@FWQ
1P37`KP00`2][Jd0@FWQ045Yh@0>0<O1^P@0@FWQ0P37`KX00`2][Jd0@FWQ0<S1^`030<S1^`80[Jf]
0P11JN470:f][@03045Yh@38`K/0b<6k00<0b<6k00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@H0
b<6k0P11JN400`38`K/0[Jf]0<O1_0040<O1_0D0@FWQ2P37`K`00`2][Jd0a/2l0<K0_0060<K0_080
@FWQ2036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^003
0:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M
0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/00<0_[N/
0`11JN4:0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01@33_K<2045Yh@T0`kfc
00@0@FWQ0<>m/`33_K<0[Jf]0P35_[D3045Yh@`0aKje1P2][Jd3045Yh@L0[Jf]0P11JN420<Jo]`04
045Yh@36_kL0@FWQ045Yh@<0a[ng00<0@FWQ0<Jo]`2][Jd01037`KP2045Yh@L0al6h1`11JN430<O1
^0030:f][@11JN40@FWQ00T0al6j2@2][Jd4045Yh@@0[Jf]0P38`K/2045Yh@L0b<6k00<0@FWQ0<S1
^`38`K/00`38`K/0102][Jd0b<6k045Yh@11JN460<S1^`80@FWQ1`38`K/2045Yh@030<S1^`2][Jd0
al6l01<0al6l00<0[Jf]0<K0_036`;`01P36`;`2045Yh@P0a/2l00<0[Jf]0<>m^`33_K/00P33_K/4
0:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`h>H0
/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[0040;jg[003045Yh@2n]j`0@FWQ
00X0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ2@33_K<01011
JN40`kfc0<>m/`2][Jd20<Fn]@<0@FWQ1035_[D00`11JN40aKje0<Fn]@0:0<Fn]@040:f][@36_kL0
a[ng045Yh@L0a[ng0P11JN420:f][@04045Yh@2][Jd0@FWQ045Yh@<0[Jf]00<0@FWQ0:f][@2][Jd0
102][Jd2045YhA80[Jf]0P11JN490:f][@/0al6j00<0[Jf]045Yh@38`K/01@38`K/2045Yh@L0b<6k
00<0@FWQ0<S1^`38`K/00`38`K/00`2][Jd0b<6k045Yh@02045Yh@D0b<6k0P11JN450<S1^`@0@FWQ
00<0b<6k0:f][@37`K`04`37`K`00`2][Jd0a/2l0<K0_0060<K0_080@FWQ2036`;`00`2][Jd0`kfk
0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]
B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;Vb
YP0=0;VbYP<0[Jf]1@2n]j`00`11JN40_[N/0;jg[0090;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<01@33_K<2045Yh@T0`kfc00@0@FWQ0<>m/`33_K<0[Jf]0P35_[D3045Yh@<0aKje
00<0@FWQ0<Fn]@11JN401@35_[D2045Yh@@0aKje00@0[Jf]0<Jo]`36_kL0@FWQ1`36_kL2045Yh@80
a[ng00@0@FWQ0<Jo]`11JN40@FWQ0`36_kL00`11JN4000000:f][@040<O1^080@FWQ4@37`KP00`2]
[Jd0@FWQ045Yh@0<0<O1^P80@FWQ1P37`KX00`2][Jd0@FWQ0<S1^`050<S1^`80@FWQ1P38`K/00`11
JN40b<6k0<S1^`040<S1^`060:f][@38`K/0@FWQ045Yh@38`K/0@FWQ0`38`K/2045Yh@/0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0060<K0_003045Yh@36`;`0a/2l00D0a/2l102]
[Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3P
iP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd00`2n]j`0@FWQ0;jg[00:0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01@33_K<2045Yh@T0`kfc00@0@FWQ0<>m/`33_K<0[Jf]0P35
_[D2045Yh@030<Fn]@11JN40aKje0080aKje0P11JN450<Fn]@80@FWQ1035_[D0102][Jd0a[ng0<Jo
]`11JN470<Jo]`06045Yh@36_kL0a[ng0<Jo]`11JN40a[ng0P11JN430<Jo]`03045Yh@36_kL0[Jf]
00@0al6h0P11JN4A0<O1^0030:f][@11JN40@FWQ00D0al6j00<0@FWQ0<O1^P37`KX01037`KX2045Y
h@H0al6j00<0[Jf]045Yh@38`K/01@38`K/3045Yh@@0b<6k0P11JN460<S1^`040:f][@38`K/0@FWQ
045Yh@80b<6k0`11JN4=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01P36`;`0
0`11JN40a/2l0<K0_0050:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[@T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ2033_K<2045Y
h@80`kfc00<0[Jf]045Yh@11JN400P11JN420<Fn]@@0@FWQ1`35_[D00`11JN40aKje0<Fn]@020<Fn
]@030:f][@36_kL0@FWQ00L0a[ng0P11JN440<Jo]`80@FWQ1@36_kL00`11JN40[Jf]0<O1^0030<O1
^080@FWQ4@37`KP0102][Jd0@FWQ045Yh@11JN430<O1^P03045Yh@37`KX0@FWQ00H0al6j00<0@FWQ
0<O1^P37`KX01037`KX00`11JN40b<6k0<S1^`050<S1^`80@FWQ00<0b<6k045Yh@11JN400P11JN48
0<S1^`040:f][@38`K/0@FWQ045YhA80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0
[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[
W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ2033_K<2045Yh@80`kfc00<0
[Jf]0<Fn]@35_[D04035_[D6045Yh@P0a[ng0P11JN440<Jo]`80@FWQ1@36_kL00`11JN40[Jf]0<O1
^0030<O1^080@FWQ4@37`KP01@2][Jd0@FWQ045Yh@37`KX0@FWQ00<0al6j0P11JN470<O1^P03045Y
h@37`KX0al6j00<0@FWQ00<0[Jf]0<S1^`38`K/00P38`K/5045Yh@d0b<6k00@0[Jf]0<S1^`11JN40
@FWQ4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?oo
o`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0
[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ2033_K<2045Yh@80
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`040<Jo]`L0@FWQ0P36_kL2045Yh@<0
a[ng1P11JN420<O1^080@FWQ3`37`KP5045Yh@80al6j1011JN490<O1^P80@FWQ0`37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`040:f][@38`K/0@FWQ045YhA80b<6k00<0[Jf]0<O1_037`K`04037`K`50:f]
[A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?oo
o`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0
[Jf]4@31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ1`33_K<2045Yh@<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h0080al6h0P11JN4:0<O1^003
045Yh@37`KP0al6h00@0al6h00<0[Jf]0<O1^P37`KX02@37`KX00`000000al6j0<O1^P080<O1^P03
0:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`11JN40@FWQ3`38`K/01011JN40b<6k0<S1^`2][Jd=
0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]
0<>m/`33_K<01@33_K<2045Yh@L0`kfc0P11JN430<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0030<O1^003045Yh@37`KP0al6h00P0al6h00<0@FWQ
0<O1^037`KP01037`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]
0<S1^`11JN40@FWQ3`38`K/2045Yh@030<S1^`2][Jd0al6l00H0al6l1P2][Jd70<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`
h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc00D0`kfc0P11JN46
0<>m/`80@FWQ1033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP00`37`KP00`11JN40al6h0<O1^0070<O1^080@FWQ1P37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`11JN40@FWQ3`38`K/01011JN40b<6k0<S1
^`2][Jd20<O1_0D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]0P33
_K<4045Yh@D0`kfc0P11JN450<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^0030<O1^003045Yh@37`KP0al6h00L0al6h0P11JN460<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k045Yh@11JN4?0<S1^`H0[Jf]
4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
0P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`H0[Jf]
1P11JN460<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^0030<O1^080@FWQ2037`KP2045Yh@H0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`@0@FWQ2038`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo
001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00@0al6h0P11JN460<O1^0<0@FWQ1P37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k
202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JdA0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@@0al6h0P11JN400`37`KP0@FWQ0<O1
^0050<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102]
[JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00L0al6h1011JN430<O1^003045Yh@37`KP0
al6h00@0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D03`35_[DA0:f][@X0a[ng00<000000<Jo]`2][Jd03037`KPX0:f][A40b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/00`33_K/30:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;Vb
YP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102]
[Jd@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`00`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0
[Jf]PP2`h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00?0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@
0<S1^`L0[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0
[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38
`K/0b<6k202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0
[Jf][`2`h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52062 .3309 m
.51894 .3341 L
s
.52229 .33411 m
.52062 .3309 L
s
.539 .33079 m
.53232 .33086 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54568 .33067 m
.54235 .33394 L
s
.54902 .3306 m
.54568 .33067 L
s
.52061 .33732 m
.52229 .33411 L
s
.51894 .3341 m
.52061 .33732 L
s
.55236 .33373 m
.54902 .3306 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54902 .3306 m
.55403 .33368 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59492 .3286 m
.59703 .32847 L
s
.255 .412 .882 r
.5016 .33842 m
.50326 .33845 L
s
.49829 .34061 m
.5016 .33842 L
s
.49994 .34065 m
.5016 .33842 L
s
.49828 .34512 m
.49994 .34065 L
s
0 0 0 r
.55745 .35364 m
.55746 .35613 L
s
.255 .412 .882 r
.49662 .34509 m
.49829 .34061 L
s
.49004 .33815 m
.49333 .3405 L
s
.4851 .338 m
.49004 .33815 L
s
0 0 0 r
.55911 .35253 m
.55913 .35608 L
s
.255 .412 .882 r
.49333 .3405 m
.49662 .34509 L
s
.48179 .34014 m
.4851 .338 L
s
.48015 .34008 m
.4851 .338 L
s
.55785 .34033 m
.56114 .33797 L
s
.56114 .33797 m
.56443 .33786 L
s
.5562 .34038 m
.56114 .33797 L
s
.55292 .34499 m
.5562 .34038 L
s
.55457 .34494 m
.55785 .34033 L
s
.56443 .33786 m
.56938 .33992 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48012 .3446 m
.48179 .34014 L
s
.47848 .34453 m
.48015 .34008 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56938 .33992 m
.57269 .3443 L
s
.57265 .33753 m
.57276 .35561 L
s
.55294 .3495 m
.55457 .34494 L
s
.55128 .34954 m
.55292 .34499 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57429 .33745 m
.57441 .35554 L
s
.54965 .35637 m
.55128 .34954 L
s
.55131 .35633 m
.55294 .3495 L
s
.4801 .34912 m
.48012 .3446 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49823 .36095 m
.49828 .34512 L
s
.49656 .36545 m
.49662 .34509 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47845 .34905 m
.47848 .34453 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51815 .33861 m
.52478 .37027 L
s
.51149 .37022 m
.51815 .33861 L
s
.5314 .33859 m
.53808 .37017 L
s
.52478 .37027 m
.5314 .33859 L
s
0 0 0 r
.51892 .39227 m
.51907 .38866 L
s
.52213 .38865 m
.52229 .39228 L
s
.255 .412 .882 r
.51315 .37023 m
.51815 .34537 L
s
.52645 .37026 m
.53141 .34535 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57256 .37308 m
.57258 .37502 L
s
.57422 .37198 m
.57424 .37496 L
s
.255 .412 .882 r
.58411 .33696 m
.59552 .33629 L
s
.4801 .34912 m
.48172 .3537 L
s
0 0 0 r
.5206 .39227 m
.5206 .38866 L
s
.255 .412 .882 r
.47845 .34905 m
.48007 .35364 L
s
.54965 .35637 m
.54969 .3677 L
s
.55131 .35633 m
.55135 .36766 L
s
.44584 .33602 m
.45722 .33674 L
s
.48501 .35607 m
.49492 .35861 L
s
.49492 .35861 m
.49657 .36091 L
s
.48172 .3537 m
.48501 .35607 L
s
.48007 .35364 m
.48501 .35607 L
s
.49656 .36545 m
.49823 .36095 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56782 .35581 m
.57933 .35531 L
s
.49489 .36768 m
.49656 .36545 L
s
.5065 .37016 m
.51813 .37026 L
s
.53309 .37022 m
.54306 .3701 L
s
.54969 .3677 m
.55137 .37447 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49157 .36987 m
.49489 .36768 L
s
.55135 .36766 m
.55303 .37443 L
s
.48003 .3627 m
.48168 .36276 L
s
.48167 .36503 m
.48168 .36276 L
s
.48002 .36497 m
.48003 .3627 L
s
.48495 .36968 m
.49157 .36987 L
s
.48002 .36497 m
.48165 .3673 L
s
0 0 0 r
.57258 .37502 m
.57923 .37473 L
s
.255 .412 .882 r
.48165 .3673 m
.48495 .36968 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45206 .36819 m
.45233 .33644 L
s
.45043 .36809 m
.45071 .33634 L
s
.46355 .36427 m
.46521 .36208 L
s
.46521 .36208 m
.46684 .36443 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59079 .3547 m
.59248 .36141 L
s
.55303 .37443 m
.5547 .37894 L
s
.55137 .37447 m
.55305 .37898 L
s
.59064 .33659 m
.5909 .36833 L
s
.58901 .33669 m
.58927 .36842 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46682 .3667 m
.46684 .36443 L
s
.45218 .35455 m
.45375 .36146 L
s
.55305 .37898 m
.55638 .38345 L
s
.46355 .36427 m
.46518 .36662 L
s
.42811 .33465 m
.4329 .33732 L
s
.4329 .33732 m
.43607 .3421 L
s
.46516 .36889 m
.46682 .3667 L
s
.5547 .37894 m
.55804 .3834 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43607 .3421 m
.43764 .34676 L
s
.42811 .33465 m
.43129 .33719 L
s
.43129 .33719 m
.43446 .34197 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59098 .39053 m
.59103 .39696 L
s
.255 .412 .882 r
.57451 .37143 m
.57459 .3851 L
s
.5729 .37833 m
.57451 .37143 L
s
.41219 .33316 m
.42811 .33465 L
s
.43446 .34197 m
.43602 .34663 L
s
.46024 .36864 m
.46516 .36889 L
s
.43764 .34676 m
.43918 .35369 L
s
.45375 .36146 m
.45698 .36619 L
s
.59248 .36141 m
.59578 .36576 L
s
.55638 .38345 m
.56136 .38558 L
s
.61813 .33685 m
.62289 .33416 L
s
.61658 .34152 m
.61813 .33685 L
s
.43602 .34663 m
.43757 .35357 L
s
.55804 .3834 m
.56136 .38558 L
s
.58435 .36869 m
.5909 .36833 L
s
.45698 .36619 m
.46024 .36864 L
s
.61973 .33671 m
.62289 .33416 L
s
.61818 .34138 m
.61973 .33671 L
s
.56963 .38301 m
.5729 .37833 L
s
.5729 .37833 m
.57459 .3851 L
s
.61658 .34152 m
.61663 .34605 L
s
.62289 .33416 m
.62767 .33371 L
s
.56136 .38558 m
.56468 .38547 L
s
.43907 .36506 m
.43918 .35369 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61818 .34138 m
.61823 .34592 L
s
.56468 .38547 m
.56963 .38301 L
s
.43745 .36494 m
.43757 .35357 L
s
.59578 .36576 m
.59906 .36783 L
s
.44554 .36778 m
.45206 .36819 L
s
.41792 .38167 m
.41854 .33379 L
s
.61663 .34605 m
.61829 .35046 L
s
.62767 .33371 m
.63088 .33567 L
s
.60227 .36306 m
.60387 .36068 L
s
.60387 .36068 m
.60551 .36284 L
s
.61823 .34592 m
.61989 .35033 L
s
.41632 .38153 m
.41695 .33364 L
s
.60227 .36306 m
.60391 .36523 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59906 .36783 m
.60394 .36751 L
s
.64322 .31619 m
.6541 .31488 L
s
.60551 .36284 m
.60553 .36511 L
s
.61829 .35046 m
.62312 .35232 L
s
.63088 .33567 m
.6341 .33989 L
s
.60394 .36751 m
.60553 .36511 L
s
.61989 .35033 m
.62312 .35232 L
s
.43738 .37178 m
.43907 .36506 L
s
.43576 .37166 m
.43745 .36494 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63562 .33519 m
.63874 .33259 L
s
.6341 .33989 m
.63562 .33519 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62312 .35232 m
.63271 .35371 L
s
.63874 .33259 m
.64031 .33242 L
s
.6372 .33502 m
.63874 .33259 L
s
.63568 .33973 m
.6372 .33502 L
s
.61839 .35957 m
.61842 .36185 L
s
.61839 .35957 m
.62 .35943 L
s
.6341 .33989 m
.63438 .3604 L
s
.43571 .37623 m
.43738 .37178 L
s
.62 .35943 m
.62003 .36171 L
s
.63568 .33973 m
.63591 .35568 L
s
.61842 .36185 m
.62005 .36399 L
s
.43409 .37611 m
.43576 .37166 L
s
.62005 .36399 m
.62329 .366 L
s
.43242 .38057 m
.43571 .37623 L
s
.43081 .38044 m
.43409 .37611 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63271 .35371 m
.63432 .35584 L
s
.62329 .366 m
.62968 .36543 L
s
.42756 .38248 m
.43242 .38057 L
s
.42756 .38248 m
.43081 .38044 L
s
.63438 .3604 m
.63591 .35568 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64789 .31565 m
.64863 .36349 L
s
.64945 .31546 m
.6502 .36332 L
s
.62968 .36543 m
.63283 .36284 L
s
.63283 .36284 m
.63438 .3604 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6498 .33818 m
.65284 .33325 L
s
.65284 .33325 m
.6559 .33059 L
s
.41154 .38109 m
.42756 .38248 L
s
.6559 .33059 m
.65899 .3302 L
s
.65899 .3302 m
.6621 .33208 L
s
.65899 .3302 m
.66364 .33187 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6621 .33208 m
.66525 .33623 L
s
.64393 .36401 m
.6502 .36332 L
s
.66364 .33187 m
.66678 .33602 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66525 .33623 m
.6669 .34289 L
s
.66678 .33602 m
.66843 .34268 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65009 .35645 m
.65328 .36067 L
s
.65328 .36067 m
.65643 .36259 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6669 .34289 m
.66698 .34747 L
s
.65643 .36259 m
.65953 .36222 L
s
.66843 .34268 m
.66851 .34726 L
s
.66557 .35455 m
.66698 .34747 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67726 .32765 m
.68772 .32601 L
s
.5 Mabswid
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65953 .36222 m
.66257 .35954 L
s
.65953 .36222 m
.66411 .35934 L
s
.6671 .35435 m
.66851 .34726 L
s
.66257 .35954 m
.66557 .35455 L
s
.66411 .35934 m
.6671 .35435 L
s
.68176 .32696 m
.68271 .3753 L
s
.68326 .32672 m
.68421 .37508 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69362 .32502 m
.7038 .32321 L
s
.68376 .35198 m
.68684 .35613 L
s
.68684 .35613 m
.69134 .35774 L
s
.67818 .37594 m
.68421 .37508 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69134 .35774 m
.6943 .35727 L
s
.69946 .324 m
.70001 .34935 L
s
.698 .32426 m
.69855 .3496 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6943 .35727 m
.69719 .35447 L
s
.6943 .35727 m
.69865 .35422 L
s
.69719 .35447 m
.69855 .3496 L
s
.70954 .32212 m
.71942 .32014 L
s
.69865 .35422 m
.70001 .34935 L
s
.7138 .32128 m
.71456 .35369 L
s
.71521 .321 m
.71598 .35342 L
s
.32938 .32548 m
.33085 .32345 L
s
.32949 .32086 m
.33085 .32345 L
s
.32803 .32288 m
.32949 .32086 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32803 .32288 m
.32938 .32548 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32911 .33704 m
.32986 .3652 L
s
.32703 .36467 m
.32911 .33704 L
s
.71028 .35449 m
.71598 .35342 L
s
.32844 .36494 m
.32878 .35097 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31693 .32052 m
.31824 .32314 L
s
.31807 .3301 m
.31824 .32314 L
s
.72654 .3256 m
.72916 .32036 L
s
.72533 .33286 m
.72654 .3256 L
s
.31426 .31759 m
.31693 .32052 L
s
.72533 .33286 m
.72544 .3375 L
s
.72791 .3253 m
.73053 .32005 L
s
.72671 .33256 m
.72791 .3253 L
s
.31669 .3298 m
.31813 .32777 L
s
.71347 .36793 m
.71484 .36533 L
s
.71347 .36793 m
.71495 .37 L
s
.71484 .36533 m
.71631 .3674 L
s
.30885 .31633 m
.31426 .31759 L
s
.31663 .33212 m
.31807 .3301 L
s
.72671 .33256 m
.72683 .33721 L
s
.32833 .3696 m
.32986 .3652 L
s
.72544 .3375 m
.727 .34419 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73053 .32005 m
.73319 .31712 L
s
.72916 .32036 m
.73319 .31712 L
s
.3139 .33151 m
.31669 .3298 L
s
.71495 .37 m
.71631 .3674 L
s
.73319 .31712 m
.73589 .31649 L
s
.72683 .33721 m
.72838 .34389 L
s
.31384 .33384 m
.31663 .33212 L
s
.32703 .36467 m
.32833 .3696 L
s
.31628 .34608 m
.31777 .34172 L
s
.31754 .35104 m
.31777 .34172 L
s
.727 .34419 m
.72987 .34826 L
s
.73589 .31649 m
.73996 .31785 L
s
.30701 .33463 m
.3139 .33151 L
s
.30611 .31801 m
.30885 .31633 L
s
.30695 .33696 m
.31384 .33384 L
s
.72838 .34389 m
.73125 .34797 L
s
.31485 .34812 m
.31628 .34608 L
s
.31628 .34608 m
.31754 .35104 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30472 .32002 m
.30611 .31801 L
s
.31205 .34986 m
.31485 .34812 L
s
.73996 .31785 m
.74274 .32186 L
s
.30352 .31504 m
.30472 .32002 L
s
.30326 .32435 m
.30352 .31504 L
s
.30326 .32435 m
.30472 .32002 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73125 .34797 m
.73403 .34971 L
s
.72987 .34826 m
.73403 .34971 L
s
.30664 .34865 m
.31205 .34986 L
s
.30428 .33634 m
.30701 .33463 L
s
.73403 .34971 m
.73809 .3488 L
s
.30422 .33867 m
.30695 .33696 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30288 .33836 m
.30428 .33634 L
s
.74053 .33883 m
.7418 .33617 L
s
.74053 .33883 m
.74192 .34085 L
s
.7418 .33617 m
.74319 .3382 L
s
.73809 .3488 m
.74071 .34584 L
s
.30282 .3407 m
.30422 .33867 L
s
.30403 .34569 m
.30664 .34865 L
s
.30276 .34304 m
.30288 .33836 L
s
.74071 .34584 m
.74325 .34054 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74319 .3382 m
.74325 .34054 L
s
.30276 .34304 m
.30403 .34569 L
s
.75168 .31252 m
.7531 .31685 L
s
.75168 .31252 m
.75195 .32187 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29173 .31435 m
.29417 .3197 L
s
.28798 .31097 m
.29173 .31435 L
s
.75195 .32187 m
.7531 .31685 L
s
.7531 .31685 m
.75431 .31417 L
s
.75431 .31417 m
.75679 .31114 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75679 .31114 m
.76181 .30972 L
s
.28547 .31026 m
.28798 .31097 L
s
.29364 .33844 m
.29371 .33609 L
s
.29248 .33341 m
.29371 .33609 L
s
.29113 .33543 m
.29248 .33341 L
s
.75234 .33592 m
.75357 .33324 L
s
.75234 .33592 m
.75248 .34062 L
s
.29093 .34248 m
.29364 .33844 L
s
.75357 .33324 m
.75606 .33022 L
s
.75241 .33827 m
.75363 .33559 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2829 .31188 m
.28547 .31026 L
s
.28166 .31152 m
.28547 .31026 L
s
.75363 .33559 m
.75613 .33257 L
s
.29113 .33543 m
.29235 .33811 L
s
.75248 .34062 m
.75383 .34264 L
s
.75606 .33022 m
.76223 .32379 L
s
.76181 .30972 m
.76436 .31134 L
s
.75613 .33257 m
.7623 .32614 L
s
.75383 .34264 m
.75646 .34433 L
s
.2883 .34416 m
.29093 .34248 L
s
.28029 .31586 m
.2829 .31188 L
s
.27906 .31549 m
.28166 .31152 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76436 .31134 m
.76566 .31332 L
s
.75646 .34433 m
.76153 .34297 L
s
.2845 .34315 m
.2883 .34416 L
s
.76223 .32379 m
.76464 .32073 L
s
.7623 .32614 m
.76471 .32308 L
s
.27884 .32255 m
.28029 .31586 L
s
.76464 .32073 m
.76581 .31802 L
s
.27762 .32219 m
.27906 .31549 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76566 .31332 m
.76588 .32037 L
s
.76471 .32308 m
.76588 .32037 L
s
.28207 .3401 m
.2845 .34315 L
s
.28082 .33976 m
.2845 .34315 L
s
.76153 .34297 m
.76396 .33993 L
s
.2787 .32726 m
.27884 .32255 L
s
.27972 .33469 m
.28207 .3401 L
s
.27748 .3269 m
.27762 .32219 L
s
.2787 .32726 m
.27972 .33469 L
s
.76396 .33993 m
.76513 .33722 L
s
.76513 .33722 m
.76623 .33215 L
s
.76623 .33215 m
.76651 .34159 L
s
.26496 .30391 m
.27321 .30659 L
s
.76513 .33722 m
.76651 .34159 L
s
.27849 .33433 m
.28082 .33976 L
s
.27748 .3269 m
.27849 .33433 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77406 .30837 m
.77518 .30564 L
s
.77406 .30837 m
.77532 .31035 L
s
.77518 .30564 m
.77643 .30761 L
s
.2686 .33856 m
.26964 .30545 L
s
.77532 .31035 m
.77643 .30761 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26742 .33819 m
.26846 .30507 L
s
.77569 .32215 m
.77777 .35026 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77614 .33636 m
.77658 .35062 L
s
.2639 .33708 m
.2686 .33856 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77539 .35098 m
.77569 .32215 L
s
.25259 .29949 m
.26038 .30233 L
s
.77539 .35098 m
.77673 .35538 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24931 .29071 m
.25103 .29319 L
s
.255 .412 .882 r
.77673 .35538 m
.77777 .35026 L
s
.2669 .35485 m
.26816 .35283 L
s
.26705 .35008 m
.26816 .35283 L
s
.26579 .3521 m
.26705 .35008 L
s
0 0 0 r
.24931 .29071 m
.251 .2941 L
s
.255 .412 .882 r
.25614 .32726 m
.257 .30112 L
s
.26579 .3521 m
.2669 .35485 L
s
.25503 .32687 m
.25589 .30072 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25487 .33164 m
.25614 .32726 L
s
.25376 .33125 m
.25503 .32687 L
s
.25148 .33285 m
.25487 .33164 L
s
.24099 .29485 m
.24828 .29783 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25148 .33285 m
.25376 .33125 L
s
.2493 .33206 m
.25148 .33285 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24616 .32846 m
.2493 .33206 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24234 .3465 m
.24408 .29614 L
s
.24339 .3469 m
.24512 .29656 L
s
.24422 .32285 m
.24616 .32846 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23923 .3453 m
.24339 .3469 L
s
.23202 .29328 m
.23378 .29897 L
s
.23378 .29897 m
.23449 .30662 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23432 .31143 m
.23449 .30662 L
s
.23107 .29283 m
.23281 .29853 L
s
.23281 .29853 m
.23352 .30618 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22927 .28953 m
.23202 .29328 L
s
.23309 .31823 m
.23432 .31143 L
s
.23335 .311 m
.23352 .30618 L
s
.22927 .28953 m
.23107 .29283 L
s
.23212 .3178 m
.23335 .311 L
s
.22742 .28862 m
.22927 .28953 L
s
.23098 .3222 m
.23309 .31823 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23002 .32177 m
.23212 .3178 L
s
.2255 .29011 m
.22742 .28862 L
s
.22804 .32332 m
.23098 .3222 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22115 .27858 m
.22117 .27815 L
s
.5 Mabswid
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22254 .32069 m
.22442 .26992 L
s
.22093 .26801 m
.22712 .27134 L
s
.22165 .32024 m
.22354 .26945 L
s
.22804 .32332 m
.23002 .32177 L
s
.22353 .29402 m
.2255 .29011 L
s
.22618 .32245 m
.22804 .32332 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22444 .31914 m
.22618 .32245 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22094 .30925 m
.22096 .30855 L
s
.21998 .30999 m
.22006 .308 L
s
.5 Mabswid
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22281 .3134 m
.22444 .31914 L
s
.21775 .28348 m
.21859 .28396 L
s
.21902 .3189 m
.22254 .32069 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.216 .28496 m
.21775 .28348 L
s
.21682 .28543 m
.21775 .28348 L
s
.21581 .28981 m
.21682 .28543 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2188 .34165 m
.21887 .33965 L
s
.21976 .34087 m
.21979 .34017 L
s
.5 Mabswid
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21499 .28934 m
.216 .28496 L
s
.21517 .30686 m
.21581 .28981 L
s
.83053 .2818 m
.83824 .27691 L
s
.21357 .28352 m
.21499 .28934 L
s
.21416 .31128 m
.21499 .28934 L
s
.21208 .28012 m
.21357 .28352 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21416 .31128 m
.21517 .30686 L
s
.20977 .27865 m
.21208 .28012 L
s
.21362 .30348 m
.21434 .30639 L
s
.20901 .29819 m
.21362 .30348 L
s
.21325 .31326 m
.21416 .31128 L
s
.21155 .31478 m
.21325 .31326 L
s
.20817 .2801 m
.20977 .27865 L
s
.20743 .27961 m
.20977 .27865 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83371 .27987 m
.83569 .3313 L
s
.83293 .28035 m
.83491 .33175 L
s
.20844 .31292 m
.21155 .31478 L
s
.20724 .2845 m
.20817 .2801 L
s
.83249 .33311 m
.84026 .32854 L
s
.20651 .28401 m
.20743 .27961 L
s
.83824 .27691 m
.83978 .27836 L
s
.83824 .27691 m
.84049 .27786 L
s
.2076 .29478 m
.20901 .29819 L
s
.20686 .2943 m
.20901 .29819 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20705 .2894 m
.20724 .2845 L
s
.20705 .2894 m
.2076 .29478 L
s
.20632 .28891 m
.20651 .28401 L
s
.83978 .27836 m
.84138 .28227 L
s
.20632 .28891 m
.20686 .2943 L
s
.20702 .30951 m
.20844 .31292 L
s
.20647 .30412 m
.20721 .3046 L
s
.20712 .30705 m
.20721 .3046 L
s
.84049 .27786 m
.84208 .28177 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20638 .30658 m
.20702 .30951 L
s
.20638 .30658 m
.20647 .30412 L
s
.84138 .28227 m
.84227 .28668 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84771 .27011 m
.8478 .27046 L
s
.84746 .26393 m
.84752 .26345 L
s
.84752 .26345 m
.84833 .26644 L
s
.255 .412 .882 r
.84208 .28177 m
.84296 .28618 L
s
.84227 .28668 m
.84325 .29357 L
s
0 0 0 r
.8478 .27046 m
.84833 .26644 L
s
.255 .412 .882 r
.84296 .28618 m
.84393 .29307 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84026 .32854 m
.84162 .32513 L
s
.84026 .32854 m
.84233 .32466 L
s
.84325 .29357 m
.84374 .30591 L
s
.84393 .29307 m
.84442 .30542 L
s
.84162 .32513 m
.84284 .31923 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84334 .31381 m
.84374 .30591 L
s
.84233 .32466 m
.84354 .31876 L
s
.84284 .31923 m
.84334 .31381 L
s
.84403 .31333 m
.84442 .30542 L
s
.20017 .29975 m
.20074 .30271 L
s
.20064 .30518 m
.20074 .30271 L
s
.84354 .31876 m
.84403 .31333 L
s
.19988 .30717 m
.20064 .30518 L
s
.19942 .30173 m
.20017 .29975 L
s
.19397 .26644 m
.19806 .27008 L
s
.19942 .30173 m
.19998 .3047 L
s
.19793 .30571 m
.19988 .30717 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85003 .3256 m
.85022 .33048 L
s
.8488 .29309 m
.84882 .29344 L
s
.85054 .32379 m
.8509 .33001 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84764 .26982 m
.84904 .30447 L
s
.84577 .27136 m
.85002 .26774 L
s
.84825 .2693 m
.84965 .30397 L
s
.19485 .30323 m
.19625 .26853 L
s
0 0 0 r
.8504 .33682 m
.85051 .3376 L
s
.255 .412 .882 r
.84715 .30594 m
.84965 .30397 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19426 .30274 m
.19567 .26801 L
s
.19677 .30224 m
.19793 .30571 L
s
.84905 .28908 m
.84995 .29602 L
s
0 0 0 r
.85051 .3376 m
.8509 .33001 L
s
.255 .412 .882 r
.19575 .29627 m
.19677 .30224 L
s
.19545 .28832 m
.19575 .29627 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84995 .29602 m
.85133 .29999 L
s
.19255 .30124 m
.19485 .30323 L
s
.85133 .29999 m
.85257 .30148 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85257 .30148 m
.85422 .29997 L
s
0 0 0 r
.18328 .24919 m
.18459 .25075 L
s
.255 .412 .882 r
.18998 .28319 m
.1908 .26327 L
s
.18804 .28111 m
.19153 .28474 L
s
.85347 .29548 m
.85412 .29747 L
s
.85347 .29548 m
.85391 .29247 L
s
.18948 .28267 m
.1903 .26274 L
s
.85391 .29247 m
.85454 .29446 L
s
.18924 .26416 m
.19 .2702 L
s
.85422 .29997 m
.85465 .29696 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85454 .29446 m
.85465 .29696 L
s
.18796 .26005 m
.18924 .26416 L
s
.85707 .26834 m
.85731 .26281 L
s
.85707 .26834 m
.85727 .27333 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85731 .26281 m
.85852 .25869 L
s
.18709 .25897 m
.18796 .26005 L
s
.18863 .31578 m
.18926 .30071 L
s
.18845 .30773 m
.18926 .30071 L
s
.85727 .27333 m
.85794 .27781 L
s
.85752 .2678 m
.85776 .26227 L
s
.85752 .2678 m
.85773 .2728 L
s
.85776 .26227 m
.85852 .25869 L
s
.85773 .2728 m
.85838 .27728 L
s
0 0 0 r
.86249 .25794 m
.86289 .25192 L
s
.255 .412 .882 r
.18615 .26039 m
.18709 .25897 L
s
.18575 .25985 m
.18709 .25897 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85794 .27781 m
.85935 .27873 L
s
.85852 .25869 m
.85974 .25706 L
s
.18726 .31176 m
.18845 .30773 L
s
.18845 .30773 m
.18863 .31578 L
s
0 0 0 r
.86289 .25192 m
.86394 .24668 L
s
.255 .412 .882 r
.85838 .27728 m
.85935 .27873 L
s
.85835 .28784 m
.85846 .29035 L
s
.85835 .28784 m
.8588 .28732 L
s
.18515 .26432 m
.18615 .26039 L
s
.85846 .29035 m
.85901 .29234 L
s
.8588 .28732 m
.8589 .28983 L
s
.18476 .26378 m
.18575 .25985 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85974 .25706 m
.86061 .25848 L
s
.18577 .31277 m
.18726 .31176 L
s
.85935 .27873 m
.86183 .27806 L
s
0 0 0 r
.86353 .2775 m
.86399 .28827 L
s
.255 .412 .882 r
.85901 .29234 m
.85998 .29382 L
s
0 0 0 r
.86379 .28874 m
.86414 .29187 L
s
.255 .412 .882 r
.18455 .2688 m
.18515 .26432 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86399 .28827 m
.86472 .29495 L
s
.255 .412 .882 r
.86061 .25848 m
.86155 .26241 L
s
.18417 .26826 m
.18476 .26378 L
s
0 0 0 r
.86414 .29187 m
.86472 .29495 L
s
.255 .412 .882 r
.85998 .29382 m
.8616 .29174 L
s
.18489 .31176 m
.18577 .31277 L
s
.18386 .27582 m
.18455 .2688 L
s
.18349 .27528 m
.18417 .26826 L
s
.86155 .26241 m
.86169 .25684 L
s
.86155 .26241 m
.86251 .28511 L
s
.18415 .30822 m
.18489 .31176 L
s
.18375 .30771 m
.18489 .31176 L
s
.86169 .25684 m
.86225 .25322 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86352 .27743 m
.86472 .27571 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18333 .28844 m
.18386 .27582 L
s
.8619 .26187 m
.86203 .25629 L
s
.8619 .26187 m
.86265 .27952 L
s
.86203 .25629 m
.86225 .25322 L
s
.86183 .27806 m
.86229 .28005 L
s
.18296 .28791 m
.18349 .27528 L
s
.8616 .29174 m
.86225 .28816 L
s
.18356 .30213 m
.18415 .30822 L
s
.86225 .25322 m
.86258 .25267 L
s
0 0 0 r
.86648 .29642 m
.86684 .29593 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18317 .30161 m
.18375 .30771 L
s
.18333 .28844 m
.18339 .29655 L
s
.18356 .30213 m
.18339 .29655 L
s
.86225 .28816 m
.86251 .28511 L
s
.18296 .28791 m
.18301 .29603 L
s
.86251 .28511 m
.86265 .27952 L
s
.18301 .29603 m
.18317 .30161 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17621 .23675 m
.17669 .23794 L
s
.255 .412 .882 r
.17972 .28514 m
.18148 .28833 L
s
.18056 .28674 m
.18097 .24907 L
s
.17852 .28247 m
.18097 .24907 L
s
.17874 .283 m
.18065 .25666 L
s
.86469 .287 m
.86654 .28326 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86502 .24766 m
.86737 .28111 L
s
.86502 .24766 m
.86554 .2854 L
s
0 0 0 r
.86939 .24363 m
.86945 .24007 L
s
.255 .412 .882 r
.86534 .25526 m
.8658 .28487 L
s
0 0 0 r
.86945 .24007 m
.86968 .2353 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86968 .2353 m
.87003 .23414 L
s
.87003 .23414 m
.8705 .23661 L
s
.87003 .23414 m
.87064 .23603 L
s
.17527 .23386 m
.1748 .24054 L
s
.17465 .24839 m
.17527 .23386 L
s
.255 .412 .882 r
.17852 .28247 m
.17927 .24457 L
s
0 0 0 r
.87101 .28107 m
.87133 .28371 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17727 .27869 m
.17895 .2522 L
s
0 0 0 r
.87109 .24274 m
.8705 .23661 L
s
.1748 .24054 m
.17465 .24839 L
s
.17482 .23633 m
.1748 .24054 L
s
.255 .412 .882 r
.86651 .24315 m
.86737 .28111 L
s
0 0 0 r
.17471 .23154 m
.17482 .23633 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17714 .27814 m
.17927 .24457 L
s
0 0 0 r
.87121 .24216 m
.87064 .23603 L
s
.87133 .28371 m
.87189 .28629 L
s
.255 .412 .882 r
.86684 .25079 m
.86756 .28057 L
s
0 0 0 r
.17432 .2292 m
.17471 .23154 L
s
.87241 .31349 m
.8728 .31256 L
s
.87168 .25312 m
.87109 .24274 L
s
.255 .412 .882 r
.17679 .27651 m
.17775 .28031 L
s
0 0 0 r
.87189 .28629 m
.87224 .2852 L
s
.1737 .27028 m
.1737 .26606 L
s
.17338 .2776 m
.1737 .27028 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87179 .25255 m
.87121 .24216 L
s
.1737 .26606 m
.17357 .26129 L
s
.17354 .27394 m
.17354 .26972 L
s
.17354 .26972 m
.17342 .26495 L
s
.17306 .28072 m
.17338 .2776 L
s
.17357 .26129 m
.17337 .25113 L
s
.87224 .2852 m
.8724 .28044 L
s
.87224 .2852 m
.87254 .27989 L
s
.17403 .23168 m
.17432 .2292 L
s
.872 .26044 m
.87168 .25312 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17342 .26495 m
.17321 .2548 L
s
.17262 .2833 m
.17306 .28072 L
s
.255 .412 .882 r
.17808 .23889 m
.17815 .23946 L
s
0 0 0 r
.87211 .25987 m
.87179 .25255 L
s
.8724 .28044 m
.87236 .27199 L
s
.87236 .27199 m
.872 .26044 L
s
.255 .412 .882 r
.17785 .24031 m
.17808 .23889 L
s
.1779 .24088 m
.17808 .23889 L
s
0 0 0 r
.87254 .27989 m
.87248 .27144 L
s
.87248 .27144 m
.87211 .25987 L
s
.17382 .23476 m
.17403 .23168 L
s
.255 .412 .882 r
.17763 .24544 m
.1779 .24088 L
s
0 0 0 r
.17218 .28111 m
.17262 .2833 L
s
.17337 .25113 m
.1734 .24633 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86819 .27841 m
.86882 .27514 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86651 .24315 m
.86855 .27678 L
s
0 0 0 r
.17334 .24575 m
.17382 .23476 L
s
.17321 .2548 m
.17324 .24999 L
s
.255 .412 .882 r
.17759 .24488 m
.17785 .24031 L
s
0 0 0 r
.1734 .24633 m
.1735 .24208 L
s
.255 .412 .882 r
.17686 .26345 m
.17763 .24544 L
s
0 0 0 r
.17324 .24999 m
.17334 .24575 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17759 .24488 m
.17776 .2386 L
s
.17659 .26806 m
.17759 .24488 L
s
0 0 0 r
.8715 .22905 m
.87178 .23754 L
s
.87132 .22362 m
.8715 .22905 L
s
.255 .412 .882 r
.17786 .23488 m
.17776 .2386 L
s
0 0 0 r
.17218 .27632 m
.17218 .28111 L
s
.255 .412 .882 r
.17659 .26806 m
.17686 .26345 L
s
.86786 .24345 m
.86806 .24916 L
s
.86806 .24916 m
.86837 .25745 L
s
.86764 .23716 m
.86786 .24345 L
s
.17792 .23316 m
.17786 .23488 L
s
0 0 0 r
.17228 .27208 m
.17218 .27632 L
s
.17254 .26414 m
.17228 .27208 L
s
.1719 .27892 m
.17254 .26414 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86837 .25745 m
.86893 .27036 L
s
.17681 .2629 m
.17689 .25976 L
s
0 0 0 r
.17228 .27208 m
.1719 .27892 L
s
.87258 .25592 m
.8729 .26329 L
s
.87216 .24909 m
.87258 .25592 L
s
.255 .412 .882 r
.86786 .24288 m
.86808 .2486 L
s
.86808 .2486 m
.8684 .25689 L
s
0 0 0 r
.87124 .22244 m
.87132 .22362 L
s
.255 .412 .882 r
.86762 .23659 m
.86786 .24288 L
s
.17689 .25976 m
.17703 .25382 L
s
.8684 .25689 m
.86895 .26981 L
s
.86744 .23286 m
.86764 .23716 L
s
.17645 .2701 m
.17659 .26806 L
s
0 0 0 r
.87261 .25535 m
.87309 .26643 L
s
.8729 .26329 m
.87325 .27012 L
s
.17393 .227 m
.17412 .22274 L
s
.1738 .23009 m
.17393 .227 L
s
.255 .412 .882 r
.86744 .23286 m
.86762 .23659 L
s
.86893 .27036 m
.86929 .27758 L
s
0 0 0 r
.17412 .22274 m
.17401 .22583 L
s
.255 .412 .882 r
.1763 .27159 m
.17645 .2701 L
s
0 0 0 r
.87129 .22494 m
.87124 .22244 L
s
.87122 .22435 m
.87124 .22244 L
s
.255 .412 .882 r
.17791 .23459 m
.17792 .23316 L
s
.17797 .23401 m
.17792 .23316 L
s
.86895 .26981 m
.8693 .27704 L
s
0 0 0 r
.87309 .26643 m
.87342 .27327 L
s
.17401 .22583 m
.1738 .23009 L
s
.255 .412 .882 r
.86734 .23171 m
.86744 .23286 L
s
0 0 0 r
.87325 .27012 m
.87342 .27327 L
s
.255 .412 .882 r
.86929 .27758 m
.86953 .28223 L
s
.17637 .26939 m
.1763 .27159 L
s
0 0 0 r
.87145 .23114 m
.87129 .22494 L
s
.255 .412 .882 r
.8693 .27704 m
.86953 .28169 L
s
.17775 .23918 m
.17791 .23459 L
s
.8672 .23257 m
.86734 .23171 L
s
0 0 0 r
.87342 .27327 m
.87358 .27587 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86953 .28223 m
.86975 .28635 L
s
0 0 0 r
.87136 .23056 m
.87122 .22435 L
s
.255 .412 .882 r
.17783 .23861 m
.17797 .23401 L
s
.17703 .25382 m
.17724 .25011 L
s
.17703 .25382 m
.17731 .24954 L
s
0 0 0 r
.173 .24854 m
.1711 .2926 L
s
.17103 .29368 m
.173 .24854 L
s
.255 .412 .882 r
.86953 .28169 m
.86974 .28581 L
s
.17753 .24436 m
.17775 .23918 L
s
.17724 .25011 m
.17753 .24436 L
s
0 0 0 r
.87358 .27587 m
.8735 .27421 L
s
.255 .412 .882 r
.1776 .24379 m
.17783 .23861 L
s
0 0 0 r
.87184 .24167 m
.87145 .23114 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8672 .23257 m
.86721 .2366 L
s
.17731 .24954 m
.1776 .24379 L
s
.17657 .26568 m
.17637 .26939 L
s
.86975 .28635 m
.86979 .28735 L
s
0 0 0 r
.87173 .24109 m
.87136 .23056 L
s
.255 .412 .882 r
.1768 .26048 m
.17686 .25993 L
s
.17668 .26308 m
.1768 .26048 L
s
.86974 .28581 m
.86979 .28735 L
s
0 0 0 r
.17106 .29314 m
.17203 .27078 L
s
.255 .412 .882 r
.86688 .22883 m
.86777 .24959 L
s
.17657 .26568 m
.17675 .26253 L
s
.17675 .26253 m
.17686 .25993 L
s
.86721 .24734 m
.86808 .25128 L
s
0 0 0 r
.8735 .27421 m
.87322 .26938 L
s
.8735 .27421 m
.87315 .26882 L
s
.87216 .24909 m
.87184 .24167 L
s
.255 .412 .882 r
.86675 .22825 m
.86764 .24903 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87206 .24852 m
.87173 .24109 L
s
.255 .412 .882 r
.86968 .28627 m
.86979 .28735 L
s
0 0 0 r
.87274 .26081 m
.87216 .24909 L
s
.87322 .26938 m
.87274 .26081 L
s
.86887 .21237 m
.87023 .21652 L
s
.17073 .30062 m
.17103 .29368 L
s
.87265 .26025 m
.87206 .24852 L
s
.87315 .26882 m
.87265 .26025 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86933 .28203 m
.86968 .28627 L
s
0 0 0 r
.1711 .2926 m
.17073 .30062 L
s
.86972 .21475 m
.87149 .25573 L
s
.255 .412 .882 r
.86889 .2757 m
.86933 .28203 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86843 .2673 m
.8691 .28303 L
s
.86843 .2673 m
.86889 .2757 L
s
.86889 .2757 m
.8691 .28303 L
s
.17765 .25808 m
.17792 .2549 L
s
.17754 .26069 m
.17765 .25808 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87149 .25573 m
.87162 .26267 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86952 .21415 m
.8713 .25517 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8713 .25517 m
.87142 .26211 L
s
.86562 .20585 m
.86785 .21 L
s
.87114 .26475 m
.87162 .26267 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87114 .26475 m
.87142 .26211 L
s
.87065 .26364 m
.87114 .26475 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86664 .20763 m
.86842 .24895 L
s
.86696 .20822 m
.86874 .24951 L
s
.86966 .25819 m
.87065 .26364 L
s
.86874 .24951 m
.86966 .25819 L
s
.86874 .24951 m
.86874 .25651 L
s
.86841 .25595 m
.86842 .24895 L
s
.86099 .19934 m
.86409 .20348 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86788 .25862 m
.86874 .25651 L
s
.86788 .25862 m
.86841 .25595 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86283 .2017 m
.86509 .25472 L
s
.86239 .20111 m
.86464 .25417 L
s
.86714 .2575 m
.86788 .25862 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85644 .20917 m
.85691 .20974 L
s
0 0 0 r
.86578 .25203 m
.86714 .2575 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8646 .2433 m
.86578 .25203 L
s
.255 .412 .882 r
.85589 .23141 m
.85784 .23188 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86324 .2525 m
.86509 .25472 L
s
.255 .412 .882 r
.85749 .24588 m
.85847 .24698 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1844 .2678 m
.18516 .26695 L
s
.18764 .23476 m
.18779 .23119 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85508 .2245 m
.85527 .22895 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85732 .19523 m
.85956 .24864 L
s
.85497 .19289 m
.85896 .19699 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84756 .18651 m
.85244 .19056 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8572 .24644 m
.85956 .24864 L
s
.85675 .19464 m
.85899 .24809 L
s
.85042 .18882 m
.85215 .23102 L
s
.84972 .18824 m
.85145 .23047 L
s
.86012 .27508 m
.86053 .27174 L
s
.85979 .26735 m
.86053 .27174 L
s
.85937 .27067 m
.85979 .26735 L
s
.85937 .27067 m
.86012 .27508 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85177 .2382 m
.85215 .23102 L
s
.83875 .18024 m
.84452 .18422 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85106 .23765 m
.85145 .23047 L
s
.84976 .24044 m
.85177 .2382 L
s
.84976 .24044 m
.85106 .23765 L
s
.84211 .18251 m
.84538 .26404 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84129 .18194 m
.84455 .26352 L
s
.84825 .23936 m
.84976 .24044 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84575 .23386 m
.84825 .23936 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84382 .22501 m
.84575 .23386 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83162 .17965 m
.83381 .1885 L
s
.82855 .17412 m
.83162 .17965 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84199 .26198 m
.84538 .26404 L
s
.82655 .17302 m
.82855 .17412 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82465 .17582 m
.82655 .17302 L
s
.82361 .17528 m
.82655 .17302 L
s
.83487 .21574 m
.83503 .21965 L
s
.83378 .2113 m
.83487 .21574 L
s
.83298 .21468 m
.83378 .2113 L
s
.83343 .22642 m
.83503 .21965 L
s
.83298 .21468 m
.83408 .21912 L
s
.82285 .18254 m
.82465 .17582 L
s
.82178 .18201 m
.82361 .17528 L
s
.83164 .22931 m
.83343 .22642 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82222 .19374 m
.82285 .18254 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82115 .19322 m
.82178 .18201 L
s
.82864 .22776 m
.83164 .22931 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82222 .19374 m
.82252 .20158 L
s
.82643 .22279 m
.82864 .22776 L
s
.82538 .22228 m
.82864 .22776 L
s
.82115 .19322 m
.82144 .20106 L
s
.82252 .20158 m
.82403 .21389 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82403 .21389 m
.82643 .22279 L
s
.82144 .20106 m
.82296 .21338 L
s
.82296 .21338 m
.82538 .22228 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81517 .20982 m
.81646 .21427 L
s
.81646 .21427 m
.8166 .21823 L
s
.81415 .21327 m
.81517 .20982 L
s
.8156 .22169 m
.8166 .21823 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79903 .16037 m
.80771 .16396 L
s
.81415 .21327 m
.81546 .21773 L
s
.81209 .22021 m
.8156 .22169 L
s
.78846 .1564 m
.79645 .15937 L
s
.80955 .21526 m
.81209 .22021 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80517 .19395 m
.80683 .20634 L
s
.80683 .20634 m
.80955 .21526 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80282 .1619 m
.80477 .21729 L
s
.80406 .16241 m
.80602 .21778 L
s
.80096 .21586 m
.80602 .21778 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25898 .23875 m
.26174 .15471 L
s
.77799 .17645 m
.79062 .18066 L
s
.2604 .23831 m
.26315 .15423 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78669 .22685 m
.7925 .15787 L
s
.78709 .23896 m
.79383 .15837 L
s
.77136 .15071 m
.78009 .15351 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25759 .15616 m
.2808 .14868 L
s
.77431 .15164 m
.78709 .23896 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27043 .19209 m
.27183 .18912 L
s
0 0 0 r
.27927 .14913 m
.28007 .17266 L
s
.255 .412 .882 r
.76989 .18801 m
.76999 .18814 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27183 .18912 m
.27187 .18919 L
s
0 0 0 r
.26172 .19805 m
.2704 .19536 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28007 .17266 m
.2808 .14868 L
s
.26989 .21146 m
.27091 .17932 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25479 .24007 m
.27822 .23325 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29647 .14833 m
.30151 .14308 L
s
.29462 .15677 m
.29647 .14833 L
s
.29811 .14792 m
.30151 .14308 L
s
.29625 .15636 m
.29811 .14792 L
s
.29335 .20117 m
.29462 .15677 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30151 .14308 m
.30484 .14226 L
s
.29498 .20077 m
.29625 .15636 L
s
.30484 .14226 m
.30978 .14507 L
s
.27668 .23366 m
.27896 .2089 L
s
.27822 .23325 m
.27896 .2089 L
s
.30978 .14507 m
.31299 .15234 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31331 .14026 m
.32024 .13872 L
s
.31181 .19694 m
.31331 .14026 L
s
.28851 .20237 m
.29498 .20077 L
s
.31354 .19658 m
.31503 .13987 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31942 .17857 m
.31948 .17615 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33442 .13983 m
.34 .13474 L
s
.3306 .14863 m
.33442 .13983 L
s
.30667 .19806 m
.31354 .19658 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32851 .16114 m
.3306 .14863 L
s
.33624 .13948 m
.34 .13474 L
s
.33241 .14827 m
.33624 .13948 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33031 .16079 m
.33241 .14827 L
s
.34 .13474 m
.34369 .13406 L
s
.32831 .16927 m
.32851 .16114 L
s
.34369 .13406 m
.34733 .13744 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33011 .16892 m
.33031 .16079 L
s
.32831 .16927 m
.32982 .18114 L
s
.33011 .16892 m
.33163 .1808 L
s
.34733 .13744 m
.35091 .14491 L
s
.35118 .13274 m
.35877 .13147 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34931 .21874 m
.35118 .13274 L
s
.35122 .21844 m
.35306 .13242 L
s
.32982 .18114 m
.33326 .18864 L
s
.33163 .1808 m
.33509 .18831 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33326 .18864 m
.33868 .19175 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33509 .18831 m
.33868 .19175 L
s
.37423 .13317 m
.38024 .12828 L
s
.37015 .14189 m
.37423 .13317 L
s
.33868 .19175 m
.34241 .19111 L
s
.3762 .1329 m
.38024 .12828 L
s
.37211 .1416 m
.3762 .1329 L
s
.36795 .15442 m
.37015 .14189 L
s
.38024 .12828 m
.38422 .12775 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36991 .15413 m
.37211 .1416 L
s
.34625 .18637 m
.35021 .17755 L
s
.34241 .19111 m
.34625 .18637 L
s
.38422 .12775 m
.38816 .1313 L
s
.38422 .12775 m
.39018 .13105 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36779 .1626 m
.36795 .15442 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38816 .1313 m
.39206 .13897 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36975 .16232 m
.36991 .15413 L
s
.39018 .13105 m
.39409 .13873 L
s
.36779 .1626 m
.36952 .17463 L
s
.36975 .16232 m
.37149 .17436 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39206 .13897 m
.39389 .15102 L
s
.255 .412 .882 r
.66761 .20153 m
.66771 .20154 L
s
0 0 0 r
.39409 .13873 m
.39593 .15078 L
s
.40655 .12508 m
.419 .12383 L
s
.36952 .17463 m
.37331 .18232 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37149 .17436 m
.37529 .18206 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34363 .21963 m
.35122 .21844 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39376 .15923 m
.39389 .15102 L
s
.3958 .159 m
.39593 .15078 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37331 .18232 m
.3792 .18567 L
s
.42739 .12307 m
.4401 .12205 L
s
.37529 .18206 m
.3792 .18567 L
s
.39152 .17182 m
.39376 .15923 L
s
.39356 .17158 m
.3958 .159 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66704 .20105 m
.66761 .20153 L
s
.66163 .19789 m
.66761 .20153 L
s
.66057 .19627 m
.66163 .19789 L
s
0 0 0 r
.3792 .18567 m
.38322 .18516 L
s
.38732 .18055 m
.39152 .17182 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38935 .18031 m
.39356 .17158 L
s
.38322 .18516 m
.38732 .18055 L
s
.38322 .18516 m
.38935 .18031 L
s
.45937 .1249 m
.46372 .12056 L
s
.46372 .12056 m
.46806 .12034 L
s
.45721 .12502 m
.46372 .12056 L
s
.45498 .13336 m
.45721 .12502 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46806 .12034 m
.47455 .12415 L
s
.45714 .13323 m
.45937 .1249 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47893 .11987 m
.48766 .11957 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41068 .12465 m
.43521 .18011 L
s
.40987 .18225 m
.43372 .12254 L
s
.41195 .18205 m
.43584 .12237 L
s
.47861 .17775 m
.47893 .11987 L
s
.48081 .17768 m
.48111 .11979 L
s
.45459 .17886 m
.45498 .13336 L
s
.47455 .12415 m
.47886 .1322 L
s
.45676 .17874 m
.45714 .13323 L
s
.49862 .11928 m
.50079 .12746 L
s
.49857 .13575 m
.49862 .11928 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54038 .11917 m
.54258 .12331 L
s
.53819 .12325 m
.54038 .11917 L
s
.503 .12331 m
.5074 .11913 L
s
.51619 .11905 m
.5074 .11913 L
s
.51619 .11905 m
.52059 .12314 L
s
.5404 .12739 m
.54258 .12331 L
s
.50079 .12746 m
.503 .12331 L
s
.40571 .18266 m
.41824 .18148 L
s
.53819 .12325 m
.5404 .12739 L
s
.52059 .12314 m
.52279 .12726 L
s
.49857 .13575 m
.50079 .12746 L
s
.52279 .12726 m
.52279 .13962 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52059 .13963 m
.52279 .1355 L
s
.51617 .14377 m
.52059 .13963 L
s
.52058 .14376 m
.52279 .13962 L
s
.42669 .18076 m
.43949 .1798 L
s
.50513 .15216 m
.51617 .14377 L
s
.51617 .14791 m
.52058 .14376 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50512 .15631 m
.51617 .14791 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50071 .15638 m
.50513 .15216 L
s
.49849 .16057 m
.50071 .15638 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5007 .16053 m
.50512 .15631 L
s
.4481 .17924 m
.45676 .17874 L
s
.49847 .16888 m
.49849 .16057 L
s
.49848 .16472 m
.5007 .16053 L
s
.52058 .16864 m
.52279 .16033 L
s
.52279 .16033 m
.52279 .17696 L
s
.49847 .16888 m
.50066 .173 L
s
.47203 .17801 m
.48081 .17768 L
s
.51836 .17281 m
.52058 .16864 L
s
.52058 .16864 m
.52279 .17696 L
s
.50066 .173 m
.50507 .17709 L
s
.51393 .17699 m
.51836 .17281 L
s
.50507 .17709 m
.51393 .17699 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54044 .14802 m
.54277 .19802 L
s
.53834 .19796 m
.54044 .14802 L
s
.5405 .17293 m
.54055 .19799 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54057 .20637 m
.54277 .19802 L
s
.53834 .19796 m
.54057 .20637 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P3o
YQ000`000000ojH@0?nV40020?nV40D000002`3oYQ000`000000ojH@0?nV40020?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V0@3oool00880/>3V0P2][Jd4
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA00l0ojHA0`0000020?nV4@<0[Jf]1@0000040:f][@030000002][Jd0
[Jf]008000001@2][Jd00`000000[Jf]0:f][@070:f][@800000502][Jd?0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ47000000030?nV4@2][Jd0[Jf]
00H0[Jf]0P0000030:f][@8000000`3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ000P3oYQ000`00
0000ojH@000000080?nV40030000003oYQ00ojH@00H0ojH@00<000000?nV400000000`3oYQ000`2]
[Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@P0
00001P2][Jd2000000<0[Jf]1`3oYQ42000000H0ojHA00<000000?nV4@3oYQ400P0000020?nV4@03
0:f][@3oYQ00ojH@0080ojH@0`0000080?nV40030000003oYQ00ojH@00H0ojH@0P0000040?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa090:f][@h0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40
oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ40303oYQ460:f][@040000002][Jd0[Jf]0:f][@@0ojHA00@0[Jf]0?nV4@00
000000002`3oYQ42000000H0ojHA00<000000?nV4@3oYQ400P0000020?nV4@030:f][@3oYQ00ojH@
0080ojH@0P00000:0?nV40030000003oYQ00ojH@00H0ojH@00<000000?nV403oYQ000P3oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?oo
o`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA0080ojHA100000060:f][@L0ojHA00<000000?nV4@3oYQ40103oYQ40102][Jd0
ojHA00000000000:0?nV4@800000203oYQ4010000000ojHA0000000000020?nV4@030:f][@3oYQ00
ojH@0080ojH@0P00000:0?nV40030000003oYQ00ojH@00/0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400E0?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01D0ojHA1@2][Jd2000000<0ojHA0`00000;0?nV4@030000003oYQ40ojHA
00@0ojHA00<0[Jf]0000000000002`3oYQ42000000P0ojHA00@000000?nV4@00000000000P3oYQ40
0`2][Jd0ojH@0?nV40020?nV408000002P3oYQ000`000000ojH@0?nV400;0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP40060:f][A80o:0@00<0[Jf]
0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f]
[A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@D000000P2][Jd20?nV
4@040:f][@3oYQ400000000000D0ojHA0P00000<0?nV4@030000003oYQ40ojHA00<0ojHA00<0[Jf]
0000000000002`3oYQ42000000T0ojHA0`0000020?nV4@030:f][@3oYQ00ojH@0080ojH@00<00000
0?nV403oYQ002@3oYQ000`000000ojH@0?nV400;0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP40060?bP40D0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3P
iP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV
4@3oYQ40203oYQ43000000<0[Jf]0P0000070?nV4@040:f][@3oYQ400000000000H0ojHA0P00000;
0?nV4@030000003oYQ40ojHA00<0ojHA00<0[Jf]0000000000002`3oYQ42000000X0ojHA0P000002
0?nV4@030:f][@3oYQ00ojH@0080ojH@00<000000?nV403oYQ002@3oYQ000`000000ojH@0?nV400;
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400;
0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@050?nV4@80[Jf]00@000000:f]
[@2][Jd0[Jf]0P0000000`3oYQ400000000000070?nV4@030:f][@000000000000L0ojHA0P00000<
0?nV4@030000003oYQ40ojHA0080ojHA0P00000<0?nV4@8000002P3oYQ4200000080ojHA00<0[Jf]
0?nV403oYQ000P3oYQ000`000000ojH@0?nV40090?nV40030000003oYQ00ojH@00/0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@0100o:0@1P2][Jd2
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@04
0=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd00000000000050:f][@030?nV4@0000000000
00@0ojHA00@000000?nV4@00000000001`3oYQ400`2][Jd00000000000080?nV4@8000002`3oYQ40
0`000000ojHA0?nV4@020?nV4@800000303oYQ42000000X0ojHA0P0000020?nV4@030:f][@3oYQ00
ojH@00d0ojH@0P00000=0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa00
0`2][Jd0o:0@0?bP400F0?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A0180oj@A0`0000020:f][@H0ojHA00<000000?nV4@3oYQ40103oYQ430000
00L0ojHA0P0000090?nV4@8000002`3oYQ4010000000ojHA0?nV4@3oYQ42000000d0ojHA0P00000:
0?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV400=0?nV408000003@3oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0:f][@03
0:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H1
0?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0<0?nT
4@<000000`2][Jd2000000030:f][@3oYQ40ojHA00D0ojHA0P0000060?nV4@<000001`3oYQ420000
00T0ojHA0P00000<0?nV4@030000003oYQ40ojHA008000003@3oYQ42000000X0ojHA0P0000020?nV
4@030:f][@3oYQ00ojH@00`0ojH@0P00000>0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0
/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY14200000080
[Jf]0P000000103oY14000000000002][Jd70?nV4@030000003oYQ40ojHA00H0ojHA0P0000070?nV
4@8000002@3oYQ42000000`0ojHA00<000000?nV4@3oYQ400P00000=0?nV4@8000002P3oYQ420000
0080ojHA00<0[Jf]0?nV403oYQ002`3oYQ000`000000ojH@0000000>0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00L0mY`?102][Jd90?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2]
[Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]00<000000?nT4@3oY1400P3oY1401@000000
oj@A000000000000[Jf]00H0ojHA0P0000080?nV4@8000001`3oYQ42000000X0ojHA0P00000<0?nV
4@<000003P3oYQ42000000X0ojHA0P0000020?nV4@030:f][@3oYQ00ojH@00X0ojH@00<000000?nV
400000003`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0
o:0@0?bP400?0?bP40040:f][@3oY140oj@A0?nT4@800000102][Jd30?nT4@8000001@3oY1430000
00030:f][@3oYQ40ojHA00@0ojHA0P0000080?nV4@8000001P3oYQ42000000/0ojHA0P00000<0?nV
4@<000003P3oYQ42000000X0ojHA0P0000020?nV4@030:f][@3oYQ00ojH@00P0ojH@0P0000000`3o
YQ0000000?nV400:0?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f]
[@030?JL3`2][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0:f][@1@0;3P
iP40oooo001U0;3PiP030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
000000000003000000L0oj@A0P0000050?nT4@<0000000<0[Jf]0?nV4@3oYQ40103oYQ42000000P0
ojHA0P0000060?nV4@8000002`3oYQ42000000`0ojHA0P0000000`2][Jd0ojHA0?nV4@0<0?nV4@80
00002@3oYQ42000000<0ojHA00<0[Jf]0?nV403oYQ001`3oYQ0010000000ojH@0?nV4000000<0?nV
40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l20:f][@800000403/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>7
3P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400=0?bP40<0000000<0[Jf]0?nT4@3oY1400P000006
0?nT4@8000001`3oY142000000030:f][@3oYQ40ojHA00@0ojHA0P0000080?nV4@8000001P3oYQ42
000000/0ojHA0P00000<0?nV4@80000000<0[Jf]0?nV4@3oYQ40303oYQ42000000T0ojHA0P000003
0?nV4@030:f][@3oYQ00ojH@00H0ojH@00@000000?nV4000000000003@3oYQ000`000000ojH@0?nV
40020?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00`00000=0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3C
Q`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400:0?bP40<0000000<0[Jf]0?bP402][Jd0
0`3oY142000000H0oj@A0P0000070?nT4@80000000<0[Jf]0?nV4@3oYQ400`3oYQ42000000T0ojHA
0P0000060?nV4@8000002`3oYQ42000000`0ojHA0P0000000`2][Jd0ojHA0?nV4@0<0?nV4@800000
2@3oYQ42000000<0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000030?nV40000000ojH@00h0ojH@
00<000000?nV403oYQ000P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`050:f][@3/UPh0k9H>0000003/
UPh00P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0
/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00P0o:0@100000030?bP40040:f][@3oY140oj@A0?nT4@8000001P3oY142000000L0
oj@A0P0000000`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000H0ojHA0P00000;0?nV4@80
00002`3oYQ42000000030?nV4@000000ojHA00`0ojHA0P0000080?nV4@80[Jf]0P0000090:f][@04
0000002][Jd0[Jf]00000100[Jf]00<000000:f][@2][Jd02P2][JdG0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`040:f][@3/UPh0k9H>
000000<0k9H>0`2][Jd2000000L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`04
0;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd00`3lX1000000000000030?bP
40040:f][@3oY140oj@A0?nT4@8000001P3oY142000000L0oj@A0P0000060?nV4@8000002@3oYQ42
000000H0ojHA0P00000;0?nV4@8000002`3oYQ42000000030?nV4@000000ojHA00H0ojHA1P2][Jd2
000000P0[Jf]0P3oYQ42000000<0ojHA00<0[Jf]0?nV403oYQ000P3oYQ0010000000ojH@00000000
000A0?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00@0
[Jf]0>bF3P3/UPh000001P3/UPh20:f][@<00000103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>7
3P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@<0o:0@0P00
00030?bP40040:f][@3oY140oj@A0?nT4@8000001P3oY142000000L0oj@A0P0000060?nV4@800000
2@3oYQ42000000H0ojHA0P00000;0?nV4@8000002P3oYQ42000000<0[Jf]00<000000:f][@2][Jd0
102][Jd60?nV4@8000002P3oYQ42000000<0ojHA00<0[Jf]0?nV403oYQ000P3oYQ02000000X0ojH@
00<000000?nV403oYQ001P3oYQ000`000000ojH@0?nV40020?nV40030:f][@3oYA00ojD@01D0ojD@
302][JdH0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l01@2][Jd0k9H>
0>bF3P3/UPh0000000L0k9H>00@000000:f][@2][Jd000000`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0
dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd60?bP
408000000`3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00@0oj@A0P0000070?nT
4@8000001P3oYQ42000000T0ojHA0P0000060?nV4@8000002`3oYQ42000000030?nV4@2][Jd0[Jf]
00L0[Jf]0P0000020?nV4@030:f][@000000ojHA00/0ojHA0P00000:0?nV4@8000000`3oYQ400`2]
[Jd0ojH@0?nV40020?nV40030000003oYQ00ojH@00T0ojH@00<000000?nV403oYQ001P3oYQ000`00
0000ojH@0?nV40020?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f]
[@h0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`050:f][@3/UPh0k9H>
0>bF3P0000001`3/UPh010000000k9H>0>bF3P2][Jd2000000030>bF3P2][Jd0fhX=00`0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0:f][@2][Jd90?bP408000000`3l
X1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00@0oj@A0P0000070?nT4@8000001P3o
YQ400`000000ojHA0?nV4@080?nV4@8000001P3oYQ42000000@0ojHA1`2][Jd00`000000[Jf]0:f]
[@090?nV4@8000000P3oYQ400`2][Jd0ojHA0000000;0?nV4@8000002P3oYQ42000000<0ojHA00<0
[Jf]0?nV403oYQ000P3oYQ000`000000ojH@0?nV40080?nV40800000203oYQ000`000000ojH@0?nV
40020?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`050:f][@3/UPh0k9H>0>bF3P000000
1`3/UPh00`000000k9H>0>bF3P020>bF3P<000003@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]
A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1020:f][@/0o:0@0P00
00030?bP40030:f][@3oY140oj@A0080oj@A00<000000?nT4@3oY140103oY142000000L0oj@A0P00
00060?nV4@030000003oYQ40ojHA00P0ojHA0P0000050?nV4@030:f][@000000000000@0[Jf]1P3o
YQ42000000X0ojHA0P0000030?nV4@030:f][@3oYQ40000000/0ojHA0P00000:0?nV4@8000000`3o
YQ400`2][Jd0ojH@0?nV40020?nV40030000003oYQ00ojH@00P0ojH@0P0000080?nV40030000003o
YQ00ojH@0080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]5P3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`050:f][@3/UPh0k9H>0>bF3P0000001`3/UPh00`000000k9H>
0>bF3P020>bF3P030000003/UPh0[Jf]0080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]
A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][@`0o:0@0P00
00030?bP40030:f][@3oY140oj@A0080oj@A00<000000?nT4@3oY140103oY142000000H0oj@A0P00
00000`2][Jd0ojHA0?nV4@040?nV4@030000003oYQ40ojHA00P0ojHA0P0000050:f][@030?nV4@00
0000000000X0ojHA0P00000:0?nV4@8000000`3oYQ400`2][Jd0ojHA0000000;0?nV4@8000002P3o
YQ42000000<0ojHA00<0[Jf]0?nV403oYQ000P3oYQ000`000000ojH@0?nV40080?nV40800000203o
YQ000`000000ojH@0?nV40020?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa00102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l01@2][Jd0k9H>
0>bF3P3/UPh0000000L0k9H>00<000000>bF3P3/UPh00P3/UPh00`000000k9H>0:f][@020=^:3@80
[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V
00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@
0?bP400:0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00@0oj@A
0P0000060?nT4@80000000<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0?nV4@040?nV4@@0[Jf]
0P0000070?nV4@8000002@3oYQ42000000T0ojHA0P0000040?nV4@040:f][@3oYQ40ojHA000000X0
ojHA0P00000:0?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV40020?nV40030000003oYQ00ojH@00L0
ojH@0`0000080?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0mY`?01@0
mY`?00D0[Jf]0>bF3P3/UPh0k9H>000000060>bF3P800000103/UPh00`000000k9H>0:f][@040=^:
3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0
/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2]
[Jd0o:0@0?bP400:0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A
00@0oj@A0P0000060?nT4@80000000<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0:f][@040:f]
[@@0ojHA0P0000070?nV4@8000002@3oYQ42000000T0ojHA0P0000040?nV4@040:f][@3oYQ40ojHA
000000X0ojHA0P00000:0?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV40030?nV40030000003oYQ00
ojH@00H0ojH@0`0000080?nV40030000003oYQ00ojH@0080ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1P2][Jd30?bP40030:f][@3fW0l0
mY`?01@0mY`?00D0[Jf]0>bF3P3/UPh0k9H>000000060>bF3P030000003/UPh0k9H>00<0k9H>00<0
00000>bF3P2][Jd01P3KRPd0102][Jd0fhX=0=^:3@0000030=^:3@030:f][@2iM@/0^GD;00L0^GD;
00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P03
0:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400:0?bP4080
00000`3lX1000`2][Jd0oj@A0?nT4@090?nT4@8000001P3oY142000000030:f][@3oYQ40ojHA00@0
[Jf]00<000000:f][@3oYQ40203oYQ42000000L0ojHA0P0000080?nV4@8000002P3oYQ42000000@0
ojHA00D0[Jf]0?nV4@3oYQ40ojHA000000090?nV4@8000002P3oYQ42000000<0ojHA00<0[Jf]0?nV
403oYQ00103oYQ02000000D0ojH@00@000000?nV403oYQ0000001`3oYQ03000000<0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01@0o:0@1@2][JdE
0?JL3`030:f][@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P03
0>bF3P030000003/UPh0[Jf]00L0fhX=0P0000001@3KRPd000000=^:3@3KRPd0[Jf]00T0^GD;00D0
[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP400:0?bP40800000
0`3lX1000`2][Jd0oj@A0?nT4@090?nT4@8000001P3oY142000000<0[Jf]103oYQ42000000P0ojHA
0P0000080?nV4@800000203oYQ42000000T0ojHA0P0000050?nV4@050:f][@3oYQ40ojHA0?nV4@00
00002@3oYQ42000000X0ojHA0P0000030?nV4@030:f][@3oYQ00ojH@00H0ojH@1@0000030?nV4003
0000003oYQ00ojH@00D0ojH@0`0000030?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l0102][Jd0
k9H>0>bF3P3/UPh2000000D0k9H>00<000000>bF3P3/UPh00`3/UPh00`000000k9H>0:f][@070=^:
3@80000000D0[Jf]0000003KRPd0fhX=0:f][@090;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`
h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P2]
[Jd90>nH40030:f][@3lX100o:0@00X0o:0@0P0000030?bP40030000003oY140oj@A00P0oj@A0P00
00040?nT4@<0[Jf]0P0000000`2][Jd0ojHA0?nV4@040?nV4@800000203oYQ42000000P0ojHA00<0
[Jf]0000000000001P3oYQ42000000X0ojHA0P0000050?nV4@030:f][@3oYQ40ojHA0080ojHA00<0
00000?nV4@3oYQ400`3oYQ45000000L0ojHA1@0000030?nV4@030:f][@3oYQ00ojH@01H0ojH@0`00
00030?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>0080k9H>1@00
00000`3/UPh000000>bF3P040>bF3P030000003/UPh0[Jf]00H0fhX=00<000000=^:3@0000000P3K
RPd00`000000[Jf]0:f][@090;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0`2][Jd;
0>nH40030:f][@3lX100o:0@00X0o:0@0P0000030?bP40030000003oY140oj@A00P0oj@A0P000004
0:f][@<0oj@A0P0000000`2][Jd0ojHA0?nV4@040?nV4@8000001`3oYQ43000000P0ojHA00<0[Jf]
0000000000001P3oYQ42000000T0ojHA1@0000030?nV4@030:f][@000000000000D000005`3oYQ40
0`2][Jd0ojH@0?nV400F0?nV40<000000`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l0
0`2][Jd0k9H>0>bF3P020>bF3P030000003/UPh0k9H>0080k9H>0P0000050>bF3P030000003/UPh0
[Jf]00H0fhX=0P0000030=^:3@050000003KRPd0[Jf]0;Ue2`0000001`2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@090=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX102000000<0o:0@00<0
00000?nT4@3oY1401`3oY1400`2][Jd00000000000070?nT4@80000000<0[Jf]0?nV4@3oYQ40103o
YQ42000000L0ojHA0`0000080?nV4@040:f][@3oYQ400000000000@0ojHA0P0000080?nV4@@00000
1P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01H0ojH@0`0000030?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh0
0`3/UPh00`000000k9H>0>bF3P030>bF3P030000003/UPh0[Jf]00H0fhX=0P0000030=^:3@060000
003KRPd0[Jf]0:f][@2iM@/000001P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V
0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]303_V1000`2]
[Jd0o:0@0?bP400;0?bP408000000`3lX1000`000000oj@A0?nT4@030?nT4@@0[Jf]00<0oj@A0000
000000001`3oY142000000030:f][@3oYQ40ojHA00D0ojHA0P0000050?nV4@040000003oYQ400000
000000P0ojHA00@0[Jf]0?nV4@3oYQ40ojHA1000000D0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ005P3oYQ03000000<0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030?JL3`2]
[Jd0k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P030>bF3P030000003/
UPh0[Jf]00H0fhX=0P0000040=^:3@040000002][Jd0^GD;0:f][@8000001@2iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@060=>73P80[Jf]00<0dhL>0:f][@3_V1002`3_V1000`2][Jd0o:0@0?bP400;0?bP40800000
0`3lX1000`000000oj@A0:f][@030:f][@D0oj@A0P0000070?nT4@80000000<0[Jf]0?nV4@3oYQ40
1@3oYQ42000000D0ojHA00@000000?nV4@00000000001`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ005P3oYQ03000000<0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3f
W0l04`3fW0l30:f][@<0k9H>00<000000>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P030>bF3P03
0000003/UPh0[Jf]00H0fhX=0P0000040=^:3@080000002][Jd0^GD;0;Ue2`000000[Jf]0;Ue2`00
00030;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0<0>nH40030:f]
[@3lX100o:0@00/0o:0@0P0000020?bP40030:f][@000000[Jf]00T0oj@A0P0000070?nT4@800000
00<0[Jf]0?nV4@3oYQ401P3oYQ42000000<0ojHA00<000000?nV4@3oYQ400P0000070?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400F0?nV40<00000
0`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]00<0k9H>0000003/UPh0
0`3/UPh00`000000k9H>0>bF3P030>bF3P030000003/UPh0[Jf]00H0fhX=00<000000=^:3@3KRPd0
0`3KRPd02@000000[Jf]0;Ue2`2iM@/000000;Ue2`2][Jd0^GD;000000020;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0
0`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1002`3lX102
00000080[Jf]00<0o:0@0000003oY1402@3oY142000000L0oj@A0P0000000`2][Jd0ojHA0?nV4@07
0?nV4@8000000P3oYQ400`000000ojHA0?nV4@02000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01H0ojH@0`0000030?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh00`2][Jd000000>bF3P030>bF3P030000003/UPh0
k9H>00@0k9H>00<000000:f][@3KRPd01@3KRPd00`000000fhX=0=^:3@040=^:3@040:f][@2iM@/0
^GD;00000080^GD;00D0[Jf]000000000000^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`
h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@
0>nH400:0>nH40030:f][@3lX100o:0@00X0o:0@00<0[Jf]0000000000000`3lX1000`000000oj@A
0?nT4@080?nT4@8000001`3oY142000000030:f][@3oYQ40ojHA00T0ojHA0P0000030?nV4@800000
1`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
5P3oYQ03000000<0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P030>bF3P040000
002][Jd0[Jf]0:f][@8000001P3/UPh00`000000[Jf]0=^:3@050=^:3@030000003KRPd0fhX=00@0
fhX=00@0[Jf]0;Ue2`2iM@/000000`2iM@/010000000[Jf]0;Ue2`00000408QF1`80[Jf]@P2`h>H1
0?ooo`00F@2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1P3CQ`h00`2][Jd0kiP@0>nH
400:0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd00`3lX1000000000000020?bP408000002P3o
Y142000000L0oj@A0P0000000`2][Jd0ojHA0?nV4@0>0?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA802][Jd3000000/0[Jf]5`3oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P030>bF3P040000003/UPh0k9H>0>bF3P80000000<0[Jf]0>bF3P3/UPh00`3/UPh00`000000[Jf]
0=^:3@050=^:3@030000003KRPd0fhX=00@0fhX=00@0[Jf]0;Ue2`2iM@/000000`2iM@/01@000000
^GD;0:f][@2][Jd0000000<0R5H70P2][Je20;3PiP40oooo001I0;3PiP040:f][@2GH0/0Uf0;09MP
2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd30?bP
4080000000D0o:0@00000000000000000:f][@0:0?nT4@8000001`3oY142000000030:f][@3oYQ40
ojHA00h0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@
0:f][@L0ojHA00<0[Jf]0?nV403oYQ005P3oYQ03000000<0ojH@00<0[Jf]0?nU403oYA001@3oYA0@
0:f][@L0ojD@00<0[Jf]0?nS403oXa005@3oXa000`11JN40oj<@0?nS40020?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P030>bF3P040000003/UPh0
k9H>0>bF3P80000000<0k9H>0:f][@2][Jd00`3/UPh00`000000[Jf]0=^:3@050=^:3@030000003K
RPd0fhX=00@0fhX=00@0[Jf]0;Ue2`2iM@/000000`2iM@/010000000^GD;0;Ue2`2][Jd2000000<0
R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0
dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]1P3lX10300000080
o:0@00<000000:f][@3oY1402@3oY142000000D0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA00h0
ojHA0P0000070?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01H0
ojH@0`0000030?nV40030:f][@3oYA00ojD@01D0ojD@302][JdH0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P030>bF3P050000003/UPh0k9H>0>bF
3P000000103/UPh30:f][@030000002][Jd0fhX=00D0fhX=0P0000060=^:3@030:f][@2iM@/00000
00<0^GD;00L000000;Ue2`2iM@/0[Jf]00000028EPL000000080R5H700<0[Jf]0;3PiP2`h>H0@02`
h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0:f][@020:f][@P0o:0@0P0000030?bP40030000002][Jd0oj@A00T0oj@A0P000009
0?nT4@030:f][@3oYQ40ojHA00h0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd4
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ005P3oYQ000`000000ojH@00000003
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@`0oj<@00<0@FWQ
0?nS402][Jd06P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00<0k9H>00D00000
0>bF3P3/UPh0k9H>000000070>bF3P030000002][Jd0[Jf]00D0fhX=0P0000060=^:3@030:f][@2i
M@/0000000<0^GD;00H000000;Ue2`2iM@/0[Jf]00000028EPL20000000308QF1`2][Jd0/>3V0440
/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@
0P2][Jd;0?bP408000000`3lX1000`000000[Jf]0?nT4@070?nT4@8000002`3oY1400`2][Jd0ojHA
0?nV4@0>0?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01H0ojH@0P0000040?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?
0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00<0k9H>00D000000>bF3P3/UPh0k9H>000000070>bF3P80
000000<0fhX=0:f][@2][Jd00`3KRPd2000000H0fhX=00<0[Jf]0;Ue2`0000000`2iM@/01P000000
^GD;0;Ue2`2][Jd000000:f][@80000000<0R5H70:f][@2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][@`0o:0@0P000003
0?bP40030000002][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000@0ojHA202][JdH
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ005`3oYQ000`000000ojH@0?nV4002
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AL0o:0@00<0[Jf]
0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P040>bF3P040000003/UPh0k9H>000000L0k9H>0P00
00030=^:3@80[Jf]00<0fhX=0000000000001P3KRPd0102][Jd0^GD;0;Ue2`0000020;Ue2`060000
002iM@/0^GD;0:f][@000000R5H70P0000000`28EPL0[Jf]0;3PiP110;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2]
[Jd0o:0@0?bP400:0?bP408000000`3lX1000`000000oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA
00h0ojHA0P0000040:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01L0ojH@00<000000?nV403oYQ000P3oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh010000000k9H>0>bF3P0000070>bF3P8000001@3K
RPd00`2][Jd00000000000060=^:3@040:f][@2iM@/0^GD;00000080^GD;00H000000;Ue2`2iM@/0
[Jf]00000028EPL3000000030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V0P2][Jd209MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@@0kiP@00<0[Jf]0?bP403l
X1002P3lX102000000<0o:0@00<000000?nT4@3oY1400P3oY1400`000000oj@A0?nT4@0?0?nT4@03
0:f][@3oYQ40ojHA00L0ojHA1`2][Jd2000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@00P0o:0@1P2][Jd:0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh010000000k9H>0>bF3P0000070>bF3P8000001`3KRPd00`00
0000[Jf]0=^:3@040=^:3@040:f][@2iM@/0^GD;00000080^GD;00H000000;Ue2`2iM@/0[Jf]0000
0028EPL400000480/>3V0@3oool005T0/>3V0P2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1000`3_V1020:f][@H0kiP@00<0[Jf]0?bP403lX1002P3lX102000000<0o:0@00<0
00000?nT4@3oY1400P3oY1400`000000oj@A0?nT4@0?0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]
1`3oYQ42000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00h0o:0@1`2][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
0`3/UPh010000000k9H>0>bF3P0000070>bF3P8000000`3KRPd01P000000fhX=0=^:3@3KRPd00000
0=^:3@80[Jf]00@0fhX=0000003KRPd0[Jf]0P2iM@/02@000000^GD;0;Ue2`2iM@/000000;Ue2`2]
[Jd0000008QF1`0400000480/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>7
3P040:f][@3_V100kiP@0>nH4080[Jf]203_V1000`2][Jd0o:0@0?bP400:0?bP408000000`3lX100
0`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00h0oj@A1@2][Jd=0?nV4@8000001`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX106
0:f][A@0mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh010000000k9H>0>bF3P0000070>bF3P040000002]
[Jd000000=^:3@8000000`3KRPd020000000fhX=0=^:3@3KRPd0[Jf]0000003KRPd0[Jf]0P2iM@/0
2@000000^GD;0;Ue2`2iM@/000000;Ue2`2][Jd0000008QF1`0500000440/>3V0@3oool005P0/>3V
0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2P3_V1000`2][Jd0
o:0@0?bP400:0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00X0
oj@A102][Jd00`3oY140[Jf]0?nV4@0?0?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][A00
mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh010000000k9H>0>bF3P0000070>bF3P070000002][Jd00000
0=^:3@000000fhX=000000020=^:3@030000003KRPd0fhX=0080fhX=0P000000102][Jd0^GD;0;Ue
2`0000030;Ue2`040000002iM@/0^GD;00000080R5H7100000110;3PiP40oooo001H0;3PiP80[Jf]
0`2GH0/00`2][Jd0dhL>0=>73P060=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400:0?bP40800000
0`3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A00H0oj@A102][Jd50?nT4@030:f]
[@3oYQ40ojHA00h0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd;0?JL3`030:f]
[@3/UPh0k9H>00<0k9H>00@000000>bF3P00000000001@3/UPh3000000040:f][@000000fhX=0=^:
3@8000000P3KRPd00`000000fhX=0=^:3@020=^:3@8000000P2][Jd00`2iM@/000000;Ue2`020;Ue
2`040000002iM@/0^GD;00000080R5H7100000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P050=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400:0?bP408000000`3lX1000`2]
[Jd0oj@A0?nT4@020?nT4@030000003oY140oj@A0080oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA
00/0ojHA1@0000070?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>
00@0k9H>0`0000080>bF3P030:f][@3KRPd000000080fhX=00<000000=^:3@3KRPd00P0000030=^:
3@80000000@0[Jf]0;Ue2`2][Jd000000`2iM@/010000000^GD;0;Ue2`00000208QF1`@00000@@2`
h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@00X0o:0@0P0000030?bP40040:f][@3oY140oj@A0?nT4@800000102]
[Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l40:f][@80mY`?00<0
[Jf]0>bF3P3/UPh0103/UPh3000000T0k9H>00@0[Jf]0000000000000000103KRPd00`000000fhX=
0=^:3@020=^:3@060000002][Jd0^GD;0;Ue2`000000[Jf]0P2iM@/010000000^GD;0;Ue2`000002
08QF1`@00000@@2`h>H10?ooo`00E`2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>
00<0dhL>00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400:0?bP408000000`3lX100
102][Jd0oj@A0:f][@2][Jd200000140oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0B0?JL3`@0[Jf]1@3/UPh3000000T0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd01`000000fhX=0=^:
3@3KRPd000000=^:3@2][Jd00P2iM@/01@000000^GD;0:f][@2iM@/000000080^GD;00<0[Jf]0000
0028EPL01@0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]00<0Uf0;00@0[Jf]0=>73P3C
Q`h0dhL>0P2][Jd30=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020000
0080o:0@0`2][Jd20?nT4@8000004@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd20>bF3P<000002@3/UPh00`2][Jd0fhX=0=^:3@060=^:
3@060000003KRPd0fhX=0000003KRPd0[Jf]0P2iM@/02P000000^GD;0;Ue2`2][Jd000000;Ue2`11
JN40[Jf]00000028EPL500000400/>3V0@3oool005L0/>3V00<000000:f][@2][Jd00`2GH0/0102]
[Jd0dhL>0=>73P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX102
00000080[Jf]00<0o:0@0:f][@3oY1400P3oY14200000140oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd2000000X0k9H>00<0[Jf]
0=^:3@3KRPd01`3KRPd01@000000fhX=0000003KRPd0[Jf]0080^GD;00X000000;Ue2`2iM@/0^GD;
0000002][Jd0^GD;0:f][@000000R5H71@0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]
00<0Uf0;00<0[Jf]0=>73P2][Jd01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00T0o:0@00<0[Jf]0000000000000`3lX100102][Jd0oj@A0?nT4@3oY14200000140oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0P000000
0`2][Jd0k9H>0>bF3P070>bF3P030:f][@3KRPd0fhX=00P0fhX=00@000000=^:3@3KRPd0[Jf]0P2i
M@/01P000000^GD;0;Ue2`2iM@/000000;Ue2`80[Jf]00<0000008QF1`000000100000100;3PiP40
oooo001G0;3PiP030000002][Jd0[Jf]00<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1001`3lX1020:f][@030?bP40000000000000<0o:0@00@0[Jf]0?nT4@3oY140
oj@A0P00000A0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P040>bF3P80000000@0k9H>0:f][@2][Jd0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;008000000P2iM@/01P000000^GD;0;Ue2`2][Jd0000008QF1`D00000@02`
h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]0`3lX102000000<0o:0@00@0[Jf]
0?nT4@3oY140oj@A0P00000@0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P050>bF3P030000003/
UPh0k9H>0080k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P00
00020;Ue2`060000002iM@/0^GD;0:f][@000000R5H71@0000100;3PiP40oooo001G0;3PiP030000
002][Jd0Uf0;0080Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP403lX100
o:0@0`2][Jd60?bP408000000`3lX100102][Jd0000000000000000B0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f]
[@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh01@3/UPh00`000000k9H>0>bF3P040>bF3P<0[Jf]00<0k9H>0:f]
[@3KRPd03@3KRPd0102][Jd0^GD;0000000000020;Ue2`060000002iM@/0^GD;0:f][@000000R5H7
1@0000100;3PiP40oooo001G0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd70=>73P030:f][@3_
V100kiP@00`0kiP@00@0[Jf]0?bP402][Jd0[Jf]2@3lX102000000040?bP400000000000000001D0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00D0
k9H>00<000000>bF3P3/UPh01`3/UPh30:f][@d0fhX=00L0[Jf]0;Ue2`000000^GD;0000002iM@/0
00000080^GD;00<0[Jf]0000002][Jd01@0000100;3PiP40oooo001G0;3PiP070000002][Jd0Uf0;
09MP2`2][Jd0Uf0;0:f][@070=>73P030:f][@3_V100kiP@00/0kiP@0`2][Jd;0?bP40<000000P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303o
YQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P050>bF3P030000003/UPh0k9H>00P0k9H>00@0[Jf]0=^:3@2][Jd0[Jf]
2`3KRPd0102][Jd0^GD;0000002iM@/300000080^GD;00<0[Jf]0000002][Jd01@0000100;3PiP40
oooo001F0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f]
[@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP40090?bP408000001@3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V
2P2][JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=
0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`0000000P2iM@/01`000000^GD;0;Ue2`2iM@/0[Jf]
00000028EPL01@0000100;3PiP40oooo001F0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2]
[Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f]
[A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00<0fhX=0P2][Jd70=^:3@030:f][@2iM@/0000000H0^GD;00<0[Jf]00000028EPL01@0000100;3P
iP40oooo001F0;3PiP8000000P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_
V1001@3_V1020:f][@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00@0[Jf]0;Ue2`2i
M@/000001@2iM@/00`2][Jd0000008QF1`0500000400/>3V0@3oool005H0/>3V0P0000020:f][@<0
Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0
/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@070=^:3@80[Jf]0`3KRPd0102][Jd0^GD;0;Ue2`0000050;Ue2`80000000<0R5H70000
000000000`0000100;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00@0Uf0;00<0[Jf]0=>73P3C
Q`h01@3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]
0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd0
1@3KRPd0[Jf]0;Ue2`2iM@/0000000H0^GD;00<0000008QF1`28EPL0100000100;3PiP40oooo001F
0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f][@2]
[Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2]
[JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@80^GD;00<0
00000;Ue2`2iM@/0102iM@/00`2][Jd0R5H708QF1`0400000400/>3V0@3oool005H0/>3V00<00000
0:f][@2][Jd00`2GH0/00`2][Jd0dhL>0=>73P060=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd00`000000^GD;0;Ue2`040;Ue2`030:f][@28EPL0
000000@00000@02`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>
00D0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f]
[M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102]
[Jd0^GD;0;Ue2`0000060;Ue2`030:f][@28EPL0R5H700@00000@02`h>H10?ooo`00EP2`h>H00`00
0000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400<0>nH
40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`000000
[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0R5H71000000o0;3PiP40oooo001F0;3PiP030000002][Jd0
[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0
[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/
UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`000000^GD;0080[Jf]
0`2iM@/0102][Jd0R5H708QF1`28EPL4000003l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd0
0`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0
00000;Ue2`0000030;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H700@0[Jf]0000000000000000?`2`
h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`040:f][@3CQ`h0[Jf]0:f][@D0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0000000000040;Ue2`<0[Jf]0`28EPL0102][Jd00000
00000000000o0;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;0P2][Jd70=>73P030:f]
[@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]
00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3PiP030000
002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`000000[Jf]08QF1`0208QF1`030:f]
[@000000000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@P0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i
/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<000000:f][@28EPL00P28EPL00`2][Jd000000000000o0;3PiP40oooo001E
0;3PiP80000000@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0
[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102]
[Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`0300000028EPL0[Jf]0080R5H700<0[Jf]000000000000?`2`
h>H10?ooo`00E@2`h>H2000000060:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f]
[@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`0300000028EPL0[Jf]0080R5H7
00<0[Jf]000000000000?`2`h>H10?ooo`00E@2`h>H2000000030:f][@2GH0/0[Jf]0080Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0
000008QF1`28EPL0[Jf]08QF1`2][Jd2000003l0/>3V0@3oool005D0/>3V0P0000000`2][Jd0Uf0;
0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00
E@2`h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0kiP@
0P2][Jd00`11JN40[Jf]0;6[W@0:0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
2`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
1`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@03
0000002`h>H0/>3V03h0/>3V0@3oool005D0/>3V0P0000020:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?045Yh@11JN40/J^M0P2][Jd90;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_003
0:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080
[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80
[Jf]@02`h>H10?ooo`00E@2`h>H2000000030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@80Y9j?00@0@FWQ0:BNS`11JN40@FWQ0`2aZid20:f]
[@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00L0dhL>00P0[Jf]0>nH402][Jd0[Jf]0:BNS`11
JN40Y9j?045Yh@80Y9j?0P11JN450;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0
_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`040:f][@28EPL0R5H7
08QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>
00L0dhL>0P2][Jd01011JN40Y9j?0:BNS`2TWXl2045Yh@80Y9j?0P11JN470;6[W@80[Jf]0`2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[05
0:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0
102][Jd0_[Vh0:f][@2][Jd:0;ji^0060:f][@2d/;40];2a0;B`/@11JN40];2a0P2][Jd:0;Ue2`04
0:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0:BNS`2TWXl0@FWQ0`2TWXl2045Yh@80Y9j?1011JN470;6[
W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@`0_[Vh00D0[Jf]0;B`/@2d/;40];2a045Yh@03
0;B`/@80[Jf]202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<00000
0;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P040=>73P80[Jf]0`2TWXl01011JN40Y9j?0:BNS`2T
WXl2045Yh@80Y9j?0P11JN400`2aZid0@FWQ045Yh@080;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]
1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
2@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00D0[Jf]0;B`/@2d/;40];2a045Yh@040;B`/@03
045Yh@2][Jd0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP03
0000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h30:f][@<0Y9j?00@0@FWQ0:BNS`2T
WXl0Y9j?0P11JN40102TWXl0[Jf]045Yh@11JN420;6[W@80@FWQ202aZid00`2][Jd0^K:V0:f][@03
0:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0
102][Jd0];2a0;B`/@11JN440;B`/@04045Yh@2d/;40[Jf]0:f][@D0^GD;00@0[Jf]08QF1`28EPL0
R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h0
0P3CQ`h0102][Jd0@FWQ045Yh@2][Jd30:BNS`04045Yh@2TWXl0Y9j?0:BNS`80@FWQ00<0Y9j?045Y
h@11JN400`2aZid2045Yh@<0/J^M0`11JN420;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m
/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`
/@2d/;40@FWQ102d/;401011JN40[Jf]0:f][@11JN420:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00H0[Jf]0=>73P3CQ`h0dhL>
0:f][@2:QGD2045Yh@<0[Jf]0P2TWXl00`11JN40Y9j?0:BNS`02045Yh@030:BNS`11JN40@FWQ00@0
/J^M00<0@FWQ0;6[W@2aZid00`2aZid3045Yh@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0
`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`/@11JN440;B`/@07045Yh@2d/;40];2a
045Yh@2OVj00@FWQ0:f][@020;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`
h>H00`000000/>3V0:f][@0309MP2`040:f][@3CQ`h0[Jf]0:f][@80RXEe0P11JN40102][Jd0@FWQ
0:BNS`2][Jd20:BNS`03045Yh@2TWXl0@FWQ0080Y9j?0P11JN440;6[W@03045Yh@2aZid0/J^M00<0
/J^M00D0@FWQ0;6[W@2aZid0[Jf]045Yh@0:0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f]
[Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0<0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a
045Yh@80];2a0P2][Jd00`11JN40];2a0;B`/@03045Yh@0409nKX02][Jd0[Jf]0:f][@@0R5H700<0
[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`80[Jf]00<0RXEe
045Yh@2:QGD01@11JN420:BNS`80[Jf]00<0@FWQ0:BNS`11JN400P2TWXl2045Yh@@0/J^M00<0@FWQ
0;6[W@2aZid00`2aZid01@11JN40/J^M0;6[W@2][Jd0^K:V0080@FWQ302i/ZH30:f][A40_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0_02]
[Jd0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`/@11JN420:f][@80];2a
00<0@FWQ0;B`/@2d/;400P11JN4409nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0
?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`040:f][@2:QGD0RXEe045Yh@80RXEe
1011JN420:BNS`03045Yh@2TWXl0[Jf]0080@FWQ0P2TWXl2045Yh@@0/J^M00<0@FWQ0;6[W@2aZid0
0`2aZid01@11JN40/J^M0;6[W@2][Jd0^K:V00@0@FWQ00<0^K:V045Yh@2i/ZH0202i/ZH00`2][Jd0
_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33
_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a045Yh@@0];2a00@0@FWQ0;B`
/@2d/;40@FWQ1P2OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V0@3oool005H0/>3V00@0[Jf]
09MP2`2GH0/0Uf0;0P2][Jd00`11JN40RXEe045Yh@0408Z5M@80@FWQ0P2TWXl00`11JN40Y9j?0:BN
S`02045Yh@80Y9j?0P11JN440;6[W@80@FWQ102aZid01@11JN40/J^M0;6[W@2][Jd0^K:V0080@FWQ
102i/ZH2045Yh@L0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[00
4@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`0
0`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/00P33_K/00`11JN40`kfk0<>m^`090<>m^`030:f]
[@2n^KP0_[Vh00/0_[Vh0`2][Jd00`11JN40];2a0;B`/@020;B`/@04045Yh@2d/;40@FWQ045Yh@H0
Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP
2`80[Jf]00<0@FWQ08Z5M@11JN40102:QGD01@2][Jd0@FWQ0:BNS`2TWXl0@FWQ00<0Y9j?00D0@FWQ
0:f][@2][Jd00000045Yh@040;6[W@80@FWQ102aZid01@11JN40/J^M0;6[W@2][Jd0^K:V0080@FWQ
1@2i/ZH3045Yh@D0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[00
4@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd0
0`2][Jd=0<K0_0070:f][@33_K/0`kfk0<>m^`11JN40`kfk045Yh@0:0<>m^`030:f][@2n^KP0_[Vh
00X0_[Vh0P2][Jd30;B`/@05045Yh@2d/;40];2a0;B`/@11JN400P2d/;400`2][Jd0Wi^P09nKX005
09nKX0040:f][@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd3
045Yh@@0RXEe00D0[Jf]0:BNS`2TWXl0Y9j?045Yh@030:BNS`05045Yh@2TWXl0Y9j?0:f][@11JN40
102aZid2045Yh@@0/J^M00D0@FWQ0;6[W@2aZid0[Jf]0;VbYP02045Yh@D0^K:V00<0@FWQ0;VbYP2i
/ZH01@2i/ZH00`11JN40_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][Jd?0<K0_003045Yh@36`;`0[Jf]00<0
`kfk0P11JN4;0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@020;B`/@05
045Yh@2d/;40];2a0;B`/@11JN400P2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]00<0R5H70:f]
[@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@<0@FWQ0`2:QGD00`2]
[Jd0Y9j?0:BNS`020:BNS`05045Yh@2TWXl0Y9j?0:BNS`11JN400P2TWXl0102][Jd0@FWQ0:f][@2]
[Jd20;6[W@80@FWQ102aZid01@11JN40/J^M0;6[W@2][Jd0^K:V0080@FWQ1@2i/ZH00`11JN40^K:V
0;VbYP030;VbYP80@FWQ00<0[Jf]045Yh@2n]j`03`2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00<0<K0_080@FWQ
00<0a/2l045Yh@11JN401033_K/00`11JN40`kfk0<>m^`090<>m^`030:f][@2n^KP0_[Vh00H0_[Vh
0P2][Jd30;ji^0050:f][@2d/;40];2a0;B`/@11JN400`2d/;401011JN40];2a0;B`/@2][Jd709nK
X0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`040:f][@2:QGD0@FWQ
045Yh@<0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl00`11JN40Y9j?045Yh@030:BNS`040:f][@11JN40
/J^M0;6[W@80[Jf]0P11JN440;6[W@05045Yh@2aZid0/J^M0:f][@2i/ZH00P11JN450;VbYP03045Y
h@2i/ZH0^K:V0080^K:V0P11JN40102i/ZH0[Jf]0;jg[011JN4@0;jg[0030:f][@31^[00`KZ`00D0
[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_003
0:f][@36`;`0a/2l00T0a/2l00<0@FWQ0<K0_011JN401036`;`00`11JN40`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0050:f][@2d/;40];2a0;B`/@11JN400`2d/;401011
JN40];2a0;B`/@2][Jd609nKX080[Jf]00@0L6ii0:f][@2][Jd00000?`2`h>H10?ooo`00EP2`h>H2
0:f][@<0Hf1C0P2][Jd00`2:QGD0@FWQ08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00@0Y9j?00<0@FWQ
0:BNS`2TWXl00P2TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2][Jd0[Jf]00<0/J^M00D0@FWQ
0;6[W@2aZid0[Jf]0;VbYP02045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045Yh@050;VbYP2]
[Jd0_[N/0;jg[011JN401@2n]j`00`11JN40_[N/0;jg[0070;jg[0030:f][@31^[00`KZ`00D0`KZ`
1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`L0@FWQ3`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0_036`;`0
2@36`;`2045Yh@D0a/2l00<0@FWQ0<>m^`33_K/03P33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0
_[Vh00D0[Jf]0;B`/@2d/;40];2a045Yh@030;B`/@04045Yh@2d/;40];2a0:f][@D0Wi^P00<0[Jf]
09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2]
[Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]045Yh@11JN400`2aZid00`11
JN40/J^M0;6[W@030:f][@05045Yh@2aZid0/J^M0:f][@2i/ZH00P11JN450;VbYP03045Yh@2i/ZH0
^K:V0080^K:V0P11JN400`2][Jd0_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/0080_[N/1`11JN43
0;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k045Yh@l0b<6k1P2]
[JdA0<O1_0030:f][@36`;`0a/2l00@0@FWQ1@36`;`2045Yh@D0a/2l00<0@FWQ0<>m^`33_K/03P33
_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0050:f][@2d/;40];2a0;B`/@11JN400`2d/;401011JN40
];2a0;B`/@2][Jd409nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`08
0:BNS`04045Yh@2][Jd0@FWQ045Yh@80/J^M00<0@FWQ0;6[W@2aZid0102aZid01@11JN40[Jf]0;6[
W@2][Jd0^K:V0080@FWQ1@2i/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@030;VbYP2][Jd0_[N/00@0
_[N/00@0@FWQ0;jg[02n]j`0_[N/0P11JN440;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd04@31^[08
0:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0
b<6k045Yh@P0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00/0al6l0`11JN430<O1_0030:f][@36
`;`0@FWQ00@0a/2l00<0@FWQ0<K0_036`;`00P36`;`00`11JN40a/2l0<K0_0040<K0_003045Yh@33
_K/0`kfk00d0`kfk0`2][Jd<0;ji^0050:f][@2d/;40];2a0;B`/@11JN400`2d/;401011JN40];2a
0;B`/@2][Jd209nKX080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl3045Yh@80/J^M00<0@FWQ0;6[W@2aZid00`2aZid2045Yh@040;6[W@2][Jd0[Jf]0:f]
[@80@FWQ102i/ZH2045Yh@<0^K:V0P11JN400`2i/ZH0[Jf]0;jg[0080;jg[080@FWQ1@2n]j`01011
JN40_[N/0;jg[02][Jd20<6j/003045Yh@31^[00`KZ`00h0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;
0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0
b<6k045Yh@P0[Jf]2P38`K/00`2][Jd0al6l0<O1_0080<O1_0@0@FWQ1@37`K`00`2][Jd0@FWQ0<K0
_0050<K0_005045Yh@36`;`0a/2l0<K0_011JN401P36`;`00`11JN40`kfk0<>m^`020<>m^`03045Y
h@33_K/0`kfk00D0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0050:f][@2d/;40];2a0;B`/@11
JN400`2d/;401P11JN40];2a0;B`/@2][Jd0Wi^P0:f][@D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo
0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2]
[Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M0080@FWQ1P2aZid2045Yh@80/J^M00D0[Jf]0;Vb
YP11JN40@FWQ0:f][@030;VbYP80@FWQ0`2i/ZH2045Yh@030;VbYP2][Jd0_[N/00P0_[N/00<0@FWQ
0;jg[02n]j`01@2n]j`01`11JN40_[N/0:f][@31^[00@FWQ0<6j/011JN403`31^[000`2][Jd0`kfc
0<>m/`0>0<>m/`/0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`P0[Jf]00<0@FWQ0<S1^`38`K/0
4038`K/00`2][Jd0al6l0<O1_0030<O1_0<0@FWQ1037`K`2045Yh@D0al6l0P11JN4@0<K0_080@FWQ
1033_K/00`11JN40`kfk0<>m^`020<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0050:f]
[@2d/;40];2a0;B`/@11JN400P2d/;401P11JN40];2a0;B`/@2d/;4000000:f][@H0Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5
M@2:QGD00`2:QGD20:f][@/0Y9j?00<0[Jf]0;6[W@2aZid0202aZid2045Yh@80/J^M00D0[Jf]0;Vb
YP11JN40@FWQ0;VbYP030:f][@80@FWQ0`2i/ZH2045Yh@030;VbYP2][Jd0_[N/00P0_[N/00<0@FWQ
0;jg[02n]j`01@2n]j`00`11JN40_[N/0:f][@020<6j/003045Yh@31^[00`KZ`00h0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`03
0<S1^``0[Jf]1@38`K/0102][Jd0b<6k0<S1^`11JN4@0<S1^`<0@FWQ0P37`K`4045Yh@H0al6l0P11
JN450<O1_003045Yh@36`;`0a/2l00h0a/2l0P11JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33
_K/0`kfk0080[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0050:f][@2d/;40];2a0;B`/@11JN40
0P2d/;401@11JN40];2a0;B`/@2d/;40[Jf]00L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00P0/J^M00H0@FWQ0;6[W@11JN40/J^M0:f][@2i/ZH2
045Yh@@0^K:V0P11JN420:f][@050;VbYP11JN40@FWQ0;VbYP2][Jd0402n]j`00`11JN40_[N/0:f]
[@0D0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/0102][Jd0b<6k0<S1
^`11JN4=0<S1^`@0@FWQ00<0b<6k0:f][@37`K`01037`K`00`11JN40al6l0<O1_0040<O1_080@FWQ
1@37`K`00`11JN40a/2l0<K0_00<0<K0_0<0@FWQ00<0a/2l0:f][@33_K/00`33_K/00`11JN40[Jf]
0:f][@090<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00L0[Jf]0;B`/@2d/;40];2a045Yh@2d/;40@FWQ
0080];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2]
[Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0/J^M00P0/J^M00D0@FWQ
0;6[W@11JN40/J^M0:f][@02045Yh@D0^K:V0P11JN420;VbYP050:f][@11JN40@FWQ0;VbYP2][Jd0
402n]j`00`11JN40_[N/0:f][@0D0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f]
[@38`K/0b<6k045Yh@@0b<6k00<0@FWQ0<S1^`38`K/02038`K/2045Yh@030<S1^`2][Jd0al6l00@0
al6l00<0@FWQ0<O1_037`K`01037`K`2045Yh@@0al6l0P11JN4=0<K0_003045Yh@36`;`0@FWQ0080
a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd00`11JN40`kfk0<>m^`090<>m^`030:f][@2n^KP0_[Vh00/0
_[Vh00T0[Jf]0;B`/@2d/;40];2a045Yh@2d/;40@FWQ0;B`/@2][Jd00P2d/;400`2][Jd0Wi^P09nK
X00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=P
D`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd70:BNS`030:f][@2aZid0/J^M00P0/J^M
00D0@FWQ0;6[W@2aZid0@FWQ0:f][@02045Yh@D0^K:V0P11JN440;VbYP04045Yh@2][Jd0[Jf]0:f]
[@d0_[N/0`11JN400`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k045Yh@<0b<6k00@0@FWQ
0<S1^`11JN40@FWQ2038`K/2045Yh@030<S1^`2][Jd0al6l00@0al6l00<0@FWQ0<O1_037`K`01037
`K`2045Yh@@0al6l0P11JN4<0<K0_004045Yh@36`;`0@FWQ0<K0_0<0[Jf]00D0@FWQ0<>m^`33_K/0
`kfk045Yh@0;0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P11JN420:f]
[@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool0
05L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0
Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0202aZid01011JN40/J^M0;6[W@2aZid2045Yh@H0^K:V0P11
JN440;VbYP04045Yh@2i/ZH0[Jf]0;jg[0<0[Jf]00<0@FWQ0;jg[02n]j`01@2n]j`4045Yh@80_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0@FWQ00<0@FWQ
4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`0:0<S1^`@0@FWQ1038`K/2045Yh@050:f][@38`K/0b<6k045Yh@38
`K/00P11JN430<S1^`80@FWQ1`38`K/2045Yh@030<S1^`2][Jd0al6l00@0al6l00<0@FWQ0<O1_037
`K`01037`K`2045Yh@@0al6l0P11JN4;0<K0_0030:f][@11JN40@FWQ0080[Jf]0P36`;`00`2][Jd0
@FWQ0<>m^`020<>m^`03045Yh@33_K/0`kfk00T0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0
];2a0;B`/@11JN420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je0
0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl2
0:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0202aZid01@11JN40/J^M0;6[W@2aZid0[Jf]00L0^K:V0P11
JN440;VbYP03045Yh@2i/ZH0[Jf]00<0_[N/0P11JN440:f][@030;jg[011JN40@FWQ0080@FWQ102n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00P35
_[D7045Yh@L0aKje0`11JN400`35_[D0[Jf]0<Jo]`0F0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX04`37`KX3045Yh@/0b<6k00<0@FWQ0<S1^`38`K/00P38`K/01011JN40b<6k0<S1
^`11JN420<S1^`030:f][@38`K/0b<6k0080@FWQ1P38`K/2045Yh@H0b<6k0P11JN400`38`K/0[Jf]
0<O1_0040<O1_003045Yh@37`K`0al6l00@0al6l0P11JN440<O1_080@FWQ1P36`;`00`11JN40[Jf]
0:f][@020:f][@030<K0_011JN40a/2l00@0a/2l0P11JN430<>m^`03045Yh@33_K/0`kfk00T0`kfk
00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0
Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@03
0:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M00P0/J^M00@0@FWQ0;6[W@2a
Zid0[Jf]1P2i/ZH4045Yh@D0^K:V00<0@FWQ0:f][@2n]j`00`2n]j`00`11JN40_[N/0;jg[0020;jg
[004045Yh@2][Jd0@FWQ0:f][@D0_[N/00D0[Jf]0<6j/031^[00`KZ`045Yh@0@0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00P35_[D00`11JN40aKje0<Fn]@030<Fn]@<0@FWQ1`35
_[D5045Yh@`0a[ng1011JN450<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX00`37
`KX4045Yh@80al6j0P11JN440<O1^P@0@FWQ0P37`KX00`2][Jd0b<6k0<S1^`080<S1^`80@FWQ1@38
`K/3045Yh@80b<6k00<0[Jf]0<S1^`38`K/00P11JN460<S1^`80@FWQ1P38`K/2045Yh@030<S1^`2]
[Jd0al6l00@0al6l0P11JN450<O1_080@FWQ1037`K`2045Yh@80a/2l102][Jd2045Yh@@0a/2l00<0
@FWQ0<K0_036`;`00`36`;`2045Yh@<0`kfk0P11JN4:0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2]
[Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H0
0`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0P2][Jd00`000000/J^M0;6[W@08
0;6[W@04045Yh@2aZid0/J^M0:f][@P0^K:V0P11JN450;VbYP80@FWQ102n]j`00`11JN40_[N/0;jg
[0020;jg[080@FWQ0P2n]j`40:f][@030;jg[02][Jd0`KZ`0080`KZ`00<0@FWQ0<6j/031^[003P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0080aKje00<0@FWQ0<Fn]@35_[D01035
_[D2045Yh@L0aKje0P11JN400`2][Jd0a[ng0<Jo]`0:0<Jo]`<0@FWQ0`36_kL00`11JN40a[ng0<Jo
]`020<Jo]`80@FWQ1P37`KP00`11JN40al6h0<O1^0040<O1^003045Yh@37`KP0al6h00D0al6h00@0
[Jf]0<O1^P37`KX0al6j0P11JN440<O1^P@0@FWQ1P37`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/0
1`38`K/2045Yh@L0b<6k0P11JN420<S1^`040:f][@38`K/0b<6k045Yh@L0b<6k0P11JN460<S1^`80
@FWQ00<0b<6k0:f][@37`K`01037`K`2045Yh@H0al6l0P11JN420<O1_0030:f][@11JN40@FWQ0080
[Jf]1036`;`2045Yh@@0a/2l00<0@FWQ0<K0_036`;`00P36`;`3045Yh@<0`kfk0P11JN4:0<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2]
[Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@T0/J^M
00@0@FWQ0;6[W@2aZid0[Jf]402i/ZH01@11JN40_[N/0;jg[02n]j`0@FWQ00D0_[N/00<0@FWQ0;jg
[02n]j`0102n]j`00`11JN40[Jf]0:f][@030:f][@03045Yh@31^[00`KZ`00h0`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@020<Fn]@03045Yh@35_[D0aKje00D0aKje0P11JN460<Fn
]@80@FWQ00<0[Jf]0<Jo]`36_kL02P36_kL2045Yh@D0a[ng00D0@FWQ0<Jo]`11JN40@FWQ0:f][@07
0<O1^003045Yh@37`KP0al6h00@0al6h00<0@FWQ0<O1^037`KP01@37`KP00`2][Jd0al6j0<O1^P02
045Yh@H0al6j0`11JN460<O1^P80@FWQ0P37`KX00`2][Jd0b<6k0<S1^`070<S1^`80@FWQ1`38`K/2
045Yh@80b<6k00<0[Jf]0<S1^`38`K/00P11JN470<S1^`80@FWQ1@38`K/2045Yh@030<S1^`2][Jd0
al6l00@0al6l0P11JN450<O1_0030:f][@11JN40@FWQ0080[Jf]0P37`K`00`2][Jd0@FWQ0<K0_004
0<K0_080@FWQ1036`;`02011JN40a/2l0<K0_036`;`0@FWQ0<K0_02][Jd0@FWQ0`33_K/2045Yh@X0
`kfk00<0[Jf]0;ji^02n^KP0202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02O
Vj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0[Jf]0;6[W@2][Jd00P2][Jd60;6[W@04045Yh@2aZid0/J^M0:f][A00^K:V00<0[Jf]045Yh@11
JN400P11JN450;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0;jg[02][Jd00`31^[000`11JN40
[Jf]0:f][@040:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@020<Fn]@03
045Yh@35_[D0aKje00D0aKje0P11JN460<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL02@36_kL2045Yh@H0
a[ng0`11JN400`36_kL0[Jf]0<O1^0060<O1^003045Yh@37`KP0al6h00<0al6h0P11JN470<O1^003
0:f][@37`KX0al6j0080@FWQ1`37`KX2045Yh@H0al6j0P11JN420<O1^P030:f][@38`K/0b<6k00L0
b<6k0P11JN470<S1^`80@FWQ0P38`K/00`2][Jd0b<6k0<S1^`02045Yh@L0b<6k0P11JN450<S1^`80
@FWQ00<0b<6k0:f][@37`K`01037`K`2045Yh@D0[Jf]00<0al6l045Yh@11JN401037`K`2045Yh@D0
a/2l00<0@FWQ0<K0_036`;`00`36`;`5045Yh@030<K0_02][Jd0`kfk00<0`kfk0P11JN4:0<>m^`03
0:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02O
Vj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?
0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd20;6[W@03045Yh@2aZid0@FWQ0080/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[003045Yh@2n]j`0_[N/00@0_[N/
00<0@FWQ0;jg[02][Jd00`31^[000`11JN40`KZ`0<6j/0040<6j/0L0[Jf]0`31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje0080aKje00<0@FWQ0<Fn]@35_[D01P35_[D2045Yh@D0aKje
0P11JN400`2][Jd0a[ng0<Jo]`090<Jo]`80@FWQ1`36_kL2045Yh@030<Jo]`2][Jd0al6h00D0al6h
0`11JN440<O1^0<0@FWQ1`37`KP00`2][Jd0@FWQ045Yh@080<O1^P80@FWQ1P37`KX2045Yh@80al6j
00<0[Jf]0<S1^`38`K/01`38`K/2045Yh@L0b<6k0P11JN420<S1^`030:f][@38`K/0b<6k0080@FWQ
1`38`K/2045Yh@D0b<6k0P11JN401038`K/0[Jf]0<O1_037`K`30:f][@80@FWQ1P37`K`2045Yh@@0
al6l0P11JN450<K0_003045Yh@36`;`0a/2l00T0a/2l00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@X0
`kfk00<0[Jf]0;ji^02n^KP00`2n^KP30:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0
Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0
102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M0`2][Jd2045Yh@80/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0080;jg[003045Yh@2n]j`0_[N/0080_[N/
0P11JN400`2n]j`0[Jf]0<6j/0020<6j/003045Yh@31^[00`KZ`00/0`KZ`1`2][JdB0<>m/`030:f]
[@35_[D0aKje0080aKje00<0@FWQ0<Fn]@35_[D01P35_[D2045Yh@D0aKje0P11JN400`2][Jd0a[ng
0<Jo]`090<Jo]`80@FWQ1`36_kL2045Yh@030<Jo]`2][Jd0al6h00D0al6h0`11JN440<O1^0<0@FWQ
1`37`KP00`2][Jd0@FWQ0<O1^P080<O1^P80@FWQ1P37`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/0
1`38`K/2045Yh@L0b<6k0P11JN420<S1^`030:f][@38`K/0b<6k0080@FWQ1`38`K/2045Yh@D0b<6k
0P11JN440:f][@<0al6l0P11JN460<O1_080@FWQ1037`K`00`2][Jd0@FWQ045Yh@030<K0_003045Y
h@36`;`0a/2l00/0a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11JN4:0<>m^`040:f][@2n^KP0_[Vh0;ji
^080[Jf]202n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3P
iP2`h>H0@P2`h>H10?ooo`00G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid01`2aZid30:f][@030;6[W@2][Jd0^K:V00L0^K:V00<0@FWQ0;VbYP2i
/ZH01@2i/ZH00`2][Jd0_[N/0;jg[0090;jg[0@0@FWQ00@0_[N/045Yh@2n]j`0[Jf]0`31^[000`11
JN40`KZ`0<6j/00>0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@02
0<Fn]@03045Yh@35_[D0aKje00H0aKje0P11JN450<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL02@36_kL2
045Yh@L0a[ng0P11JN400`36_kL0[Jf]0<O1^0050<O1^0<0@FWQ1037`KP00`11JN40al6h045Yh@07
0<O1^0030:f][@11JN40al6j00P0al6j0P11JN460<O1^P80@FWQ0P37`KX00`2][Jd0b<6k0<S1^`08
0<S1^`80@FWQ1P38`K/2045Yh@80b<6k00<0[Jf]0<S1^`38`K/00P11JN470<S1^`80@FWQ1@2][Jd2
045Yh@030<S1^`2][Jd0al6l00@0al6l0P11JN460<O1_080@FWQ1037`K`00`2][Jd0a/2l045Yh@04
045Yh@d0a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11JN4:0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh
00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V
0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2a
Zid0/J^M00X0/J^M0`2][Jd60;VbYP80@FWQ1`2i/ZH00`2][Jd0_[N/0;jg[00>0;jg[003045Yh@2n
]j`0[Jf]0080`KZ`0P11JN4@0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35
_[D0aKje0080aKje00<0@FWQ0<Fn]@35_[D01`35_[D2045Yh@@0aKje0P11JN400`2][Jd0a[ng0<Jo
]`090<Jo]`80@FWQ1`36_kL2045Yh@030<Jo]`2][Jd0al6h00D0al6h00<0@FWQ0<O1^011JN400`37
`KP2045Yh@030<O1^011JN40al6h00H0al6h00<0[Jf]045Yh@37`KX02037`KX2045Yh@H0al6j0P11
JN420<O1^P030:f][@38`K/0b<6k00P0b<6k1@11JN430<S1^`80@FWQ0P38`K/00`2][Jd0b<6k0<S1
^`02045Yh@H0[Jf]0P11JN460<S1^`80@FWQ00<0b<6k0:f][@37`K`01037`K`00`11JN40al6l0<O1
_0050<O1_080@FWQ1037`K`00`2][Jd0a/2l0<K0_00A0<K0_0040:f][@33_K/0`kfk0<>m^`80@FWQ
2@33_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V
0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2a
Zid00`2][Jd0^K:V0:f][@030:f][@80^K:V00<0@FWQ0;VbYP11JN401P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0080@FWQ4031^[000`2][Jd0`kfc0<>m/`0@0<>m/`P0[Jf]00<0
@FWQ0<Fn]@35_[D01`35_[D2045Yh@@0aKje0P11JN400`2][Jd0a[ng0<Jo]`0:0<Jo]`80@FWQ1P36
_kL2045Yh@030<Jo]`2][Jd0al6h00D0al6h00<0@FWQ0<O1^011JN400`37`KP2045Yh@030<O1^011
JN40al6h00H0al6h0P11JN420<O1^P0300000037`KX0al6j00@0al6j0P11JN460<O1^P80@FWQ0P37
`KX00`2][Jd0b<6k0<S1^`0=0<S1^`D0@FWQ1@2][Jd2045Yh@H0b<6k0P11JN470<S1^`80@FWQ00<0
[Jf]0<O1_037`K`00P37`K`2045Yh@L0al6l0P11JN440<O1_0030:f][@36`;`0a/2l0140a/2l00@0
[Jf]0<>m^`33_K/0`kfk0P11JN460<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a
0;B`/@090;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2T
WXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd00`11JN40^K:V0;Vb
YP050;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[000P11JN4@0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00P35_[D00`11JN40[Jf]0:f][@070:f][@80@FWQ00@0
[Jf]0<Fn]@35_[D0aKje0P11JN400`2][Jd0a[ng0<Jo]`0<0<Jo]`80@FWQ1036_kL2045Yh@030<Jo
]`2][Jd0al6h00@0al6h0P11JN420<O1^003045Yh@37`KP0al6h0080@FWQ0P37`KP00`11JN40al6h
0<O1^0040<O1^080@FWQ1`37`KX6045Yh@@0al6j0P11JN420<O1^P030:f][@38`K/0b<6k00<0b<6k
302][Jd00`38`K/0@FWQ045Yh@020<S1^`030:f][@38`K/0b<6k0080@FWQ1P38`K/2045Yh@L0b<6k
0`11JN440<O1_003045Yh@37`K`0al6l00@0al6l0P11JN470<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/00P33_K/01011JN40`kfk0<>m^`33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`0080@FWQ4031^[000`2][Jd0`kfc0<>m/`0C0<>m/`040:f]
[@35_[D0aKje0<Fn]@80@FWQ2@35_[D2045Yh@040<Fn]@2][Jd0[Jf]0:f][@80@FWQ302][Jd50<Jo
]`80@FWQ0P36_kL2045Yh@030<Jo]`2][Jd0al6h00@0al6h0P11JN420<O1^004045Yh@37`KP0al6h
045Yh@<0al6h00<0@FWQ0<O1^037`KP01037`KP2045Yh@X0al6j1`2][Jd2045Yh@P0[Jf]3@38`K/0
1@11JN40b<6k0<S1^`38`K/0[Jf]0080b<6k0P11JN450<S1^`80@FWQ2038`K/2045Yh@030:f][@11
JN40@FWQ0080@FWQ4037`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102]
[Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3P
iP180;3PiP40oooo001R0;3PiP030:f][@2TWXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/002
045YhA00`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0102][Jd0aKje0<Fn]@35_[D2045Yh@T0aKje0P11
JN440<Fn]@<0@FWQ2`36_kL70:f][@@0@FWQ1`2][Jd2045Yh@80[Jf]00@0@FWQ0:f][@11JN40@FWQ
0`2][Jd00`11JN40[Jf]0:f][@040:f][@80@FWQ2P2][Jd70<O1^P<0@FWQ00<0al6j0:f][@38`K/0
2@38`K/2045Yh@H0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@020<S1^`<0@FWQ1038`K/2045Yh@P0
b<6k0P11JN400`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2]
[Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0
/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[000P11JN4@0<6j/0030:f][@33_K<0`kfc01<0`kfc
00@0[Jf]0<Fn]@35_[D0aKje0P11JN490<Fn]@80@FWQ1035_[D3045Yh@D0a[ng00<0@FWQ0<Jo]`36
_kL03036_kL2045Yh@030<Jo]`2][Jd0al6h00@0al6h0P11JN420<O1^004045Yh@37`KP0@FWQ045Y
h@<0al6h00<0@FWQ0<O1^037`KP01037`KP2045YhA40al6j0`11JN400`37`KX0[Jf]0<S1^`020<S1
^`03045Yh@38`K/0b<6k00@0b<6k0P11JN450<S1^`03045Yh@38`K/0b<6k0080b<6k00<0[Jf]0<S1
^`38`K/00`11JN420<S1^`80@FWQ2P38`K/2045Yh@030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`03P36`;`40:f][@h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`
/@030:f][@2`h>H0/>3V04/0/>3V0@3oool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031
^[000P11JN4@0<6j/0030:f][@33_K<0`kfc01<0`kfc00@0[Jf]0<Fn]@35_[D0aKje0P11JN490<Fn
]@80@FWQ1035_[D2045Yh@030:f][@11JN40a[ng0080a[ng0P11JN460<Jo]`80@FWQ1P36_kL01011
JN40a[ng0<Jo]`2][Jd50<O1^006045Yh@37`KP0al6h0<O1^011JN40al6h0P11JN430<O1^003045Y
h@37`KP0al6h00@0al6h0P11JN4A0<O1^P80@FWQ00<0al6j045Yh@2][Jd00P38`K/00`11JN40b<6k
045Yh@060<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0@FWQ
045Yh@02045Yh@030<S1^`11JN40@FWQ00`0b<6k0P11JN400`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00T0a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0
302n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?00<0
[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102]
[Jd90;jg[0030:f][@31^[00`KZ`0080@FWQ4031^[000`2][Jd0`kfc0<>m/`0C0<>m/`040:f][@35
_[D0aKje0<Fn]@80@FWQ2@35_[D2045Yh@@0aKje0P11JN400`2][Jd0a[ng045Yh@020<Jo]`80@FWQ
1P36_kL2045Yh@H0a[ng00@0@FWQ0<Jo]`36_kL0[Jf]1037`KP2045Yh@@0al6h0P11JN450<O1^003
045Yh@37`KP0al6h00<0al6h0P11JN4A0<O1^P80@FWQ0P37`KX01011JN40b<6k0<S1^`38`K/2045Y
h@L0b<6k1@11JN450<S1^`030:f][@38`K/0b<6k0140b<6k0P11JN400`2][Jd0al6l0<O1_00;0<O1
_003045Yh@37`K`0al6l00@0al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m
^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H1
0?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0080@FWQ4031^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`040:f][@35_[D0aKje0<Fn]@80@FWQ2@35_[D2045Yh@80aKje1011JN40
0`2][Jd0a[ng045Yh@030<Jo]`03045Yh@36_kL0a[ng00D0a[ng00<0@FWQ0<Jo]`36_kL00`36_kL0
1@11JN40a[ng0<Jo]`36_kL0[Jf]00@0al6h0P11JN440<O1^080@FWQ1@37`KP00`11JN40al6h0<O1
^0030<O1^080@FWQ4@37`KX2045Yh@80al6j00<0[Jf]045Yh@11JN400P11JN4B0<S1^`030:f][@38
`K/0b<6k0140b<6k0P11JN400`2][Jd0al6l0<O1_00:0<O1_003045Yh@37`K`0@FWQ00D0al6l00<0
[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/0020<6j/003045Yh@31
^[00`KZ`00h0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0102][Jd0aKje0<Fn]@35_[D2045Yh@P0aKje
0P11JN470<Fn]@030:f][@36_kL0a[ng00@0@FWQ2036_kL5045Yh@@0a[ng00<0[Jf]0<O1^011JN40
1P11JN420<O1^080@FWQ0P37`KP6045Yh@<0al6h0P11JN4?0<O1^P80@FWQ1037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k0140b<6k0P11JN400`2][Jd0al6l0<O1_00;0<O1_003045Y
h@37`K`0al6l0080al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
2`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`03`2n]j`50:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0102][Jd0aKje0<Fn
]@35_[D2045Yh@P0aKje0P11JN470<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0@FWQ0<O1^P090<O1^P03045Yh@37`KX0al6j00P0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0A0<S1^`80@FWQ00<0[Jf]0<O1_037`K`02`37`K`50:f][@80al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh
0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc
00@0[Jf]0<Fn]@35_[D0aKje0P11JN470<Fn]@80@FWQ2035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]045Yh@37`KX02@37`KX00`11JN40al6j0<O1^P080<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04@38`K/2045Yh@030:f][@37`K`0al6l00D0
al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f]
[@33_K<0`kfc01<0`kfc00@0[Jf]0<Fn]@35_[D0aKje0P11JN470<Fn]@80@FWQ2035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]045Yh@37`KX02037`KX2045Yh@X0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0?0<S1^`@0@FWQ00<0[Jf]0<O1_037
`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`040:f]
[@35_[D0aKje0<Fn]@80@FWQ1P35_[D2045Yh@T0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@11JN40@FWQ00P0al6j0P11JN4:0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]
0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00@0[Jf]0<Fn]@35_[D0aKje0P11JN460<Fn
]@03045Yh@35_[D0aKje00P0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@11JN40@FWQ00P0al6j0P11JN4:0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80
[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@11JN402@11JN4;0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0102][Jd0al6j045Yh@11JN460<O1
^P<0@FWQ2P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/3
0:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00P11JN440<O1^P80@FWQ00<0al6j045Y
h@37`KX02@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0
/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P020<O1^P@0@FWQ0`37`KX00`11JN40
al6j0<O1^P080<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0
`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]
3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]
K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0A0<O1^P0400000037`KX0al6j0:f][AH0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00L0a/2l102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0
[Jf]OP2`h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo
002N0;3PiPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2]
[Jf60;3PiP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l00P0al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`040:f][@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3P
iP40oooo002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0
/>3V0@3oool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo
003A0;3PiP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51956 .34087 m
.52287 .33862 L
s
.52287 .33862 m
.52784 .33861 L
s
.5179 .34086 m
.52287 .33862 L
s
.52784 .33861 m
.53115 .34084 L
s
.53942 .3385 m
.54108 .33847 L
s
.53612 .34079 m
.53942 .3385 L
s
.53777 .34077 m
.53942 .3385 L
s
0 0 0 r
.58999 .33189 m
.59024 .33211 L
s
.59078 .33136 m
.59189 .33201 L
s
.255 .412 .882 r
.5179 .34537 m
.51956 .34087 L
s
.51624 .34536 m
.5179 .34086 L
s
.53115 .34084 m
.53447 .34532 L
s
.53447 .34532 m
.53612 .34079 L
s
.53612 .3453 m
.53777 .34077 L
s
.4832 .33794 m
.49474 .33828 L
s
.51789 .34988 m
.5179 .34537 L
s
.51624 .34988 m
.51624 .34536 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51789 .34988 m
.51955 .35441 L
s
.51624 .34988 m
.51789 .3544 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51955 .35441 m
.52287 .35667 L
s
.51789 .3544 m
.52287 .35667 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48966 .36982 m
.48979 .33815 L
s
.48801 .36977 m
.48814 .3381 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46514 .33717 m
.47004 .33966 L
s
.47004 .33966 m
.47329 .34432 L
s
.46514 .33717 m
.4684 .33959 L
s
.44884 .33622 m
.46514 .33717 L
s
.52287 .35667 m
.53283 .35889 L
s
.4684 .33959 m
.47165 .34425 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53447 .34532 m
.5345 .36567 L
s
.53612 .3453 m
.53615 .36112 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55594 .33814 m
.56269 .3696 L
s
.54945 .36997 m
.55594 .33814 L
s
.56269 .3696 m
.56912 .33768 L
s
.5511 .36993 m
.55597 .3449 L
s
.56434 .36955 m
.56915 .34445 L
s
.47329 .34432 m
.47491 .34891 L
s
.47165 .34425 m
.47326 .34884 L
s
.53283 .35889 m
.53449 .36114 L
s
.47491 .34891 m
.47652 .35577 L
s
.5345 .36567 m
.53615 .36112 L
s
.48972 .35621 m
.49135 .36305 L
s
.47326 .34884 m
.47487 .3557 L
s
.45495 .38432 m
.45534 .33663 L
s
.51789 .36345 m
.51955 .36346 L
s
.51955 .36573 m
.51955 .36346 L
s
.51788 .36572 m
.51789 .36345 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50128 .36554 m
.50295 .3633 L
s
.50295 .3633 m
.5046 .36559 L
s
.51788 .36572 m
.51955 .36799 L
s
.53284 .36796 m
.5345 .36567 L
s
.50459 .36786 m
.5046 .36559 L
s
.59366 .33866 m
.59851 .33609 L
s
.59045 .34339 m
.59366 .33866 L
s
.51955 .36799 m
.52287 .37027 L
s
.47645 .36711 m
.47652 .35577 L
s
.50128 .36554 m
.50293 .36784 L
s
.52952 .37025 m
.53284 .36796 L
s
.49135 .36305 m
.49464 .36767 L
s
.4748 .36704 m
.47487 .3557 L
s
.59529 .33856 m
.59851 .33609 L
s
.59207 .34329 m
.59529 .33856 L
s
0 0 0 r
.57916 .36868 m
.58062 .37142 L
s
.255 .412 .882 r
.59851 .33609 m
.60176 .33586 L
s
.50293 .37011 m
.50459 .36786 L
s
.58885 .34801 m
.59045 .34339 L
s
.52287 .37027 m
.52952 .37025 L
s
.59048 .34791 m
.59207 .34329 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59381 .36422 m
.59476 .35824 L
s
.255 .412 .882 r
.49464 .36767 m
.49795 .37001 L
s
.49795 .37001 m
.50293 .37011 L
s
.60176 .33586 m
.60663 .33777 L
s
.54447 .37007 m
.55607 .36981 L
s
0 0 0 r
.59546 .36412 m
.59659 .35702 L
s
.255 .412 .882 r
.58727 .3549 m
.58885 .34801 L
s
.58891 .35481 m
.59048 .34791 L
s
.48304 .36962 m
.48966 .36982 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47476 .37386 m
.47645 .36711 L
s
.47311 .3738 m
.4748 .36704 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58891 .35481 m
.589 .36616 L
s
.58727 .3549 m
.58736 .36625 L
s
.56912 .33768 m
.57589 .36909 L
s
0 0 0 r
.55735 .3918 m
.55749 .38826 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60983 .33526 m
.61002 .3534 L
s
.61144 .33513 m
.61164 .35328 L
s
.60663 .33777 m
.6099 .34205 L
s
.57095 .3693 m
.58082 .36886 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47309 .37835 m
.47476 .37386 L
s
.47144 .37828 m
.47311 .3738 L
s
.58736 .36625 m
.58905 .37299 L
s
.62106 .33432 m
.63219 .33327 L
s
.589 .36616 m
.59069 .3729 L
s
.46976 .38277 m
.47309 .37835 L
s
.46811 .3827 m
.47144 .37828 L
s
.60517 .35376 m
.61646 .35289 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58905 .37299 m
.59073 .37746 L
s
.4648 .38483 m
.46976 .38277 L
s
.59069 .3729 m
.59237 .37736 L
s
.4648 .38483 m
.46811 .3827 L
s
0 0 0 r
.5806 .39747 m
.58247 .39739 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59073 .37746 m
.59404 .38183 L
s
0 0 0 r
.61622 .37243 m
.61687 .37238 L
s
.255 .412 .882 r
.59237 .37736 m
.59567 .38174 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4484 .38394 m
.4648 .38483 L
s
.45331 .38423 m
.45371 .33653 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59404 .38183 m
.59896 .38382 L
s
.62743 .33373 m
.62784 .3656 L
s
.62584 .33388 m
.62624 .36574 L
s
.59567 .38174 m
.59896 .38382 L
s
.61181 .36922 m
.61196 .38293 L
s
.61027 .37619 m
.61181 .36922 L
s
.62766 .35191 m
.62935 .3586 L
s
.59896 .38382 m
.60222 .38361 L
s
.60222 .38361 m
.60707 .38099 L
s
.60707 .38099 m
.61027 .37619 L
s
.61027 .37619 m
.61196 .38293 L
s
.62144 .36616 m
.62784 .3656 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62935 .3586 m
.63259 .36286 L
s
0 0 0 r
.64561 .35338 m
.64407 .35681 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63259 .36286 m
.63579 .36484 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65416 .33309 m
.65875 .33023 L
s
.65268 .33784 m
.65416 .33309 L
s
.65268 .33784 m
.65275 .3424 L
s
.6557 .3329 m
.65875 .33023 L
s
.65423 .33765 m
.6557 .3329 L
s
.63889 .35995 m
.64044 .3575 L
s
.64044 .3575 m
.64205 .35962 L
s
.63889 .35995 m
.6405 .36207 L
s
.63579 .36484 m
.64054 .36436 L
s
.65423 .33765 m
.6543 .34221 L
s
.65875 .33023 m
.66336 .32962 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65275 .3424 m
.65438 .34678 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64205 .35962 m
.64208 .36191 L
s
.6543 .34221 m
.65593 .34659 L
s
.64054 .36436 m
.64208 .36191 L
s
.66336 .32962 m
.66646 .33149 L
s
.65438 .34678 m
.65906 .34849 L
s
.65593 .34659 m
.65906 .34849 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66646 .33149 m
.66959 .33564 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65906 .34849 m
.66832 .34958 L
s
.65453 .35593 m
.65608 .35574 L
s
.65453 .35593 m
.65456 .35822 L
s
.65456 .35822 m
.65615 .36033 L
s
.65608 .35574 m
.65612 .35803 L
s
0 0 0 r
.686 .31856 m
.68685 .31843 L
s
.255 .412 .882 r
.67103 .33085 m
.67402 .32813 L
s
.66959 .33564 m
.67103 .33085 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66959 .33564 m
.66997 .35626 L
s
.65615 .36033 m
.65929 .36225 L
s
.67255 .33063 m
.67402 .32813 L
s
.67111 .33542 m
.67255 .33063 L
s
.67402 .32813 m
.67553 .32791 L
s
.68271 .31077 m
.68367 .35893 L
s
.67111 .33542 m
.67141 .35146 L
s
.6842 .31053 m
.68516 .3587 L
s
.65929 .36225 m
.66546 .36147 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67823 .31148 m
.68864 .30979 L
s
.66832 .34958 m
.66988 .35167 L
s
.36258 .33139 m
.36412 .32933 L
s
.36267 .32681 m
.36412 .32933 L
s
.36113 .32886 m
.36267 .32681 L
s
.66546 .36147 m
.66848 .35877 L
s
.66997 .35626 m
.67141 .35146 L
s
.66848 .35877 m
.66997 .35626 L
s
.36113 .32886 m
.36258 .33139 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68466 .3334 m
.68754 .32834 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68754 .32834 m
.69045 .32556 L
s
.36236 .34286 m
.36331 .37075 L
s
.36031 .3703 m
.36236 .34286 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69045 .32556 m
.69339 .32506 L
s
.69339 .32506 m
.69637 .32685 L
s
.69339 .32506 m
.69783 .32659 L
s
.67916 .35959 m
.68516 .3587 L
s
0 0 0 r
.72715 .31075 m
.72885 .3104 L
s
.255 .412 .882 r
.34932 .3269 m
.35074 .32945 L
s
.35059 .33635 m
.35074 .32945 L
s
.68502 .35179 m
.6881 .35594 L
s
.34646 .32409 m
.34932 .3269 L
s
.69637 .32685 m
.69939 .33093 L
s
.36181 .37053 m
.36208 .35667 L
s
.69783 .32659 m
.70084 .33068 L
s
.34913 .3361 m
.35064 .33405 L
s
.34067 .32304 m
.34646 .32409 L
s
.34908 .3384 m
.35059 .33635 L
s
.34616 .3379 m
.34913 .3361 L
s
.6881 .35594 m
.69112 .35778 L
s
.69939 .33093 m
.70099 .33759 L
s
.34611 .3402 m
.34908 .3384 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36172 .37516 m
.36331 .37075 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70084 .33068 m
.70244 .33733 L
s
.33774 .3248 m
.34067 .32304 L
s
.34878 .35225 m
.35035 .34787 L
s
.35015 .35711 m
.35035 .34787 L
s
.33881 .34122 m
.34616 .3379 L
s
.36031 .3703 m
.36172 .37516 L
s
.33876 .34353 m
.34611 .3402 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70099 .33759 m
.70109 .3422 L
s
.69112 .35778 m
.69407 .3573 L
s
.69407 .3573 m
.69696 .35451 L
s
.69407 .3573 m
.69843 .35426 L
s
.70244 .33733 m
.70255 .34195 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33626 .32683 m
.33774 .3248 L
s
.34727 .35431 m
.34878 .35225 L
s
.34878 .35225 m
.35015 .35711 L
s
.69979 .34939 m
.70109 .3422 L
s
.69696 .35451 m
.69979 .34939 L
s
.70125 .34913 m
.70255 .34195 L
s
.33494 .32195 m
.33626 .32683 L
s
.33473 .33117 m
.33494 .32195 L
s
.71075 .32189 m
.72061 .31989 L
s
.3443 .35613 m
.34727 .35431 L
s
.33473 .33117 m
.33626 .32683 L
s
.69843 .35426 m
.70125 .34913 L
s
.33589 .343 m
.33881 .34122 L
s
.3385 .35511 m
.3443 .35613 L
s
.715 .32104 m
.71615 .36977 L
s
.33584 .34532 m
.33876 .34353 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32102 .31138 m
.32107 .31182 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71641 .32076 m
.71757 .36951 L
s
.33441 .34505 m
.33589 .343 L
s
.33435 .34737 m
.33584 .34532 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33568 .35227 m
.3385 .35511 L
s
.3343 .34968 m
.33441 .34505 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3343 .34968 m
.33568 .35227 L
s
.32223 .32167 m
.3249 .32689 L
s
.31815 .31846 m
.32223 .32167 L
s
.71701 .34622 m
.71994 .35031 L
s
.31541 .31785 m
.31815 .31846 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32445 .34544 m
.32451 .34312 L
s
.32317 .34051 m
.32451 .34312 L
s
.32172 .34254 m
.32317 .34051 L
s
.31263 .31955 m
.31541 .31785 L
s
.31128 .31924 m
.31541 .31785 L
s
.32155 .34953 m
.32445 .34544 L
s
.71187 .37056 m
.71757 .36951 L
s
.71994 .35031 m
.72419 .3518 L
s
.32172 .34254 m
.32305 .34516 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73026 .31778 m
.73092 .34335 L
s
.73162 .31747 m
.73228 .34305 L
s
.72615 .3187 m
.73568 .31653 L
s
.30981 .32357 m
.31263 .31955 L
s
.31871 .35128 m
.32155 .34953 L
s
.30846 .32325 m
.31128 .31924 L
s
.72419 .3518 m
.72697 .35122 L
s
.31458 .35041 m
.31871 .35128 L
s
.30828 .33023 m
.30981 .32357 L
s
.72697 .35122 m
.72967 .34831 L
s
.72697 .35122 m
.73104 .34801 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30693 .32992 m
.30846 .32325 L
s
.72967 .34831 m
.73092 .34335 L
s
.73104 .34801 m
.73228 .34305 L
s
.74103 .31525 m
.7502 .31292 L
s
.30815 .3349 m
.30828 .33023 L
s
.31191 .34748 m
.31458 .35041 L
s
.31055 .34718 m
.31458 .35041 L
s
.30681 .33458 m
.30693 .32992 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30815 .3349 m
.30932 .3422 L
s
.30932 .3422 m
.31191 .34748 L
s
.29289 .31231 m
.30199 .31466 L
s
.30681 .33458 m
.30797 .3419 L
s
.30797 .3419 m
.31055 .34718 L
s
.74499 .31426 m
.74588 .34698 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7463 .31393 m
.7472 .34666 L
s
.29715 .34641 m
.29806 .31367 L
s
.29585 .34609 m
.29676 .31333 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74191 .34792 m
.7472 .34666 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27908 .3084 m
.28779 .31091 L
s
.29196 .34511 m
.29715 .34641 L
s
.74495 .36139 m
.74621 .35873 L
s
.74495 .36139 m
.74634 .36344 L
s
.7568 .31821 m
.75919 .31282 L
s
.75573 .32558 m
.7568 .31821 L
s
.74621 .35873 m
.74759 .36077 L
s
.75573 .32558 m
.75587 .33027 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75919 .31282 m
.76287 .30941 L
s
.75807 .31786 m
.76044 .31247 L
s
.757 .32524 m
.75807 .31786 L
s
.74634 .36344 m
.74759 .36077 L
s
.757 .32524 m
.75714 .32993 L
s
.75587 .33027 m
.75734 .33698 L
s
.76044 .31247 m
.76287 .30941 L
s
.29539 .36256 m
.29676 .36052 L
s
.29552 .35785 m
.29676 .36052 L
s
.75714 .32993 m
.75861 .33664 L
s
.29415 .35989 m
.29552 .35785 L
s
.76287 .30941 m
.76534 .30868 L
s
.29415 .35989 m
.29539 .36256 L
s
.75734 .33698 m
.76001 .34101 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2821 .33289 m
.28235 .33131 L
s
.5 Mabswid
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28327 .33568 m
.28403 .30985 L
s
.28202 .33533 m
.28278 .30949 L
s
.75861 .33664 m
.76127 .34067 L
s
.76001 .34101 m
.76384 .34234 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76534 .30868 m
.76907 .30993 L
s
.28188 .34005 m
.28327 .33568 L
s
.76127 .34067 m
.76384 .34234 L
s
.76907 .30993 m
.77163 .31389 L
s
.28063 .3397 m
.28202 .33533 L
s
.26594 .30424 m
.27422 .30691 L
s
.27809 .34137 m
.28188 .34005 L
s
.76384 .34234 m
.76756 .34129 L
s
.27809 .34137 m
.28063 .3397 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26909 .35551 m
.27064 .30578 L
s
.27564 .34066 m
.27809 .34137 L
s
.76972 .33113 m
.77086 .32841 L
s
.2679 .35515 m
.26946 .3054 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77086 .32841 m
.77214 .33041 L
s
.76756 .34129 m
.76993 .33822 L
s
.76972 .33113 m
.771 .33313 L
s
.76993 .33822 m
.77221 .33277 L
s
.27208 .33722 m
.27564 .34066 L
s
.77214 .33041 m
.77221 .33277 L
s
.77969 .30416 m
.781 .30849 L
s
.77969 .30416 m
.77999 .3136 L
s
.26983 .33175 m
.27208 .33722 L
s
.77999 .3136 m
.781 .30849 L
s
.781 .30849 m
.78208 .30573 L
s
.78208 .30573 m
.78429 .30258 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78429 .30258 m
.78879 .30098 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78044 .32781 m
.78153 .32506 L
s
.78044 .32781 m
.78059 .33256 L
s
.78153 .32506 m
.78376 .32192 L
s
.78052 .33019 m
.7816 .32743 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7816 .32743 m
.78383 .3243 L
s
.78059 .33256 m
.78183 .33456 L
s
.26436 .35407 m
.26909 .35551 L
s
.78376 .32192 m
.78926 .31521 L
s
.78383 .3243 m
.78934 .31759 L
s
.78183 .33456 m
.78422 .33619 L
s
.78879 .30098 m
.79108 .30254 L
s
.25564 .30303 m
.25772 .30857 L
s
.25772 .30857 m
.25861 .31609 L
s
.25846 .32084 m
.25861 .31609 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25243 .29943 m
.25564 .30303 L
s
.25454 .30262 m
.2566 .30817 L
s
.2566 .30817 m
.25749 .31569 L
s
.25733 .32045 m
.25749 .31569 L
s
.2571 .32759 m
.25846 .32084 L
s
.78422 .33619 m
.78876 .33466 L
s
.25243 .29943 m
.25454 .30262 L
s
.79108 .30254 m
.79226 .3045 L
s
.25597 .3272 m
.25733 .32045 L
s
.78926 .31521 m
.7914 .31204 L
s
.24244 .27854 m
.24975 .28158 L
s
.78934 .31759 m
.79148 .31442 L
s
.25026 .2986 m
.25243 .29943 L
s
.79226 .3045 m
.7925 .31163 L
s
.2547 .33158 m
.2571 .32759 L
s
.7914 .31204 m
.79242 .30926 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79148 .31442 m
.7925 .31163 L
s
.25359 .33119 m
.25597 .3272 L
s
.24804 .30015 m
.25026 .2986 L
s
.78876 .33466 m
.79092 .3315 L
s
.25131 .33279 m
.2547 .33158 L
s
.79092 .3315 m
.79195 .32872 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24486 .3304 m
.24658 .28029 L
s
.24381 .32999 m
.24553 .27986 L
s
.79195 .32872 m
.79289 .32355 L
s
.79289 .32355 m
.79321 .3331 L
s
.79195 .32872 m
.79321 .3331 L
s
.25131 .33279 m
.25359 .33119 L
s
.24576 .30407 m
.24804 .30015 L
s
.24914 .332 m
.25131 .33279 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79968 .29922 m
.80081 .30118 L
s
.79968 .29922 m
.80065 .29641 L
s
.80065 .29641 m
.80177 .29837 L
s
.80081 .30118 m
.80177 .29837 L
s
.24707 .32881 m
.24914 .332 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24511 .3232 m
.24707 .32881 L
s
.23882 .29391 m
.23982 .29435 L
s
.24069 .32876 m
.24486 .3304 L
s
.23674 .29543 m
.23882 .29391 L
s
.23773 .29587 m
.23882 .29391 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80122 .31312 m
.80326 .34153 L
s
.80116 .34233 m
.80122 .31312 L
s
.80172 .3275 m
.80221 .34193 L
s
.23657 .30022 m
.23773 .29587 L
s
.80116 .34233 m
.80238 .34676 L
s
.23558 .29979 m
.23674 .29543 L
s
.23597 .31704 m
.23657 .30022 L
s
.80238 .34676 m
.80326 .34153 L
s
.2338 .29411 m
.23558 .29979 L
s
.23481 .32143 m
.23558 .29979 L
s
.23196 .29081 m
.2338 .29411 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23481 .32143 m
.23597 .31704 L
s
.22913 .28946 m
.23196 .29081 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23409 .31377 m
.23498 .31661 L
s
.22843 .30874 m
.23409 .31377 L
s
.23374 .32342 m
.23481 .32143 L
s
.22719 .29096 m
.22913 .28946 L
s
.22627 .2905 m
.22913 .28946 L
s
.23171 .32498 m
.23374 .32342 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2261 .29532 m
.22719 .29096 L
s
.2279 .32326 m
.23171 .32498 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22519 .29486 m
.22627 .2905 L
s
.22666 .30543 m
.22843 .30874 L
s
.22574 .30498 m
.22843 .30874 L
s
.22592 .30015 m
.2261 .29532 L
s
.22592 .30015 m
.22666 .30543 L
s
.22501 .2997 m
.22519 .29486 L
s
.22501 .2997 m
.22574 .30498 L
s
.22613 .31996 m
.2279 .32326 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22104 .30859 m
.22128 .31354 L
s
.255 .412 .882 r
.22539 .31467 m
.22631 .31511 L
s
.22622 .31753 m
.22631 .31511 L
s
.2253 .31709 m
.22613 .31996 L
s
.2253 .31709 m
.22539 .31467 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21745 .31061 m
.21821 .3135 L
s
.21812 .31594 m
.21821 .3135 L
s
.21718 .31793 m
.21812 .31594 L
s
.21652 .31259 m
.21745 .31061 L
s
.2089 .27808 m
.21434 .2815 L
s
.21652 .31259 m
.21727 .31549 L
s
.21467 .31656 m
.21718 .31793 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21064 .31425 m
.21196 .28004 L
s
.20986 .31378 m
.21118 .27955 L
s
.21313 .31319 m
.21467 .31656 L
s
.21171 .30736 m
.21313 .31319 L
s
.21121 .29955 m
.21171 .30736 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20756 .31237 m
.21064 .31425 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20377 .29473 m
.20455 .2751 L
s
.20103 .29276 m
.20592 .29619 L
s
.20308 .29424 m
.20385 .27459 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20239 .27604 m
.20356 .28195 L
s
.2005 .27206 m
.20239 .27604 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19922 .27103 m
.2005 .27206 L
s
.20251 .32684 m
.20309 .31199 L
s
.2021 .31893 m
.20309 .31199 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19787 .27247 m
.19922 .27103 L
s
.19726 .27195 m
.19922 .27103 L
s
.20053 .32294 m
.2021 .31893 L
s
.2021 .31893 m
.20251 .32684 L
s
.19646 .27638 m
.19787 .27247 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84693 .27041 m
.85271 .2652 L
s
.19586 .27586 m
.19726 .27195 L
s
.19842 .324 m
.20053 .32294 L
s
.19566 .28081 m
.19646 .27638 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19508 .2803 m
.19586 .27586 L
s
.19713 .32304 m
.19842 .324 L
s
.19478 .28774 m
.19566 .28081 L
s
.1942 .28723 m
.19508 .2803 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84876 .26886 m
.85087 .32101 L
s
.84935 .26834 m
.85146 .32052 L
s
.19597 .31958 m
.19713 .32304 L
s
.19536 .3191 m
.19713 .32304 L
s
.19427 .30017 m
.19478 .28774 L
s
.19369 .29967 m
.1942 .28723 L
s
.19495 .31362 m
.19597 .31958 L
s
.85271 .2652 m
.85386 .26662 L
s
.85271 .2652 m
.85437 .26609 L
s
.19427 .30017 m
.19456 .30814 L
s
.19435 .31313 m
.19536 .3191 L
s
.19456 .30814 m
.19495 .31362 L
s
.19369 .29967 m
.19397 .30765 L
s
.19397 .30765 m
.19435 .31313 L
s
.85386 .26662 m
.85508 .27054 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84902 .32246 m
.85485 .31758 L
s
.85437 .26609 m
.85557 .27001 L
s
.85508 .27054 m
.85578 .27499 L
s
0 0 0 r
.18365 .24966 m
.18458 .25079 L
s
.255 .412 .882 r
.1883 .2971 m
.19137 .30015 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85557 .27001 m
.85626 .27447 L
s
.18927 .26158 m
.18979 .29863 L
s
.18599 .29453 m
.18927 .26158 L
s
.85578 .27499 m
.85657 .28196 L
s
.18644 .29505 m
.18896 .26906 L
s
.85626 .27447 m
.85705 .28144 L
s
.85485 .31758 m
.85581 .31408 L
s
.85485 .31758 m
.85633 .31358 L
s
.85657 .28196 m
.85709 .29448 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85705 .28144 m
.85757 .29397 L
s
.85581 .31408 m
.85662 .30805 L
s
.85802 .25932 m
.86082 .25551 L
s
.85633 .31358 m
.85712 .30755 L
s
.85691 .30252 m
.85709 .29448 L
s
.85662 .30805 m
.85691 .30252 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8574 .30202 m
.85757 .29397 L
s
.85712 .30755 m
.8574 .30202 L
s
.85928 .25769 m
.86075 .29286 L
s
.18579 .25726 m
.18599 .29453 L
s
.85968 .25715 m
.86115 .29234 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85949 .29442 m
.86115 .29234 L
s
0 0 0 r
.86501 .26402 m
.86503 .26411 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1828 .29036 m
.18579 .25726 L
s
.18316 .29088 m
.18548 .26478 L
s
0 0 0 r
.86483 .26569 m
.86518 .2677 L
s
.255 .412 .882 r
.86052 .27722 m
.86123 .28425 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86123 .28425 m
.86219 .28824 L
s
.18176 .28878 m
.18432 .29245 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86219 .28824 m
.86302 .28972 L
s
.18231 .25176 m
.18261 .25232 L
s
.18162 .25318 m
.18231 .25176 L
s
.18191 .25373 m
.18231 .25176 L
s
.86302 .28972 m
.86402 .28814 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18141 .25823 m
.18191 .25373 L
s
.86348 .2836 m
.86392 .2856 L
s
.86348 .2836 m
.8637 .28053 L
s
.18113 .25768 m
.18162 .25318 L
s
.8637 .28053 m
.86412 .28253 L
s
.18065 .27596 m
.18141 .25823 L
s
.86402 .28814 m
.86423 .28507 L
s
.18082 .25151 m
.18113 .25768 L
s
.18016 .28051 m
.18113 .25768 L
s
.86412 .28253 m
.86423 .28507 L
s
.18045 .24786 m
.18082 .25151 L
s
.18016 .28051 m
.18065 .27596 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1798 .24618 m
.18045 .24786 L
s
.18022 .27234 m
.18038 .27542 L
s
.86508 .2559 m
.86509 .25028 L
s
.86508 .2559 m
.86529 .26097 L
s
.86509 .25028 m
.86563 .24606 L
s
.17894 .26652 m
.18022 .27234 L
s
.17979 .28252 m
.18016 .28051 L
s
.86529 .26097 m
.86574 .26551 L
s
.86531 .25535 m
.86532 .24972 L
s
.86531 .25535 m
.86553 .26042 L
s
0 0 0 r
.17597 .23608 m
.17602 .24027 L
s
.17566 .24332 m
.17602 .24027 L
s
.255 .412 .882 r
.86532 .24972 m
.86563 .24606 L
s
0 0 0 r
.17562 .23913 m
.17597 .23608 L
s
.255 .412 .882 r
.86553 .26042 m
.86597 .26496 L
s
.17917 .28399 m
.17979 .28252 L
s
0 0 0 r
.86973 .24739 m
.86981 .239 L
s
.255 .412 .882 r
.17931 .24759 m
.1798 .24618 L
s
.17914 .24703 m
.1798 .24618 L
s
0 0 0 r
.17562 .23913 m
.17566 .24332 L
s
.255 .412 .882 r
.86574 .26551 m
.86649 .26641 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86563 .24606 m
.86617 .24437 L
s
0 0 0 r
.86981 .239 m
.87017 .23365 L
s
.255 .412 .882 r
.86597 .26496 m
.86649 .26641 L
s
.86618 .27569 m
.86628 .27824 L
s
.86618 .27569 m
.8664 .27515 L
s
.17828 .28185 m
.17917 .28399 L
s
.86628 .27824 m
.86662 .28025 L
s
.17892 .25212 m
.17931 .24759 L
s
.8664 .27515 m
.86651 .2777 L
s
0 0 0 r
.87051 .26555 m
.87083 .27284 L
s
.17318 .30591 m
.17487 .26147 L
s
.87017 .23365 m
.87046 .23249 L
s
.255 .412 .882 r
.86617 .24437 m
.8666 .24578 L
s
.17866 .26287 m
.17894 .26652 L
s
.17849 .26232 m
.17894 .26652 L
s
.17876 .25156 m
.17914 .24703 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86649 .26641 m
.86762 .26566 L
s
.86662 .28025 m
.86715 .28173 L
s
0 0 0 r
.87072 .265 m
.87119 .27594 L
s
.87083 .27284 m
.87135 .2796 L
s
.255 .412 .882 r
.1787 .25722 m
.17892 .25212 L
s
.17866 .26287 m
.1787 .25722 L
s
0 0 0 r
.87087 .23496 m
.87046 .23249 L
s
.87098 .23438 m
.87046 .23249 L
s
.255 .412 .882 r
.17854 .25666 m
.17876 .25156 L
s
.8666 .24578 m
.86709 .24976 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87119 .27594 m
.8717 .28271 L
s
.255 .412 .882 r
.17801 .27821 m
.17828 .28185 L
s
.17849 .26232 m
.17854 .25666 L
s
.86715 .28173 m
.86787 .27957 L
s
0 0 0 r
.87135 .2796 m
.8717 .28271 L
s
.255 .412 .882 r
.17805 .27254 m
.17823 .27309 L
s
.17812 .27565 m
.17823 .27309 L
s
0 0 0 r
.17297 .30538 m
.17393 .28337 L
s
.255 .412 .882 r
.17794 .2751 m
.17801 .27821 L
s
.17794 .2751 m
.17805 .27254 L
s
0 0 0 r
.8714 .2411 m
.87087 .23496 L
s
.8717 .28271 m
.87222 .28529 L
s
.255 .412 .882 r
.86699 .24409 m
.86709 .24976 L
s
0 0 0 r
.87149 .24052 m
.87098 .23438 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86699 .24409 m
.8671 .2404 L
s
.86709 .24976 m
.86808 .27281 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17266 .31275 m
.17318 .30591 L
s
.255 .412 .882 r
.86711 .24352 m
.86721 .24919 L
s
.86721 .24919 m
.86798 .26712 L
s
.8671 .2404 m
.86711 .24352 L
s
.86762 .26566 m
.86786 .26767 L
s
.86787 .27957 m
.86806 .27592 L
s
.8671 .2404 m
.86719 .23983 L
s
0 0 0 r
.87222 .28529 m
.87268 .28365 L
s
.87197 .2515 m
.8714 .2411 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17278 .30485 m
.17487 .26147 L
s
.17266 .31275 m
.17278 .30485 L
s
.255 .412 .882 r
.86806 .27592 m
.86808 .27281 L
s
.86798 .26712 m
.86808 .27281 L
s
0 0 0 r
.87268 .28365 m
.87278 .27888 L
s
.87268 .28365 m
.87289 .27833 L
s
.87228 .25883 m
.87197 .2515 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87149 .24052 m
.87205 .25093 L
s
.87066 .26501 m
.87228 .25883 L
s
.87051 .26555 m
.87066 .26501 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87236 .25827 m
.87205 .25093 L
s
.87267 .27041 m
.87228 .25883 L
s
.87278 .27888 m
.87267 .27041 L
s
.87134 .2243 m
.8713 .22665 L
s
.255 .412 .882 r
.1769 .27073 m
.17693 .2676 L
s
.17679 .27331 m
.1769 .27073 L
s
0 0 0 r
.87276 .26986 m
.87236 .25827 L
s
.87289 .27833 m
.87276 .26986 L
s
.255 .412 .882 r
.17659 .27534 m
.17679 .27331 L
s
.17674 .26963 m
.17693 .2676 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17797 .2325 m
.17788 .23652 L
s
.17674 .26963 m
.1767 .27276 L
s
.17641 .2737 m
.17659 .27534 L
s
.1763 .27095 m
.17786 .2348 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86888 .27468 m
.86908 .27084 L
s
.86753 .23468 m
.86896 .26864 L
s
.86753 .23468 m
.86903 .27303 L
s
.17644 .27001 m
.17641 .2737 L
s
.17632 .2704 m
.17787 .23422 L
s
0 0 0 r
.87145 .22679 m
.87182 .23531 L
s
.255 .412 .882 r
.86786 .2424 m
.86906 .27249 L
s
0 0 0 r
.8712 .22194 m
.87145 .22679 L
s
.255 .412 .882 r
.17644 .27001 m
.17664 .26373 L
s
0 0 0 r
.87107 .22076 m
.8712 .22194 L
s
.255 .412 .882 r
.17664 .26373 m
.17697 .25542 L
s
0 0 0 r
.87105 .22326 m
.87107 .22076 L
s
.87095 .22267 m
.87107 .22076 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87134 .2243 m
.87472 .30204 L
s
.87134 .22488 m
.87472 .30257 L
s
.255 .412 .882 r
.17641 .26875 m
.1763 .27095 L
s
0 0 0 r
.8731 .26483 m
.87338 .27113 L
s
.87115 .22948 m
.87105 .22326 L
s
.255 .412 .882 r
.86711 .23007 m
.86896 .26864 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87103 .2289 m
.87095 .22267 L
s
.87338 .27113 m
.87345 .27374 L
s
.255 .412 .882 r
.86744 .23783 m
.86891 .26808 L
s
.1778 .24257 m
.17813 .23681 L
s
.17737 .25092 m
.1778 .24257 L
s
0 0 0 r
.87464 .30043 m
.87472 .30257 L
s
.255 .412 .882 r
.17813 .23681 m
.17861 .23047 L
s
0 0 0 r
.87151 .24002 m
.87115 .22948 L
s
.255 .412 .882 r
.17681 .26394 m
.17737 .25092 L
s
0 0 0 r
.87345 .27374 m
.87332 .27263 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17791 .242 m
.17825 .23624 L
s
.17747 .25036 m
.17791 .242 L
s
.17825 .23624 m
.17875 .2299 L
s
0 0 0 r
.87137 .23945 m
.87103 .2289 L
s
.255 .412 .882 r
.17691 .26338 m
.17747 .25036 L
s
.17657 .27122 m
.17681 .26394 L
s
0 0 0 r
.87332 .27263 m
.87299 .26779 L
s
.87332 .27263 m
.87288 .26723 L
s
.87151 .24002 m
.87183 .24746 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17668 .27067 m
.17691 .26338 L
s
0 0 0 r
.8717 .24689 m
.87137 .23945 L
s
.255 .412 .882 r
.86774 .26255 m
.86857 .26588 L
s
0 0 0 r
.87244 .2592 m
.87183 .24746 L
s
.87299 .26779 m
.87244 .2592 L
s
.255 .412 .882 r
.17646 .2759 m
.17657 .27122 L
s
0 0 0 r
.87232 .25864 m
.8717 .24689 L
s
.87288 .26723 m
.87232 .25864 L
s
.255 .412 .882 r
.17658 .27535 m
.17668 .27067 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86752 .24277 m
.8682 .26422 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86883 .21559 m
.86962 .22421 L
s
.255 .412 .882 r
.17652 .28016 m
.17683 .28106 L
s
.17667 .27991 m
.17683 .28106 L
s
.86564 .23497 m
.86573 .23618 L
s
.86573 .23618 m
.86629 .2446 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86789 .21009 m
.86883 .21559 L
s
.87042 .24288 m
.87075 .25037 L
s
.86731 .2089 m
.86789 .21009 L
s
.8702 .24231 m
.87068 .25356 L
s
.87075 .25037 m
.87085 .25731 L
s
.86685 .21145 m
.86731 .2089 L
s
.86652 .21086 m
.86731 .2089 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87068 .25356 m
.87077 .26051 L
s
.87077 .26051 m
.87085 .25731 L
s
.255 .412 .882 r
.86696 .26977 m
.86696 .26865 L
s
0 0 0 r
.8665 .21777 m
.86685 .21145 L
s
.87043 .26316 m
.87077 .26051 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86696 .236 m
.87042 .24288 L
s
.86615 .21719 m
.86652 .21086 L
s
.86958 .26149 m
.87043 .26316 L
s
.8665 .21777 m
.86664 .22847 L
s
.86615 .21719 m
.86628 .22789 L
s
.86664 .22847 m
.86696 .236 L
s
.86879 .25659 m
.86958 .26149 L
s
.86846 .25603 m
.86958 .26149 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86628 .22789 m
.8666 .23543 L
s
.86057 .19884 m
.86375 .20298 L
s
.86696 .236 m
.8678 .2479 L
s
.8678 .2479 m
.86879 .25659 L
s
.8666 .23543 m
.86745 .24734 L
s
.86745 .24734 m
.86846 .25603 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86246 .2012 m
.86423 .24283 L
s
.862 .20061 m
.86377 .24226 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8641 .24988 m
.86423 .24283 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85737 .22993 m
.85807 .24651 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85807 .24651 m
.85847 .24697 L
s
0 0 0 r
.86363 .24933 m
.86377 .24226 L
s
.255 .412 .882 r
.85723 .23794 m
.8574 .2305 L
s
0 0 0 r
.86282 .25203 m
.8641 .24988 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86282 .25203 m
.86363 .24933 L
s
.86181 .25093 m
.86282 .25203 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85684 .19473 m
.85859 .23666 L
s
.85626 .19414 m
.85801 .2361 L
s
.85445 .19239 m
.85851 .19649 L
s
.86004 .24544 m
.86181 .25093 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85859 .23666 m
.86004 .24544 L
s
.84693 .18602 m
.85188 .19007 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85774 .24322 m
.85801 .2361 L
s
.85833 .24378 m
.85859 .23666 L
s
.85668 .24597 m
.85833 .24378 L
s
.85668 .24597 m
.85774 .24322 L
s
.84983 .18833 m
.85203 .24215 L
s
.84912 .18775 m
.85132 .24161 L
s
.85541 .24488 m
.85668 .24597 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85326 .23938 m
.85541 .24488 L
s
.85156 .23056 m
.85326 .23938 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83801 .17977 m
.84385 .18373 L
s
.84912 .23998 m
.85203 .24215 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84142 .18203 m
.84358 .23623 L
s
.255 .412 .882 r
.8365 .19232 m
.83682 .19302 L
s
0 0 0 r
.84058 .18146 m
.84275 .23569 L
s
.255 .412 .882 r
.8365 .19232 m
.83684 .19351 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82771 .17365 m
.83443 .17752 L
s
.84016 .2341 m
.84358 .23623 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84384 .26309 m
.84452 .25968 L
s
.84353 .25524 m
.84452 .25968 L
s
.84283 .25865 m
.84353 .25524 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83065 .1753 m
.83231 .21814 L
s
.83161 .17586 m
.83327 .21867 L
s
.84283 .25865 m
.84384 .26309 L
s
.81603 .16771 m
.82362 .17147 L
s
.83261 .22598 m
.83327 .21867 L
s
.83164 .22546 m
.83231 .21814 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8298 .22835 m
.83261 .22598 L
s
.8298 .22835 m
.83164 .22546 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82043 .16985 m
.82353 .25252 L
s
.81935 .16931 m
.82243 .25203 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82777 .22732 m
.8298 .22835 L
s
.82449 .22185 m
.82777 .22732 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22912 .16782 m
.24395 .16148 L
s
.24395 .16148 m
.24847 .15955 L
s
.82205 .21294 m
.82449 .22185 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80683 .16744 m
.80951 .17633 L
s
.803 .16197 m
.80683 .16744 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80049 .16096 m
.803 .16197 L
s
.81908 .25058 m
.82353 .25252 L
s
.23212 .20899 m
.23935 .20602 L
s
.79808 .16388 m
.80049 .16096 L
s
.79678 .16338 m
.80049 .16096 L
s
.81051 .20393 m
.81065 .20789 L
s
.80917 .19948 m
.81051 .20393 L
s
.8081 .20294 m
.80917 .19948 L
s
.24718 .16005 m
.24765 .18326 L
s
.80852 .21484 m
.81065 .20789 L
s
.23878 .22193 m
.23991 .19018 L
s
.24765 .18326 m
.24847 .15955 L
s
.79575 .17079 m
.79808 .16388 L
s
.8081 .20294 m
.80945 .2074 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22951 .24923 m
.23253 .16623 L
s
.23068 .24876 m
.23369 .16571 L
s
.22606 .25068 m
.24102 .24491 L
s
.24102 .24491 m
.24558 .24315 L
s
.79443 .17029 m
.79678 .16338 L
s
.79484 .18218 m
.79575 .17079 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8062 .21785 m
.80852 .21484 L
s
.79351 .1817 m
.79443 .17029 L
s
.80243 .21641 m
.8062 .21785 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79484 .18218 m
.79511 .19012 L
s
.79351 .1817 m
.79378 .18964 L
s
.79972 .21147 m
.80243 .21641 L
s
.79842 .21099 m
.80243 .21641 L
s
.79511 .19012 m
.79684 .20254 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79378 .18964 m
.79552 .20207 L
s
.79684 .20254 m
.79972 .21147 L
s
.26183 .1586 m
.26621 .15321 L
s
.26017 .16701 m
.26183 .1586 L
s
.79552 .20207 m
.79842 .21099 L
s
.25872 .21092 m
.26017 .16701 L
s
.26323 .15813 m
.26621 .15321 L
s
.26156 .16654 m
.26323 .15813 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26012 .21047 m
.26156 .16654 L
s
.24428 .24361 m
.24641 .21908 L
s
.24558 .24315 m
.24641 .21908 L
s
.26621 .15321 m
.26909 .15227 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26909 .15227 m
.27337 .15486 L
s
.77306 .15124 m
.77483 .20727 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76708 .14941 m
.77744 .15264 L
s
.77158 .15078 m
.77334 .20684 L
s
.25457 .21229 m
.26012 .21047 L
s
.27337 .15486 m
.27611 .16192 L
s
.78598 .1988 m
.78751 .20326 L
s
.78751 .20326 m
.78764 .20727 L
s
.7847 .20235 m
.78598 .1988 L
s
.78637 .21083 m
.78764 .20727 L
s
.27648 .14996 m
.28257 .14816 L
s
.7847 .20235 m
.78624 .20681 L
s
.78212 .20948 m
.78637 .21083 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27474 .20607 m
.27648 .14996 L
s
.27626 .20564 m
.27799 .14951 L
s
.255 .412 .882 r
.76882 .19326 m
.7698 .18681 L
s
0 0 0 r
.77407 .18316 m
.77592 .19564 L
s
.77911 .20457 m
.78212 .20948 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76829 .18657 m
.76846 .18545 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75465 .14588 m
.76403 .14851 L
s
.77592 .19564 m
.77911 .20457 L
s
.27025 .20737 m
.27626 .20564 L
s
.76881 .20555 m
.77483 .20727 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2951 .14869 m
.30011 .14343 L
s
.29165 .15755 m
.2951 .14869 L
s
.2897 .17002 m
.29165 .15755 L
s
.29672 .14827 m
.30011 .14343 L
s
.29325 .15713 m
.29672 .14827 L
s
.2913 .1696 m
.29325 .15713 L
s
.74228 .16666 m
.75695 .17035 L
s
.30011 .14343 m
.30342 .14261 L
s
.28946 .17807 m
.2897 .17002 L
s
.73488 .14091 m
.74493 .14334 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29106 .17765 m
.2913 .1696 L
s
.30342 .14261 m
.30666 .14581 L
s
.28946 .17807 m
.29071 .18976 L
s
.29106 .17765 m
.29232 .18935 L
s
.30666 .14581 m
.30983 .15306 L
s
.30787 .22625 m
.31015 .14099 L
s
.29071 .18976 m
.29371 .19705 L
s
.30959 .22589 m
.31186 .1406 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31015 .14099 m
.31702 .13943 L
s
.29232 .18935 m
.29535 .19665 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73827 .14171 m
.75226 .22954 L
s
.75191 .21729 m
.75939 .14718 L
s
.75226 .22954 m
.76094 .14763 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29371 .19705 m
.29853 .19992 L
s
.29535 .19665 m
.29853 .19992 L
s
.29853 .19992 m
.30186 .19915 L
s
.30186 .19915 m
.30534 .19431 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31842 .17633 m
.31877 .17822 L
s
.3167 .17664 m
.31679 .17715 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30534 .19431 m
.30896 .18543 L
s
.33107 .14048 m
.33661 .13538 L
s
.32729 .14929 m
.33107 .14048 L
s
.3252 .1618 m
.32729 .14929 L
s
.33288 .14013 m
.33661 .13538 L
s
.32908 .14893 m
.33288 .14013 L
s
.32699 .16144 m
.32908 .14893 L
s
.33661 .13538 m
.34028 .13469 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.325 .16992 m
.3252 .1618 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34028 .13469 m
.34389 .13806 L
s
.34028 .13469 m
.34575 .13772 L
s
.32679 .16957 m
.32699 .16144 L
s
.325 .16992 m
.32649 .18178 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32679 .16957 m
.32828 .18144 L
s
.34389 .13806 m
.34744 .14551 L
s
.34575 .13772 m
.34931 .14518 L
s
.30275 .22735 m
.30959 .22589 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32649 .18178 m
.32989 .18926 L
s
.34744 .14551 m
.34905 .15739 L
s
.32828 .18144 m
.33171 .18892 L
s
.34931 .14518 m
.35094 .15707 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36098 .13112 m
.37264 .12935 L
s
.32989 .18926 m
.33527 .19235 L
s
.34887 .16555 m
.34905 .15739 L
s
.33171 .18892 m
.33527 .19235 L
s
.35076 .16523 m
.35094 .15707 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34672 .17813 m
.34887 .16555 L
s
.33527 .19235 m
.33897 .1917 L
s
.3486 .17782 m
.35076 .16523 L
s
.33897 .1917 m
.34278 .18696 L
s
.33897 .1917 m
.34465 .18664 L
s
.34278 .18696 m
.34672 .17813 L
s
.38054 .12824 m
.39257 .12669 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34465 .18664 m
.3486 .17782 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38832 .12777 m
.38854 .12719 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36484 .13051 m
.38735 .18414 L
s
.38735 .18414 m
.38756 .18464 L
s
.3637 .18777 m
.38653 .12745 L
s
.36565 .18749 m
.38832 .12777 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35982 .18834 m
.37155 .18667 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40887 .12892 m
.41515 .1242 L
s
.40669 .13732 m
.40887 .12892 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41094 .1287 m
.41515 .1242 L
s
.41515 .1242 m
.41932 .1238 L
s
.40875 .1371 m
.41094 .1287 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41932 .1238 m
.42555 .12732 L
s
.40602 .18263 m
.40669 .13732 L
s
.4081 .18242 m
.40875 .1371 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42982 .12286 m
.43829 .12218 L
s
.42555 .12732 m
.42967 .13516 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37951 .18563 m
.39163 .18417 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44897 .12143 m
.45104 .12949 L
s
.44882 .13785 m
.44897 .12143 L
s
.45323 .12526 m
.45757 .1209 L
s
.45757 .1209 m
.46622 .12043 L
s
.45104 .12949 m
.45323 .12526 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46622 .12043 m
.47053 .12433 L
s
.44882 .13785 m
.45104 .12949 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42914 .18057 m
.42982 .12286 L
s
.43127 .1804 m
.43193 .12268 L
s
.47053 .12433 m
.47268 .12834 L
s
.49018 .11949 m
.49236 .12354 L
s
.48798 .12367 m
.49018 .11949 L
s
.39982 .18327 m
.4081 .18242 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4726 .1407 m
.47268 .12834 L
s
.48798 .12367 m
.49015 .12771 L
s
.49015 .12771 m
.49236 .12354 L
s
.47042 .14079 m
.47263 .13657 L
s
.46604 .14512 m
.47042 .14079 L
s
.47039 .14492 m
.4726 .1407 L
s
.45514 .15396 m
.46604 .14512 L
s
.46601 .14925 m
.47039 .14492 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45078 .15835 m
.45514 .15396 L
s
.4551 .15809 m
.46601 .14925 L
s
.44859 .16262 m
.45078 .15835 L
s
.255 .412 .882 r
.53293 .15782 m
.53521 .15734 L
s
0 0 0 r
.42278 .18108 m
.43127 .1804 L
s
.45074 .16249 m
.4551 .15809 L
s
.44851 .17091 m
.44859 .16262 L
s
.44855 .16676 m
.45074 .16249 L
s
.255 .412 .882 r
.53075 .1607 m
.53293 .15782 L
s
.56988 .17013 m
.56988 .17031 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48845 .15748 m
.48855 .15794 L
s
.49591 .16236 m
.49697 .15746 L
s
.49048 .15748 m
.49088 .15934 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55039 .16389 m
.55252 .16395 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44851 .17091 m
.45063 .17493 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47023 .16977 m
.47247 .16137 L
s
.47236 .17799 m
.47247 .16137 L
s
.45063 .17493 m
.45492 .17884 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46802 .17402 m
.47023 .16977 L
s
.47023 .16977 m
.47236 .17799 L
s
.45492 .17884 m
.46362 .17838 L
s
.46362 .17838 m
.46802 .17402 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49007 .14834 m
.49207 .19823 L
s
.48765 .19834 m
.49007 .14834 L
s
.48986 .19828 m
.48996 .17323 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48765 .19834 m
.48983 .20667 L
s
.48983 .20667 m
.49207 .19823 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@D000000`3oYQ480:f][@030000002][Jd0
[Jf]02/0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f]
[@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0000000000000`0000020?nV4@<0[Jf]00@000000:f][@2][Jd000001@2][Jd0
0`000000[Jf]0:f][@070?nV4@8000007@3oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh3
0:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4@@000000`2][Jd2000000D0[Jf]0`3oYQ400`00
0000ojHA000000070?nV4@030000003oYQ40ojHA00H0ojHA00<000000?nV40000000703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?oo
o`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA00L0ojHA0`0000020?nV4@H0[Jf]0P0000020:f][@80ojHA0P0000000`2][Jd0
0000000000080?nV4@030000003oYQ40000000L0ojHA00<000000?nV4@3oYQ401P3oYQ42000001d0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS40X0[Jf]103oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0
/>3V0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ4300000080ojHA00<0[Jf]0000000000000P0000050:f][@D0ojHA0P0000060?nV4@040000
002][Jd00000000000P0ojHA0P0000090?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0000003o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01D0oj<@1`2][JdH0?bP4003
0:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][F40/>3V0@3oool007D0/>3V
0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ404`3oYQ44000000D0[Jf]
103oYQ400`000000ojHA0?nV4@080?nV4@8000001`3oYQ43000000P0ojHA0P0000090?nV4@030000
003oYQ40ojHA00D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1001P2][JdB0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ450:f][@030000003oYQ40[Jf]00L0ojHA00<0
00000?nV4@3oYQ40203oYQ42000000P0ojHA0`0000080?nV4@8000002@3oYQ400`000000ojHA0?nV
4@050?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400I0?nS40030:f][@3lX100o:0@00H0o:0@1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd2
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@07
0?nV4@<0000000<0ojHA0:f][@2][Jd00`2][Jd60?nV4@030000002][Jd0ojHA00H0ojHA00<00000
0?nV4@3oYQ40203oYQ42000000P0ojHA00<0[Jf]000000000000203oYQ400`000000ojHA0?nV4@08
0?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1002`3lX1050:f][@P0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK
0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ40102][Jd000000:f][@2][Jd2000000/0ojHA00<00000
0:f][@3oYQ401@3oYQ400`000000ojHA0?nV4@090?nV4@800000203oYQ400`2][Jd0000000000008
0?nV4@030000003oYQ40ojHA00P0ojHA00<000000?nV4@3oYQ401@3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400@
0?bP40H0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A0P0000020?nV4@D0[Jf]0P0000030?nV
4@8000002`3oYQ400`000000ojHA0?nV4@040?nV4@030000003oYQ40ojHA00T0ojHA0P0000080?nV
4@030:f][@000000000000P0ojHA00<000000?nV4@3oYQ401`3oYQ42000000L0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP
403lX1005P3lX1040:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@060=^:
3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@0A0?nT4@800000102][Jd40?nV4@8000001@3oYQ42000000X0ojHA00<000000?nV4@3o
YQ40103oYQ400`000000ojHA0?nV4@090?nV4@800000203oYQ400`2][Jd000000000000B0?nV4@80
00001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0[Jf]00<0[Jf]0`00000>0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V
0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140303oY142000000070?nT
4@2][Jd0[Jf]0000002][Jd0oj@A0:f][@050?nV4@8000001P3oYQ42000000X0ojHA00<000000?nV
4@3oYQ400`3oYQ400`000000ojHA0?nV4@0:0?nV4@8000001`3oYQ40102][Jd0ojHA00000000000A
0?nV4@800000203oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?0P2][Jd4
000000/0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H1
0?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0;0?nT
4@040000002][Jd0[Jf]00000080oj@A00@000000?nT4@3oY140[Jf]1@3oYQ42000000L0ojHA0P00
00090?nV4@030:f][@000000ojHA00<0ojHA00<000000?nV4@3oYQ402P3oYQ42000000L0ojHA00@0
[Jf]0?nV4@0000000000403oYQ400`000000ojHA000000080?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l01@3fW0l00`000000mY`?0:f][@030:f][@T0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A0`2]
[Jd2000000<0oj@A00<000000?nT4@0000000P3oY1400`2][Jd0ojHA0?nV4@020?nV4@800000203o
YQ42000000T0ojHA00<0[Jf]0000003oYQ400P3oYQ42000000`0ojHA0P0000070?nV4@040:f][@3o
YQ400000000000l0ojHA00<000000?nV4@0000002@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00D0mY`?00<000000?JL3`3fW0l00`3fW0l20:f][@<00000103fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_
V1000`2][Jd0o:0@0?bP400?0?bP40050:f][@3oY140oj@A0000003oY1400P0000030:f][@80oj@A
0P0000040?nT4@030000003oY14000000080oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ42000000P0ojHA
0P0000090?nV4@030:f][@3oYQ4000000080ojHA00<000000?nV4@3oYQ402`3oYQ42000000L0ojHA
00@0[Jf]0?nV4@00000000003P3oYQ400`000000ojHA0000000:0?nV4@030:f][@000000ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l01@3fW0l00`000000mY`?0?JL3`070?JL3`<0000000<0[Jf]00000000
00004P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V
00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00800000
00<0[Jf]0?nT4@3oY1400`3oY142000000H0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA0080ojHA
0P0000080?nV4@8000002@3oYQ400`2][Jd0ojHA000000020?nV4@030000003oYQ40ojHA00/0ojHA
0P0000070?nV4@040:f][@3oYQ400000000000d0ojHA00<000000?nV4@0000002`3oYQ400`2][Jd0
00000?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l01P3fW0l200000080
mY`?0P2][Jd200000100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3P
iP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX1003@3lX1020000
0080[Jf]00<0oj@A0000003oY1401P3oY142000000H0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA
0080ojHA0P0000090?nV4@800000203oYQ401@2][Jd0ojHA0000003oYQ40000000h0ojHA0P000007
0?nV4@040:f][@3oYQ400000000000`0ojHA00<000000?nV4@000000303oYQ400`2][Jd000000?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l01P3fW0l2000000<0mY`?00<0
[Jf]0000000000000P00000>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;
0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@
0?bP400<0?bP40030000002][Jd0o:0@0080000000<0oj@A0000003oY1401@3oY142000000P0oj@A
00@000000?nT4@3oY140[Jf]103oYQ400`000000ojHA0?nV4@080?nV4@800000203oYQ400`2][Jd0
ojHA0?nV4@02000000h0ojHA0P0000070?nV4@040:f][@3oYQ400000000000/0ojHA00<000000?nV
4@0000003@3oYQ400`2][Jd000000?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00H0mY`?00<000000?JL
3`3fW0l01P3fW0l2000000<0mY`?00<0[Jf]0000000000000P3/UPh20:f][@`0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0
dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1020:f][@80
00000P3lX100102][Jd000000?nT4@0000060?nT4@800000203oY14010000000oj@A0?nT4@2][Jd3
0?nV4@8000002P3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ400P00000>0?nV4@8000001`3oYQ40
102][Jd0ojHA00000000000:0?nV4@030000003oYQ40000000L0ojHA202][Jd00`000000[Jf]0:f]
[@0S0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00H0mY`?00<000000?JL3`3fW0l01@3fW0l00`000000mY`?000000030?JL3`030:f][@00
0000000000@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102i
M@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40030000003lX100o:0@0080[Jf]00<0o:0@
0000000000000`3lX100102][Jd0oj@A0000000000060?nT4@800000203oY1400`000000oj@A0:f]
[@040?nV4@8000002P3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ400P00000>0?nV4@8000001`3o
YQ40102][Jd0ojHA0000000000040?nV4@D0[Jf]00<000000:f][@000000202][Jd70?nV4@03045Y
h@000000ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l0
1@3fW0l2000000@0mY`?00<0[Jf]0000000000001`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0
[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0`00
00020:f][@<0o:0@0P0000030?bP40040:f][@3oY1400000000000H0oj@A0P0000080?nT4@030000
003oY140[Jf]00@0ojHA0P00000:0?nV4@800000203oYQ400`2][Jd0ojHA0?nV4@02000000d0ojHA
0P0000040?nV4@H0[Jf]0P0000040:f][@@0ojHA0`0000080?nV4@030000003oYQ40ojHA00D0ojHA
00<0[Jf]0000003oYQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l01@3fW0l2000000@0mY`?
00<0[Jf]0000000000002P3/UPh20:f][@050>bF3P000000k9H>0>bF3P2][Jd03@3KRPd00`2][Jd0
^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h0
1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080000000<0[Jf]000000000000
1@3lX1000`000000o:0@0?bP40020?bP40040:f][@3oY140oj@A000000H0oj@A00<000000?nT4@3o
Y1401P3oY142000000030?nT4@2][Jd0ojHA00<0ojHA0P00000:0?nV4@800000203oYQ401P2][Jd0
ojHA000000000000ojHA000000T0ojHA0`2][Jd2000000@0[Jf]103oYQ40102][Jd0ojHA00000000
00070?nV4@8000002P3oYQ400`000000ojHA0?nV4@050?nV4@050:f][@000000ojH@0?nV4011JN40
6P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f]
[@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l00`000000mY`?0?JL3`040?JL3`800000
103fW0l00`2][Jd000000000000;0>bF3P80000000@0[Jf]0000003/UPh0[Jf]3@3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@00000000000:f][@80o:0@0P0000050?bP4003
0000003lX100o:0@0080o:0@00@0[Jf]0?nT4@3oY14000001@3oY142000000P0oj@A0P0000000`3o
Y140[Jf]0?nV4@030?nV4@8000002P3oYQ42000000P0ojHA00<0[Jf]0?nV4@0000000P3oYQ400`00
0000[Jf]0:f][@070:f][@<0ojHA0P0000080?nV4@040:f][@3oYQ400000000000L0ojHA00<00000
0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@000000ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400G
0?bP40030:f][@3fW0l0mY`?00L0mY`?00<000000?JL3`3fW0l0103fW0l2000000@0mY`?00<0[Jf]
0000000000002`3/UPh01P000000k9H>0>bF3P3/UPh000000:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00X0kiP@0P00
00000`2][Jd0o:0@0?bP40020?bP408000001@3lX1000`000000o:0@0?bP40020?bP40040:f][@3o
Y140oj@A000000D0oj@A0P0000080?nT4@80000000<0oj@A0:f][@3oYQ400`3oYQ42000000X0ojHA
0P0000060?nV4@<0[Jf]0P0000020:f][@030000003oYQ40ojHA00X0ojHA0P0000080?nV4@040:f]
[@3oYQ400000000000L0ojHA00<000000?nV4@3oYQ40203oYQ42000000L0ojHA00<0[Jf]0000003o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdF0?bP4003
0:f][@3fW0l0mY`?00L0mY`?0P0000050?JL3`800000103fW0l00`2][Jd000000000000:0>bF3P80
0000103/UPh00`000000[Jf]0:f][@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40
oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40080>nH40<0000000<0[Jf]0?bP403lX100
0`3lX102000000D0o:0@00<000000?bP403lX1000P3lX100102][Jd0oj@A0?nT4@0000050?nT4@80
0000203oY142000000030?nT4@2][Jd0ojHA00<0ojHA0P00000:0?nV4@8000001P2][Jd20?nV4@03
0:f][@000000ojHA00<0ojHA00<000000?nV4@3oYQ402@3oYQ42000000P0ojHA00@0[Jf]0?nV4@00
000000001`3oYQ400`000000ojHA0?nV4@080?nV4@8000001`3oYQ400`2][Jd000000?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX106
0:f][A00o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l00`000000mY`?00000003000000030?JL3`000000
000000@0mY`?00<0[Jf]0000000000002P3/UPh00`000000k9H>0>bF3P030>bF3P040000003KRPd0
fhX=0:f][@<000001`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3o
ool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]00<0kiP@
0000002][Jd01@3lX1000`000000o:0@0?bP40040?bP40030000003lX100o:0@0080o:0@00@0[Jf]
0?nT4@3oY14000001@3oY142000000P0oj@A0P0000000`3oY140[Jf]0?nV4@030?nV4@8000001`3o
YQ430:f][@800000203oYQ400`2][Jd000000?nV4@030?nV4@030000003oYQ40ojHA00T0ojHA0P00
00080?nV4@040:f][@3oYQ400000000000L0ojHA00<000000?nV4@3oYQ40203oYQ42000000L0ojHA
00<0[Jf]0000003oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1001`3lX1070:f][@T0o:0@00<0[Jf]0?JL3`3fW0l01`3fW0l00`000000mY`?
0?JL3`030?JL3`<00000103fW0l00`2][Jd000000000000:0>bF3P030000003/UPh0k9H>00<0k9H>
00<000000=^:3@3KRPd00P3KRPd0102][Jd000000000000000050=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P03
0:f][@3_V100kiP@00D0kiP@0P2][Jd30>nH40030000002][Jd0o:0@00@0o:0@00<000000?bP403l
X100103lX1000`000000o:0@0?bP40020?bP40040:f][@3oY140oj@A000000D0oj@A0P0000080?nT
4@80000000<0oj@A0:f][@3oYQ400`3oYQ4200000080ojHA1@2][Jd20?nV4@8000002@3oYQ420000
00D0ojHA00<000000?nV4@3oYQ40203oYQ42000000P0ojHA00@0[Jf]0?nV4@00000000001`3oYQ40
0`000000ojHA0?nV4@070?nV4@<000001`3oYQ400`2][Jd000000?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40H0[Jf]0`3lX100
0`2][Jd0mY`?0?JL3`070?JL3`030000003fW0l0mY`?00@0mY`?0P0000040?JL3`030:f][@000000
000000X0k9H>00<000000>bF3P3/UPh00`3/UPh00`2][Jd000000=^:3@030=^:3@050000002][Jd0
fhX=0=^:3@0000000`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V
0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40040>nH40030:f]
[@3_V100kiP@00<0kiP@00<000000:f][@3lX100103lX1000`000000o:0@0?bP40040?bP40030000
003lX100o:0@0080o:0@00@0[Jf]0?nT4@3oY14000001@3oY142000000P0oj@A0P000000103oY140
[Jf]0?nV4@3oYQ420:f][@8000000P2][Jd70?nV4@8000002@3oYQ400`000000ojHA0?nV4@040?nV
4@030000003oYQ40ojHA00P0ojHA0P0000080?nV4@040:f][@3oYQ400000000000P0ojHA00<00000
0?nV4@3oYQ401P3oYQ43000000L0ojHA0`00000L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400D0?bP40D0[Jf]2@3fW0l00`000000mY`?0?JL3`02
0?JL3`030000003fW0l0000000@0mY`?00<0[Jf]0000000000002P3/UPh00`000000k9H>0>bF3P03
0>bF3P030:f][@000000fhX=00<0fhX=00D000000=^:3@2][Jd0[Jf]0=^:3@02000000030=^:3@2]
[Jd0^GD;00P0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]1P3_V1000`000000[Jf]
0?bP40040?bP40030000003lX100o:0@00@0o:0@00<000000?bP403lX1000P3lX100102][Jd0oj@A
0?nT4@0000050?nT4@800000203oY142000000@0[Jf]0P3oYQ400`000000ojHA000000080?nV4@80
0000203oYQ42000000H0ojHA00<000000?nV4@3oYQ40203oYQ42000000P0ojHA00@0[Jf]0?nV4@00
000000002@3oYQ42000000D0ojHA00@000000?nV4@3oYQ4000001`3oYQ43000001`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`2][Jd00`2][Jd50?JL3`030000003fW0l0mY`?0080mY`?00<000000?JL3`000000103fW0l0
0`2][Jd00000000000090>bF3P8000001@3/UPh00`2][Jd000000=^:3@030=^:3@040000003KRPd0
fhX=0=^:3@80[Jf]0P0000000`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0
A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V100
0P2][Jd80>nH40030000002][Jd0o:0@00@0o:0@00<000000?bP403lX100103lX1000`000000o:0@
0?bP40020?bP40040:f][@3oY1400000000000D0oj@A0P0000060?nT4@80[Jf]0P0000000`3oY140
[Jf]0?nV4@040?nV4@800000203oYQ42000000P0ojHA0P0000070?nV4@030000003oYQ40ojHA00L0
ojHA0P0000080?nV4@040:f][@3oYQ400000000000/0ojHA1@0000030?nV4@030000003oYQ40ojHA
00D0ojHA0`00000L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd00`3fW0l000000?JL3`030?JL
3`8000001@3fW0l00`2][Jd00000000000090>bF3P8000001@3/UPh00`2][Jd0fhX=0=^:3@030=^:
3@030000003KRPd0fhX=00<0fhX=00<000000:f][@2][Jd02@2iM@/00`2][Jd0R5H708QF1`0208QF
1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P060=>73P<0[Jf]2P3_V1000`000000[Jf]0?bP40040?bP40030000003lX100o:0@00@0
o:0@00<000000?bP403lX1000P3lX100102][Jd0oj@A0000000000050?nT4@8000000P3oY1440:f]
[@80oj@A0P0000000`3oY140[Jf]0?nV4@040?nV4@8000001`3oYQ42000000T0ojHA00<000000:f]
[@3oYQ401P3oYQ400`000000ojHA0?nV4@070?nV4@8000001`3oYQ45000001/0ojHA0`00000L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP
40030:f][@3fW0l0mY`?00L0mY`?00@0[Jf]0000002][Jd0[Jf]0P3fW0l2000000D0mY`?00@0[Jf]
0>bF3P0000000000203/UPh2000000D0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:
3@030=^:3@060000003KRPd0[Jf]0000002iM@/000001P2iM@/00`2][Jd0R5H708QF1`0208QF1`03
0:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P03
0:f][@3_V100kiP@00X0kiP@00<000000:f][@3lX100103lX1000`000000o:0@0?bP40040?bP4003
0000003lX100o:0@0080o:0@00@0[Jf]0?nT4@00000000001@3oY14200000080[Jf]1P3oY1401000
0000oj@A0?nT4@2][Jd50?nV4@8000001`3oYQ42000000P0ojHA0P0000000`2][Jd0ojHA0?nV4@06
0?nV4@030000003oYQ40ojHA00<0ojHA1@0000080?nV4@030:f][@3oYQ40ojHA01`0ojHA0`00000L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G
0?bP40030:f][@3fW0l0mY`?00P0mY`?00<000000?JL3`3fW0l00P2][Jd2000000D0mY`?00@0[Jf]
0>bF3P0000000000203/UPh2000000D0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:
3@030=^:3@040000003KRPd0[Jf]0:f][@8000001P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]
303_V1000`000000o:0@0?bP400;0?bP40030000003lX100o:0@0080o:0@00@0[Jf]0?nT4@000000
00000P3oY1430:f][@030000003oY140000000L0oj@A00@000000?nT4@3oY140[Jf]1@3oYQ420000
00H0ojHA0P0000090?nV4@030000003oYQ40[Jf]00@0ojHA1`00000@0?nV4@030:f][@3oYQ40ojHA
01`0ojHA0`00000L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00P0mY`?00<000000?JL3`3fW0l00P3fW0l20000
00@0[Jf]00<0mY`?045Yh@3/UPh00P0000080>bF3P8000001@3/UPh00`2][Jd0fhX=0=^:3@030=^:
3@030000003KRPd0fhX=00<0fhX=00D000000=^:3@2][Jd0^GD;0:f][@02000000D0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd01P3CQ`h20:f][@030=>73P2][Jd0kiP@00/0kiP@00<000000?bP403lX1002`3lX100
0`000000o:0@0?bP40020?bP40040:f][@3oY140000000000080[Jf]103oY142000000L0oj@A00@0
00000?nT4@3oY140[Jf]1P3oYQ42000000D0ojHA0P0000080?nV4@D000006P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@<00000703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`090?JL3`040000003fW0l0mY`?0?JL3`80
0000103fW0l30:f][@800000203/UPh2000000D0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000
fhX=0=^:3@030=^:3@030000003KRPd0[Jf]0080^GD;00@000000:f][@2iM@/000000`2iM@/00`2]
[Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@050=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd02`3_V102000000`0o:0@0P000003
0?bP40<0[Jf]0P0000060?nT4@8000001P3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ40103oYQ42
000000@0ojHA0P0000070?nV4@@0000000<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@<00000703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`090?JL3`040000003fW0l0mY`?0?JL3`8000001@3f
W0l01@2][Jd0k9H>000000000000[Jf]00L0k9H>0P0000050>bF3P030:f][@3KRPd0fhX=00<0fhX=
00<000000=^:3@3KRPd00`3KRPd00`000000fhX=0:f][@020;Ue2`050000002iM@/0[Jf]0;Ue2`00
00000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00@0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH40090>nH4080
00000`3lX1000`000000o:0@0?bP40060?bP408000000`2][Jd00`3lX100[Jf]0?nT4@02000000H0
oj@A0P0000060?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@050?nV4@8000000P3oYQ400`000000
ojHA0?nV4@0;0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ43000001`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l01P000000mY`?0?JL3`000000mY`?000000D0mY`?00D0[Jf]
0>bF3P00000000000>bF3P020:f][@D0k9H>0P0000050>bF3P030:f][@3KRPd0fhX=00<0fhX=00<0
00000=^:3@3KRPd00`3KRPd00`000000fhX=0:f][@020;Ue2`040000002iM@/0^GD;0:f][@800000
00<0^GD;0:f][@28EPL00`28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@030=>73P030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002@3_V102000000<0o:0@
00<000000?bP403lX1001P3lX102000000@0o:0@00@0[Jf]0?nT4@00000000001P3oY142000000D0
oj@A00<000000?nT4@0000000P3oY1400`2][Jd0ojHA0?nV4@070?nV4@8000003P3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA0`00000L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00T0
mY`?00H000000?JL3`3fW0l000000?JL3`0000050?JL3`040:f][@3/UPh00000000000<0k9H>0`2]
[Jd20>bF3P8000001@3/UPh00`2][Jd0fhX=0=^:3@030=^:3@800000103KRPd01P000000fhX=0:f]
[@11JN40^GD;000000<0^GD;00@000000:f][@000000[Jf]1028EPL20:f][D80/>3V0@3oool005T0
/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@H0dhL>00<0[Jf]0>nH403_V1002@3_V102
000000<0o:0@00<000000?bP403lX1000`3lX1030:f][@800000103lX100102][Jd0oj@A00000000
00070?nT4@800000103oY1400`000000oj@A000000020?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]0`00000T0:f][AL0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00P0mY`?00H0
00000?JL3`3fW0l000000?JL3`0000050?JL3`040:f][@3/UPh00000000000H0k9H>0P2][Jd20000
00D0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2000000@0fhX=00<000000=^:3@2][Jd00P2iM@/01`00
0000^GD;0;Ue2`2iM@/000000;Ue2`2][Jd00P00000308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0
102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V102000000<0o:0@00<0
00000?bP403lX1000`2][Jd30?bP40800000103lX100102][Jd0oj@A0000000000070?nT4@800000
0`3oY14010000000oj@A0?nT4@0000020?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ43000001`0ojH@00<0[Jf]0?nU403o
YA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00P0mY`?00H000000?JL3`3fW0l000000?JL3`0000050?JL3`040:f][@3/UPh0
0000000000T0k9H>00<000000:f][@3/UPh00`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@800000103K
RPd00`000000fhX=0:f][@020;Ue2`050000002iM@/0^GD;0;Ue2`0000000P2iM@/2000000@0R5H7
00<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>
00<0[Jf]0>nH403_V1002@3_V102000000<0o:0@00<000000:f][@2][Jd01P3lX102000000@0o:0@
00@0[Jf]0?nT4@0000000000203oY142000000030?nT4@000000oj@A0080oj@A00@000000?nT4@3o
Y140[Jf]6@3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5`3oYQ43000001`0ojH@00<0[Jf]0?nU
403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`090?JL
3`040000003fW0l00000000000H0mY`?00<0[Jf]0>bF3P0000000P0000030>bF3P030000003/UPh0
k9H>0080k9H>0P0000030:f][@030>bF3P2][Jd0000000@0fhX=0P0000040=^:3@80000000@0fhX=
0:f][@2iM@/000000`2iM@/00`000000^GD;0;Ue2`03000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`
h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V102
000000040?bP402][Jd0[Jf]000000P0o:0@0P0000040?bP40040:f][@3oY1400000000000X0oj@A
00<000000?nT4@3oY1400P3oY14010000000oj@A0?nT4@2][JdI0?nV4@030:f][@3oYQ40ojHA00`0
ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<000000?nV40000000703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l010000000mY`?0000000000060?JL3`030:f][@3/UPh00000
008000000`3/UPh00`000000k9H>0>bF3P020>bF3P8000000`3/UPh00`2][Jd00000000000040=^:
3@800000103KRPd2000000040=^:3@2][Jd0^GD;000000<0^GD;00<000000;Ue2`2iM@/00P000000
1@28EPL0000008QF1`28EPL0[Jf]0480/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd8
0=>73P030:f][@3_V100kiP@00X0kiP@0P000000102][Jd0o:0@0?bP400000080?bP40800000103l
X100102][Jd0oj@A00000000000?0?nT4@040000003oY140oj@A0:f][AT0ojHA00<0[Jf]0?nV4@3o
YQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ42000001d0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00T0mY`?00@000000?JL3`00000000001P3fW0l01P2][Jd0k9H>000000000000
k9H>00000080k9H>0P0000030>bF3P800000103/UPh010000000fhX=0000002][Jd20=^:3@800000
103KRPd2000000040=^:3@2][Jd0^GD;000000<0^GD;00<000000;Ue2`2iM@/00P0000001@2][Jd0
000000000028EPL0[Jf]0480/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>7
3P030:f][@3_V100kiP@00T0kiP@00<0[Jf]0000000000000`3lX1000`000000o:0@0?bP40060?bP
40800000103lX100102][Jd0oj@A00000000000?0?nT4@040000003oY140oj@A0:f][AH0ojHA202]
[JdH0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0000003oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?00T0mY`?00@0
00000?JL3`00000000001P3fW0l4000000040>bF3P000000k9H>0>bF3P8000000`3/UPh2000000@0
k9H>00@000000=^:3@000000fhX=0P2][Jd2000000@0fhX=0P000000103KRPd0[Jf]0;Ue2`000003
0;Ue2`030000002iM@/0^GD;0080000000D0R5H700000028EPL0R5H70:f][@120;3PiP40oooo001I
0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]00@0
kiP@000000000000o:0@0P0000090?bP408000000`3lX100102][Jd0000000000000000?0?nT4@80
00000P3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0000003oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?
00T0mY`?00@000000?JL3`00000000001`3fW0l01@2][Jd000000000003/UPh000000080k9H>0P00
00040>bF3P030000003/UPh0k9H>0080k9H>00<0[Jf]0000000000000`3KRPd2000000@0fhX=0P00
0000103KRPd0[Jf]0;Ue2`0000030;Ue2`030000002iM@/0^GD;0080000000D0R5H70000002][Jd0
R5H70:f][@120;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f]
[@3_V100kiP@00D0kiP@0P2][Jd30>nH40<0000000<0o:0@0000003lX100203lX102000000<0o:0@
00<0[Jf]0?nT4@3oY140403oY14200000080oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00P0o:0@
1P2][Jd:0?bP40030:f][@3fW0l0mY`?00T0mY`?0P0000000`3fW0l000000?JL3`060?JL3`030:f]
[@3/UPh0k9H>0080k9H>0P0000000`3/UPh000000>bF3P030>bF3P8000000`3/UPh00`2][Jd0fhX=
000000030=^:3@8000000P2][Jd20=^:3@80000000<0fhX=0:f][@2iM@/00P0000020;Ue2`030000
002iM@/0^GD;0080000000D0R5H70000002][Jd0R5H7000000120;3PiP40oooo001I0;3PiP80[Jf]
0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd50>nH40050000
002][Jd0o:0@0?bP400000002@3lX102000000<0o:0@00<0[Jf]0?nT4@3oY140403oY14200000080
oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0:0?JL
3`030000003fW0l0000000L0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh2000000D0k9H>00L000000>bF
3P3/UPh0k9H>0:f][@3KRPd0000000<0fhX=0P0000020=^:3@80[Jf]0P0000001@3KRPd0[Jf]0;Ue
2`2iM@/000000080^GD;00<000000;Ue2`2iM@/00P0000000`28EPL0000008QF1`0200000480/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f][@3_V100kiP@0>nH4080
[Jf]1`3_V1001@000000[Jf]0?bP403lX100000000L0o:0@0P0000050?bP40030:f][@3oY140oj@A
0100oj@A0P0000000`3oY140[Jf]0:f][@030:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][Jd:0?JL3`030000003fW0l00000
00L0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh01@000000k9H>0>bF3P2][Jd0000000D0fhX=00<00000
0=^:3@3KRPd00P3KRPd2000000050=^:3@2][Jd0^GD;0;Ue2`0000000P2iM@/00`000000^GD;0;Ue
2`020000000308QF1`000000R5H700800000@P2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]
0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f][@2][Jd90>nH40050000002][Jd0o:0@0?bP40000000
3P3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@060:f][@00000000000:f][@3oY140[Jf]6@3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`040:f][@H0mY`?00<000000?JL3`0000001`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF
3P050000003/UPh0k9H>0:f][@0000001@3KRPd00`000000fhX=0=^:3@020=^:3@8000000P2][Jd2
0;Ue2`040000002iM@/0^GD;00000080^GD;0P0000001P28EPL0000008QF1`000000[Jf]00000440
/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>0P2][Jd;0>nH40050000
002][Jd0o:0@0?bP400000003P3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]00<0oj@A00000000
00000P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd0103fW0l0
00000?JL3`0000070?JL3`030:f][@3/UPh0k9H>00d0k9H>0`0000060=^:3@8000000`3KRPd20000
00050=^:3@2][Jd0[Jf]0;Ue2`0000000`2iM@/02P000000^GD;0;Ue2`000000R5H700000028EPL0
00000:f][@0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P80
[Jf]303_V1001@000000[Jf]0?bP403lX100000000<0o:0@00<000000?bP403lX100203lX1000`2]
[Jd0oj@A0?nT4@070?nT4@@0[Jf]1@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`090?JL3`030:f][@00000000000080[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00@0fhX=0P0000030=^:3@80000000D0fhX=0:f][@2iM@/0[Jf]00000003
0;Ue2`0:0000002iM@/0^GD;00000028EPL0000008QF1`000000[Jf]00000440/>3V0@3oool005P0
/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0=>73P2][Jd0303_V1001@000000
[Jf]0?bP403lX100000000<0o:0@00<000000?bP403lX100203lX1000`2][Jd0oj@A0?nT4@030?nT
4@@0[Jf]2@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0:0?JL
3`8000000P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@030=^:
3@030000003KRPd000000080fhX=0P0000001P3KRPd0[Jf]0;Ue2`2iM@/000000:f][@80^GD;00T0
00000;Ue2`2iM@/0000008QF1`000000R5H70000002][Jd00P0000100;3PiP40oooo001H0;3PiP80
[Jf]0`2GH0/00`2][Jd0dhL>0=>73P030=>73P040:f][@3CQ`h0dhL>0:f][@`0kiP@00D000000:f]
[@3lX100o:0@000000030?bP40030000003lX100o:0@00P0o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd=
0?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?00<00000
0?JL3`3fW0l0103fW0l40:f][A40k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=00000002
0=^:3@80000000T0fhX=0:f][@2iM@/0^GD;0000002iM@/0[Jf]0;Ue2`0000000P2iM@/00`000000
R5H708QF1`02000000030:f][@00000000000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`040:f]
[@3CQ`h0dhL>0=>73P80[Jf]0`3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030000002][Jd0o:0@00D0
o:0@00<000000?bP403lX1001`3lX1030:f][A40oj@A0P0000020?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l00`000000mY`?0?JL3`060?JL3`030:f][@3/UPh0[Jf]0080
[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@030=^:3@050000003KRPd0fhX=0000003KRPd00P0000001@3K
RPd0[Jf]0;Ue2`2iM@/000000080^GD;00D0[Jf]0000002iM@/0^GD;0000000208QF1`80000000<0
[Jf]000000000000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0[Jf]1@3C
Q`h00`2][Jd0kiP@0>nH400:0>nH40030000002][Jd0o:0@00D0o:0@00<000000?bP403lX1001@3l
X1020:f][@030?bP402][Jd0oj@A00l0oj@A0`0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l02`3fW0l00`000000mY`?0?JL3`060?JL3`030:f][@3/UPh0k9H>0080k9H>0P2]
[Jd<0>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P000000103KRPd000000=^:
3@2][Jd20;Ue2`080000002iM@/0^GD;0;Ue2`000000[Jf]0;Ue2`00000208QF1`8000000P2][Jd0
0`000000/>3V0;3PiP0n0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0:f][@060=>7
3P030:f][@3_V100kiP@00T0kiP@0P0000000`2][Jd0o:0@0?bP40040?bP40030000003lX100o:0@
0080o:0@0`2][Jd30?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`0;0?JL3`030000003fW0l0mY`?00H0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f]
[@T0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd010000000fhX=0=^:3@3KRPd200000080fhX=00@0[Jf]
0;Ue2`2iM@/000000`2iM@/010000000^GD;0:f][@00000208QF1`8000000P2][Jd00`000000/>3V
0;3PiP0n0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002@3_
V102000000030:f][@3lX100o:0@00<0o:0@00@000000?bP403lX100o:0@0P2][Jd60?bP40030:f]
[@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd0
1@3KRPd0102][Jd0^GD;0;Ue2`0000030;Ue2`040000002iM@/0^GD;00000080R5H70P0000020:f]
[@030000002`h>H0/>3V03h0/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P060=>73P030:f][@3_V100kiP@00T0kiP@0P0000000`2][Jd0o:0@0?bP40030?bP4004
0000002][Jd0[Jf]0:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2000000H0fhX=00@0[Jf]0;Ue
2`2iM@/000000`2iM@/01P000000^GD;0;Ue2`000000[Jf]08QF1`8000000P2][Jd00`000000/>3V
0;3PiP0n0;3PiP40oooo001H0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@
0>nH400:0>nH4080000000@0[Jf]0?bP403lX100o:0@0P2][Jd00`000000o:0@0?bP40090?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0
[Jf]00<0k9H>0:f][@3KRPd0103KRPd2000000L0fhX=00<000000;Ue2`0000000`2iM@/01P000000
^GD;0;Ue2`000000[Jf]08QF1`<0000000<0[Jf]0000002`h>H0?`2`h>H10?ooo`00F02`h>H0102]
[Jd0Uf0;09MP2`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002P3_V102000000040:f][@3lX100
[Jf]0:f][@80o:0@00<000000?bP403lX1002@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]103K
RPd2000000L0fhX=00<0[Jf]0000000000000`2iM@/2000000040;Ue2`000000R5H70:f][@<00000
00<0[Jf]0000002`h>H0?`2`h>H10?ooo`00F02`h>H01P2][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@L0
dhL>00<0[Jf]0>nH403_V1002P3_V10200000080[Jf]103lX1000`000000o:0@0?bP40090?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0
[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]0P3KRPd2000000L0fhX=00<0[Jf]0;Ue
2`2iM@/00`2iM@/2000000040;Ue2`000000R5H70:f][@<0000000<0[Jf]0000002`h>H0?`2`h>H1
0?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH
403_V1002@3_V100102][Jd000000000002][Jd50?bP40030000003lX100o:0@00T0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf1
0;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]
0=^:3@3KRPd0fhX=0P2][Jd2000000L0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/3000000040;Ue2`00
0000R5H708QF1`D00000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3C
Q`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@040>nH4000000000000:f][@D0o:0@
00<000000?bP403lX1002@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA
202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd00`3KRPd2000000L0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/00`000000^GD;
000000020000000308QF1`000000[Jf]00<00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0
[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]0`3_V102000000030:f][@3l
X100o:0@00<00000303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2]
[JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd00`3KRPd200000080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0000000<0
R5H70000002][Jd01000000o0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P05
0=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd50>nH4080000000<0[Jf]0000000000003`3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX100
0`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2
00000080fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00D0[Jf]00000028EPL0000008QF
1`04000003l0/>3V0@3oool005L0/>3V0P2][Jd409MP2`030:f][@3CQ`h0dhL>00D0dhL>00@0[Jf]
0>nH403_V100kiP@0P2][Jd70>nH40<000004@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3o
YQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P0000040=^:3@80[Jf]00<0fhX=0:f][@2iM@/0
202iM@/01P2][Jd0000000000028EPL000000:f][@800000?`2`h>H10?ooo`00E`2`h>H20:f][@<0
Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f][@2][Jd80>nH4080000000<0kiP@0:f]
[@3lX100403lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@<000001P3KRPd20:f][@T0^GD;00H0[Jf]0000
00000000R5H700000011JN42000003l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0
dhL>00H0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY144
0:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2
000000L0fhX=0`2][Jd70;Ue2`040:f][@28EPL0000008QF1`@00000?`2`h>H10?ooo`00E`2`h>H2
0:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@h0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/000000:f][@H0^GD;00@0[Jf]08QF1`28EPL0R5H7
1000000o0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P030=>73P80[Jf]00<0
dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2]
[JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0
[Jf]0;Ue2`000000^GD;0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`@00000?`2`h>H10?ooo`00
E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h00P3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0
kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`03
0:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;000000020;Ue2`80
[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL4000003l0/>3V0@3oool005L0/>3V00<000000:f][@2G
H0/00P2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2]
[Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;000000040;Ue2`040:f][@2iM@/0^GD;0:f][@<0R5H700@0[Jf]0000000000000000?`2`
h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`040:f][@3CQ`h0[Jf]0:f][@D0dhL>00<0
[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;000000050;Ue2`<0[Jf]0`28EPL0102][Jd000000000
0000000o0;3PiP40oooo001G0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd70=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0
`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000000000o0;3PiP40oooo001G0;3PiP030:f][@2G
H0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102][Jd70>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0[Jf]000000000000?`2`
h>H10?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2]
[Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2]
[Jd208QF1`04045Yh@2][Jd00000000003l0/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0Uf0;
0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M
00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f]
[@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f]
[@28EPL0[Jf]0080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP
2`2][Jd0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0
/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@000000000003l0/>3V0@3oool005L0/>3V
00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00X0kiP@
0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][MP0/>3V
102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@/0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H708QF1`2][Jd0R5H70:f][@800000?`2`h>H10?oo
o`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_
V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0
[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080
[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3P
iP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0
kiP@102][Jd70;6[W@80@FWQ0P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0
_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0
_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd20000
03l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_
V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]1P2aZid3045Yh@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l
00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f]
[@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3P
iP2`h>H0?@2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0
dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd40;6[
W@80@FWQ00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]0P00000n0;3PiP40oooo001F0;3P
iP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h0102][Jd0kiP@0:f][@2][Jd2
045Yh@@0Y9j?00<0[Jf]0;6[W@2aZid0102aZid20:f][@80/J^M0P11JN400`2aZid0[Jf]0;VbYP0?
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n
^KP20:f][@P0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]00<0/>3V0000002`h>H0?@2`h>H10?ooo`00EP2`h>H00`000000[Jf]
09MP2`0209MP2`030:f][@3CQ`h0dhL>00L0dhL>0P2][Jd20:BNS`80@FWQ102TWXl00`2][Jd0/J^M
0;6[W@060;6[W@80[Jf]0P11JN400`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00<0
];2a0P2][Jd:0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0/>3V0000002`h>H0?@2`h>H10?oo
o`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]045Yh@11
JN400P2TWXl2045Yh@@0Y9j?00@0[Jf]0;6[W@2aZid0@FWQ1`2aZid2045Yh@030;6[W@2][Jd0^K:V
00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f]
[@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00D0];2a0P2][Jd80;Ue2`040:f][@28EPL0R5H7
08QF1`80[Jf]00<0/>3V0000002`h>H0?@2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP
2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd00`2TWXl0@FWQ045Yh@020:BNS`80@FWQ102TWXl0102]
[Jd0/J^M045Yh@2aZid2045Yh@D0/J^M0P11JN430:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2]
[Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00L0];2a00<0[Jf]0;Ue2`2iM@/01@2i
M@/0102][Jd0R5H708QF1`28EPL20:f][@030;3PiP000000/>3V03d0/>3V0@3oool005H0/>3V00<0
00000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P030=>73P<0[Jf]0`11JN420:BNS`80@FWQ0`2T
WXl0102][Jd0/J^M045Yh@11JN420;6[W@04045Yh@2aZid0/J^M045Yh@80/J^M0P11JN400`2aZid0
[Jf]0;VbYP040:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP00`2][Jd0];2a0;B`/@070;B`/@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f]
[@030;3PiP000000/>3V03d0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P020=>73P050:f][@11JN40RXEe0:f][@2TWXl00`11JN400`2TWXl0@FWQ045Yh@030:BN
S`040:f][@2aZid0@FWQ045Yh@80/J^M00@0@FWQ0;6[W@11JN40@FWQ0P2aZid2045Yh@030;6[W@2]
[Jd0^K:V00@0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][@03045Yh@2][Jd0[Jf]00<0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Jd00`2`h>H000000;3PiP0m0;3PiP40oooo001F0;3PiP030000002]
[Jd0Uf0;0080Uf0;00P0[Jf]0=>73P3CQ`h0dhL>0:f][@2:QGD0@FWQ08Z5M@<0[Jf]0`2TWXl00`11
JN40Y9j?0:BNS`020:BNS`040:f][@2aZid0@FWQ045Yh@<0/J^M0P11JN430;6[W@80@FWQ00<0/J^M
0:f][@2i/ZH01`2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd5
0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh045Yh@0<0;ji^0030:f][@2d/;40
];2a00D0];2a00L0[Jf]0;B`/@2d/;40[Jf]045Yh@2OVj00[Jf]0080^GD;00@0[Jf]08QF1`28EPL0
R5H70P2][Jd00`2`h>H000000;3PiP0m0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;
00T0[Jf]0=>73P2][Jd0[Jf]045Yh@2:QGD0@FWQ08Z5M@2][Jd00P2TWXl0102][Jd0Y9j?0:BNS`11
JN440:BNS`040:f][@2aZid0@FWQ045Yh@<0/J^M0P11JN430;6[W@D0@FWQ2P2i/ZH40:f][@030;Vb
YP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@h0`kfk00<0[Jf]045Yh@11JN40
302n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]0`2d/;40102][Jd0@FWQ09nKX02OVj030:f][@@0
R5H700<0[Jf]0;3PiP000000?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]
102:QGD00`11JN40RXEe0:f][@030:BNS`80[Jf]00<0@FWQ0:BNS`2TWXl00P2TWXl0102][Jd0/J^M
045Yh@11JN430;6[W@80@FWQ0`2aZid2045Yh@030;6[W@2][Jd0@FWQ00h0^K:V0`2][JdA0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0
[Jf]0<>m^`0:0<>m^`07045Yh@33_K/0`kfk0<>m^`2][Jd0_[Vh045Yh@0<0;ji^0040:f][@2d/;40
];2a0;B`/@80[Jf]1@2d/;401`2][Jd0@FWQ09nKX02OVj00@FWQ09nKX02][Jd01028EPL00`2][Jd0
00000000000n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD0
0`2:QGD00`11JN40RXEe0:f][@050:BNS`03045Yh@2][Jd0Y9j?0080Y9j?00@0[Jf]0;6[W@11JN40
@FWQ0`2aZid2045Yh@<0/J^M0P11JN40102aZid0[Jf]0;VbYP11JN440;VbYP80@FWQ202i/ZH00`2]
[Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m
^`33_K/01033_K/00`11JN40`kfk0<>m^`02045Yh@050<>m^`11JN40`kfk0<>m^`2][Jd03P2n^KP0
102][Jd0];2a0;B`/@2][Jd70;B`/@050:f][@11JN40Wi^P09nKX011JN400P2OVj001`2][Jd0R5H7
08QF1`28EPL0[Jf]0;3PiP000000?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@D0RXEe00<0@FWQ08Z5M@2][Jd01@2TWXl2045Yh@050:f][@2TWXl0Y9j?0:f][@2aZid00P11JN43
0;6[W@80@FWQ0P2aZid01`11JN40/J^M045Yh@2aZid0[Jf]0;VbYP11JN401P2i/ZH2045Yh@H0^K:V
00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc
0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0a/2l
00<0[Jf]0<>m^`33_K/01033_K/3045Yh@<0`kfk00D0@FWQ0<>m^`33_K/0`kfk0:f][@0=0;ji^0<0
[Jf]202d/;401@2][Jd0@FWQ09nKX02OVj00@FWQ0080Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@10
0;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1@2:QGD00`11JN40RXEe0:f][@05
0:BNS`80@FWQ00@0Y9j?0:f][@2][Jd0[Jf]0P2aZid01011JN40/J^M0;6[W@2aZid2045Yh@80/J^M
0P11JN420;6[W@040:f][@2i/ZH0^K:V045Yh@D0^K:V1011JN440;VbYP030:f][@2n]j`0_[N/00L0
_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk0<>m^`040<>m^`80
@FWQ1033_K/01@11JN40`kfk0<>m^`33_K/0[Jf]00`0_[Vh0P2][Jd:0;B`/@050:f][@11JN40Wi^P
09nKX011JN400`2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0
Uf0;00<0[Jf]1@2:QGD00`11JN40RXEe0:f][@050:BNS`80@FWQ0`2TWXl20:f][@80/J^M00<0@FWQ
0;6[W@2aZid00P11JN420;6[W@80@FWQ0P2aZid0102][Jd0^K:V0;VbYP11JN450;VbYP80@FWQ0`2i
/ZH4045Yh@d0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k0`11
JN4@0<O1_0@0[Jf]4036`;`4045Yh@@0`kfk0P11JN450<>m^`04045Yh@33_K/0`kfk0:f][@X0_[Vh
0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@050:f][@11JN40Wi^P09nKX011JN400`2OVj020:f][@03
08QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd508Z5M@05
045Yh@2][Jd0Y9j?0:BNS`11JN400`2TWXl2045Yh@050:BNS`11JN40Y9j?0:f][@2aZid00P2][Jd0
0`2aZid0@FWQ045Yh@02045Yh@80/J^M0P11JN420;6[W@040:f][@2i/ZH0^K:V045Yh@D0^K:V0P11
JN450;VbYP<0@FWQ402n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03`38`K/4045Yh@030:f][@37
`K`0al6l00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l00h0a/2l00D0@FWQ0<K0_02][Jd0`kfk
045Yh@040<>m^`03045Yh@33_K/0`kfk00<0`kfk0P11JN420<>m^`030:f][@2n^KP0_[Vh00H0_[Vh
0P2][Jd30;ji^0030:f][@2d/;40];2a00P0];2a00@0[Jf]045Yh@2OVj00@FWQ102OVj00102][Jd0
L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@06
045Yh@2][Jd0Y9j?0:BNS`11JN40Y9j?1011JN40102TWXl0@FWQ045Yh@2][Jd30;6[W@<0[Jf]0P11
JN420;6[W@80@FWQ0P2aZid00`2][Jd0^K:V0;VbYP02045Yh@@0^K:V0P11JN450;VbYP80@FWQ0`2n
]j`3045Yh@`0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0140b<6k0P11
JN400`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0_0060<K0_0@0@FWQ0`36
`;`2045Yh@050<K0_02][Jd0`kfk0<>m^`11JN400`33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ
0`33_K/00`2][Jd0@FWQ0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@080;B`/@040:f]
[@11JN40Wi^P045Yh@<0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]
0`1SH5<20:f][@@0RXEe00D0@FWQ0:f][@2TWXl0Y9j?045Yh@040:BNS`06045Yh@2TWXl0@FWQ045Y
h@2][Jd0/J^M0P11JN430;6[W@80@FWQ0P2aZid2045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH00P11JN44
0;VbYP80@FWQ1@2i/ZH2045Yh@D0_[N/0`11JN4:0;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd7
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k0140b<6k0P11JN400`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]
0<K0_036`;`01036`;`4045Yh@@0a/2l0P11JN420<K0_0030:f][@33_K/0`kfk00T0`kfk0P11JN43
0<>m^`040:f][@11JN40_[Vh0;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`/@080;B`/@040:f][@11
JN40Wi^P045Yh@80Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0308Z5M@80@FWQ0P2TWXl00`11JN40Y9j?0:BN
S`030:BNS`80@FWQ00<0Y9j?0:f][@2aZid00P11JN430;6[W@80@FWQ0P2][Jd2045Yh@80/J^M00<0
[Jf]0;VbYP2i/ZH00P11JN440;VbYP80@FWQ1@2i/ZH2045Yh@D0_[N/00<0@FWQ0;jg[02n]j`01P2n
]j`01@11JN40_[N/0;jg[02n]j`0[Jf]00`0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k
00<0[Jf]045Yh@11JN400`2][JdA0<O1_0030:f][@36`;`0@FWQ0080@FWQ1036`;`2045Yh@@0a/2l
00D0@FWQ0<K0_036`;`0a/2l0:f][@0:0<>m^`80@FWQ1033_K/0102][Jd0@FWQ0:f][@2][Jd:0;ji
^0030:f][@2d/;40];2a00P0];2a00H0[Jf]045Yh@2OVj00@FWQ09nKX02][Jd209nKX0030:f][@1`
KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0
RXEe0:f][@80RXEe0P11JN420:BNS`03045Yh@2TWXl0Y9j?00H0Y9j?00@0[Jf]0;6[W@2aZid0@FWQ
0`2aZid01011JN40/J^M0;6[W@2aZid2045Yh@030:f][@2aZid0[Jf]0080^K:V0P11JN440;VbYP80
@FWQ1@2i/ZH2045Yh@D0_[N/00<0@FWQ0;jg[02n]j`0102n]j`2045Yh@050;jg[011JN40@FWQ0;jg
[02][Jd04@31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd01038`K/0@FWQ045Yh@2][Jd>0<O1_0<0@FWQ0P37`K`3
045Yh@H0a/2l0P11JN440<K0_005045Yh@36`;`0a/2l0<K0_02][Jd02@33_K/2045Yh@@0`kfk0P2]
[Jd00`11JN40_[Vh0;ji^00:0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]045Yh@11JN400P2]
[Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`02
06=PD`060:f][@2:QGD0RXEe08Z5M@2][Jd0RXEe0P11JN400`2TWXl0@FWQ045Yh@080:BNS`040:f]
[@2aZid0/J^M045Yh@<0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN401@2aZid0[Jf]0:f][@2][Jd0
^K:V0080@FWQ102i/ZH2045Yh@D0^K:V0P11JN450;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11JN44
0;jg[080@FWQ1@31^[000`11JN40`KZ`0<6j/00;0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd5
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38
`K/80:f][@P0b<6k0P11JN400`2][Jd0al6l0<O1_0090<O1_0@0@FWQ1037`K`00`2][Jd0a/2l045Y
h@060<K0_080@FWQ0`36`;`2045Yh@<0a/2l00<0[Jf]0<>m^`33_K/01P33_K/2045Yh@80`kfk0`2]
[Jd00`33_K/0[Jf]045Yh@0<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]045Yh@2][Jd01@2O
Vj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0
0`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0@FWQ00<0@FWQ202TWXl01`2][Jd0/J^M0;6[W@2a
Zid0@FWQ0;6[W@11JN40102aZid2045Yh@80/J^M00<0[Jf]0;VbYP2][Jd00P11JN440;VbYP80@FWQ
1@2i/ZH00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`0
102n]j`00`11JN40`KZ`0<6j/0030<6j/003045Yh@31^[00`KZ`00@0@FWQ1`31^[000`2][Jd0`kfc
0<>m/`0>0<>m/`/0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4038`K/2045Yh@030:f]
[@37`K`0al6l00/0al6l0P11JN440<O1_0030:f][@36`;`0@FWQ00H0a/2l0P11JN430<K0_080@FWQ
0`36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ0`2][Jd01P33_K/0@FWQ0<>m^`33_K/0[Jf]045Y
h@`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`11JN40[Jf]09nKX00509nKX0030:f][@1`KWT0L6ii
0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0
RXEe0P2][Jd20:BNS`03045Yh@2TWXl0Y9j?00H0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid00`11JN40
/J^M0;6[W@030;6[W@80@FWQ0P2aZid01@2][Jd0^K:V0;VbYP11JN40^K:V00<0[Jf]00<0^K:V045Y
h@11JN401@2i/ZH00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg
[02n]j`0102n]j`00`2][Jd0@FWQ0<6j/0030<6j/0<0@FWQ0`31^[000`11JN40`KZ`0<6j/0050<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04@38`K/2045Yh@040:f][@37`K`0@FWQ
045Yh@X0al6l0P11JN440<O1_0030:f][@36`;`0@FWQ00H0a/2l0P11JN430<K0_080@FWQ0`36`;`0
0`2][Jd0`kfk0<>m^`050<>m^`03045Yh@2][Jd0`kfk00<0`kfk00D0@FWQ0<>m^`33_K/0[Jf]045Y
h@0<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^
N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5
M@0408Z5M@040:f][@2TWXl0Y9j?045Yh@P0Y9j?00<0[Jf]0;6[W@2aZid0202aZid3045Yh@050;6[
W@2][Jd0^K:V0;VbYP11JN40102i/ZH0102][Jd0@FWQ045Yh@2][Jd40;VbYP03045Yh@2n]j`0_[N/
00@0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@D0_[N/00<0[Jf]0<6j/011JN401031^[000`11
JN40`KZ`0<6j/0040<6j/003045Yh@31^[00`KZ`00@0`KZ`00<0@FWQ0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00d0b<6k00@0@FWQ0<S1^`38`K/0b<6k1011JN42
0<O1_080@FWQ2037`K`2045Yh@@0al6l00<0[Jf]0<K0_011JN401P36`;`2045Yh@<0a/2l0P11JN43
0<K0_0030:f][@33_K/0`kfk0080`kfk0`2][Jd00`11JN40`kfk0<>m^`020<>m^`80@FWQ0P33_K/0
0`2][Jd0@FWQ0;ji^00;0;ji^0030:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0
L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2]
[Jd90:BNS`030:f][@2aZid0/J^M00L0/J^M1011JN40102aZid0[Jf]0;VbYP11JN460;VbYP80@FWQ
00H0^K:V0:f][@2][Jd0[Jf]0;VbYP11JN450;jg[080@FWQ102n]j`2045Yh@D0_[N/00<0[Jf]0<6j
/031^[001031^[000`11JN40`KZ`0<6j/0050<6j/003045Yh@31^[00`KZ`0080`KZ`0P11JN4E0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`050<S1^`<0@FWQ1038`K/00`11JN40b<6k0<S1^`020<S1
^`<0@FWQ1037`K`2045Yh@L0al6l0P11JN440<O1_0030:f][@36`;`0@FWQ00H0a/2l0P11JN430<K0
_080@FWQ0`36`;`01@2][Jd0`kfk0:f][@11JN40[Jf]00<0`kfk00<0@FWQ0<>m^`33_K/00P33_K/2
045Yh@80`kfk00<0[Jf]045Yh@11JN402`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40
];2a0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1S
H5<0Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid0
202aZid2045Yh@030;6[W@11JN40[Jf]0080@FWQ1@2i/ZH2045Yh@D0^K:V00<0[Jf]045Yh@2][Jd0
102n]j`2045Yh@@0_[N/0P11JN450;jg[0030:f][@31^[00`KZ`00@0`KZ`00<0@FWQ0<6j/031^[00
1@31^[000`11JN40`KZ`0<6j/0030<6j/003045Yh@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
4P37`KX010000000al6j0<O1^P2][JdF0<S1^`030:f][@38`K/0b<6k00@0b<6k00@0@FWQ0<S1^`38
`K/0b<6k0P11JN400`38`K/0@FWQ045Yh@040<S1^`80@FWQ00<0[Jf]0<O1_037`K`00`37`K`2045Y
h@H0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN430<K0_080@FWQ00<0a/2l
0:f][@2][Jd00P2][Jd2045Yh@@0`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@80`kfk00<0[Jf]
045Yh@11JN402`2n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX005
09nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2]
[Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[
W@0<0;6[W@80@FWQ1P2i/ZH3045Yh@D0^K:V00<0@FWQ0;jg[02][Jd00`2][Jd2045Yh@@0_[N/0P11
JN450;jg[0030:f][@31^[00`KZ`00`0`KZ`00<0@FWQ0<6j/031^[000`31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/02@38`K/7045Yh@@0b<6k00<0
[Jf]0<S1^`38`K/00`38`K/2045Yh@@0b<6k0`11JN450<S1^`80@FWQ00<0[Jf]0<O1_037`K`00`37
`K`2045Yh@H0al6l0P11JN440<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN400`36`;`0[Jf]
0:f][@02045Yh@040:f][@36`;`0a/2l0:f][@80`kfk00<0@FWQ0<>m^`33_K/00P33_K/01`11JN40
`kfk0<>m^`33_K/0@FWQ0<>m^`11JN400P33_K/00`2][Jd0@FWQ045Yh@0;0;ji^0040:f][@2d/;40
];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V
0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]
102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00D0^K:V0`11JN450;VbYP03045Y
h@2n]j`0_[N/00<0_[N/0P11JN420:f][@80_[N/0P11JN450;jg[0030:f][@31^[00`KZ`00/0`KZ`
0P11JN450<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D04P35_[D4045YhAH0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P040:f][@11JN40@FWQ045Yh@<0
b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`11JN40b<6k0<S1^`050<S1^`030:f][@38`K/0b<6k0080
b<6k0P11JN460<S1^`80@FWQ1@38`K/2045Yh@030:f][@37`K`0al6l00@0al6l0P11JN450<O1_080
@FWQ1037`K`0102][Jd0a/2l045Yh@11JN440<K0_0040:f][@11JN40@FWQ0:f][@<0a/2l0P11JN42
0<K0_0030:f][@33_K/0@FWQ00D0`kfk1@11JN440<>m^`030:f][@11JN40@FWQ00/0_[Vh00@0[Jf]
0;B`/@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V
0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2T
WXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0P11JN400`2i/ZH0@FWQ0;Vb
YP020;VbYP03045Yh@2][Jd0_[N/00@0_[N/0P11JN420;jg[080[Jf]0P11JN450;jg[0030:f][@31
^[00`KZ`00T0`KZ`0`11JN460<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D7045Yh@P0a[ng1P11JN430<Jo]`030:f][@37`KP0al6h01@0al6h00D0[Jf]0<O1^P37`KX0al6j
045Yh@050<O1^P03045Yh@37`KX0al6j00/0al6j00@0@FWQ0<S1^`38`K/0b<6k0P11JN400`38`K/0
@FWQ0<S1^`060<S1^`03045Yh@38`K/0b<6k00D0b<6k00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@H0
b<6k0P11JN450<S1^`80@FWQ00<0[Jf]0<O1_037`K`01037`K`2045Yh@D0al6l0P11JN440<O1_004
0:f][@36`;`0@FWQ045Yh@@0[Jf]00<0a/2l045Yh@11JN401036`;`2045Yh@80a/2l00<0[Jf]0<>m
^`11JN403P33_K/00`2][Jd0@FWQ045Yh@0;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nK
X0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0
Y9j?0:BNS`070:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP060;VbYP80@FWQ00<0^K:V045Yh@2i
/ZH00P2i/ZH00`11JN40[Jf]0;jg[0040;jg[080@FWQ102n]j`2045Yh@@0[Jf]00<0_[N/0:f][@31
^[002031^[05045Yh@H0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@80
@FWQ1@36_kL2045Yh@P0a[ng0P11JN450<Jo]`030:f][@37`KP0al6h00L0al6h1011JN450<O1^005
045Yh@37`KP0al6h0<O1^02][Jd00`37`KX00`11JN40al6j0<O1^P030<O1^P03045Yh@37`KX0al6j
00X0al6j00<0@FWQ0:f][@38`K/01038`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`2]
[Jd0b<6k0<S1^`020<S1^`80@FWQ1P38`K/2045Yh@D0b<6k0P11JN400`2][Jd0al6l0<O1_0040<O1
_080@FWQ1@37`K`2045Yh@80al6l102][Jd2045Yh@D0a/2l0P11JN440<K0_080@FWQ0P36`;`00`2]
[Jd0@FWQ0<>m^`0>0<>m^`030:f][@11JN40@FWQ00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P
00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl20:f][@`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH2045Yh@80^K:V0`11JN400`2i/ZH0
[Jf]0;jg[0040;jg[080@FWQ102n]j`2045Yh@@0_[N/0P2][Jd00`11JN40[Jf]0:f][@050<6j/0<0
@FWQ2@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje0P11JN460<Jo]`80
@FWQ1`36_kL2045Yh@D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@@0al6h0P11JN400`37`KP0
@FWQ045Yh@040<O1^0050:f][@37`KX0al6j0<O1^P11JN401@37`KX00`11JN40al6j0<O1^P090<O1
^P03045Yh@37`KX0[Jf]00H0b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`11JN40b<6k0<S1^`050<S1
^`030:f][@38`K/0b<6k0080b<6k0P11JN460<S1^`80@FWQ1@38`K/2045Yh@030:f][@37`K`0al6l
00@0al6l0P11JN440<O1_0030:f][@11JN40@FWQ0080[Jf]0P37`K`0102][Jd0a/2l045Yh@11JN45
0<K0_080@FWQ1@36`;`5045Yh@l0`kfk00<0[Jf]045Yh@11JN40202n^KP20:f][@030;ji^02][Jd0
];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd90;6[W@030:f][@2i/ZH0^K:V
00H0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/00<0_[N/0P11JN450;jg[003045Yh@2n]j`0_[N/
00<0_[N/00@0@FWQ0<6j/011JN40`KZ`0`2][Jd3045Yh@030:f][@31^[00`KZ`00L0`KZ`00<0@FWQ
0:f][@33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@80@FWQ1`36_kL2045Yh@H0a[ng0P11JN45
0<Jo]`030:f][@37`KP0al6h00@0al6h0P11JN460<O1^0<0@FWQ1@37`KP01P2][Jd0al6j0<O1^P11
JN40al6j045Yh@<0al6j00<0@FWQ0<O1^P11JN402@37`KX2045Yh@030<O1^P2][Jd0b<6k00D0b<6k
00<0@FWQ0<S1^`38`K/01@38`K/00`11JN40b<6k0<S1^`050<S1^`030:f][@38`K/0b<6k0080b<6k
0P11JN460<S1^`80@FWQ1@38`K/2045Yh@030:f][@37`K`0al6l00@0al6l0P11JN440:f][@030<O1
_011JN40@FWQ00@0al6l00@0[Jf]0<K0_011JN40@FWQ1@36`;`2045Yh@P0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0@FWQ045Yh@060;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@03
0:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V
0;VbYP060;VbYP80@FWQ1P2i/ZH0102][Jd0_[N/0;jg[02n]j`4045Yh@D0_[N/0P11JN440;jg[003
0:f][@11JN40@FWQ00@0`KZ`0P11JN420<6j/0L0[Jf]0P31^[000`11JN40[Jf]0<>m/`0D0<>m/`03
0:f][@35_[D0aKje01@0aKje0P11JN470<Jo]`80@FWQ1P36_kL2045Yh@D0a[ng00<0[Jf]0<O1^037
`KP01037`KP2045Yh@L0al6h0P11JN460<O1^0030:f][@37`KX0@FWQ0080@FWQ0`37`KX3045Yh@P0
al6j0P11JN420<O1^P030:f][@38`K/0b<6k00@0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00D0
b<6k00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@D0b<6k0P11JN450<S1^`80@FWQ00<0[Jf]0<O1_037
`K`00`2][Jd2045Yh@H0al6l0P11JN440<O1_0030:f][@11JN40@FWQ00H0a/2l0P11JN480<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^011JN400`2n^KP30:f][@D0_[Vh00<0[Jf]0;B`/@2d
/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3oool005/0/>3V
00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M
0`2][Jd40;6[W@030:f][@2i/ZH0^K:V00H0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/00/0_[N/
00<0@FWQ0;jg[02n]j`00P2n]j`00`2][Jd0@FWQ0<6j/0040<6j/003045Yh@31^[00`KZ`00D0`KZ`
00<0@FWQ0<6j/031^[000P2][Jd00`11JN40[Jf]0:f][@020:f][A80`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D2045Yh@P0a[ng0P11JN450<Jo]`80@FWQ1@36_kL00`2][Jd0al6h0<O1^0040<O1^080@FWQ
1`37`KP2045Yh@H0al6h00<0[Jf]0<O1^P11JN400P11JN430<O1^P<0@FWQ2037`KX2045Yh@80al6j
00<0[Jf]0<S1^`38`K/01038`K/2045Yh@H0b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`2][Jd0b<6k
0<S1^`030<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`020<S1^`030:f][@11JN40@FWQ00<0[Jf]
0`37`K`2045Yh@L0al6l00<0@FWQ0<O1_037`K`00P37`K`00`2][Jd0@FWQ045Yh@040<K0_0@0@FWQ
2@36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0@FWQ0;ji^080[Jf]202n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00
G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
1`2aZid30:f][@030;6[W@2][Jd0^K:V00L0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/00`0_[N/
0P11JN420;jg[003045Yh@31^[00`KZ`00@0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@@0`KZ`
00<0@FWQ0:f][@33_K<00P33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D2045Yh@P0a[ng
0P11JN450<Jo]`80@FWQ1@36_kL00`2][Jd0al6h0<O1^0040<O1^080@FWQ1`37`KP2045Yh@H0al6h
00D0[Jf]0<O1^P11JN40al6j045Yh@030<O1^P<0@FWQ2037`KX2045Yh@80al6j00<0[Jf]0<S1^`38
`K/01038`K/2045Yh@H0b<6k00<0@FWQ0<S1^`38`K/01@38`K/00`2][Jd0b<6k0<S1^`040<S1^`P0
@FWQ102][Jd01038`K/0@FWQ045Yh@2][Jd50<O1_080@FWQ1`37`K`3045Yh@80al6l0P11JN4B0<K0
_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@09
0;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2]
[Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f]
[@L0^K:V0P11JN460;VbYP030:f][@2n]j`0_[N/00h0_[N/0P11JN400`2][Jd0`KZ`0<6j/0040<6j
/003045Yh@31^[00`KZ`00@0`KZ`0P11JN440<6j/003045Yh@2][Jd0`kfc00T0`kfc202][Jd30<>m
/`030:f][@35_[D0aKje01@0aKje0P11JN480<Jo]`80@FWQ1@36_kL2045Yh@D0a[ng00<0[Jf]0<O1
^037`KP01037`KP2045Yh@L0al6h0P11JN460<O1^0050:f][@37`KX0@FWQ0<O1^P11JN400`37`KX0
1011JN40al6j0<O1^P11JN460<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ1P38
`K/2045Yh@H0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd20<S1^`03045Yh@38`K/0b<6k00<0b<6k
0P11JN400`2][Jd0al6l0<O1_0030<O1_003045Yh@37`K`0al6l00H0al6l00<0@FWQ0<O1_037`K`0
0`11JN4C0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a
00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BN
S`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd20;VbYP<0@FWQ1P2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j/031^[000P31
^[02045Yh@D0`KZ`00<0@FWQ0:f][@33_K<04@33_K<90:f][A40aKje0P11JN480<Jo]`80@FWQ1@36
_kL2045Yh@D0a[ng00<0[Jf]0<O1^037`KP01@37`KP2045Yh@H0al6h0P11JN460<O1^0050:f][@11
JN40@FWQ0<O1^P11JN400P37`KX2045Yh@80al6j00<0@FWQ0<O1^P37`KX01037`KX2045Yh@<0al6j
00@0[Jf]0<S1^`38`K/0b<6k1`11JN440<S1^`80@FWQ00<0b<6k0:f][@2][Jd01`2][Jd:0<S1^`03
045Yh@38`K/0b<6k00<0b<6k0`11JN440<O1_080@FWQ2037`K`00`11JN40al6l0<O1_0020<O1_003
0:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f]
[@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]
0P11JN460;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001P31^[04045Yh@030<6j
/011JN40`KZ`00@0`KZ`00<0@FWQ0:f][@33_K<05033_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]
1@35_[D2045Yh@P0a[ng0P11JN450<Jo]`80@FWQ1@36_kL00`2][Jd0al6h0<O1^0060<O1^003045Y
h@37`KP0al6h00@0al6h0P11JN460<O1^0030:f][@11JN40@FWQ0080al6j00@0@FWQ0<O1^P11JN40
@FWQ0P37`KX00`11JN40al6j0<O1^P040<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`030<S1^`T0
[Jf]0P11JN400`2][Jd0b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k00<0b<6k0P11JN460<S1^`03
045Yh@38`K/0b<6k00<0b<6k0P11JN400`2][Jd0@FWQ0<O1_0020<O1_003045Yh@37`K`0al6l00L0
al6l00<0@FWQ0<O1_037`K`00`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0
`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0
/>3V0@3oool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
1P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[00:0;jg[0030:f]
[@31^[00`KZ`00/0`KZ`00<0@FWQ0<6j/031^[000P31^[02045Yh@030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D03`35_[D50:f][@80@FWQ202][Jd2045Yh@D0a[ng0P11JN450<Jo]`030:f]
[@37`KP0al6h00L0al6h0`11JN430<O1^080@FWQ1P37`KP00`2][Jd0@FWQ0<O1^P020<O1^P04045Y
h@37`KX0@FWQ045Yh@80al6j00<0@FWQ0:f][@2][Jd0102][Jd2045Yh@80[Jf]00<000000:f][@2]
[Jd0102][Jd90<S1^`80@FWQ1@38`K/00`11JN40[Jf]0<S1^`040<S1^`80@FWQ1@38`K/00`11JN40
b<6k0<S1^`040<S1^`80@FWQ00<0[Jf]0<O1_011JN400P11JN4:0<O1_003045Yh@37`K`0al6l00<0
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00
HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
2@2i/ZH40:f][@030;VbYP2][Jd0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`02P2n]j`00`2][Jd0`KZ`
0<6j/00@0<6j/0<0@FWQ5@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@80@FWQ2036_kL2045Yh@D0[Jf]
0P11JN4B0:f][@D0@FWQ1`2][Jd01P11JN40[Jf]0:f][@2][Jd0@FWQ0:f][@80@FWQ0`2][Jd00`11
JN40al6j0<O1^P030<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`0<0<S1^`80@FWQ1038`K/00`11
JN40b<6k045Yh@060<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/00P38`K/4045Y
h@030:f][@37`K`0al6l00`0al6l00<0@FWQ0<O1_037`K`00`37`K`00`2][Jd0a/2l0<K0_0060<K0
_003045Yh@36`;`0a/2l00L0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh
00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`03
0:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@@0_[N/0P11JN4;0;jg[003
0:f][@31^[00`KZ`0100`KZ`0`11JN4E0<>m/`030:f][@35_[D0aKje01@0aKje0P11JN480<Jo]`80
@FWQ1@36_kL3045Yh@@0a[ng00<0[Jf]0<O1^037`KP03@37`KP2045Yh@H0al6h00<0[Jf]045Yh@37
`KX00P37`KX01011JN40al6j045Yh@11JN430<O1^P03045Yh@37`KX0al6j00<0al6j0P11JN430<O1
^P030:f][@38`K/0b<6k00`0b<6k0`11JN440<S1^`80@FWQ1`38`K/5045Yh@T0b<6k00<0[Jf]0<O1
_037`K`03037`K`00`11JN40al6l0<O1_0030<O1_0030:f][@36`;`0a/2l00D0a/2l0P11JN470<K0
_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3P
iP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]00<0@FWQ0;jg[02n]j`02P2n]j`00`2][Jd0
`KZ`0<6j/00@0<6j/0<0@FWQ5@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@80@FWQ2036_kL2045Yh@D0
a[ng0`11JN440<Jo]`03045Yh@37`KP0al6h00D0al6h0P11JN460<O1^003045Yh@37`KP0al6h00D0
al6h00<0[Jf]045Yh@37`KX00P37`KX00`11JN40al6j045Yh@040<O1^P03045Yh@37`KX0al6j00<0
al6j0P11JN430<O1^P030:f][@38`K/0b<6k00`0b<6k0P11JN400`38`K/0@FWQ0<S1^`020<S1^`03
045Yh@2][Jd0b<6k01@0b<6k00<0[Jf]0<O1_037`K`03037`K`00`11JN40al6l0<O1_0030<O1_003
0:f][@36`;`0a/2l00H0a/2l00<0@FWQ0<K0_036`;`01@2][Jd20<K0_0030:f][@33_K/0`kfk00d0
`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]CP2`h>H10?ooo`00
I`2`h>H20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0100`KZ`0`11JN4E0<>m/`030:f]
[@35_[D0aKje01@0aKje0P11JN480<Jo]`80@FWQ1@36_kL3045Yh@@0a[ng0P11JN460<O1^080@FWQ
1P37`KP00`11JN40al6h0<O1^0050<O1^003045Yh@37`KX0al6j00<0al6j0P11JN440<O1^P03045Y
h@37`KX0al6j00<0al6j0P11JN430<O1^P030:f][@38`K/0b<6k00T0b<6k1@11JN420<S1^`<0@FWQ
00<0b<6k0:f][@38`K/05038`K/00`2][Jd0al6l0<O1_00<0<O1_003045Yh@37`K`0al6l00<0al6l
00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh
0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/
102][Jd50;jg[0030:f][@31^[00`KZ`0100`KZ`0`11JN4E0<>m/`030:f][@35_[D0aKje01@0aKje
0P11JN480<Jo]`80@FWQ1@36_kL2045Yh@030<Jo]`11JN40a[ng0080a[ng0P11JN470<O1^003045Y
h@37`KP0al6h00<0al6h00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6j0<O1^P030<O1^P80@FWQ
1@37`KX00`11JN40al6j0<O1^P020<O1^P80@FWQ0`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03037`K`00`11JN40al6l0<O1_0030<O1_0030:f]
[@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004@31^[03045YhAD0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D2045Yh@P0a[ng0P11JN430<Jo]`@0@FWQ0P36_kL4045Yh@T0al6h
1@11JN460<O1^0L0@FWQ0P37`KX2045Yh@80al6j1P11JN420<O1^P80@FWQ0`37`KX00`2][Jd0b<6k
0<S1^`050<S1^`03045Yh@38`K/0b<6k00`0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00;0<O1_080@FWQ0`37`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]3`31^[000`11JN40`KZ`045Yh@0E0<>m/`030:f][@35
_[D0aKje01@0aKje0P11JN480<Jo]`03045Yh@36_kL0a[ng00/0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0@0<O1^P80@FWQ0P37`KX00`2][Jd0b<6k0<S1^`050<S1^`03045Yh@38
`K/0000000`0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0090<O1_080@FWQ1@2]
[Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2@31^[000`11JN40[Jf]0<>m
/`0D0<>m/`030:f][@35_[D0aKje01@0aKje0P11JN480<Jo]`03045Yh@36_kL0a[ng00/0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0@0<O1^P80@FWQ0P37`KX00`2][Jd0b<6k0<S1
^`040<S1^`80@FWQ3P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1P2]
[Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd20<6j/003045Yh@2][Jd0
`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D2045Yh@L0a[ng0P11JN4=0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX04037`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/01038`K/2
045Yh@h0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ
0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D2045Y
h@L0a[ng0P11JN4=0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX04@37`KX2045Y
h@030<O1^P2][Jd0b<6k00@0b<6k0`11JN4>0<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdB0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji
^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m
/`030:f][@35_[D0aKje01@0aKje0P11JN460<Jo]`80@FWQ3P36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j0180al6j0P11JN400`2][Jd0b<6k0<S1^`030<S1^`<0@FWQ3P38`K/00`2]
[Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0
/>3V0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@80
@FWQ1P36_kL2045Yh@h0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0C0<O1^P80
@FWQ1038`K/01011JN40b<6k0<S1^`11JN4>0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/3
0:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]3P35_[D5045Yh@D0a[ng0P11JN4?0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX5045Yh@<0b<6k00<0@FWQ0<S1
^`38`K/01`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0@FWQ045Yh@04045YhA40a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V
0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f]
[A00_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l00L0a/2l102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX03037`KX00`000000al6j
0<O1^P050<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0
/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3P
iP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]
X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H1
0?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52096 .33862 m
.53255 .33858 L
s
.50275 .33845 m
.50606 .34075 L
s
.48624 .33804 m
.50275 .33845 L
s
.50275 .33845 m
.50771 .34077 L
s
.50771 .34077 m
.51102 .34532 L
s
.50606 .34075 m
.50936 .3453 L
s
.51102 .34532 m
.51267 .34985 L
s
.55735 .34035 m
.56064 .33799 L
s
.56064 .33799 m
.56558 .33782 L
s
.5557 .3404 m
.56064 .33799 L
s
.50936 .3453 m
.51101 .34983 L
s
.55407 .34496 m
.5557 .3404 L
s
.55572 .34491 m
.55735 .34035 L
s
0 0 0 r
.59492 .33182 m
.59653 .3285 L
s
.5982 .33161 m
.59653 .3285 L
s
.255 .412 .882 r
.56558 .33782 m
.56888 .33994 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51267 .34985 m
.51432 .35664 L
s
.51101 .34983 m
.51266 .35663 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56888 .33994 m
.57219 .34432 L
s
.55572 .34491 m
.55574 .34943 L
s
.55407 .34496 m
.55409 .34947 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57707 .33732 m
.57871 .33724 L
s
.57381 .33973 m
.57707 .33732 L
s
.57545 .33966 m
.57707 .33732 L
s
.57219 .34432 m
.57381 .33973 L
s
.55409 .34947 m
.55576 .35395 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49267 .38582 m
.49284 .33823 L
s
.49101 .38578 m
.49119 .33819 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55574 .34943 m
.55741 .3539 L
s
.57383 .34425 m
.57545 .33966 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5276 .35666 m
.52926 .36345 L
s
.52593 .33861 m
.52594 .37026 L
s
.52758 .33861 m
.5276 .37026 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51431 .36797 m
.51432 .35664 L
s
.51265 .36796 m
.51266 .35663 L
s
.57219 .34432 m
.57232 .3647 L
s
.57383 .34425 m
.57393 .36009 L
s
.55576 .35395 m
.56072 .35606 L
s
.55741 .3539 m
.56072 .35606 L
s
.52926 .36345 m
.53259 .36796 L
s
.56072 .35606 m
.57063 .35796 L
s
.53923 .36562 m
.54088 .36333 L
s
.54088 .36333 m
.54254 .36557 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53923 .36562 m
.54089 .36786 L
s
.54254 .36557 m
.54255 .36783 L
s
.51264 .37477 m
.51431 .36797 L
s
.53259 .36796 m
.53591 .37019 L
s
.51097 .37475 m
.51265 .36796 L
s
.55579 .36301 m
.5558 .36527 L
s
.55579 .36301 m
.55745 .36296 L
s
.55745 .36296 m
.55746 .36523 L
s
.5409 .37013 m
.54255 .36783 L
s
.52095 .37027 m
.5276 .37026 L
s
.53591 .37019 m
.5409 .37013 L
s
.57063 .35796 m
.57229 .36016 L
s
.5558 .36527 m
.55747 .3675 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55747 .3675 m
.56079 .36967 L
s
.57232 .3647 m
.57393 .36009 L
s
.51097 .3793 m
.51264 .37477 L
s
.5093 .37928 m
.51097 .37475 L
s
.56079 .36967 m
.5674 .36944 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57068 .36704 m
.57232 .3647 L
s
.50763 .38381 m
.51097 .3793 L
s
.50597 .38379 m
.5093 .37928 L
s
.5674 .36944 m
.57068 .36704 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58877 .36845 m
.59346 .3432 L
s
0 0 0 r
.59649 .35851 m
.59654 .35705 L
s
.255 .412 .882 r
.58713 .36854 m
.5934 .33642 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59703 .35669 m
.59705 .35705 L
s
.59851 .38538 m
.59875 .38998 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60019 .36776 m
.60636 .33553 L
s
.5934 .33642 m
.60019 .36776 L
s
.60182 .36765 m
.60643 .34232 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50264 .38602 m
.50763 .38381 L
s
.50264 .38602 m
.50597 .38379 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59544 .39017 m
.59553 .38749 L
s
.255 .412 .882 r
.48603 .38564 m
.50264 .38602 L
s
.58221 .36879 m
.59367 .36817 L
s
0 0 0 r
.59706 .38644 m
.59709 .39008 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63039 .33572 m
.63511 .33297 L
s
.62728 .34056 m
.63039 .33572 L
s
.62574 .34525 m
.62728 .34056 L
s
.63198 .33556 m
.63511 .33297 L
s
.62887 .34041 m
.63198 .33556 L
s
.62733 .34511 m
.62887 .34041 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62423 .35222 m
.62574 .34525 L
s
.63511 .33297 m
.63826 .33264 L
s
.62583 .35208 m
.62733 .34511 L
s
.63826 .33264 m
.64301 .3344 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6083 .3672 m
.61799 .36645 L
s
.60636 .33553 m
.61315 .36683 L
s
.62423 .35222 m
.62437 .36362 L
s
.62583 .35208 m
.62597 .36348 L
s
.64301 .3344 m
.64621 .33859 L
s
.62437 .36362 m
.62606 .37033 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39758 .33157 m
.3991 .33403 L
s
.39598 .33366 m
.39758 .33157 L
s
.39751 .33612 m
.3991 .33403 L
s
.62597 .36348 m
.62766 .37019 L
s
.39598 .33366 m
.39751 .33612 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6469 .34962 m
.64694 .35263 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6461 .33177 m
.64638 .34999 L
s
.64766 .33159 m
.64795 .34982 L
s
.62606 .37033 m
.62772 .37477 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64167 .35051 m
.65262 .34928 L
s
.62766 .37019 m
.62931 .37462 L
s
.65698 .33045 m
.66772 .32903 L
s
.62772 .37477 m
.63097 .37906 L
s
.39733 .34752 m
.39848 .37517 L
s
.39534 .37483 m
.39733 .34752 L
s
.62931 .37462 m
.63256 .37891 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63097 .37906 m
.63577 .38091 L
s
.38361 .33212 m
.38511 .3346 L
s
.38499 .34145 m
.38511 .3346 L
s
.38058 .32943 m
.38361 .33212 L
s
.63256 .37891 m
.63577 .38091 L
s
.37449 .32858 m
.38058 .32943 L
s
.38345 .34125 m
.38503 .33916 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39691 .375 m
.39712 .36124 L
s
.38341 .34354 m
.38499 .34145 L
s
.63577 .38091 m
.63894 .3806 L
s
.38034 .34313 m
.38345 .34125 L
s
.3803 .34542 m
.38341 .34354 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64819 .36584 m
.6484 .37962 L
s
.63894 .3806 m
.64365 .37782 L
s
.64673 .37289 m
.64819 .36584 L
s
.66313 .32965 m
.66368 .3617 L
s
.6616 .32986 m
.66214 .36189 L
s
.37142 .33043 m
.37449 .32858 L
s
0 0 0 r
.68601 .31901 m
.68662 .31846 L
s
.255 .412 .882 r
.64365 .37782 m
.64673 .37289 L
s
.64673 .37289 m
.6484 .37962 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37263 .34667 m
.38034 .34313 L
s
.39684 .3796 m
.39848 .37517 L
s
.38318 .35728 m
.3848 .35289 L
s
.38464 .36207 m
.3848 .35289 L
s
.66345 .34793 m
.6651 .35461 L
s
.37259 .34897 m
.3803 .34542 L
s
.36986 .33249 m
.37142 .33043 L
s
.65751 .36246 m
.66368 .3617 L
s
.39534 .37483 m
.39684 .3796 L
s
.36844 .32769 m
.36986 .33249 L
s
.36827 .33685 m
.36844 .32769 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3816 .35938 m
.38318 .35728 L
s
.38318 .35728 m
.38464 .36207 L
s
.36827 .33685 m
.36986 .33249 L
s
.6651 .35461 m
.66825 .3588 L
s
.37849 .36128 m
.3816 .35938 L
s
.36956 .34854 m
.37263 .34667 L
s
.36952 .35084 m
.37259 .34897 L
s
.37238 .36046 m
.37849 .36128 L
s
.66825 .3588 m
.67134 .36069 L
s
.36801 .35062 m
.36956 .34854 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36796 .35292 m
.36952 .35084 L
s
.67134 .36069 m
.6759 .36006 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36196 .37797 m
.36199 .37822 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6743 .35567 m
.67586 .35776 L
s
.6743 .35567 m
.67577 .35315 L
s
.67577 .35315 m
.67733 .35524 L
s
.36792 .35522 m
.36801 .35062 L
s
.36939 .35774 m
.37238 .36046 L
s
.68741 .33296 m
.68879 .32813 L
s
.68741 .33296 m
.6875 .33755 L
s
.35498 .32786 m
.35784 .33294 L
s
.36792 .35522 m
.36939 .35774 L
s
.67733 .35524 m
.67737 .35754 L
s
.68889 .33272 m
.69027 .32789 L
s
.35061 .32482 m
.35498 .32786 L
s
.6759 .36006 m
.67737 .35754 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6875 .33755 m
.68908 .34191 L
s
.68889 .33272 m
.68898 .33731 L
s
.69027 .32789 m
.69317 .3251 L
s
.68879 .32813 m
.69317 .3251 L
s
.69317 .3251 m
.69756 .32433 L
s
.68898 .33731 m
.69056 .34167 L
s
.34769 .32431 m
.35061 .32482 L
s
.68908 .34191 m
.69356 .34349 L
s
.69756 .32433 m
.70052 .32611 L
s
.34473 .32609 m
.34769 .32431 L
s
.34328 .32583 m
.34769 .32431 L
s
.69056 .34167 m
.69356 .34349 L
s
.35747 .35134 m
.35752 .34903 L
s
.35608 .34649 m
.35752 .34903 L
s
.35455 .34856 m
.35608 .34649 L
s
.35441 .35548 m
.35747 .35134 L
s
.68927 .35112 m
.68931 .35343 L
s
.68927 .35112 m
.69075 .35089 L
s
.35455 .34856 m
.35598 .3511 L
s
.70052 .32611 m
.70352 .33019 L
s
.34174 .33017 m
.34473 .32609 L
s
.68931 .35343 m
.69084 .3555 L
s
.69075 .35089 m
.6908 .3532 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36045 .37772 m
.36069 .37957 L
s
.5 Mabswid
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34029 .3299 m
.34328 .32583 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3514 .35732 m
.35441 .35548 L
s
.71158 .30555 m
.72139 .3035 L
s
.70486 .32532 m
.70767 .32248 L
s
.70352 .33019 m
.70486 .32532 L
s
.34014 .33682 m
.34174 .33017 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70352 .33019 m
.70398 .35098 L
s
.69084 .3555 m
.69385 .35734 L
s
.69356 .34349 m
.70238 .34429 L
s
.70629 .32505 m
.70767 .32248 L
s
.70496 .32993 m
.70629 .32505 L
s
.70767 .32248 m
.7091 .32221 L
s
.70496 .32993 m
.70532 .34609 L
s
.3387 .33656 m
.34029 .3299 L
s
.69385 .35734 m
.69972 .35636 L
s
.347 .35659 m
.3514 .35732 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71581 .30468 m
.71697 .35323 L
s
.71721 .30439 m
.71838 .35296 L
s
.34004 .34144 m
.34014 .33682 L
s
.70238 .34429 m
.70388 .34635 L
s
.32347 .31961 m
.3333 .32162 L
s
.34413 .35378 m
.347 .35659 L
s
.34267 .35352 m
.347 .35659 L
s
.33859 .34118 m
.3387 .33656 L
s
.34004 .34144 m
.34133 .34864 L
s
.69972 .35636 m
.70258 .35355 L
s
.34133 .34864 m
.34413 .35378 L
s
.33859 .34118 m
.33988 .34838 L
s
.70398 .35098 m
.70532 .34609 L
s
.70258 .35355 m
.70398 .35098 L
s
.33988 .34838 m
.34267 .35352 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32829 .35321 m
.32906 .32078 L
s
.32688 .35293 m
.32766 .32049 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71776 .32745 m
.72045 .32224 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72045 .32224 m
.72318 .31934 L
s
.72318 .31934 m
.72594 .31875 L
s
.71271 .35404 m
.71838 .35296 L
s
.72594 .31875 m
.72875 .32045 L
s
.72594 .31875 m
.73011 .32015 L
s
.30844 .31623 m
.31794 .31841 L
s
.71821 .34598 m
.72113 .35007 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32267 .3521 m
.32829 .35321 L
s
.31318 .34307 m
.31384 .31749 L
s
.72113 .35007 m
.72398 .35184 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73011 .32015 m
.73296 .32417 L
s
.72875 .32045 m
.7316 .32448 L
s
.31182 .34277 m
.31249 .31718 L
s
.7316 .32448 m
.73314 .33114 L
s
.32649 .36925 m
.32796 .36719 L
s
.3266 .36458 m
.32796 .36719 L
s
.32513 .36665 m
.3266 .36458 L
s
.73296 .32417 m
.73449 .33084 L
s
.72398 .35184 m
.72676 .35127 L
s
.32513 .36665 m
.32649 .36925 L
s
.73314 .33114 m
.73326 .3358 L
s
.72676 .35127 m
.72946 .34835 L
s
.72676 .35127 m
.73083 .34806 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73449 .33084 m
.73461 .33549 L
s
.73208 .34309 m
.73326 .3358 L
s
.72946 .34835 m
.73208 .34309 L
s
.3117 .34743 m
.31318 .34307 L
s
.73344 .34279 m
.73461 .33549 L
s
.73083 .34806 m
.73344 .34279 L
s
.31034 .34713 m
.31182 .34277 L
s
.74215 .31497 m
.75129 .31263 L
s
.29398 .3126 m
.30311 .31494 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30758 .34887 m
.3117 .34743 L
s
.30758 .34887 m
.31034 .34713 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29781 .36314 m
.29917 .31395 L
s
.2965 .36283 m
.29786 .31361 L
s
.30489 .34825 m
.30758 .34887 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30097 .34497 m
.30489 .34825 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7474 .31365 m
.74877 .36286 L
s
.7461 .31398 m
.74745 .36317 L
s
.29846 .33964 m
.30097 .34497 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28335 .30224 m
.28335 .302 L
s
.5 Mabswid
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74812 .33935 m
.75085 .34339 L
s
.74348 .3641 m
.74877 .36286 L
s
.75085 .34339 m
.75479 .34476 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7564 .31124 m
.76515 .30874 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76018 .31018 m
.76094 .33601 L
s
.76143 .30982 m
.7622 .33566 L
s
.29258 .36188 m
.29781 .36314 L
s
.28252 .31177 m
.28488 .31718 L
s
.28488 .31718 m
.28593 .32456 L
s
.28579 .32926 m
.28593 .32456 L
s
.2789 .30834 m
.28252 .31177 L
s
.28129 .31141 m
.28363 .31682 L
s
.28363 .31682 m
.28467 .32422 L
s
.75479 .34476 m
.75735 .34409 L
s
.28454 .32891 m
.28467 .32422 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28375 .33192 m
.28376 .33176 L
s
.28245 .33268 m
.28249 .33135 L
s
.5 Mabswid
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28433 .33597 m
.28579 .32926 L
s
.2789 .30834 m
.28129 .31141 L
s
.26745 .2881 m
.27575 .29082 L
s
.28308 .33563 m
.28454 .32891 L
s
.75735 .34409 m
.75982 .34106 L
s
.75735 .34409 m
.76108 .34072 L
s
.27646 .3076 m
.2789 .30834 L
s
.75982 .34106 m
.76094 .33601 L
s
.28169 .34 m
.28433 .33597 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76108 .34072 m
.7622 .33566 L
s
.27397 .30921 m
.27646 .3076 L
s
.28044 .33965 m
.28308 .33563 L
s
.27062 .33917 m
.27216 .28966 L
s
.77003 .30726 m
.77835 .3046 L
s
.26943 .33881 m
.27097 .28928 L
s
.2779 .34132 m
.28169 .34 L
s
.27143 .31316 m
.27397 .30921 L
s
.2779 .34132 m
.28044 .33965 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28154 .36336 m
.28158 .36202 L
s
.28285 .36257 m
.28286 .3624 L
s
.5 Mabswid
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27545 .34061 m
.2779 .34132 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77482 .30576 m
.77585 .33884 L
s
.77363 .30614 m
.77465 .33921 L
s
.2731 .33753 m
.27545 .34061 L
s
.77104 .34029 m
.77585 .33884 L
s
.27084 .33206 m
.2731 .33753 L
s
.26345 .3034 m
.26461 .30379 L
s
.26109 .30497 m
.26345 .3034 L
s
.26223 .30537 m
.26345 .3034 L
s
.26588 .33771 m
.27062 .33917 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26094 .3097 m
.26223 .30537 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77389 .35382 m
.77517 .35584 L
s
.77389 .35382 m
.77502 .35108 L
s
.2598 .30931 m
.26109 .30497 L
s
.77502 .35108 m
.77629 .35311 L
s
.78434 .30974 m
.78646 .30421 L
s
.78343 .31724 m
.78434 .30974 L
s
.2604 .32631 m
.26094 .3097 L
s
.77517 .35584 m
.77629 .35311 L
s
.78343 .31724 m
.78358 .32198 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78646 .30421 m
.78973 .30063 L
s
.78548 .30935 m
.78758 .30381 L
s
.78457 .31685 m
.78548 .30935 L
s
.2577 .30377 m
.2598 .30931 L
s
.25911 .33069 m
.2598 .30931 L
s
.78457 .31685 m
.78473 .32159 L
s
.78358 .32198 m
.78496 .32872 L
s
.78758 .30381 m
.78973 .30063 L
s
.25555 .3006 m
.2577 .30377 L
s
.78473 .32159 m
.7861 .32834 L
s
.78973 .30063 m
.79193 .29982 L
s
.25226 .29937 m
.25555 .3006 L
s
.25911 .33069 m
.2604 .32631 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78496 .32872 m
.78739 .33272 L
s
.25821 .32316 m
.25926 .32593 L
s
.7861 .32834 m
.78851 .33233 L
s
.25162 .3184 m
.25821 .32316 L
s
.79193 .29982 m
.79527 .30095 L
s
.2579 .33268 m
.25911 .33069 L
s
.25002 .30092 m
.25226 .29937 L
s
.24894 .3005 m
.25226 .29937 L
s
.78739 .33272 m
.79083 .33395 L
s
.25557 .3343 m
.2579 .33268 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78851 .33233 m
.79083 .33395 L
s
.79527 .30095 m
.79757 .30488 L
s
.24878 .30526 m
.25002 .30092 L
s
.25114 .33273 m
.25557 .3343 L
s
.24772 .30484 m
.24894 .3005 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79083 .33395 m
.79414 .33277 L
s
.24953 .31521 m
.25162 .3184 L
s
.24846 .3148 m
.25162 .3184 L
s
.24862 .31003 m
.24878 .30526 L
s
.24862 .31003 m
.24953 .31521 L
s
.24755 .30961 m
.24772 .30484 L
s
.24755 .30961 m
.24846 .3148 L
s
.79414 .33277 m
.79624 .32958 L
s
.79599 .32241 m
.79699 .31961 L
s
.79599 .32241 m
.79715 .3244 L
s
.24905 .32955 m
.25114 .33273 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79699 .31961 m
.79814 .3216 L
s
.24814 .32436 m
.24921 .32476 L
s
.24913 .32715 m
.24921 .32476 L
s
.79624 .32958 m
.79822 .32399 L
s
.24806 .32675 m
.24905 .32955 L
s
.24806 .32675 m
.24814 .32436 L
s
.79814 .3216 m
.79822 .32399 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80461 .29476 m
.80579 .2991 L
s
.80461 .29476 m
.80494 .30432 L
s
.80494 .30432 m
.80579 .2991 L
s
.80579 .2991 m
.80671 .29628 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80671 .29628 m
.80862 .29301 L
s
.80862 .29301 m
.81252 .29124 L
s
.80545 .3187 m
.80638 .31588 L
s
.80545 .3187 m
.80561 .32351 L
s
.80553 .32111 m
.80646 .31828 L
s
.80638 .31588 m
.80831 .31263 L
s
.80561 .32351 m
.80671 .3255 L
s
.80646 .31828 m
.80839 .31503 L
s
.23875 .32065 m
.23968 .32347 L
s
.2396 .32588 m
.23968 .32347 L
s
.22806 .28894 m
.23471 .29209 L
s
.23849 .32787 m
.2396 .32588 L
s
.23765 .32264 m
.23875 .32065 L
s
0 0 0 r
.2218 .27848 m
.22257 .27887 L
s
.255 .412 .882 r
.80831 .31263 m
.81304 .30565 L
s
.80671 .3255 m
.80882 .32707 L
s
.80839 .31503 m
.81313 .30806 L
s
.23765 .32264 m
.23858 .32546 L
s
.23548 .32661 m
.23849 .32787 L
s
.81252 .29124 m
.81452 .29274 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2306 .32449 m
.23182 .29075 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80882 .32707 m
.81276 .32538 L
s
.22965 .32406 m
.23087 .2903 L
s
.81452 .29274 m
.81555 .29469 L
s
.2336 .32335 m
.23548 .32661 L
s
.81304 .30565 m
.81487 .30236 L
s
.81313 .30806 m
.81495 .30477 L
s
.81555 .29469 m
.81581 .30192 L
s
.23182 .31767 m
.2336 .32335 L
s
.81487 .30236 m
.81572 .29951 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81495 .30477 m
.81581 .30192 L
s
.23112 .30999 m
.23182 .31767 L
s
.81276 .32538 m
.81461 .32211 L
s
.81461 .32211 m
.81548 .31926 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81548 .31926 m
.81625 .31399 L
s
.81548 .31926 m
.8166 .32367 L
s
.22683 .32276 m
.2306 .32449 L
s
.81625 .31399 m
.8166 .32367 L
s
.82187 .28909 m
.82266 .28621 L
s
.82187 .28909 m
.82284 .29104 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82266 .28621 m
.82363 .28816 L
s
.22192 .30553 m
.22264 .28617 L
s
.82284 .29104 m
.82363 .28816 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22104 .30507 m
.22177 .2857 L
s
.21845 .3037 m
.22461 .30688 L
s
.21994 .28718 m
.2215 .29295 L
s
.82329 .30315 m
.82526 .3319 L
s
.82329 .30315 m
.82349 .33278 L
s
.21749 .28334 m
.21994 .28718 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82383 .31772 m
.82438 .33234 L
s
.21584 .28238 m
.21749 .28334 L
s
.22075 .33719 m
.22129 .32254 L
s
.82349 .33278 m
.82456 .33723 L
s
.21412 .28385 m
.21584 .28238 L
s
.21332 .28337 m
.21584 .28238 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22014 .32942 m
.22129 .32254 L
s
.21821 .33342 m
.22014 .32942 L
s
.22014 .32942 m
.22075 .33719 L
s
.82456 .33723 m
.82526 .3319 L
s
.21234 .28776 m
.21412 .28385 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21156 .28727 m
.21332 .28337 L
s
.21556 .33454 m
.21821 .33342 L
s
.21137 .29215 m
.21234 .28776 L
s
.21059 .29167 m
.21156 .28727 L
s
.21031 .29901 m
.21137 .29215 L
s
.21389 .33365 m
.21556 .33454 L
s
.20954 .29853 m
.21059 .29167 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21235 .33029 m
.21389 .33365 L
s
.21154 .32984 m
.21389 .33365 L
s
.20984 .31126 m
.21031 .29901 L
s
.20906 .31079 m
.20954 .29853 L
s
.21093 .32446 m
.21235 .33029 L
s
0 0 0 r
.19992 .26861 m
.19998 .26855 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20984 .31126 m
.21033 .31909 L
s
.21014 .32401 m
.21154 .32984 L
s
.21033 .31909 m
.21093 .32446 L
s
.20906 .31079 m
.20955 .31863 L
s
.20955 .31863 m
.21014 .32401 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19865 .26491 m
.19868 .26408 L
s
.5 Mabswid
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2017 .30848 m
.20596 .31135 L
s
.20238 .27351 m
.20379 .30992 L
s
.19902 .30654 m
.20209 .28087 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19736 .29691 m
.19748 .29391 L
s
.5 Mabswid
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19837 .30605 m
.20238 .27351 L
s
.19727 .26941 m
.19837 .30605 L
s
.1935 .30209 m
.19727 .26941 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19408 .30258 m
.19697 .27681 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19183 .30058 m
.19587 .30408 L
s
.19166 .26417 m
.19218 .2647 L
s
.19054 .26559 m
.19166 .26417 L
s
.19105 .26612 m
.19166 .26417 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19034 .27057 m
.19105 .26612 L
s
.18985 .27004 m
.19054 .26559 L
s
.18962 .28803 m
.19034 .27057 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18909 .26399 m
.18985 .27004 L
s
.18892 .29252 m
.18985 .27004 L
s
.18827 .26043 m
.18909 .26399 L
s
.18892 .29252 m
.18962 .28803 L
s
.18696 .25881 m
.18827 .26043 L
s
.18874 .28449 m
.18912 .28751 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18613 .27884 m
.18874 .28449 L
s
.18833 .29451 m
.18892 .29252 L
s
0 0 0 r
.18315 .24902 m
.18343 .25314 L
s
.255 .412 .882 r
.18728 .296 m
.18833 .29451 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18603 .26022 m
.18696 .25881 L
s
.18563 .25968 m
.18696 .25881 L
s
.1855 .29393 m
.18728 .296 L
s
.18542 .26469 m
.18603 .26022 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85881 .25832 m
.86248 .25284 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1854 .27527 m
.18613 .27884 L
s
.185 .27474 m
.18613 .27884 L
s
.18503 .26415 m
.18563 .25968 L
s
.86001 .25668 m
.86223 .30962 L
s
.18521 .26971 m
.18542 .26469 L
s
.86039 .25614 m
.86261 .30911 L
s
.18521 .26971 m
.1854 .27527 L
s
.18482 .26918 m
.18503 .26415 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18071 .31776 m
.18091 .31136 L
s
.18179 .28353 m
.18198 .27785 L
s
.18157 .28395 m
.1819 .2777 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18477 .29037 m
.1855 .29393 L
s
.185 .27474 m
.18482 .26918 L
s
0 0 0 r
.18027 .31725 m
.18055 .31068 L
s
.255 .412 .882 r
.18458 .28481 m
.18498 .28533 L
s
.18487 .28785 m
.18498 .28533 L
s
.18447 .28733 m
.18477 .29037 L
s
.18447 .28733 m
.18458 .28481 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86101 .31115 m
.86473 .30603 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86248 .25284 m
.8632 .25425 L
s
.86248 .25284 m
.8635 .2537 L
s
.8632 .25425 m
.864 .2582 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8635 .2537 m
.86427 .25765 L
s
.18139 .28003 m
.1816 .2831 L
s
.18149 .28563 m
.1816 .2831 L
s
.864 .2582 m
.86449 .26271 L
s
.18107 .28764 m
.18149 .28563 L
s
.18098 .28203 m
.18139 .28003 L
s
.17958 .24553 m
.18115 .24946 L
s
.86427 .25765 m
.86475 .26216 L
s
.18098 .28203 m
.18118 .2851 L
s
.18018 .28605 m
.18107 .28764 L
s
.86449 .26271 m
.86508 .26977 L
s
.86475 .26216 m
.86533 .26922 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86473 .30603 m
.86524 .30244 L
s
.86473 .30603 m
.86554 .30192 L
s
.1789 .28338 m
.18042 .24778 L
s
.86508 .26977 m
.86562 .28248 L
s
.17975 .28243 m
.18018 .28605 L
s
.17867 .28284 m
.18019 .24722 L
s
.86533 .26922 m
.86587 .28195 L
s
.86524 .30244 m
.86561 .29629 L
s
.86539 .24671 m
.86661 .24276 L
s
.86554 .30192 m
.86589 .29577 L
s
.86562 .28248 m
.86567 .29066 L
s
.17946 .27626 m
.17975 .28243 L
s
.86561 .29629 m
.86567 .29066 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17946 .27626 m
.17955 .26808 L
s
.86587 .28195 m
.86594 .29013 L
s
.86589 .29577 m
.86594 .29013 L
s
.86597 .24502 m
.8675 .28074 L
s
.86615 .24445 m
.86768 .2802 L
s
.17806 .28123 m
.1789 .28338 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87046 .24099 m
.87046 .23679 L
s
.87093 .25191 m
.87046 .24099 L
s
.87046 .23679 m
.87058 .23199 L
s
.255 .412 .882 r
.86691 .28235 m
.86768 .2802 L
s
0 0 0 r
.87109 .25134 m
.87078 .24827 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87125 .25499 m
.87093 .25191 L
s
.87058 .23199 m
.871 .22966 L
s
.255 .412 .882 r
.86702 .26484 m
.86751 .27196 L
s
0 0 0 r
.87152 .25385 m
.87109 .25134 L
s
.87168 .25751 m
.87125 .25499 L
s
.255 .412 .882 r
.17822 .25546 m
.1783 .24979 L
s
.17803 .26368 m
.17822 .25546 L
s
.17829 .24355 m
.1783 .24979 L
s
.17748 .2765 m
.17803 .26368 L
s
.86751 .27196 m
.86803 .276 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87172 .27016 m
.8722 .27694 L
s
.87236 .28482 m
.87172 .27016 L
s
.255 .412 .882 r
.17808 .2549 m
.17818 .24923 L
s
.17789 .26313 m
.17808 .2549 L
s
.17818 .24923 m
.17819 .24299 L
s
.17734 .27595 m
.17789 .26313 L
s
.17813 .23929 m
.17829 .24355 L
s
0 0 0 r
.871 .22966 m
.87131 .23214 L
s
.255 .412 .882 r
.17813 .23929 m
.17819 .24299 L
s
.17701 .28366 m
.17748 .2765 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8722 .27694 m
.8725 .28006 L
s
.8722 .27694 m
.87236 .28482 L
s
.255 .412 .882 r
.86803 .276 m
.8684 .27748 L
s
.17688 .28312 m
.17734 .27595 L
s
.17813 .23929 m
.1779 .23356 L
s
0 0 0 r
.87131 .23214 m
.87153 .23522 L
s
.255 .412 .882 r
.17666 .28828 m
.17701 .28366 L
s
0 0 0 r
.8725 .28006 m
.87292 .28264 L
s
.255 .412 .882 r
.17653 .28774 m
.17688 .28312 L
s
0 0 0 r
.87126 .22732 m
.87153 .23522 L
s
.87189 .24196 m
.87126 .22732 L
s
.87153 .23522 m
.87189 .24196 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8684 .27748 m
.86872 .27585 L
s
0 0 0 r
.87168 .25751 m
.87251 .26203 L
s
.87152 .25385 m
.87235 .25835 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1762 .29237 m
.17666 .28828 L
s
.8684 .27125 m
.86861 .27327 L
s
.86838 .26812 m
.8684 .27125 L
s
0 0 0 r
.87292 .28264 m
.87331 .28045 L
s
.255 .412 .882 r
.86838 .26812 m
.86858 .27015 L
s
.17609 .29184 m
.17653 .28774 L
s
0 0 0 r
.87264 .2609 m
.87235 .25835 L
s
.8728 .26459 m
.87251 .26203 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86869 .27273 m
.86872 .27585 L
s
.86858 .27015 m
.86869 .27273 L
s
.1758 .29336 m
.1762 .29237 L
s
.17553 .29015 m
.17786 .23586 L
s
0 0 0 r
.87285 .26402 m
.87264 .2609 L
s
.255 .412 .882 r
.1758 .29336 m
.17609 .29184 L
s
.17552 .28961 m
.17786 .23528 L
s
0 0 0 r
.87301 .26771 m
.8728 .26459 L
s
.87331 .28045 m
.87328 .27565 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87317 .27141 m
.87285 .26402 L
s
.255 .412 .882 r
.86764 .23734 m
.86786 .24305 L
s
.86786 .24305 m
.86809 .24821 L
s
.86746 .23304 m
.86764 .23734 L
s
0 0 0 r
.87328 .27565 m
.87317 .27141 L
s
.255 .412 .882 r
.17556 .288 m
.1758 .29336 L
s
.86809 .24821 m
.8683 .2528 L
s
.86763 .23676 m
.86786 .24248 L
s
.86786 .24248 m
.86808 .24764 L
s
.86746 .23304 m
.86763 .23676 L
s
.86808 .24764 m
.86829 .25224 L
s
.8683 .2528 m
.86835 .2537 L
s
.86729 .23131 m
.86746 .23304 L
s
0 0 0 r
.87137 .22571 m
.87178 .23424 L
s
.871 .22026 m
.87137 .22571 L
s
.255 .412 .882 r
.86829 .25224 m
.86835 .2537 L
s
.86875 .26315 m
.86886 .26574 L
s
.86874 .26259 m
.86875 .26315 L
s
.86886 .26574 m
.86896 .26778 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86874 .26259 m
.86885 .26518 L
s
.86723 .23274 m
.86729 .23131 L
s
0 0 0 r
.87258 .25268 m
.8729 .26009 L
s
.87141 .24583 m
.87258 .25268 L
s
.8708 .21907 m
.871 .22026 L
s
.255 .412 .882 r
.86803 .25293 m
.86835 .2537 L
s
.86896 .26778 m
.86901 .26927 L
s
0 0 0 r
.87254 .25211 m
.87302 .26323 L
s
.8729 .26009 m
.87319 .26694 L
s
.87072 .22158 m
.8708 .21907 L
s
.87059 .22099 m
.8708 .21907 L
s
.255 .412 .882 r
.86723 .23274 m
.86725 .23678 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87302 .26323 m
.8733 .2701 L
s
.255 .412 .882 r
.86877 .26706 m
.86901 .26927 L
s
0 0 0 r
.87319 .26694 m
.8733 .2701 L
s
.87076 .22782 m
.87072 .22158 L
s
.8733 .2701 m
.87334 .27271 L
s
.255 .412 .882 r
.8669 .23102 m
.86725 .23678 L
s
.86725 .23678 m
.86825 .26019 L
s
.86652 .22727 m
.8669 .23102 L
s
0 0 0 r
.87061 .22723 m
.87059 .22099 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86677 .23044 m
.86713 .2362 L
s
.86713 .2362 m
.86791 .25441 L
s
.86652 .22727 m
.86677 .23044 L
s
.86803 .25293 m
.86803 .25497 L
s
.86636 .22669 m
.86652 .22727 L
s
.86847 .26335 m
.86877 .26706 L
s
0 0 0 r
.87334 .27271 m
.87306 .27105 L
s
.87109 .23838 m
.87076 .22782 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86825 .26019 m
.86847 .26335 L
s
0 0 0 r
.87092 .2378 m
.87061 .22723 L
s
.255 .412 .882 r
.86791 .25441 m
.86825 .26019 L
s
0 0 0 r
.87306 .27105 m
.87266 .2662 L
s
.87306 .27105 m
.87253 .26564 L
s
.87141 .24583 m
.87109 .23838 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87124 .24526 m
.87092 .2378 L
s
.87141 .24583 m
.87206 .2576 L
s
.87266 .2662 m
.87206 .2576 L
s
.8682 .21077 m
.86917 .21315 L
s
.87124 .24526 m
.8719 .25703 L
s
.87253 .26564 m
.8719 .25703 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86781 .21332 m
.86868 .22196 L
s
.86705 .2084 m
.86781 .21332 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86641 .20721 m
.86705 .2084 L
s
.86589 .20977 m
.86641 .20721 L
s
.86553 .20918 m
.86641 .20721 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86846 .21137 m
.87187 .29028 L
s
.86975 .25836 m
.86998 .25195 L
s
.86548 .2161 m
.86589 .20977 L
s
.86509 .21552 m
.86553 .20918 L
s
.86932 .26102 m
.86975 .25836 L
s
.86548 .2161 m
.86558 .22682 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87077 .28813 m
.87187 .29028 L
s
.8682 .21077 m
.87161 .28974 L
s
.86868 .2599 m
.86932 .26102 L
s
.86509 .21552 m
.86518 .22624 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86558 .22682 m
.8659 .23437 L
s
.86783 .255 m
.86868 .2599 L
s
.86747 .25444 m
.86868 .2599 L
s
.86518 .22624 m
.8655 .2338 L
s
.8659 .23437 m
.86677 .24629 L
s
.86677 .24629 m
.86783 .255 L
s
.8655 .2338 m
.86638 .24573 L
s
.86638 .24573 m
.86747 .25444 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86031 .20212 m
.86162 .21085 L
s
.85859 .19658 m
.86031 .20212 L
s
.255 .412 .882 r
.85692 .2173 m
.85739 .22118 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85749 .19541 m
.85859 .19658 L
s
.86242 .22981 m
.86274 .23741 L
s
.86193 .22924 m
.86242 .24066 L
s
.86258 .24448 m
.86274 .23741 L
s
.85651 .19803 m
.85749 .19541 L
s
.255 .412 .882 r
.85837 .25194 m
.85847 .24701 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86224 .24774 m
.86242 .24066 L
s
.255 .412 .882 r
.85859 .2573 m
.85876 .25412 L
s
0 0 0 r
.86224 .24774 m
.86258 .24448 L
s
.86137 .25046 m
.86224 .24774 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85563 .20448 m
.85651 .19803 L
s
.85592 .19745 m
.85749 .19541 L
s
.85502 .2039 m
.85592 .19745 L
s
.8555 .21535 m
.85563 .20448 L
s
.85973 .2488 m
.86137 .25046 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85487 .21479 m
.85502 .2039 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85783 .24331 m
.85973 .2488 L
s
.85842 .24386 m
.85973 .2488 L
s
.8555 .21535 m
.85581 .22301 L
s
.85581 .22301 m
.86242 .22981 L
s
.85487 .21479 m
.85519 .22244 L
s
.84629 .18554 m
.85131 .18957 L
s
.85581 .22301 m
.85691 .23507 L
s
.85691 .23507 m
.85842 .24386 L
s
.85519 .22244 m
.85629 .23451 L
s
.85629 .23451 m
.85783 .24331 L
s
.84923 .18784 m
.85096 .23009 L
s
.84851 .18726 m
.85024 .22954 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85055 .23728 m
.85096 .23009 L
s
.84982 .23673 m
.85024 .22954 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20591 .21644 m
.20705 .21726 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84848 .23953 m
.85055 .23728 L
s
.84848 .23953 m
.84982 .23673 L
s
.84071 .18155 m
.84241 .22409 L
s
.83987 .18098 m
.84156 .22355 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83727 .17929 m
.84317 .18325 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20646 .18036 m
.22171 .1715 L
s
.84694 .23845 m
.84848 .23953 L
s
.84438 .23295 m
.84694 .23845 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83695 .22167 m
.8379 .22492 L
s
0 0 0 r
.84241 .22409 m
.84438 .23295 L
s
.84187 .23134 m
.84241 .22409 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82686 .17319 m
.83364 .17705 L
s
.84101 .23081 m
.84156 .22355 L
s
.83941 .23365 m
.84187 .23134 L
s
.83941 .23365 m
.84101 .23081 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20587 .26055 m
.20909 .17868 L
s
.20678 .26005 m
.20999 .17812 L
s
.20832 .22082 m
.21399 .21765 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83761 .2326 m
.83941 .23365 L
s
.82983 .17484 m
.83194 .22946 L
s
.8308 .17539 m
.83291 .22998 L
s
.83468 .22711 m
.83761 .2326 L
s
.22067 .17204 m
.22082 .19491 L
s
.21339 .23335 m
.2146 .20201 L
s
.20321 .26209 m
.20918 .25896 L
s
.20918 .25896 m
.21859 .25403 L
s
.22082 .19491 m
.22171 .1715 L
s
.83246 .21822 m
.83468 .22711 L
s
.81507 .16726 m
.82273 .17101 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82895 .22791 m
.83291 .22998 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81951 .16939 m
.82156 .22435 L
s
.81842 .16886 m
.82046 .22384 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23257 .17007 m
.23623 .16458 L
s
.23113 .17843 m
.23257 .17007 L
s
.22954 .2218 m
.23113 .17843 L
s
.21754 .25452 m
.21949 .23027 L
s
.21859 .25403 m
.21949 .23027 L
s
.23373 .16955 m
.23623 .16458 L
s
.23228 .17791 m
.23373 .16955 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80602 .16335 m
.80605 .16425 L
s
.5 Mabswid
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80195 .16154 m
.81045 .16515 L
s
.23623 .16458 m
.23863 .16355 L
s
.8171 .22234 m
.82156 .22435 L
s
.23863 .16355 m
.24217 .16594 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2307 .2213 m
.23228 .17791 L
s
.5 Mabswid
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22614 .22329 m
.2307 .2213 L
s
.24217 .16594 m
.24441 .1728 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80729 .19912 m
.80732 .20003 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80687 .16359 m
.80842 .20698 L
s
.80566 .16308 m
.8072 .20649 L
s
.8215 .25162 m
.82245 .24813 L
s
.8212 .24366 m
.82245 .24813 L
s
.82023 .24715 m
.8212 .24366 L
s
.24482 .16099 m
.24997 .15897 L
s
.24288 .21644 m
.24482 .16099 L
s
.24416 .21596 m
.24609 .16048 L
s
.82023 .24715 m
.8215 .25162 L
s
.78751 .15606 m
.79685 .15952 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80748 .21443 m
.80842 .20698 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80389 .21696 m
.80748 .21443 L
s
.80625 .21394 m
.8072 .20649 L
s
.80389 .21696 m
.80625 .21394 L
s
.23911 .21788 m
.24416 .21596 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80135 .21601 m
.80389 .21696 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25761 .1679 m
.26064 .15901 L
s
.25584 .18029 m
.25761 .1679 L
s
.79731 .21059 m
.80135 .21601 L
s
.26064 .15901 m
.265 .15361 L
s
.25899 .16742 m
.26204 .15853 L
s
.25721 .17981 m
.25899 .16742 L
s
.26204 .15853 m
.265 .15361 L
s
.25558 .18825 m
.25584 .18029 L
s
.265 .15361 m
.26786 .15267 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79157 .15753 m
.79441 .24131 L
s
.79291 .15802 m
.79575 .24176 L
s
.79439 .20167 m
.79731 .21059 L
s
.25695 .18778 m
.25721 .17981 L
s
.25558 .18825 m
.25655 .19975 L
s
.25695 .18778 m
.25793 .19929 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26786 .15267 m
.27064 .15571 L
s
.5 Mabswid
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77634 .15622 m
.77948 .1651 L
s
.77181 .15085 m
.77634 .15622 L
s
.25655 .19975 m
.25906 .20684 L
s
.27064 .15571 m
.27334 .16276 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25793 .19929 m
.26047 .20639 L
s
.76882 .14994 m
.77181 .15085 L
s
.27372 .15081 m
.27974 .14899 L
s
.76592 .15302 m
.76882 .14994 L
s
.76439 .15257 m
.76882 .14994 L
s
.25906 .20684 m
.26318 .2095 L
s
.79031 .23997 m
.79575 .24176 L
s
.26047 .20639 m
.26318 .2095 L
s
.78038 .19304 m
.78051 .19705 L
s
.77881 .18859 m
.78038 .19304 L
s
.77749 .19214 m
.77881 .18859 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77787 .20419 m
.78051 .19705 L
s
.77749 .19214 m
.77907 .1966 L
s
.26318 .2095 m
.26607 .20862 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76154 .15968 m
.76439 .15257 L
s
.76309 .16012 m
.76592 .15302 L
s
.7619 .1717 m
.76309 .16012 L
s
.26607 .20862 m
.26912 .20371 L
s
.77505 .20734 m
.77787 .20419 L
s
.76034 .17127 m
.76154 .15968 L
s
.26912 .20371 m
.27234 .19479 L
s
.77056 .20604 m
.77505 .20734 L
s
.7619 .1717 m
.76214 .17973 L
s
.2887 .15834 m
.29212 .14947 L
s
.28677 .1708 m
.2887 .15834 L
s
.29212 .14947 m
.29708 .1442 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27107 .23519 m
.27372 .15081 L
s
.27258 .23477 m
.27521 .15035 L
s
.76034 .17127 m
.76058 .17931 L
s
.29373 .14905 m
.29708 .1442 L
s
.29029 .15791 m
.29373 .14905 L
s
.28835 .17038 m
.29029 .15791 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76214 .17973 m
.76406 .19224 L
s
.29708 .1442 m
.30036 .14337 L
s
.28653 .17884 m
.28677 .1708 L
s
.76739 .20116 m
.77056 .20604 L
s
.28811 .17842 m
.28835 .17038 L
s
.76406 .19224 m
.76739 .20116 L
s
.30036 .14337 m
.30356 .14656 L
s
.30036 .14337 m
.30523 .14615 L
s
.28653 .17884 m
.28775 .19052 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76058 .17931 m
.76251 .19181 L
s
.76585 .20073 m
.77056 .20604 L
s
.26662 .23646 m
.27258 .23477 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76251 .19181 m
.76585 .20073 L
s
.28811 .17842 m
.28935 .19011 L
s
.73 .13979 m
.74187 .14258 L
s
.30356 .14656 m
.3067 .15379 L
s
.30523 .14615 m
.30839 .1534 L
s
.28775 .19052 m
.29072 .19779 L
s
.73683 .14137 m
.73836 .19798 L
s
.28935 .19011 m
.29233 .19739 L
s
.73514 .14097 m
.73665 .19761 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3067 .15379 m
.30806 .1655 L
s
.30839 .1534 m
.30976 .16511 L
s
.74983 .19257 m
.75135 .18893 L
s
.75135 .18893 m
.75309 .19338 L
s
.75309 .19338 m
.7532 .19743 L
s
.29072 .19779 m
.29548 .20065 L
s
.7517 .20108 m
.7532 .19743 L
s
.29233 .19739 m
.29548 .20065 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71591 .13679 m
.72652 .13902 L
s
.74983 .19257 m
.75158 .19703 L
s
.31903 .13899 m
.32965 .13675 L
s
.30784 .17359 m
.30806 .1655 L
s
.74676 .1999 m
.7517 .20108 L
s
.30955 .1732 m
.30976 .16511 L
s
.29548 .20065 m
.29878 .19986 L
s
.7377 .17362 m
.73973 .18617 L
s
.30582 .18613 m
.30784 .17359 L
s
.255 .412 .882 r
.31602 .17855 m
.31655 .1776 L
s
0 0 0 r
.30751 .18575 m
.30955 .1732 L
s
.255 .412 .882 r
.31655 .1776 m
.31964 .17612 L
s
0 0 0 r
.74332 .19506 m
.74676 .1999 L
s
.29878 .19986 m
.30223 .19502 L
s
.29878 .19986 m
.30391 .19464 L
s
.73973 .18617 m
.74332 .19506 L
s
.30223 .19502 m
.30582 .18613 L
s
.30391 .19464 m
.30751 .18575 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32253 .13823 m
.34297 .19101 L
s
.33689 .13533 m
.34799 .13329 L
s
.73148 .1965 m
.73836 .19798 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69381 .13267 m
.705 .13467 L
s
.70185 .15834 m
.7183 .16142 L
s
.3211 .19503 m
.34241 .1343 L
s
.32288 .19468 m
.34426 .13396 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31757 .19574 m
.32826 .19364 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71223 .20908 m
.72125 .13789 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36312 .13483 m
.36902 .12988 L
s
.36103 .14326 m
.36312 .13483 L
s
.36506 .13453 m
.36902 .12988 L
s
.36296 .14296 m
.36506 .13453 L
s
.36902 .12988 m
.37294 .1293 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36011 .18829 m
.36103 .14326 L
s
.36205 .18801 m
.36296 .14296 L
s
.37294 .1293 m
.37878 .13254 L
s
.33555 .1923 m
.34673 .19038 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37878 .13254 m
.38262 .14016 L
s
.38283 .12793 m
.39086 .1269 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69757 .13332 m
.71252 .22145 L
s
.71252 .22145 m
.72302 .13826 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38182 .18534 m
.38283 .12793 L
s
.38383 .18509 m
.38483 .12767 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35433 .18917 m
.36205 .18801 L
s
.40102 .12569 m
.40294 .13363 L
s
.40077 .14205 m
.40102 .12569 L
s
.40506 .12932 m
.40924 .1248 L
s
.40924 .1248 m
.41755 .12396 L
s
.40294 .13363 m
.40506 .12932 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40077 .14205 m
.40294 .13363 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41755 .12396 m
.42167 .12766 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42167 .12766 m
.42372 .13157 L
s
.255 .412 .882 r
.66307 .20096 m
.66384 .19868 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42357 .14388 m
.42372 .13157 L
s
.37582 .1861 m
.38383 .18509 L
s
.255 .412 .882 r
.66175 .19714 m
.66307 .20096 L
s
0 0 0 r
.44074 .122 m
.44284 .12594 L
s
.43857 .12626 m
.44074 .122 L
s
.43857 .12626 m
.44066 .1302 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42146 .14407 m
.42362 .13977 L
s
.44066 .1302 m
.44284 .12594 L
s
.4067 .15782 m
.41722 .14857 L
s
.40251 .16237 m
.4067 .15782 L
s
.40039 .16671 m
.40251 .16237 L
s
.41722 .14857 m
.42146 .14407 L
s
.40026 .17496 m
.40039 .16671 L
s
.42141 .14818 m
.42357 .14388 L
s
.40664 .16194 m
.41716 .15268 L
s
.40245 .16649 m
.40664 .16194 L
s
.40032 .17083 m
.40245 .16649 L
s
.41716 .15268 m
.42141 .14818 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40026 .17496 m
.40226 .17888 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43046 .16317 m
.43099 .16067 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40226 .17888 m
.40634 .1826 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4211 .17295 m
.42331 .16449 L
s
.4231 .18106 m
.42331 .16449 L
s
.40634 .1826 m
.41468 .1818 L
s
.41894 .17727 m
.4211 .17295 L
s
.4211 .17295 m
.4231 .18106 L
s
.41468 .1818 m
.41894 .17727 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44045 .15077 m
.44208 .20045 L
s
.43778 .20074 m
.44045 .15077 L
s
.43993 .20059 m
.44019 .1756 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43778 .20074 m
.43984 .20895 L
s
.43984 .20895 m
.44208 .20045 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ400`00
0000[Jf]0:f][@0=0:f][@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU
41@0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF
3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0A0?nV4@D000002P2][Jd2000001H0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080
oj<@2@2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0
k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00L0ojHA0P0000030?nV4@050:f]
[@000000[Jf]0:f][@0000001@2][Jd01@000000ojHA0?nV4@3oYQ40[Jf]00@0ojHA00@000000?nV
4@3oYQ4000005@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa002`3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@0000000P3oYQ420:f]
[@<000001@2][Jd0103oYQ4000000?nV4@0000070?nV4@040000003oYQ40ojHA0:f][@@0ojHA00<0
00000?nV4@0000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa005@3oXa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0E0?nV4@80[Jf]0P0000000`2][Jd00000000000020?nV4@8000001`3oYQ40
0`000000ojHA000000070?nV4@040000003oYQ40ojHA0:f][@D0ojHA00<000000?nV4@3oYQ405@3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`2][Jd0o:0@0?bP40060:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0:0?nV4@<000000`3oYQ450:f][@80000000<0[Jf]0?nV4@3oYQ400P3oYQ40
10000000ojHA0000000000070?nV4@8000002@3oYQ400`000000ojHA0:f][@0M0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@00H0o:0@0`2][Jd3000000`0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA10000005
0:f][@@0ojHA0P0000000`3oYQ40[Jf]0?nV4@030?nV4@040000003oYQ400000000000L0ojHA0P00
00090?nV4@030000003oYQ40[Jf]01d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1002`3lX105000000P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2]
[JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA0`0000000`3oYQ40[Jf]0:f][@030:f][@030000003o
YQ40ojHA00L0ojHA0P0000000`3oYQ40[Jf]0?nV4@040?nV4@<000001`3oYQ42000000T0ojHA00<0
00000?nV4@2][Jd07@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400;0?bP40030000003lX100o:0@0080o:0@102]
[Jd3000000030?bP402][Jd0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd000000000000000040:f][@@0ojHA00<0
00000?nV4@3oYQ401`3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ43000000L0ojHA00<0
00000?nV4@3oYQ40203oYQ400`000000ojHA0:f][@0M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00`0o:0@00<0
00000?bP403lX1001`3lX1000`2][Jd0000000000002000001@0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@060=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@@0[Jf]00<000000?nV4@3oYQ401P3oYQ40
0`000000ojHA0?nV4@070?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000001`3oYQ40
0`000000ojHA0?nV4@080?nV4@030000003oYQ40[Jf]01d0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100303lX100
0`000000o:0@0?bP40080?bP4080000000<0mY`?0:f][@0000001000000?0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140303oY1400`000000oj@A0?nT4@040:f]
[@030?nT4@2][Jd0ojHA0080ojHA00<000000?nV4@3oYQ401@3oYQ400`000000ojHA0?nV4@070?nV
4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000001`3oYQ400`000000ojHA0?nV4@070?nV
4@80000000<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400<0?bP40030000003lX100o:0@
00P0o:0@0P0000050?JL3`@000003@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140oj@A00X0oj@A100000000`2][Jd0oj@A0?nT4@030?nT4@050:f][@3oYQ40ojHA0?nV
4@0000001P3oYQ400`000000ojHA0?nV4@080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV
4@8000004@3oYQ42000000030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100303lX1000`00
0000o:0@0?bP40080?bP408000001@3fW0l200000080mY`?102][Jd90?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@80
[Jf]00@000000:f][@3oY140oj@A0P0000050?nT4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV
4@3oYQ400`3oYQ400`000000ojHA0?nV4@080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV
4@800000403oYQ42000000030?nV4@2][Jd0ojHA01d0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100303lX1000`00
0000o:0@0?bP40080?bP408000001@3fW0l2000000H0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400P0000000`3oY140[Jf]0:f][@020:f][@03
0?nT4@000000oj@A00<0oj@A00<000000?nT4@000000103oY1400`2][Jd0ojHA0?nV4@020?nV4@03
0000003oYQ40ojHA0080ojHA0P00000:0?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@80
00003`3oYQ401@000000ojHA0000003oYQ40[Jf]01h0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1002`3lX1000`00
0000o:0@0?bP40070?bP4080000000<0[Jf]0?JL3`3fW0l00`3fW0l2000000X0mY`?102][Jd00`3f
W0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?oo
o`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]00000000
00000`2][Jd50?nT4@030000003oY140oj@A00<0oj@A0P0000040?nT4@030:f][@3oYQ40ojHA0080
ojHA00<000000?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@090?nV4@8000000P3oYQ400`2][Jd0
ojHA0?nV4@040?nV4@8000003P3oYQ400`000000ojHA000000020?nV4@030:f][@3oYQ40ojHA00@0
ojHA00<000000?nV4@3oYQ405@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400<0?bP40030000003lX100o:0@00H0
o:0@0P0000000`2][Jd0mY`?0?JL3`030?JL3`8000003P3fW0l00`2][Jd000000000000A0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0
dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00d0o:0@00<000000:f][@2][Jd00P0000070?nT
4@8000001@3oY1400`000000oj@A000000030?nT4@030:f][@3oYQ40ojHA00<0ojHA00D000000?nV
4@3oYQ40ojHA0000000;0?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000003@3oYQ40
0`000000ojHA000000030?nV4@030:f][@3oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ405@3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400<0?bP40030000003lX100o:0@00H0o:0@0P0000000`2][Jd0mY`?0?JL3`03
0?JL3`8000003@3fW0l2000000030:f][@3/UPh000000080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3C
Q`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100303lX10010000000[Jf]0000002][Jd2000000L0oj@A
00<000000?nT4@3oY1401@3oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA
0?nV4@02000000/0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00000<0?nV4@030000
003oYQ40000000@0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0?nV4@0E0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00`0o:0@00<000000?bP403lX1001P3lX102000000030:f][@3fW0l0mY`?00<0mY`?
0P00000<0?JL3`80000000H0mY`?0:f][@3/UPh0k9H>0000003/UPh20:f][@`0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0
dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1020:f][@04
0000003lX100o:0@0?bP40<000001P3oY142000000L0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA
00<0ojHA00@000000?nV4@3oYQ400000303oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42
000000`0ojHA00<000000?nV4@0000001@3oYQ400`2][Jd0ojHA0?nV4@040?nV4@030000003oYQ40
ojHA00h0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100303lX100
0`000000o:0@0?bP40060?bP4080000000<0[Jf]0?JL3`3fW0l00`3fW0l2000000`0mY`?00@00000
0?JL3`3fW0l0[Jf]0`3/UPh00`000000k9H>0>bF3P020:f][@<000001`3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H0
0`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX102
000000040?bP402][Jd0[Jf]0?bP408000000`3lX103000000H0oj@A0P0000070?nT4@8000000P3o
Y1400`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40000000`0ojHA0P0000020?nV4@030:f][@3o
YQ40ojHA00<0ojHA0P00000;0?nV4@030000003oYQ40000000H0ojHA00<0[Jf]0?nV4@3oYQ40103o
YQ400`000000[Jf]0:f][@0>0:f][@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
40050?nU4100[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00`0o:0@1@00
00040?bP4080000000<0[Jf]0?JL3`3fW0l00`3fW0l2000000/0mY`?0P0000020?JL3`050:f][@3/
UPh0k9H>0>bF3P0000001@3/UPh00`2][Jd0000000000002000000@0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0
[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P00
00030:f][@<0o:0@00<000000?bP403lX1000P3lX1000`2][Jd00000000000060?nT4@8000001`3o
Y14200000080oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ43000000`0ojHA0P0000020?nV4@030:f][@3o
YQ40ojHA00<0ojHA0P0000090?nV4@80000000<0ojHA0000003oYQ400P3oYQ4;0:f][@030000003o
YQ40ojHA01D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603o
Xa000`2][Jd0o:0@0?bP400=0?bP40040000003lX100o:0@0?bP40H0000000<0[Jf]0?JL3`3fW0l0
0`3fW0l2000000/0mY`?0P0000020?JL3`050:f][@3/UPh0k9H>0>bF3P0000001P3/UPh200000080
[Jf]00D0k9H>000000000000k9H>0:f][@0=0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3P
iP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0
kiP@00D0[Jf]0?bP40000000o:0@0:f][@02000000D0o:0@0P0000040?bP40030:f][@0000000000
00H0oj@A0P0000070?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@060?nV4@030000003oYQ40ojHA
00/0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00<0ojHA0P0000070?nV4@050:f][@000000[Jf]
0:f][@000000102][Jd40?nV4@030:f][@3oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ405@3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:
0:f][@h0oj<@00<0[Jf]0?bP403lX1003@3lX1000`000000o:0@0?bP40050?bP4080000000<0[Jf]
0?JL3`3fW0l00`3fW0l2000000/0mY`?0P0000020?JL3`030:f][@3/UPh0k9H>0080k9H>00<00000
0>bF3P3/UPh00`3/UPh200000080k9H>0`2][Jd2000000d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
0`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH
403_V1002`3_V1001@2][Jd000000:f][@000000o:0@008000001@3lX1000`000000o:0@0?bP4003
0?bP40030:f][@000000000000D0oj@A0P0000080?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@05
0?nV4@8000003@3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`2][Jd0000000000007
0:f][@040000003oYQ400000000000P0ojHA00<000000:f][@3oYQ401@3oYQ400`000000ojHA0?nV
4@0E0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400=0?bP40030000003lX100o:0@00D0o:0@00<0
00000?bP402][Jd01@3fW0l2000000/0mY`?0P0000020?JL3`030:f][@3/UPh0k9H>0080k9H>00<0
00000>bF3P3/UPh00`3/UPh2000000D0k9H>1000000;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2]
[Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40040000002][Jd0
o:0@0?bP40<00000103lX102000000D0o:0@00<0[Jf]0000000000001@3oY142000000P0oj@A0P00
00020?nT4@030:f][@3oYQ40ojHA00D0ojHA0P00000<0?nV4@80000000<0ojHA0:f][@2][Jd01@2]
[Jd00`3oYQ400000000000070?nV4@8000002P3oYQ400`000000[Jf]0?nV4@050?nV4@030000003o
YQ40ojHA01D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01H0oj<@202][Jd<0?bP40030000003lX100o:0@00@0o:0@0P0000000`3lX100[Jf]0?JL
3`040?JL3`8000002`3fW0l01@000000mY`?0?JL3`3fW0l0[Jf]00X0k9H>0P0000050>bF3P800000
0P2][Jd00`3KRPd000000=^:3@080=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo
001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40090>nH40030:f][@000000000000<0o:0@0`00
00040?bP408000001@3lX1000`2][Jd00000000000050?nT4@800000203oY14200000080oj@A00<0
[Jf]0?nV4@3oYQ401@3oYQ400`000000ojHA000000080?nV4@<0[Jf]0P000000102][Jd0ojHA0?nV
4@2][Jd50?nV4@8000001`3oYQ400`000000ojHA0?nV4@080?nV4@80000000<0[Jf]0?nV4@3oYQ40
103oYQ400`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP40H0[Jf]1P3lX1000`000000
o:0@0?bP40040?bP4080000000<0o:0@0:f][@3fW0l0103fW0l2000000/0mY`?00D000000?JL3`3f
W0l0mY`?0:f][@0:0>bF3P8000001@3/UPh200000080fhX=0P2][Jd2000000L0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0
dhL>00<0[Jf]0>nH403_V100103_V1000`000000kiP@0>nH40020:f][@030>nH40000000[Jf]00@0
o:0@0P0000040?bP408000001@3lX1000`2][Jd00000000000050?nT4@800000203oY14200000080
oj@A00<0[Jf]0?nV4@3oYQ40103oYQ42000000030?nV4@000000ojHA0080ojHA1@2][Jd30?nV4@80
00000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ400`000000ojHA0?nV4@080?nV4@80
000000<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00L0
o:0@1P2][Jd00`000000o:0@0?bP40040?bP4080000000<0o:0@0:f][@3fW0l01@3fW0l2000000X0
mY`?00D000000?JL3`3fW0l0mY`?0:f][@0:0>bF3P8000001@3/UPh2000000@0fhX=100000050=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0102][Jd0
Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@0080kiP@0`0000020:f][@<0kiP@00<000000:f]
[@3lX1000`3lX102000000@0o:0@0P0000050?bP40030:f][@000000000000D0oj@A0P0000080?nT
4@8000000P3oY1400`2][Jd0ojHA0?nV4@040?nV4@8000000P2][Jd00`000000[Jf]0:f][@080?nV
4@8000000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ400`000000ojHA0?nV4@080?nV
4@80000000<0[Jf]0?nV4@3oYQ40103oYQ400`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
00h0o:0@00<000000:f][@2][Jd00`2][Jd2000000030?bP402][Jd0mY`?00D0mY`?0P00000:0?JL
3`050000003fW0l0mY`?0?JL3`2][Jd02P3/UPh2000000D0k9H>0P0000040=^:3@80000000@0[Jf]
0=^:3@3KRPd000000`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V
0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h01@2][Jd0kiP@0>nH403_V10000000080
kiP@00<000000>nH403_V1000P3_V102000000030:f][@3lX100o:0@0080o:0@0P0000030?bP4080
00001P3lX1000`2][Jd00000000000050?nT4@800000203oY14200000080oj@A00<0[Jf]0?nV4@3o
YQ40102][Jd01@000000[Jf]0?nV4@3oYQ40000000X0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA
00<0ojHA0P0000070?nV4@030000003oYQ40ojHA00L0ojHA0`0000000`2][Jd0ojHA0?nV4@040?nV
4@030000003oYQ40ojHA01D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003P3lX1000`000000o:0@0?bP40030?bP
408000000`2][Jd50?JL3`8000002P3fW0l01@000000mY`?0?JL3`3fW0l0[Jf]00X0k9H>0P000005
0>bF3P800000103KRPd2000000040=^:3@2][Jd0[Jf]0=^:3@80000000<0fhX=0:f][@2iM@/0202i
M@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@080=>73P050:f][@3_V100kiP@0000003_V1000P2][Jd00`000000kiP@0>nH40020>nH4080
000000<0[Jf]0?bP403lX1000P3lX102000000<0o:0@0P0000060?bP40030:f][@000000000000D0
oj@A0P0000080?nT4@80000000<0oj@A0:f][@2][Jd00P2][Jd30?nV4@8000000`3oYQ400`000000
ojHA0?nV4@080?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ400`000000
ojHA0?nV4@070?nV4@<0000000<0[Jf]0?nV4@3oYQ400`3oYQ43000001H0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X1003P3lX1000`000000o:0@0?bP40030?bP4080000000<0o:0@0:f][@3fW0l0102][Jd00`3fW0l0
00000000000:0?JL3`050000003fW0l0mY`?0?JL3`2][Jd02P3/UPh2000000D0k9H>0P0000040=^:
3@8000000`3KRPd01@2][Jd00000000000000000[Jf]00T0^GD;00D0[Jf]08QF1`28EPL0R5H70:f]
[@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd000000000
00020:f][@80kiP@00<000000>nH403_V1000P3_V102000000030:f][@3lX100o:0@0080o:0@0P00
00030?bP408000001P3lX1000`2][Jd00000000000050?nT4@8000001`3oY1401P2][Jd000000000
002][Jd0oj@A0:f][@D0ojHA0P0000040?nV4@030000003oYQ40ojHA00L0ojHA0P0000030?nV4@03
0:f][@3oYQ40ojHA00<0ojHA0P0000080?nV4@030000003oYQ40ojHA00D0ojHA00D000000?nV4@3o
YQ4000000:f][@050?nV4@<000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40030000003lX100o:0@
00<0o:0@0P0000000`3lX100[Jf]0?JL3`040?JL3`040:f][@00000000000:f][@T0mY`?00D00000
0?JL3`3fW0l0mY`?0:f][@0;0>bF3P030000003/UPh0k9H>00<0k9H>0P0000040=^:3@800000103K
RPd200000080[Jf]00<000000;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`
h>H0/>3V0440/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P06
0=>73P<00000103_V1000`000000kiP@0>nH40020>nH4080000000<0[Jf]0?bP403lX1000P3lX102
000000<0o:0@0P0000060?bP40030:f][@000000000000D0oj@A0P0000030?nT4@@0[Jf]0P000003
0?nT4@030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ400`3oYQ400`000000ojHA0?nV4@07
0?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ400`000000ojHA0?nV4@04
0?nV4@050000003oYQ40ojHA0000002][Jd01@3oYQ43000001H0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003P3l
X1000`000000o:0@0?bP40030?bP40040000003lX100o:0@0:f][@H0mY`?0P0000000`3fW0l0[Jf]
0:f][@020:f][@D0mY`?00D000000?JL3`3fW0l0mY`?0:f][@0;0>bF3P030000003/UPh0k9H>00<0
k9H>0P0000040=^:3@800000103KRPd2000000030=^:3@2][Jd0^GD;008000001P2iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@090=>73P030:f][@000000000000@0kiP@00<000000>nH403_V1000P3_V10200000003
0:f][@3lX100o:0@0080o:0@0P0000030?bP408000001P3lX1000`2][Jd00000000000050?nT4@80
00000`2][Jd40?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@020?nV4@8000001@3oYQ400`000000
ojHA0?nV4@070?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000002P3oYQ46000000@0
ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ43000001H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003`3lX10010000000
o:0@0?bP403lX10200000080o:0@00<0[Jf]0?JL3`3fW0l0103fW0l2000000D0mY`?102][Jd00`3f
W0l000000?JL3`020?JL3`030:f][@3/UPh0k9H>00T0k9H>00<000000>bF3P3/UPh00`3/UPh20000
00D0fhX=00<000000=^:3@3KRPd00P3KRPd2000000030=^:3@2][Jd0[Jf]00<000001@2iM@/00`2]
[Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@080=>73P80[Jf]0P0000040>nH40030000003_V100kiP@0080kiP@0P0000050?bP
408000000`3lX102000000H0o:0@00<0[Jf]0000000000000`3oY1420:f][@8000001`3oY1420000
00<0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ42000000H0ojHA00<000000?nV4@3oYQ401P3oYQ420000
00<0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000001@0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ430000
01H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1003`3lX10010000000o:0@0?bP403lX10200000080o:0@00<0[Jf]
0?JL3`3fW0l0103fW0l2000000T0mY`?00H0[Jf]0000002][Jd0[Jf]0?JL3`2][Jd;0>bF3P030000
003/UPh0k9H>00<0k9H>0P0000050=^:3@030000003KRPd0fhX=0080fhX=0P0000000`3KRPd0[Jf]
0;Ue2`02000000030;Ue2`000000^GD;00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V
0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@040=>7
3P2][Jd00000000000@0kiP@00<000000>nH403_V1000P3_V102000000D0o:0@0P0000030?bP4080
00001P3lX1000`2][Jd00000000000030:f][@80oj@A0P0000070?nT4@8000000`3oY140102][Jd0
ojHA0?nV4@3oYQ42000000L0ojHA00<000000?nV4@3oYQ401P3oYQ4200000080ojHA00@0[Jf]0?nV
4@3oYQ40ojHA0`00000F0?nV4@030:f][@3oYQ40ojHA00<0ojHA0`00000F0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@00l0o:0@00@000000?bP403lX100o:0@0P0000020?bP40030:f][@3fW0l0mY`?00@0mY`?0P00
000:0?JL3`80000000@0mY`?0:f][@2][Jd0[Jf]2P3/UPh00`000000k9H>0>bF3P040>bF3P800000
103KRPd00`000000fhX=0=^:3@020=^:3@80000000<0fhX=0:f][@2iM@/00P000000102][Jd0^GD;
0000000000020;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00
F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00D0[Jf]0=>73P3CQ`h0dhL>0:f][@020000
00@0kiP@00<000000>nH403_V1000P3_V102000000@0o:0@0P0000040?bP408000001@3lX1020:f]
[@8000001@3oY142000000L0oj@A00<000000?nT4@3oY1400P3oY140102][Jd0ojHA0?nV4@3oYQ42
000000P0ojHA00<000000?nV4@3oYQ400P3oYQ4500000080ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@030?nV4@<000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400?0?bP40040000003lX100
o:0@0?bP408000000P3lX1000`2][Jd0mY`?0?JL3`040?JL3`8000001@3fW0l00`000000mY`?0?JL
3`030?JL3`050000003fW0l0mY`?0:f][@3/UPh00`2][Jd00`000000k9H>0>bF3P040>bF3P030000
003/UPh0k9H>00@0k9H>0P0000040=^:3@030000003KRPd0fhX=0080fhX=0P0000000`3KRPd0[Jf]
0;Ue2`02000000030;Ue2`2][Jd000000080000000<0^GD;0:f][@28EPL00`28EPL20:f][D80/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P030:f][@3CQ`h0dhL>0080dhL>
00<0[Jf]000000000000103_V1000`000000kiP@0>nH40020>nH40800000103lX102000000@0o:0@
0P0000020?bP40<0[Jf]00@0o:0@0:f][@00000000001@3oY142000000H0oj@A0P0000040?nT4@04
0:f][@3oYQ40ojHA0?nV4@800000203oYQ43000000T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@030?nV4@<000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400?0?bP40040000003lX100o:0@
0?bP408000000P3lX1000`2][Jd0mY`?0?JL3`040?JL3`<000000`3fW0l2000000D0mY`?00@00000
0?JL3`3fW0l0[Jf]0`3/UPh2000000030:f][@3/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh0103/
UPh2000000@0fhX=00<000000=^:3@3KRPd00P3KRPd2000000030=^:3@2][Jd0^GD;008000000P2i
M@/200000080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]000000000000103_
V1000`000000kiP@0>nH40020>nH40800000103lX102000000@0o:0@0P0000020:f][@@0o:0@0P00
00060?nT4@030000003oY140000000D0oj@A00<000000?nT4@3oY1400`3oY1400`2][Jd0ojHA0?nV
4@0500000080ojHA1000000<0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ400`3o
YQ43000001H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003`3lX10010000000o:0@0?bP403lX10200000080o:0@
00<0[Jf]0?JL3`3fW0l0103fW0l3000000<0mY`?00<000000?JL3`000000103fW0l010000000mY`?
0?JL3`2][Jd30>bF3P030000003/UPh0000000<0[Jf]0P3/UPh00`000000k9H>0>bF3P040>bF3P80
0000103KRPd00`000000fhX=0=^:3@020=^:3@80000000<0fhX=0:f][@2iM@/00P0000020;Ue2`80
000000<0[Jf]0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0
Uf0;0:f][@3CQ`h20:f][@H0dhL>00<0[Jf]000000000000103_V1000`000000kiP@0>nH40020>nH
40800000103lX102000000<0o:0@0P2][Jd2000000D0o:0@0P0000070?nT4@8000001@3oY1400`00
0000oj@A0?nT4@030?nT4@030:f][@0000000000008000005@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00<0ojHA0`00000?0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@0100o:0@00<000000?bP403lX1000P0000030?bP40030:f][@3fW0l0mY`?
00<0mY`?0P0000001`3fW0l000000?JL3`3fW0l000000?JL3`000000103fW0l010000000mY`?0?JL
3`2][Jd30>bF3P030000003/UPh0000000<0k9H>0P2][Jd00`000000k9H>0>bF3P040>bF3P800000
103KRPd00`000000fhX=0=^:3@020=^:3@80000000<0fhX=0:f][@2iM@/00P0000020;Ue2`800000
00@0^GD;0:f][@2][Jd000000`28EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0
Uf0;0P2][Jd80=>73P030:f][@000000000000T0kiP@0P0000040?bP408000000`2][Jd20?bP4080
00001@3lX102000000L0oj@A00<000000?nT4@0000000`3oY1400`000000oj@A0?nT4@040?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@<0
00003`2][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0
ojD@00<0[Jf]0?nS403oXa005P3oXa001@11JN40oj<@0?nS403oXa00[Jf]0180o:0@00@000000?bP
403lX1000000103lX1000`2][Jd0mY`?0?JL3`02000000030?JL3`00000000000080mY`?00<00000
0?JL3`3fW0l00P0000040?JL3`80000000<0mY`?0:f][@3/UPh00`3/UPh2000000D0k9H>00<00000
0:f][@2][Jd0103/UPh2000000@0fhX=00<000000=^:3@3KRPd00P3KRPd2000000030=^:3@2][Jd0
^GD;008000000P2iM@/200000080^GD;0P00000408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool0
05T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@000000000000T0kiP@0P000004
0?bP408000001@3lX102000000D0o:0@0P0000080?nT4@8000000`3oY1400`000000oj@A0?nT4@04
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4:0:f][@<000005P3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01D0ojD@302][JdE0?nS4004045Yh@3oXa00
oj<@0:f][A80o:0@00@000000?bP403lX1000000103lX1000`2][Jd0mY`?0?JL3`020?JL3`<00000
0P3fW0l010000000mY`?0?JL3`0000060?JL3`030000003fW0l0[Jf]00@0k9H>00<000000>bF3P3/
UPh0103/UPh00`000000k9H>0>bF3P030:f][@030>bF3P000000000000@0fhX=0P0000030=^:3@80
00000P3KRPd00`2][Jd00000000000020;Ue2`8000000P2iM@/2000000@0R5H700<0[Jf]0;3PiP2`
h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@P0dhL>00<0[Jf]0>nH40000000
2@3_V102000000030:f][@3lX100[Jf]0080[Jf]0P0000050?bP40800000103lX103000000T0oj@A
100000070?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA
00<0[Jf]0?nV4@3oYQ400`3oYQ43000001H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@0100o:0@
00@000000?bP400000000000103lX1000`2][Jd0mY`?0?JL3`080?JL3`<000001P3fW0l200000003
0:f][@3/UPh0k9H>0080k9H>00<000000>bF3P3/UPh0103/UPh2000000@0k9H>00<0[Jf]00000000
0000103KRPd2000000<0fhX=0P0000020=^:3@030:f][@00000000000080^GD;0P0000020;Ue2`03
0000002][Jd0000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;
09MP2`020:f][@P0dhL>00<0[Jf]0>nH400000000P3_V1000`000000kiP@0>nH40040>nH40800000
0P2][Jd30?bP408000001@3lX102000000@0o:0@0`00000D0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA
0000000F0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400@0?bP40040000003lX1000000000000@0
o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000<0k9H>00<000000>bF3P3/UPh01@3/UPh2000000D0
k9H>0P0000020:f][@80fhX=0P0000040=^:3@060000003KRPd0fhX=0:f][@2iM@/000000P2iM@/2
00000080^GD;00<0000008QF1`0000000`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3P
iP050:f][@2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@000000020>nH40030000003_V100
kiP@00@0kiP@0P0000000`2][Jd0o:0@0?bP40020?bP408000001P3lX102000000<0o:0@0`00000D
0?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdH0?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00000G
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F
0?nS40P0[Jf]403lX103000000@0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l01@000000k9H>0>bF3P3/
UPh0000000L0k9H>0P0000050>bF3P8000000P3KRPd20:f][@800000103KRPd2000000040=^:3@2]
[Jd0^GD;00000080^GD;0P0000020;Ue2`0400000028EPL000000:f][@80R5H700<0[Jf]0;3PiP2`
h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH4000
00000P3_V1000`000000kiP@0>nH40020>nH4080[Jf]0P0000000`2][Jd0o:0@0?bP40020?bP4080
00001P3lX10200000080o:0@00@000000:f][@0000000000503oY1400`2][Jd0ojHA0?nV4@0>0?nV
4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00@0ojHA00<000000?nV
4@3oYQ405@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa00102][Jd0o:0@0?bP403lX1070:f][@T0o:0@0`0000040?bP40030:f][@3fW0l0
mY`?01@0mY`?0`0000080>bF3P<00000103/UPh2000000@0fhX=0P0000040=^:3@80000000@0fhX=
0:f][@2iM@/000000P2iM@/200000080^GD;00L0000008QF1`000000R5H70:f][@000000[Jf]0480
/>3V0@3oool005T0/>3V0P2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH40000000
0P3_V1000`000000kiP@0>nH40020:f][@80kiP@0P0000000`2][Jd0o:0@0?bP40020?bP40800000
1`3lX104000000030:f][@000000000001@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@030000003oYQ40ojHA01D0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100203lX1060:f][@<0o:0@0`0000040?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh0203/UPh3000000@0k9H>0P0000040=^:3@8000000P2][Jd20=^:3@800000
00@0fhX=0:f][@2iM@/000000`2iM@/010000000^GD;0;Ue2`00000208QF1`040000002][Jd00000
00000480/>3V0@3oool005T0/>3V0P2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH
400000000P3_V1000`000000[Jf]0:f][@040>nH4080000000<0[Jf]0?bP403lX1000P3lX1020000
00/0o:0@00<0[Jf]000000000000503oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@0`2][Jd0
10000000[Jf]0000002][Jd30?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0203/
UPh3000000<0k9H>0P0000060=^:3@030000003KRPd0fhX=0080[Jf]0P000000103KRPd0[Jf]0;Ue
2`0000030;Ue2`80000000H0^GD;00000028EPL0R5H700000028EPL200000480/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P060:f][@3_V10000000>nH402][Jd000001P3_
V102000000030:f][@3lX100o:0@0080o:0@0P00000;0?bP40030:f][@000000000001<0oj@A1@2]
[JdF0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400A0?bP408000000P3lX1060:f][A@0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh2000000040>bF3P00
0000k9H>0>bF3P8000001P3KRPd00`000000fhX=0=^:3@020=^:3@80000000@0fhX=0:f][@2iM@/0
00000`2iM@/2000000030;Ue2`000000R5H700<0R5H70`0000110;3PiP40oooo001H0;3PiP80[Jf]
0`2GH0/00`2][Jd0dhL>0=>73P060=>73P060:f][@3_V10000000:f][@3_V10000001P3_V1020000
00030:f][@3lX100o:0@0080o:0@0P00000;0?bP40030:f][@000000000000l0oj@A102][Jd00`3o
Y140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400A0?bP408000001@3lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0[Jf]0>bF
3P3/UPh0203/UPh2000000040>bF3P000000k9H>0>bF3P8000001P3KRPd00`000000fhX=0=^:3@02
0=^:3@8000000P2][Jd00`2iM@/000000;Ue2`020;Ue2`80000000<0^GD;0000002][Jd00`28EPL2
000000030:f][@2`h>H0/>3V03l0/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>
00H0dhL>0P2][Jd010000000kiP@0>nH400000060>nH4080000000<0[Jf]0?bP403lX1000P3lX102
000000/0o:0@00<0[Jf]0000000000002`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004P3lX100
0`000000o:0@0?bP40030?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd;0?JL3`030:f][@3/UPh0
k9H>00P0k9H>0P0000020>bF3P<0000000<0[Jf]0=^:3@3KRPd0103KRPd00`000000fhX=0=^:3@02
0=^:3@80000000@0fhX=0:f][@2][Jd000000`2iM@/2000000030;Ue2`000000[Jf]00<0R5H70P00
00000`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P05
0=>73P80[Jf]00@0kiP@00000000000000001`3_V102000000030:f][@3lX100o:0@008000003@3l
X1000`2][Jd00000000000070?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400B0?bP40030000003l
X100o:0@00<0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]0>bF3P3/UPh0203/
UPh2000000D0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd00`000000fhX=0=^:3@020=^:3@80000000D0
fhX=0:f][@2iM@/000000:f][@020;Ue2`80000000<0^GD;0000002][Jd00`28EPL400000400/>3V
0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0=>73P2][Jd00P00
00000`3_V10000000>nH40060>nH4080000000<0[Jf]0?bP403lX1003`3lX1000`2][Jd000000000
00030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400B0?bP40030000003lX100o:0@00<0o:0@00<0
[Jf]0?JL3`3fW0l03P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh02@3/UPh00`000000k9H>0>bF
3P040>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P3KRPd2000000070=^:3@2]
[Jd0^GD;0000002iM@/0[Jf]0;Ue2`02000000030;Ue2`000000[Jf]00<0R5H7100000100;3PiP40
oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P030=>73P040:f][@3CQ`h0dhL>0:f][@80
000000<0kiP@0000003_V1001@3_V102000000030>nH402][Jd0o:0@0100o:0@00<0[Jf]00000000
00000`2][JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l40:f][@X0
k9H>00<000000>bF3P3/UPh0103/UPh01`2][Jd0fhX=0=^:3@3KRPd000000=^:3@000000103KRPd2
000000040=^:3@2][Jd0^GD;00000080^GD;00H0[Jf]000000000000^GD;0000002][Jd308QF1`@0
0000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P2][Jd30=>73P05
0:f][@00000000000>nH400000002@3_V1000`2][Jd0o:0@0?bP400>0?bP4080[Jf]0P00000D0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f]
[@L0k9H>00<000000>bF3P3/UPh0103/UPh00`2][Jd0fhX=0=^:3@020=^:3@800000103KRPd20000
00040=^:3@2][Jd0^GD;000000<0^GD;0P0000000`2iM@/000000000000308QF1`@00000@02`h>H1
0?ooo`00F02`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0[Jf]1@3CQ`h01@2][Jd000000000003_
V100000000T0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@040?bP402][Jd00000000001@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>
0P2][Jd50>bF3P030000003/UPh0k9H>00@0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd3000000030:f]
[@2iM@/0000000<0^GD;0P000000102][Jd000000:f][@00000208QF1`@00000@02`h>H10?ooo`00
F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P2][Jd01P3CQ`h01@2][Jd000000000003_V100000000T0
kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0o:0@00<0[Jf]000000000000503oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@80
k9H>00<000000>bF3P3/UPh0103/UPh00`2][Jd0fhX=0=^:3@070=^:3@@0000000<0[Jf]0;Ue2`00
00000`2iM@/2000000060;Ue2`000000[Jf]08QF1`000000R5H7100000100;3PiP40oooo001H0;3P
iP80[Jf]0`2GH0/20:f][@L0dhL>00D0[Jf]000000000000kiP@000000020>nH40030000003_V100
kiP@00@0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]000000000000503oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh2
0:f][@030000003/UPh0k9H>00@0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd2000000030=^:3@000000
^GD;008000000P2iM@/2000000060;Ue2`000000000008QF1`000000R5H7100000100;3PiP40oooo
001H0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h01@2][Jd000000000
003_V10000000080kiP@00<000000>nH403_V100103_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]
203lX1000`2][Jd000000000000C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P090>bF3P030000
002][Jd0[Jf]00@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd2000000040;Ue2`000000^GD;0;Ue2`80
000000P0^GD;000000000000[Jf]00000028EPL000000:f][@800000@02`h>H10?ooo`00F02`h>H0
102][Jd0Uf0;09MP2`2GH0/20:f][@L0dhL>00@0[Jf]0>nH400000000000103_V1000`000000kiP@
0>nH40040>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd000000000000C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00
[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02@3/UPh00`000000k9H>0>bF3P030:f][@03
0>bF3P2][Jd0fhX=00d0fhX=00H0[Jf]0;Ue2`2iM@/000000;Ue2`0000020;Ue2`80000000D0[Jf]
00000000000000000:f][@0200000400/>3V0@3oool005P0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2]
[Jd70=>73P040:f][@3_V1000000000000@0kiP@00<000000>nH403_V100103_V100102][Jd0o:0@
0:f][@2][Jd=0?bP408000005@3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0
ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh02@3/UPh00`000000k9H>0>bF3P030>bF3P<0[Jf]3@3KRPd01P2][Jd0
^GD;0;Ue2`000000^GD;00000080^GD;0P0000001@28EPL00000000000000000[Jf]00800000@02`
h>H10?ooo`00F02`h>H01P2][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@L0dhL>00@0[Jf]0>nH40000000
0000103_V1000`000000kiP@0>nH40030>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P090>bF3P03
0000003/UPh0k9H>00@0k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0
000000<0^GD;0P0000001@28EPL00000000000000000[Jf]00800000@02`h>H10?ooo`00F02`h>H0
0`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH400000001@3_V100
10000000kiP@0>nH403_V1020:f][@030>nH402][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`0000060>bF3P040:f][@3K
RPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`0600000028EPL000000:f][@00
0000[Jf]0P0000100;3PiP40oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3C
Q`h01@3CQ`h00`2][Jd0kiP@000000040>nH4080000000<0kiP@0:f][@2][Jd00`3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0
/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@030=^:3@030000002][Jd0fhX=00H0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/010000000
R5H700000028EPL400000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0
dhL>00<0[Jf]0>nH40000000103_V102000000030:f][@3_V100kiP@00<0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0
[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd00P3KRPd2000000030=^:3@2][Jd0[Jf]00D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/010000000
R5H700000028EPL400000400/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0
dhL>00<0[Jf]0>nH400000000`3_V1000`2][Jd00000000000060>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0
o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080
fhX=00<000000=^:3@0000000P3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0
000000000028EPL400000400/>3V0@3oool005L0/>3V0P2][Jd409MP2`030:f][@3CQ`h0dhL>00D0
dhL>00@0[Jf]0>nH40000000kiP@0P2][Jd00`3_V1000000000000060>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd2
0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@02
0=^:3@030000003KRPd0000000@0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`080;Ue2`80000000<0R5H7
0000000000000P0000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>7
3P040:f][@3_V10000000:f][@<0kiP@0P0000060>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:3@050=^:3@80[Jf]2@2iM@/0102][Jd0000008QF1`28
EPL300000400/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>0P2][Jd0
0`000000kiP@0>nH40020>nH408000001P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00`0fhX=0`2][Jd70;Ue2`040:f][@28EPL0R5H708QF1`<00000@02`h>H10?ooo`00E`2`h>H2
0:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@030>nH40000000kiP@00<0kiP@0P000006
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2]
[Jd60;Ue2`040:f][@28EPL0R5H708QF1`<00000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0
[Jf]0=>73P3CQ`h00`3CQ`h20:f][@040=>73P2][Jd0kiP@00000080kiP@0P0000070>nH40030:f]
[@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f]
[@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0
^GD;00@0[Jf]08QF1`28EPL0R5H70`0000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0
dhL>0=>73P020=>73P060:f][@3CQ`h0dhL>0=>73P2][Jd0kiP@0`0000090>nH40030:f][@3lX100
o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00D0[Jf]
08QF1`28EPL0R5H70:f][@03000003l0/>3V0@3oool005L0/>3V0P2][Jd309MP2`050:f][@3CQ`h0
dhL>0=>73P2][Jd0103CQ`h00`2][Jd000000000000;0>nH40030:f][@3lX100o:0@00l0o:0@102]
[Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00@0
[Jf]0;Ue2`2iM@/0[Jf]0`28EPL0102][Jd0000000000000000o0;3PiP40oooo001G0;3PiP80[Jf]
0`2GH0/0102][Jd0dhL>0:f][@2][Jd50=>73P030000003_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01@2iM@/30:f][@<0R5H700@0[Jf]0000000000000000?`2`h>H10?ooo`00E`2`h>H20:f][@<0
Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0
^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL3000003l0/>3V0@3oool005L0
/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL3000003l0
/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0
[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]0`28EPL3000003l0/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i
/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0
[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080
R5H70`00000o0;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;Vb
YP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]
0080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`03
0:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`06
0:f][@28EPL0R5H70:f][@28EPL0[Jf]0P00000o0;3PiP40oooo001G0;3PiP030:f][@2GH0/0[Jf]
0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;
00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005L0/>3V0P2][Jd309MP
2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2]
[Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid2
0:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H5
0:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;09MP2`0209MP
2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd2045Yh@80Y9j?00<0[Jf]
0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40
[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@00
0000000003l0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P040:f][@3_
V100[Jf]0:f][@80@FWQ0P2TWXl00`11JN40Y9j?045Yh@060;6[W@80[Jf]1@2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V
1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh
0;ji^02n^KP20:f][@P0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue
2`060:f][@28EPL0R5H708QF1`2][Jd00000@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00T0dhL>0P2][Jd20:BNS`80@FWQ0`2TWXl2045Yh@P0/J^M0P2][Jd30;6[W@030:f][@2i
/ZH0^K:V00D0^K:V00<0@FWQ0;VbYP2i/ZH01P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2@2n^KP00`11JN40[Jf]0;B`/@040;B`/@80[Jf]
2P2iM@/01P2][Jd0R5H708QF1`28EPL0[Jf]00000400/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@080=>73P030:f][@11JN40Y9j?0080Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl2045Y
h@80/J^M0P11JN460;6[W@80[Jf]00<0/J^M0:f][@2i/ZH01`2i/ZH3045Yh@D0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd:0;ji
^080@FWQ00<0[Jf]0;B`/@2d/;401@2d/;420:f][@P0^GD;00H0[Jf]08QF1`28EPL0R5H70:f][@00
00100;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h20:f][@80@FWQ0`2T
WXl00`11JN40Y9j?0:BNS`020:BNS`80@FWQ0`2aZid3045Yh@H0/J^M0`2][Jd80;VbYP<0@FWQ102i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc
1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00H0_[Vh00<0@FWQ0;ji^02n^KP0
0P2n^KP00`11JN40[Jf]0;B`/@080;B`/@030:f][@2iM@/0^GD;00D0^GD;00H0[Jf]08QF1`28EPL0
R5H70:f][@0000100;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h20:f]
[@80@FWQ00D0Y9j?045Yh@2TWXl0Y9j?045Yh@040:BNS`80@FWQ0`2aZid2045Yh@P0/J^M00<0[Jf]
0;VbYP2][Jd00`2][Jd40;VbYP80@FWQ1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/0
0`2][Jd0_[Vh0;ji^0030;ji^080@FWQ00<0_[Vh045Yh@2n^KP0102n^KP00`2][Jd0];2a0;B`/@07
0;B`/@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@040=>73P030:f][@11JN40RXEe0080@FWQ00<0Y9j?045Yh@2TWXl00P11
JN440:BNS`80@FWQ0`2aZid2045Yh@P0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@030;VbYP11
JN40@FWQ00D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00@0[Jf]0;ji^02n^KP0_[Vh
0P11JN430;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;450:f][@<0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00`3CQ`h0102][Jd0@FWQ045Yh@2:QGD2045Yh@030:f][@11JN40Y9j?0080@FWQ102TWXl2045Y
h@<0/J^M0P11JN480;6[W@030:f][@2i/ZH0^K:V00H0^K:V00<0[Jf]045Yh@11JN401@2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m
^`040:f][@2n^KP0_[Vh0;ji^080@FWQ0`2n^KP00`11JN40_[Vh0;ji^0030;ji^0030:f][@2d/;40
];2a00D0];2a00@0[Jf]0;B`/@2d/;40[Jf]0P2OVj00102][Jd0^GD;0;Ue2`2][Jd308QF1`80[Jf]
@02`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]00@0RXEe045Yh@11
JN40RXEe0P11JN400`2TWXl0@FWQ0:BNS`02045Yh@@0Y9j?0P11JN430;6[W@80@FWQ202aZid00`2]
[Jd0@FWQ0;VbYP070;VbYP80@FWQ102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f]
[A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00l0a/2l0`2][Jd;0<>m^`04045Yh@33_K/0`kfk0:f][@<0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP0
0`11JN40_[Vh0;ji^0030;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@040:f][@2OVj00
Wi^P09nKX0<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0
Uf0;0080Uf0;0P2][Jd308Z5M@80@FWQ00H0RXEe045Yh@2TWXl0Y9j?045Yh@2][Jd2045Yh@@0Y9j?
0P11JN430;6[W@80@FWQ1`2aZid2045Yh@030;VbYP11JN40^K:V00H0^K:V0P11JN440;VbYP<0[Jf]
4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]
00<0a/2l0:f][@33_K/02P33_K/01@11JN40`kfk045Yh@11JN40[Jf]00<0_[Vh00<0@FWQ0;ji^02n
^KP00P2n^KP00`11JN40_[Vh0;ji^0030;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;400`2]
[Jd0Wi^P09nKX00309nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?oo
o`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@2:QGD0RXEe00<0RXEe0`11JN420:BNS`05
045Yh@2TWXl0@FWQ045Yh@2][Jd00P2TWXl3045Yh@<0/J^M0P11JN460;6[W@80@FWQ00@0[Jf]0;Vb
YP2i/ZH0@FWQ0P2i/ZH2045Yh@80^K:V0P11JN440;VbYP030000002][Jd0_[N/00@0[Jf]3@2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03037`K`3
045Yh@80al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/02033_K/0
1P11JN40`kfk0<>m^`33_K/0@FWQ0:f][@<0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP01`11JN40_[Vh
0;ji^02n^KP0@FWQ0;ji^02][Jd00P2d/;400`2][Jd0];2a0;B`/@050;B`/@030:f][@2OVj00Wi^P
00<0Wi^P00<0@FWQ0:f][@28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP04
0:f][@2GH0/0Uf0;09MP2`80[Jf]1`2:QGD01@11JN40Y9j?0:BNS`11JN40Y9j?0080@FWQ00@0Y9j?
0:f][@2TWXl0Y9j?0P11JN430;6[W@80@FWQ1P2aZid2045Yh@050:f][@2i/ZH0^K:V045Yh@2i/ZH0
0P11JN430;VbYP80@FWQ1@2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`
0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02@37`K`4045Yh@@0al6l
00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0a/2l00@0[Jf]0<>m^`33_K/0`kfk1011JN430<>m^`03
045Yh@33_K/0`kfk0080`kfk00D0@FWQ0:f][@2n^KP0_[Vh045Yh@030;ji^080@FWQ0`2n^KP00`11
JN40_[Vh0:f][@020:f][@P0];2a00<0[Jf]09nKX02OVj000`2OVj000`11JN40[Jf]08QF1`0208QF
1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd708Z5
M@050:f][@2TWXl0Y9j?045Yh@2TWXl00P11JN420:BNS`<0[Jf]00H0/J^M045Yh@2aZid0@FWQ0;6[
W@11JN460;6[W@80@FWQ00@0[Jf]0;VbYP2i/ZH0^K:V0P11JN440;VbYP80@FWQ00<0^K:V045Yh@2i
/ZH00P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/003
0:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02`37`K`2045Yh@@0al6l00<0[Jf]0<K0_02]
[Jd00`2][Jd=0<K0_0030:f][@33_K/0@FWQ00<0@FWQ1033_K/00`11JN40`kfk0<>m^`040<>m^`03
0:f][@2n^KP0_[Vh00<0_[Vh0P11JN440;ji^003045Yh@2][Jd0[Jf]00X0];2a00<0[Jf]09nKX02O
Vj000`2OVj02045Yh@040:f][@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2G
H0/00`2][Jd708Z5M@050:f][@2TWXl0@FWQ045Yh@2TWXl00P11JN440:BNS`80[Jf]0P2aZid2045Y
h@L0/J^M0P11JN40102][Jd0^K:V0;VbYP2i/ZH2045Yh@@0^K:V0`11JN401@2i/ZH0@FWQ0;VbYP2i
/ZH0[Jf]00d0_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02`37`K`2045Yh@80al6l102][Jd?0<K0_0<0@FWQ0`33_K/2045Yh@@0`kfk00<0
@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^0020;ji^080@FWQ102n^KP0102][Jd0@FWQ0;ji
^02][Jd:0;B`/@030:f][@2OVj00Wi^P00<0Wi^P0P11JN420:f][@0308QF1`2][Jd0/>3V03l0/>3V
0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd608Z5M@040:f][@2TWXl0Y9j?0:BNS`@0
@FWQ102TWXl0102][Jd0/J^M0:f][@2][Jd2045Yh@L0/J^M0P11JN40102][Jd0^K:V0;VbYP2i/ZH2
045Yh@@0^K:V0P11JN430;VbYP80@FWQ00<0[Jf]0;jg[02n]j`03`2n]j`40:f][A40`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0030:f][@11JN40@FWQ0080[Jf]0P37`K`0
0`2][Jd0a/2l0<K0_00<0<K0_0<0@FWQ00<0a/2l0:f][@33_K/00P33_K/2045Yh@@0`kfk00<0@FWQ
0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^0020;ji^080@FWQ0P2n^KP20:f][@040;ji^011JN40
_[Vh0:f][@X0];2a00<0[Jf]09nKX02OVj000`2OVj001011JN40Wi^P0:f][@1`KWT20:f][D00/>3V
0@3oool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl00`2T
WXl2045Yh@@0Y9j?00@0[Jf]0;6[W@2aZid0/J^M0P11JN400`2][Jd0/J^M0;6[W@050;6[W@03045Y
h@2][Jd0^K:V0080^K:V0P11JN440;VbYP80@FWQ0`2i/ZH2045Yh@040:f][@2n]j`0_[N/0;jg[0@0
@FWQ2`2n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_0050<O1_0D0[Jf]00<0al6l045Yh@11JN401037`K`00`2][Jd0a/2l0<K0_0060<K0_0@0
@FWQ1036`;`00`11JN40a/2l0:f][@030<>m^`80@FWQ0`33_K/2045Yh@H0`kfk00@0[Jf]0;ji^02n
^KP0_[Vh0P11JN420:f][@07045Yh@2n^KP0_[Vh0;ji^011JN40_[Vh0:f][@0:0;B`/@030:f][@2O
Vj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<2
0:f][@D0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl2045Yh@@0Y9j?00@0[Jf]0;6[W@2aZid0/J^M0`11
JN420:f][@D0/J^M00<0@FWQ0:f][@2i/ZH00P2i/ZH2045Yh@<0^K:V0P11JN450;VbYP80@FWQ1@2n
]j`4045Yh@80_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]1P37`K`2045Yh@@0al6l00<0
[Jf]0<K0_036`;`01@36`;`3045Yh@H0a/2l00<0@FWQ0<K0_02][Jd00`33_K/2045Yh@<0`kfk0P11
JN460<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ0P2n^KP01`11JN40_[Vh0;ji^02n^KP0@FWQ0;ji
^02][Jd02P2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0
Y9j?0:BNS`030:BNS`80@FWQ102TWXl0102][Jd0/J^M0;6[W@2aZid3045Yh@80/J^M0`2][Jd20;6[
W@03045Yh@2][Jd0^K:V0080^K:V0P11JN430;VbYP80@FWQ1@2i/ZH2045Yh@D0_[N/0P11JN450;jg
[080@FWQ102n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1
^`H0[Jf]2`37`K`2045Yh@@0al6l00<0[Jf]0<K0_036`;`01P36`;`2045Yh@H0a/2l00<0@FWQ0<K0
_02][Jd00`33_K/2045Yh@<0`kfk0P11JN460<>m^`030:f][@2n^KP0[Jf]0080@FWQ0`2n^KP01`11
JN40_[Vh0;ji^02n^KP0@FWQ0;ji^02][Jd02P2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2O
Vj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0
[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80@FWQ102TWXl0102][Jd0/J^M
0;6[W@2aZid3045Yh@D0/J^M0P2][Jd00`2aZid0@FWQ0;VbYP020;VbYP80@FWQ0`2i/ZH2045Yh@D0
^K:V0P11JN450;jg[080@FWQ1P2n]j`3045Yh@80_[N/00<0[Jf]045Yh@11JN403`31^[080:f][A00
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0
b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00/0al6l0P11JN420<O1_0D0@FWQ1P36`;`2045Yh@H0
a/2l00<0@FWQ0<K0_02][Jd00`33_K/2045Yh@<0`kfk0P11JN450<>m^`05045Yh@2][Jd0[Jf]0;ji
^011JN40102n^KP2045Yh@80_[Vh0P11JN400`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P
0080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1S
H5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl2045Y
h@@0Y9j?00@0[Jf]0;6[W@2aZid0/J^M0`11JN420;6[W@03045Yh@2aZid0/J^M0080/J^M0P2][Jd2
045Yh@030;VbYP11JN40@FWQ00<0^K:V0P11JN450;VbYP030:f][@11JN40_[N/00@0_[N/0P11JN46
0;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]0<6j/011JN400`11JN4>0<6j/0030:f][@33_K<0
`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0
102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`02037`K`00`11JN40al6l0<O1
_002045Yh@040<O1_011JN40al6l0<O1_0<0@FWQ1P36`;`2045Yh@H0a/2l00<0@FWQ0<K0_02][Jd0
0`33_K/2045Yh@<0`kfk0P11JN420<>m^`80[Jf]0P11JN40102][Jd0_[Vh0;ji^011JN440;ji^080
@FWQ0P2n^KP2045Yh@030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0
L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe
08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00H0Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl00`11JN40/J^M
0;6[W@04045Yh@030;6[W@11JN40@FWQ00D0/J^M00<0[Jf]0;VbYP2][Jd00`11JN430;VbYP80@FWQ
1@2i/ZH00`2][Jd0@FWQ0;jg[0040;jg[080@FWQ1P2n]j`00`11JN40_[N/0;jg[0020;jg[0040:f]
[@31^[00@FWQ045Yh@P0`KZ`00<0@FWQ0<6j/031^[001@31^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0
[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0020<O1_003
045Yh@37`K`0al6l0080al6l00@0@FWQ0<O1_037`K`0al6l0`11JN430<O1_0040:f][@11JN40a/2l
045Yh@D0a/2l0P11JN460<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P33_K/01011JN40`kfk0<>m^`33
_K/2045Yh@80[Jf]0P33_K/2045Yh@040:f][@2n^KP0_[Vh045Yh@<0_[Vh00<0@FWQ0;ji^011JN40
0P2n^KP2045Yh@030:f][@2d/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]
?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2]
[Jd60:BNS`03045Yh@2TWXl0Y9j?0080Y9j?00@0@FWQ0;6[W@2aZid0/J^M0`11JN420;6[W@03045Y
h@2aZid0/J^M0080/J^M00<0@FWQ0:f][@2i/ZH00P2i/ZH2045Yh@80[Jf]00<0^K:V045Yh@11JN40
1@2i/ZH00`2][Jd0@FWQ0;jg[0040;jg[080@FWQ1P2n]j`00`11JN40_[N/0;jg[0020;jg[0040:f]
[@31^[00@FWQ045Yh@H0`KZ`0P11JN400`31^[00@FWQ045Yh@050<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_002045Yh@040<O1_011JN40@FWQ0<O1
_080@FWQ0`37`K`3045Yh@<0al6l00@0[Jf]0<K0_011JN40@FWQ1@36`;`2045Yh@H0a/2l0P11JN40
0`2][Jd0`kfk0<>m^`020<>m^`04045Yh@33_K/0`kfk0:f][@80@FWQ1@33_K/00`11JN40[Jf]0;ji
^0020;ji^004045Yh@2n^KP0_[Vh045Yh@@0_[Vh0P11JN400`2][Jd0];2a0;B`/@080;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f]
[@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`040:BNS`03045Y
h@2TWXl0Y9j?0080Y9j?00<0@FWQ0;6[W@2aZid0102aZid3045Yh@@0/J^M00<0@FWQ0:f][@2i/ZH0
0P2i/ZH2045Yh@80^K:V00@0[Jf]045Yh@11JN40[Jf]102i/ZH00`2][Jd0@FWQ0;jg[0040;jg[080
@FWQ1P2n]j`01@11JN40_[N/0;jg[02n]j`0[Jf]0080`KZ`0P11JN450<6j/080@FWQ1031^[02045Y
h@<0`KZ`00@0[Jf]0<>m/`33_K<0@FWQ4P33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]045Yh@11JN401037`K`3045Yh@@0al6l0P11JN440<O1_0040:f][@36`;`0
@FWQ045Yh@D0a/2l0P11JN460<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P33_K/00`11JN40[Jf]0:f]
[@020<>m^`03045Yh@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`2][Jd0102n^KP2045Yh@D0_[Vh0P11
JN400`2][Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V
0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]102TWXl2045Yh@<0Y9j?
00<0@FWQ0;6[W@2aZid02`2aZid00`11JN40[Jf]0;VbYP020;VbYP03045Yh@2i/ZH0^K:V0080^K:V
0P11JN401`2i/ZH0[Jf]0:f][@2][Jd0^K:V0:f][@11JN401@2n]j`2045Yh@H0_[N/00D0@FWQ0;jg
[02n]j`0_[N/0:f][@020<6j/080@FWQ1@31^[000`11JN40`KZ`0<6j/0040<6j/005045Yh@31^[00
`KZ`0<6j/02][Jd00P33_K<00`11JN40`kfc0<>m/`04045Yh@`0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k00H0b<6k1011JN490<S1^`030:f][@11JN40@FWQ00D0al6l0P11JN440<O1_080@FWQ1037
`K`00`2][Jd0a/2l0<K0_002045Yh@@0a/2l0P11JN460<K0_080@FWQ00<0[Jf]0<>m^`2][Jd00P2]
[Jd00`11JN40`kfk0<>m^`020<>m^`80@FWQ0`33_K/00`11JN40`kfk0:f][@0;0;ji^080@FWQ00<0
[Jf]0;B`/@2d/;401@2d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2]
[Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2T
WXl00P2][Jd30:BNS`03045Yh@2TWXl0Y9j?0080@FWQ3@2aZid00`11JN40[Jf]0;VbYP020;VbYP03
045Yh@2i/ZH0^K:V0080^K:V0P11JN440;VbYP80[Jf]00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@D0
_[N/0P11JN430;jg[0030:f][@31^[00`KZ`0080@FWQ1@31^[000`11JN40`KZ`0<6j/0050<6j/004
045Yh@31^[00`KZ`0:f][@80`kfc0`11JN440<>m/`03045Yh@33_K<0`kfc00@0`kfc00<0@FWQ0<>m
/`33_K<00P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1
^`11JN40@FWQ0`38`K/4045Yh@/0b<6k0P11JN460<O1_080@FWQ1@37`K`2045Yh@<0al6l00<0[Jf]
0<K0_036`;`00P11JN440<K0_080@FWQ1P36`;`2045Yh@80[Jf]0`33_K/00`11JN40`kfk0<>m^`02
0<>m^`05045Yh@33_K/0@FWQ0<>m^`11JN400P33_K/00`2][Jd0_[Vh0;ji^0090;ji^080@FWQ00<0
[Jf]0;B`/@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^
N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?
0:BNS`020:BNS`060:f][@2TWXl0Y9j?0:BNS`11JN40Y9j?0P11JN4>0;6[W@@0@FWQ1@2i/ZH2045Y
h@D0^K:V0P11JN440:f][@030;jg[011JN40@FWQ00D0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`
0080@FWQ1031^[000`11JN40`KZ`0<6j/0060<6j/005045Yh@31^[00`KZ`0:f][@33_K<00P11JN46
0<>m/`03045Yh@33_K<0`kfc00<0`kfc00<0@FWQ0<>m/`11JN400`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k0100b<6k0`11JN400`38`K/0[Jf]0<S1^`02045Yh@D0b<6k0P11JN4;
0<S1^`80@FWQ1P37`K`2045Yh@D0al6l0P11JN430<O1_0030:f][@36`;`0a/2l0080@FWQ1036`;`2
045Yh@030<K0_02][Jd0[Jf]00<0[Jf]0P11JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33_K/0
`kfk00<0`kfk1011JN420<>m^`030:f][@2n^KP0_[Vh00T0_[Vh0P11JN40102][Jd0];2a0;B`/@2d
/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo
001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@050:BN
S`11JN40@FWQ0:BNS`11JN403P2aZid00`2][Jd0^K:V0;VbYP060;VbYP<0@FWQ102i/ZH2045Yh@@0
_[N/00@0[Jf]045Yh@11JN40[Jf]102n]j`2045Yh@<0_[N/00<0[Jf]0<6j/031^[000P11JN440<6j
/003045Yh@31^[00`KZ`00T0`KZ`00<0[Jf]0<>m/`11JN402033_K<00`11JN40`kfc0<>m/`030<>m
/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`020<S1
^`03045Yh@38`K/0b<6k00T0b<6k0P11JN430<S1^`80@FWQ00<0b<6k045Yh@11JN401@38`K/2045Y
h@/0b<6k0P11JN460<O1_080@FWQ1@37`K`2045Yh@<0al6l00<0[Jf]0<K0_036`;`00P11JN430<K0
_0040:f][@11JN40@FWQ0:f][@D0a/2l0P11JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33_K/0
`kfk00T0`kfk00<0[Jf]0;ji^02n^KP02@2n^KP2045Yh@040:f][@2d/;40];2a0:f][@L0];2a00<0
[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1S
H5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0@FWQ0;6[W@2aZid02`2a
Zid00`2][Jd0^K:V0;VbYP050;VbYPD0@FWQ0`2i/ZH2045Yh@H0_[N/0P11JN400`2n]j`0[Jf]0:f]
[@020:f][@80@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/002045Yh@@0`KZ`00<0@FWQ0<6j/031^[002@31
^[000`2][Jd0`kfc045Yh@080<>m/`03045Yh@33_K<0`kfc00P0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0=0<Jo]`@0@FWQ1036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j00<0al6j1011JN440<O1^P80@FWQ1P37`KX00`11JN40al6j0:f][@040<S1^`03045Yh@38
`K/0b<6k00P0b<6k0P11JN450<S1^`040:f][@11JN40@FWQ045Yh@D0b<6k0P11JN4;0<S1^`80@FWQ
1P37`K`2045Yh@D0al6l0P11JN430<O1_0030:f][@36`;`0a/2l0080@FWQ0`2][Jd00`36`;`0@FWQ
045Yh@060<K0_080@FWQ00<0[Jf]0<>m^`33_K/00P33_K/00`11JN40`kfk0<>m^`090<>m^`030:f]
[@2n^KP0_[Vh00X0_[Vh00@0@FWQ0:f][@2][Jd0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX003
0:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?
0:BNS`070:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP070;VbYP<0@FWQ0`2i/ZH00`11JN40[Jf]
0;jg[0050;jg[080@FWQ1@2n]j`2045Yh@80[Jf]00@0_[N/0:f][@31^[00`KZ`0P11JN440<6j/003
045Yh@31^[00`KZ`00T0`KZ`00<0[Jf]0<>m/`33_K<02033_K<00`11JN40`kfc0<>m/`080<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04036_kL7045Yh@L0al6h1`11JN470<O1^004
0:f][@37`KX0al6j0<O1^P80@FWQ1037`KX00`11JN40al6j0<O1^P02045Yh@L0al6j00<0@FWQ0<O1
^P2][Jd01038`K/00`11JN40b<6k0<S1^`080<S1^`80@FWQ1@38`K/0102][Jd0b<6k045Yh@11JN45
0<S1^`80@FWQ2`38`K/2045Yh@H0al6l0P11JN450<O1_080@FWQ00<0al6l0:f][@2][Jd00`2][Jd0
0`11JN40a/2l0<K0_0040<K0_080@FWQ1036`;`2045Yh@040<K0_02][Jd0`kfk0<>m^`<0@FWQ2`33
_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`
KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<
0;6[W@030:f][@2i/ZH0^K:V00X0^K:V0`11JN400`2i/ZH0[Jf]0;jg[0050;jg[080@FWQ1@2n]j`2
045Yh@80_[N/102][Jd2045Yh@@0`KZ`00<0@FWQ0<6j/031^[002@31^[000`2][Jd0`kfc0<>m/`07
0<>m/`80@FWQ2P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0100a[ng00<0@FWQ
0<Jo]`36_kL00P36_kL0102][Jd0@FWQ045Yh@11JN480<O1^080@FWQ2@37`KP0102][Jd0al6j0<O1
^P37`KX2045Yh@D0al6j0`11JN480<O1^P80@FWQ00@0[Jf]0<S1^`38`K/0b<6k0`11JN480<S1^`80
@FWQ1P38`K/0102][Jd0b<6k045Yh@11JN450<S1^`80@FWQ2`38`K/00`2][Jd0@FWQ045Yh@060<O1
_004045Yh@37`K`0al6l0<O1_080[Jf]0P11JN40102][Jd0al6l0<O1_02][Jd20<K0_003045Yh@36
`;`0a/2l00@0a/2l0P11JN440<K0_080@FWQ00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji
^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`
h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@02
0:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0040;jg[003045Yh@2n]j`0
@FWQ00@0_[N/0P11JN430;jg[0030:f][@31^[00`KZ`0080@FWQ102][Jd00`11JN40[Jf]0<6j/009
0<6j/0030:f][@33_K<0`kfc00D0`kfc0`11JN4;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL04036_kL00`11JN40a[ng0<Jo]`020<Jo]`040:f][@37`KP0al6h045Yh@P0al6h0P11
JN490<O1^0030:f][@37`KX0al6j0080@FWQ1`37`KX2045Yh@L0al6j00@0@FWQ0<O1^P11JN40[Jf]
0`38`K/3045Yh@P0b<6k00<0@FWQ0<S1^`38`K/01@38`K/0102][Jd0b<6k045Yh@11JN450<S1^`80
@FWQ2`38`K/00`2][Jd0al6l045Yh@07045Yh@<0[Jf]0P37`K`2045Yh@<0al6l00@0[Jf]0<K0_036
`;`0@FWQ1P36`;`3045Yh@80a/2l0P11JN420<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nK
X080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[0040;jg[003045Yh@2n]j`0@FWQ00@0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`2][Jd0
`KZ`0<6j/002045Yh@@0`KZ`00<0@FWQ0<6j/02][Jd01P2][Jd30<6j/0030:f][@33_K<0`kfc00<0
`kfc1011JN4<0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04036_kL00`11JN40
a[ng0<Jo]`020<Jo]`050:f][@37`KP0al6h0<O1^011JN401`37`KP2045Yh@X0al6h00@0[Jf]0<O1
^P11JN40@FWQ1`37`KX2045Yh@L0al6j00@0@FWQ0<O1^P11JN40[Jf]0`38`K/3045Yh@P0b<6k00<0
@FWQ0<S1^`38`K/01@38`K/0102][Jd0b<6k045Yh@11JN450<S1^`80@FWQ2`38`K/00`2][Jd0al6l
0<O1_0050:f][@80@FWQ1@37`K`2045Yh@<0al6l00<0[Jf]0<K0_011JN401`36`;`2045Yh@030<K0
_011JN40@FWQ00@0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]
1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0
@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0040;jg[003045Yh@2n]j`0_[N/0080@FWQ0P2n]j`00`11JN40_[N/0;jg[0020;jg[0030:f][@31
^[00`KZ`0080@FWQ1031^[02045Yh@H0`KZ`00<0@FWQ0:f][@2][Jd01@2][Jd01033_K<0@FWQ045Y
h@11JN490<>m/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0@0<Jo]`03045Yh@36_kL0a[ng0080a[ng00D0[Jf]0<O1^037`KP0al6h045Yh@070<O1^080
@FWQ2P37`KP0102][Jd0al6j045Yh@11JN470<O1^P80@FWQ1`37`KX3045Yh@040:f][@38`K/0b<6k
0<S1^`<0@FWQ2038`K/00`11JN40b<6k0<S1^`050<S1^`040:f][@38`K/0@FWQ045Yh@H0b<6k00<0
@FWQ0<S1^`38`K/01P38`K/60:f][@H0al6l00<0@FWQ0<O1_037`K`00`37`K`2045Yh@<0al6l00<0
[Jf]045Yh@11JN401`36`;`2045Yh@P0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji
^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f]
[@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BN
S`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n
]j`0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@D0_[N/00<0[Jf]0<6j/031^[000P11
JN450<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN420<6j/0030:f][@33_K<0`kfc00<0@FWQ1@2]
[Jd60<>m/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0@0<Jo]`03045Yh@36_kL0a[ng0080a[ng00@0[Jf]0<O1^037`KP0al6h0P11JN460<O1^080@FWQ
2P37`KP0102][Jd0al6j045Yh@11JN470<O1^P80@FWQ1`37`KX2045Yh@030<O1^P11JN40b<6k0080
b<6k00<0@FWQ0<S1^`11JN401`38`K/2045Yh@L0b<6k00<0[Jf]0<S1^`11JN400`11JN440<S1^`03
045Yh@38`K/0[Jf]00H0[Jf]0`38`K/00`2][Jd0al6l0<O1_0060<O1_003045Yh@37`K`0al6l00<0
al6l0`11JN420<O1_080@FWQ2036`;`2045Yh@P0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0
_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2]
[Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[0040;jg[003
045Yh@2n]j`0_[N/00T0_[N/00<0[Jf]045Yh@11JN400P11JN450<6j/003045Yh@31^[00`KZ`00@0
`KZ`0P11JN420<6j/0030:f][@33_K<0@FWQ0080@FWQ1P33_K<60:f][@03045Yh@2][Jd0`kfc0080
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0@0<Jo]`03045Yh@36_kL0a[ng0080
a[ng00@0[Jf]0<O1^037`KP0al6h0P11JN460<O1^080@FWQ2P37`KP0102][Jd0al6j045Yh@11JN47
0<O1^P80@FWQ1`37`KX2045Yh@040<O1^P11JN40b<6k0<S1^`80@FWQ00<0b<6k045Yh@38`K/01P38
`K/2045Yh@L0b<6k0`11JN400`38`K/0[Jf]0:f][@040:f][@03045Yh@2][Jd0b<6k00T0b<6k00<0
[Jf]045Yh@11JN401P37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ00@0al6l045Yh@11JN40@FWQ
2@36`;`2045Yh@P0a/2l00D0[Jf]0<>m^`33_K/0`kfk045Yh@0:0<>m^`<0[Jf]302n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]
2`2i/ZH00`2][Jd0_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00T0_[N/00<0[Jf]0<6j/031^[00
0P11JN460<6j/003045Yh@31^[00`KZ`00<0`KZ`00L0@FWQ0<6j/031^[00`KZ`0:f][@33_K<0@FWQ
00P0`kfc00<0@FWQ0<>m/`33_K<00`33_K<00`11JN40`kfc0:f][@080:f][A40aKje00<0[Jf]0<Jo
]`36_kL04036_kL00`11JN40a[ng0<Jo]`020<Jo]`040:f][@37`KP0al6h0<O1^080@FWQ1P37`KP2
045Yh@X0al6h00<0[Jf]0<O1^P37`KX00P11JN460<O1^P80@FWQ1P37`KX01@11JN40al6j045Yh@37
`KX0@FWQ0080b<6k0P11JN420<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN420<S1^`T0[Jf]1P38
`K/2045Yh@@0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`2][Jd0@FWQ045Yh@050<O1_003045Yh@37
`K`0al6l0080al6l1011JN430<O1_0030:f][@36`;`0a/2l00L0a/2l0P11JN480<K0_0060:f][@33
_K/0`kfk045Yh@33_K/0@FWQ1P33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d
/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?
00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/
0;jg[0040;jg[003045Yh@2n]j`0_[N/00T0_[N/00<0[Jf]0<6j/031^[002@31^[000`11JN40`KZ`
0<6j/0020<6j/007045Yh@31^[00`KZ`0<6j/02][Jd0`kfc045Yh@070<>m/`80@FWQ1@33_K<00`11
JN40`kfc0<>m/`020<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng
0100a[ng00<0@FWQ0<Jo]`36_kL00P36_kL00`2][Jd0al6h0<O1^0020<O1^080@FWQ1@37`KP2045Y
h@X0al6h00@0[Jf]0<O1^P37`KX0al6j1011JN430<O1^P80@FWQ1P37`KX2045Yh@80al6j00<0@FWQ
0<S1^`38`K/00P11JN400`38`K/0[Jf]045Yh@060:f][@80@FWQ0P2][Jd50<S1^`030:f][@38`K/0
b<6k00L0b<6k0P11JN440<S1^`80@FWQ1038`K/00`2][Jd0al6l045Yh@020<O1_0<0@FWQ3@37`K`0
0`2][Jd0a/2l0<K0_0060<K0_080@FWQ2036`;`01@2][Jd0`kfk0<>m^`33_K/0@FWQ00@0`kfk0`2]
[Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3o
ool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH3
0:f][@D0^K:V00<0[Jf]0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0090;jg[0030:f][@31^[00
`KZ`00X0`KZ`1011JN440<6j/0040:f][@33_K<0`kfc045Yh@H0`kfc0P11JN450<>m/`03045Yh@33
_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@L0a[ng00<0@FWQ0<Jo]`36_kL00P36
_kL00`2][Jd0al6h0<O1^0020<O1^080@FWQ1@37`KP2045Yh@X0al6h00<0[Jf]0<O1^P37`KX01@37
`KX5045Yh@H0[Jf]0P11JN430:f][@07045Yh@2][Jd0@FWQ045Yh@2][Jd0b<6k045Yh@060<S1^`80
@FWQ1`38`K/00`2][Jd0b<6k0<S1^`070<S1^`03045Yh@38`K/0@FWQ00@0b<6k00<0@FWQ0<S1^`38
`K/00P38`K/00`2][Jd0al6l0<O1_002045YhA00al6l00<0[Jf]0<K0_036`;`01P36`;`2045Yh@P0
a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0
];2a0;B`/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0
202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]
0;jg[0050;jg[003045Yh@2n]j`0_[N/00T0_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc
0<>m/`33_K<2045Yh@<0`kfc0`11JN450<>m/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]`L0[Jf]00<0@FWQ0:f][@2][Jd01`2][Jd2045Yh@D0
[Jf]0P11JN4E0:f][@80@FWQ1P37`KX2045Yh@80al6j00<0[Jf]045Yh@38`K/00P11JN420<S1^`03
045Yh@38`K/0b<6k00@0b<6k0P11JN470<S1^`030:f][@38`K/0b<6k00L0b<6k00@0@FWQ0<S1^`38
`K/0@FWQ0P38`K/2045Yh@@0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0060<K0
_080@FWQ2036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2]
[Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]0`2n]j`00`11JN40_[N/045Yh@0;0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<00`33_K<3045Yh@80`kfc00<0@FWQ0<>m/`33
_K<00P33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0@0<Jo]`03
045Yh@36_kL0a[ng0080a[ng00<0[Jf]0<O1^037`KP00P37`KP2045Yh@D0al6h0`11JN490<O1^003
0:f][@37`KX0al6j00P0al6j0P11JN460<O1^P80@FWQ0P37`KX0102][Jd0@FWQ0<S1^`11JN430<S1
^`03045Yh@38`K/0b<6k00@0b<6k0P11JN470<S1^`030:f][@38`K/0b<6k00@0b<6k1011JN430<S1
^`80@FWQ1P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00H0a/2l0P11JN460<K0
_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3P
iP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0
^K:V0;VbYP0=0;VbYP80000000<0_[N/0:f][@2][Jd00P2][Jd2045Yh@/0_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0=0<>m/`80@FWQ1033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng0100a[ng00<0@FWQ0<Jo]`36_kL00P36_kL00`2][Jd0al6h0<O1^0020<O1^080
@FWQ1@37`KP3045Yh@@0al6h00<0@FWQ0<O1^037`KP00P37`KP00`2][Jd0al6j0<O1^P02045Yh@H0
al6j00<0@FWQ0<O1^P37`KX01@37`KX01@11JN40al6j0<O1^P37`KX0[Jf]00<0@FWQ1038`K/00`11
JN40b<6k0<S1^`030<S1^`80@FWQ1`38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`01036`;`4045Yh@030<K0_02][Jd0[Jf]00<0[Jf]0P36`;`00`2]
[Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f]
[Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`0102][Jd0`KZ`0<6j/011JN4A0<6j
/0030:f][@33_K<0`kfc00d0`kfc0P11JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL04036_kL00`11JN40a[ng0<Jo]`020<Jo]`030:f][@37`KP0al6h0080al6h0P11JN450<O1
^0<0@FWQ1037`KP2045Yh@<0al6h00<0[Jf]0<O1^P37`KX00P11JN460<O1^P03045Yh@37`KX0al6j
00@0al6j0P11JN430<O1^P040:f][@38`K/0@FWQ045Yh@@0b<6k1011JN420<S1^`80@FWQ1`38`K/0
102][Jd0b<6k0<S1^`11JN4B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@36
`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d
/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0040:f][@31
^[00@FWQ045YhA40`KZ`00<0[Jf]0<>m/`33_K<03@33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0@0<Jo]`03045Yh@36_kL0a[ng0080a[ng00<0[Jf]0<O1^037`KP0
0P37`KP2045Yh@D0al6h0P11JN400`37`KP0@FWQ0<O1^0020<O1^080@FWQ0`37`KP01@2][Jd0al6j
0<O1^P37`KX0@FWQ00D0al6j00<0@FWQ0<O1^P37`KX01@37`KX5045Yh@040:f][@38`K/0@FWQ045Y
h@80b<6k0`11JN460<S1^`80@FWQ1P38`K/0102][Jd0b<6k0<S1^`11JN4B0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd01@2n]j`0[Jf]0<6j/031
^[00@FWQ0140`KZ`00<0[Jf]0<>m/`33_K<03@33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0@0<Jo]`03045Yh@36_kL0a[ng0080a[ng00<0[Jf]0<O1^037`KP00P37
`KP2045Yh@80al6h1@11JN420<O1^0@0@FWQ1037`KP00`2][Jd0al6j0<O1^P020<O1^PD0@FWQ1P37
`KX4045Yh@<0al6j00<0[Jf]0<S1^`38`K/03038`K/2045Yh@H0b<6k00@0[Jf]0<S1^`11JN40@FWQ
4P38`K/00`2][Jd0al6l0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33_K<0`kfc00d0`kfc0P11
JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04036_kL00`11JN40a[ng0<Jo
]`020<Jo]`040:f][@37`KP0al6h0<O1^080@FWQ4P37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k00`0b<6k0P11JN460<S1^`040:f][@38`K/0@FWQ045YhA80b<6k00<0[Jf]0<O1_037
`K`02`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd:0<6j/003
0:f][@33_K<0`kfc00d0`kfc0P11JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL04036_kL00`11JN40a[ng0<Jo]`020<Jo]`040:f][@37`KP0al6h0<O1^080@FWQ4P37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00d0b<6k00<0@FWQ0<S1^`38`K/01038`K/0102]
[Jd0b<6k045Yh@11JN4B0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H1
0?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc00d0`kfc0P11JN440<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04036_kL00`11JN40a[ng0<Jo]`020<Jo
]`040:f][@37`KP0al6h0<O1^080@FWQ4P37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k00d0b<6k00<0@FWQ0<S1^`38`K/01038`K/0102][Jd0@FWQ045Yh@11JN4B0<S1^`030:f][@37
`K`0al6l00D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]3033_K<2
045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0@0<Jo]`03045Yh@36_kL0
a[ng0080a[ng00D0[Jf]0<O1^037`KP0al6h045Yh@0C0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/03@38`K/2045Yh@D0b<6k00@0[Jf]045Yh@38`K/0@FWQ3`38`K/60:f][A80al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh
0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004@31^[000`000000[Jf]0<>m/`020<>m/`L0[Jf]1P33
_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL04036
_kL00`11JN40a[ng0<Jo]`020<Jo]`050:f][@37`KP0al6h0<O1^011JN404`37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k00h0b<6k0P11JN430<S1^`80@FWQ0P38`K/00`11JN40b<6k
0<S1^`060<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2]
[Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng0100a[ng00<0@FWQ0<Jo]`36_kL00P36_kL0102][Jd0al6h0<O1^011JN4D0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/04038`K/3045Yh@030<S1^`2][Jd0b<6k0080b<6k
202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JdA0<Fn]@030:f][@36
_kL0a[ng0100a[ng00<0@FWQ0<Jo]`36_kL00P36_kL0102][Jd0al6h045Yh@11JN4D0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo
001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo
]`0=0<Jo]`X0@FWQ5P37`KP00`2][Jd0al6j0<O1^P0D0<O1^P8000001038`K/<0:f][@D0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0
[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f]
[H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038
`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f]
[@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k
0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f]
[Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52402 .33862 m
.54057 .33848 L
s
.54057 .33848 m
.54389 .34068 L
s
.54057 .33848 m
.54554 .34064 L
s
.54389 .34068 m
.54721 .34512 L
s
.54554 .34064 m
.54886 .34508 L
s
.55874 .33805 m
.57026 .33763 L
s
.54721 .34512 m
.54888 .3496 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54886 .34508 m
.55053 .34956 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54888 .3496 m
.55055 .35634 L
s
.55053 .34956 m
.55221 .3563 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52899 .3386 m
.52903 .38617 L
s
.53064 .33859 m
.53069 .38616 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56368 .33788 m
.56384 .36957 L
s
.56533 .33782 m
.56549 .36951 L
s
.55055 .35634 m
.55059 .36768 L
s
.55221 .3563 m
.55225 .36764 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56542 .3559 m
.56711 .36264 L
s
.59317 .3387 m
.59802 .33612 L
s
.59158 .34332 m
.59317 .3387 L
s
.59479 .33859 m
.59802 .33612 L
s
.59321 .34322 m
.59479 .33859 L
s
.59802 .33612 m
.60288 .33578 L
s
.59158 .34332 m
.59162 .34784 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54896 .37453 m
.55059 .36768 L
s
.59321 .34322 m
.59325 .34775 L
s
.55061 .37449 m
.55225 .36764 L
s
.60288 .33578 m
.60614 .33781 L
s
.56711 .36264 m
.57043 .36705 L
s
.59162 .34784 m
.59329 .35228 L
s
.59325 .34775 m
.59492 .35218 L
s
.55888 .36973 m
.56549 .36951 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54731 .37911 m
.54896 .37453 L
s
.577 .3645 m
.57863 .36215 L
s
.4338 .33512 m
.43539 .33751 L
s
.43217 .33726 m
.4338 .33512 L
s
.43375 .33965 m
.43539 .33751 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.577 .3645 m
.57866 .36669 L
s
.57863 .36215 m
.58029 .36434 L
s
.57043 .36705 m
.57374 .36919 L
s
.54897 .37907 m
.55061 .37449 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59329 .35228 m
.59819 .35424 L
s
.60614 .33781 m
.60941 .34209 L
s
.59492 .35218 m
.59819 .35424 L
s
.544 .38372 m
.54731 .37911 L
s
.54566 .38369 m
.54897 .37907 L
s
.61097 .33744 m
.61416 .33491 L
s
.60941 .34209 m
.61097 .33744 L
s
.58029 .36434 m
.5803 .36661 L
s
.61416 .33491 m
.61577 .33478 L
s
.61258 .33731 m
.61416 .33491 L
s
.57374 .36919 m
.57868 .36897 L
s
.61102 .34197 m
.61258 .33731 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43217 .33726 m
.43375 .33965 L
s
.57868 .36897 m
.5803 .36661 L
s
.60941 .34209 m
.60963 .36254 L
s
.52403 .38618 m
.54068 .38605 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54068 .38605 m
.544 .38372 L
s
.54068 .38605 m
.54566 .38369 L
s
.59819 .35424 m
.60794 .35583 L
s
.61102 .34197 m
.61119 .35786 L
s
.59337 .36136 m
.59338 .36363 L
s
.59337 .36136 m
.595 .36126 L
s
.595 .36126 m
.59502 .36353 L
s
.59338 .36363 m
.59504 .36581 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59504 .36581 m
.59832 .36788 L
s
.43363 .35099 m
.43495 .37846 L
s
.43171 .37822 m
.43363 .35099 L
s
.60794 .35583 m
.60958 .35799 L
s
.41622 .33357 m
.41937 .33614 L
s
.41937 .33614 m
.42094 .33855 L
s
.42085 .34536 m
.42094 .33855 L
s
.40989 .33293 m
.41622 .33357 L
s
.59832 .36788 m
.60482 .36744 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60963 .36254 m
.61119 .35786 L
s
.41926 .34522 m
.42088 .34309 L
s
.41923 .34749 m
.42085 .34536 L
s
.60803 .36493 m
.60963 .36254 L
s
.60482 .36744 m
.60803 .36493 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41604 .34719 m
.41926 .34522 L
s
.40671 .33487 m
.40989 .33293 L
s
.41601 .34947 m
.41923 .34749 L
s
.43333 .37834 m
.43348 .36465 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62576 .36578 m
.63021 .34028 L
s
.62416 .36593 m
.63012 .33347 L
s
.63012 .33347 m
.63689 .36473 L
s
.4051 .33697 m
.40671 .33487 L
s
.4036 .33225 m
.4051 .33697 L
s
.40346 .34135 m
.4036 .33225 L
s
.41905 .36116 m
.42071 .35674 L
s
.42059 .36587 m
.42071 .35674 L
s
.40346 .34135 m
.4051 .33697 L
s
.61935 .36634 m
.63054 .36535 L
s
.43328 .38292 m
.43495 .37846 L
s
.41743 .3633 m
.41905 .36116 L
s
.41905 .36116 m
.42059 .36587 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40803 .35325 m
.41601 .34947 L
s
.40806 .35096 m
.41604 .34719 L
s
.43171 .37822 m
.43328 .38292 L
s
.41421 .36529 m
.41743 .3633 L
s
.40487 .35292 m
.40806 .35096 L
s
.40484 .3552 m
.40803 .35325 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64274 .33215 m
.64948 .3634 L
s
.63689 .36473 m
.64274 .33215 L
s
.63848 .36457 m
.64284 .33897 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40786 .36467 m
.41421 .36529 L
s
.40326 .35503 m
.40487 .35292 L
s
.40323 .35732 m
.40484 .3552 L
s
.38954 .33288 m
.39256 .33782 L
s
.38495 .33001 m
.38954 .33288 L
s
.4032 .35961 m
.40326 .35503 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40474 .36206 m
.40786 .36467 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38188 .3296 m
.38495 .33001 L
s
.4032 .35961 m
.40474 .36206 L
s
.37878 .33147 m
.38188 .3296 L
s
.37726 .33126 m
.38188 .3296 L
s
0 0 0 r
.686 .31855 m
.68789 .31826 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36286 .32238 m
.36433 .32106 L
s
.255 .412 .882 r
.66302 .33653 m
.666 .33155 L
s
.66156 .3413 m
.66302 .33653 L
s
.39227 .35609 m
.39231 .35381 L
s
.39079 .35133 m
.39231 .35381 L
s
.3892 .35343 m
.39079 .35133 L
s
.666 .33155 m
.67053 .32863 L
s
.37565 .33562 m
.37878 .33147 L
s
.66455 .33633 m
.66753 .33134 L
s
.66309 .3411 m
.66455 .33633 L
s
.38909 .36031 m
.39227 .35609 L
s
.66753 .33134 m
.67053 .32863 L
s
.37413 .3354 m
.37726 .33126 L
s
.3892 .35343 m
.39072 .35591 L
s
.67053 .32863 m
.67356 .3282 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66167 .34816 m
.66309 .3411 L
s
.66013 .34836 m
.66156 .3413 L
s
.64478 .36391 m
.65416 .36286 L
s
.66013 .34836 m
.66033 .35982 L
s
.66167 .34816 m
.66187 .35962 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67356 .3282 m
.67813 .32981 L
s
.37401 .34227 m
.37565 .33562 L
s
.38595 .36223 m
.38909 .36031 L
s
.37249 .34205 m
.37413 .3354 L
s
.66033 .35982 m
.66199 .36652 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38133 .36165 m
.38595 .36223 L
s
.35628 .32578 m
.36671 .32743 L
s
.66187 .35962 m
.66353 .36632 L
s
.37392 .34685 m
.37401 .34227 L
s
.67813 .32981 m
.68122 .33393 L
s
.3724 .34664 m
.37249 .34205 L
s
.68108 .32706 m
.68144 .34541 L
s
.37392 .34685 m
.37532 .35395 L
s
.3783 .35895 m
.38133 .36165 L
s
.37676 .35875 m
.38133 .36165 L
s
.66199 .36652 m
.66361 .37093 L
s
.68258 .32683 m
.68294 .34518 L
s
.3724 .34664 m
.3738 .35374 L
s
.37532 .35395 m
.3783 .35895 L
s
.66353 .36632 m
.66515 .37073 L
s
.3738 .35374 m
.37676 .35875 L
s
.66361 .37093 m
.66677 .37515 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66515 .37073 m
.6683 .37495 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36158 .35891 m
.36222 .32674 L
s
.36009 .35868 m
.36073 .3265 L
s
.66677 .37515 m
.67141 .37686 L
s
.6683 .37495 m
.67141 .37686 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67692 .34608 m
.68741 .34448 L
s
.69148 .32538 m
.7017 .32359 L
s
.34023 .32295 m
.35039 .32478 L
s
.67141 .37686 m
.67446 .37645 L
s
.67446 .37645 m
.67896 .37351 L
s
.35562 .35799 m
.36158 .35891 L
s
.34546 .34936 m
.34601 .32401 L
s
.68326 .3613 m
.68353 .37518 L
s
.68189 .36845 m
.68326 .3613 L
s
.34401 .34911 m
.34456 .32375 L
s
.67896 .37351 m
.68189 .36845 L
s
.68189 .36845 m
.68353 .37518 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35976 .37487 m
.36131 .37277 L
s
.35985 .37024 m
.36131 .37277 L
s
.35831 .37233 m
.35985 .37024 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69215 .35761 m
.69803 .35665 L
s
.69773 .34279 m
.69935 .34946 L
s
.69734 .32437 m
.69803 .35665 L
s
.69588 .32463 m
.69657 .35689 L
s
.35831 .37233 m
.35976 .37487 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69935 .34946 m
.70236 .35359 L
s
.3439 .35374 m
.34546 .34936 L
s
.32465 .31986 m
.33451 .32186 L
s
.34245 .35348 m
.34401 .34911 L
s
.3395 .35529 m
.3439 .35374 L
s
.70236 .35359 m
.70531 .35539 L
s
.3291 .36975 m
.33026 .32102 L
s
.3395 .35529 m
.34245 .35348 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32769 .36948 m
.32885 .32073 L
s
.70531 .35539 m
.70963 .35461 L
s
.33662 .35477 m
.3395 .35529 L
s
.70809 .35024 m
.70958 .35229 L
s
.70809 .35024 m
.70947 .34766 L
s
.70947 .34766 m
.71095 .34971 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33239 .35166 m
.33662 .35477 L
s
.71095 .34971 m
.71101 .35203 L
s
.70963 .35461 m
.71101 .35203 L
s
.72163 .322 m
.72573 .31879 L
s
.72035 .32691 m
.72163 .322 L
s
.72035 .32691 m
.72047 .33154 L
s
.72302 .3217 m
.72573 .31879 L
s
.72175 .32662 m
.72302 .3217 L
s
.72175 .32662 m
.72186 .33125 L
s
.32965 .34647 m
.33239 .35166 L
s
.72047 .33154 m
.72197 .33589 L
s
.72573 .31879 m
.72985 .31788 L
s
.72186 .33125 m
.72337 .3356 L
s
.72197 .33589 m
.7262 .33734 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72337 .3356 m
.7262 .33734 L
s
0 0 0 r
.73186 .33564 m
.73188 .33634 L
s
.255 .412 .882 r
.7222 .34518 m
.72226 .34751 L
s
.7222 .34518 m
.7236 .3449 L
s
.72226 .34751 m
.72371 .34955 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73019 .33936 m
.73043 .33719 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72985 .31788 m
.73263 .31958 L
s
.7236 .3449 m
.72365 .34722 L
s
.7262 .33734 m
.73447 .33787 L
s
.31222 .31945 m
.31482 .32471 L
s
.31482 .32471 m
.31601 .33198 L
s
.73263 .31958 m
.73546 .3236 L
s
.30824 .31619 m
.31222 .31945 L
s
.32346 .36867 m
.3291 .36975 L
s
.31589 .33663 m
.31601 .33198 L
s
.31087 .31914 m
.31346 .3244 L
s
.31346 .3244 m
.31464 .33168 L
s
.72371 .34955 m
.72655 .35131 L
s
.30824 .31619 m
.31087 .31914 L
s
.29553 .2966 m
.30467 .29898 L
s
.31452 .33633 m
.31464 .33168 L
s
.31434 .34332 m
.31589 .33663 L
s
.31298 .34302 m
.31452 .33633 L
s
.30557 .31554 m
.30824 .31619 L
s
.73668 .31863 m
.73929 .31567 L
s
.73546 .3236 m
.73668 .31863 L
s
.74283 .29844 m
.75192 .29604 L
s
.72655 .35131 m
.73205 .35014 L
s
.73802 .31832 m
.73929 .31567 L
s
.7368 .32328 m
.73802 .31832 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73929 .31567 m
.74062 .31535 L
s
.29938 .34695 m
.30072 .29797 L
s
.31149 .34739 m
.31434 .34332 L
s
.30285 .31722 m
.30557 .31554 L
s
.31014 .34709 m
.31298 .34302 L
s
.29807 .34663 m
.29942 .29763 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73205 .35014 m
.73471 .34721 L
s
.74675 .29742 m
.74811 .34644 L
s
.73447 .33787 m
.73588 .3399 L
s
.7368 .32328 m
.73723 .33959 L
s
.73546 .3236 m
.73601 .34457 L
s
.74805 .29708 m
.74942 .34612 L
s
.30009 .32122 m
.30285 .31722 L
s
.30737 .34882 m
.31149 .34739 L
s
.73471 .34721 m
.73601 .34457 L
s
.73601 .34457 m
.73723 .33959 L
s
.30737 .34882 m
.31014 .34709 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30469 .3482 m
.30737 .34882 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30209 .34524 m
.30469 .3482 L
s
.7487 .32036 m
.75116 .31501 L
s
.75116 .31501 m
.75366 .31199 L
s
.29957 .33992 m
.30209 .34524 L
s
.29122 .31186 m
.2925 .3122 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75366 .31199 m
.75621 .3113 L
s
0 0 0 r
.28433 .30564 m
.28467 .30671 L
s
.255 .412 .882 r
.74416 .34739 m
.74942 .34612 L
s
.28861 .3135 m
.29122 .31186 L
s
.28987 .31384 m
.29122 .31186 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29415 .34566 m
.29938 .34695 L
s
.28847 .31817 m
.28987 .31384 L
s
.75621 .3113 m
.75881 .31293 L
s
.75621 .3113 m
.76006 .31258 L
s
.74922 .33907 m
.75195 .34312 L
s
.2872 .31783 m
.28861 .3135 L
s
.288 .3346 m
.28847 .31817 L
s
.75881 .31293 m
.76145 .31691 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28483 .31244 m
.2872 .31783 L
s
.28659 .33896 m
.2872 .31783 L
s
.75195 .34312 m
.7546 .34481 L
s
.76006 .31258 m
.7627 .31655 L
s
.28241 .30938 m
.28483 .31244 L
s
.27871 .30828 m
.28241 .30938 L
s
.76145 .31691 m
.76291 .3236 L
s
.7546 .34481 m
.75716 .34414 L
s
.28659 .33896 m
.288 .3346 L
s
.7627 .31655 m
.76415 .32324 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28553 .33156 m
.28673 .33426 L
s
.27814 .3271 m
.28553 .33156 L
s
.75716 .34414 m
.75963 .34111 L
s
.75716 .34414 m
.76089 .34077 L
s
.28526 .34098 m
.28659 .33896 L
s
.76291 .3236 m
.76305 .3283 L
s
.2762 .30989 m
.27871 .30828 L
s
.27499 .30952 m
.27871 .30828 L
s
.75963 .34111 m
.762 .33571 L
s
.76415 .32324 m
.76429 .32795 L
s
.762 .33571 m
.76305 .3283 L
s
.28268 .34265 m
.28526 .34098 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76089 .34077 m
.76325 .33537 L
s
.76325 .33537 m
.76429 .32795 L
s
.27485 .31423 m
.2762 .30989 L
s
.27364 .31386 m
.27499 .30952 L
s
.77105 .30695 m
.77934 .30427 L
s
.27772 .34126 m
.28268 .34265 L
s
.27577 .32402 m
.27814 .3271 L
s
.27456 .32365 m
.27814 .3271 L
s
.2747 .31894 m
.27485 .31423 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2735 .31857 m
.27364 .31386 L
s
.2747 .31894 m
.27577 .32402 L
s
.2735 .31857 m
.27456 .32365 L
s
.27534 .33819 m
.27772 .34126 L
s
.27427 .3331 m
.27548 .33346 L
s
.27541 .33582 m
.27548 .33346 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2742 .33546 m
.27427 .3331 L
s
.2742 .33546 m
.27534 .33819 L
s
.77663 .33142 m
.77914 .33542 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78394 .3027 m
.79177 .29988 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77257 .3566 m
.77738 .35519 L
s
.77582 .30543 m
.77738 .35519 L
s
.77464 .30581 m
.77618 .35554 L
s
.77914 .33542 m
.78271 .33668 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2636 .32977 m
.26469 .33253 L
s
.26461 .3349 m
.26469 .33253 L
s
.78733 .3015 m
.78819 .32763 L
s
.26237 .33177 m
.2636 .32977 L
s
.26337 .33691 m
.26461 .3349 L
s
.78845 .3011 m
.78931 .32724 L
s
.26237 .33177 m
.26345 .33453 L
s
.25992 .33577 m
.26337 .33691 L
s
.78271 .33668 m
.78501 .33593 L
s
.25428 .33385 m
.25539 .30053 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25101 .29889 m
.25873 .30175 L
s
.25318 .33346 m
.25428 .30013 L
s
.78501 .33593 m
.78721 .33278 L
s
.78501 .33593 m
.78834 .33239 L
s
.25772 .33263 m
.25992 .33577 L
s
.78721 .33278 m
.78819 .32763 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25563 .32708 m
.25772 .33263 L
s
.25476 .31954 m
.25563 .32708 L
s
.78834 .33239 m
.78931 .32724 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24989 .33228 m
.25428 .33385 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79928 .29696 m
.80043 .33043 L
s
.7961 .29822 m
.80343 .29525 L
s
.24398 .31548 m
.24464 .29637 L
s
.23986 .3138 m
.24715 .31671 L
s
.24294 .31506 m
.2436 .29594 L
s
.24146 .29747 m
.24336 .3031 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23851 .29378 m
.24146 .29747 L
s
.23652 .2929 m
.23851 .29378 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79723 .33164 m
.80148 .33003 L
s
.80033 .29654 m
.80148 .33003 L
s
.24291 .34672 m
.24341 .33227 L
s
.24211 .33909 m
.24341 .33227 L
s
.79986 .34526 m
.80084 .34246 L
s
.79986 .34526 m
.801 .34727 L
s
.80084 .34246 m
.80198 .34447 L
s
.23448 .29441 m
.23652 .2929 L
s
.23351 .29397 m
.23652 .2929 L
s
.801 .34727 m
.80198 .34447 L
s
.80873 .30026 m
.81052 .29459 L
s
.80798 .30789 m
.80873 .30026 L
s
.80798 .30789 m
.80815 .31269 L
s
.23988 .3431 m
.24211 .33909 L
s
.24211 .33909 m
.24291 .34672 L
s
.80971 .29983 m
.8115 .29415 L
s
.80898 .30746 m
.80971 .29983 L
s
.81052 .29459 m
.81334 .29086 L
s
.80815 .31269 m
.80941 .31949 L
s
.80898 .30746 m
.80915 .31227 L
s
.23237 .29833 m
.23448 .29441 L
s
.8115 .29415 m
.81334 .29086 L
s
.80915 .31227 m
.8104 .31906 L
s
.23141 .29788 m
.23351 .29397 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23674 .3443 m
.23988 .3431 L
s
.81334 .29086 m
.81523 .28995 L
s
.80941 .31949 m
.81155 .32346 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23124 .3027 m
.23237 .29833 L
s
.8104 .31906 m
.81253 .32303 L
s
.23029 .30225 m
.23141 .29788 L
s
.81523 .28995 m
.81811 .291 L
s
.23003 .30949 m
.23124 .3027 L
s
.81155 .32346 m
.81455 .32459 L
s
.23473 .34348 m
.23674 .3443 L
s
.22908 .30905 m
.23029 .30225 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81253 .32303 m
.81455 .32459 L
s
0 0 0 r
.22076 .27794 m
.22257 .27888 L
s
.255 .412 .882 r
.22959 .32157 m
.23003 .30949 L
s
.23284 .34023 m
.23473 .34348 L
s
.23187 .33981 m
.23473 .34348 L
s
.81811 .291 m
.82011 .29491 L
s
.22864 .32114 m
.22908 .30905 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81455 .32459 m
.8174 .3233 L
s
.23107 .33454 m
.23284 .34023 L
s
.22959 .32157 m
.23028 .32927 L
s
.23011 .33412 m
.23187 .33981 L
s
.23028 .32927 m
.23107 .33454 L
s
.22864 .32114 m
.22933 .32884 L
s
.22933 .32884 m
.23011 .33412 L
s
.8174 .3233 m
.81917 .32 L
s
.81891 .31273 m
.81974 .30986 L
s
.81891 .31273 m
.81991 .31471 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81974 .30986 m
.82074 .31184 L
s
.81917 .32 m
.82083 .31427 L
s
.82074 .31184 m
.82083 .31427 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21949 .31915 m
.22484 .32181 L
s
.2199 .28469 m
.22213 .32049 L
s
.21524 .31688 m
.2199 .28469 L
s
.826 .28441 m
.82636 .2941 L
s
.21608 .31733 m
.21963 .29195 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.826 .28441 m
.82703 .28878 L
s
.82636 .2941 m
.82703 .28878 L
s
.82703 .28878 m
.82778 .28588 L
s
.82778 .28588 m
.82935 .2825 L
s
.82935 .2825 m
.83257 .28057 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82691 .30867 m
.82767 .30578 L
s
.82691 .30867 m
.82709 .31355 L
s
.827 .31111 m
.82776 .30822 L
s
.82767 .30578 m
.82926 .30242 L
s
.82709 .31355 m
.82804 .31553 L
s
.82776 .30822 m
.82935 .30486 L
s
.2133 .28087 m
.21524 .31688 L
s
.20885 .31317 m
.2133 .28087 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82935 .30486 m
.83322 .29763 L
s
.82804 .31553 m
.82981 .31706 L
s
.82926 .30242 m
.83313 .29519 L
s
.83257 .28057 m
.83423 .28203 L
s
.20962 .31364 m
.21302 .28816 L
s
.82981 .31706 m
.83308 .31522 L
s
.83423 .28203 m
.83509 .28399 L
s
.83313 .29519 m
.8346 .29179 L
s
.83322 .29763 m
.8347 .29423 L
s
.83509 .28399 m
.83538 .29131 L
s
.8346 .29179 m
.83528 .28887 L
s
.8347 .29423 m
.83538 .29131 L
s
.83308 .31522 m
.83458 .31184 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20659 .31176 m
.21199 .31504 L
s
.83458 .31184 m
.83527 .30892 L
s
.83527 .30892 m
.83585 .30354 L
s
.83527 .30892 m
.83623 .31336 L
s
.83585 .30354 m
.83623 .31336 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20575 .27595 m
.20647 .27644 L
s
.20424 .27739 m
.20575 .27595 L
s
.20494 .27789 m
.20575 .27595 L
s
.84017 .27809 m
.84077 .27514 L
s
.84017 .27809 m
.84097 .28004 L
s
.20405 .2823 m
.20494 .27789 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84077 .27514 m
.84157 .27709 L
s
.20335 .2818 m
.20424 .27739 L
s
.84097 .28004 m
.84157 .27709 L
s
.20337 .2995 m
.20405 .2823 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20218 .27588 m
.20335 .2818 L
s
.20248 .30395 m
.20335 .2818 L
s
.84145 .29232 m
.84332 .32145 L
s
.84145 .29232 m
.84191 .3224 L
s
.20095 .27241 m
.20218 .27588 L
s
.20248 .30395 m
.20337 .2995 L
s
.19903 .27088 m
.20095 .27241 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84203 .30709 m
.84262 .32193 L
s
.20208 .29606 m
.20267 .29902 L
s
.20169 .30593 m
.20248 .30395 L
s
.84191 .3224 m
.84281 .32688 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19823 .29061 m
.20208 .29606 L
s
.20024 .30744 m
.20169 .30593 L
s
.19768 .27231 m
.19903 .27088 L
s
.19708 .2718 m
.19903 .27088 L
s
.84281 .32688 m
.84332 .32145 L
s
.19764 .30548 m
.20024 .30744 L
s
.19688 .27673 m
.19768 .27231 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19628 .27622 m
.19708 .2718 L
s
.19709 .28713 m
.19823 .29061 L
s
.19648 .28663 m
.19823 .29061 L
s
.19668 .28168 m
.19688 .27673 L
s
.19668 .28168 m
.19709 .28713 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19608 .28117 m
.19628 .27622 L
s
.19608 .28117 m
.19648 .28663 L
s
.19649 .30201 m
.19764 .30548 L
s
.19608 .29655 m
.19669 .29705 L
s
.19659 .29953 m
.19669 .29705 L
s
.19598 .29903 m
.19649 .30201 L
s
.19598 .29903 m
.19608 .29655 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19098 .29199 m
.19141 .295 L
s
.1913 .2975 m
.19141 .295 L
s
.19067 .29949 m
.1913 .2975 L
s
.19035 .29398 m
.19098 .29199 L
s
.18648 .25818 m
.1896 .26196 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19035 .29398 m
.19077 .29699 L
s
.18913 .29797 m
.19067 .29949 L
s
.18675 .2954 m
.18821 .26035 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18825 .29444 m
.18913 .29797 L
s
.1863 .29489 m
.18776 .25981 L
s
.18752 .28839 m
.18825 .29444 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18737 .28034 m
.18752 .28839 L
s
.18501 .29333 m
.18675 .2954 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18386 .26244 m
.18401 .26802 L
s
.18401 .26802 m
.18406 .27611 L
s
.18338 .25632 m
.18386 .26244 L
s
.18353 .28872 m
.18406 .27611 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18351 .2619 m
.18365 .26748 L
s
.18365 .26748 m
.18369 .27557 L
s
.18305 .25577 m
.18351 .2619 L
s
.18316 .2882 m
.18369 .27557 L
s
.18252 .25215 m
.18338 .25632 L
s
.18252 .25215 m
.18305 .25577 L
s
.18284 .29579 m
.18353 .28872 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18248 .29527 m
.18316 .2882 L
s
.17995 .24657 m
.18252 .25215 L
s
.18226 .30034 m
.18284 .29579 L
s
.18191 .29982 m
.18248 .29527 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18135 .30439 m
.18226 .30034 L
s
.18102 .30387 m
.18191 .29982 L
s
.18027 .30538 m
.18135 .30439 L
s
.17858 .30226 m
.18086 .24881 L
s
.18027 .30538 m
.18102 .30387 L
s
.17834 .30174 m
.18061 .24825 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17766 .30017 m
.18027 .30538 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86644 .24341 m
.86875 .29721 L
s
.86629 .24397 m
.86859 .29774 L
s
.86576 .24567 m
.86716 .24 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86716 .24 m
.86743 .24142 L
s
.86716 .24 m
.86749 .24085 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86805 .29932 m
.86948 .29402 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86749 .24085 m
.8678 .24484 L
s
.86743 .24142 m
.86776 .24541 L
s
.86776 .24541 m
.86802 .24998 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8678 .24484 m
.86805 .24942 L
s
0 0 0 r
.8715 .22931 m
.87166 .2324 L
s
.87134 .22506 m
.8715 .22931 L
s
.255 .412 .882 r
.86802 .24998 m
.86839 .25715 L
s
0 0 0 r
.8715 .22814 m
.87134 .22506 L
s
.255 .412 .882 r
.86805 .24942 m
.86841 .25659 L
s
0 0 0 r
.87166 .2324 m
.8715 .22814 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86948 .29402 m
.86959 .28983 L
s
.86948 .29402 m
.86953 .29036 L
s
.86839 .25715 m
.86894 .27006 L
s
.86841 .25659 m
.86896 .26951 L
s
.86942 .2841 m
.86953 .29036 L
s
.86704 .22967 m
.8675 .2337 L
s
.86947 .28356 m
.86959 .28983 L
s
.86894 .27006 m
.86924 .27838 L
s
.86924 .27838 m
.86942 .2841 L
s
.86896 .26951 m
.86927 .27783 L
s
.86927 .27783 m
.86947 .28356 L
s
.86737 .23197 m
.86892 .26825 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87246 .25079 m
.8744 .29473 L
s
.87246 .25079 m
.87439 .29581 L
s
.255 .412 .882 r
.8673 .2314 m
.86886 .2677 L
s
0 0 0 r
.8744 .29527 m
.87343 .27297 L
s
.87133 .22772 m
.87108 .22344 L
s
.87181 .2388 m
.87133 .22772 L
s
.87108 .22344 m
.87071 .21857 L
s
.255 .412 .882 r
.86886 .2677 m
.86905 .2699 L
s
0 0 0 r
.87172 .23823 m
.87165 .23511 L
s
.87439 .29581 m
.87472 .30273 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87015 .2162 m
.87071 .21857 L
s
.87189 .24193 m
.87181 .2388 L
s
.255 .412 .882 r
.86819 .2521 m
.86845 .25934 L
s
0 0 0 r
.87167 .24078 m
.87172 .23823 L
s
.87472 .30273 m
.8744 .29473 L
s
.87183 .24449 m
.87189 .24193 L
s
.255 .412 .882 r
.86845 .25934 m
.86849 .26343 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87262 .25735 m
.87285 .26423 L
s
.87327 .27224 m
.87262 .25735 L
s
.87127 .24535 m
.87167 .24078 L
s
.86996 .21872 m
.87015 .2162 L
s
.87143 .24908 m
.87183 .24449 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86849 .26343 m
.86837 .26494 L
s
0 0 0 r
.87285 .26423 m
.87292 .2674 L
s
.87285 .26423 m
.87327 .27224 L
s
.86993 .22185 m
.86996 .21872 L
s
.87292 .2674 m
.87284 .27002 L
s
.255 .412 .882 r
.86837 .26494 m
.86795 .26328 L
s
0 0 0 r
.86941 .21383 m
.86993 .22185 L
s
.86941 .21383 m
.87006 .2287 L
s
.86993 .22185 m
.87006 .2287 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86784 .26066 m
.86788 .2586 L
s
.86762 .25543 m
.86788 .2586 L
s
.86757 .25749 m
.86762 .25543 L
s
0 0 0 r
.87284 .27002 m
.87224 .26779 L
s
.87106 .24794 m
.87127 .24535 L
s
.87123 .25168 m
.87143 .24908 L
s
.255 .412 .882 r
.86768 .2601 m
.86795 .26328 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86757 .25749 m
.86768 .2601 L
s
0 0 0 r
.87103 .25111 m
.87106 .24794 L
s
.87119 .25486 m
.87123 .25168 L
s
.87224 .26779 m
.87171 .26292 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87103 .25111 m
.87135 .25861 L
s
.87135 .25861 m
.87171 .26292 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86726 .21222 m
.86818 .22088 L
s
.86613 .20671 m
.86726 .21222 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86898 .23962 m
.86931 .24714 L
s
.86474 .23275 m
.86898 .23962 L
s
.86542 .20552 m
.86613 .20671 L
s
.86869 .23904 m
.86918 .25033 L
s
.86931 .24714 m
.86934 .25411 L
s
.86483 .20809 m
.86542 .20552 L
s
.86444 .2075 m
.86542 .20552 L
s
.86918 .25033 m
.8692 .25732 L
s
.8692 .25732 m
.86934 .25411 L
s
.86435 .21444 m
.86483 .20809 L
s
.86873 .25999 m
.8692 .25732 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86394 .21386 m
.86444 .2075 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86768 .25832 m
.86873 .25999 L
s
.86435 .21444 m
.86442 .22518 L
s
.86394 .21386 m
.86399 .2246 L
s
.86442 .22518 m
.86474 .23275 L
s
.86677 .2534 m
.86768 .25832 L
s
.86637 .25284 m
.86768 .25832 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86399 .2246 m
.86432 .23217 L
s
.8592 .19726 m
.86121 .19961 L
s
.86474 .23275 m
.86565 .24469 L
s
.86565 .24469 m
.86677 .2534 L
s
.86432 .23217 m
.86523 .24412 L
s
.86523 .24412 m
.86637 .25284 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85972 .19784 m
.8631 .27799 L
s
.255 .412 .882 r
.85721 .24558 m
.85847 .24703 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85764 .23057 m
.8579 .23343 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18684 .23689 m
.1871 .24167 L
s
.18639 .24756 m
.18684 .23689 L
s
.85714 .22936 m
.85827 .24226 L
s
0 0 0 r
.85829 .19987 m
.85968 .20861 L
s
.85701 .19491 m
.85829 .19987 L
s
.255 .412 .882 r
.1871 .24167 m
.18639 .24756 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85585 .19374 m
.85701 .19491 L
s
.18978 .19351 m
.20082 .18425 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8553 .22897 m
.85536 .22516 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85417 .19579 m
.85585 .19374 L
s
.8548 .19637 m
.85585 .19374 L
s
.86021 .2456 m
.86096 .23906 L
s
.85386 .20284 m
.8548 .19637 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18827 .27245 m
.19162 .19176 L
s
.85321 .20226 m
.85417 .19579 L
s
.18892 .27192 m
.19226 .19117 L
s
.85368 .21374 m
.85386 .20284 L
s
.86095 .27585 m
.8631 .27799 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8592 .19726 m
.86258 .27745 L
s
.85925 .24834 m
.86021 .2456 L
s
.85303 .21317 m
.85321 .20226 L
s
.85808 .24724 m
.85925 .24834 L
s
.85368 .21374 m
.854 .22141 L
s
.85671 .24229 m
.85808 .24724 L
s
.85608 .24174 m
.85808 .24724 L
s
.85303 .21317 m
.85334 .22084 L
s
.854 .22141 m
.85513 .23349 L
s
.85513 .23349 m
.85671 .24229 L
s
.85334 .22084 m
.85448 .23293 L
s
.85448 .23293 m
.85608 .24174 L
s
.19052 .23327 m
.19461 .22995 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18642 .27404 m
.19754 .26563 L
s
.8458 .18889 m
.84762 .1977 L
s
.19397 .24543 m
.19524 .21454 L
s
.19989 .20733 m
.20005 .18482 L
s
.84329 .18334 m
.8458 .18889 L
s
.19989 .20733 m
.20082 .18425 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84167 .1822 m
.84329 .18334 L
s
.84841 .21694 m
.84872 .22466 L
s
.84766 .21638 m
.84813 .22798 L
s
.84828 .23185 m
.84872 .22466 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84015 .18492 m
.84167 .1822 L
s
.8393 .18436 m
.84167 .1822 L
s
.255 .412 .882 r
.83675 .19249 m
.8368 .19252 L
s
0 0 0 r
.84768 .23519 m
.84813 .22798 L
s
.84768 .23519 m
.84828 .23185 L
s
.83874 .19152 m
.84015 .18492 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83786 .19096 m
.8393 .18436 L
s
.255 .412 .882 r
.2045 .22665 m
.20532 .22368 L
s
0 0 0 r
.84627 .23799 m
.84768 .23519 L
s
.255 .412 .882 r
.20532 .22368 m
.2063 .21623 L
s
.20439 .22935 m
.20614 .22314 L
s
.20614 .22314 m
.2071 .2158 L
s
0 0 0 r
.83832 .20258 m
.83874 .19152 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84384 .23639 m
.84627 .23799 L
s
.19676 .26615 m
.19848 .24221 L
s
.19754 .26563 m
.19848 .24221 L
s
.20908 .18245 m
.21197 .17692 L
s
.20788 .19074 m
.20908 .18245 L
s
.20619 .23352 m
.20788 .19074 L
s
.20998 .1819 m
.21197 .17692 L
s
.20877 .19019 m
.20998 .1819 L
s
.20709 .233 m
.20877 .19019 L
s
.21197 .17692 m
.21386 .17581 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83832 .20258 m
.83863 .21035 L
s
.83863 .21035 m
.84763 .21641 L
s
.84763 .21641 m
.84841 .21694 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83743 .20203 m
.83786 .19096 L
s
.842 .23142 m
.84384 .23639 L
s
.84114 .23089 m
.84384 .23639 L
s
.826 .17272 m
.83285 .17658 L
s
.83743 .20203 m
.83773 .2098 L
s
.83863 .21035 m
.83997 .22256 L
s
.83997 .22256 m
.842 .23142 L
s
.21386 .17581 m
.21663 .17803 L
s
.83773 .2098 m
.83909 .22202 L
s
.83909 .22202 m
.84114 .23089 L
s
.20357 .23511 m
.20709 .233 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21663 .17803 m
.21833 .18472 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.829 .17437 m
.83065 .21725 L
s
.82998 .17492 m
.83163 .21777 L
s
.21878 .17305 m
.22292 .17088 L
s
.21669 .22779 m
.21878 .17305 L
s
.21771 .22727 m
.2198 .17251 L
s
.81411 .16681 m
.82183 .17055 L
s
.83095 .2251 m
.83163 .21777 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82996 .22458 m
.83065 .21725 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82808 .22748 m
.83095 .2251 L
s
.21369 .22934 m
.21771 .22727 L
s
.81859 .16894 m
.82019 .21207 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82808 .22748 m
.82996 .22458 L
s
.81749 .1684 m
.81908 .21156 L
s
.82601 .22645 m
.82808 .22748 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22903 .17939 m
.23159 .17051 L
s
.22748 .19168 m
.22903 .17939 L
s
.23159 .17051 m
.23522 .16503 L
s
.82267 .22098 m
.82601 .22645 L
s
.23016 .17887 m
.23274 .16999 L
s
.2286 .19116 m
.23016 .17887 L
s
.22718 .19954 m
.22748 .19168 L
s
.23274 .16999 m
.23522 .16503 L
s
.22831 .19903 m
.2286 .19116 L
s
.23522 .16503 m
.2376 .16399 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22718 .19954 m
.22787 .21085 L
s
.82019 .21207 m
.82267 .22098 L
s
.81938 .21946 m
.82019 .21207 L
s
.22831 .19903 m
.22901 .21035 L
s
.2376 .16399 m
.23989 .16688 L
s
.81826 .21896 m
.81908 .21156 L
s
.22787 .21085 m
.22986 .21776 L
s
.81613 .22192 m
.81938 .21946 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22901 .21035 m
.23102 .21726 L
s
.23989 .16688 m
.24208 .17373 L
s
.81613 .22192 m
.81826 .21896 L
s
.2425 .16193 m
.24757 .1599 L
s
.22986 .21776 m
.23323 .22024 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80088 .16111 m
.80945 .16471 L
s
.81381 .22093 m
.81613 .22192 L
s
.23102 .21726 m
.23323 .22024 L
s
.8101 .21548 m
.81381 .22093 L
s
.23323 .22024 m
.23562 .21926 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23956 .24531 m
.2425 .16193 L
s
.24082 .24485 m
.24375 .16142 L
s
.78634 .15565 m
.79574 .15909 L
s
.80739 .20656 m
.8101 .21548 L
s
.23562 .21926 m
.2382 .21431 L
s
.2382 .21431 m
.24097 .20539 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79178 .15761 m
.79366 .21326 L
s
.80462 .16264 m
.80658 .218 L
s
.80584 .16316 m
.80781 .21848 L
s
.80282 .21656 m
.80781 .21848 L
s
.79043 .15711 m
.79231 .2128 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25509 .16879 m
.25808 .1599 L
s
.25334 .18117 m
.25509 .16879 L
s
.25808 .1599 m
.26238 .15449 L
s
.25645 .1683 m
.25946 .15942 L
s
.25469 .18069 m
.25645 .1683 L
s
.25946 .15942 m
.26238 .15449 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25307 .18912 m
.25334 .18117 L
s
.23584 .24672 m
.24082 .24485 L
s
.26238 .15449 m
.26521 .15354 L
s
.25442 .18865 m
.25469 .18069 L
s
.25307 .18912 m
.25402 .20061 L
s
.77055 .15046 m
.78074 .15373 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25442 .18865 m
.25538 .20015 L
s
.26521 .15354 m
.26795 .15657 L
s
.26521 .15354 m
.26941 .1561 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77643 .15232 m
.77784 .19622 L
s
.25402 .20061 m
.25649 .20769 L
s
.26795 .15657 m
.27062 .1636 L
s
.77498 .15185 m
.77637 .19578 L
s
.25538 .20015 m
.25788 .20723 L
s
.26941 .1561 m
.27209 .16314 L
s
.78819 .21142 m
.79366 .21326 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25649 .20769 m
.26055 .21033 L
s
.27062 .1636 m
.27171 .17512 L
s
.25788 .20723 m
.26055 .21033 L
s
.27209 .16314 m
.2732 .17467 L
s
.79326 .24093 m
.79448 .23735 L
s
.79299 .23287 m
.79448 .23735 L
s
.79176 .23645 m
.79299 .23287 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27146 .18312 m
.27171 .17512 L
s
.26055 .21033 m
.2634 .20944 L
s
.2815 .14847 m
.29088 .14584 L
s
.79176 .23645 m
.79326 .24093 L
s
.27294 .18268 m
.2732 .17467 L
s
.2696 .1956 m
.27146 .18312 L
s
.77663 .20382 m
.77784 .19622 L
s
.28459 .14758 m
.30237 .19903 L
s
.2634 .20944 m
.26642 .20453 L
s
.2634 .20944 m
.26788 .20408 L
s
.27108 .19516 m
.27294 .18268 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75354 .14558 m
.7645 .14865 L
s
.77515 .20338 m
.77637 .19578 L
s
.26642 .20453 m
.2696 .1956 L
s
.26788 .20408 m
.27108 .19516 L
s
.7723 .20654 m
.77663 .20382 L
s
.7723 .20654 m
.77515 .20338 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76927 .20568 m
.7723 .20654 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29733 .14414 m
.30728 .14167 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76454 .20037 m
.76927 .20568 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2829 .20383 m
.30226 .14289 L
s
.76118 .19146 m
.76454 .20037 L
s
.28447 .20342 m
.30393 .14248 L
s
.27979 .20467 m
.28924 .20219 L
s
.74056 .14625 m
.74412 .1551 L
s
.7354 .14103 m
.74056 .14625 L
s
.73198 .14024 m
.7354 .14103 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72863 .14349 m
.73198 .14024 L
s
.72689 .14311 m
.73198 .14024 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7583 .14688 m
.76081 .23161 L
s
.75986 .14732 m
.76239 .23201 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72535 .1508 m
.72863 .14349 L
s
.74312 .1789 m
.7449 .18334 L
s
.74156 .18256 m
.74312 .1789 L
s
.7449 .18334 m
.74502 .18739 L
s
.72359 .15042 m
.72689 .14311 L
s
.7419 .19473 m
.74502 .18739 L
s
.75601 .23043 m
.76239 .23201 L
s
.32094 .14258 m
.32634 .13743 L
s
.31898 .15102 m
.32094 .14258 L
s
.29573 .20059 m
.30574 .19827 L
s
.74156 .18256 m
.74335 .187 L
s
.3227 .1422 m
.32634 .13743 L
s
.32073 .15065 m
.3227 .1422 L
s
.32634 .13743 m
.32992 .1367 L
s
.7239 .16256 m
.72535 .1508 L
s
.72213 .1622 m
.72359 .15042 L
s
.32992 .1367 m
.33525 .13967 L
s
.73862 .19804 m
.7419 .19473 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31784 .19569 m
.31898 .15102 L
s
.3196 .19533 m
.32073 .15065 L
s
.73348 .19692 m
.73862 .19804 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7239 .16256 m
.72411 .17068 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72213 .1622 m
.72234 .17031 L
s
.33525 .13967 m
.33872 .14707 L
s
.339 .13493 m
.3464 .13357 L
s
.33768 .19192 m
.339 .13493 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72411 .17068 m
.72618 .18324 L
s
.33953 .1916 m
.34084 .13458 L
s
.72234 .17031 m
.72441 .18288 L
s
.72989 .19211 m
.73348 .19692 L
s
.72815 .19175 m
.73348 .19692 L
s
.68841 .13176 m
.70158 .13404 L
s
.3126 .19678 m
.3196 .19533 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72618 .18324 m
.72989 .19211 L
s
.72441 .18288 m
.72815 .19175 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35583 .13195 m
.35757 .13976 L
s
.35549 .1482 m
.35583 .13195 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6941 .13272 m
.69534 .18984 L
s
.69598 .13304 m
.69723 .19015 L
s
.67293 .12937 m
.68458 .13114 L
s
.71009 .18419 m
.71183 .18044 L
s
.71183 .18044 m
.71375 .18487 L
s
.35757 .13976 m
.35957 .13539 L
s
.35957 .13539 m
.3635 .13072 L
s
.71375 .18487 m
.71385 .18895 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35549 .1482 m
.35757 .13976 L
s
.3635 .13072 m
.37127 .12954 L
s
.71212 .19271 m
.71385 .18895 L
s
.71009 .18419 m
.71202 .18862 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33217 .19291 m
.33953 .1916 L
s
.37127 .12954 m
.37513 .13305 L
s
.70659 .19173 m
.71212 .19271 L
s
.69669 .16558 m
.69885 .17816 L
s
.37513 .13305 m
.37703 .13684 L
s
.70278 .18699 m
.70659 .19173 L
s
.69885 .17816 m
.70278 .18699 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3768 .14909 m
.37703 .13684 L
s
.64895 .12622 m
.66105 .12773 L
s
.35697 .16831 m
.36091 .16362 L
s
.35497 .17271 m
.35697 .16831 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3548 .18091 m
.35497 .17271 L
s
.36091 .16362 m
.37081 .15401 L
s
.35689 .17241 m
.36082 .16772 L
s
.35488 .1768 m
.35689 .17241 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37482 .14936 m
.37688 .14501 L
s
.37081 .15401 m
.37482 .14936 L
s
.68961 .18895 m
.69723 .19015 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36082 .16772 m
.37073 .1581 L
s
.255 .412 .882 r
.6687 .17004 m
.67036 .16777 L
s
0 0 0 r
.39319 .12661 m
.39515 .13045 L
s
.3911 .13094 m
.39319 .12661 L
s
.3548 .18091 m
.35663 .18472 L
s
.37475 .15345 m
.3768 .14909 L
s
.3911 .13094 m
.39305 .13477 L
s
.37073 .1581 m
.37475 .15345 L
s
.255 .412 .882 r
.6687 .17004 m
.66875 .17291 L
s
0 0 0 r
.39305 .13477 m
.39515 .13045 L
s
.35663 .18472 m
.36041 .18825 L
s
.255 .412 .882 r
.66875 .17291 m
.6705 .17566 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65746 .15173 m
.67536 .15412 L
s
.36041 .18825 m
.36821 .18713 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37429 .17808 m
.37643 .16959 L
s
.37612 .18606 m
.37643 .16959 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37223 .18247 m
.37429 .17808 L
s
.37429 .17808 m
.37612 .18606 L
s
.36821 .18713 m
.37223 .18247 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38987 .20506 m
.39272 .15525 L
s
.39272 .15525 m
.39395 .20461 L
s
.255 .412 .882 r
.43022 .16432 m
.43026 .16071 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66837 .20245 m
.67879 .13024 L
s
.66859 .21491 m
.68073 .13054 L
s
.65301 .12671 m
.66859 .21491 L
s
.39191 .20483 m
.39231 .17996 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43444 .1611 m
.43703 .16033 L
s
.43231 .16415 m
.43444 .1611 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43231 .16421 m
.43236 .16059 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38987 .20506 m
.39177 .21315 L
s
.39177 .21315 m
.39395 .20461 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48786 .16408 m
.48953 .15748 L
s
.48775 .16423 m
.48786 .16408 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49222 .16015 m
.49223 .15747 L
s
.49006 .15885 m
.49006 .15748 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa090:f][@h0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40
oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV4@0:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
2`3oXa040:f][@<000000`2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
4`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA1P2]
[Jd200000080[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400A0?nS40D000001@2][Jd3000001H0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H2
0:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0D0?nV4@D000000`2][Jd6
0?nV4@030000003oYQ40000000l0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004@3oXa000`000000oj<@0?nS4005
0?nS40030:f][@3lX100o:0@0080[Jf]1000000B0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ401@000000[Jf]0:f][@000000[Jf]0080ojHA00@0[Jf]
0?nV4@00000000001`3oYQ4200000100ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004P3oXa000`000000oj<@0?nS
40040?nS40030:f][@3lX100o:0@0080o:0@0P0000020?bP40030:f][@000000000000<00000303l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2]
[JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ45000000<0[Jf]00<000000?nV4@000000103oYQ40
102][Jd0ojHA0?nV4@0000080?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004P3o
Xa000`000000oj<@0?nS40040?nS40030:f][@3lX100o:0@0080o:0@0P0000060?bP40@000000P2]
[Jd80?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA0080ojHA0P000000103oYQ40[Jf]0:f][@2]
[Jd2000000030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@000000103oYQ401@2][Jd0ojHA0?nV
4@3oYQ40000001P0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004P3oXa000`000000oj<@0?nS40040?nS40030:f]
[@3lX100o:0@0080o:0@0P0000060?bP40800000103lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo
001^0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@0D0?nT4@050:f][@3oYQ40ojHA0:f][@0000000P2][Jd200000080ojHA0P0000060?nV4@800000
1@3oYQ401@2][Jd0ojHA0?nV4@3oYQ40000001P0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa004P3oXa000`000000
oj<@0?nS40040?nS40040:f][@3lX100o:0@0?bP408000001`3lX102000000X0o:0@102][JdE0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0
/>3V0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1440:f][@80
0000103oYQ4010000000ojHA0000000000060?nV4@8000001@3oYQ401@2][Jd0ojHA0?nV4@3oYQ40
000001P0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa004P3oXa000`000000oj<@0?nS40040?nS40040:f][@3lX100
o:0@0?bP408000001`3lX102000000`0o:0@00@0[Jf]0?JL3`2][Jd0[Jf]0`00000@0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2]
[Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY143000000<0[Jf]00<0
oj@A0:f][@3oYQ400P0000060?nV4@<000001P3oYQ42000000D0ojHA00D0[Jf]0?nV4@3oYQ40ojHA
0000000G0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@0180oj<@00<000000?nS403oXa00103oXa00102][Jd0o:0@
0?bP403lX102000000L0o:0@0P00000<0?bP40040:f][@3fW0l0000000000080mY`?00@0[Jf]0000
002][Jd0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC
0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00X0oj@A100000000`2][Jd0oj@A0?nT4@030?nT4@040:f][@3oYQ400000000000H0ojHA0`000006
0?nV4@030000003oYQ40ojHA00@0ojHA00D0[Jf]0?nV4@3oYQ40ojHA0000000G0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01<0oj<@00<000000?nS403oXa000`3oXa00102][Jd0o:0@0?bP403lX102000000L0o:0@
0P00000<0?bP40030:f][@000000000000D0mY`?00<000000?JL3`2][Jd00`2][Jd90?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo
001W0;3PiP030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@050?nT4@<000000`2][Jd00`3oY14000000?nT4@060?nT4@030:f][@000000000000P0ojHA0P00
00060?nV4@030000003oYQ40ojHA00@0ojHA00<0[Jf]0?nV4@3oYQ400P00000G0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01<0oj<@00<000000?nS403oXa000`3oXa00102][Jd0o:0@0?bP403lX102000000L0o:0@
0P00000<0?bP40030:f][@000000000000H0mY`?00<000000?JL3`3fW0l00P3fW0l00`2][Jd00000
00000002000000@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]
D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@020?nT4@<000000P2][Jd50?nT4@030000003oY140oj@A00D0oj@A00<0[Jf]000000000000203o
YQ42000000H0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0ojHA0?nV4@02000001L0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa004`3oXa000`000000oj<@0?nS40040?nS40030:f][@3lX100o:0@008000001`3l
X102000000`0o:0@0P0000070?JL3`030000003fW0l0mY`?00H0mY`?100000000`3fW0l0[Jf]0>bF
3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H0
0`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd0
0`3oY14000000?nT4@060?nT4@030000003oY140oj@A00D0oj@A00<0[Jf]000000000000203oYQ42
000000d0ojHA00@0[Jf]0?nV4@0000000000603oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400C0?nS40030000003o
Xa00oj<@00@0oj<@00<0[Jf]0?bP403lX1000P0000070?bP40800000303lX102000000P0mY`?00<0
00000?JL3`3fW0l01@3fW0l010000000mY`?0?JL3`3fW0l20:f][@800000403/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0
[Jf]3@3_V1000`2][Jd0o:0@0?bP400<0?bP40030000003lX100[Jf]0080[Jf]1P3oY1400`000000
oj@A0?nT4@030?nT4@030000003oY140oj@A00H0oj@A00<0[Jf]000000000000203oYQ42000000d0
ojHA00@0[Jf]0?nV4@0000000000603oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400C0?nS40D000000P3oXa00102]
[Jd0o:0@0000000000080?bP40800000303lX102000000P0mY`?00<000000?JL3`3fW0l01@3fW0l0
0`000000mY`?0?JL3`020?JL3`030:f][@3/UPh0[Jf]008000003P3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3C
Q`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1002`3lX103000000030?bP402][Jd0oj@A00H0oj@A00<0
00000?nT4@3oY1400`3oY1400`000000oj@A0?nT4@060?nT4@030:f][@000000000000P0ojHA0P00
000=0?nV4@030:f][@000000000000T0ojHA00<000000?nV4@3oYQ403@3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400D0?nS40040000003oXa00oj<@0?nS40H00000203lX102000000`0o:0@0P0000090?JL3`030000
003fW0l0mY`?00@0mY`?00<000000?JL3`3fW0l00P3fW0l00`2][Jd0k9H>0>bF3P04000000`0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`
h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3l
X100102][Jd000000:f][@3lX102000000030:f][@3oY140oj@A00D0oj@A00<000000?nT4@3oY140
0`3oY1400`000000oj@A0?nT4@060?nT4@030:f][@000000000000P0ojHA0P00000=0?nV4@030000
003oYQ40000000T0ojHA00<000000?nV4@3oYQ403@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]
5`3oYA000`2][Jd0oj<@0?nS400D0?nS40030000003oXa00oj<@00<0oj<@00@0[Jf]0?bP40000000
0000203lX102000000`0o:0@00<000000?JL3`3fW0l03`3fW0l00`000000mY`?0?JL3`020?JL3`03
0:f][@3/UPh0k9H>008000000P3/UPh20:f][@<000001`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>
0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@800000
0`3lX102000000P0oj@A00@000000?nT4@3oY140oj@A0P0000070?nT4@040:f][@3oYQ4000000000
00P0ojHA0P00000<0?nV4@030000002][Jd0000000X0ojHA00<000000?nV4@3oYQ403@3oYQ400`2]
[Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0@FWQ0?nV400L0?nV40030:f][@3oYA00ojD@
00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@01@0oj<@00<000000?nS403oXa000`3oXa00102]
[Jd0o:0@0000000000080?bP40800000303lX1000`000000mY`?0?JL3`0?0?JL3`030000003fW0l0
mY`?0080mY`?00<0[Jf]0>bF3P3/UPh00P0000050>bF3P040:f][@0000000000000000D0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3o
ool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40070:f][@3lX100
o:0@0?bP40000000o:0@000000030:f][@80o:0@00<000000?bP403lX1000P3lX102000000P0oj@A
00D000000?nT4@3oY140oj@A000000080?nT4@040:f][@3oYQ400000000000P0ojHA0P00000;0?nV
4@030000003oYQ40000000/0ojHA00<000000?nV4@3oYQ402@3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV
4011JN40703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]4P3oXa000`000000oj<@0?nS40030?nS
40040:f][@3lX1000000000000P0o:0@0P00000<0?bP40030000003fW0l0mY`?00l0mY`?00<00000
0?JL3`3fW0l00P3fW0l00`2][Jd0k9H>0>bF3P02000000H0k9H>00H000000>bF3P2][Jd0[Jf]0>bF
3P0000020>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V
0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_
V100102][Jd0o:0@0?bP403lX102000000030:f][@3lX100o:0@0080o:0@0P0000050?bP40800000
203oY14010000000oj@A0?nT4@0000080?nT4@040:f][@3oYQ400000000000P0ojHA00<000000?nV
4@3oYQ402@3oYQ4010000000ojHA0000002][Jd;0?nV4@030000003oYQ40ojHA00T0[Jf]103oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS40020?nS40X0[Jf]203oXa000`000000oj<@0?nS40030?nS40040:f][@3lX100
0000000000P0o:0@0P00000<0?bP40030000003fW0l0mY`?00l0mY`?00<000000?JL3`3fW0l00P3f
W0l00`2][Jd0k9H>0>bF3P02000000H0k9H>00@000000>bF3P3/UPh0k9H>0P2][Jd2000000030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo
001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V10200000080[Jf]00<0
00000?bP403lX100103lX1000`000000o:0@0?bP40040?bP40800000203oY14010000000oj@A0000
000000080?nT4@040:f][@3oYQ400000000000L0ojHA0P00000:0?nV4@050000003oYQ4000000?nV
4@2][Jd0103oYQ470:f][@030000002][Jd0[Jf]00d0ojHA00@0[Jf]0?nV4@3oYQ40@FWQ6`3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa08
0:f][@030000002][Jd0oj<@00<0oj<@00@0[Jf]0?bP400000000000203lX102000000`0o:0@00<0
00000?JL3`3fW0l03`3fW0l00`000000mY`?0?JL3`020?JL3`030:f][@3/UPh0k9H>008000001P3/
UPh00`000000k9H>0>bF3P040>bF3P<00000303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`
h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V102000000040:f][@000000
0000000000D0o:0@0P0000060?bP40800000203oY1400`000000oj@A000000090?nT4@040:f][@3o
YQ400000000000L0ojHA0P0000090?nV4@030000003oYQ40000000L0[Jf]1`3oYQ400`000000ojHA
0?nV4@0=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01D0oj<@00<000000:f][@2][Jd00`2][Jd2000000030:f]
[@3lX100o:0@00H0o:0@0P00000<0?bP40030000003fW0l0mY`?00l0mY`?00<000000?JL3`3fW0l0
0P3fW0l00`2][Jd0k9H>0>bF3P02000000H0k9H>00<000000>bF3P3/UPh0103/UPh01@000000[Jf]
0:f][@2][Jd0000000X0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V
0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@00<0[Jf]0000002][Jd00P3lX102000000D0o:0@
0P0000060?bP408000002@3oY142000000T0oj@A00@0[Jf]0?nV4@00000000001`3oYQ42000000H0
ojHA0P2][Jd010000000[Jf]0000002][Jd20?nV4@040:f][@3oYQ40ojHA000000L0ojHA0P00000?
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01D0oj<@00<000000?nS403oXa000P3oXa00102][Jd000000000003l
X1060:f][@80o:0@0P00000<0?bP40800000403fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh00P00
00060>bF3P030000003/UPh0k9H>00@0k9H>00D000000:f][@3KRPd0fhX=0:f][@03000000L0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2G
H0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001@3_V10010000000kiP@0:f][@2][Jd2000000030:f]
[@3lX100o:0@008000001@3lX102000000H0o:0@0P0000090?nT4@8000002@3oY140102][Jd0ojHA
0000000000070?nV4@80000000<0ojHA0:f][@2][Jd00`2][Jd0103oYQ4000000?nV4@0000040?nV
4@040:f][@3oYQ40ojHA000000L0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01D0oj<@00<00000
0?nS403oXa000P3oXa000`2][Jd00000000000070?bP4080[Jf]0P0000030:f][@T0o:0@0P00000@
0?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P02000000H0k9H>00<000000>bF3P3/UPh0103/UPh0
0`000000[Jf]0=^:3@030=^:3@<000001P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH4003
0>nH408000000P2][Jd20>nH4080000000D0[Jf]0?bP403lX100o:0@000000050?bP408000001P3l
X102000000T0oj@A00<000000?nT4@3oY140203oY1400`2][Jd00000000000060?nV4@80[Jf]0P00
00000`2][Jd0ojHA0?nV4@040?nV4@8000001@3oYQ40102][Jd0ojHA0?nV4@0000070?nV4@800000
3`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400E0?nS40030000003oXa00oj<@0080oj<@00<0[Jf]000000000000
2@3lX10300000080o:0@1P2][Jd30?bP40800000403fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh0
0P0000060>bF3P030000003/UPh0k9H>00@0k9H>00<000000:f][@3KRPd00`3KRPd2000000030:f]
[@3KRPd0000000@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40
oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V102000000<0
kiP@0P0000000`3_V100[Jf]0?bP40020?bP40030000003lX100o:0@0080o:0@0P0000070?bP4080
00002@3oY142000000T0oj@A00<0[Jf]0000000000001P2][Jd20?nV4@8000001`3oYQ400`000000
ojHA0?nV4@040?nV4@040:f][@3oYQ400000000000L0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01D0oj<@00<000000?nS403oXa000P3oXa000`2][Jd00000000000090?bP40<00000203lX1030:f]
[@800000403fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh00P0000060>bF3P030000003/UPh0k9H>
00@0k9H>00<000000:f][@3KRPd00`3KRPd2000000030=^:3@2][Jd0[Jf]008000000P3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P0000000`2][Jd0000000000003
0>nH4080000000<0kiP@0:f][@3lX1000P3lX1000`000000o:0@0?bP40020?bP408000001`3lX102
000000T0oj@A0P0000080?nT4@80[Jf]0P0000080?nV4@8000001`3oYQ400`000000ojHA0?nV4@04
0?nV4@040:f][@3oYQ400000000000L0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@00D0
00000?nS403oXa00oj<@0:f][@02000000T0o:0@0`00000;0?bP40800000102][Jd<0?JL3`800000
0`3fW0l01@2][Jd0k9H>0>bF3P3/UPh0000000H0k9H>00<000000>bF3P3/UPh0103/UPh00`000000
[Jf]0=^:3@030=^:3@8000000`3KRPd01@2][Jd00000000000000000[Jf]00T0^GD;00D0[Jf]08QF
1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0
1@2][Jd0kiP@000000000000[Jf]00<000000`3_V102000000030>nH402][Jd0o:0@0080o:0@00<0
00000?bP403lX1000P3lX102000000L0o:0@0P0000080?nT4@<00000103oY1440:f][@040?nT4@2]
[Jd00000000000P0ojHA0P0000070?nV4@030000003oYQ40ojHA00@0ojHA00@0[Jf]0?nV4@000000
00001`3oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa001@000000oj<@0?nS403oXa00[Jf]
008000002@3lX103000000/0o:0@00<0[Jf]0000000000000`3fW0l40:f][@030000003fW0l0mY`?
00D0mY`?0P0000030?JL3`050:f][@3/UPh0k9H>0>bF3P0000001P3/UPh00`000000k9H>0>bF3P04
0>bF3P030000002][Jd0fhX=00<0fhX=0P0000040=^:3@040000002][Jd0[Jf]0:f][@T0^GD;00<0
[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0
Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f][@030000003_V100kiP@00<000000`3_V102
000000030>nH402][Jd0o:0@0080o:0@00<000000?bP403lX1000P3lX102000000L0o:0@0P000008
0?nT4@040000003oY140oj@A000000<0[Jf]1@3oY1400`2][Jd00000000000080?nV4@8000001`3o
YQ400`000000ojHA0?nV4@040?nV4@040:f][@0000000000000000L0ojHA0P00000?0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01H0oj<@00H000000?nS403oXa00oj<@0:f][@00000:0?bP40<000001@3lX1000`00
0000o:0@0?bP40030?bP40030:f][@000000000000H0mY`?0P0000030:f][@@0mY`?0P0000030?JL
3`050:f][@3/UPh0k9H>0>bF3P0000001P3/UPh00`000000k9H>0>bF3P040>bF3P030000002][Jd0
fhX=00<0fhX=0P0000040=^:3@040000003KRPd0fhX=0:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28
EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3C
Q`h00`2][Jd00000000000030>nH408000000`3_V102000000030>nH402][Jd0o:0@0080o:0@00<0
00000?bP403lX1000P3lX102000000L0o:0@0P0000080?nT4@040000002][Jd0[Jf]000000P0oj@A
00<0[Jf]000000000000203oYQ42000000L0ojHA00<000000?nV4@3oYQ40103oYQ40102][Jd00000
0000000000070?nV4@8000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40040000003oXa00oj<@0?nS
408000002P3lX102000000030?bP40000000o:0@00<0o:0@00<000000?bP403lX1000`3lX1000`2]
[Jd00000000000060?JL3`030000003fW0l000000080mY`?102][Jd2000000<0mY`?00D0[Jf]0>bF
3P3/UPh0k9H>000000060>bF3P030000003/UPh0k9H>00@0k9H>00<000000:f][@3KRPd00`3KRPd2
000000@0fhX=00<000000=^:3@3KRPd00P2][Jd00`2iM@/00000000000050;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00H0dhL>00@000000=>73P2][Jd0[Jf]0P0000030>nH408000000P3_V102000000030>nH402]
[Jd0o:0@0080o:0@0P0000040?bP408000001`3lX102000000@0oj@A0`2][Jd200000080oj@A00<0
00000?nT4@3oY1401P3oY1400`2][Jd00000000000080?nV4@800000203oYQ400`000000ojHA0?nV
4@030?nV4@040000003oYQ40ojHA000000L0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@
00@000000?nS403oXa00oj<@0P00000:0?bP4080000000<0o:0@0000003lX1000`3lX102000000@0
o:0@00<0[Jf]0000000000001P3fW0l00`000000mY`?000000060?JL3`8000000P2][Jd00`3fW0l0
[Jf]0>bF3P020>bF3P030000003/UPh0k9H>00@0k9H>00<000000>bF3P3/UPh0103/UPh00`000000
[Jf]0=^:3@030=^:3@800000103KRPd020000000fhX=0=^:3@2][Jd0^GD;0000002][Jd000001@2i
M@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@050=>73P80000000@0[Jf]0=>73P2][Jd00000103_V10010000000kiP@
0>nH403_V102000000030>nH402][Jd0o:0@0080o:0@0P0000040?bP408000001`3lX102000000@0
[Jf]0`3oY1400`000000oj@A0?nT4@020?nT4@030000003oY140oj@A00D0oj@A00<0[Jf]00000000
0000203oYQ42000000T0ojHA00<000000?nV4@3oYQ400P0000030?nV4@030000003oYQ40ojHA00D0
ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@00@000000?nS403oXa00oj<@0P00000:0?bP
408000000P3lX10010000000o:0@0?bP403lX102000000@0o:0@00<0[Jf]0?JL3`0000001`3fW0l2
000000H0mY`?0P0000020?JL3`<0[Jf]0P3/UPh00`000000k9H>0>bF3P050>bF3P030000003/UPh0
k9H>00<0k9H>00<000000:f][@3KRPd00`3KRPd2000000@0fhX=00T000000=^:3@3KRPd0[Jf]0;Ue
2`000000^GD;0:f][@000000102iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440
/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P80000000H0[Jf]0000003C
Q`h0dhL>0:f][@0000040>nH40040000003_V100kiP@0>nH4080000000<0kiP@0:f][@3lX1000P3l
X102000000@0o:0@0P0000060?bP4080000000<0[Jf]0?nT4@3oY1401@3oY1400`000000oj@A0?nT
4@020?nT4@030000003oY140oj@A00D0oj@A00<0[Jf]000000000000203oYQ42000000X0ojHA0P00
00000`3oYQ40[Jf]0?nV4@0:0?nV4@8000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400G0?nS40030000003o
Xa00oj<@008000001`3lX102000000030?bP40000000000000<0o:0@00D000000?bP403lX100o:0@
000000040?bP40040:f][@3fW0l00000000000H0mY`?00<000000?JL3`3fW0l01@3fW0l2000000<0
mY`?00D0[Jf]0>bF3P2][Jd0[Jf]000000070>bF3P030000003/UPh0k9H>00<0k9H>00<000000:f]
[@3KRPd00`3KRPd2000000@0fhX=00@000000=^:3@3KRPd0[Jf]0P0000020;Ue2`030000002iM@/0
^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@020=>73P050000003CQ`h0[Jf]0=>73P0000000P3CQ`h00`2][Jd000000>nH
40030>nH40040000003_V100kiP@0>nH4080000000<0kiP@0:f][@3lX1000P3lX102000000@0o:0@
0P0000030?bP40<0[Jf]0P0000070?nT4@8000001@3oY1400`000000oj@A0?nT4@040?nT4@030:f]
[@000000000000P0ojHA0P00000=0?nV4@030:f][@3oYQ40ojHA00T0ojHA0P00000?0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01L0oj<@00<000000?nS403oXa000P0000090?bP40<00000103lX102000000030?bP
40000000o:0@00<0o:0@00@0[Jf]0?JL3`3fW0l000001P3fW0l00`000000mY`?0?JL3`060?JL3`05
0000003fW0l0mY`?0?JL3`2][Jd00`3/UPh00`000000[Jf]0:f][@050>bF3P030000003/UPh0k9H>
00<0k9H>00<000000:f][@3KRPd0103KRPd00`000000fhX=0=^:3@020=^:3@040000003KRPd0fhX=
0:f][@8000000P2iM@/00`000000[Jf]0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je2
0;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P000000102][Jd0dhL>0=>7
3P0000020=>73P030:f][@000000kiP@00<0kiP@00@000000>nH403_V100kiP@0P0000000`3_V100
[Jf]0?bP40020?bP40800000103lX102000000030?bP402][Jd0[Jf]00<0o:0@0P0000070?nT4@03
0000003oY140oj@A00@0oj@A00<000000?nT4@3oY140103oY1400`2][Jd00000000000050?nV4@@0
00003P3oYQ400`2][Jd0ojHA0?nV4@080?nV4@<000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400G0?nS4003
0000003oXa00oj<@008000004P3lX102000000@0o:0@00@0[Jf]0?JL3`3fW0l000001@3fW0l00`00
0000mY`?0?JL3`070?JL3`050000003fW0l0mY`?0?JL3`2][Jd00`3/UPh00`000000k9H>0>bF3P03
0:f][@80k9H>00<000000>bF3P3/UPh0103/UPh00`000000fhX=0=^:3@030=^:3@030000003KRPd0
fhX=0080fhX=00@000000=^:3@3KRPd0[Jf]0P0000020;Ue2`060000002iM@/0[Jf]0:f][@2iM@/0
00001028EPL20:f][D80/>3V0@3oool005T0/>3V00P0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h0[Jf]
000000<0dhL>00D000000=>73P3CQ`h0[Jf]000000040>nH40040000003_V100kiP@0>nH40800000
00<0kiP@0:f][@3lX1000P3lX102000000@0o:0@0P0000000`2][Jd0o:0@0?bP40030?bP40800000
1`3oY1400`000000oj@A0?nT4@040?nT4@030000003oY140oj@A00@0oj@A00<0[Jf]000000000000
5`3oYQ400`2][Jd0ojHA0?nV4@080?nV4@<000003`3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]
5`3oYA000`2][Jd0oj<@0?nS400G0?nS40040000003oXa00oj<@000001X0o:0@00@0[Jf]0?JL3`3f
W0l00000103fW0l00`000000mY`?0?JL3`070?JL3`8000000P3fW0l01@2][Jd0k9H>0>bF3P3/UPh0
000000D0k9H>0P2][Jd00`000000k9H>0>bF3P040>bF3P030000003KRPd0fhX=00<0fhX=00<00000
0=^:3@3KRPd00P3KRPd010000000fhX=0=^:3@2][Jd2000000<0^GD;00<000000;Ue2`2iM@/00`00
000308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@030=>73P00
0000dhL>0080dhL>00D000000=>73P3CQ`h0[Jf]000000040>nH40040000003_V100kiP@0>nH4080
000000<0kiP@0:f][@3lX1000P3lX102000000060?bP402][Jd0[Jf]0:f][@3lX10000001P3lX102
000000H0oj@A0P0000070?nT4@030000003oY140oj@A0080oj@A0P00000I0?nV4@030:f][@3oYQ40
ojHA00P0ojHA0`00000?0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa005`3oXa00
10000000oj<@00000000000J0?bP40040:f][@3fW0l0mY`?0?JL3`80000000<0mY`?0000003fW0l0
2@3fW0l200000080mY`?00D0[Jf]0>bF3P3/UPh0k9H>000000070>bF3P030000002][Jd0[Jf]00@0
k9H>00<000000=^:3@3KRPd00`3KRPd00`000000fhX=0=^:3@030=^:3@040000003KRPd0[Jf]0000
00@0^GD;00<000000;Ue2`2iM@/01000000308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P050000003CQ`h0dhL>0=>73P0000000P3CQ`h0
0`2][Jd000000>nH40030>nH40040000003_V100kiP@0>nH4080000000<0kiP@0:f][@3lX1000P3l
X102000000030:f][@3lX100o:0@0080o:0@00<000000?bP403lX100103lX1000`000000[Jf]0?nT
4@050?nT4@8000001P3oY143000000@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@080?nV4@<000002`3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400E0?nU40`0[Jf]5P3oXa03000001X0o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l2000000X0mY`?00D0
00000?JL3`000000mY`?0:f][@030>bF3P030000003/UPh0k9H>00D0k9H>00<000000>bF3P3/UPh0
0`2][Jd00`3/UPh000000=^:3@040=^:3@030000003KRPd0fhX=00<0fhX=00@000000=^:3@3KRPd0
00001`2iM@/500000080R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;
09MP2`020:f][@80dhL>00T000000=>73P3CQ`h0dhL>0000003CQ`h0[Jf]0>nH400000000`3_V102
000000<0kiP@0P0000000`3_V100[Jf]0?bP40020:f][@8000001@3lX1000`000000o:0@0?bP4003
0?bP4080000000<0[Jf]0?nT4@3oY140103oY1400`000000oj@A0?nT4@020?nT4@<000001`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00P0ojHA0`0000000`3oYQ40[Jf]0:f][@08
0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@`0oj<@0`00000J0?bP40030:f][@3fW0l0
mY`?00l0mY`?00D000000?JL3`000000mY`?0:f][@020>bF3P8000001`3/UPh00`000000k9H>0>bF
3P030>bF3P030:f][@000000[Jf]00@0fhX=00<000000=^:3@3KRPd00`3KRPd010000000fhX=0=^:
3@0000070;Ue2`040000002][Jd00000000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00
F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@80dhL>00T000000=>73P3CQ`h0dhL>0000003CQ`h0[Jf]
0>nH400000000`3_V102000000<0kiP@0P0000000`3_V100[Jf]0:f][@020?bP40030000003lX100
o:0@00@0o:0@00<000000?bP403lX1000`3lX1000`000000o:0@0:f][@050?nT4@@00000303oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA1P2][Jd3000000030:f][@3oYQ40
ojHA00`0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@80oj<@0`00000J0?bP40030:f][@3fW0l0
mY`?00l0mY`?00D000000?JL3`3fW0l000000:f][@020>bF3P8000001`3/UPh00`000000k9H>0>bF
3P040>bF3P040000003KRPd0[Jf]0:f][@80fhX=00<000000=^:3@3KRPd00`3KRPd010000000fhX=
0=^:3@0000070;Ue2`040000002][Jd00000000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?oo
o`00F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0[Jf]0080dhL>00T000000=>73P3CQ`h0dhL>0000003C
Q`h0[Jf]0>nH400000000`3_V102000000<0kiP@0P0000020:f][@<0o:0@00<000000?bP403lX100
1@3lX1000`000000o:0@0?bP40020?bP40030000003lX100[Jf]00<0oj@A0`00000?0?nT4@030:f]
[@3oYQ40ojHA01@0ojHA202][Jd60?nV4@<000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS4080[Jf]
00<000000:f][@0000000`2][JdG0?bP40030:f][@3fW0l0mY`?00l0mY`?00T000000?JL3`3fW0l0
mY`?0000003/UPh000000>bF3P0000001`3/UPh00`000000k9H>0>bF3P040>bF3P040000003KRPd0
fhX=0=^:3@80[Jf]00<000000=^:3@3KRPd00`3KRPd010000000fhX=0=^:3@0000070;Ue2`080000
002][Jd000000000002][Jd0R5H70000002][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]
09MP2`2][Jd00P3CQ`h02@000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@000000030>nH4080
00000P3_V1020:f][@030000003_V100[Jf]00<0o:0@00<000000?bP403lX1001@3lX1001`000000
o:0@0?bP403lX10000000?bP402][Jd05P3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ40
0`2][Jd0ojHA0?nV4@080?nV4@030000003oYQ40000000l0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00603oXa00
0`000000oj<@000000030?bP40L0[Jf]403lX1000`2][Jd0mY`?0?JL3`0?0?JL3`030000003fW0l0
mY`?0080mY`?0`0000080>bF3P030000003/UPh0k9H>00@0k9H>00<000000=^:3@3KRPd00`3KRPd0
0`000000[Jf]0=^:3@030=^:3@040000003KRPd0fhX=000000L0^GD;00D000000:f][@28EPL00000
08QF1`02000000030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V0P2][Jd209MP2`040:f][@3C
Q`h0dhL>000000D0dhL>00<0[Jf]0>nH400000000`3_V10200000080[Jf]0P3_V1000`000000kiP@
0:f][@030?bP40030000003lX100o:0@00H0o:0@00<000000?bP400000000P3lX1000`2][Jd0oj@A
0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA1`2][Jd90?nV4@030:f][@3oYQ40ojHA00P0ojHA
0P00000@0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01P0oj<@0P0000000`2][Jd0o:0@0?bP40080?bP40H0[Jf]
2P3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`030000003fW0l0mY`?0080mY`?00<0[Jf]0>bF3P3/UPh0
203/UPh00`000000k9H>0>bF3P040>bF3P030000003KRPd0fhX=00<0fhX=00@000000=^:3@2][Jd0
[Jf]0P3KRPd00`000000fhX=0=^:3@02000000H0^GD;00D000000:f][@28EPL0000008QF1`020000
00030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V0P2][Jd209MP2`040:f][@3CQ`h000000000
00D0dhL>00<0[Jf]0>nH400000000`3_V102000000@0kiP@00<000000>nH402][Jd00P3lX1020000
00T0o:0@00D000000?bP403lX100o:0@0:f][@0F0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]403o
YQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3o
Xa000`000000[Jf]0?bP400?0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`030000003f
W0l0mY`?0080mY`?00<0[Jf]0>bF3P3/UPh01@3/UPh2000000030>bF3P000000k9H>00D0k9H>00<0
00000=^:3@3KRPd00`3KRPd010000000fhX=0=^:3@3KRPd20:f][@030000003KRPd0fhX=00800000
1P2iM@/01@000000[Jf]08QF1`000000R5H700<00000@P2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;
09MP2`2GH0/0[Jf]0=>73P0000001P3CQ`h0102][Jd000000>nH403_V1020:f][@800000103_V100
0`000000kiP@0:f][@020?bP408000003@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@D0[Jf]5P3oYQ40
0`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa00
0`000000[Jf]0?bP400F0?bP40H0[Jf]3`3fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh2
000000H0k9H>0P0000040=^:3@030000003KRPd0fhX=00<0fhX=00<000000:f][@3KRPd00`000005
0;Ue2`070000002][Jd0R5H700000028EPL0000008QF1`0200000440/>3V0@3oool005P0/>3V0P2]
[Jd309MP2`050:f][@3CQ`h000000=>73P000000103CQ`h0102][Jd000000:f][@2][Jd20>nH4003
0000003_V100kiP@00@0kiP@00@000000:f][@3lX100o:0@0P00000=0?bP40030:f][@3oY140oj@A
00l0oj@A102][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006@3oXa000`000000[Jf]0?bP400I0?bP40030:f][@3fW0l0mY`?00@0[Jf]2`3fW0l20000
00<0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh2000000<0fhX=0P0000050=^:3@030000003KRPd0[Jf]
0080000000<0^GD;0000000000000`2iM@/01`000000^GD;0:f][@000000R5H700000028EPL00P00
00110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/01@2][Jd0dhL>0000003CQ`h0000000@0dhL>00<0
[Jf]0000003_V1000`3_V1000`000000kiP@0>nH40040>nH40060000002][Jd0o:0@0000003lX100
00003@3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00@0mY`?1@2][Jd60?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P0=0>bF3P05
0000003/UPh000000=^:3@0000000P3KRPd3000000@0fhX=00D000000=^:3@3KRPd0[Jf]00000003
0;Ue2`0:0000002iM@/0^GD;0000002iM@/0[Jf]00000028EPL0000008QF1`800000@@2`h>H10?oo
o`00F02`h>H20:f][@<0Uf0;00D0[Jf]0=>73P000000dhL>000000030=>73P80[Jf]00<000000>nH
403_V1000P3_V1000`000000kiP@0>nH40040>nH40030000002][Jd000000080o:0@00<000000?bP
403lX1002`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd00`3fW0l00000000000030?JL3`030:f][@3/UPh0k9H>
00h0k9H>0P000000103KRPd000000=^:3@3KRPd3000000@0fhX=00D000000=^:3@3KRPd0[Jf]0000
00020:f][@070;Ue2`000000^GD;0;Ue2`000000^GD;0:f][@030000000408QF1`00000000000000
0400/>3V0@3oool005P0/>3V0P2][Jd309MP2`050:f][@3CQ`h000000=>73P0000000P3CQ`h0102]
[Jd0dhL>0:f][@0000040>nH40030000003_V100kiP@00D0kiP@00D000000?bP403lX100o:0@0000
000=0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l03P3fW0l0102][Jd000000000002][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>
00<0[Jf]0=^:3@0000000P0000020=^:3@030000003KRPd0fhX=008000000P3KRPd01P2][Jd00000
0;Ue2`2iM@/0[Jf]00000080^GD;00<000000;Ue2`2][Jd00`0000001028EPL00000000000000010
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/01`2][Jd0dhL>0000003CQ`h000000=>73P2][Jd00P3C
Q`h00`2][Jd000000>nH40030>nH40030000003_V100kiP@00D0kiP@00D0[Jf]0?bP403lX100o:0@
0000000=0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00l0mY`?0P0000000`3fW0l0[Jf]0:f][@020:f][A40k9H>00@0[Jf]0=^:3@3KRPd0
00000`3KRPd00`000000fhX=0=^:3@0200000080fhX=00<0[Jf]0000002iM@/00P2iM@/200000004
0;Ue2`000000^GD;0:f][@<0000000@0R5H70:f][@0000000000@02`h>H10?ooo`00F02`h>H20:f]
[@<0Uf0;00H0[Jf]0=>73P000000dhL>0000002][Jd30=>73P030:f][@000000kiP@00<0kiP@00<0
00000>nH403_V1001@3_V1000`2][Jd0o:0@0?bP4002000000`0o:0@0`2][JdE0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l2000000<0mY`?00<0[Jf]0>bF3P2][Jd00P2]
[Jd>0>bF3P030:f][@3KRPd0fhX=00D0fhX=00@000000=^:3@00000000000P3KRPd00`2][Jd00000
0;Ue2`020;Ue2`80000000@0^GD;00000011JN40[Jf]0`0000001028EPL0[Jf]0000000000100;3P
iP40oooo001H0;3PiP80[Jf]0`2GH0/01@2][Jd0dhL>0000002][Jd0000000@0dhL>00<0[Jf]0000
003_V1000`3_V1000`000000kiP@0>nH40050>nH40030:f][@3lX100o:0@008000002P3lX1020:f]
[@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0?0?JL
3`8000000`3fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@050=^:
3@<000000`3KRPd00`2][Jd000000;Ue2`020;Ue2`80000000@0[Jf]0000002iM@/0[Jf]0`000000
1028EPL0[Jf]0000000000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/01@2][Jd0dhL>0000003C
Q`h0000000@0dhL>00@0[Jf]0000003_V100kiP@0P0000080>nH40030:f][@3lX100o:0@00800000
1`3lX1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00l0mY`?0P0000030?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`0000000P2iM@/00`000000^GD;0;Ue2`0200000006045Y
h@000000000000000028EPL0[Jf]0P0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/20:f][@03
0000003CQ`h0000000@0dhL>00<0[Jf]0000003_V1002`3_V1000`2][Jd0o:0@0?bP4002000000D0
o:0@0P2][Jd60?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0<0?JL3`80000000<0mY`?0000000000000`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0
[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/000000080^GD;00<000000;Ue2`2i
M@/00P0000000`2][Jd000000000000200000080[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00
F02`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0000000800000103CQ`h00`2][Jd00000
0>nH400;0>nH40030:f][@3lX100o:0@008000000P3lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
5@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00h0mY`?0`0000030?JL3`030:f][@3/UPh0k9H>00P0k9H>00@000000>bF3P2][Jd0
[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/000000080^GD;00<000000;Ue2`2i
M@/00P0000000`2][Jd000000000000200000080[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00
F02`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@040=>73P000000dhL>000000<0dhL>0P00000=0>nH
40030:f][@3lX100o:0@008000000P2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3P
iQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P8000000`3/UPh30:f][@030>bF3P2][Jd0fhX=
00d0fhX=00D0[Jf]0;Ue2`000000^GD;000000020;Ue2`80000000<0[Jf]0000000000000`000000
0`2][Jd000000;3PiP0o0;3PiP40oooo001H0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]00@0dhL>
0000003CQ`h000000`3CQ`h00`2][Jd0kiP@0>nH400<0>nH40030:f][@3lX100[Jf]008000003@3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3o
YQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P070>bF3P030000003/UPh0000000D0k9H>0`2][Jd=0=^:3@040:f][@2i
M@/00000000000<0^GD;0P0000000`2][Jd0000000000003000000030:f][@000000/>3V03l0/>3V
0@3oool005P0/>3V00X0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd0dhL>0000003CQ`h000000`3CQ`h0
0`2][Jd0kiP@0>nH400;0>nH40<0[Jf]00<0o:0@0000000000003@3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd7
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P07
0>bF3P8000001`3/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@040:f][@2iM@/0^GD;000000@0^GD;
0P0000001@28EPL00000000000000000[Jf]00800000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;
0:f][@0209MP2`050:f][@3CQ`h000000=>73P0000000`3CQ`h00`2][Jd0kiP@0>nH40090>nH4080
[Jf]00@0kiP@0:f][@3lX100o:0@0P00000=0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P080>bF3P030000003/UPh0k9H>00D0k9H>00@0[Jf]0=^:
3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00D0^GD;0P0000001@28EPL000000:f][@00
0000[Jf]00800000@02`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`090:f][@3CQ`h0
00000=>73P000000dhL>0000003CQ`h0[Jf]00T0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@0080
00003@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0
[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/40000000308QF1`000000[Jf]0080
0000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00T0[Jf]0=>73P000000dhL>0000003CQ`h00000
0=>73P2][Jd01`3_V1020:f][@D0kiP@00<0[Jf]0?bP403lX1000P00000=0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0
mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`<0000000<0R5H70000002][Jd00P0000100;3PiP40oooo001H0;3P
iP80[Jf]0`2GH0/00`2][Jd0dhL>000000030=>73P030000003CQ`h0[Jf]00D0kiP@0P2][Jd70>nH
40040:f][@3lX1000000000000h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@08
0?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;0`000000
0`28EPL000000:f][@0200000400/>3V0@3oool005L0/>3V0P2][Jd409MP2`030:f][@3CQ`h00000
00<0dhL>00<000000=>73P2][Jd00`3_V1020:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]
0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd0
0`3KRPd0[Jf]0;Ue2`080;Ue2`80000000<0R5H70000002][Jd00P0000100;3PiP40oooo001G0;3P
iP80[Jf]0`2GH0/0102][Jd0dhL>0000000000030=>73P040000003CQ`h0[Jf]0>nH4080[Jf]2`3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue2`030:f][@00
0000R5H700@00000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P000000103CQ`h0
10000000dhL>0:f][@2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3o
Y1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303K
RPd30:f][@L0^GD;00<0[Jf]00000028EPL0100000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/0
0`2][Jd0dhL>000000030=>73P040000003CQ`h0[Jf]0:f][@h0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00<0[Jf]00000028EPL0
100000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>000000030=>73P040000002]
[Jd0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]
h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f]
[@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/0102][Jd0000008QF1`28EPL300000400/>3V0@3oool005L0
/>3V0P2][Jd309MP2`030:f][@3CQ`h000000080dhL>00D0[Jf]0000003CQ`h0dhL>0:f][@0=0>nH
40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f]
[@<0^GD;00@0[Jf]000000000000R5H70`0000100;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/01`2]
[Jd0dhL>0000003CQ`h0[Jf]0=>73P0000000P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0P0000001028EPL0[Jf]045Yh@0000100;3PiP40
oooo001G0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0000002][Jd20=>73P040000003CQ`h0dhL>0:f]
[@d0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@80000000<0R5H70:f][@11JN400P00000o0;3P
iP40oooo001G0;3PiP80[Jf]0`2GH0/20:f][@050000003CQ`h0dhL>0=>73P0000000P3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f]
[@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@00000000000080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H00`2]
[Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h000000080dhL>0P0000020=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f]
[@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@0000000000
0080R5H700<0[Jf]000000000000?`2`h>H10?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@040=>73P0000000000000000@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP4004
0?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0000000000000P28EPL0
0`2][Jd000000000000o0;3PiP40oooo001G0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]00<0dhL>
0000003CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd4
0;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/0
0`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0
0`2][Jd000000000000208QF1`030:f][@000000000003l0/>3V0@3oool005L0/>3V00H0[Jf]09MP
2`2GH0/0[Jf]09MP2`2][Jd2000000H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f]
[@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2]
[Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd000000000000208QF1`030:f][@000000000003l0/>3V0@3o
ool005L0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100
kiP@00X0kiP@0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`4
0:f][MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP2
0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0202][Jd000000000002][Jd0R5H70:f][@2`h>H0
0000?`2`h>H10?ooo`00E`2`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@000000000008QF1`80
[Jf]00<0/>3V0000002`h>H0?P2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0
R5H70P2][Jd00`2`h>H000000;3PiP0n0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>
0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80
al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0
_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080
R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP030:f][@2GH0/0Uf0;0080Uf0;
00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@@0Y9j?00<0[Jf]0;6[W@2a
Zid00P2aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f]
[@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]00<000000;3P
iP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00H0[Jf]0>nH
402][Jd0[Jf]0:BNS`11JN430:BNS`03045Yh@2][Jd0/J^M00D0/J^M0P2][Jd50;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/0H0[Jf]Z@2`
h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n
^KP0_[Vh0;ji^080[Jf]202n^KP2045Yh@80];2a0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd30:BNS`06045Yh@2TWXl0Y9j?0:BNS`11JN40[Jf]202aZid2
0:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP2045Yh@<0];2a00<0@FWQ0:f][@2][Jd02P2i
M@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@11JN40@FWQ0080Y9j?0P11JN430:BNS`03045Y
h@2][Jd0/J^M00T0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]1`2n^KP00`11JN40_[Vh
0;ji^0020;ji^080@FWQ0`2d/;400`11JN40];2a0;B`/@020:f][@P0^GD;00@0[Jf]08QF1`28EPL0
R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd01P3CQ`h20:f][@030:BNS`11JN40Y9j?0080Y9j?0P11JN420:BNS`80@FWQ00<0[Jf]0;6[W@2a
Zid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/004
0:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0060;ji
^003045Yh@2n^KP0@FWQ00<0_[Vh00<0@FWQ0;B`/@2d/;400P2d/;400`11JN40];2a0;B`/@020;B`
/@030:f][@2iM@/0^GD;00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m
0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h30:f][@80@FWQ0`2TWXl2
045Yh@80Y9j?0P11JN450;6[W@@0@FWQ1@2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jej
0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP0102n^KP01011JN40_[Vh0;ji^011
JN430;ji^004045Yh@2][Jd0];2a0;B`/@80@FWQ0P2d/;400`11JN40];2a0;B`/@020:f][@D0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01P2][Jd0RXEe08Z5M@2][Jd0Y9j?045Yh@<0Y9j?0P11JN42
0:BNS`80@FWQ102aZid01`11JN40/J^M045Yh@2aZid0@FWQ0;6[W@11JN400`2aZid00`2][Jd0^K:V
0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`02@36`;`00`11JN40a/2l0<K0_0040<K0_0030:f][@33_K/0`kfk0080`kfk
102][Jd70<>m^`040:f][@2n^KP0_[Vh045Yh@<0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh045Yh@030;ji
^0030:f][@2d/;40];2a0080@FWQ0P2d/;400`11JN40];2a0:f][@040:f][@<0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd00`3CQ`h0102][Jd0RXEe08Z5M@11JN420:f][@04045Yh@2TWXl0Y9j?0:BNS`80@FWQ
0P2TWXl2045Yh@@0/J^M0P11JN430;6[W@<0@FWQ0P2aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]
1@2i/ZH00`2][Jd0_[N/0;jg[0020;jg[0@0@FWQ2P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f]
[@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0070<K0_080@FWQ
1`36`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]045Yh@11JN400`2n^KP2045Yh@L0_[Vh
00@0[Jf]0;B`/@11JN40@FWQ0`2d/;401@11JN40[Jf]0;B`/@2d/;40[Jf]0080Wi^P00@0[Jf]0;Ue
2`2iM@/0[Jf]0`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00H0[Jf]09MP
2`2GH0/0Uf0;0:f][@3CQ`h20:f][@08045Yh@2:QGD0RXEe045Yh@2][Jd0Y9j?045Yh@2][Jd20:BN
S`80@FWQ0P2TWXl2045Yh@@0/J^M0P11JN430;6[W@<0@FWQ0P2aZid3045Yh@T0^K:V102][Jd00`2i
/ZH0[Jf]0;jg[0050;jg[0@0@FWQ202n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k
0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050<K0_0<0@FWQ1`36`;`30:f]
[@/0`kfk00<0@FWQ0<>m^`11JN400P11JN440;ji^003045Yh@2n^KP0_[Vh00H0_[Vh00<0[Jf]0;B`
/@11JN400`2d/;400`2][Jd0@FWQ0;B`/@020;B`/@040:f][@2OVj00Wi^P09nKX0<0[Jf]1028EPL0
0`2][Jd000000;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd508Z5
M@05045Yh@2][Jd0Y9j?045Yh@2TWXl00P2][Jd00`11JN40Y9j?045Yh@03045Yh@@0/J^M00<0@FWQ
0;6[W@2aZid00`2aZid2045Yh@80/J^M00<0[Jf]0;VbYP11JN400P11JN4;0;VbYP<0[Jf]1@2n]j`2
045Yh@X0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`0
1011JN40a/2l0<K0_036`;`40:f][@030<K0_02][Jd0`kfk00T0`kfk0P11JN430<>m^`030:f][@11
JN40_[Vh00<0_[Vh00<0@FWQ0;ji^02n^KP01P2n^KP0102][Jd0@FWQ045Yh@2d/;420:f][@030;B`
/@11JN40];2a0080];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0R5H708QF1`0208QF1`030:f]
[@2`h>H0000003h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe08Z5
M@0408Z5M@04045Yh@2][Jd0Y9j?045Yh@<0Y9j?00<0@FWQ0:f][@11JN400`11JN440;6[W@03045Y
h@2aZid0/J^M00<0/J^M0P11JN420;6[W@030:f][@2i/ZH0@FWQ00h0^K:V00<0[Jf]0;jg[02][Jd0
0`2][Jd00`2n]j`0@FWQ045Yh@0:0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00L0a/2l00@0@FWQ0:f][@2][Jd0
[Jf]1@36`;`00`2][Jd0`kfk0<>m^`060<>m^`@0@FWQ0`33_K/00`2][Jd0@FWQ0;ji^0030;ji^003
045Yh@2n^KP0_[Vh00H0_[Vh00D0[Jf]045Yh@2d/;40[Jf]045Yh@020;B`/@05045Yh@2d/;40];2a
0;B`/@2][Jd01P2OVj001`2][Jd0R5H708QF1`28EPL0[Jf]0;3PiP000000?P2`h>H10?ooo`00EP2`
h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@L0RXEe00<0@FWQ0:BNS`11JN400P2TWXl2045Yh@060:BN
S`11JN40@FWQ0:BNS`2][Jd0@FWQ0`2aZid00`11JN40/J^M0;6[W@030;6[W@80@FWQ0P2aZid00`2]
[Jd0^K:V045Yh@0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/00@0[Jf]045Yh@11JN40[Jf]2@2n]j`0
0`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`0
0`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]00<0@FWQ0<K0_036`;`01P36`;`00`2][Jd0`kfk0<>m^`02
0<>m^`<0@FWQ0`33_K/2045Yh@@0`kfk00@0@FWQ0;ji^02n^KP0_[Vh0P11JN480;ji^080@FWQ00<0
[Jf]0;B`/@11JN400P2d/;401@11JN40];2a0;B`/@2d/;40[Jf]00H0Wi^P00D0[Jf]08QF1`28EPL0
R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`2:QGD00`2][Jd0
@FWQ0:BNS`020:BNS`03045Yh@2TWXl0Y9j?0080@FWQ0P2][Jd00`11JN40/J^M0;6[W@02045Yh@D0
/J^M0P11JN420;6[W@030:f][@2i/ZH0@FWQ00h0^K:V00<0[Jf]0;jg[02n]j`0102n]j`2045Yh@03
0;jg[02][Jd0[Jf]0080[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0:f][@030:f][@@0a/2l00<0@FWQ0<K0_036
`;`01P36`;`00`2][Jd0`kfk0<>m^`03045Yh@D0`kfk0P11JN440<>m^`04045Yh@2n^KP0_[Vh0;ji
^080@FWQ1`2n^KP00`2][Jd0@FWQ0;B`/@020;B`/@04045Yh@2d/;40];2a045Yh@<0];2a00<0[Jf]
09nKX02OVj001@2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0
Uf0;00<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`03045Yh@2TWXl0Y9j?0080@FWQ00<0Y9j?
0:f][@11JN400P2aZid2045Yh@D0/J^M0P11JN420;6[W@030:f][@2i/ZH0@FWQ00T0^K:V1@11JN40
0`2][Jd0_[N/0;jg[0040;jg[080@FWQ1@2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]2036`;`00`11JN40a/2l0<K0_006
0<K0_0030:f][@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@@0`kfk00@0@FWQ
0;ji^02n^KP0_[Vh0P11JN440;ji^005045Yh@2][Jd0[Jf]0;ji^011JN400`2d/;400`11JN40];2a
0;B`/@02045Yh@80];2a00<0[Jf]09nKX02OVj001@2OVj020:f][@0308QF1`2][Jd0/>3V03l0/>3V
0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd608Z5M@030:f][@2TWXl0Y9j?0080Y9j?
0P11JN420:BNS`80@FWQ00<0Y9j?0:f][@11JN400P2][Jd2045Yh@D0/J^M0P11JN420;6[W@030:f]
[@2i/ZH0@FWQ00P0^K:V0P11JN430;VbYP04045Yh@2][Jd0_[N/0;jg[080@FWQ0P2n]j`2045Yh@T0
_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80
al6l00<0[Jf]0<K0_036`;`01`36`;`00`11JN40a/2l0<K0_003045Yh@<0a/2l00<0[Jf]0<>m^`33
_K/00P33_K/00`11JN40`kfk0<>m^`030<>m^`80@FWQ1033_K/01011JN40_[Vh0;ji^02n^KP2045Y
h@<0_[Vh00<0[Jf]045Yh@11JN400P2n^KP01@11JN40];2a0;B`/@2d/;40@FWQ0080];2a0P11JN42
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H2
0:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80@FWQ00H0Y9j?
045Yh@11JN40Y9j?0:f][@11JN420;6[W@80@FWQ00@0[Jf]0;6[W@2aZid0/J^M0`11JN420;6[W@03
0:f][@2i/ZH0@FWQ00P0^K:V0P11JN440;VbYP03045Yh@2n]j`0@FWQ00@0_[N/0P11JN4:0;jg[003
0:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0
al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_011JN400`36`;`01011JN40
a/2l0<K0_02][Jd40<>m^`03045Yh@33_K/0`kfk00<0`kfk0P11JN440<>m^`04045Yh@2n^KP0_[Vh
0;ji^080@FWQ0`2][Jd00`2n^KP0@FWQ045Yh@020;ji^003045Yh@2d/;40];2a0080@FWQ0P2d/;42
045Yh@80];2a00<0[Jf]09nKX02OVj00102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool0
05H0/>3V0P2][Jd306=PD`80[Jf]1@2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`<0@FWQ00<0Y9j?0:f]
[@11JN400P2aZid00`11JN40/J^M0;6[W@020:f][@80/J^M0P11JN420;6[W@030:f][@2i/ZH0@FWQ
00P0^K:V0P11JN440;VbYP<0@FWQ102n]j`2045Yh@040;jg[011JN40@FWQ045Yh@H0_[N/00<0[Jf]
0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_005
0:f][@`0al6l00<0[Jf]0<K0_036`;`00`36`;`2045Yh@80a/2l00<0@FWQ0<K0_011JN400`36`;`2
045Yh@030<K0_02][Jd0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@@0`kfk00@0[Jf]
045Yh@2n^KP0_[Vh0P11JN440;ji^080@FWQ0P2n^KP01011JN40];2a0;B`/@11JN430;B`/@80@FWQ
0P2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo
001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0Y9j?0:BN
S`060:BNS`80@FWQ00<0Y9j?0:f][@11JN400P2aZid00`11JN40/J^M0;6[W@020;6[W@<0[Jf]00@0
/J^M045Yh@2aZid0[Jf]0P11JN480;VbYP80@FWQ0`2i/ZH0102][Jd0_[N/045Yh@11JN440;jg[0<0
@FWQ0P2n]j`2045Yh@D0_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04038`K/60:f][A40al6l00<0[Jf]045Yh@36`;`00P36`;`00`11JN40a/2l0<K0_0020<K0_003
045Yh@36`;`0@FWQ00@0a/2l0P11JN400`2][Jd0`kfk0<>m^`020<>m^`03045Yh@33_K/0`kfk00<0
`kfk0P11JN440<>m^`050:f][@11JN40[Jf]0:f][@2n^KP00P11JN430;ji^005045Yh@2n^KP0_[Vh
0;ji^02][Jd00P11JN440;B`/@80@FWQ0P2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2OVj00
Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]
08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`080:BNS`<0@FWQ0P2aZid00`11JN40/J^M0;6[
W@050;6[W@80[Jf]00@0/J^M0:f][@11JN40@FWQ202i/ZH2045Yh@<0^K:V00@0[Jf]0;jg[011JN40
@FWQ102n]j`2045Yh@@0_[N/0P11JN440;jg[0040:f][@11JN40@FWQ045Yh@h0`KZ`202][Jd@0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1
^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00@0<O1_080@FWQ00D0a/2l045Yh@11JN40a/2l045Yh@04
0<K0_080@FWQ1@36`;`2045Yh@030:f][@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`33_K/00`33_K/2
045Yh@<0`kfk0P2][Jd01011JN40_[Vh0;ji^02n^KP2045Yh@<0_[Vh00D0@FWQ0;ji^02n^KP0_[Vh
0:f][@060;B`/@80@FWQ0P2d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT0
0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe
0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00D0[Jf]045Yh@11JN40/J^M045Yh@090;6[W@80
[Jf]0P11JN480;VbYP80@FWQ0`2i/ZH0102][Jd0_[N/045Yh@11JN440;jg[080@FWQ102n]j`2045Y
h@@0_[N/00<0[Jf]0<6j/031^[001011JN4=0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/8
0:f][@X0b<6k00<0[Jf]0<O1_037`K`03P37`K`2045Yh@040<O1_02][Jd0a/2l0<K0_0<0@FWQ1036
`;`2045Yh@H0a/2l00<0@FWQ0:f][@33_K/00`33_K/00`11JN40`kfk0<>m^`030<>m^`80@FWQ0`2]
[Jd00`33_K/0[Jf]045Yh@030;ji^080@FWQ0P2n^KP00`11JN40_[Vh0;ji^0020;ji^0030:f][@2d
/;40];2a00@0];2a0P11JN420;B`/@030:f][@2OVj00[Jf]00D0Wi^P00<0[Jf]071^N@1`KWT00P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD0
0`2][Jd0RXEe0:f][@0;0:BNS`050:f][@2aZid0/J^M0;6[W@11JN402P2aZid00`2][Jd0@FWQ045Y
h@020:f][@L0^K:V00H0@FWQ0;VbYP2i/ZH0^K:V0:f][@2n]j`2045Yh@<0_[N/0P11JN460;jg[080
@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/002045Yh@<0`KZ`1011JN480<6j/0030:f][@33_K<0`kfc00h0
`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0080
al6l0`11JN490<O1_080@FWQ00<0al6l0:f][@36`;`00P36`;`2045Yh@D0a/2l00<0@FWQ0<K0_036
`;`01036`;`00`11JN40[Jf]0<>m^`030<>m^`03045Yh@33_K/0`kfk0080`kfk00<0[Jf]045Yh@11
JN401033_K/00`2][Jd0@FWQ0;ji^0030;ji^080@FWQ00<0_[Vh045Yh@2n^KP00`2n^KP00`2][Jd0
];2a0;B`/@040;B`/@80@FWQ0P2d/;420:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40
oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD20:f][@/0Y9j?
00D0[Jf]0;6[W@2aZid0/J^M045Yh@0:0;6[W@030:f][@11JN40@FWQ0080^K:V0`2][Jd50;VbYP05
045Yh@2i/ZH0^K:V0:f][@2n]j`00P11JN430;jg[080@FWQ1P2n]j`2045Yh@<0_[N/00<0[Jf]0<6j
/031^[000P11JN460<6j/0@0@FWQ00H0`KZ`045Yh@11JN40@FWQ0<6j/02][JdE0<>m/`030:f][@35
_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_011JN400`11JN4;0<O1_004045Yh@37`K`0al6l0:f][@<0a/2l
0P11JN450<K0_003045Yh@36`;`0a/2l00@0a/2l00<0@FWQ0:f][@33_K/00`33_K/00`11JN40`kfk
0<>m^`020:f][@030<>m^`11JN40@FWQ00@0`kfk00<0[Jf]045Yh@2n^KP0102n^KP2045Yh@D0_[Vh
00<0[Jf]0;B`/@2d/;40102d/;42045Yh@80];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii
071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe
08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00@0[Jf]0;6[W@2aZid0/J^M0P11JN490;6[W@03
0:f][@11JN40@FWQ00D0^K:V102][Jd20;VbYP05045Yh@2i/ZH0[Jf]0;jg[011JN40102n]j`2045Y
h@H0_[N/0P11JN420;jg[0040:f][@31^[00`KZ`0<6j/080@FWQ1P31^[000`11JN40`KZ`0<6j/005
0<6j/0@0@FWQ4`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00`0b<6k0P11JN42
0<S1^`80@FWQ00<0b<6k0:f][@37`K`00`37`K`00`11JN40al6l0<O1_0090<O1_004045Yh@37`K`0
al6l0:f][@<0a/2l0P11JN450<K0_003045Yh@36`;`0a/2l00@0a/2l0P11JN440<>m^`03045Yh@2]
[Jd0[Jf]00<0`kfk0P11JN440<>m^`030:f][@11JN40_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;401@2d
/;401011JN40[Jf]0:f][@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00
EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`040:f][@2aZid0/J^M0;6[
W@80@FWQ2@2aZid00`2][Jd0@FWQ045Yh@030;VbYP03045Yh@2i/ZH0^K:V00<0^K:V0`2][Jd2045Y
h@030;jg[011JN40_[N/00<0_[N/0P11JN470;jg[004045Yh@2n]j`0_[N/0:f][@<0`KZ`0P11JN46
0<6j/003045Yh@31^[00`KZ`00D0`KZ`00<0@FWQ0:f][@33_K<01`33_K<3045Yh@X0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00/0b<6k00<0@FWQ0<S1^`38`K/01011JN400`38`K/0[Jf]0<O1_003
0<O1_003045Yh@37`K`0al6l00T0al6l00@0@FWQ0<O1_037`K`0[Jf]0`36`;`2045Yh@D0a/2l00<0
@FWQ0<K0_036`;`01036`;`2045Yh@050<>m^`2][Jd0[Jf]0:f][@11JN401@33_K/2045Yh@@0`kfk
00<0[Jf]045Yh@2n^KP02`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f][@L0
Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=P
D`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00@0[Jf]0;6[W@2aZid0/J^M0P11JN45
0;6[W@04045Yh@2aZid0/J^M0;6[W@@0@FWQ0P2i/ZH00`11JN40^K:V0;VbYP060;VbYP80[Jf]0P11
JN440;jg[080@FWQ1`2n]j`01011JN40_[N/0;jg[02][Jd30<6j/080@FWQ1P31^[000`11JN40`KZ`
0<6j/0050<6j/003045Yh@2][Jd0`kfc00D0`kfc0P11JN430<>m/`03045Yh@33_K<0`kfc00D0`kfc
00<0@FWQ0<>m/`2][Jd05P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03045Yh@38`K/0b<6k00T0b<6k
0P11JN440<S1^`<0@FWQ00<0b<6k0:f][@37`K`00`37`K`00`11JN40al6l0<O1_0090<O1_004045Y
h@37`K`0al6l0:f][@<0a/2l0P11JN450<K0_003045Yh@36`;`0a/2l00<0a/2l0P11JN420:f][@<0
`kfk0P11JN440<>m^`80@FWQ0`33_K/3045Yh@`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][@<0
];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0
/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?
00@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid00`11JN40/J^M0;6[W@030;6[W@05045Yh@2aZid0/J^M
0;6[W@2][Jd00`11JN420;VbYP80@FWQ102i/ZH01`11JN40^K:V0;VbYP2i/ZH0[Jf]0;jg[011JN40
0`2][Jd00`2n]j`0@FWQ045Yh@070;jg[004045Yh@2n]j`0_[N/0:f][@<0`KZ`0P11JN460<6j/003
045Yh@31^[00`KZ`00D0`KZ`00<0@FWQ0:f][@33_K<01033_K<2045Yh@D0`kfc00<0@FWQ0<>m/`33
_K<01033_K<00`11JN40`kfc0:f][@04045YhA80aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03P38`K/00`11JN40
b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00P0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@03
0<S1^`2][Jd0al6l00<0al6l00<0@FWQ0<O1_037`K`02@37`K`01011JN40al6l0<O1_02][Jd30<K0
_080@FWQ1@36`;`00`11JN40[Jf]0:f][@030:f][@80@FWQ00<0[Jf]0<>m^`33_K/00P33_K/2045Y
h@@0`kfk0P11JN440<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd5
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0
102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2a
Zid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid00`2aZid01@11JN40/J^M0;6[W@2aZid0[Jf]00<0^K:V
1011JN440;VbYP07045Yh@2i/ZH0^K:V0;VbYP2][Jd0_[N/045Yh@030;jg[0040:f][@11JN40@FWQ
0:f][@H0_[N/00@0@FWQ0;jg[02n]j`0[Jf]0`31^[02045Yh@H0`KZ`00<0@FWQ0<6j/031^[001@31
^[000`11JN40[Jf]0<>m/`030<>m/`80@FWQ1`33_K<00`11JN40`kfc0<>m/`030<>m/`<0@FWQ1035
_[D2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D01`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0102][Jd0@FWQ045Yh@11JN450<S1^`80@FWQ
1P38`K/00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00P0b<6k00<0@FWQ0<S1^`38`K/0
1@38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l00<0@FWQ0<O1_037`K`02@37`K`2045Yh@030<O1
_02][Jd0a/2l0080a/2l0P11JN420<K0_0<0[Jf]00<0@FWQ0<K0_036`;`00`36`;`2045Yh@030:f]
[@33_K/0`kfk0080`kfk0`11JN420<>m^`80@FWQ1@33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f]
[@2d/;40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3P
iP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80
Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2045Yh@@0/J^M00@0@FWQ0;6[W@2aZid0[Jf]1P2i/ZH00`11
JN40^K:V0;VbYP030;VbYP07045Yh@2i/ZH0^K:V0;VbYP2][Jd0_[N/045Yh@040;jg[080@FWQ00<0
_[N/0:f][@2][Jd00P2][Jd20;jg[004045Yh@2n]j`0_[N/0:f][@<0`KZ`0P11JN450<6j/080@FWQ
1`31^[000`11JN40[Jf]0<>m/`030<>m/`80@FWQ2033_K<00`11JN40`kfc0<>m/`020<>m/`80@FWQ
00<0[Jf]0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@030<Fn]@03045Yh@35_[D0@FWQ00P0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j0080al6j
1`11JN4;0<O1^P80@FWQ0`38`K/2045Yh@030<S1^`11JN40@FWQ00P0b<6k00<0@FWQ0<S1^`38`K/0
0P38`K/00`11JN40[Jf]045Yh@080<S1^`80@FWQ1`38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l
00<0@FWQ0<O1_037`K`02`37`K`7045Yh@80[Jf]0`36`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ
00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@030<>m^`11JN40@FWQ00L0`kfk00<0[Jf]0;ji^02n^KP0
2`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo
001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@D0/J^M00<0
@FWQ0;6[W@2aZid00P2aZid01011JN40/J^M0;6[W@2][Jd<0;VbYP07045Yh@2i/ZH0^K:V0;VbYP2]
[Jd0_[N/045Yh@040;jg[080@FWQ1@2n]j`01P2][Jd0@FWQ045Yh@2][Jd0_[N/0:f][@<0`KZ`0P11
JN450<6j/080@FWQ1`31^[000`11JN40[Jf]0<>m/`030<>m/`03045Yh@33_K<0`kfc00`0`kfc00<0
@FWQ0<>m/`2][Jd01P35_[D00`11JN40aKje0<Fn]@030<Fn]@03045Yh@35_[D0aKje00L0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0080<O1^0X0@FWQ0P37`KP00`2][Jd0al6j0<O1
^P050<O1^P80@FWQ3037`KX2045Yh@030:f][@38`K/0b<6k0080b<6k0`11JN480<S1^`<0@FWQ0`38
`K/3045Yh@L0b<6k0P11JN480<S1^`80@FWQ00<0b<6k0:f][@37`K`00`37`K`00`11JN40al6l0<O1
_00:0<O1_0D0[Jf]00<0a/2l045Yh@11JN401@36`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ00<0
a/2l0:f][@33_K/00`33_K/2045Yh@X0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][@X0];2a00<0
[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD0
0`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]102aZid01011JN40/J^M0;6[W@2aZid2045Yh@80/J^M00<0
[Jf]0;VbYP2i/ZH02`2i/ZH2045Yh@030;VbYP2][Jd0@FWQ00D0_[N/0P11JN460;jg[080@FWQ00<0
_[N/0:f][@2][Jd00`2][Jd2045Yh@D0`KZ`0P11JN470<6j/003045Yh@2][Jd0`kfc00<0`kfc00<0
@FWQ0<>m/`33_K<03033_K<00`11JN40`kfc0:f][@060<Fn]@03045Yh@35_[D0aKje00d0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00:0<O1^080@FWQ1@37`KP3045Yh@030:f][@37
`KX0al6j00D0al6j0P11JN4<0<O1^P03045Yh@37`KX0[Jf]00D0b<6k0P11JN480<S1^`<0@FWQ0`38
`K/3045Yh@L0b<6k0P11JN480<S1^`80@FWQ00<0b<6k0:f][@37`K`00`37`K`00`11JN40al6l0<O1
_0050<O1_0D0[Jf]0P37`K`0102][Jd0a/2l0<K0_036`;`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`0
0P36`;`2045Yh@030<K0_02][Jd0`kfk00<0`kfk0P11JN4:0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh
0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo
001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]0P2a
Zid5045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH2045Yh@H0_[N/0`11JN450;jg[080@FWQ0P2n
]j`0102][Jd0`KZ`0<6j/031^[02045Yh@D0[Jf]0P11JN460<6j/080@FWQ00<0[Jf]0<>m/`33_K<0
0P33_K<00`11JN40`kfc0<>m/`0>0<>m/`030:f][@35_[D0aKje00@0aKje00<0@FWQ0<Fn]@35_[D0
3@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00X0al6h0P11JN470<O1^003045Y
h@2][Jd0al6j00H0al6j0P11JN4<0<O1^P03045Yh@37`KX0[Jf]00D0b<6k0P11JN480<S1^`<0@FWQ
0`38`K/3045Yh@L0b<6k0P11JN480<S1^`80@FWQ00<0b<6k0:f][@37`K`00`37`K`2045Yh@030<O1
_02][Jd0[Jf]00<0[Jf]1`37`K`01@2][Jd0a/2l0<K0_036`;`0@FWQ00H0a/2l0P11JN420<K0_080
@FWQ0P36`;`00`2][Jd0`kfk0<>m^`020<>m^`80@FWQ2P33_K/00`2][Jd0@FWQ0;ji^0060;ji^080
[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40
oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@020;6[W@80[Jf]102aZid01011JN40/J^M0;6[W@2][Jd@0;VbYP030:f][@2n]j`0_[N/00<0
_[N/1011JN440;jg[080@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/002045Yh@H0`KZ`0P11JN450:f][@04
0<6j/011JN40@FWQ0:f][@<0`kfc0P11JN4@0<>m/`030:f][@35_[D0aKje00<0aKje0P11JN4?0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02P37`KP2045Yh@P0al6h00<0@FWQ0:f]
[@37`KX01@37`KX2045Yh@`0al6j00<0@FWQ0<O1^P2][Jd01@38`K/2045Yh@P0b<6k0`11JN430<S1
^`<0@FWQ1`38`K/00`11JN40b<6k0<S1^`050<S1^`H0@FWQ0P37`K`20:f][@80@FWQ00<0[Jf]0<O1
_037`K`02037`K`00`11JN40al6l0:f][@030<K0_003045Yh@36`;`0a/2l00@0a/2l00@0@FWQ0<K0
_011JN40@FWQ1036`;`00`2][Jd0`kfk0<>m^`020<>m^`80@FWQ2P33_K/2045Yh@@0_[Vh0`2][Jd5
0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP11
0;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2]
[Jd0/J^M0;6[W@040;6[W@<0[Jf]00D0/J^M045Yh@2aZid0/J^M0:f][@0@0;VbYP030:f][@2n]j`0
_[N/00@0_[N/0P11JN40102n]j`0@FWQ045Yh@2n]j`2045Yh@@0_[N/00<0[Jf]0<6j/031^[000P11
JN460<6j/080@FWQ1@31^[000`2][Jd0@FWQ045Yh@040:f][@80@FWQ4033_K<0102][Jd0aKje0<Fn
]@35_[D3045YhA00aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00:0<O1^080@FWQ
2037`KP00`11JN40[Jf]0<O1^P050<O1^P80@FWQ3037`KX00`11JN40al6j0:f][@050<S1^`80@FWQ
2038`K/00`11JN40b<6k045Yh@030<S1^`03045Yh@2][Jd0@FWQ00L0b<6k00<0@FWQ0<S1^`38`K/0
1`38`K/60:f][@80al6l0P11JN440<O1_003045Yh@37`K`0al6l00@0al6l00<0@FWQ0<O1_02][Jd0
0`36`;`00`11JN40a/2l0<K0_0020<K0_0<0@FWQ2036`;`0102][Jd0`kfk0<>m^`33_K/2045Yh@X0
`kfk00@0[Jf]045Yh@2n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nK
X02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0
RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i
/ZH03`2i/ZH00`2][Jd0_[N/0;jg[0090;jg[080@FWQ1@2n]j`00`2][Jd0`KZ`0<6j/003045Yh@D0
`KZ`0P11JN460<6j/080@FWQ00@0[Jf]0<>m/`33_K<0`kfc0P11JN450:f][@/0`kfc00<0[Jf]0<Fn
]@11JN400`11JN4A0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02P37`KP2045Y
h@P0al6h0P11JN460<O1^P80@FWQ3037`KX00`11JN40al6j0:f][@050<S1^`80@FWQ1`38`K/2045Y
h@040<S1^`11JN40b<6k0<S1^`80@FWQ00<0[Jf]0<S1^`11JN401P38`K/00`11JN40b<6k0<S1^`07
0:f][@<0b<6k00<0[Jf]0<O1_037`K`00P37`K`2045Yh@@0al6l0P11JN450<O1_004045Yh@37`K`0
[Jf]0<K0_080@FWQ4036`;`0102][Jd0`kfk0<>m^`33_K/2045Yh@X0`kfk00@0[Jf]0;ji^02][Jd0
[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`
h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/002045Yh@030<6j/011JN40`KZ`00<0`KZ`00<0@FWQ0<6j/031^[001@31^[02045Yh@030:f]
[@33_K<0`kfc0080`kfc0P11JN440<>m/`<0[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd30<>m/`@0@FWQ
2@35_[D00`11JN40aKje0<Fn]@070<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
2P37`KP2045Yh@P0al6h0P11JN460<O1^P80@FWQ3037`KX2045Yh@030:f][@38`K/0b<6k00<0b<6k
0P11JN470<S1^`80@FWQ0P38`K/02011JN40b<6k045Yh@11JN40[Jf]0<S1^`11JN40b<6k1@2][Jd0
0`11JN40[Jf]0:f][@0:0<S1^`030:f][@37`K`0al6l0080al6l0`11JN430<O1_080@FWQ1P37`K`3
045YhA80a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11JN490<>m^`<0[Jf]302n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0080@FWQ0P31^[001@11JN40`KZ`0<6j/031
^[00@FWQ00L0`KZ`0P11JN400`2][Jd0`kfc0<>m/`020<>m/`80@FWQ1P33_K<2045Yh@@0`kfc0P2]
[Jd3045Yh@@0[Jf]1`35_[D00`11JN40aKje0<Fn]@070<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP02P37`KP2045Yh@T0al6h0P11JN450<O1^P80@FWQ3P37`KX4045Yh@<0b<6k00<0
@FWQ0<S1^`38`K/01@38`K/2045Yh@040<S1^`2][Jd0@FWQ0:f][@80@FWQ0P2][Jd00`11JN40[Jf]
0<S1^`040<S1^`03045Yh@38`K/0b<6k00X0b<6k00<0[Jf]0<O1_037`K`00P37`K`2045Yh@050<O1
_011JN40al6l0<O1_011JN402037`K`00`2][Jd0a/2l0<K0_00A0<K0_0040:f][@33_K/0`kfk0<>m
^`80@FWQ1P33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2]
[Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2a
Zid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0080@FWQ0`31^[03045Yh@P0`KZ`0P11JN400`2][Jd0`kfc0<>m/`030<>m/`03
045Yh@33_K<0`kfc00D0`kfc00<0@FWQ0<>m/`33_K<00`33_K<2045Yh@030:f][@35_[D0aKje00<0
aKje1`2][Jd00`11JN40[Jf]0:f][@020:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00:0<O1^080@FWQ2@37`KP2045Yh@D0al6j0P11JN4>0<O1^P040:f][@38`K/0b<6k0<S1
^`@0@FWQ1`2][Jd2045Yh@040:f][@38`K/0@FWQ0<S1^`80@FWQ00<0[Jf]0<S1^`11JN401P38`K/2
045Yh@/0b<6k00<0[Jf]0<O1_037`K`00P37`K`2045Yh@80al6l0`11JN490<O1_0030:f][@36`;`0
a/2l0100a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11JN430<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[000P11JN4<0<6j/0@0@FWQ00<0[Jf]0<>m/`33_K<00`33_K<2
045Yh@D0`kfc00<0@FWQ0<>m/`33_K<01033_K<00`11JN40`kfc0:f][@060<Fn]@03045Yh@35_[D0
aKje00<0aKje00<0@FWQ0<Fn]@35_[D00P35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KP2
045Yh@T0al6h0P11JN450<O1^P80@FWQ0`37`KXA0:f][@030<S1^`11JN40b<6k00H0b<6k0P11JN42
0<S1^`07045Yh@38`K/0@FWQ045Yh@2][Jd0b<6k045Yh@060<S1^`80@FWQ2`38`K/00`2][Jd0al6l
0<O1_004045Yh@h0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`02045Yh@@0[Jf]
1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0
B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0
[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[000P11
JN4>0<6j/080@FWQ00<0[Jf]0<>m/`33_K<01033_K<00`11JN40`kfc0<>m/`030<>m/`03045Yh@33
_K<0`kfc00@0`kfc00<0@FWQ0<>m/`2][Jd01@35_[D2045Yh@D0aKje00<0@FWQ0<Fn]@35_[D01`35
_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]0P11JN490:f][@80@FWQ1@2][Jd2045Yh@<0[Jf]2`37
`KX00`2][Jd0b<6k0<S1^`040<S1^`03045Yh@38`K/0b<6k00D0b<6k00T0@FWQ0<S1^`38`K/0b<6k
045Yh@38`K/0@FWQ0<S1^`2][Jd00P38`K/00`11JN40b<6k0<S1^`030<S1^`80@FWQ2`38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m
^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0
/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40
_[N/00<0[Jf]0<6j/031^[000P11JN4@0<6j/0030:f][@33_K<0`kfc00D0`kfc1@11JN480<>m/`03
045Yh@2][Jd0aKje00@0aKje00<0@FWQ0<Fn]@35_[D01035_[D00`11JN40aKje0<Fn]@070<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02P37`KP2045Yh@T0al6h0P11JN450<O1^P80
@FWQ1@37`KX00`11JN40al6j0<O1^P040<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/00`11JN40
b<6k0<S1^`040<S1^`80@FWQ1038`K/2045Yh@050<S1^`2][Jd0b<6k0<S1^`11JN401@38`K/2045Y
h@T0b<6k00<0@FWQ0<S1^`2][Jd05037`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2]
[Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?oo
o`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/002045YhA00`KZ`00<0[Jf]0<>m/`33
_K<04P33_K<00`11JN40[Jf]0<Fn]@030<Fn]@80@FWQ1P35_[D00`11JN40aKje0<Fn]@070<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02P37`KP2045Yh@T0al6h0P11JN450<O1^P80
@FWQ1037`KX00`11JN40al6j045Yh@050<O1^P80@FWQ00<0[Jf]0<S1^`38`K/01038`K/00`11JN40
b<6k0<S1^`040<S1^`80@FWQ1038`K/2045Yh@030<S1^`2][Jd0@FWQ00D0@FWQ0`38`K/00`11JN40
b<6k0<S1^`070<S1^`03045Yh@38`K/0[Jf]01@0al6l00<0[Jf]0<K0_036`;`02@36`;`50:f][@80
a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0
];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[00
0P11JN4@0<6j/0030:f][@33_K<0`kfc01<0`kfc1@11JN400`35_[D0@FWQ0<Fn]@040<Fn]@<0@FWQ
2035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00X0al6h0P11JN490<O1^080@FWQ
1@37`KX3045Yh@<0al6j00<0@FWQ0<O1^P11JN401P37`KX00`11JN40[Jf]0<S1^`040<S1^`03045Y
h@38`K/0b<6k0080b<6k1`11JN420<S1^`80@FWQ00<0b<6k0:f][@38`K/02038`K/00`11JN40b<6k
0<S1^`070<S1^`03045Yh@38`K/0[Jf]01@0al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l
00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80
[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0080@FWQ
4031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00T0aKje0`11JN480<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02P37`KP2045Yh@T0al6h0P11JN450<O1^P80@FWQ
00<0al6j045Yh@37`KX00P37`KX2045Yh@L0al6j1P11JN4A0<S1^`030:f][@38`K/0b<6k00L0b<6k
00<0@FWQ0<S1^`38`K/01`38`K/00`11JN40b<6k0:f][@0D0<O1_0030:f][@36`;`0a/2l00D0[Jf]
2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40
[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@11JN400`11JN4>0<6j/003045Yh@31^[00[Jf]01D0`kfc
00<0[Jf]0<Fn]@35_[D02@35_[D3045Yh@P0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00:0<O1^080@FWQ2@37`KP2045Yh@80al6j1@11JN420<O1^P@0@FWQ2037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k00L0b<6k0P11JN470<S1^`80@FWQ00<0b<6k0:f][@37`K`0
4@37`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]
D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00?0;jg[0D0[Jf]3P31^[02045Yh@030<6j/02][Jd0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D02@35
_[D3045Yh@P0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00:0<O1^080@FWQ2037
`KP2045YhAH0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`070<S1^`80@FWQ1`38
`K/2045Yh@030<S1^`2][Jd0al6l00`0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H2
0:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00
`KZ`0<6j/0L0[Jf]1`31^[001011JN40`KZ`045Yh@2][JdE0<>m/`030:f][@35_[D0aKje00T0aKje
0`11JN480<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02P37`KP2045Yh@P0al6h
0P11JN4F0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02038`K/2045Yh@D0b<6k
00D0@FWQ0<S1^`11JN40b<6k0:f][@070<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V
0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0080<6j/0L0[Jf]00@0`KZ`045Yh@31^[00[Jf]5@33_K<00`2][Jd0aKje0<Fn]@090<Fn]@<0
@FWQ2035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00X0al6h0P11JN480<O1^080
@FWQ5P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k0P11JN420<S1^`80
@FWQ0P38`K/00`11JN40b<6k0:f][@020<O1_0D0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][EX0/>3V0@3oool007@0/>3V
0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00?0<6j/0L0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@090<Fn]@<0@FWQ2035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00X0al6h0P11JN480<O1^003045Yh@2][Jd0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0:0<S1^`<0@FWQ0`38`K/60:f][A80al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh
0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc
00<0[Jf]0<Fn]@35_[D02@35_[D00`11JN40aKje045Yh@080<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP02P37`KP2045Yh@P0al6h00<0@FWQ0:f][@37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]
G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35
_[D0aKje00X0aKje00<0@FWQ0<Fn]@35_[D01`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00X0al6h0P11JN470<O1^003045Yh@37`KP0[Jf]01H0al6j00<0[Jf]0<S1^`38`K/05038
`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033
_K<90:f][@L0aKje00<0@FWQ0<Fn]@35_[D01`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00X0al6h0P11JN460<O1^080@FWQ00<0al6h0:f][@37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP02037`KP:
045Yh@<0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/00`33_K/30:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;Vb
YP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102]
[Jd@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`00`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0
[Jf]PP2`h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00?0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@
0<S1^`L0[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0
[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38
`K/0b<6k202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0
[Jf][`2`h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56178 .33795 m
.57821 .33727 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47094 .33745 m
.47257 .33978 L
s
.46929 .33963 m
.47094 .33745 L
s
.47092 .34196 m
.47257 .33978 L
s
.57821 .33727 m
.5815 .33936 L
s
.57821 .33727 m
.58314 .33928 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46929 .33963 m
.47092 .34196 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5815 .33936 m
.5848 .34371 L
s
.58314 .33928 m
.58644 .34362 L
s
.45297 .33648 m
.45621 .33894 L
s
.45621 .33894 m
.45782 .34129 L
s
.44648 .33606 m
.45297 .33648 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45777 .34808 m
.45782 .34129 L
s
.5848 .34371 m
.58647 .34814 L
s
.58644 .34362 m
.58811 .34805 L
s
.59615 .33624 m
.60748 .33544 L
s
.47084 .35327 m
.47232 .3806 L
s
.46902 .38046 m
.47084 .35327 L
s
.44321 .3381 m
.44648 .33606 L
s
.45614 .34798 m
.45779 .34581 L
s
.58647 .34814 m
.58816 .35485 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45612 .35025 m
.45777 .34808 L
s
.58811 .34805 m
.58979 .35475 L
s
.45286 .35006 m
.45614 .34798 L
s
.44157 .34024 m
.44321 .3381 L
s
.44 .3356 m
.44157 .34024 L
s
.43991 .34466 m
.44 .3356 L
s
.45284 .35232 m
.45612 .35025 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44468 .35407 m
.45286 .35006 L
s
.43991 .34466 m
.44157 .34024 L
s
.44466 .35634 m
.45284 .35232 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58979 .35475 m
.58989 .36611 L
s
.58816 .35485 m
.58825 .3662 L
s
.56837 .33771 m
.56863 .38533 L
s
.56672 .33777 m
.56698 .38539 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60102 .33592 m
.60132 .36768 L
s
.60264 .3358 m
.60295 .36757 L
s
.47067 .38053 m
.47076 .36687 L
s
.45601 .36386 m
.45768 .35941 L
s
.45761 .3685 m
.45768 .35941 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44141 .35612 m
.44468 .35407 L
s
.45435 .36604 m
.45601 .36386 L
s
.45601 .36386 m
.45761 .3685 L
s
.58667 .37312 m
.58825 .3662 L
s
.60281 .35393 m
.6045 .36063 L
s
.44139 .35839 m
.44466 .35634 L
s
.42551 .33669 m
.42866 .3415 L
s
.42075 .334 m
.42551 .33669 L
s
.58831 .37303 m
.58989 .36611 L
s
0 0 0 r
.40772 .32822 m
.40847 .32986 L
s
.40459 .32464 m
.40772 .32822 L
s
.255 .412 .882 r
.45107 .36813 m
.45435 .36604 L
s
.56201 .38556 m
.57854 .38492 L
s
.43977 .35828 m
.44141 .35612 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47064 .38509 m
.47232 .3806 L
s
.41757 .3337 m
.42075 .334 L
s
.58506 .37776 m
.58667 .37312 L
s
.43975 .36055 m
.44139 .35839 L
s
.46902 .38046 m
.47064 .38509 L
s
.44455 .36772 m
.45107 .36813 L
s
.5867 .37768 m
.58831 .37303 L
s
.43973 .36283 m
.43977 .35828 L
s
.41436 .33565 m
.41757 .3337 L
s
.41278 .3355 m
.41757 .3337 L
s
.59644 .368 m
.60295 .36757 L
s
.6045 .36063 m
.60779 .36495 L
s
.58181 .38249 m
.58506 .37776 L
s
.58346 .38241 m
.5867 .37768 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57854 .38492 m
.58181 .38249 L
s
.57854 .38492 m
.58346 .38241 L
s
.43973 .36283 m
.44132 .36522 L
s
.44132 .36522 m
.44455 .36772 L
s
.62991 .33576 m
.63463 .33302 L
s
.62838 .34046 m
.62991 .33576 L
s
.41114 .33988 m
.41436 .33565 L
s
.6315 .33561 m
.63463 .33302 L
s
.62997 .3403 m
.6315 .33561 L
s
.62838 .34046 m
.62844 .345 L
s
.40956 .33972 m
.41278 .3355 L
s
.63463 .33302 m
.63936 .33252 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62997 .3403 m
.63003 .34485 L
s
.4269 .355 m
.42848 .35741 L
s
.42527 .35714 m
.4269 .355 L
s
.42845 .35969 m
.42848 .35741 L
s
.61422 .36218 m
.61581 .35978 L
s
.62844 .345 m
.63009 .3494 L
s
.42518 .36398 m
.42845 .35969 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61422 .36218 m
.61586 .36434 L
s
.61581 .35978 m
.61744 .36193 L
s
.60779 .36495 m
.61105 .36699 L
s
.61105 .36699 m
.61589 .36662 L
s
.42527 .35714 m
.42684 .35955 L
s
.63003 .34485 m
.63168 .34925 L
s
.63936 .33252 m
.64253 .33445 L
s
.40946 .34654 m
.41114 .33988 L
s
.61744 .36193 m
.61747 .36421 L
s
.40788 .34638 m
.40956 .33972 L
s
.61589 .36662 m
.61747 .36421 L
s
.63009 .3494 m
.63488 .35121 L
s
.39089 .33077 m
.40179 .33205 L
s
.63168 .34925 m
.63488 .35121 L
s
.42195 .36599 m
.42518 .36398 L
s
.64253 .33445 m
.64573 .33865 L
s
.4094 .3511 m
.40946 .34654 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40782 .35094 m
.40788 .34638 L
s
.41716 .36556 m
.42195 .36599 L
s
.39661 .36348 m
.3971 .33152 L
s
.64723 .33392 m
.65031 .33128 L
s
.64573 .33865 m
.64723 .33392 L
s
.63021 .35852 m
.63024 .3608 L
s
.63021 .35852 m
.6318 .35837 L
s
.4094 .3511 m
.41089 .3581 L
s
.39505 .3633 m
.39555 .33133 L
s
.6318 .35837 m
.63183 .36065 L
s
.65031 .33128 m
.65186 .33109 L
s
.64879 .33374 m
.65031 .33128 L
s
.6473 .33847 m
.64879 .33374 L
s
.63024 .3608 m
.63186 .36293 L
s
.40782 .35094 m
.4093 .35795 L
s
.414 .36298 m
.41716 .36556 L
s
.41241 .36283 m
.41716 .36556 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63488 .35121 m
.64437 .3525 L
s
.64573 .33865 m
.64604 .35919 L
s
.6473 .33847 m
.64754 .35444 L
s
.41089 .3581 m
.414 .36298 L
s
.63186 .36293 m
.63507 .36491 L
s
.4093 .35795 m
.41241 .36283 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63507 .36491 m
.64139 .36427 L
s
.64437 .3525 m
.64597 .35462 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37403 .32851 m
.38472 .32998 L
s
.64604 .35919 m
.64754 .35444 L
s
.64139 .36427 m
.64451 .36165 L
s
.64451 .36165 m
.64604 .35919 L
s
0 0 0 r
.36414 .32258 m
.3643 .3225 L
s
.255 .412 .882 r
.37968 .35453 m
.38012 .32936 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37814 .35433 m
.37859 .32916 L
s
0 0 0 r
.686 .31856 m
.68616 .31854 L
s
.255 .412 .882 r
.39037 .36276 m
.39661 .36348 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66168 .36195 m
.66585 .33615 L
s
.66013 .36214 m
.66573 .3293 L
s
.66573 .3293 m
.6724 .36054 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65548 .3627 m
.66629 .36136 L
s
.39487 .37478 m
.3964 .37725 L
s
.39327 .3769 m
.39487 .37478 L
s
.39479 .37938 m
.3964 .37725 L
s
.35753 .32598 m
.36798 .32763 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67785 .32756 m
.68448 .35881 L
s
.6724 .36054 m
.67785 .32756 L
s
.39327 .3769 m
.39479 .37938 L
s
.37806 .35892 m
.37968 .35453 L
s
.37653 .35872 m
.37814 .35433 L
s
.67392 .36033 m
.67798 .33442 L
s
.37344 .36061 m
.37806 .35892 L
s
.37344 .36061 m
.37653 .35872 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36102 .34774 m
.36126 .3496 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3704 .36019 m
.37344 .36061 L
s
.36591 .35724 m
.3704 .36019 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68674 .34732 m
.68674 .34744 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36299 .35218 m
.36591 .35724 L
s
.67998 .35947 m
.68896 .35812 L
s
.69726 .33131 m
.70008 .32619 L
s
.6959 .33616 m
.69726 .33131 L
s
.69458 .34332 m
.6959 .33616 L
s
.70008 .32619 m
.70437 .3231 L
s
.34429 .32601 m
.3471 .33113 L
s
.3471 .33113 m
.34841 .33829 L
s
.69872 .33105 m
.70153 .32593 L
s
.69736 .33591 m
.69872 .33105 L
s
.34001 .32291 m
.34429 .32601 L
s
.69605 .34307 m
.69736 .33591 L
s
.32622 .30398 m
.33609 .306 L
s
.70153 .32593 m
.70437 .3231 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36103 .37506 m
.36199 .3267 L
s
.36254 .37527 m
.36348 .32694 L
s
.34284 .32575 m
.34564 .33087 L
s
.34564 .33087 m
.34695 .33804 L
s
.34831 .3429 m
.34841 .33829 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34001 .32291 m
.34284 .32575 L
s
.70437 .3231 m
.70724 .32256 L
s
.34685 .34265 m
.34695 .33804 L
s
.3467 .34957 m
.34831 .3429 L
s
.35655 .37439 m
.36254 .37527 L
s
.33714 .32237 m
.34001 .32291 L
s
.34524 .34932 m
.34685 .34265 L
s
.33069 .35367 m
.33184 .30515 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68734 .3773 m
.68735 .37742 L
s
.5 Mabswid
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69605 .34307 m
.69629 .35462 L
s
.69458 .34332 m
.69482 .35486 L
s
.70724 .32256 m
.71157 .32404 L
s
.69482 .35486 m
.69644 .36156 L
s
.33424 .32412 m
.33714 .32237 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32927 .3534 m
.33043 .30486 L
s
.69629 .35462 m
.69791 .36132 L
s
.34368 .3537 m
.3467 .34957 L
s
.34223 .35345 m
.34524 .34932 L
s
.33129 .32818 m
.33424 .32412 L
s
.69644 .36156 m
.69801 .36595 L
s
.71157 .32404 m
.71452 .3281 L
s
.69791 .36132 m
.69947 .36571 L
s
.33928 .35525 m
.34368 .3537 L
s
.71435 .32117 m
.71479 .33966 L
s
.69801 .36595 m
.70104 .37011 L
s
.33928 .35525 m
.34223 .35345 L
s
.71576 .32089 m
.7162 .33939 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69947 .36571 m
.7025 .36986 L
s
.71052 .34048 m
.72042 .33854 L
s
.3364 .35473 m
.33928 .35525 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70104 .37011 m
.70545 .37169 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7025 .36986 m
.70545 .37169 L
s
.33359 .35188 m
.3364 .35473 L
s
.32166 .31923 m
.32305 .31952 L
s
.33086 .3467 m
.33359 .35188 L
s
.31884 .32094 m
.32166 .31923 L
s
.32022 .32124 m
.32166 .31923 L
s
.70545 .37169 m
.70835 .37119 L
s
.31872 .32557 m
.32022 .32124 L
s
.32505 .35257 m
.33069 .35367 L
s
.70835 .37119 m
.7126 .36809 L
s
.31735 .32527 m
.31884 .32094 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31832 .34183 m
.31872 .32557 L
s
.71659 .35564 m
.71692 .36963 L
s
.71534 .3629 m
.71659 .35564 L
s
.7126 .36809 m
.71534 .3629 L
s
.31473 .32003 m
.31735 .32527 L
s
.31682 .3462 m
.31735 .32527 L
s
.71534 .3629 m
.71692 .36963 L
s
.31207 .31709 m
.31473 .32003 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72827 .31823 m
.7291 .35077 L
s
.72964 .31792 m
.73047 .35048 L
s
.72414 .31914 m
.73372 .31699 L
s
.30803 .31614 m
.31207 .31709 L
s
.31682 .3462 m
.31832 .34183 L
s
.72495 .35164 m
.73047 .35048 L
s
.31562 .33891 m
.31694 .34154 L
s
.73011 .3365 m
.73166 .34319 L
s
.30754 .33475 m
.31562 .33891 L
s
.3053 .31782 m
.30803 .31614 L
s
.30397 .31749 m
.30803 .31614 L
s
.31539 .34824 m
.31682 .3462 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31259 .34998 m
.31539 .34824 L
s
.30385 .32215 m
.3053 .31782 L
s
.30252 .32182 m
.30397 .31749 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73166 .34319 m
.73451 .34725 L
s
.30717 .34877 m
.31259 .34998 L
s
.30372 .32681 m
.30385 .32215 L
s
.30493 .33179 m
.30754 .33475 L
s
.30359 .33147 m
.30754 .33475 L
s
0 0 0 r
.28424 .30225 m
.2848 .30241 L
s
.255 .412 .882 r
.73451 .34725 m
.73727 .34899 L
s
.3024 .32649 m
.30252 .32182 L
s
.30372 .32681 m
.30493 .33179 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3024 .32649 m
.30359 .33147 L
s
.73727 .34899 m
.7413 .34806 L
s
.30455 .34582 m
.30717 .34877 L
s
.73984 .34369 m
.74124 .34572 L
s
.73984 .34369 m
.74111 .34104 L
s
.30334 .34082 m
.30468 .34114 L
s
.30461 .34347 m
.30468 .34114 L
s
.74111 .34104 m
.74251 .34307 L
s
.30328 .34316 m
.30334 .34082 L
s
.30328 .34316 m
.30455 .34582 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74251 .34307 m
.74257 .34541 L
s
.7413 .34806 m
.74257 .34541 L
s
.75225 .31472 m
.75602 .31135 L
s
.7511 .31974 m
.75225 .31472 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7511 .31974 m
.75123 .32441 L
s
.75354 .31438 m
.75602 .31135 L
s
.75239 .3194 m
.75354 .31438 L
s
.75239 .3194 m
.75252 .32407 L
s
.75123 .32441 m
.75265 .32876 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75252 .32407 m
.75394 .32842 L
s
.75602 .31135 m
.7598 .31029 L
s
.75265 .32876 m
.75656 .33009 L
s
.75394 .32842 m
.75656 .33009 L
s
.2773 .30786 m
.28596 .3104 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7598 .31029 m
.76237 .31192 L
s
.75292 .33814 m
.75298 .34049 L
s
.75292 .33814 m
.7542 .33781 L
s
.29157 .33791 m
.29279 .34059 L
s
.29272 .34294 m
.29279 .34059 L
s
.75298 .34049 m
.75434 .34251 L
s
.29022 .33992 m
.29157 .33791 L
s
.29137 .34496 m
.29272 .34294 L
s
.7542 .33781 m
.75427 .34016 L
s
.75656 .33009 m
.76417 .33036 L
s
.29022 .33992 m
.29143 .34261 L
s
.75434 .34251 m
.75696 .34419 L
s
.76237 .31192 m
.76499 .31589 L
s
.28753 .34396 m
.29137 .34496 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28124 .34225 m
.28222 .30932 L
s
.28 .34191 m
.28098 .30896 L
s
.75696 .34419 m
.76202 .34284 L
s
.28507 .34093 m
.28753 .34396 L
s
.76608 .31083 m
.76845 .30775 L
s
.76499 .31589 m
.76608 .31083 L
s
.7673 .31046 m
.76845 .30775 L
s
.76622 .31553 m
.7673 .31046 L
s
.2827 .33552 m
.28507 .34093 L
s
.28166 .32811 m
.2827 .33552 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76499 .31589 m
.76562 .33708 L
s
.76622 .31553 m
.76671 .33201 L
s
.76845 .30775 m
.76966 .30738 L
s
.77156 .2902 m
.7798 .28746 L
s
.76417 .33036 m
.76548 .33236 L
s
.76202 .34284 m
.76445 .33979 L
s
.76445 .33979 m
.76562 .33708 L
s
.2763 .34086 m
.28124 .34225 L
s
.76562 .33708 m
.76671 .33201 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26951 .32448 m
.2701 .3056 L
s
.26833 .32411 m
.26892 .30522 L
s
.26481 .32298 m
.2731 .32559 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7763 .28865 m
.77786 .33822 L
s
.77513 .28904 m
.77667 .33859 L
s
.2665 .30681 m
.2687 .31229 L
s
.77704 .31218 m
.77923 .30669 L
s
.26311 .30328 m
.2665 .30681 L
s
.77923 .30669 m
.78148 .30355 L
s
.77309 .33968 m
.77786 .33822 L
s
.78148 .30355 m
.78377 .30276 L
s
.26082 .30249 m
.26311 .30328 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77764 .3311 m
.78013 .33511 L
s
.78377 .30276 m
.78611 .30433 L
s
.78377 .30276 m
.78724 .30393 L
s
.26855 .35535 m
.26899 .34107 L
s
.26758 .34784 m
.26899 .34107 L
s
.25848 .30405 m
.26082 .30249 L
s
.25736 .30365 m
.26082 .30249 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78611 .30433 m
.78851 .30827 L
s
.78013 .33511 m
.78254 .33674 L
s
.26508 .35188 m
.26758 .34784 L
s
.26758 .34784 m
.26855 .35535 L
s
.25609 .30799 m
.25848 .30405 L
s
.78724 .30393 m
.78963 .30787 L
s
.25498 .30759 m
.25736 .30365 L
s
.78254 .33674 m
.78484 .33598 L
s
.78851 .30827 m
.78986 .315 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2615 .35317 m
.26508 .35188 L
s
.25482 .31234 m
.25609 .30799 L
s
.78963 .30787 m
.79097 .3146 L
s
.78484 .33598 m
.78704 .33284 L
s
.78484 .33598 m
.78817 .33245 L
s
.25372 .31194 m
.25498 .30759 L
s
.78986 .315 m
.79002 .31976 L
s
.25348 .31908 m
.25482 .31234 L
s
.78704 .33284 m
.78914 .3273 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79097 .3146 m
.79113 .31936 L
s
.78914 .3273 m
.79002 .31976 L
s
.25238 .31868 m
.25372 .31194 L
s
.2592 .35243 m
.2615 .35317 L
s
.78817 .33245 m
.79026 .3269 L
s
.79026 .3269 m
.79113 .31936 L
s
.25309 .33101 m
.25348 .31908 L
s
.25701 .34929 m
.2592 .35243 L
s
.25588 .34892 m
.2592 .35243 L
s
.25199 .33062 m
.25238 .31868 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24869 .322 m
.24874 .32051 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25491 .34375 m
.25701 .34929 L
s
.25309 .33101 m
.25396 .33857 L
s
.25396 .33857 m
.25491 .34375 L
s
.2538 .34336 m
.25588 .34892 L
s
.25199 .33062 m
.25285 .33819 L
s
.25285 .33819 m
.2538 .34336 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79701 .29787 m
.8043 .29489 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24125 .32899 m
.24757 .33142 L
s
.24139 .29502 m
.24438 .33021 L
s
.23618 .32691 m
.24139 .29502 L
s
.23718 .32733 m
.24114 .30218 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80017 .2966 m
.8019 .34694 L
s
.80121 .29618 m
.80295 .34654 L
s
.80212 .32248 m
.80436 .32646 L
s
.79871 .34812 m
.80295 .34654 L
s
.80832 .29314 m
.81509 .29002 L
s
.80436 .32646 m
.8075 .32762 L
s
.81126 .29182 m
.81221 .31827 L
s
.23344 .2915 m
.23618 .32691 L
s
.22841 .32349 m
.23344 .2915 L
s
.81223 .29137 m
.81318 .31784 L
s
.8075 .32762 m
.80951 .32678 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22936 .32393 m
.23319 .2987 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22153 .27834 m
.22257 .27887 L
s
.255 .412 .882 r
.80951 .32678 m
.8114 .32352 L
s
.80951 .32678 m
.81238 .3231 L
s
.8114 .32352 m
.81221 .31827 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81238 .3231 m
.81318 .31784 L
s
.22562 .32219 m
.23224 .32521 L
s
.8188 .2882 m
.82501 .28495 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22415 .28696 m
.22504 .28742 L
s
.22229 .28844 m
.22415 .28696 L
s
.22317 .28891 m
.22415 .28696 L
s
.82151 .28682 m
.82276 .32073 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82239 .28635 m
.82365 .32029 L
s
.22211 .29328 m
.22317 .28891 L
s
.22123 .29281 m
.22229 .28844 L
s
.22147 .31024 m
.22211 .29328 L
s
.82004 .32205 m
.82365 .32029 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21968 .28704 m
.22123 .29281 L
s
.22042 .31466 m
.22123 .29281 L
s
.21808 .28367 m
.21968 .28704 L
s
.22042 .31466 m
.22147 .31024 L
s
.21559 .28224 m
.21808 .28367 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21982 .30691 m
.2206 .30979 L
s
.21485 .3017 m
.21982 .30691 L
s
.8224 .33579 m
.82321 .33291 L
s
.8224 .33579 m
.82339 .33779 L
s
.21945 .31664 m
.22042 .31466 L
s
.82321 .33291 m
.8242 .33492 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82339 .33779 m
.8242 .33492 L
s
.21764 .31817 m
.21945 .31664 L
s
.21388 .28371 m
.21559 .28224 L
s
.21308 .28322 m
.21559 .28224 L
s
.8295 .28986 m
.83094 .28404 L
s
.82895 .29762 m
.8295 .28986 L
s
.82895 .29762 m
.82913 .30249 L
s
.83032 .28938 m
.83175 .28356 L
s
.82978 .29715 m
.83032 .28938 L
s
.83094 .28404 m
.83324 .28016 L
s
.82978 .29715 m
.82996 .30202 L
s
.21429 .31635 m
.21764 .31817 L
s
.21289 .28809 m
.21388 .28371 L
s
.83175 .28356 m
.83324 .28016 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82996 .30202 m
.83106 .30888 L
s
.82913 .30249 m
.83024 .30934 L
s
.2121 .28761 m
.21308 .28322 L
s
.21332 .29832 m
.21485 .3017 L
s
.21252 .29784 m
.21485 .3017 L
s
.83024 .30934 m
.83206 .31331 L
s
.83324 .28016 m
.83479 .27919 L
s
.21271 .29296 m
.21289 .28809 L
s
.21271 .29296 m
.21332 .29832 L
s
.83106 .30888 m
.83287 .31284 L
s
.21192 .29249 m
.2121 .28761 L
s
.21192 .29249 m
.21252 .29784 L
s
.21276 .31298 m
.21429 .31635 L
s
.83479 .27919 m
.83715 .28015 L
s
.21215 .30762 m
.21295 .30809 L
s
.21285 .31053 m
.21295 .30809 L
s
.83206 .31331 m
.83455 .31436 L
s
.21205 .31007 m
.21276 .31298 L
s
.21205 .31007 m
.21215 .30762 L
s
.83287 .31284 m
.83455 .31436 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83715 .28015 m
.83881 .28405 L
s
.83455 .31436 m
.83688 .31296 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83688 .31296 m
.83829 .30956 L
s
.83801 .30218 m
.83865 .29925 L
s
.83801 .30218 m
.83885 .30416 L
s
.83865 .29925 m
.83948 .30122 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83829 .30956 m
.83958 .30368 L
s
.83948 .30122 m
.83958 .30368 L
s
.2053 .30335 m
.20593 .30629 L
s
.20583 .30875 m
.20593 .30629 L
s
.20501 .31073 m
.20583 .30875 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20448 .30533 m
.2053 .30335 L
s
.19831 .27028 m
.20285 .27386 L
s
.20448 .30533 m
.2051 .30827 L
s
.20287 .3093 m
.20501 .31073 L
s
.84341 .2732 m
.84427 .27761 L
s
.84341 .2732 m
.8438 .28303 L
s
.19948 .30688 m
.20085 .27234 L
s
.8438 .28303 m
.84427 .27761 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84427 .27761 m
.84483 .27464 L
s
.84483 .27464 m
.84601 .27116 L
s
.20159 .30586 m
.20287 .3093 L
s
.84601 .27116 m
.84848 .2691 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19882 .30639 m
.2002 .27182 L
s
.84439 .29782 m
.84496 .29485 L
s
.84439 .29782 m
.84458 .30276 L
s
.20043 .29994 m
.20159 .30586 L
s
.84449 .30029 m
.84505 .29732 L
s
.84496 .29485 m
.84616 .29139 L
s
.20007 .29204 m
.20043 .29994 L
s
.84458 .30276 m
.84535 .30474 L
s
.84505 .29732 m
.84626 .29386 L
s
.84535 .30474 m
.84676 .30624 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84616 .29139 m
.84908 .28392 L
s
.84626 .29386 m
.84918 .2864 L
s
.19691 .30491 m
.19948 .30688 L
s
.84848 .2691 m
.84976 .27053 L
s
.84676 .30624 m
.84928 .30427 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84976 .27053 m
.85044 .27248 L
s
.84908 .28392 m
.85017 .28043 L
s
.84918 .2864 m
.85027 .2829 L
s
.85017 .28043 m
.85064 .27743 L
s
.19444 .27459 m
.19481 .28007 L
s
.19481 .28007 m
.19509 .28802 L
s
.19353 .2686 m
.19444 .27459 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85027 .2829 m
.85075 .27991 L
s
.85044 .27248 m
.85075 .27991 L
s
.84928 .30427 m
.85038 .30079 L
s
.19459 .30044 m
.19509 .28802 L
s
.19388 .27407 m
.19424 .27955 L
s
.19424 .27955 m
.19451 .28751 L
s
.19298 .26807 m
.19388 .27407 L
s
.19202 .26454 m
.19353 .2686 L
s
.19401 .29994 m
.19451 .28751 L
s
.85038 .30079 m
.85087 .2978 L
s
.19202 .26454 m
.19298 .26807 L
s
.85087 .2978 m
.85125 .29233 L
s
.85087 .2978 m
.85165 .30228 L
s
.1937 .30742 m
.19459 .30044 L
s
.85125 .29233 m
.85165 .30228 L
s
.19313 .30692 m
.19401 .29994 L
s
.18726 .25918 m
.19202 .26454 L
s
.19292 .31192 m
.1937 .30742 L
s
.85414 .26633 m
.85454 .26332 L
s
.85414 .26633 m
.85475 .26829 L
s
.19236 .31143 m
.19313 .30692 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85454 .26332 m
.85514 .26527 L
s
.19159 .31594 m
.19292 .31192 L
s
.85475 .26829 m
.85514 .26527 L
s
.19104 .31545 m
.19236 .31143 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85526 .28074 m
.857 .31029 L
s
.85526 .28074 m
.85599 .3113 L
s
.18987 .31697 m
.19159 .31594 L
s
.18687 .31398 m
.18905 .26134 L
s
.18987 .31697 m
.19104 .31545 L
s
.1864 .31348 m
.18859 .2608 L
s
.85588 .29574 m
.8565 .3108 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18506 .31196 m
.18987 .31697 L
s
.85599 .3113 m
.85671 .31583 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85671 .31583 m
.857 .31029 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86641 .22687 m
.86743 .23264 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86724 .23091 m
.86958 .28552 L
s
.86715 .23033 m
.8695 .28498 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17841 .23136 m
.17842 .23338 L
s
.17865 .22819 m
.17841 .23136 L
s
.17867 .23021 m
.17865 .22819 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17842 .23338 m
.17867 .23021 L
s
.86876 .28173 m
.86977 .28713 L
s
.86619 .22831 m
.86641 .22687 L
s
.86601 .22773 m
.86641 .22687 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1764 .27827 m
.17787 .24637 L
s
.17652 .27773 m
.1772 .26202 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86605 .23668 m
.86605 .23701 L
s
.86584 .23579 m
.86584 .23644 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1763 .28298 m
.17635 .28043 L
s
.17764 .25223 m
.17787 .24637 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1763 .28298 m
.17647 .28024 L
s
0 0 0 r
.86886 .21899 m
.86894 .21586 L
s
.86853 .21155 m
.86894 .21586 L
s
.255 .412 .882 r
.86605 .23701 m
.86617 .24429 L
s
0 0 0 r
.86844 .21468 m
.86853 .21155 L
s
.86844 .21468 m
.86886 .21899 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86814 .27747 m
.86876 .28173 L
s
.86832 .27802 m
.86876 .28173 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86773 .27182 m
.86832 .27802 L
s
.86751 .27112 m
.86814 .27747 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86749 .27082 m
.86751 .27112 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86966 .23768 m
.87186 .28341 L
s
.86966 .23768 m
.87136 .28232 L
s
.87064 .26021 m
.87162 .28287 L
s
.86599 .20995 m
.8665 .21429 L
s
.8665 .21429 m
.86698 .22555 L
s
.86511 .20502 m
.86599 .20995 L
s
.86664 .22497 m
.86682 .22179 L
s
.17676 .28468 m
.18017 .2052 L
s
.87186 .28341 m
.87194 .29045 L
s
.86352 .20265 m
.86511 .20502 L
s
.8668 .22873 m
.86698 .22555 L
s
.17714 .28414 m
.18054 .20461 L
s
.86607 .22757 m
.86664 .22497 L
s
.86624 .23135 m
.8668 .22873 L
s
.87136 .28232 m
.87194 .29045 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86777 .25138 m
.86779 .24438 L
s
.86779 .24438 m
.86844 .25951 L
s
.86438 .23226 m
.86607 .22757 L
s
.86282 .20524 m
.86352 .20265 L
s
.86454 .23605 m
.86624 .23135 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86758 .25461 m
.86777 .25138 L
s
.86777 .25138 m
.86844 .25951 L
s
.86253 .20842 m
.86282 .20524 L
s
.86699 .25729 m
.86758 .25461 L
s
.255 .412 .882 r
.18664 .21432 m
.18802 .21027 L
s
0 0 0 r
.17877 .24607 m
.18127 .24269 L
s
.86175 .20029 m
.86253 .20842 L
s
.86175 .20029 m
.86239 .21539 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86239 .21539 m
.86253 .20842 L
s
.86535 .25506 m
.86699 .25729 L
s
.1757 .28629 m
.18257 .2777 L
s
.86366 .23492 m
.86438 .23226 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18145 .20373 m
.18595 .19752 L
s
.17911 .20698 m
.18145 .20373 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86382 .23872 m
.86454 .23605 L
s
.18062 .25793 m
.18192 .2275 L
s
.18499 .22026 m
.18544 .19811 L
s
.86336 .23815 m
.86366 .23492 L
s
.255 .412 .882 r
.18529 .24664 m
.18599 .24803 L
s
0 0 0 r
.86352 .24196 m
.86382 .23872 L
s
.255 .412 .882 r
.85584 .21103 m
.85657 .2169 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8643 .25014 m
.86535 .25506 L
s
.86336 .23815 m
.86368 .24577 L
s
.86368 .24577 m
.8643 .25014 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18499 .22026 m
.18595 .19752 L
s
.85726 .19879 m
.85869 .20754 L
s
.255 .412 .882 r
.85695 .23764 m
.85706 .24031 L
s
.85643 .23709 m
.85695 .23764 L
s
.85643 .23709 m
.85654 .23976 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85534 .19324 m
.85726 .19879 L
s
.85411 .19208 m
.85534 .19324 L
s
.85949 .22657 m
.85981 .23421 L
s
.85894 .226 m
.85942 .23747 L
s
.85958 .2413 m
.85981 .23421 L
s
.85299 .19472 m
.85411 .19208 L
s
.85234 .19414 m
.85411 .19208 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18257 .2777 m
.18354 .25462 L
s
.18205 .27823 m
.18354 .25462 L
s
.5 Mabswid
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85918 .24458 m
.85942 .23747 L
s
.19156 .19547 m
.19367 .18992 L
s
.19061 .20367 m
.19156 .19547 L
s
.18886 .24584 m
.19061 .20367 L
s
.85918 .24458 m
.85958 .2413 L
s
.1922 .19489 m
.19367 .18992 L
s
.19124 .2031 m
.1922 .19489 L
s
.85199 .2012 m
.85299 .19472 L
s
.18949 .24529 m
.19124 .2031 L
s
.85131 .20063 m
.85234 .19414 L
s
.19367 .18992 m
.19504 .18876 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85817 .24732 m
.85918 .24458 L
s
.8521 .21981 m
.85949 .22657 L
s
.19504 .18876 m
.19701 .19086 L
s
.18704 .24748 m
.18949 .24529 L
s
.85178 .21213 m
.85199 .2012 L
s
.85634 .24567 m
.85817 .24732 L
s
.85109 .21156 m
.85131 .20063 L
s
.85178 .21213 m
.8521 .21981 L
s
.19701 .19086 m
.19817 .19739 L
s
.8549 .24072 m
.85634 .24567 L
s
.85424 .24017 m
.85634 .24567 L
s
.84421 .18399 m
.84727 .18629 L
s
.85109 .21156 m
.8514 .21925 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8521 .21981 m
.85325 .23191 L
s
.19864 .18588 m
.20173 .18359 L
s
.19645 .23985 m
.19864 .18588 L
s
.85325 .23191 m
.8549 .24072 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8514 .21925 m
.85257 .23136 L
s
.19721 .23931 m
.1994 .18531 L
s
.85257 .23136 m
.85424 .24017 L
s
.84499 .18457 m
.84828 .26591 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84421 .18399 m
.84749 .26539 L
s
.84276 .1867 m
.84467 .19552 L
s
.84096 .18172 m
.84276 .1867 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19424 .24147 m
.19721 .23931 L
s
.83927 .18059 m
.84096 .18172 L
s
.255 .412 .882 r
.20439 .22926 m
.20443 .22956 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8368 .18276 m
.83927 .18059 L
s
.83769 .18332 m
.83927 .18059 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84463 .23311 m
.84592 .22643 L
s
.255 .412 .882 r
.83717 .21433 m
.83789 .22027 L
s
0 0 0 r
.83621 .18994 m
.83769 .18332 L
s
.20626 .19177 m
.20832 .18293 L
s
.20832 .18293 m
.21119 .17739 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20494 .20393 m
.20626 .19177 L
s
.255 .412 .882 r
.83628 .21286 m
.83826 .22957 L
s
0 0 0 r
.20713 .19121 m
.20921 .18237 L
s
.2058 .20338 m
.20713 .19121 L
s
.20463 .21168 m
.20494 .20393 L
s
.20921 .18237 m
.21119 .17739 L
s
.20549 .21114 m
.2058 .20338 L
s
.84313 .23594 m
.84463 .23311 L
s
.20463 .21168 m
.20503 .2228 L
s
.21119 .17739 m
.21306 .17628 L
s
.20549 .21114 m
.2059 .22226 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83575 .20103 m
.83621 .18994 L
s
.8353 .18939 m
.8368 .18276 L
s
.83483 .20048 m
.8353 .18939 L
s
.21306 .17628 m
.21482 .17904 L
s
.84506 .26384 m
.84828 .26591 L
s
.84143 .23487 m
.84313 .23594 L
s
.20503 .2228 m
.20648 .22953 L
s
.83575 .20103 m
.83606 .2088 L
s
.2059 .22226 m
.20738 .229 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83953 .22991 m
.84143 .23487 L
s
.83864 .22938 m
.84143 .23487 L
s
.83483 .20048 m
.83514 .20827 L
s
.21482 .17904 m
.21648 .18572 L
s
.83606 .2088 m
.83743 .22103 L
s
.83743 .22103 m
.83953 .22991 L
s
.21693 .17407 m
.22098 .17188 L
s
.21377 .25636 m
.21693 .17407 L
s
.83514 .20827 m
.83652 .2205 L
s
.20648 .22953 m
.20906 .23186 L
s
.83652 .2205 m
.83864 .22938 L
s
.21477 .25586 m
.21793 .17352 L
s
.20738 .229 m
.20906 .23186 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82528 .17615 m
.82761 .18502 L
s
.82199 .17063 m
.82528 .17615 L
s
.20906 .23186 m
.21094 .23082 L
s
.81985 .16956 m
.82199 .17063 L
s
.21094 .23082 m
.21301 .22585 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82835 .20453 m
.82865 .21236 L
s
.81543 .19829 m
.82835 .20453 L
s
.21301 .22585 m
.21528 .21696 L
s
.82734 .204 m
.82779 .21576 L
s
.8178 .17239 m
.81985 .16956 L
s
.81669 .17186 m
.81985 .16956 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82794 .21969 m
.82865 .21236 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82706 .2231 m
.82779 .21576 L
s
.81585 .17916 m
.8178 .17239 L
s
.82706 .2231 m
.82794 .21969 L
s
.81471 .17864 m
.81669 .17186 L
s
.22697 .18037 m
.22949 .17149 L
s
.22543 .19264 m
.22697 .18037 L
s
.21082 .25787 m
.21477 .25586 L
s
.22949 .17149 m
.23306 .16599 L
s
.82512 .22602 m
.82706 .2231 L
s
.22808 .17984 m
.23062 .17096 L
s
.22653 .19212 m
.22808 .17984 L
s
.22514 .2005 m
.22543 .19264 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23627 .16739 m
.23633 .16563 L
s
.5 Mabswid
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23062 .17096 m
.23306 .16599 L
s
.81514 .19041 m
.81585 .17916 L
s
.22624 .19998 m
.22653 .19212 L
s
.23306 .16599 m
.2354 .16495 L
s
.22514 .2005 m
.2258 .21179 L
s
.814 .1899 m
.81471 .17864 L
s
.8219 .2245 m
.82512 .22602 L
s
.22624 .19998 m
.22692 .21128 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80526 .19764 m
.80656 .1982 L
s
.5 Mabswid
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2354 .16495 m
.23765 .16783 L
s
.2354 .16495 m
.23886 .16731 L
s
.81514 .19041 m
.81543 .19829 L
s
.2258 .21179 m
.22775 .21868 L
s
.814 .1899 m
.81428 .19778 L
s
.81955 .21954 m
.8219 .2245 L
s
.81843 .21903 m
.8219 .2245 L
s
.81543 .19829 m
.81701 .21063 L
s
.22692 .21128 m
.22889 .21818 L
s
.23765 .16783 m
.2398 .17467 L
s
.81701 .21063 m
.81955 .21954 L
s
.81428 .19778 m
.81587 .21012 L
s
.23886 .16731 m
.24103 .17416 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23498 .20314 m
.23504 .20136 L
s
.5 Mabswid
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81587 .21012 m
.81843 .21903 L
s
.22775 .21868 m
.23105 .22115 L
s
.22889 .21818 m
.23105 .22115 L
s
.2398 .17467 m
.24061 .186 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80481 .16272 m
.80635 .20614 L
s
.80357 .16221 m
.80511 .20566 L
s
.7998 .16068 m
.80844 .16427 L
s
.24103 .17416 m
.24186 .1855 L
s
.23105 .22115 m
.23341 .22016 L
s
.24033 .19391 m
.24061 .186 L
s
.24158 .19341 m
.24186 .1855 L
s
.24906 .15932 m
.25705 .15635 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23341 .22016 m
.23595 .21521 L
s
.23341 .22016 m
.23717 .21472 L
s
.23867 .20629 m
.24033 .19391 L
s
.78517 .15524 m
.79463 .15867 L
s
.23991 .2058 m
.24158 .19341 L
s
.23595 .21521 m
.23867 .20629 L
s
.25168 .15832 m
.26651 .20848 L
s
.23717 .21472 m
.23991 .2058 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80414 .21312 m
.80511 .20566 L
s
.80539 .21361 m
.80635 .20614 L
s
.79064 .15719 m
.79211 .20087 L
s
.80174 .21615 m
.80539 .21361 L
s
.78929 .1567 m
.79075 .2004 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80174 .21615 m
.80414 .21312 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79916 .2152 m
.80174 .21615 L
s
.79507 .2098 m
.79916 .2152 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24715 .21487 m
.25519 .21208 L
s
.24979 .21393 m
.26686 .153 L
s
.79211 .20087 m
.79507 .2098 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2626 .15442 m
.27122 .15159 L
s
.5 Mabswid
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79102 .2084 m
.79211 .20087 L
s
.25112 .21347 m
.2683 .15253 L
s
.78965 .20794 m
.79075 .2004 L
s
.7752 .15192 m
.77698 .20791 L
s
.77373 .15145 m
.7755 .20747 L
s
.78701 .21103 m
.79102 .2084 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76928 .15008 m
.77953 .15333 L
s
.5 Mabswid
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78701 .21103 m
.78965 .20794 L
s
.7842 .21013 m
.78701 .21103 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26077 .21026 m
.26944 .2076 L
s
.77977 .20477 m
.7842 .21013 L
s
.28315 .15195 m
.28796 .14664 L
s
.28137 .16038 m
.28315 .15195 L
s
.77659 .19585 m
.77977 .20477 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75218 .14522 m
.7632 .14827 L
s
.28003 .2046 m
.28137 .16038 L
s
.28471 .15151 m
.28796 .14664 L
s
.28291 .15994 m
.28471 .15151 L
s
.28158 .20418 m
.28291 .15994 L
s
.28796 .14664 m
.29113 .14577 L
s
.77102 .20618 m
.77698 .20791 L
s
.29113 .14577 m
.29584 .1485 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29584 .1485 m
.29888 .15569 L
s
.27543 .20587 m
.28158 .20418 L
s
.29922 .14366 m
.30585 .14201 L
s
.29763 .20014 m
.29922 .14366 L
s
.73395 .14069 m
.74568 .14353 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75696 .14651 m
.75862 .20282 L
s
.75853 .14695 m
.76021 .20323 L
s
.29928 .19975 m
.30086 .14324 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74071 .1423 m
.74193 .18667 L
s
.73903 .14189 m
.74024 .18628 L
s
.75381 .2016 m
.76021 .20323 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31435 .14003 m
.31587 .14769 L
s
.31393 .15614 m
.31435 .14003 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71466 .13654 m
.72705 .13914 L
s
.29271 .20132 m
.29928 .19975 L
s
.31587 .14769 m
.31771 .14328 L
s
.31771 .14328 m
.32131 .13849 L
s
.31393 .15614 m
.31587 .14769 L
s
.32131 .13849 m
.3284 .13701 L
s
.75946 .23128 m
.76093 .2276 L
s
.75922 .22313 m
.76093 .2276 L
s
.75774 .2268 m
.75922 .22313 L
s
.74046 .19441 m
.74193 .18667 L
s
.75774 .2268 m
.75946 .23128 L
s
.73877 .19403 m
.74024 .18628 L
s
.3284 .13701 m
.3319 .14032 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72289 .17497 m
.72363 .17834 L
s
0 0 0 r
.73546 .19735 m
.74046 .19441 L
s
.3319 .14032 m
.33361 .14401 L
s
.73546 .19735 m
.73877 .19403 L
s
.31513 .17601 m
.31873 .17121 L
s
.31329 .18044 m
.31513 .17601 L
s
.31308 .18857 m
.31329 .18044 L
s
.31873 .17121 m
.3278 .16128 L
s
.31503 .18007 m
.31862 .17527 L
s
.31318 .1845 m
.31503 .18007 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33332 .15617 m
.33361 .14401 L
s
.31862 .17527 m
.3277 .16534 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31308 .18857 m
.31471 .19228 L
s
.73201 .19661 m
.73546 .19735 L
s
.3278 .16128 m
.33151 .15652 L
s
.33151 .15652 m
.33342 .15211 L
s
.3277 .16534 m
.33141 .16058 L
s
.31471 .19228 m
.3181 .19563 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72666 .19144 m
.73201 .19661 L
s
.33141 .16058 m
.33332 .15617 L
s
.7001 .1378 m
.70399 .14658 L
s
.69439 .13277 m
.7001 .1378 L
s
.34856 .13319 m
.35035 .13692 L
s
.3466 .13757 m
.34856 .13319 L
s
.72291 .18258 m
.72666 .19144 L
s
.3466 .13757 m
.34838 .1413 L
s
.6906 .13213 m
.69439 .13277 L
s
.3181 .19563 m
.32521 .19422 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34838 .1413 m
.35035 .13692 L
s
.68688 .13556 m
.6906 .13213 L
s
.68496 .13525 m
.6906 .13213 L
s
.33082 .18502 m
.33284 .17651 L
s
.33245 .19286 m
.33284 .17651 L
s
.32521 .19422 m
.32891 .18945 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72179 .138 m
.72394 .22353 L
s
.72002 .13763 m
.72215 .22319 L
s
.6832 .14308 m
.68688 .13556 L
s
.32891 .18945 m
.33082 .18502 L
s
.33082 .18502 m
.33245 .19286 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68126 .14278 m
.68496 .13525 L
s
.70269 .17067 m
.70465 .17508 L
s
.70092 .17443 m
.70269 .17067 L
s
.34793 .16164 m
.34875 .21058 L
s
.34496 .21119 m
.34793 .16164 L
s
.70465 .17508 m
.70474 .17917 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68151 .15502 m
.6832 .14308 L
s
.70119 .18672 m
.70474 .17917 L
s
.70092 .17443 m
.70288 .17884 L
s
.67957 .15473 m
.68126 .14278 L
s
.71673 .22219 m
.72394 .22353 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69752 .1902 m
.70119 .18672 L
s
.68151 .15502 m
.68167 .1632 L
s
.67957 .15473 m
.67973 .16291 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34685 .21088 m
.34739 .18618 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68167 .1632 m
.68386 .17579 L
s
.69182 .18929 m
.69752 .1902 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67973 .16291 m
.68192 .1755 L
s
.68386 .17579 m
.68789 .18458 L
s
.68789 .18458 m
.69182 .18929 L
s
.68596 .18429 m
.69182 .18929 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66495 .16255 m
.66501 .16598 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64314 .12555 m
.65734 .12725 L
s
.68192 .1755 m
.68596 .18429 L
s
.62658 .12384 m
.63903 .1251 L
s
.34496 .21119 m
.34667 .21915 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34667 .21915 m
.34875 .21058 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66622 .17744 m
.66814 .17358 L
s
.66814 .17358 m
.67021 .17796 L
s
.67021 .17796 m
.67028 .18208 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66837 .18595 m
.67028 .18208 L
s
.66622 .17744 m
.66829 .18182 L
s
.65182 .15925 m
.65406 .17184 L
s
.60122 .12175 m
.61398 .12273 L
s
.255 .412 .882 r
.66565 .20128 m
.66624 .20046 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66409 .19887 m
.66565 .20128 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65406 .17184 m
.65825 .18057 L
s
.66236 .18519 m
.66837 .18595 L
s
.62122 .19759 m
.63283 .12446 L
s
.64926 .12626 m
.65018 .18377 L
s
.65129 .1265 m
.65222 .18399 L
s
.65825 .18057 m
.66236 .18519 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61001 .14703 m
.629 .14864 L
s
.64401 .1831 m
.65222 .18399 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60484 .16001 m
.60579 .16072 L
s
.60793 .16376 m
.60579 .16072 L
s
.60052 .15979 m
.60156 .16042 L
s
.60582 .16361 m
.60156 .16042 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62137 .21011 m
.6349 .12467 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48822 .15775 m
.48822 .15749 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60549 .12206 m
.62137 .21011 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU40T0[Jf]200000030:f]
[AL0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00L0k9H>0`2][JeX0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AH0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400I0?nU40040000003oYA00ojD@0:f][@@0oj<@0P2][Jd70000
00h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00X0k9H>0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3o
YQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01T0ojD@00@000000?nU403o
YA00[Jf]2@3oXa0200000080oj<@00<0[Jf]0000000000001P0000000`2][Jd0oj<@0?nS40020?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF
3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV4@030:f][@3oYQ40ojHA01/0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400I0?nU40040000003oYA00ojD@0:f]
[@T0oj<@0P0000060?nS40800000103oXa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006P3oYA000`000000ojD@0:f][@080?nS4003
0000003oXa00000000H0oj<@0P0000080?nS40030:f][@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]
4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00d0ojHA00<000000?nV4@3oYQ40
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01X0ojD@00<000000?nU402][Jd0203oXa02000000L0oj<@
0P0000080?nS40030:f][@3lX100o:0@00H0o:0@00<0[Jf]0000000000000P00000=0?bP40030:f]
[@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V
0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503o
Y1400`2][Jd0ojHA0?nV4@0;0?nV4@80[Jf]00<000000:f][@2][Jd01`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400J0?nU40030000003oYA00[Jf]00P0oj<@0P0000070?nS40800000203oXa000`2][Jd0o:0@0?bP
40050?bP40<000000`3lX1000`000000[Jf]0:f][@020:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_
0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]
0?nV4@3oYQ400P3oYQ42000000030?nV4@2][Jd0[Jf]00@0[Jf]00@0ojHA0000003oYQ400000203o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400J0?nU40030000003oYA00[Jf]00P0oj<@0P0000070?nS40800000203o
Xa000`2][Jd0o:0@0?bP40040?bP40030000003lX100000000D0o:0@00@000000?bP403lX100o:0@
102][Jd3000000030?bP402][Jd0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA00000002000000030:f][@00
0000[Jf]00L0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01X0ojD@00<000000?nU402][Jd0203o
Xa02000000L0oj<@0P0000080?nS40030:f][@3lX100o:0@00@0o:0@0P0000070?bP40030000003l
X100o:0@00H0o:0@00<0[Jf]0000000000000P00000D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY14010000000[Jf]0000002][Jd40?nV4@030000003o
YQ40ojHA00H0ojHA00<000000?nV4@3oYQ401`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400J0?nU40030000003o
YA00[Jf]00P0oj<@0P0000070?nS40800000203oXa000`2][Jd0o:0@0?bP40030?bP40030000003l
X100000000L0o:0@00<000000?bP403lX1001`3lX1000`000000[Jf]0?JL3`030:f][@800000403f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z
0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00`0oj@A0`000004
0:f][@8000001P3oYQ400`000000ojHA0?nV4@0@0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<00000
0:f][@3oXa001P3oXa000`000000oj<@000000070?nS40800000203oXa000`2][Jd0o:0@0?bP4003
0?bP408000002@3lX1000`000000o:0@0?bP40060?bP40030000002][Jd0mY`?00@0mY`?00@0[Jf]
00000000000000003@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2]
[JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00/0oj@A0P0000020:f][@@0oj@A0P0000070?nV4@030000003oYQ40ojHA00l0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA006`3oYA000`000000[Jf]0?nS40060?nS40800000203oXa02000000P0oj<@00<0[Jf]
0?bP403lX1000`3lX102000000T0o:0@00<000000?bP403lX1001P3lX1000`000000[Jf]0?JL3`06
0?JL3`@000000P2][Jd00`3fW0l00000000000060?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0303KRPd00`2][Jd0/>3V0;3PiP1@0;3PiP40oooo001W0;3PiP030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@050?nT4@<000000`2][Jd20000
00H0oj@A00<000000:f][@3oYQ401P3oYQ400`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA
01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@1@0000040?nS40800000203oXa02000000P0oj<@00<0[Jf]0?bP403lX1000`3lX1020000
00X0o:0@00<000000?bP403lX1001@3lX1000`000000[Jf]0?JL3`060?JL3`800000103fW0l30:f]
[@800000103fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3P
iP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00<0
oj@A00D0[Jf]0000002][Jd0[Jf]0?nT4@02000000030?nT4@000000000000D0oj@A0P0000000`2]
[Jd0ojHA0?nV4@050?nV4@030000003oYQ40ojHA00l0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`00
0000[Jf]0?nS40020?nS40H00000203oXa02000000T0oj<@00@0[Jf]0?bP403lX100o:0@0P00000C
0?bP40030000002][Jd0mY`?00H0mY`?0P0000070?JL3`@0000000<0[Jf]0?JL3`2][Jd04P3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>7
3P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]00<0oj@A0000
003oY1400`3oY14010000000oj@A0000000000050?nT4@80000000<0[Jf]0?nV4@3oYQ401@3oYQ40
0`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<000000:f][@3oXa001P3oXa02
000000P0oj<@0P0000090?nS40040:f][@3lX100o:0@0?bP408000004`3lX1000`000000[Jf]0?JL
3`060?JL3`8000001`3fW0l2000000<0mY`?0P2][Jd200000100k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@
00<0[Jf]0?bP403lX1003@3lX10200000080[Jf]103oY142000000D0oj@A0`0000050?nT4@030000
003oY140[Jf]00L0ojHA00<000000?nV4@3oYQ403`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030000
002][Jd0oj<@00H0oj<@0P0000080?nS408000002@3oXa00102][Jd0o:0@0?bP403lX102000001<0
o:0@00<000000:f][@3fW0l01P3fW0l2000000L0mY`?0P0000040?JL3`030:f][@3/UPh0000000<0
00003@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?oo
o`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1002`3lX1040000
00030:f][@3oY140oj@A00<0oj@A0P0000050?nT4@<000001@3oY1400`000000oj@A0:f][@060?nV
4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030000003oXa00oj<@00@0oj<@00<000000?nS
40000000203oXa02000000T0oj<@00@0[Jf]0?bP403lX100o:0@0P00000C0?bP40030000002][Jd0
mY`?00H0mY`?0P0000070?JL3`800000103fW0l01@2][Jd0k9H>000000000000k9H>0080[Jf]00<0
k9H>0000000000002@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2]
[Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40070?bP408000000`2][Jd2000000030?bP402][Jd0oj@A00<0oj@A0P000007
0?nT4@8000001@3oY1400`000000oj@A0:f][@060?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV4@0I
0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030000003oXa00oj<@00@0oj<@0P00000:
0?nS40800000203oXa00102][Jd0o:0@0?bP403lX102000001<0o:0@00<000000:f][@3fW0l01P3f
W0l2000000L0mY`?0P0000040?JL3`040:f][@3/UPh00000000000<0k9H>0`2][Jd2000000L0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V
0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00@0o:0@0`0000020:f][@<0o:0@0P0000000`3lX100[Jf]0?nT4@030?nT4@8000001`3o
Y142000000H0oj@A00<0[Jf]0?nV4@3oYQ40103oYQ4200000180ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`11JN40ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@00D0ojD@402][Jd70?nU40030000003oXa00oj<@00@0oj<@0P00000:0?nS40800000203o
Xa00102][Jd0o:0@0?bP403lX102000001<0o:0@00<000000:f][@3fW0l01P3fW0l2000000L0mY`?
0P0000040?JL3`040:f][@3/UPh00000000000H0k9H>100000050>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3PiP40oooo001P0;3PiP030:f]
[@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40030:f]
[@000000[Jf]00D0o:0@0P0000000`3lX100[Jf]0?nT4@030?nT4@8000001`3oY142000000H0oj@A
00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA0000000B0?nV4@030:f][@3oYQ40ojHA01D0ojHA
302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA005@3oYA070:f][@030000
002][Jd0[Jf]0080[Jf]0P3oXa02000000X0oj<@0P0000080?nS40040:f][@3lX100o:0@0?bP4080
00004`3lX1000`000000[Jf]0?JL3`060?JL3`8000001`3fW0l2000000@0mY`?00@0[Jf]0>bF3P00
000000001P3/UPh2000000030>bF3P2][Jd0[Jf]008000000P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0
dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd20?bP
40030000003lX100o:0@00<0o:0@00@000000?bP403lX100[Jf]103oY142000000L0oj@A0P000006
0?nT4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@000000203oYQ400`000000ojHA0?nV4@08
0?nV4@030:f][@3oYQ40ojHA00`0ojHA2@2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030000003oXa00oj<@0080oj<@0P2][Jd2
000000H0[Jf]103oXa02000000P0oj<@00@0[Jf]0?bP403lX100o:0@0P00000C0?bP40030000002]
[Jd0mY`?00H0mY`?0P0000070?JL3`800000103fW0l0102][Jd0k9H>0000000000060>bF3P800000
0`3/UPh20:f][@80000000<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f]
[@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH
400;0>nH40040000003lX100[Jf]0:f][@D0o:0@00<000000?bP403lX1000P3lX10200000080o:0@
00<0[Jf]0?nT4@3oY1400P3oY142000000L0oj@A0P0000060?nT4@070:f][@3oYQ40ojHA0?nV4@00
0000ojHA000000090?nV4@030000003oYQ40ojHA00P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f]
[@d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<000000?nS403oXa00103oXa02000000H0oj<@102][Jd2000000@0[Jf]103oXa00102]
[Jd0o:0@0?bP403lX102000001<0o:0@00<000000:f][@3fW0l01P3fW0l2000000L0mY`?0P000004
0?JL3`040:f][@3/UPh00000000000H0k9H>0P0000050>bF3P@00000303KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V104
000000H0o:0@00<000000?bP403lX1000P3lX10200000080o:0@00<0[Jf]0?nT4@3oY1400P3oY142
000000L0oj@A0P0000060?nT4@040:f][@3oYQ40ojHA0?nV4@8000002P3oYQ400`000000ojHA0?nV
4@060?nV4@L0[Jf]5`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`000000oj<@0?nS40030?nS40030000003oXa00000000X0oj<@0`00
00030?nS40P0[Jf]00<0o:0@0000000000004P3lX1000`000000[Jf]0?JL3`070?JL3`030000003f
W0l0mY`?00D0mY`?0P0000040?JL3`040:f][@3/UPh00000000000H0k9H>0P0000050>bF3P800000
0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203C
Q`h00`2][Jd0kiP@0>nH40090>nH40030000002][Jd0[Jf]008000001`3lX10010000000o:0@0?bP
403lX10200000080o:0@00<0[Jf]0?nT4@3oY1400P3oY142000000L0oj@A0P0000060?nT4@030:f]
[@3oYQ40ojHA008000002`3oYQ400`000000ojHA0?nV4@060:f][@80ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd000000?nS40030?nS408000002`3oXa03000000L0oj<@00D0[Jf]0?bP403lX100
o:0@0:f][@02000000<0[Jf]3`3lX1000`000000[Jf]0?JL3`070?JL3`030000003fW0l0mY`?00D0
mY`?0P0000040?JL3`040:f][@3/UPh00000000000H0k9H>0P0000050>bF3P80000000<0[Jf]0=^:
3@3KRPd00P2][Jd00`3KRPd000000=^:3@060=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0
kiP@00D0[Jf]000000000000kiP@0:f][@02000000L0o:0@00<000000?bP403lX1000P0000030?bP
40030:f][@3oY140oj@A0080oj@A0P0000070?nT4@030000003oY140oj@A00D0oj@A00D0[Jf]0?nV
4@000000ojHA000000090?nV4@80[Jf]00<000000:f][@2][Jd0203oYQ400`2][Jd0ojHA0?nV4@0I
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@000000oj<@00<0oj<@0P00000;0?nS40<000001`3oXa000`2][Jd0o:0@0?bP4002
0?bP408000000`3lX1060:f][@030000003lX100o:0@00H0o:0@00<000000:f][@3fW0l01`3fW0l0
0`000000mY`?0?JL3`050?JL3`800000103fW0l0102][Jd0k9H>0000000000060>bF3P8000001@3/
UPh2000000030:f][@3KRPd0fhX=0080fhX=00<000000:f][@0000001P3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203C
Q`h00`2][Jd0kiP@0>nH40030>nH408000000P2][Jd01P3_V10000000000003_V100[Jf]0?bP4080
00001P3lX1000`000000o:0@0?bP4002000000<0o:0@00<0[Jf]0?nT4@3oY1400P3oY142000000H0
oj@A0P0000070?nT4@040:f][@000000ojHA000000D0ojHA1@2][Jd20?nV4@030000003oYQ40ojHA
00P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd000000?nS40030?nS408000002`3oXa030000
00H0oj<@00<000000:f][@3lX100103lX1000`000000o:0@0?bP40060?bP408000001P2][Jd20?bP
40030000002][Jd0mY`?00L0mY`?00<000000?JL3`3fW0l01@3fW0l2000000@0mY`?00@0[Jf]0>bF
3P00000000001P3/UPh2000000D0k9H>0P0000000`2][Jd0fhX=0=^:3@020=^:3@040000003KRPd0
[Jf]000000D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo
001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000P3_V102000000040:f]
[@3_V100kiP@0>nH4080000000<0kiP@0:f][@3lX1000P0000070?bP40040000003lX10000000000
00<0o:0@00<0[Jf]0?nT4@3oY1400P3oY142000000H0oj@A0P0000070?nT4@030:f][@0000000000
00H0[Jf]1`3oYQ400`000000ojHA0?nV4@080?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0000
003oXa000`3oXa02000000/0oj<@0`0000050?nS4080000000<0[Jf]0?bP403lX1000`3lX1020000
00L0o:0@00<000000?bP400000001@3lX1020:f][@030000002][Jd0[Jf]00L0mY`?00<000000?JL
3`3fW0l01@3fW0l2000000@0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2000000D0k9H>0P000000
0`2][Jd0fhX=0=^:3@020=^:3@050000003KRPd0fhX=0000002][Jd0103KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00P0dhL>00D0[Jf]0>nH4000000000000>nH4002000000<0kiP@0P0000020>nH4004
0:f][@3lX1000000000000L0o:0@00<000000?bP40000000103lX1000`2][Jd0oj@A0?nT4@020?nT
4@8000001P3oY142000000H0oj@A00@0[Jf]000000000000[Jf]1P3oYQ400`000000ojHA0?nV4@04
0?nV4@030000003oYQ40ojHA00P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd000000?nS4003
0?nS408000002`3oXa02000000030?nS40000000oj<@00<0oj<@00<000000?nS400000001@3lX102
000000L0o:0@00<000000?bP400000001`3lX1000`000000[Jf]0?JL3`040:f][@<0mY`?00<00000
0?JL3`3fW0l01P3fW0l2000000<0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2000000D0k9H>0P00
00001@2][Jd0fhX=0=^:3@3KRPd0000000@0fhX=00<000000:f][@2][Jd00P3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00P0dhL>00@0[Jf]0>nH40000000[Jf]0`0000030>nH408000000P3_V100102]
[Jd0o:0@0000000000070?bP40<00000103lX1000`2][Jd0oj@A0?nT4@020?nT4@8000001P3oY142
00000080oj@A102][Jd00`000000[Jf]000000070?nV4@030000003oYQ40ojHA00@0ojHA00<00000
0?nV4@3oYQ40203oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@000000oj<@0080oj<@00<00000
0?nS400000002`3oXa02000000030?nS40000000oj<@00<0oj<@00<000000?nS400000001P3lX100
0`000000o:0@0?bP40060?bP408000001`3lX1000`000000[Jf]0?JL3`040?JL3`<0[Jf]00<00000
0?JL3`3fW0l01P3fW0l2000000<0mY`?00@0[Jf]0>bF3P00000000001P3/UPh2000000D0k9H>0P00
00001@2][Jd0fhX=0=^:3@3KRPd0000000@0fhX=00<000000=^:3@3KRPd00`2][Jd90;Ue2`030:f]
[@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP
2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0000002][Jd0kiP@0`0000030>nH40800000
0P3_V1001@2][Jd0o:0@0000003lX100000000L0o:0@0P0000040?bP40030:f][@3oY140oj@A0080
oj@A0P0000060?nT4@8000000P2][Jd40?nT4@8000001`3oYQ42000000H0ojHA00<000000?nV4@3o
YQ40203oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa0000000080oj<@0P00000<0?nS4080
00000P3oXa000`000000oj<@0?nS40020?nS408000001P3lX102000000L0o:0@00<000000?bP403l
X1001P3lX1000`000000[Jf]0?JL3`070?JL3`030000002][Jd0[Jf]0080[Jf]103fW0l2000000<0
mY`?00@0[Jf]0>bF3P3/UPh000001`3/UPh00`000000k9H>0>bF3P030>bF3P80000000D0[Jf]0=^:
3@3KRPd0fhX=000000040=^:3@030000003KRPd0fhX=0080fhX=00<0[Jf]0;Ue2`0000001`2iM@/0
0`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@070=>73P040000003CQ`h0[Jf]00000080kiP@0`0000030>nH408000000P3_
V1000`2][Jd0o:0@0?bP4002000000L0o:0@00<000000?bP403lX1000`3lX1000`2][Jd0oj@A0?nT
4@020?nT4@030000003oY140oj@A0080oj@A0`2][Jd2000000H0oj@A00<000000:f][@3oYQ401P3o
YQ42000000H0ojHA00<000000?nV4@3oYQ40203oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa0000000080oj<@0P0000090?nS4080000000<0oj<@0000000000000`3oXa0010000000oj<@0?nS
403oXa02000000L0o:0@00<000000?bP403lX1001@3lX1000`000000o:0@0?bP40070?bP40030000
003fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l00P3fW0l40:f][@8000000`3fW0l00`2][Jd0k9H>
0>bF3P02000000H0k9H>00<000000>bF3P3/UPh00`3/UPh2000000050:f][@3KRPd0fhX=0=^:3@00
00001@3KRPd020000000fhX=0=^:3@3KRPd0[Jf]0000002iM@/000001P2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@050=>73P80000000@0dhL>0:f][@2][Jd000000`3_V102000000<0kiP@0P0000000`3_V100[Jf]
0?bP40020?bP408000001P3lX102000000D0o:0@00<0[Jf]0?nT4@3oY1400P3oY1400`000000[Jf]
0:f][@020:f][@<0oj@A0P0000060?nT4@030000002][Jd0ojHA00H0ojHA0P0000060?nV4@030000
003oYQ40ojHA00P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@000000020?nS40800000
2`3oXa03000000@0oj<@0P0000000`3oXa0000000:f][@070?bP408000001@3lX1000`000000o:0@
0?bP40080?bP40030000003fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l01P3fW0l200000080[Jf]
00@0mY`?0:f][@3/UPh0k9H>0P0000060>bF3P030000003/UPh0k9H>00@0k9H>00@000000:f][@3K
RPd0fhX=0P0000050=^:3@070000003KRPd0fhX=0=^:3@2][Jd000000:f][@03000000@0^GD;00<0
[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd01@3CQ`h010000000[Jf]0:f][@3CQ`h2000000<0kiP@0P0000020>nH40800000
0P3_V100102][Jd0o:0@0?bP403lX102000000H0o:0@0P0000050?bP40030:f][@3oY140[Jf]0080
[Jf]00<000000?nT4@3oY1401@3oY142000000H0oj@A00<000000:f][@3oYQ401@3oYQ43000000D0
ojHA0P0000090?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS400000000P3oXa02000001@0
oj<@0P0000000`2][Jd0o:0@0?bP40060?bP40030000003lX100o:0@00<0o:0@00<000000?bP403l
X100203lX102000000L0mY`?00<000000?JL3`3fW0l01P3fW0l200000080mY`?0`2][Jd00`3/UPh0
0000000000060>bF3P030000003/UPh0k9H>00@0k9H>00@000000:f][@3KRPd0fhX=0P0000090=^:
3@040000002iM@/0^GD;0;Ue2`<000000`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0
/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030000003CQ`h0
000000<0dhL>00<000000>nH403_V1000P3_V10200000080kiP@0P0000020>nH40050:f][@3lX100
o:0@0?bP400000001`3lX103000000<0o:0@0`2][Jd30?nT4@030000003oY140oj@A00D0oj@A0P00
00060?nT4@030000002][Jd0ojHA00D0ojHA0`0000050?nV4@<00000203oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa0000000080oj<@0P00000F0?nS40030:f][@3lX100o:0@00L0o:0@0P00
00020?bP40030000003lX100o:0@00T0o:0@0P0000070?JL3`030000003fW0l0mY`?00H0mY`?0P00
00030?JL3`030:f][@3/UPh0[Jf]008000001P3/UPh00`000000k9H>0>bF3P040>bF3P040000002]
[Jd0fhX=0=^:3@8000002@3KRPd010000000^GD;0;Ue2`2iM@/2000000@0^GD;00<0[Jf]08QF1`28
EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P<0
00000`3CQ`h00`000000kiP@0>nH40020>nH408000000P3_V10200000080kiP@00D0[Jf]0?bP403l
X100o:0@000000060?bP4080000000<0o:0@0000002][Jd00P2][Jd00`3lX100[Jf]0?nT4@030?nT
4@030000003oY140oj@A00D0oj@A0P0000060?nT4@030000002][Jd0ojHA00@0ojHA00@000000?nV
4@3oYQ4000001@3oYQ43000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA001`2][Jd0oj<@0000003o
Xa0000000?nS400000005P3oXa000`2][Jd0o:0@0?bP40090?bP40800000303lX1000`000000mY`?
000000050?JL3`800000203fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh00P0000020:f][@@0k9H>
00<000000>bF3P3/UPh0103/UPh010000000[Jf]0=^:3@3KRPd2000000T0fhX=00@000000;Ue2`2i
M@/0^GD;0P0000001@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je20;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h010000000[Jf]0000000000030=>73P030000003_
V100kiP@0080kiP@0P0000020>nH408000000P3_V1001@2][Jd0o:0@0?bP403lX100000000H0o:0@
0P0000000`2][Jd000000?bP40030?bP40030:f][@3oY140oj@A0080oj@A00<000000?nT4@3oY140
1@3oY142000000L0oj@A00<000000?nV4@3oYQ400`3oYQ4010000000ojHA0?nV4@0000050?nV4@<0
0000203oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00<000005`3oXa000`2][Jd0
o:0@0?bP400G0?bP40040000003fW0l0mY`?000000@0mY`?0P0000080?JL3`8000000`3fW0l00`2]
[Jd0k9H>0>bF3P0200000080k9H>0`2][Jd00`3/UPh000000>bF3P050>bF3P040000002][Jd0fhX=
0=^:3@8000002@3KRPd010000000^GD;0;Ue2`2iM@/2000000030;Ue2`2][Jd0[Jf]008000001028
EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h200000080dhL>
00D000000=>73P3CQ`h0dhL>000000040>nH40040000003_V100kiP@0>nH408000000P3_V1001@2]
[Jd0o:0@0?bP403lX100000000D0o:0@00<0[Jf]0000000000000P3lX1001@000000o:0@0?bP403l
X100[Jf]00@0oj@A00<000000?nT4@3oY1401@3oY142000000L0oj@A00<0[Jf]0000000000000`00
00090?nV4@<00000203oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2]
[JdG0?nU40030:f][@3oXa00oj<@00<000005`3oXa000`2][Jd0o:0@0?bP400G0?bP40040000002]
[Jd0mY`?000000@0mY`?0P0000080?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P02000000D0k9H>
00<0[Jf]0000002][Jd01@3/UPh010000000[Jf]0=^:3@3KRPd2000000T0fhX=00@000000;Ue2`2i
M@/0^GD;0P0000020;Ue2`<000001028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2G
H0/0Uf0;0000002][Jd200000080dhL>00D000000=>73P3CQ`h0dhL>000000040>nH40040000003_
V100kiP@0>nH408000000P3_V1001@2][Jd0o:0@0?bP403lX10000000080o:0@0`2][Jd00`3lX100
00000?bP40020?bP40050000003lX100o:0@0?bP402][Jd0103oY1400`000000oj@A0?nT4@050?nT
4@8000001`3oY1400`2][Jd0ojHA0?nV4@0<0?nV4@<00000203oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa000`00000G0?nS40030:f][@3lX100o:0@
01L0o:0@00@000000:f][@3fW0l0mY`?1000000:0?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P02
000000H0k9H>00@000000>bF3P2][Jd0[Jf]0`3/UPh010000000[Jf]0=^:3@3KRPd2000000T0fhX=
00@000000;Ue2`2iM@/0^GD;0P0000020;Ue2`80000000<0[Jf]00000028EPL00`28EPL00`2][Jd0
/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080000000<0dhL>0000003CQ`h0
0P3CQ`h00`000000dhL>0=>73P02000000@0kiP@00@000000>nH403_V100kiP@0P0000020>nH4005
0:f][@3lX100o:0@0?bP400000000P2][Jd30?bP408000000`3lX1001@000000o:0@0?bP403lX100
[Jf]00@0oj@A00<000000?nT4@3oY1401@3oY142000000L0oj@A00<0[Jf]0?nV4@3oYQ40303oYQ43
000000P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400E0?nU40X0[Jf]00<000000:f][@000000503oXa001011JN40oj<@0?nS402]
[JdI0?bP40030000002][Jd0mY`?00l0mY`?0P0000030?JL3`030:f][@3/UPh0k9H>008000001P3/
UPh010000000k9H>0>bF3P3/UPh30:f][@0400000011JN40fhX=0=^:3@8000002@3KRPd010000000
[Jf]0;Ue2`2iM@/200000080^GD;00@000000;Ue2`2][Jd000001028EPL00`2][Jd0/>3V0;3PiP10
0;3PiP40oooo001I0;3PiP030:f][@2GH0/000000080000000<0dhL>0000003CQ`h00P3CQ`h00`00
0000dhL>0=>73P02000000@0kiP@00@000000>nH403_V100kiP@0P0000020>nH40030:f][@11JN40
[Jf]008000001@3lX102000000@0o:0@00@000000?bP403lX100[Jf]103oY1400`000000oj@A0?nT
4@030?nT4@<00000203oY1400`2][Jd0ojHA0?nV4@0<0?nV4@<00000203oYQ400`2][Jd0ojHA0?nV
4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA001P2][Jd0oj<@0?nS40000000oj<@000000T0[Jf]303oXa000`11JN40
oj<@0:f][@0I0?bP40030000002][Jd0mY`?00`0mY`?0P0000000`3fW0l00000000000030?JL3`03
0:f][@3/UPh0k9H>008000001P3/UPh00`000000k9H>0>bF3P040>bF3P040000002][Jd0[Jf]0=^:
3@@000001`3KRPd010000000[Jf]0;Ue2`2iM@/200000080^GD;00H000000;Ue2`2][Jd0000008QF
1`00000208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]0000002GH0/00P00
00000`3CQ`h000000=>73P020=>73P030000003CQ`h0dhL>00800000103_V10010000000kiP@0>nH
403_V10200000080kiP@0P2][Jd00`3lX1000000000000050?bP40030000003lX100o:0@00<0o:0@
00@000000?bP403lX100[Jf]103oY1400`000000oj@A0?nT4@0>0?nT4@030:f][@3oYQ40ojHA00`0
ojHA0`0000080?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40060:f][@3oXa00oj<@0000
003oXa0000002@3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX1005`3lX1000`000000[Jf]0?JL3`0>
0?JL3`<000000`3fW0l00`2][Jd0k9H>0>bF3P03000000D0k9H>00<000000>bF3P3/UPh0103/UPh0
10000000[Jf]0=^:3@2][Jd200000080fhX=0P0000050=^:3@040000002][Jd0^GD;0;Ue2`800000
0P2iM@/01@000000^GD;0:f][@000000[Jf]0080000000<0R5H70:f][@2`h>H0@@2`h>H10?ooo`00
F@2`h>H2000000050:f][@00000000000=>73P0000000`3CQ`h00`000000dhL>0=>73P02000000@0
kiP@00@000000>nH403_V100kiP@0P0000030:f][@80o:0@0P0000040?bP408000001@3lX1001000
0000o:0@0?bP402][Jd30?nT4@800000403oY1400`2][Jd0ojHA0?nV4@0<0?nV4@<000001@3oYQ48
0:f][AP0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00D0[Jf]0?nS403oXa00oj<@0000000D0?nS40P0[Jf]5P3lX1000`000000[Jf]0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00<00000103/UPh3000000D0k9H>00@000000:f][@3KRPd0fhX=
0P000000102][Jd0fhX=0=^:3@3KRPd2000000<0fhX=00@000000:f][@2iM@/0^GD;0P0000020;Ue
2`040000002iM@/0[Jf]08QF1`@0000000<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H20000
00050:f][@00000000000=>73P0000000`3CQ`h010000000dhL>0=>73P0000050>nH40060000003_
V100kiP@0>nH402][Jd000000P3_V1000`2][Jd0o:0@0?bP4002000000@0o:0@0P0000060?bP4080
00000P3oY14200000180oj@A00<0[Jf]0?nV4@3oYQ40303oYQ43000000D0[Jf]0`3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40050:f][@3oXa00oj<@0?nS40000000603oXa00102][Jd0o:0@0?bP403lX107
0:f][@l0o:0@00<000000:f][@3fW0l05@3fW0l4000000030>bF3P000000k9H>0080k9H>0`000005
0>bF3P030000002][Jd0fhX=0080fhX=0P0000020:f][@80fhX=00H000000=^:3@3KRPd0fhX=0000
002][Jd30;Ue2`070000002iM@/0^GD;0000002iM@/0[Jf]08QF1`02000000030:f][@000000[Jf]
0480/>3V0@3oool005T0/>3V00L0[Jf]0000002GH0/000000:f][@3CQ`h0000000<0dhL>00@00000
0=>73P3CQ`h000001@3_V1001P000000kiP@0:f][@2][Jd0kiP@00000080kiP@00@0[Jf]0?bP403l
X10000001@3lX102000000D0o:0@0P0000000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA
00L0ojHA1@2][Jd3000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA001@2][Jd0oj<@0?nS403oXa00
000001P0oj<@00<0[Jf]0?bP403lX100203lX1060:f][@T0o:0@00<000000:f][@3fW0l05@3fW0l0
1P2][Jd0k9H>000000000000k9H>000000<0k9H>0P0000000`3/UPh000000>bF3P020>bF3P800000
00@0[Jf]0=^:3@3KRPd0fhX=0P0000020=^:3@80[Jf]00H000000=^:3@3KRPd0fhX=0000002][Jd3
0;Ue2`060000002iM@/0^GD;0000002iM@/0[Jf]0P28EPL010000000[Jf]0000002][Je20;3PiP40
oooo001I0;3PiP070:f][@000000Uf0;0000002][Jd0dhL>000000030=>73P040000003CQ`h0dhL>
000000D0kiP@00<000000:f][@3_V1000P3_V1001@000000kiP@0>nH402][Jd0o:0@008000001@3l
X1000`000000o:0@0?bP40020?bP408000000P3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@3o
YQ40ojHA0?nV4@H0[Jf]1@3oYQ43000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA001@2][Jd0oj<@
0?nS403oXa00000001P0oj<@00<0[Jf]0?bP403lX1003P3lX1070:f][@80o:0@00<000000:f][@3f
W0l05@3fW0l00`2][Jd0k9H>0>bF3P030>bF3P@000000`3/UPh00`000000k9H>0>bF3P0200000004
0:f][@3KRPd0fhX=0=^:3@800000103KRPd200000080fhX=00<000000:f][@2iM@/00P2iM@/01P00
0000^GD;0;Ue2`000000^GD;0:f][@80R5H700@0000008QF1`0000000000@P2`h>H10?ooo`00F@2`
h>H01`2][Jd0000009MP2`000000[Jf]0=>73P0000000P3CQ`h01@000000dhL>0=>73P3CQ`h00000
00<0kiP@0P2][Jd00`000000kiP@0>nH40020>nH40060000003_V100kiP@0:f][@3lX10000001@3l
X104000000H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1450:f][@/0ojHA00<000000?nV4@000000203o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3l
X1020:f][@040000002][Jd0[Jf]0:f][A@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh00`000000k9H>
0>bF3P02000000040:f][@3KRPd0fhX=0=^:3@800000103KRPd200000080[Jf]00<000000:f][@2i
M@/00P2iM@/01P000000^GD;0;Ue2`000000^GD;0:f][@80R5H700@0000008QF1`0000000000@P2`
h>H10?ooo`00F02`h>H20:f][@060000002GH0/000000:f][@3CQ`h000000P3CQ`h01P000000dhL>
0=>73P3CQ`h000000>nH4080[Jf]0P3_V1000`000000kiP@0>nH40020>nH40060000003_V100kiP@
0:f][@3lX1000000103lX103000000P0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2]
[Jd0ojHA00d0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400G0?bP40040000002][Jd0mY`?0?JL3`@0[Jf]403fW0l00`2][Jd0k9H>
0>bF3P0;0>bF3P<0000000<0k9H>0:f][@3KRPd00`3KRPd00`000000fhX=0=^:3@020=^:3@800000
0P3KRPd00`000000[Jf]0;Ue2`020;Ue2`040000002iM@/0^GD;00000080^GD;00@0[Jf]08QF1`00
0000R5H70`0000110;3PiP40oooo001H0;3PiP80[Jf]00H0000009MP2`000000[Jf]0=>73P000002
0=>73P060000003CQ`h0dhL>0=>73P000000[Jf]0`3_V102000000@0kiP@0P0000000`3_V100[Jf]
0000000@0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA00d0ojHA
00<000000?nV4@3oYQ401`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`000000[Jf]0?JL3`050?JL3`D0[Jf]2`3fW0l00`2][Jd0k9H>
0>bF3P0<0>bF3P040000003/UPh0k9H>0:f][@@0fhX=0P0000030=^:3@030000003KRPd0fhX=0080
fhX=00D000000:f][@2iM@/0^GD;000000020;Ue2`040000002iM@/0^GD;0:f][@<0R5H70`000011
0;3PiP40oooo001H0;3PiP80[Jf]00H0000009MP2`000000[Jf]0=>73P0000020=>73P040000003C
Q`h0dhL>0:f][@8000000`3_V102000000@0kiP@0P0000000`3_V100[Jf]0000000@0?bP40030:f]
[@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA00d0ojHA00<000000?nV4@3oYQ40
1`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`000000[Jf]0?JL3`0:0?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00<0fhX=00D000000=^:3@3KRPd0fhX=000000040=^:3@050000002iM@/0[Jf]0:f]
[@0000000P2iM@/010000000^GD;0;Ue2`2][Jd308QF1`030000002][Jd000000440/>3V0@3oool0
05P0/>3V0P2][Jd01P000000Uf0;0000002][Jd0dhL>00000080dhL>00@000000=>73P2][Jd0dhL>
0P0000020>nH40<000001@3_V10300000140o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`000000[Jf]0?JL3`0?0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>
0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=00D000000=^:3@3KRPd0fhX=000000040=^:3@05
0000002iM@/0^GD;0;Ue2`0000000P2iM@/2000000030;Ue2`2][Jd0R5H700<0R5H700<000000:f]
[@2`h>H0@02`h>H10?ooo`00F02`h>H20:f][@060000002GH0/0Uf0;0:f][@3CQ`h000000P3CQ`h0
10000000[Jf]0=>73P3CQ`h200000080kiP@0`0000070>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01@0o:0@100000000`2][Jd0mY`?0?JL
3`0>0?JL3`040000003fW0l0mY`?0?JL3`@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@030=^:3@040000
003KRPd0fhX=000000@0fhX=00/000000;Ue2`2iM@/0^GD;0000002][Jd0^GD;0000002iM@/00000
0:f][@0308QF1`80000000<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00F02`h>H00`2][Jd0000009MP
2`0209MP2`060:f][@000000dhL>0=>73P2][Jd000000`3CQ`h200000080kiP@0`0000070>nH4003
0:f][@3lX100o:0@00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l03@3fW0l2000000D0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00<0
fhX=00<000000=^:3@0000001@3KRPd020000000^GD;0;Ue2`2iM@/000000;Ue2`2][Jd000000P2i
M@/010000000R5H708QF1`28EPL2000000030:f][@2`h>H0/>3V03l0/>3V0@3oool005P0/>3V00/0
[Jf]0000002GH0/0000009MP2`2][Jd000000=>73P2][Jd0dhL>000000030=>73P040:f][@000000
kiP@0>nH40<000001`3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00d0mY`?00<000000?JL3`000000103f
W0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@040=^:3@8000001@3K
RPd0102][Jd000000;Ue2`2iM@/2000000060;Ue2`00000000000;Ue2`2][Jd000000P28EPL20000
00030:f][@2`h>H0/>3V03l0/>3V0@3oool005P0/>3V00P0[Jf]0000002GH0/0000009MP2`2][Jd0
00000:f][@80dhL>00T000000=>73P3CQ`h0dhL>0:f][@000000kiP@0000003_V1000P0000070>nH
40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0=0?JL3`8000001@3fW0l00`2][Jd0k9H>0>bF3P040>bF
3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@000000^GD;0;Ue2`80000000<0^GD;
0000000000000P2][Jd00`000000R5H708QF1`02000000030:f][@2`h>H0/>3V03l0/>3V0@3oool0
05P0/>3V00L0[Jf]0000002GH0/0000009MP2`2][Jd0000000<0dhL>00H000000=>73P3CQ`h0dhL>
0:f][@3_V102000000030>nH40000000000000L0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00h0
mY`?00<000000?JL3`3fW0l00`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@040:f][@000000^GD;0;Ue2`80000000L0^GD;000000000000^GD;0:f][@00
0000R5H7008000000P2][Je10;3PiP40oooo001H0;3PiP070:f][@000000Uf0;0000002GH0/0[Jf]
000000030=>73P050000003CQ`h0dhL>0=>73P2][Jd0103_V102000000L0kiP@00<0[Jf]0?bP403l
X100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd000000000002iM@/20000
00070;Ue2`00000000000;Ue2`2][Jd0000008QF1`0200000080[Jf]@@2`h>H10?ooo`00F02`h>H0
102][Jd0000009MP2`0000020:f][@050000003CQ`h0dhL>0=>73P0000000P3CQ`h00`2][Jd0kiP@
0>nH40030>nH40030000003_V100kiP@00H0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@03
0:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0
[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`2][Jd0000000000002000000090;Ue2`00000000000;Ue
2`2][Jd0000008QF1`000000@FWQ0080[Jf]@@2`h>H10?ooo`00F02`h>H0102][Jd0000009MP2`00
00020:f][@050000003CQ`h0dhL>0=>73P0000000P3CQ`h00`2][Jd0kiP@0>nH40030>nH40030000
003_V100kiP@00H0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0
[Jf]3@3KRPd00`2][Jd0^GD;0000000200000080^GD;0P0000001`2][Jd000000:f][@000000@FWQ
0:f][@000000@@2`h>H10?ooo`00F02`h>H01`2][Jd0000009MP2`000000Uf0;0:f][@0000000`3C
Q`h010000000dhL>0=>73P2][Jd50>nH40030000003_V100kiP@00D0kiP@0`2][Jd@0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]
J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`0200000080
^GD;0P0000001`2][Jd000000:f][@000000R5H70:f][@000000@@2`h>H10?ooo`00F02`h>H01`2]
[Jd000000:f][@000000Uf0;0:f][@0000000P3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00D0kiP@
00<000000>nH403_V1000`3_V1020:f][@030>nH402][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0
fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;008000000P2iM@/2000000070:f][@000000R5H70000
0028EPL0[Jf]000000110;3PiP40oooo001H0;3PiP030:f][@00000000000080Uf0;00<0[Jf]0000
003CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40030>nH40040000003_V100kiP@0>nH4080[Jf]0`3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ48
0:f][ID0/>3V1P2][JdB0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`0200000080^GD;0P000000
102][Jd0000008QF1`0000020:f][@030000002`h>H0/>3V03l0/>3V0@3oool005P0/>3V00<0[Jf]
0000000000000P2GH0/00`2][Jd000000=>73P050=>73P030:f][@3_V100kiP@00<0kiP@00@00000
0>nH402][Jd0[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue
2`02000000<0^GD;00H000000:f][@000000R5H70000002][Jd200000440/>3V0@3oool005P0/>3V
00H0[Jf]000000000000Uf0;045Yh@0000070=>73P030:f][@3_V100kiP@00<0kiP@00<000000:f]
[@3_V1001P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0
000000@0^GD;00D0000008QF1`28EPL0000008QF1`0200000440/>3V0@3oool005L0/>3V0P2][Jd2
00000080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@030000003_
V100kiP@00H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3o
YQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`020;Ue2`030000
002iM@/0^GD;00<0^GD;00@0[Jf]08QF1`000000R5H70P0000110;3PiP40oooo001G0;3PiP80[Jf]
0P0000000`2GH0/0[Jf]0=>73P070=>73P040:f][@3_V100[Jf]0:f][@80kiP@00<000000>nH403_
V1001P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0
[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd30;Ue2`03
0000002iM@/0^GD;00<0^GD;00@0[Jf]08QF1`000000R5H70P0000110;3PiP40oooo001G0;3PiP80
[Jf]0P0000000`2GH0/0[Jf]0=>73P070=>73P80[Jf]103_V1000`000000kiP@0>nH40060>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@030;Ue2`000000^GD;00@0
^GD;00@0[Jf]08QF1`000000R5H70P0000110;3PiP40oooo001G0;3PiP80[Jf]0`0000000`2][Jd0
dhL>0=>73P050=>73P80[Jf]1@3_V1000`000000kiP@0>nH40060>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd0303KRPd01@2][Jd0^GD;0;Ue2`2][Jd0000000D0^GD;00<0[Jf]08QF
1`28EPL00`0000110;3PiP40oooo001G0;3PiP80[Jf]0`0000000`2][Jd0dhL>0=>73P030=>73P80
[Jf]00<0dhL>0:f][@3_V1000P3_V103000000L0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0
oj@A0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`0000001@2iM@/0102][Jd0R5H708QF1`28EPL2
00000440/>3V0@3oool005L0/>3V0P2][Jd010000000Uf0;0000002][Jd40=>73P050:f][@3CQ`h0
dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`
h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2i
M@/0^GD;0;Ue2`0000000P2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`800000@@2`h>H10?ooo`00
E`2`h>H20:f][@040000002GH0/000000:f][@<0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`0000000P2iM@/0102][Jd0^GD;0;Ue2`2][Jd3
08QF1`030:f][@00000000000400/>3V0@3oool005L0/>3V0P2][Jd01@000000Uf0;0000002][Jd0
dhL>0080[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jgn
0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;008000000`2iM@/3
0:f][@<0R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H01@2][Jd0000009MP2`2GH0/0
00000080[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd3
0;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd01@2][Jd0^GD;0;Ue2`2iM@/0000000D0^GD;00<0[Jf]08QF1`28EPL00P28EPL200000400/>3V
0@3oool005L0/>3V00H0[Jf]0000002GH0/0Uf0;0000002][Jd80=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL200000400
/>3V0@3oool005L0/>3V00H0[Jf]0000002GH0/0Uf0;0000002][Jd80=>73P030:f][@3_V100kiP@
00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3P
iP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`80[Jf]0`28EPL200000400/>3V0@3oool005L0/>3V00H0[Jf]0000002GH0/0Uf0;0000002][Jd8
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]
0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0
_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0
[Jf]08QF1`11JN400P0000100;3PiP40oooo001G0;3PiP060:f][@000000Uf0;0:f][@000000[Jf]
203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V
0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f]
[@28EPL0[Jf]0080R5H700<0[Jf]0000002`h>H0?`2`h>H10?ooo`00E`2`h>H01P2][Jd000000:f]
[@2GH0/000000:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`07
0:f][@28EPL0R5H70:f][@28EPL0[Jf]000000100;3PiP40oooo001G0;3PiP060:f][@000000[Jf]
09MP2`000000[Jf]203CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001G0;3PiP030:f][@00
0000Uf0;0080000000<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2i
M@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo
001G0;3PiP060:f][@000000Uf0;0000002GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40030>nH40<0
[Jf]00@0Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@000000/>3V03l0/>3V0@3oool005L0
/>3V00<0[Jf]0000000000000P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH
4080[Jf]0`11JN400`2TWXl0[Jf]0;6[W@030;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f]
[@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0000002`h>H0?`2`h>H10?ooo`00E`2`h>H01@2][Jd000000000002GH0/0
[Jf]00T0dhL>00H0[Jf]0>nH402][Jd0[Jf]0:BNS`11JN420:BNS`03045Yh@2TWXl0[Jf]00H0/J^M
0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a0;B`/@11JN420:f]
[@030=^:3@2][Jd0^GD;00T0^GD;00H0[Jf]08QF1`28EPL0R5H70:f][@0000100;3PiP40oooo001G
0;3PiP050:f][@000000Uf0;09MP2`2][Jd02@3CQ`h20:f][@<0Y9j?00L0@FWQ0:BNS`2TWXl0@FWQ
0:BNS`2][Jd0@FWQ00L0/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`040<>m^`03045Yh@33_K/0`kfk00H0`kfk00@0[Jf]0;ji^02]
[Jd0[Jf]202n^KP2045Yh@030:f][@2d/;40@FWQ00<0];2a0P2][Jd:0;Ue2`060:f][@28EPL0R5H7
08QF1`2][Jd00000@02`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0
[Jf]0:BNS`2TWXl00`2TWXl01P11JN40Y9j?0:BNS`11JN40Y9j?045Yh@X0/J^M0P2][Jd00`2aZid0
[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0
/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`020<>m^`80@FWQ2033_K/30:f][@L0_[Vh00P0@FWQ0;ji^011JN40@FWQ0;ji^02][Jd0
];2a045Yh@D0];2a0P2][Jd80;Ue2`060:f][@28EPL0R5H708QF1`2][Jd00000@02`h>H10?ooo`00
E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd00`11JN40Y9j?0:BNS`030:BNS`04
045Yh@2TWXl0Y9j?0:BNS`80@FWQ102aZid00`11JN40/J^M0;6[W@050;6[W@<0[Jf]3`2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf7
0;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/01011JN450<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01@2n^KP2045Yh@<0_[Vh00D0@FWQ
0;ji^02][Jd0];2a045Yh@070;B`/@030:f][@2iM@/0^GD;00D0^GD;00H0[Jf]08QF1`28EPL0R5H7
0:f][@0000100;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h20:f][@80
@FWQ1@2TWXl01011JN40Y9j?0:BNS`2TWXl2045Yh@@0/J^M00<0@FWQ0;6[W@2aZid01P2aZid00`2]
[Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@80`kfk0`2][Jd40<>m
^`030:f][@2n^KP0_[Vh0080_[Vh0`11JN440;ji^005045Yh@2n^KP0_[Vh0:f][@11JN401`2d/;40
0`11JN40[Jf]0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00<0[Jf]045Yh@2:QGD00P11JN450:BNS`04045Yh@2T
WXl0Y9j?0:BNS`80@FWQ102aZid01@11JN40/J^M0;6[W@2aZid0@FWQ00@0/J^M00<0[Jf]0;VbYP2i
/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@80[Jf]1`33_K/0102][Jd0
_[Vh045Yh@11JN430;ji^003045Yh@2n^KP0_[Vh0080_[Vh00D0@FWQ0;ji^02n^KP0[Jf]045Yh@07
0;B`/@03045Yh@2][Jd0[Jf]0080[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3o
ool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P040:f][@2:QGD0@FWQ08Z5M@80@FWQ
00<0[Jf]0:BNS`2TWXl00P2TWXl01011JN40Y9j?0:BNS`2TWXl2045Yh@@0/J^M00D0@FWQ0;6[W@2a
Zid0/J^M045Yh@040;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@80@FWQ2@33_K/3045Y
h@@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP01@11JN40_[Vh0;ji^02][Jd0@FWQ00H0];2a0P11JN40
1@2d/;40[Jf]045Yh@2OVj00[Jf]0080^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo
001G0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd208Z5M@06045Yh@2:QGD0@FWQ045Y
h@2TWXl0[Jf]0`2TWXl01011JN40Y9j?0:BNS`2TWXl2045Yh@<0/J^M0P11JN430;6[W@03045Yh@2a
Zid0/J^M0080/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2]
[Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`03`36`;`30:f][@<0`kfk0P11JN490<>m^`030:f][@11JN40@FWQ00@0_[Vh00<0
@FWQ0;ji^02n^KP00P2n^KP01@11JN40_[Vh0;ji^02][Jd0@FWQ00@0];2a00<0@FWQ0:f][@11JN40
0P2d/;42045Yh@0309nKX011JN40[Jf]0080[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo
001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd01P11JN40RXEe08Z5M@2:QGD0@FWQ08Z5M@80
@FWQ0P2TWXl20:f][@80Y9j?00@0@FWQ0:BNS`2TWXl0@FWQ102aZid3045Yh@80/J^M00<0@FWQ0;6[
W@2aZid00P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo
]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/00`33_K/2045Y
h@T0`kfk00<0[Jf]045Yh@11JN40102n^KP00`11JN40_[Vh0;ji^0020;ji^005045Yh@2n^KP0_[Vh
0:f][@11JN400P2d/;40102][Jd0@FWQ045Yh@2d/;42045Yh@040;B`/@11JN40@FWQ09nKX080@FWQ
00<0Wi^P0:f][@28EPL00`28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2G
H0/0Uf0;0080Uf0;00<0[Jf]08Z5M@11JN400P2:QGD2045Yh@0508Z5M@11JN40@FWQ0:BNS`11JN40
0P2TWXl20:f][@040:BNS`11JN40Y9j?045Yh@@0/J^M0`11JN400`2aZid0@FWQ045Yh@040;6[W@03
0:f][@2i/ZH0^K:V00@0@FWQ2P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00@0[Jf]0<6j/011
JN40@FWQ4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/00P33_K/2045Yh@030<>m^`11JN40@FWQ
0080@FWQ1033_K/00`2][Jd0@FWQ045Yh@040;ji^003045Yh@2n^KP0_[Vh0080_[Vh00L0@FWQ0;ji
^02n^KP0[Jf]045Yh@2d/;40[Jf]0080];2a00D0@FWQ0;B`/@2d/;40@FWQ0;B`/@02045Yh@0309nK
X011JN40@FWQ0080Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f]
[@2GH0/0Uf0;09MP2`80[Jf]00@0RXEe045Yh@2:QGD0RXEe1@11JN400`2TWXl0@FWQ0:BNS`030:BN
S`040:f][@2TWXl0@FWQ045Yh@@0/J^M00@0@FWQ0;6[W@11JN40/J^M0`11JN430;6[W@040:f][@2i
/ZH0@FWQ045Yh@<0^K:V00@0@FWQ0;VbYP11JN40@FWQ1P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0
[Jf]2@2n]j`0102][Jd0`KZ`0<6j/031^[03045Yh@d0`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk
0080`kfk0`11JN420<>m^`80@FWQ1@33_K/2045Yh@@0_[Vh0P11JN440;ji^005045Yh@2n^KP0[Jf]
045Yh@2][Jd00`2d/;400`11JN40];2a0;B`/@03045Yh@80Wi^P0P11JN4209nKX0050:f][@28EPL0
R5H708QF1`2][Jd0@02`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@0408Z5M@11
JN40RXEe08Z5M@80@FWQ00@0RXEe045Yh@11JN40Y9j?0P11JN420:BNS`05045Yh@2TWXl0[Jf]0:f]
[@11JN40102aZid01011JN40/J^M045Yh@2aZid3045Yh@<0/J^M00@0[Jf]0;VbYP11JN40@FWQ102i
/ZH3045Yh@80^K:V00D0@FWQ0;VbYP2i/ZH0^K:V0:f][@090;jg[0@0[Jf]1@2n]j`01@2][Jd0`KZ`
0<6j/031^[00@FWQ00l0`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_003
0:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk045Yh@020<>m^`<0@FWQ0`33_K/2045Yh@@0
`kfk0P11JN440;ji^080@FWQ102n^KP00`11JN40[Jf]0:f][@02045Yh@80];2a00<0@FWQ0;B`/@2d
/;400`2d/;400`2][Jd0Wi^P09nKX002045Yh@<0Wi^P00@0[Jf]08QF1`28EPL0[Jf]@02`h>H10?oo
o`00EP2`h>H00`2][Jd0Uf0;09MP2`030:f][@0508Z5M@11JN40RXEe08Z5M@11JN400P2:QGD00`2]
[Jd0Y9j?045Yh@02045Yh@80Y9j?00H0@FWQ0:BNS`2TWXl0Y9j?045Yh@2][Jd30;6[W@07045Yh@2a
Zid0@FWQ0;6[W@11JN40/J^M045Yh@030;6[W@040:f][@11JN40^K:V045Yh@@0^K:V0`11JN430;Vb
YP<0@FWQ00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0080`KZ`00<0@FWQ0<6j
/031^[003@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][JdA0<K0
_0030:f][@11JN40`kfk0080`kfk0P11JN450<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN440;ji
^080@FWQ0`2n^KP0102][Jd0@FWQ0;ji^02][Jd2045Yh@80];2a00<0@FWQ0;B`/@2d/;400`2d/;40
0`2][Jd0Wi^P09nKX002045Yh@<0Wi^P0P2][Jd00`28EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3P
iP040:f][@2GH0/0[Jf]06=PD`80[Jf]0P11JN4208Z5M@03045Yh@2:QGD0[Jf]00<0Y9j?00D0@FWQ
0:BNS`2TWXl0Y9j?045Yh@030:BNS`0<045Yh@2aZid0[Jf]0:f][@2aZid0@FWQ0;6[W@11JN40/J^M
045Yh@2aZid0@FWQ0`2aZid00`2][Jd0@FWQ045Yh@060;VbYP80@FWQ102i/ZH3045YhA40_[N/102]
[Jd00`31^[00@FWQ0<6j/00>0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35
_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37
`K`50:f][@80al6l00<0[Jf]0<K0_036`;`02`36`;`7045Yh@<0`kfk0P11JN450<>m^`03045Yh@33
_K/0`kfk0080`kfk0P11JN440;ji^080@FWQ00L0_[Vh0:f][@2][Jd0_[Vh045Yh@2n^KP0[Jf]0080
@FWQ0P2d/;400`11JN40];2a0;B`/@030;B`/@030:f][@2OVj00Wi^P0080@FWQ0`2OVj00102][Jd0
L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<01@2][Jd0RXEe045Yh@2:QGD0@FWQ
0080RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl01@11JN40Y9j?0:BNS`2TWXl0@FWQ00<0/J^M00P0[Jf]
045Yh@2][Jd0@FWQ0;6[W@11JN40/J^M045Yh@<0/J^M00<0[Jf]045Yh@11JN401P2i/ZH2045Yh@@0
^K:V0P11JN400`2][Jd0_[N/0;jg[00@0;jg[0050:f][@31^[00`KZ`0:f][@11JN400`2][Jd<0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0
_036`;`02P36`;`00`11JN40a/2l0<K0_0020<K0_0<0@FWQ0`33_K/2045Yh@D0`kfk0P11JN430<>m
^`80@FWQ102n^KP2045Yh@080:f][@2n^KP0_[Vh0;ji^011JN40_[Vh0:f][@2d/;42045Yh@030;B`
/@11JN40];2a00@0];2a00<0[Jf]09nKX02OVj000P11JN4209nKX080[Jf]00<0L6ii0:f][@2][Jd0
@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd00`2:QGD0@FWQ045Yh@0208Z5M@030:f][@2T
WXl0Y9j?00D0Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@030;6[W@80@FWQ00H0/J^M045Yh@2][Jd0
@FWQ0;6[W@11JN430;6[W@030:f][@11JN40@FWQ00H0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Y
h@030:f][@2n]j`0_[N/00P0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`01@2][Jd0`KZ`0<6j/031^[00
@FWQ00<0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<
0<O1_0030:f][@36`;`0a/2l00X0a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@@0`kfk00<0@FWQ
0<>m^`33_K/00`33_K/2045Yh@<0`kfk0P11JN420;ji^080[Jf]0P11JN440;ji^003045Yh@2n^KP0
[Jf]0080];2a0P11JN460;B`/@090:f][@2OVj00Wi^P09nKX011JN40Wi^P0:f][@2OVj00[Jf]0080
L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2][Jd0
RXEe045Yh@0208Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0`11JN401@2][Jd0/J^M0;6[W@2aZid0@FWQ
0080/J^M00D0@FWQ0;6[W@11JN40[Jf]045Yh@030;6[W@030:f][@11JN40^K:V00H0^K:V00<0@FWQ
0;VbYP2i/ZH00`2i/ZH2045Yh@T0_[N/0P11JN400`2n]j`0@FWQ045Yh@050;jg[0050:f][@31^[00
`KZ`0<6j/011JN402031^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00@0
[Jf]045Yh@11JN40@FWQ2036`;`2045Yh@D0a/2l0P11JN440<>m^`03045Yh@33_K/0`kfk00<0`kfk
0P11JN430<>m^`80@FWQ0P2][Jd20;ji^080@FWQ102n^KP00`11JN40_[Vh0:f][@0:0;B`/@030:f]
[@2OVj00Wi^P0080Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00D0[Jf]0;6[W@2aZid0/J^M045Yh@030;6[W@80@FWQ00L0/J^M045Yh@2][Jd0[Jf]0;6[W@2]
[Jd0@FWQ00L0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@T0_[N/00<0@FWQ0;jg[02n]j`00P2n
]j`2045Yh@80_[N/0P11JN430<6j/003045Yh@31^[00`KZ`00/0`KZ`202][Jd@0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38
`K/00`2][Jd0al6l0<O1_00@0<O1_0<0@FWQ2P36`;`2045Yh@D0a/2l0P11JN440<>m^`03045Yh@33
_K/0`kfk00<0`kfk0P11JN420<>m^`030:f][@11JN40@FWQ00@0_[Vh0P11JN440;ji^003045Yh@2n
^KP0[Jf]00X0];2a00<0[Jf]09nKX02OVj000P2][Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`
h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:
QGD00`2][Jd0Y9j?0:BNS`090:BNS`050:f][@2aZid0@FWQ0;6[W@11JN400`2aZid01P11JN40/J^M
0;6[W@2aZid0@FWQ0;6[W@80[Jf]00<0@FWQ0;VbYP2i/ZH01@2i/ZH00`11JN40^K:V0;VbYP030;Vb
YP80@FWQ2@2n]j`00`11JN40_[N/0;jg[0030;jg[005045Yh@2n]j`0@FWQ045Yh@2][Jd00`31^[00
0`11JN40`KZ`0<6j/00=0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0
[Jf]0<O1_037`K`02`37`K`00`11JN40al6l0<O1_0030<O1_0030:f][@11JN40a/2l00T0a/2l0P11
JN450<K0_080@FWQ1033_K/00`11JN40`kfk0<>m^`030<>m^`80@FWQ0P2][Jd00`33_K/0@FWQ045Y
h@040;ji^004045Yh@2n^KP0_[Vh0;ji^0<0@FWQ00<0_[Vh0:f][@2d/;402@2d/;400`2][Jd0Wi^P
0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[
W@02045Yh@<0/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@020;6[W@030:f][@11JN40[Jf]0080[Jf]
0P2i/ZH3045Yh@D0^K:V0P11JN490;jg[003045Yh@2n]j`0_[N/00@0_[N/0P11JN400`2n]j`0[Jf]
0<6j/0020<6j/0D0@FWQ2`31^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0[Jf]4@35_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0060<O1_0@0@FWQ00<0al6l045Yh@37`K`0
1037`K`00`2][Jd0@FWQ0<K0_0090<K0_080@FWQ1@36`;`2045Yh@@0`kfk00@0@FWQ0<>m^`33_K/0
`kfk0P2][Jd00`11JN40`kfk0<>m^`020<>m^`030:f][@11JN40@FWQ00<0_[Vh00<0@FWQ0;ji^02n
^KP01@2n^KP00`2][Jd0];2a0;B`/@080;B`/@80[Jf]1P2OVj000`2][Jd0L6ii071^N@020:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]
2`2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80@FWQ00<0/J^M045Yh@2aZid00P2aZid01@11JN40/J^M
0;6[W@2][Jd0@FWQ00<0^K:V0`2][Jd0102i/ZH0@FWQ045Yh@11JN420;VbYP80@FWQ00<0[Jf]0;jg
[02n]j`01`2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ00<0_[N/0:f][@31^[000P31^[000`11
JN40`KZ`0<6j/0020<6j/080@FWQ1P31^[03045Yh@030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_0040<O1_080@FWQ1037`K`2045Yh@D0al6l00<0[Jf]045Y
h@36`;`02@36`;`2045Yh@D0a/2l0P11JN440<>m^`04045Yh@33_K/0[Jf]0:f][@80`kfk00<0@FWQ
0<>m^`33_K/00P33_K/00`2][Jd0@FWQ045Yh@020;ji^003045Yh@2n^KP0_[Vh00H0_[Vh00<0[Jf]
0;B`/@2d/;40202d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`
h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@050;6[W@05045Yh@2aZid0/J^M0;6[W@11JN400P2a
Zid00`2][Jd0@FWQ0;VbYP050;VbYP@0[Jf]0P2i/ZH2045Yh@030:f][@2n]j`0_[N/00L0_[N/00<0
@FWQ0;jg[02n]j`0102n]j`2045Yh@030:f][@31^[00`KZ`0080`KZ`00<0@FWQ0<6j/031^[000`31
^[02045Yh@L0`KZ`1011JN4C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1^`38`K/03`38
`K/01@11JN40b<6k0<S1^`38`K/0[Jf]00D0al6l0P11JN460<O1_003045Yh@37`K`0al6l00<0al6l
00<0[Jf]045Yh@36`;`02@36`;`2045Yh@D0a/2l0P11JN430<>m^`030:f][@11JN40[Jf]00@0`kfk
00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0@FWQ045Yh@03045Yh@P0_[Vh00<0[Jf]0;B`/@2d/;40
1P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f]
[@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid3045Yh@80
/J^M00<0[Jf]045Yh@2i/ZH02@2i/ZH20:f][@80@FWQ00<0[Jf]0;jg[02n]j`01`2n]j`00`11JN40
_[N/0;jg[0040;jg[080@FWQ00@0[Jf]0<6j/031^[00`KZ`0P11JN460<6j/003045Yh@31^[00`KZ`
00D0`KZ`0P11JN440<>m/`L0@FWQ2P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
00T0a[ng<02][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02038`K/00`11
JN40b<6k0<S1^`040<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd01@37`K`00`11JN40al6l0<O1_005
0<O1_003045Yh@37`K`0al6l00<0al6l00<0[Jf]045Yh@36`;`02P36`;`4045Yh@80a/2l0P11JN43
0:f][@030<>m^`11JN40`kfk00@0`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`2][Jd0@FWQ045Yh@0;
0;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d/;40[Jf]1`2OVj001@2][Jd0L6ii071^
N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@030:f]
[@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@090;6[W@80@FWQ00<0/J^M0:f][@11JN40
302i/ZH2045Yh@80[Jf]202n]j`2045Yh@D0_[N/0P11JN40102][Jd0`KZ`0<6j/031^[02045Yh@H0
`KZ`0P11JN460<6j/080@FWQ1`33_K<00`11JN40`kfc0<>m/`030<>m/`H0@FWQ0P33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k0P11JN450<S1
^`03045Yh@38`K/0b<6k00@0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@040<O1_080@FWQ1`37`K`2
045Yh@@0al6l00<0[Jf]045Yh@36`;`03P36`;`4045Yh@@0`kfk00<0@FWQ0<>m^`33_K/00P33_K/0
0`11JN40`kfk0<>m^`030<>m^`030:f][@11JN40@FWQ00/0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;42
0:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3o
ool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2T
WXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0@FWQ0;VbYP0;0;VbYP<0@FWQ00<0
_[N/0:f][@2][Jd00P2][Jd50;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11JN40102][Jd0`KZ`0<6j
/031^[02045Yh@H0`KZ`0P11JN460<6j/080@FWQ1`33_K<00`11JN40`kfc0<>m/`050<>m/`80@FWQ
1033_K<00`2][Jd0aKje0<Fn]@020<Fn]@<0@FWQ3`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0@0<S1^`<0@FWQ
00<0b<6k0:f][@38`K/00P11JN470<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<S1^`11JN40
0P38`K/00`2][Jd0al6l0<O1_0020<O1_003045Yh@37`K`0al6l00H0al6l0P11JN440<O1_0030:f]
[@11JN40a/2l00T0a/2l1@2][Jd20<K0_080@FWQ1033_K/00`11JN40`kfk0<>m^`020<>m^`03045Y
h@33_K/0`kfk00<0`kfk00<0[Jf]045Yh@11JN402@2n^KP00`11JN40_[Vh0:f][@030;B`/@80[Jf]
1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V
00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@11JN40^K:V00/0^K:V0`11JN450;jg[0@0[Jf]0P2n]j`00`11JN40
_[N/0;jg[0020;jg[080@FWQ00@0[Jf]0<6j/031^[00`KZ`0P11JN470<6j/080@FWQ1@31^[02045Y
h@L0`kfc00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D00P11JN430<Fn
]@03045Yh@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D00P11JN420<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^PL0@FWQ2P38`K/2045Y
h@<0b<6k0P11JN400`38`K/0@FWQ045Yh@070<S1^`80@FWQ1038`K/3045Yh@80b<6k00<0[Jf]0<O1
_037`K`00P37`K`00`11JN40al6l0<O1_0060<O1_080@FWQ1037`K`00`2][Jd0@FWQ045Yh@050<K0
_0@0[Jf]1`36`;`00`11JN40`kfk0<>m^`030<>m^`80@FWQ0P33_K/00`11JN40`kfk0<>m^`040<>m
^`030:f][@11JN40@FWQ00P0_[Vh0P11JN401@2n^KP0[Jf]0;B`/@2d/;40[Jf]00L0];2a00<0[Jf]
09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0
[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid02`2aZid0
102][Jd0^K:V045Yh@11JN4;0;VbYP<0@FWQ0`2n]j`00`11JN40_[N/0;jg[0030;jg[0<0[Jf]0P11
JN420;jg[080@FWQ00@0[Jf]0<6j/031^[00`KZ`0P11JN470<6j/080@FWQ1@31^[02045Yh@L0`kfc
00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@11JN401P35_[D00`11JN40aKje
0<Fn]@040<Fn]@03045Yh@35_[D0@FWQ0080aKje0`11JN480<Jo]`03045Yh@36_kL0a[ng00`0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P040<O1^PT0@FWQ2037`KX0102][Jd0b<6k
045Yh@11JN4=0<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0[Jf]045Yh@11JN401`38`K/00`11JN40
b<6k045Yh@040<S1^`<0@FWQ0P38`K/00`2][Jd0al6l0<O1_0020<O1_003045Yh@37`K`0al6l00H0
al6l0P11JN440<O1_0030:f][@11JN40@FWQ00D0[Jf]1@36`;`2045Yh@@0a/2l00<0@FWQ0<>m^`33
_K/00`33_K/01011JN40`kfk045Yh@11JN470<>m^`030:f][@11JN40@FWQ00T0_[Vh00<0@FWQ0;ji
^02][Jd00P2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?oo
o`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd=0;6[W@04
0:f][@2i/ZH0@FWQ045Yh@/0^K:V0P11JN401@2][Jd0@FWQ0;jg[02n]j`0@FWQ00T0_[N/00<0[Jf]
045Yh@11JN400P11JN40102][Jd0`KZ`0<6j/031^[02045Yh@L0`KZ`0P11JN450<6j/080@FWQ1`33
_K<00`11JN40`kfc0<>m/`050<>m/`80@FWQ1033_K<00`2][Jd0@FWQ045Yh@060<Fn]@03045Yh@35
_[D0aKje00@0aKje0P11JN450<Fn]@030:f][@11JN40a[ng00D0a[ng0P11JN4>0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX01P37`KX2045Yh@D0al6j0P11JN460<O1^P040:f][@38
`K/0@FWQ045Yh@`0b<6k0P11JN450<S1^`030:f][@38`K/0@FWQ00L0b<6k00<0@FWQ0<S1^`11JN40
1038`K/3045Yh@80b<6k00@0[Jf]0<O1_037`K`0al6l0P11JN480<O1_0@0@FWQ0`2][Jd2045Yh@X0
a/2l0P11JN440<K0_004045Yh@33_K/0`kfk0<>m^`<0@FWQ2P33_K/00`2][Jd0@FWQ045Yh@0:0;ji
^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0
/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@040:f][@2i/ZH0@FWQ045Y
h@H0^K:V00@0@FWQ0;VbYP2i/ZH0^K:V0`11JN40102][Jd0@FWQ0;jg[02n]j`2045Yh@@0_[N/0P11
JN450;jg[080@FWQ102][Jd2045Yh@L0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@H0`kfc0P11
JN470<>m/`80@FWQ1033_K<00`2][Jd0@FWQ045Yh@070<Fn]@03045Yh@35_[D0aKje00<0aKje0P11
JN450<Fn]@030:f][@36_kL0@FWQ00H0a[ng00<0@FWQ0<Jo]`36_kL03036_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j00H0al6j0P11JN460<O1^P80@FWQ1@37`KX0102][Jd0b<6k045Y
h@11JN4<0<S1^`80@FWQ1@38`K/00`2][Jd0b<6k045Yh@070<S1^`<0@FWQ1038`K/00`11JN40b<6k
045Yh@020<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1P37`K`3045Yh@<0[Jf]0P37`K`00`2][Jd0
@FWQ045Yh@040<K0_003045Yh@36`;`0a/2l00<0a/2l00<0@FWQ0<K0_036`;`00P36`;`00`11JN40
[Jf]0<>m^`0?0<>m^`030:f][@11JN40@FWQ00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?
0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]2@2aZid0102][Jd0^K:V045Yh@11JN460;VbYP03
045Yh@2i/ZH0^K:V00@0^K:V00@0[Jf]0;jg[011JN40_[N/0P11JN440;jg[080@FWQ1@2n]j`00`11
JN40_[N/0:f][@030<6j/080@FWQ1@2][Jd20<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN460<>m
/`80@FWQ1`33_K<2045Yh@@0`kfc0P11JN4>0<Fn]@03045Yh@35_[D0aKje00@0aKje00<0[Jf]0<Jo
]`11JN405@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00H0al6j0P11JN470<O1
^P80@FWQ1037`KX0102][Jd0b<6k045Yh@11JN4<0<S1^`80@FWQ1@38`K/00`2][Jd0b<6k045Yh@07
0<S1^`80@FWQ00<0b<6k045Yh@38`K/00P38`K/00`11JN40b<6k045Yh@020<S1^`040:f][@37`K`0
al6l0<O1_080@FWQ0P37`K`50:f][@L0al6l00<0[Jf]045Yh@11JN400`36`;`00`11JN40a/2l045Y
h@050<K0_0@0@FWQ00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0@FWQ045Yh@060;ji^080[Jf]0`2n
^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J
0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@02
0;6[W@80[Jf]1`2aZid0102][Jd0^K:V045Yh@11JN450;VbYP80@FWQ1P2i/ZH00`2][Jd0_[N/0;jg
[002045Yh@H0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`00`11JN40_[N/0:f][@030<6j/080@FWQ1@31
^[020:f][@03045Yh@2][Jd0[Jf]0080[Jf]0P31^[02045Yh@H0`kfc0P11JN470<>m/`80@FWQ1033
_K<2045Yh@h0aKje00<0@FWQ0<Fn]@35_[D01035_[D00`2][Jd0a[ng045Yh@0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@L0al6j0P11JN440<O1^P040:f][@38
`K/0@FWQ045Yh@`0b<6k0P11JN450<S1^`030:f][@38`K/0@FWQ00L0b<6k0P11JN401038`K/0@FWQ
0<S1^`38`K/2045Yh@80b<6k00<0@FWQ0<S1^`2][Jd00P37`K`00`2][Jd0@FWQ045Yh@020:f][@`0
al6l00@0[Jf]045Yh@11JN40@FWQ0`36`;`2045Yh@X0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0@FWQ045Yh@030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P
00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@03
0:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i
/ZH00P11JN440;VbYP80@FWQ1P2i/ZH00`2][Jd0_[N/0;jg[0080;jg[003045Yh@2n]j`0_[N/0080
_[N/00@0@FWQ0;jg[02n]j`0[Jf]0`31^[02045Yh@H0`KZ`0P11JN440<6j/080[Jf]0P11JN430:f]
[@<0`kfc0P11JN470<>m/`80@FWQ1033_K<2045YhAD0aKje00<0[Jf]045Yh@11JN405@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00D0al6j0P11JN480<O1^P80@FWQ0`37`KX0102]
[Jd0b<6k045Yh@11JN4<0<S1^`80@FWQ1@38`K/00`2][Jd0b<6k045Yh@070<S1^`80@FWQ00@0b<6k
045Yh@38`K/0b<6k0P11JN400`38`K/0[Jf]045Yh@040:f][@030<O1_011JN40@FWQ00h0al6l00D0
[Jf]045Yh@11JN40a/2l045Yh@020<K0_003045Yh@36`;`0a/2l00X0a/2l00<0[Jf]0<>m^`33_K/0
3@33_K/3045Yh@030;ji^02][Jd0[Jf]00P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P
09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:
QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd0102aZid0[Jf]0;Vb
YP2i/ZH2045Yh@<0^K:V0`11JN460;VbYP030:f][@2n]j`0_[N/00T0_[N/1011JN430;jg[0040:f]
[@31^[00`KZ`0<6j/080@FWQ1P31^[02045Yh@H0`KZ`0P11JN430<>m/`<0[Jf]0P11JN420:f][@D0
`kfc0P11JN440<>m/`80@FWQ5035_[D3045YhAH0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P050<O1^P80@FWQ2037`KX2045Yh@<0al6j00@0[Jf]0<S1^`11JN40@FWQ3@38`K/2045Y
h@@0b<6k00<0[Jf]0<S1^`11JN401`38`K/01011JN40b<6k0:f][@11JN420:f][@80@FWQ00D0[Jf]
0<S1^`11JN40b<6k0:f][@030<O1_080@FWQ3P37`K`00`2][Jd0@FWQ045Yh@020<K0_080@FWQ3@36
`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0
[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00X0/J^M0`2]
[Jd20;VbYP80@FWQ0P2i/ZH3045Yh@H0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j
/031^[03045Yh@@0`KZ`0P11JN470<6j/080@FWQ1P33_K<2045Yh@80`kfc1@2][Jd2045Yh@040:f]
[@33_K<0`kfc0<>m/`80@FWQ4P35_[D4045YhAL0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P050<O1^P80@FWQ2037`KX2045Yh@<0al6j00@0[Jf]0<S1^`11JN40@FWQ3P38`K/4045Y
h@050<S1^`2][Jd0b<6k045Yh@38`K/01P2][Jd01P11JN40[Jf]0<S1^`38`K/0@FWQ0<S1^`80@FWQ
0P38`K/00`11JN40b<6k0:f][@030<O1_080@FWQ3@37`K`4045YhA40a/2l00<0[Jf]0<>m^`33_K/0
3033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V
0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2a
Zid00`2][Jd0^K:V0:f][@030:f][@80@FWQ0P2i/ZH00`11JN40^K:V0;VbYP040;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/011JN400`11JN401031^[00@FWQ0<6j/031^[02045Yh@P0`KZ`
0P11JN460<>m/`80@FWQ1`33_K<2045Yh@040<>m/`2][Jd0[Jf]0:f][@80@FWQ102][Jd<0<Fn]@@0
@FWQ00<0aKje0:f][@36_kL01P36_kL00`11JN40a[ng0<Jo]`0=0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@T0al6j0P11JN420<O1^P040:f][@38`K/0@FWQ045Y
h@h0b<6k102][Jd4045Yh@030:f][@38`K/0b<6k00<0b<6k0P11JN430<S1^`03045Yh@38`K/0@FWQ
00<0b<6k00<0@FWQ0<S1^`2][Jd00`37`K`2045Yh@h0al6l00<0[Jf]0<K0_036`;`04@36`;`00`2]
[Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@090;B`
/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0
/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd00`2i/ZH0@FWQ0;VbYP050;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[03045Yh@T0`KZ`0`11JN450<>m/`80
@FWQ1`33_K<2045Yh@@0`kfc00<0[Jf]045Yh@11JN400`35_[D40:f][@03045Yh@2][Jd0[Jf]00@0
[Jf]0`11JN430<Fn]@030:f][@36_kL0a[ng00D0a[ng00<0@FWQ0<Jo]`36_kL03@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00D0al6j0P11JN490<O1^P80@FWQ0P37`KX0102][Jd0
b<6k045Yh@11JN420<S1^``0[Jf]1@38`K/00`2][Jd0b<6k045Yh@060<S1^`80@FWQ0`38`K/00`11
JN40b<6k045Yh@040<S1^`03045Yh@2][Jd0al6l0080al6l0P11JN490<O1_003045Yh@37`K`0al6l
00<0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2]
[Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80
[Jf]2P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004@31^[03045Yh@D0`kfc00<0@FWQ0<>m/`33
_K<01P33_K<2045Yh@@0`kfc00<0[Jf]045Yh@11JN401P35_[D2045Yh@D0aKje0P11JN4=0:f][@04
045Yh@2][Jd0[Jf]0:f][@`0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P050<O1
^P80@FWQ0P37`KX70:f][@80@FWQ102][Jd2045Yh@80[Jf]3038`K/00`11JN40b<6k0<S1^`020<S1
^`030:f][@38`K/0@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/00P38`K/3045Yh@@0b<6k0`11JN420<O1
_080@FWQ2@37`K`00`11JN40al6l0<O1_0030<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`
/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[003
0:f][@31^[00`KZ`0140`KZ`0P11JN400`33_K<0@FWQ045Yh@030<>m/`03045Yh@33_K<0`kfc00H0
`kfc0P11JN440<>m/`030:f][@11JN40@FWQ00L0aKje00<0@FWQ0<Fn]@35_[D00`35_[D00`11JN40
aKje0<Fn]@040<Fn]@030:f][@36_kL0@FWQ00D0a[ng00@0@FWQ0<Jo]`36_kL0a[ng;02][Jd2045Y
h@80[Jf]1`37`KX2045Yh@80al6j00<0[Jf]0<S1^`11JN400P11JN450<S1^`03045Yh@38`K/0b<6k
00@0b<6k0P11JN440<S1^`030:f][@38`K/0@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/2045Y
h@80b<6k0`11JN400`2][Jd0al6l0<O1_0020<O1_080@FWQ1`37`K`2045Yh@D0al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2]
[Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/080
@FWQ0`33_K<3045Yh@T0`kfc0P11JN440<>m/`040:f][@35_[D0@FWQ045Yh@D0aKje00<0@FWQ0<Fn
]@35_[D01035_[D00`11JN40aKje0<Fn]@040<Fn]@030:f][@11JN40@FWQ00D0a[ng00<0@FWQ0<Jo
]`36_kL03@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00D0al6j0P11JN490<O1
^P80@FWQ0P37`KX00`2][Jd0b<6k045Yh@02045Yh@@0b<6k0P11JN460<S1^`80@FWQ1038`K/00`2]
[Jd0@FWQ0<S1^`060<S1^`@0@FWQ0P38`K/00`11JN40b<6k0<S1^`040<S1^`030:f][@37`K`0al6l
0080al6l0P11JN470<O1_080@FWQ1@37`K`00`2][Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2]
[Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?oo
o`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/080@FWQ3033_K<5045Yh@@0
`kfc00@0[Jf]0<Fn]@11JN40@FWQ1@35_[D00`11JN40aKje0<Fn]@040<Fn]@03045Yh@35_[D0aKje
00@0aKje00<0[Jf]045Yh@11JN401@36_kL00`11JN40a[ng0<Jo]`0=0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@T0al6j0P11JN420<O1^P060:f][@38`K/0@FWQ
045Yh@38`K/0@FWQ1038`K/00`11JN40b<6k0<S1^`050<S1^`03045Yh@38`K/0b<6k00<0@FWQ1@38
`K/4045Yh@`0b<6k00<0[Jf]0<O1_037`K`00P37`K`2045Yh@L0al6l0P11JN450<O1_0030:f][@36
`;`0a/2l00T0a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n
^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd9
0;jg[0030:f][@31^[00`KZ`0140`KZ`0P11JN4E0<>m/`040:f][@35_[D0aKje0<Fn]@D0@FWQ2035
_[D00`11JN40aKje0<Fn]@030<Fn]@<0@FWQ1@36_kL00`11JN40a[ng0<Jo]`0=0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@T0al6j0P11JN420<O1^P040:f][@38
`K/0@FWQ045Yh@80b<6k00D0@FWQ0<S1^`38`K/0b<6k045Yh@080<S1^`80@FWQ0P38`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01037`K`3045Yh@D0
al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80
Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0
_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`0P11JN4E0<>m/`030:f][@35_[D0aKje00l0
aKje1@11JN400`2][Jd0a[ng045Yh@050<Jo]`03045Yh@36_kL0a[ng00d0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P050<O1^P80@FWQ2@37`KX2045Yh@80al6j1011JN430<S1^`@0
@FWQ3038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00<0al6l0P11JN450<O1_003
045Yh@37`K`0@FWQ00D0al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0
[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0
[Jf]0<6j/00B0<6j/080@FWQ5@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00D0
a[ng0P11JN4>0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@P0
al6j0P11JN430<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_0040<O1_080@FWQ0`37`K`01011JN40al6l0<O1_011JN430<O1_0D0[Jf]4036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80
[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][Jd@0<6j/080
@FWQ5@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00D0a[ng0P11JN4>0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@P0al6j0P11JN430<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0@0
@FWQ0P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd70<6j/0@0
@FWQ5@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00D0a[ng0P11JN4>0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@P0al6j0P11JN430<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0H0
[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0P31^[02045Yh@l0`kfc
00<0@FWQ0<>m/`33_K<00`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00D0a[ng
0P11JN4>0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@L0al6j
0P11JN440<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f][@/0`kfc0P11
JN450<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL01@36_kL2045Yh@h0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P050<O1^P80@FWQ1`37`KX2045Yh@@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3o
ool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]1@33_K<00`11JN40`kfc0<>m
/`030<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL01@36_kL2045Yh@h0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P050<O1^P80@FWQ1P37`KX2045Yh@D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f]
[@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00D0a[ng0P11JN4>0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@H0al6j0P11JN450<O1^P030:f][@38`K/0
b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H3
0:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc0100`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng00D0a[ng00<0@FWQ0<Jo]`36_kL03@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00D0al6j0P11JN450<O1^P80@FWQ1P37`KX0
0`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng00D0a[ng00<0@FWQ0<Jo
]`36_kL03@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00<0al6j2@11JN480<O1
^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][JeY0;3P
iP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0
al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00
Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]
2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd0
0`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`4
0:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jej0;3P
iP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H10?ooo`00
V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0[Jf]4@31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3PiP40oooo002T
0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l1`2][Jf;
0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l
0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo002i0;3PiPL0
[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool00<P0/>3V
2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0[Jf]1@35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37
`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50862 .33853 m
.51027 .3408 L
s
.50696 .34076 m
.50862 .33853 L
s
.50861 .34304 m
.51027 .3408 L
s
.50696 .34076 m
.50861 .34304 L
s
.48384 .33796 m
.49044 .33816 L
s
.49044 .33816 m
.49373 .34051 L
s
.49373 .34051 m
.49537 .3428 L
s
.48054 .3401 m
.48384 .33796 L
s
.49535 .34957 m
.49537 .3428 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47726 .33772 m
.47888 .34229 L
s
.47721 .34675 m
.47726 .33772 L
s
.47888 .34229 m
.48054 .3401 L
s
.4937 .34953 m
.49536 .34731 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47721 .34675 m
.47888 .34229 L
s
.49369 .35179 m
.49535 .34957 L
s
.49038 .35171 m
.4937 .34953 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49038 .35397 m
.49369 .35179 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50688 .38153 m
.50859 .35433 L
s
.50859 .35433 m
.51021 .38157 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48211 .35598 m
.49038 .35171 L
s
.4821 .35824 m
.49038 .35397 L
s
.46249 .33929 m
.46573 .34397 L
s
.45761 .33676 m
.46249 .33929 L
s
.45435 .33657 m
.45761 .33676 L
s
.45108 .33862 m
.45435 .33657 L
s
.44945 .33852 m
.45435 .33657 L
s
.49364 .36538 m
.49531 .36088 L
s
.49528 .36996 m
.49531 .36088 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4788 .35812 m
.48211 .35598 L
s
.47878 .36039 m
.4821 .35824 L
s
.44779 .34294 m
.45108 .33862 L
s
.50854 .38155 m
.50857 .36792 L
s
.47714 .36033 m
.4788 .35812 L
s
.44616 .34283 m
.44945 .33852 L
s
.49198 .36761 m
.49364 .36538 L
s
.49364 .36538 m
.49528 .36996 L
s
.47712 .36259 m
.47878 .36039 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47711 .36486 m
.47714 .36033 L
s
.48866 .36979 m
.49198 .36761 L
s
.4461 .34963 m
.44779 .34294 L
s
.48204 .36958 m
.48866 .36979 L
s
.47711 .36486 m
.47875 .3672 L
s
.44448 .34952 m
.44616 .34283 L
s
.42689 .33455 m
.43814 .33546 L
s
.464 .35748 m
.46562 .35983 L
s
.46234 .35966 m
.464 .35748 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47875 .3672 m
.48204 .36958 L
s
.46561 .36209 m
.46562 .35983 L
s
.46234 .35966 m
.46396 .36201 L
s
.46229 .36648 m
.46561 .36209 L
s
.43296 .36689 m
.43331 .33508 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59915 .33604 m
.61528 .33482 L
s
.50853 .3861 m
.51021 .38157 L
s
.50688 .38153 m
.50853 .3861 L
s
.43135 .36676 m
.4317 .33495 L
s
.44606 .35416 m
.4461 .34963 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61528 .33482 m
.61851 .33681 L
s
.61528 .33482 m
.62011 .33667 L
s
.44443 .35405 m
.44448 .34952 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40752 .32496 m
.40853 .32575 L
s
.255 .412 .882 r
.45899 .36858 m
.46229 .36648 L
s
.44606 .35416 m
.44762 .36108 L
s
0 0 0 r
.40752 .32496 m
.40852 .32609 L
s
.255 .412 .882 r
.44443 .35405 m
.44599 .36098 L
s
0 0 0 r
.40752 .32496 m
.40435 .32461 L
s
.255 .412 .882 r
.61851 .33681 m
.62176 .34107 L
s
.45408 .36831 m
.45899 .36858 L
s
.62011 .33667 m
.62336 .34092 L
s
.44762 .36108 m
.45084 .36584 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44599 .36098 m
.44921 .36574 L
s
.40941 .33288 m
.42051 .33397 L
s
.45084 .36584 m
.45408 .36831 L
s
.44921 .36574 m
.45408 .36831 L
s
.62176 .34107 m
.62342 .34547 L
s
.62336 .34092 m
.62501 .34532 L
s
.41541 .35854 m
.41574 .33352 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41382 .35839 m
.41415 .33336 L
s
.63281 .3332 m
.64383 .33203 L
s
.62342 .34547 m
.6251 .35215 L
s
.62501 .34532 m
.62669 .352 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60401 .3357 m
.60448 .38346 L
s
.60562 .33558 m
.60611 .38335 L
s
.63754 .33271 m
.638 .36462 L
s
.63912 .33255 m
.63958 .36446 L
s
.6251 .35215 m
.62524 .36354 L
s
.42652 .36637 m
.43296 .36689 L
s
.62669 .352 m
.62684 .3634 L
s
.3922 .33093 m
.40312 .3322 L
s
.5996 .38378 m
.61582 .38264 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62373 .37054 m
.62524 .36354 L
s
.41376 .36296 m
.41541 .35854 L
s
.43122 .37818 m
.43281 .38059 L
s
.42958 .38035 m
.43122 .37818 L
s
.62533 .3704 m
.62684 .3634 L
s
.43117 .38276 m
.43281 .38059 L
s
.41217 .3628 m
.41382 .35839 L
s
.62218 .37525 m
.62373 .37054 L
s
.42958 .38035 m
.43117 .38276 L
s
.63938 .35075 m
.64105 .35744 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62378 .37511 m
.62533 .3704 L
s
.40897 .36478 m
.41376 .36296 L
s
.61902 .38009 m
.62218 .37525 L
s
.61582 .38264 m
.61902 .38009 L
s
.61582 .38264 m
.62063 .37996 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40897 .36478 m
.41217 .3628 L
s
.62063 .37996 m
.62378 .37511 L
s
.63324 .36509 m
.63958 .36446 L
s
.64105 .35744 m
.64427 .36168 L
s
.4058 .36446 m
.40897 .36478 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40111 .36168 m
.4058 .36446 L
s
.39804 .35676 m
.40111 .36168 L
s
.64427 .36168 m
.64744 .36362 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39612 .37953 m
.39687 .33149 L
s
.39769 .3797 m
.39843 .33167 L
s
.66553 .33162 m
.67007 .3287 L
s
.66408 .33639 m
.66553 .33162 L
s
.6505 .35869 m
.65202 .35622 L
s
.65202 .35622 m
.65362 .35833 L
s
.6505 .35869 m
.6521 .3608 L
s
.66408 .33639 m
.66416 .34096 L
s
.37832 .33141 m
.3813 .33639 L
s
.3813 .33639 m
.38271 .34345 L
s
.66706 .33141 m
.67007 .3287 L
s
.66561 .33618 m
.66706 .33141 L
s
.3738 .32848 m
.37832 .33141 L
s
.66561 .33618 m
.66569 .34075 L
s
.37679 .33119 m
.37976 .33618 L
s
.37976 .33618 m
.38118 .34324 L
s
.3738 .32848 m
.37679 .33119 L
s
.67007 .3287 m
.67461 .32804 L
s
.38263 .34802 m
.38271 .34345 L
s
.66416 .34096 m
.66578 .34533 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65362 .35833 m
.65365 .36062 L
s
.64744 .36362 m
.65213 .3631 L
s
.37077 .32804 m
.3738 .32848 L
s
.65213 .3631 m
.65365 .36062 L
s
.3811 .34782 m
.38118 .34324 L
s
.66569 .34075 m
.66731 .34513 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36413 .35929 m
.36506 .31115 L
s
.35911 .31019 m
.36956 .31185 L
s
.38098 .3547 m
.38263 .34802 L
s
.67461 .32804 m
.67767 .32988 L
s
.36771 .32988 m
.37077 .32804 L
s
.37944 .3545 m
.3811 .34782 L
s
.66578 .34533 m
.6704 .347 L
s
.66731 .34513 m
.6704 .347 L
s
.39143 .379 m
.39769 .3797 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37783 .35889 m
.38098 .3547 L
s
.67767 .32988 m
.68076 .334 L
s
.36462 .334 m
.36771 .32988 L
s
.66594 .3545 m
.66598 .3568 L
s
.66594 .3545 m
.66747 .3543 L
s
.3763 .35869 m
.37944 .3545 L
s
.6704 .347 m
.67952 .348 L
s
.66598 .3568 m
.66755 .35889 L
s
.66747 .3543 m
.66751 .35659 L
s
.68217 .32919 m
.6851 .32643 L
s
.68076 .334 m
.68217 .32919 L
s
.66755 .35889 m
.67065 .36078 L
s
.37321 .36057 m
.37783 .35889 L
s
.68076 .334 m
.68116 .35468 L
s
.68366 .32896 m
.6851 .32643 L
s
.68226 .33377 m
.68366 .32896 L
s
.37321 .36057 m
.3763 .35869 L
s
.6851 .32643 m
.68659 .32619 L
s
.68226 .33377 m
.68257 .34985 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67065 .36078 m
.67673 .35994 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36341 .34844 m
.36341 .34816 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36263 .35906 m
.36357 .31091 L
s
.37017 .36015 m
.37321 .36057 L
s
.35435 .32546 m
.35583 .3257 L
s
.67952 .348 m
.68107 .35007 L
s
.35136 .32725 m
.35435 .32546 L
s
.35283 .3275 m
.35435 .32546 L
s
.36719 .35742 m
.37017 .36015 L
s
.67673 .35994 m
.6797 .3572 L
s
.36426 .35237 m
.36719 .35742 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35127 .33185 m
.35283 .3275 L
s
.68116 .35468 m
.68257 .34985 L
s
.6797 .3572 m
.68116 .35468 L
s
.3498 .3316 m
.35136 .32725 L
s
.35814 .35838 m
.36413 .35929 L
s
.35093 .34797 m
.35127 .33185 L
s
.34698 .32649 m
.3498 .3316 L
s
.34936 .35234 m
.3498 .3316 L
s
.34412 .32367 m
.34698 .32649 L
s
.33979 .32287 m
.34412 .32367 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36282 .3784 m
.36282 .37811 L
s
.5 Mabswid
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34936 .35234 m
.35093 .34797 L
s
.33687 .32463 m
.33979 .32287 L
s
.33545 .32436 m
.33979 .32287 L
s
.34804 .34517 m
.34946 .34772 L
s
.33938 .34132 m
.34804 .34517 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69021 .35792 m
.70051 .35623 L
s
.69612 .35697 m
.69996 .33083 L
s
.69465 .35721 m
.69981 .32393 L
s
.69981 .32393 m
.70631 .35521 L
s
.34784 .35441 m
.34936 .35234 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33534 .32897 m
.33687 .32463 L
s
.34487 .35623 m
.34784 .35441 L
s
.33392 .32869 m
.33545 .32436 L
s
.7113 .32178 m
.71773 .35308 L
s
.70631 .35521 m
.7113 .32178 L
s
.33523 .33359 m
.33534 .32897 L
s
.33656 .33848 m
.33938 .34132 L
s
.33513 .33821 m
.33938 .34132 L
s
.33906 .35521 m
.34487 .35623 L
s
.70776 .35496 m
.71146 .3287 L
s
.33381 .33331 m
.33392 .32869 L
s
.33523 .33359 m
.33656 .33848 L
s
0 0 0 r
.72716 .31077 m
.728 .31059 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33381 .33331 m
.33513 .33821 L
s
.33491 .34747 m
.33635 .34774 L
s
.33629 .35005 m
.33635 .34774 L
s
.33624 .35237 m
.33906 .35521 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33486 .34979 m
.33491 .34747 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33486 .34979 m
.33624 .35237 L
s
.71348 .3539 m
.72195 .35225 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30649 .31577 m
.31595 .31797 L
s
.32221 .34498 m
.32354 .34759 L
s
.32349 .34992 m
.32354 .34759 L
s
.32076 .34702 m
.32221 .34498 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72836 .32987 m
.72961 .32493 L
s
.72961 .32493 m
.73222 .31967 L
s
.72716 .33714 m
.72836 .32987 L
s
.32203 .35197 m
.32349 .34992 L
s
.73222 .31967 m
.73621 .31641 L
s
.73098 .32462 m
.73357 .31936 L
s
.72973 .32957 m
.73098 .32462 L
s
.31102 .34963 m
.31187 .31704 L
s
.72716 .33714 m
.72745 .34878 L
s
.72853 .33684 m
.72973 .32957 L
s
.32076 .34702 m
.32209 .34964 L
s
.73357 .31936 m
.73621 .31641 L
s
.31787 .35111 m
.32203 .35197 L
s
.30966 .34933 m
.31052 .31672 L
s
.72853 .33684 m
.72883 .34849 L
s
.73621 .31641 m
.73889 .31577 L
s
.72745 .34878 m
.72901 .35549 L
s
.31518 .34819 m
.31787 .35111 L
s
.73889 .31577 m
.74293 .31712 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72883 .34849 m
.73038 .3552 L
s
.31138 .33563 m
.31256 .34293 L
s
.31256 .34293 m
.31518 .34819 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73038 .3552 m
.73187 .35958 L
s
.72901 .35549 m
.7305 .35988 L
s
.74293 .31712 m
.74569 .32112 L
s
.7305 .35988 m
.73336 .36398 L
s
.30562 .34842 m
.31102 .34963 L
s
.7455 .31413 m
.74601 .3328 L
s
.73187 .35958 m
.73473 .36369 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74681 .3138 m
.74733 .33247 L
s
.29806 .33247 m
.29857 .3138 L
s
.74205 .33376 m
.75123 .33148 L
s
.29675 .33214 m
.29727 .31346 L
s
.73336 .36398 m
.7375 .36544 L
s
.29286 .33115 m
.302 .33344 L
s
.73473 .36369 m
.7375 .36544 L
s
0 0 0 r
.76474 .3012 m
.76638 .30073 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29461 .31512 m
.29707 .32046 L
s
.29083 .31175 m
.29461 .31512 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7375 .36544 m
.7402 .36484 L
s
.75455 .31175 m
.76335 .30927 L
s
.28829 .31105 m
.29083 .31175 L
s
.7402 .36484 m
.74414 .36158 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2857 .31268 m
.28829 .31105 L
s
.28445 .31233 m
.28829 .31105 L
s
.74414 .36158 m
.74666 .35625 L
s
.74778 .34888 m
.74817 .363 L
s
.74666 .35625 m
.74778 .34888 L
s
.29721 .363 m
.2976 .34888 L
s
.2961 .35562 m
.2976 .34888 L
s
.75836 .3107 m
.75931 .34357 L
s
.74666 .35625 m
.74817 .363 L
s
.75961 .31035 m
.76057 .34323 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28306 .31666 m
.2857 .31268 L
s
.29336 .35969 m
.2961 .35562 L
s
.2961 .35562 m
.29721 .363 L
s
.28182 .3163 m
.28445 .31233 L
s
.28168 .321 m
.28306 .31666 L
s
.75549 .34458 m
.76057 .34323 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28942 .36109 m
.29336 .35969 L
s
.76016 .32911 m
.76162 .33582 L
s
.28044 .32064 m
.28182 .3163 L
s
.28023 .3277 m
.28168 .321 L
s
.279 .32734 m
.28044 .32064 L
s
.76162 .33582 m
.76426 .33984 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28686 .36044 m
.28942 .36109 L
s
.27988 .33949 m
.28023 .3277 L
s
.27864 .33914 m
.279 .32734 L
s
.28439 .35741 m
.28686 .36044 L
s
.28313 .35707 m
.28686 .36044 L
s
.76426 .33984 m
.76681 .34151 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28202 .352 m
.28439 .35741 L
s
.27988 .33949 m
.28091 .34693 L
s
.28091 .34693 m
.28202 .352 L
s
.28077 .35166 m
.28313 .35707 L
s
.27864 .33914 m
.27967 .34658 L
s
.27967 .34658 m
.28077 .35166 L
s
.76912 .33607 m
.77027 .33335 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77027 .33335 m
.77155 .33536 L
s
.76912 .33607 m
.77041 .33808 L
s
.76681 .34151 m
.77048 .34045 L
s
.77155 .33536 m
.77162 .33772 L
s
.77048 .34045 m
.77162 .33772 L
s
.2664 .30439 m
.27008 .33901 L
s
.26072 .33604 m
.2664 .30439 L
s
.26652 .33791 m
.27368 .34009 L
s
.78022 .30636 m
.7836 .30282 L
s
.77921 .31147 m
.78022 .30636 L
s
.77921 .31147 m
.77936 .3162 L
s
.26186 .33642 m
.26617 .31147 L
s
.78138 .30597 m
.7836 .30282 L
s
.78037 .31109 m
.78138 .30597 L
s
.78037 .31109 m
.78052 .31582 L
s
.77936 .3162 m
.78067 .32055 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78052 .31582 m
.78183 .32017 L
s
.7836 .30282 m
.78699 .30163 L
s
.78067 .32055 m
.78421 .32177 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78183 .32017 m
.78421 .32177 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78097 .33004 m
.78105 .33241 L
s
.78097 .33004 m
.78213 .32966 L
s
.78699 .30163 m
.7893 .30319 L
s
0 0 0 r
.79789 .29001 m
.798 .28997 L
s
.255 .412 .882 r
.78105 .33241 m
.78228 .33441 L
s
.78213 .32966 m
.78221 .33204 L
s
.25727 .30122 m
.26072 .33604 L
s
.25174 .33295 m
.25727 .30122 L
s
.78421 .32177 m
.79104 .3218 L
s
0 0 0 r
.25056 .29461 m
.25093 .29601 L
s
.255 .412 .882 r
.78228 .33441 m
.78467 .33604 L
s
.7893 .30319 m
.79167 .30713 L
s
.25284 .33334 m
.25704 .30833 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78467 .33604 m
.7892 .33451 L
s
.79261 .30197 m
.7947 .29877 L
s
.79167 .30713 m
.79261 .30197 L
s
.79167 .30713 m
.79238 .32856 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79277 .30672 m
.7937 .30156 L
s
.79277 .30672 m
.79332 .32339 L
s
.7937 .30156 m
.7947 .29877 L
s
.7947 .29877 m
.79578 .29835 L
s
0 0 0 r
.24854 .32135 m
.24998 .32423 L
s
.255 .412 .882 r
.79104 .3218 m
.79222 .32379 L
s
.7892 .33451 m
.79136 .33135 L
s
0 0 0 r
.24781 .32011 m
.24854 .32135 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24848 .33176 m
.25618 .33451 L
s
.79136 .33135 m
.79238 .32856 L
s
.79238 .32856 m
.79332 .32339 L
s
.24642 .29709 m
.24747 .29751 L
s
.24424 .29862 m
.24642 .29709 L
s
.24529 .29905 m
.24642 .29709 L
s
.24408 .30339 m
.24529 .29905 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79901 .31958 m
.79901 .31969 L
s
.5 Mabswid
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79734 .28089 m
.80458 .27784 L
s
.24304 .30297 m
.24424 .29862 L
s
.2435 .32014 m
.24408 .30339 L
s
.80234 .30297 m
.80423 .29734 L
s
.24115 .29734 m
.24304 .30297 L
s
.2423 .32453 m
.24304 .30297 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80423 .29734 m
.80617 .29409 L
s
.23921 .29408 m
.24115 .29734 L
s
.2423 .32453 m
.2435 .32014 L
s
.80617 .29409 m
.80817 .29321 L
s
.23622 .29277 m
.23921 .29408 L
s
.24151 .31691 m
.24246 .31973 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79905 .33096 m
.80325 .32934 L
s
.80152 .27916 m
.80325 .32934 L
s
.80048 .27959 m
.80221 .32974 L
s
.803 .32213 m
.80523 .32611 L
s
.23554 .31197 m
.24151 .31691 L
s
.24118 .32652 m
.2423 .32453 L
s
.80817 .29321 m
.81023 .29472 L
s
.80817 .29321 m
.8112 .29428 L
s
.23418 .29428 m
.23622 .29277 L
s
.23321 .29384 m
.23622 .29277 L
s
.23905 .3281 m
.24118 .32652 L
s
.80523 .32611 m
.80735 .32768 L
s
.81023 .29472 m
.81234 .29864 L
s
.8112 .29428 m
.8133 .2982 L
s
.23304 .29864 m
.23418 .29428 L
s
.23503 .32642 m
.23905 .3281 L
s
.23208 .29819 m
.23321 .29384 L
s
.80735 .32768 m
.80936 .32685 L
s
.23367 .30869 m
.23554 .31197 L
s
.23269 .30826 m
.23554 .31197 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81234 .29864 m
.81356 .30541 L
s
.23287 .30344 m
.23304 .29864 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23287 .30344 m
.23367 .30869 L
s
.8133 .2982 m
.81452 .30497 L
s
.2319 .303 m
.23208 .29819 L
s
.80936 .32685 m
.81125 .32359 L
s
.80936 .32685 m
.81223 .32316 L
s
.2319 .303 m
.23269 .30826 L
s
.23315 .32316 m
.23503 .32642 L
s
.81356 .30541 m
.81374 .31023 L
s
.81125 .32359 m
.81303 .3179 L
s
.23235 .3179 m
.23332 .31833 L
s
.23324 .32074 m
.23332 .31833 L
s
.81303 .3179 m
.81374 .31023 L
s
.81452 .30497 m
.81469 .3098 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81223 .32316 m
.814 .31747 L
s
.23226 .32032 m
.23315 .32316 L
s
.23226 .32032 m
.23235 .3179 L
s
.814 .31747 m
.81469 .3098 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82226 .28642 m
.82415 .33743 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81957 .28781 m
.82574 .28455 L
s
.5 Mabswid
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82314 .28596 m
.82504 .33699 L
s
.22393 .31395 m
.22474 .31682 L
s
.22465 .31925 m
.22474 .31682 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22366 .32124 m
.22465 .31925 L
s
.21465 .28168 m
.2205 .28502 L
s
.22294 .31593 m
.22393 .31395 L
s
.22294 .31593 m
.22375 .31881 L
s
.22098 .31991 m
.22366 .32124 L
s
.21666 .31765 m
.21795 .2836 L
s
.82413 .31261 m
.82606 .31657 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82144 .33872 m
.82504 .33699 L
s
.21582 .3172 m
.21711 .28312 L
s
.21932 .31657 m
.22098 .31991 L
s
.8291 .28265 m
.83467 .27926 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21779 .31079 m
.21932 .31657 L
s
.21722 .30302 m
.21779 .31079 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83153 .28121 m
.83256 .30802 L
s
.82606 .31657 m
.82872 .31765 L
s
.83233 .28072 m
.83336 .30755 L
s
.82872 .31765 m
.83039 .31674 L
s
.21335 .31582 m
.21666 .31765 L
s
.83039 .31674 m
.83194 .31338 L
s
.83039 .31674 m
.83275 .31291 L
s
.83194 .31338 m
.83256 .30802 L
s
.83275 .31291 m
.83336 .30755 L
s
.20966 .28608 m
.21024 .29145 L
s
.21024 .29145 m
.21073 .29926 L
s
.20835 .28022 m
.20966 .28608 L
s
.21026 .31151 m
.21073 .29926 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20891 .2856 m
.20947 .29097 L
s
.20947 .29097 m
.20996 .29879 L
s
.20761 .27973 m
.20891 .2856 L
s
.20625 .27629 m
.20835 .28022 L
s
.20948 .31104 m
.20996 .29879 L
s
.83768 .27729 m
.84263 .27378 L
s
.20625 .27629 m
.20761 .27973 L
s
.2092 .31841 m
.21026 .31151 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20843 .31795 m
.20948 .31104 L
s
.83985 .2758 m
.84121 .31019 L
s
.20824 .32287 m
.2092 .31841 L
s
.84056 .2753 m
.84192 .30971 L
s
.20748 .32241 m
.20843 .31795 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20653 .32688 m
.20824 .32287 L
s
.20578 .32641 m
.20748 .32241 L
s
.83902 .31162 m
.84192 .30971 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19947 .27123 m
.20625 .27629 L
s
.20422 .32796 m
.20653 .32688 L
s
.20002 .32514 m
.20208 .27327 L
s
.20422 .32796 m
.20578 .32641 L
s
.19934 .32466 m
.20141 .27277 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84107 .32548 m
.84169 .32254 L
s
.84107 .32548 m
.84189 .32749 L
s
.84169 .32254 m
.8425 .32455 L
s
.84189 .32749 m
.8425 .32455 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84621 .27862 m
.84727 .27267 L
s
.84587 .28653 m
.84621 .27862 L
s
.84587 .28653 m
.84607 .29147 L
s
.84685 .27812 m
.84789 .27216 L
s
.84651 .28602 m
.84685 .27812 L
s
.84607 .29147 m
.84701 .29839 L
s
.84651 .28602 m
.84671 .29097 L
s
.84671 .29097 m
.84764 .29789 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84789 .27216 m
.84899 .26866 L
s
.84727 .27267 m
.84899 .26866 L
s
.84701 .29839 m
.84847 .30236 L
s
.84899 .26866 m
.85015 .26762 L
s
.84764 .29789 m
.84908 .30186 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19738 .32323 m
.20422 .32796 L
s
.85015 .26762 m
.85194 .26852 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84908 .30186 m
.85039 .30336 L
s
.84847 .30236 m
.85039 .30336 L
s
.85194 .26852 m
.85322 .27243 L
s
.85039 .30336 m
.85214 .30186 L
s
.85214 .30186 m
.85316 .29836 L
s
.85285 .29088 m
.8533 .28788 L
s
.85285 .29088 m
.8535 .29286 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8533 .28788 m
.85394 .28986 L
s
.85316 .29836 m
.85404 .29235 L
s
.85394 .28986 m
.85404 .29235 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8564 .26126 m
.85707 .26571 L
s
.8564 .26126 m
.85682 .27124 L
s
.85682 .27124 m
.85707 .26571 L
s
.85707 .26571 m
.85742 .26268 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85742 .26268 m
.85819 .25911 L
s
.85819 .25911 m
.85983 .25693 L
s
.85744 .28624 m
.8578 .28322 L
s
.85744 .28624 m
.85765 .29126 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85754 .28875 m
.8579 .28572 L
s
.8578 .28322 m
.85859 .27966 L
s
.85765 .29126 m
.85821 .29325 L
s
.8579 .28572 m
.8587 .28217 L
s
.85859 .27966 m
.86046 .27198 L
s
.85821 .29325 m
.85922 .29473 L
s
.8587 .28217 m
.86057 .2745 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85983 .25693 m
.8607 .25835 L
s
.85922 .29473 m
.86091 .29266 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8607 .25835 m
.86117 .26031 L
s
.86046 .27198 m
.86112 .26839 L
s
.86057 .2745 m
.86123 .27091 L
s
.86117 .26031 m
.86149 .26786 L
s
.86112 .26839 m
.86138 .26534 L
s
.86123 .27091 m
.86149 .26786 L
s
.86091 .29266 m
.86159 .28909 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86159 .28909 m
.86186 .28604 L
s
.86186 .28604 m
.86202 .28046 L
s
.86186 .28604 m
.86244 .29057 L
s
.86202 .28046 m
.86244 .29057 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86337 .25395 m
.86355 .25087 L
s
.86337 .25395 m
.86376 .25592 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86355 .25087 m
.86393 .25284 L
s
.86376 .25592 m
.86393 .25284 L
s
.8643 .26857 m
.86587 .29856 L
s
.8643 .26857 m
.8653 .29961 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86494 .2838 m
.86559 .29908 L
s
.8653 .29961 m
.86581 .30419 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86581 .30419 m
.86587 .29856 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17824 .24641 m
.17847 .24443 L
s
.17846 .24131 m
.17847 .24443 L
s
.17824 .24329 m
.17846 .24131 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17824 .24641 m
.17824 .24329 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17649 .29061 m
.17769 .25921 L
s
.17626 .28954 m
.17769 .25921 L
s
.17637 .29008 m
.17703 .27461 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17615 .29525 m
.17649 .29061 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17767 .24188 m
.17776 .23874 L
s
.17734 .24959 m
.17767 .24188 L
s
.17615 .29525 m
.17626 .28954 L
s
.17776 .23874 m
.17786 .23502 L
s
.17732 .24902 m
.17745 .24702 L
s
.17721 .2516 m
.17734 .24959 L
s
.17786 .23502 m
.17795 .23272 L
s
.17719 .25047 m
.17732 .24902 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17708 .25306 m
.17721 .2516 L
s
.17654 .26709 m
.17679 .26248 L
s
.17634 .27282 m
.17679 .26248 L
s
.17712 .25283 m
.17719 .25047 L
s
.17654 .26709 m
.17634 .27282 L
s
.17701 .25543 m
.17708 .25306 L
s
.17654 .26709 m
.17642 .26913 L
s
.17795 .23272 m
.17796 .23415 L
s
.17642 .26913 m
.17631 .27062 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17796 .23415 m
.17792 .23616 L
s
.17631 .27062 m
.17645 .26842 L
s
.17792 .23616 m
.17822 .23042 L
s
.17792 .23616 m
.17778 .24077 L
s
.17778 .24077 m
.17822 .23042 L
s
.17714 .2543 m
.17712 .25283 L
s
.17703 .2569 m
.17701 .25543 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17125 .29699 m
.17465 .21875 L
s
.255 .412 .882 r
.17711 .25634 m
.17714 .2543 L
s
.17645 .26842 m
.17669 .26471 L
s
.177 .25894 m
.17703 .2569 L
s
.17689 .26155 m
.17711 .25634 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17669 .26471 m
.17689 .26155 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17435 .22052 m
.17707 .21104 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17299 .25898 m
.17394 .25559 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.178 .25242 m
.17788 .25504 L
s
.17828 .24925 m
.178 .25242 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17136 .29646 m
.17477 .21816 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17329 .2706 m
.17459 .24064 L
s
.1761 .23344 m
.17682 .21163 L
s
.1761 .23344 m
.17707 .21104 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17096 .29861 m
.17366 .28999 L
s
.5 Mabswid
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17341 .29053 m
.17464 .26727 L
s
.17366 .28999 m
.17464 .26727 L
s
.18006 .20886 m
.18139 .20333 L
s
.17938 .21695 m
.18006 .20886 L
s
.1776 .25848 m
.17938 .21695 L
s
.18044 .20827 m
.18139 .20333 L
s
.17974 .21637 m
.18044 .20827 L
s
.17796 .25792 m
.17974 .21637 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18139 .20333 m
.18223 .20215 L
s
.17656 .26015 m
.17796 .25792 L
s
.18223 .20215 m
.18341 .20415 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18341 .20415 m
.18404 .21053 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18452 .1992 m
.18656 .19684 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8602 .20559 m
.86054 .20239 L
s
.85988 .19802 m
.86054 .20239 L
s
.85952 .20122 m
.85988 .19802 L
s
.85952 .20122 m
.8602 .20559 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8577 .23084 m
.8577 .2307 L
s
.5 Mabswid
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8577 .23084 m
.85826 .24417 L
s
0 0 0 r
.18085 .25403 m
.18276 .25181 L
s
.861 .22456 m
.86344 .27099 L
s
.861 .22456 m
.86242 .26991 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18276 .25181 m
.18501 .19861 L
s
.18227 .25237 m
.18452 .1992 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85826 .24417 m
.85842 .24591 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86196 .24744 m
.86293 .27045 L
s
.85498 .19655 m
.85575 .20093 L
s
.85575 .20093 m
.85623 .21236 L
s
.85358 .19158 m
.85498 .19655 L
s
.18948 .20474 m
.19103 .19597 L
s
.18841 .21675 m
.18948 .20474 L
s
.85562 .21179 m
.85607 .20855 L
s
.19103 .19597 m
.19311 .19042 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18809 .22439 m
.18841 .21675 L
s
.19009 .20416 m
.19166 .19539 L
s
.18901 .21618 m
.19009 .20416 L
s
.85094 .18926 m
.85358 .19158 L
s
.85578 .21561 m
.85623 .21236 L
s
.86326 .27815 m
.86344 .27099 L
s
.19166 .19539 m
.19311 .19042 L
s
.18869 .22382 m
.18901 .21618 L
s
.18809 .22439 m
.18821 .23532 L
s
.85453 .21448 m
.85562 .21179 L
s
.19311 .19042 m
.19445 .18926 L
s
.18869 .22382 m
.18882 .23476 L
s
.86242 .26991 m
.86326 .27815 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85468 .21831 m
.85578 .21561 L
s
.85673 .23861 m
.85702 .23149 L
s
.85702 .23149 m
.85766 .24685 L
s
.84971 .19192 m
.85094 .18926 L
s
.85151 .21934 m
.85453 .21448 L
s
.19445 .18926 m
.19568 .19192 L
s
.18821 .23532 m
.18912 .2419 L
s
.85167 .22318 m
.85468 .21831 L
s
.18882 .23476 m
.18975 .24135 L
s
.85627 .2419 m
.85673 .23861 L
s
.85673 .23861 m
.85766 .24685 L
s
.84915 .19518 m
.84971 .19192 L
s
.19568 .19192 m
.19681 .19844 L
s
.85516 .24466 m
.85627 .2419 L
s
.18912 .2419 m
.19089 .24411 L
s
.84812 .18695 m
.84915 .19518 L
s
.84812 .18695 m
.84874 .20228 L
s
.19727 .18695 m
.20028 .18465 L
s
.19397 .26808 m
.19727 .18695 L
s
.84874 .20228 m
.84915 .19518 L
s
.18975 .24135 m
.19089 .24411 L
s
.1947 .26755 m
.19801 .18637 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85025 .22207 m
.85151 .21934 L
s
.85246 .24248 m
.85516 .24466 L
s
.85041 .22593 m
.85167 .22318 L
s
.19089 .24411 m
.19224 .24302 L
s
.84968 .22538 m
.85025 .22207 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19224 .24302 m
.19379 .23807 L
s
.84984 .22924 m
.85041 .22593 L
s
.85088 .23752 m
.85246 .24248 L
s
.255 .412 .882 r
.20564 .19771 m
.20584 .19701 L
s
0 0 0 r
.84968 .22538 m
.85 .23311 L
s
.19379 .23807 m
.19555 .22924 L
s
.85 .23311 m
.85088 .23752 L
s
.255 .412 .882 r
.83617 .19211 m
.8368 .19253 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84125 .18565 m
.8432 .19448 L
s
.83854 .18011 m
.84125 .18565 L
s
.255 .412 .882 r
.2044 .22901 m
.20455 .22948 L
s
0 0 0 r
.19182 .26965 m
.1947 .26755 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83679 .17898 m
.83854 .18011 L
s
.20468 .1928 m
.2067 .18396 L
s
.20338 .20495 m
.20468 .1928 L
s
.84397 .21379 m
.84428 .22154 L
s
.2067 .18396 m
.2095 .17842 L
s
.20553 .19224 m
.20757 .1834 L
s
.20422 .20439 m
.20553 .19224 L
s
.20307 .21269 m
.20338 .20495 L
s
.84315 .21324 m
.84362 .22488 L
s
.20757 .1834 m
.2095 .17842 L
s
.83513 .18173 m
.83679 .17898 L
s
.83422 .18117 m
.83679 .17898 L
s
.84378 .22877 m
.84428 .22154 L
s
.20391 .21214 m
.20422 .20439 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20307 .21269 m
.20344 .2238 L
s
.2095 .17842 m
.21133 .1773 L
s
.20391 .21214 m
.2043 .22326 L
s
.8431 .23212 m
.84362 .22488 L
s
.8431 .23212 m
.84378 .22877 L
s
.21133 .1773 m
.21305 .18006 L
s
.21133 .1773 m
.214 .17951 L
s
.20344 .2238 m
.20485 .23052 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83264 .18782 m
.83422 .18117 L
s
.83359 .18837 m
.83513 .18173 L
s
.84156 .23495 m
.8431 .23212 L
s
.2043 .22326 m
.20573 .22998 L
s
.21305 .18006 m
.21467 .18672 L
s
.8331 .19948 m
.83359 .18837 L
s
.214 .17951 m
.21564 .18618 L
s
.83893 .23337 m
.84156 .23495 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83214 .19894 m
.83264 .18782 L
s
.20485 .23052 m
.20736 .23284 L
s
.20573 .22998 m
.20736 .23284 L
s
.21467 .18672 m
.2152 .19786 L
s
.82321 .17126 m
.82731 .17344 L
s
.21564 .18618 m
.21618 .19732 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83214 .19894 m
.83244 .20674 L
s
.83604 .22787 m
.83893 .23337 L
s
.83696 .2284 m
.83893 .23337 L
s
.8331 .19948 m
.8334 .20727 L
s
.8334 .20727 m
.84397 .21379 L
s
.8334 .20727 m
.8348 .21952 L
s
.20736 .23284 m
.2092 .23178 L
s
.8348 .21952 m
.83696 .2284 L
s
.83244 .20674 m
.83386 .21899 L
s
.21489 .20567 m
.2152 .19786 L
s
.83386 .21899 m
.83604 .22787 L
s
.2092 .23178 m
.21123 .22682 L
s
.2092 .23178 m
.21219 .22629 L
s
.21588 .20514 m
.21618 .19732 L
s
.21346 .21793 m
.21489 .20567 L
s
.22219 .17125 m
.22868 .16803 L
s
.21123 .22682 m
.21346 .21793 L
s
.21444 .21741 m
.21588 .20514 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21219 .22629 m
.21444 .21741 L
s
.82123 .17407 m
.82365 .18295 L
s
.81892 .1691 m
.82123 .17407 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82321 .17126 m
.82632 .2538 L
s
.82425 .1718 m
.82738 .2543 L
s
.81671 .16803 m
.81892 .1691 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8146 .17088 m
.81671 .16803 L
s
.81345 .17036 m
.81671 .16803 L
s
.823 .22114 m
.82483 .21428 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81258 .17767 m
.8146 .17088 L
s
.81142 .17716 m
.81345 .17036 L
s
.23324 .16592 m
.2404 .1628 L
s
.22012 .2261 m
.22665 .22306 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82097 .22407 m
.823 .22114 L
s
.81184 .18895 m
.81258 .17767 L
s
.22225 .22508 m
.23677 .16435 L
s
.81066 .18844 m
.81142 .17716 L
s
.22333 .22457 m
.23797 .16383 L
s
.81874 .22307 m
.82097 .22407 L
s
.8231 .25233 m
.82738 .2543 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22431 .17017 m
.23599 .21911 L
s
.81184 .18895 m
.81213 .19684 L
s
.81066 .18844 m
.81095 .19633 L
s
.81633 .21811 m
.81874 .22307 L
s
.81518 .21761 m
.81874 .22307 L
s
.81213 .19684 m
.81373 .20919 L
s
.81373 .20919 m
.81633 .21811 L
s
.81095 .19633 m
.81256 .20869 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81256 .20869 m
.81518 .21761 L
s
.23123 .22107 m
.23844 .21814 L
s
.79886 .16419 m
.80168 .17308 L
s
.79483 .15875 m
.79886 .16419 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79218 .15776 m
.79483 .15875 L
s
.25043 .16269 m
.25455 .15726 L
s
.24885 .17108 m
.25043 .16269 L
s
.24735 .2148 m
.24885 .17108 L
s
.25175 .16219 m
.25455 .15726 L
s
.25016 .17059 m
.25175 .16219 L
s
.78963 .16072 m
.79218 .15776 L
s
.78827 .16024 m
.79218 .15776 L
s
.24866 .21433 m
.25016 .17059 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78643 .1871 m
.80237 .19285 L
s
.80237 .19285 m
.80265 .20078 L
s
.8011 .19236 m
.80152 .20427 L
s
.25455 .15726 m
.25726 .15628 L
s
.80165 .20825 m
.80265 .20078 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78716 .16768 m
.78963 .16072 L
s
.25726 .15628 m
.26128 .15879 L
s
.80051 .21176 m
.80152 .20427 L
s
.78577 .1672 m
.78827 .16024 L
s
.80051 .21176 m
.80165 .20825 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24346 .21622 m
.24866 .21433 L
s
.79805 .2148 m
.80051 .21176 L
s
.78617 .17913 m
.78716 .16768 L
s
.26128 .15879 m
.26383 .16578 L
s
.78477 .17866 m
.78577 .1672 L
s
.26422 .15387 m
.26998 .15199 L
s
.2624 .20975 m
.26422 .15387 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26384 .2093 m
.26565 .1534 L
s
.79407 .2134 m
.79805 .2148 L
s
.78617 .17913 m
.78643 .1871 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78477 .17866 m
.78503 .18663 L
s
.78643 .1871 m
.78822 .19954 L
s
.79123 .20847 m
.79407 .2134 L
s
.78986 .20801 m
.79407 .2134 L
s
.77396 .15153 m
.77535 .19547 L
s
.78503 .18663 m
.78683 .19908 L
s
.78822 .19954 m
.79123 .20847 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.768 .14969 m
.77832 .15293 L
s
.77248 .15106 m
.77387 .19503 L
s
.78683 .19908 m
.78986 .20801 L
s
.2774 .14969 m
.27866 .15721 L
s
.2769 .16564 m
.2774 .14969 L
s
.25817 .2111 m
.26384 .2093 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2769 .16564 m
.27866 .15721 L
s
.27866 .15721 m
.28031 .15277 L
s
.28031 .15277 m
.28351 .14789 L
s
.28351 .14789 m
.28978 .14614 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76647 .18342 m
.76655 .18614 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75082 .14486 m
.76189 .14789 L
s
.77412 .20307 m
.77535 .19547 L
s
.77263 .20264 m
.77387 .19503 L
s
.28978 .14614 m
.29285 .14928 L
s
.76974 .20581 m
.77412 .20307 L
s
.27616 .18969 m
.2778 .18524 L
s
.27591 .19774 m
.27616 .18969 L
s
.2778 .18524 m
.28099 .18036 L
s
.76974 .20581 m
.77263 .20264 L
s
.27603 .19372 m
.27768 .18926 L
s
.27768 .18926 m
.28087 .18438 L
s
.28099 .18036 m
.28907 .17018 L
s
.29285 .14928 m
.29435 .15286 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27591 .19774 m
.27731 .20135 L
s
.28087 .18438 m
.28895 .17421 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.294 .16491 m
.29435 .15286 L
s
.27731 .20135 m
.28026 .20454 L
s
.28907 .17018 m
.29239 .16532 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76668 .20496 m
.76974 .20581 L
s
.75562 .14614 m
.75692 .19034 L
s
.7572 .14658 m
.75851 .19075 L
s
.7325 .14036 m
.74428 .14318 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29239 .16532 m
.29412 .16089 L
s
.28895 .17421 m
.29227 .16935 L
s
.7619 .19966 m
.76668 .20496 L
s
.29227 .16935 m
.294 .16491 L
s
.28026 .20454 m
.28653 .20288 L
s
.73929 .14195 m
.74083 .19853 L
s
.75851 .19075 m
.7619 .19966 L
s
.75715 .19842 m
.75851 .19075 L
s
.7376 .14155 m
.73914 .19816 L
s
.30779 .14155 m
.30938 .14517 L
s
.306 .14597 m
.30779 .14155 L
s
.306 .14597 m
.30758 .14959 L
s
.75555 .19802 m
.75692 .19034 L
s
.30758 .14959 m
.30938 .14517 L
s
.29157 .19356 m
.29342 .18506 L
s
.29296 .20126 m
.29342 .18506 L
s
.28653 .20288 m
.28984 .19801 L
s
.75244 .20126 m
.75715 .19842 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28984 .19801 m
.29157 .19356 L
s
.29157 .19356 m
.29296 .20126 L
s
.75244 .20126 m
.75555 .19802 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71313 .13623 m
.72557 .13881 L
s
.74917 .20047 m
.75244 .20126 L
s
.255 .412 .882 r
.72289 .17634 m
.72358 .1763 L
s
0 0 0 r
.30703 .16975 m
.30741 .2182 L
s
.30401 .21894 m
.30703 .16975 L
s
.74408 .19524 m
.74917 .20047 L
s
.7405 .18634 m
.74408 .19524 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72122 .17882 m
.72289 .17634 L
s
0 0 0 r
.30571 .21857 m
.30637 .19408 L
s
.734 .19704 m
.74083 .19853 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7193 .1719 m
.71938 .17483 L
s
.72108 .17343 m
.72113 .17513 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72029 .13769 m
.72171 .19452 L
s
.69279 .13249 m
.70584 .13483 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30401 .21894 m
.30548 .22676 L
s
.30548 .22676 m
.30741 .2182 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67157 .12917 m
.68517 .13124 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7145 .19315 m
.72171 .19452 L
s
.69843 .13347 m
.69942 .17825 L
s
.70029 .13381 m
.70129 .17857 L
s
.71851 .13732 m
.71992 .19417 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6996 .18645 m
.70129 .17857 L
s
.72042 .21468 m
.72232 .21913 L
s
.71872 .21846 m
.72042 .21468 L
s
.72063 .22291 m
.72232 .21913 L
s
.69772 .18614 m
.69942 .17825 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71872 .21846 m
.72063 .22291 L
s
.69401 .18963 m
.6996 .18645 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69401 .18963 m
.69772 .18614 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67743 .13004 m
.67912 .21628 L
s
.67938 .13033 m
.68108 .21654 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65571 .13111 m
.65987 .13979 L
s
.64957 .1263 m
.65571 .13111 L
s
.64549 .12582 m
.64957 .1263 L
s
.69019 .18904 m
.69401 .18963 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66327 .16131 m
.66335 .1658 L
s
.66393 .19875 m
.66397 .20107 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6394 .12922 m
.64549 .12582 L
s
.64146 .12944 m
.64549 .12582 L
s
.68432 .18405 m
.69019 .18904 L
s
.68027 .17526 m
.68432 .18405 L
s
.63746 .13719 m
.64146 .12944 L
s
.63539 .13697 m
.6394 .12922 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63556 .14928 m
.63746 .13719 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63349 .14908 m
.63539 .13697 L
s
.65828 .16412 m
.66036 .16849 L
s
.65633 .16799 m
.65828 .16412 L
s
.66036 .16849 m
.66044 .1726 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65633 .16799 m
.65842 .17236 L
s
.59513 .12134 m
.61006 .12241 L
s
.63556 .14928 m
.63568 .15751 L
s
.63349 .14908 m
.6336 .15731 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65653 .18036 m
.66044 .1726 L
s
.65253 .18403 m
.65653 .18036 L
s
.57786 .12037 m
.59083 .12107 L
s
.63568 .15751 m
.63793 .17009 L
s
.6336 .15731 m
.63586 .16989 L
s
.67319 .21549 m
.68108 .21654 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64639 .18335 m
.65253 .18403 L
s
.63793 .17009 m
.6422 .17878 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55169 .1194 m
.56481 .11981 L
s
.63586 .16989 m
.64013 .17857 L
s
.6422 .17878 m
.64639 .18335 L
s
.64013 .17857 m
.64639 .18335 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61911 .17251 m
.62118 .16855 L
s
.62118 .16855 m
.62334 .17287 L
s
.60402 .15483 m
.60629 .16739 L
s
.62334 .17287 m
.62339 .17701 L
s
.56056 .14436 m
.58021 .14516 L
s
.61911 .17251 m
.62128 .17683 L
s
.62133 .18098 m
.62339 .17701 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60629 .16739 m
.61066 .17599 L
s
.61497 .18047 m
.62133 .18098 L
s
.255 .412 .882 r
.55904 .163 m
.55906 .16703 L
s
.55745 .16195 m
.55904 .16413 L
s
0 0 0 r
.61066 .17599 m
.61497 .18047 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57181 .19463 m
.58436 .1207 L
s
.60155 .12178 m
.60212 .17955 L
s
.60368 .12193 m
.60427 .17969 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59566 .17914 m
.60427 .17969 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57188 .20719 m
.58652 .12082 L
s
.55607 .11952 m
.57188 .20719 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ00102][Jd0000000000000000K0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo
00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4BT0[Jf]1@0000060:f][@L0000000<0
ojD@0000000000000P0000050?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o
0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@l0[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40040:f][@3oYA00ojD@000000`0ojD@00<0[Jf]0000000000001`2][Jd5000000D0[Jf]5`3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/
UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L
0?nV40040:f][@3oYA00ojD@000000d0ojD@0P0000070?nU408000000`3oYA000`2][Jd0oj<@0?nS
40020?nS40T0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ40
0`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00D0[Jf]0?nU403oYA00ojD@0000
000<0?nU408000001`3oYA02000000<0ojD@00<0[Jf]0?nS403oXa002`3oXa000`2][Jd000000000
0002000000D0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ40
0`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00D0[Jf]0?nU403oYA00ojD@0000
000;0?nU40800000203oYA02000000<0ojD@00<0[Jf]0?nS403oXa002P3oXa03000000<0oj<@0P00
00030?nS40D0[Jf]1000000F0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh20:f][F40/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]
0?nV4@3oYQ405@3oYQ470:f][AP0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40050:f][@3oYA00ojD@0?nU400000002`3oYA02000000P0ojD@0P0000030?nU40030:f][@3o
Xa00oj<@00T0oj<@0P0000070?nS408000001@3oXa00102][Jd0o:0@0?bP402][Jd500000180o:0@
00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`
h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@D0[Jf]0P3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ001@2][Jd0ojD@0?nU403oYA00000000/0ojD@0P0000080?nU408000000`3oYA000`2][Jd0oj<@
0?nS40090?nS40800000203oXa000`000000oj<@0?nS40030?nS40040:f][@3lX100o:0@0?bP4080
00000`3lX1030:f][@@000002`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00D0[Jf]0?nU403oYA00ojD@0000000;0?nU40800000203oYA02000000<0ojD@00<0[Jf]0?nS403o
Xa00203oXa02000000X0oj<@00<000000?nS403oXa000P3oXa00102][Jd0o:0@0?bP403lX1020000
00P0o:0@00<0[Jf]0000000000000P0000080?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0
ojHA1P2][Jd<0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0
ojH@0?nV400L0?nV40050:f][@3oYA00ojD@0?nU400000002`3oYA02000000P0ojD@0P0000030?nU
40030:f][@3oXa00oj<@00P0oj<@0P00000:0?nS40030000003oXa00oj<@0080oj<@00@0[Jf]0?bP
403lX100o:0@0P0000090?bP408000000P3lX1030:f][@@0000000<0o:0@0:f][@3fW0l05@3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3P
iP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40020?nU40030000003oYA00ojD@
00P0ojD@0P0000080?nU408000000`3oYA000`2][Jd0oj<@0?nS40080?nS408000002`3oXa001@00
0000oj<@0?nS403oXa00[Jf]00<0o:0@0P0000090?bP40800000203lX104000001D0mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@060=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f]
[@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@@0[Jf]5`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU40020?nU40030000003oYA00ojD@00L0ojD@0P0000090?nU408000000`3oYA000`2]
[Jd0oj<@0?nS40080?nS408000002`3oXa001@000000oj<@0?nS403oXa00[Jf]00<0o:0@0P000009
0?bP40800000203lX102000000030:f][@3fW0l0[Jf]0080[Jf]0`00000?0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY1401P000000[Jf]0:f][@2][Jd0
oj@A0:f][AT0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA000P3oYA000`000000ojD@0?nU40070?nU408000002@3o
YA02000000<0ojD@00<0[Jf]0?nS403oXa001`3oXa0200000100oj<@00@0[Jf]0?bP403lX100o:0@
0P0000090?bP40800000203lX102000000030:f][@3fW0l0mY`?00<0mY`?00<0[Jf]000000000000
0`00000;0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V
0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3o
Y1430:f][@030000003oY140000000<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
40020?nU40`000002@3oYA02000000<0ojD@00<0[Jf]0?nS403oXa001`3oXa0200000100oj<@00@0
[Jf]0?bP403lX100o:0@0P0000090?bP40800000203lX102000000030:f][@3fW0l0mY`?00@0mY`?
0P0000000`3fW0l0[Jf]0:f][@020:f][@8000001`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401@3oY142000000@0[Jf]0`3o
Y1400`000000oj@A000000030?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA000P3o
YA000`000000ojD@0?nU40070?nU408000002@3oYA02000000<0ojD@00<0[Jf]0?nS403oXa001`3o
Xa0200000100oj<@00@0[Jf]0?bP403lX100o:0@0P0000090?bP40800000203lX102000000030:f]
[@3fW0l0mY`?00@0mY`?0P0000050?JL3`80[Jf]0P0000050?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY14200000080[Jf]0P0000050?nT4@800000103o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00<0ojD@00<000000?nU403oYA001P3o
YA02000000T0ojD@0P0000030?nU40030:f][@3oXa00oj<@00L0oj<@0P00000A0?nS40030:f][@3l
X100o:0@008000002@3lX102000000P0o:0@0P0000000`2][Jd0mY`?0?JL3`040?JL3`8000001`3f
W0l400000080[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?
0?bP40060:f][@3oY140[Jf]0000002][Jd000001@3oY1400`000000oj@A0?nT4@040?nT4@030000
003oY140oj@A0080oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40030?nU40030000
003oYA00ojD@00H0ojD@0P0000090?nU408000000`3oYA000`2][Jd0oj<@0?nS40070?nS40800000
4@3oXa000`2][Jd0o:0@0?bP4002000000T0o:0@0P0000080?bP4080000000<0[Jf]0?JL3`3fW0l0
103fW0l2000000L0mY`?0P0000040?JL3`@00000403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f]
[@2iM@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0
o:0@0?bP400<0?bP40030000003lX10000000080[Jf]00@0oj@A0000003oY14000001P3oY1400`00
0000oj@A0?nT4@080?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA000`3oYA000`00
0000ojD@0?nU40050?nU408000002P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa001`3oXa020000
0140oj<@00<0[Jf]0?bP403lX1000P0000090?bP40800000203lX102000000030:f][@3fW0l0mY`?
00@0mY`?0P0000070?JL3`8000001@3fW0l00`2][Jd0k9H>00000003000000d0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>7
3P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P000000103lX100[Jf]0?nT4@3o
Y142000000L0oj@A00<000000?nT4@3oY140203oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@00<0ojD@00<000000?nU403oYA001@3oYA02000000X0ojD@0P0000030?nU40030:f][@3o
Xa00oj<@00P0oj<@0P00000@0?nS40030:f][@3lX100o:0@008000002@3lX102000000P0o:0@0P00
00000`2][Jd0mY`?0?JL3`040?JL3`8000001`3fW0l2000000D0mY`?00<0[Jf]0>bF3P0000000P3/
UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`
h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX1001`3lX102000000<0[Jf]00@000000?bP403lX100[Jf]0P3oY142000000L0oj@A00<0
00000?nT4@3oY140203oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ405@3oYQ4/0:f][@030000002][Jd0ojD@00D0ojD@0P00000:0?nU408000000`3o
YA000`2][Jd0oj<@0?nS40080?nS40800000403oXa000`2][Jd0o:0@0?bP4002000000T0o:0@0P00
00080?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l2000000L0mY`?0P0000050?JL3`030:f][@3/
UPh0000000@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102i
M@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40060?bP40030000002][Jd0[Jf]0080000000D0o:0@
0000003lX100o:0@0:f][@020?nT4@8000001P3oY1400`000000oj@A0?nT4@080?nT4@030:f][@3o
YQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00@0ojD@00<000000:f][@2][Jd0102]
[Jd2000000P0[Jf]0P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00203oXa0200000100oj<@00<0
[Jf]0?bP403lX1000P0000090?bP40800000203lX102000000030:f][@3fW0l0mY`?00@0mY`?0P00
00070?JL3`8000001@3fW0l00`2][Jd0k9H>000000070>bF3P040:f][@0000000000000000D0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V
0@3oool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00@0o:0@0P2][Jd01`000000o:0@0?bP403lX10000000?bP400000000P3lX1000`2][Jd0
oj@A0?nT4@02000000H0oj@A0P0000090?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3o
YQ405@3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40040?nU4003
0000003oYA00ojD@00@0ojD@0P0000080?nU4080[Jf]0P0000080:f][@H0oj<@0P00000@0?nS4003
0:f][@3lX100o:0@008000002@3lX102000000P0o:0@0P0000000`2][Jd0mY`?0?JL3`040?JL3`80
00001`3fW0l2000000D0mY`?00<0[Jf]0>bF3P0000001P3/UPh200000080k9H>00<0[Jf]0000003/
UPh00`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`
h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@
00@0[Jf]0?bP403lX10000000`2][Jd00`3lX10000000?bP40030?bP40030000003lX10000000080
o:0@00@0[Jf]0?nT4@3oY14000001`3oY1400`000000oj@A0?nT4@080?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ490:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00@0ojD@00<000000?nU403oYA00103oYA020000
00X0ojD@0`0000020?nU40030:f][@3oXa00oj<@0080oj<@1P2][Jd200000080[Jf]3P3oXa000`2]
[Jd0o:0@0?bP4002000000T0o:0@0P0000080?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l20000
00L0mY`?0P0000050?JL3`030:f][@3/UPh0000000H0k9H>0P0000030>bF3P060000002][Jd0[Jf]
0:f][@3/UPh0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V0@3o
ool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@000000
00000:f][@@0o:0@00<000000?bP403lX1000`3lX10200000080o:0@00@0[Jf]0?nT4@3oY1400000
1`3oY1400`000000oj@A0?nT4@080?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ4:0:f][@d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@00@0ojD@00<000000?nU403oYA000`3oYA02000000/0ojD@0`0000020?nU40030:f]
[@3oXa00oj<@00T0oj<@0P0000000`3oXa00[Jf]0:f][@060:f][@030000002][Jd0oj<@00<0oj<@
00<0[Jf]0?bP403lX1000P0000090?bP40800000203lX102000000030:f][@3fW0l0mY`?00@0mY`?
0P0000070?JL3`8000001@3fW0l00`2][Jd0k9H>000000050>bF3P8000001@3/UPh00`000000k9H>
0>bF3P020:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2]
[Jd80=>73P030:f][@3_V100kiP@00X0kiP@100000040?bP408000001@3lX10200000080o:0@00@0
[Jf]0?nT4@3oY14000001P3oY142000000X0oj@A00<0[Jf]0?nV4@3oYQ405P3oYQ470:f][AL0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00@0ojD@
00<000000?nU403oYA000`3oYA02000000/0ojD@0`0000020?nU40030:f][@3oXa00oj<@00T0oj<@
0P0000080?nS4080000000<0oj<@0:f][@2][Jd01@2][Jd2000000T0o:0@0P0000080?bP40800000
00<0[Jf]0?JL3`3fW0l0103fW0l2000000L0mY`?0P0000050?JL3`030:f][@3/UPh0000000D0k9H>
0P0000050>bF3P040000003/UPh0k9H>0>bF3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1001`3_V102000000<0[Jf]
00<000000?bP403lX1000`3lX102000000H0o:0@00@000000?bP403lX100[Jf]2@3oY142000000X0
oj@A00<0[Jf]0?nV4@3oYQ40403oYQ460:f][@80ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00103oYA000`000000
ojD@0?nU40030?nU408000002`3oYA0300000080ojD@00D0[Jf]0?nS403oXa00oj<@000000070?nS
40800000203oXa000`000000oj<@000000040?nS40030:f][@3lX100o:0@008000001@2][Jd40?bP
40800000203lX102000000030:f][@3fW0l0mY`?00@0mY`?0P0000070?JL3`8000001@3fW0l00`2]
[Jd0k9H>000000050>bF3P8000001@3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]0080fhX=0P2][Jd2
000000L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3P
iP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001@3_V10200000080[Jf]0P3_V1020000
00D0o:0@0P0000060?bP40040000003lX100o:0@0:f][@P0oj@A0P0000070?nT4@050000003oY140
oj@A0?nT4@2][Jd03@3oYQ450:f][@P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA000`000000ojD@0?nU
40020?nU408000002`3oYA02000000040?nU40000000ojD@0:f][@80oj<@0P0000070?nS40800000
203oXa000`000000oj<@000000040?nS40030:f][@3lX100o:0@008000001@3lX1040:f][@800000
00<0[Jf]0?bP403lX1001@3lX102000000030:f][@3fW0l0mY`?00@0mY`?0P0000080?JL3`800000
103fW0l00`2][Jd0k9H>000000050>bF3P8000001P3/UPh010000000k9H>0>bF3P2][Jd20=^:3@80
000000@0[Jf]0000003KRPd000001@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]
04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH
40030:f][@000000kiP@00<0kiP@0P0000050?bP408000001P3lX10010000000o:0@0?bP402][Jd7
0?nT4@030000003oY140000000L0oj@A00D000000?nT4@3oY140oj@A0:f][@080?nV4@D0[Jf]3@3o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU40050?nU40030000003oYA00ojD@0080ojD@0P00000;0?nU4080000000@0
ojD@0000003oYA00[Jf]0P3oXa000`000000oj<@000000060?nS408000002@3oXa02000000@0oj<@
00<0[Jf]0?bP403lX1000P0000090?bP4080000000<0o:0@0:f][@2][Jd0102][Jd0103lX1000000
0000002][Jd70?JL3`8000001`3fW0l2000000@0mY`?00<0[Jf]0>bF3P0000001@3/UPh2000000H0
k9H>00@000000>bF3P3/UPh0[Jf]0P3KRPd200000080fhX=100000030=^:3@030:f][@2iM@/0^GD;
00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd8
0=>73P030:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH40000000103_V102000000D0o:0@0P000006
0?bP40040000003lX100o:0@0:f][@H0oj@A00<000000?nT4@000000203oY1401@000000oj@A0?nT
4@3oY140[Jf]0080ojHA1P2][JdB0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@00<000000?nU403oYA00
0P3oYA02000000/0ojD@0P0000020?nU40070000002][Jd0oj<@0?nS40000000oj<@000000070?nS
40800000203oXa000`000000oj<@0?nS40030?nS40040:f][@3lX100o:0@0?bP40800000203lX102
000000L0o:0@00<0[Jf]0000000000000P2][Jd60?JL3`8000001`3fW0l2000000@0mY`?00@0[Jf]
0>bF3P0000000000103/UPh00`000000k9H>0>bF3P080>bF3P040:f][@3KRPd00000000000<0fhX=
0P0000000`2][Jd0fhX=0=^:3@020=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0
R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0
kiP@000000020>nH4080[Jf]0`3_V1001@000000kiP@0>nH403_V100000000H0o:0@0P0000060?bP
40040000003lX100o:0@0:f][@H0oj@A0P0000090?nT4@030000003oY140oj@A00@0[Jf]603oYQ40
0`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU40050?nU40040000003oYA00ojD@0?nU40800000303oYA0200000080ojD@00<0
00000:f][@3oXa000P3oXa02000000L0oj<@0P0000080?nS40030000003oXa00oj<@00<0oj<@00@0
[Jf]0?bP403lX100o:0@0P0000080?bP40800000203lX102000000030:f][@3fW0l0[Jf]00<0[Jf]
0P3fW0l2000000L0mY`?0P0000040?JL3`040:f][@3/UPh00000000000@0k9H>00<000000>bF3P3/
UPh0203/UPh0102][Jd0fhX=0000000000030=^:3@80000000<0fhX=0:f][@2][Jd00P3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0000000000000P0000050>nH40030000003_V100
kiP@008000001P3lX102000000H0o:0@00@000000?bP403lX100[Jf]1@3oY142000000T0oj@A00H0
[Jf]0000002][Jd0[Jf]0?nT4@2][JdJ0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@00@000000?nU403o
YA00ojD@0P0000090?nU4080000000<0ojD@0000000000000`3oYA001@000000oj<@0?nS403oXa00
000000T0oj<@0P0000060?nS40030000003oXa00oj<@00@0oj<@00@0[Jf]0?bP403lX100o:0@0`00
00070?bP40800000203lX102000000030:f][@3fW0l0mY`?00<0mY`?0P2][Jd2000000L0mY`?0P00
00040?JL3`040:f][@3/UPh00000000000@0k9H>00<000000>bF3P3/UPh0203/UPh0102][Jd0fhX=
0000000000030=^:3@8000000`3KRPd30:f][@030000002iM@/0^GD;00H0^GD;00<0[Jf]08QF1`28
EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;
00<0[Jf]0=>73P3CQ`h01P3CQ`h2000000030:f][@000000000000D0kiP@00<000000>nH403_V100
0P0000060?bP408000001@3lX10200000080o:0@00<0[Jf]0?nT4@3oY1400P3oY1400`000000oj@A
000000050?nT4@@0[Jf]00<0oj@A0000003oY1400P3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@00H0ojD@00<000000?nU403oYA000P00000;0?nU40<000000`3oYA000`2][Jd00000
00000002000000X0oj<@0P0000050?nS40030000003oXa00oj<@00@0oj<@00@0[Jf]0?bP403lX100
o:0@0`0000070?bP40800000203lX102000000030:f][@3fW0l0mY`?00D0mY`?0P0000040:f][@<0
mY`?0P0000040?JL3`040:f][@3/UPh00000000000@0k9H>00<000000>bF3P3/UPh0203/UPh0102]
[Jd0fhX=0000000000040=^:3@030000003KRPd0fhX=0080fhX=0P0000000`2iM@/000000;Ue2`06
0;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<000000>nH403_V1000P0000050>nH40030000003_V100
kiP@008000001P3lX102000000D0o:0@00D000000?bP403lX100o:0@0:f][@030?nT4@030000003o
Y140000000<0oj@A0`2][Jd40?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3o
YQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@00H0ojD@00<000000?nU403oYA000P00000A0?nU40030:f][@3oXa00oj<@00h0oj<@0P00
00020?nS40030000003oXa00oj<@00D0oj<@00@0[Jf]0?bP403lX100o:0@0P0000000`3lX1000000
0?bP40040?bP408000002@3lX102000000030:f][@3fW0l0mY`?00D0mY`?0P0000040?JL3`<0[Jf]
0P0000030?JL3`03045Yh@2][Jd0k9H>00800000103/UPh00`000000k9H>0>bF3P080>bF3P030:f]
[@3KRPd0000000D0fhX=00<000000=^:3@3KRPd00P3KRPd2000000030:f][@000000^GD;00H0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2G
H0/0Uf0;09MP2`2][Jd01P3CQ`h010000000dhL>0:f][@0000030>nH40030000003_V100kiP@00@0
kiP@00<000000>nH400000001`3lX102000000D0o:0@00D000000?bP403lX100o:0@0:f][@020?nT
4@030000003oY140000000@0[Jf]00<0oj@A0000003oY140103oY142000000<0oj@A00<0[Jf]0?nV
4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU40060?nU40030000003oYA00ojD@008000004@3oYA000`2]
[Jd0oj<@0?nS400@0?nS40800000203oXa00102][Jd0o:0@0?bP403lX102000000030?bP40000000
o:0@00@0o:0@0P0000090?bP4080000000<0[Jf]0?JL3`3fW0l01@3fW0l2000000L0mY`?0P000003
0:f][@030?JL3`2][Jd0k9H>00800000103/UPh2000000T0k9H>00<0[Jf]0=^:3@0000001@3KRPd0
0`000000fhX=0=^:3@020=^:3@80000000<0^GD;0:f][@0000001P2iM@/00`2][Jd0R5H708QF1`02
08QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@04
0=>73P8000000P2][Jd00`3CQ`h000000>nH40020>nH40030000003_V100kiP@00@0kiP@0`000007
0?bP408000001@3lX1001`000000o:0@0?bP403lX100[Jf]0?nT4@2][Jd00P0000000`2][Jd0oj@A
0?nT4@030?nT4@030000003oY140oj@A00<0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA001P3oYA000`000000ojD@0?nU400200000140ojD@00<0[Jf]0?nS403oXa00
6P3oXa00102][Jd0o:0@0?bP403lX10200000080o:0@0P0000030?bP408000002@3lX10200000003
0:f][@3fW0l0mY`?00D0mY`?0P0000070?JL3`8000000`3fW0l30:f][@800000103/UPh3000000P0
k9H>00<0[Jf]0=^:3@0000001@3KRPd00`000000fhX=0=^:3@020=^:3@080000002][Jd0^GD;0;Ue
2`000000[Jf]0;Ue2`0000030;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>0`0000020=>73P030000002]
[Jd0kiP@0080kiP@00<000000>nH403_V100103_V103000000L0o:0@0P0000050?bP40030000003l
X100o:0@00<0[Jf]00<0oj@A0000003oY1401@3oY142000000D0oj@A0P0000030?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001P3oYA0010000000ojD@00000000000B0?nU40030:f]
[@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@0P0000040?bP40@000002P3lX10200000003
0:f][@3fW0l0mY`?00D0mY`?0P0000070?JL3`800000103fW0l01@2][Jd0k9H>000000000000[Jf]
00<0k9H>0P0000000`3/UPh00000000000060>bF3P030:f][@3KRPd0000000D0fhX=00<000000=^:
3@3KRPd00P3KRPd030000000[Jf]0;Ue2`2iM@/000000;Ue2`2][Jd000000;Ue2`000000^GD;0:f]
[@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h40000
0080dhL>00<000000:f][@3_V1000P3_V1000`000000kiP@0>nH40040>nH40<000001`3lX1020000
00D0o:0@00D000000:f][@2][Jd0o:0@0:f][@020?nT4@030000003oY140oj@A00@0oj@A0P000005
0?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00L0ojD@0`00000B
0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP4080000000<0
[Jf]0?JL3`3fW0l01@3fW0l2000000L0mY`?0P0000040?JL3`050:f][@3/UPh000000000003/UPh0
0P2][Jd00`3/UPh00000000000030>bF3P<000000`3/UPh00`2][Jd0fhX=000000050=^:3@030000
003KRPd0fhX=0080fhX=00<000000:f][@2iM@/00P2iM@/01`000000^GD;000000000000^GD;0000
002][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>7
3P040000002][Jd0000000000080dhL>00<000000:f][@3_V1000P3_V102000000H0kiP@00<00000
0:f][@3lX1001@3lX102000000@0o:0@0P2][Jd01P000000o:0@0?bP403lX100[Jf]0?nT4@800000
1P3oY142000000D0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
1`3oYA0300000180ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX10200000100
o:0@100000000`2][Jd0mY`?0?JL3`050?JL3`<000001P3fW0l2000000@0mY`?00@0[Jf]0>bF3P00
000000000`3/UPh00`2][Jd00000000000060>bF3P80000000@0k9H>0:f][@3KRPd000001@3KRPd0
0`000000fhX=0=^:3@020=^:3@030000002][Jd0@FWQ0080^GD;00L000000;Ue2`00000000000:f]
[@000000[Jf]00@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0
dhL>0P0000000`3CQ`h00000000000020=>73P030000002][Jd0kiP@0080kiP@0P0000050>nH4080
000000<0[Jf]0?bP403lX100103lX102000000040?bP402][Jd0[Jf]0:f][@80o:0@00L000000?bP
403lX100o:0@0:f][@3oY140000000L0oj@A0P0000050?nT4@8000000`3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][@80ojD@0`00
000B0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP40800000
00<0o:0@0:f][@3fW0l01@3fW0l3000000D0mY`?0`0000040?JL3`040:f][@3/UPh00000000000D0
k9H>00@000000:f][@2][Jd0[Jf]0`3/UPh2000000040>bF3P2][Jd0fhX=000000D0fhX=0P000002
0=^:3@80000000H0[Jf]0;Ue2`2iM@/0^GD;0000002iM@/2000000030;Ue2`2][Jd0000000@0R5H7
0P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`000000[Jf]0P0000000`3CQ`h0
0000000000020=>73P030000002][Jd0kiP@0080kiP@0P0000050>nH4080000000<0[Jf]0?bP403l
X100103lX102000000030:f][@3lX100o:0@00<0o:0@00L000000?bP403lX100o:0@0:f][@3oY140
000000H0oj@A0`0000050?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU40050?nU4080[Jf]00<000000:f][@0000002`2][Jd70?nU40030:f][@3oXa00
oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@0P00000E0?bP40040:f][@3fW0l0mY`?0?JL3`800000
00D0mY`?000000000000mY`?000000040?JL3`80000000<0mY`?0000003fW0l00P3fW0l0102][Jd0
k9H>0000000000050>bF3P040000003/UPh0k9H>0>bF3P80[Jf]00L0k9H>000000000000k9H>0:f]
[@3KRPd0000000D0fhX=0P0000020=^:3@80000000<0[Jf]0;Ue2`2iM@/0102iM@/010000000^GD;
0;Ue2`00000508QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0
00000:f][@3CQ`h2000000040=>73P00000000000=>73P80000000@0[Jf]0>nH403_V100kiP@0P00
00050>nH4080000000<0[Jf]0?bP403lX1000P3lX1020:f][@8000001P3lX1001`000000o:0@0?bP
403lX100[Jf]0?nT4@0000001P3oY1400`000000oj@A000000050?nT4@8000000`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA001`3oYA000`000000ojD@0000000;0?nU40`0[Jf]5@3oXa001011JN40
oj<@0?nS402][Jd30?bP408000005@3lX1000`2][Jd0mY`?0?JL3`030?JL3`<000000P3fW0l01000
0000mY`?0?JL3`3fW0l2000000030?JL3`000000mY`?0080mY`?00<0[Jf]0>bF3P0000001P3/UPh0
0`000000k9H>0>bF3P030>bF3P070:f][@00000000000>bF3P2][Jd0fhX=000000050=^:3@800000
0P3KRPd2000000030=^:3@2][Jd0^GD;00@0^GD;00H000000;Ue2`2iM@/000000:f][@00000308QF
1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/000000:f][@020000
0080dhL>0P0000000`3CQ`h00000000000040>nH408000001@3_V10010000000kiP@0000003lX103
0:f][@80o:0@0P0000060?bP40050000003lX100o:0@0?bP402][Jd00P3oY1400`000000oj@A0?nT
4@020?nT4@040000003oY140oj@A000000D0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@00L0ojD@0P00000C0?nU40030:f][@3oXa00oj<@0080oj<@
2P2][Jd>0?nS40040:f][@3lX100o:0@0?bP408000005@3lX1000`2][Jd0mY`?0?JL3`090?JL3`@0
00000`3fW0l01P000000mY`?0?JL3`2][Jd0k9H>000000H0k9H>00<000000>bF3P3/UPh0103/UPh2
000000<0[Jf]00<000000=^:3@3KRPd00`3KRPd200000080fhX=0P0000000`3KRPd0[Jf]0;Ue2`04
0;Ue2`060000002iM@/0^GD;0000002][Jd000000`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo
001I0;3PiP050:f][@00000000000000002][Jd00P0000020=>73P80000000<0dhL>000000000000
103_V102000000D0kiP@00@000000>nH40000000[Jf]1@3lX102000000H0o:0@00D000000?bP403l
X100o:0@0:f][@030?nT4@030000003oY140oj@A00800000203oY142000000<0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00203oYA000`000000ojD@0?nU400A0?nU
40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS40040:f][@3lX100o:0@0?bP408000005@3lX100
0`2][Jd0mY`?0?JL3`0A0?JL3`050000003fW0l0[Jf]0>bF3P0000001P3/UPh2000000D0k9H>0P00
00001@3/UPh0[Jf]0=^:3@000000[Jf]00@0fhX=0P0000020=^:3@80000000<0fhX=0:f][@2iM@/0
102iM@/01P000000^GD;0;Ue2`000000R5H7000000<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?oo
o`00F@2`h>H01@2][Jd00000000000000000[Jf]008000000P3CQ`h2000000030=>73P0000000000
00@0kiP@0P0000040>nH4080000000<0[Jf]0000003lX1001@3lX102000000H0o:0@00D000000?bP
403lX100o:0@0:f][@040?nT4@8000002P3oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ48
0:f][AP0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@00P0ojD@00<000000?nU403oYA004@3oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]0P00000E
0?bP40030:f][@3fW0l0mY`?0180mY`?00<000000:f][@000000203/UPh00`000000k9H>0>bF3P03
0>bF3P040000003/UPh0k9H>0:f][@80fhX=00<000000:f][@2][Jd00P3KRPd200000080fhX=0P00
00000`3KRPd0[Jf]0;Ue2`070;Ue2`0400000028EPL000000:f][@80R5H700<0[Jf]0;3PiP2`h>H0
@02`h>H10?ooo`00F@2`h>H01@2][Jd00000000000000000[Jf]008000000P3CQ`h00`000000dhL>
0=>73P02000000@0kiP@0P0000030>nH40050:f][@000000kiP@0>nH400000001P3lX102000000H0
o:0@00@000000?bP403lX100[Jf]403oY143000000<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ460:f]
[@<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00203oYA000`000000ojD@0?nU400A0?nU40030:f][@3oXa00oj<@
01X0oj<@00@0[Jf]0?bP403lX100o:0@0P0000050:f][A00o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`000000[Jf]0>bF3P070>bF3P800000103/UPh010000000k9H>0>bF3P2][Jd20=^:3@030000003K
RPd0fhX=0080[Jf]0P0000020=^:3@80000000<0fhX=0:f][@2iM@/01`2iM@/01`000000R5H708QF
1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H01@2][Jd0000009MP2`000000[Jf]0080
00000P3CQ`h00`000000dhL>0=>73P02000000@0kiP@0P0000001@3_V100[Jf]0:f][@3_V1000000
0080kiP@00<0[Jf]0000003lX100103lX102000000H0o:0@00@000000?bP403lX100[Jf]403oY143
000000<0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP408000001@3lX1060:f][@X0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P060>bF3P800000103/UPh010000000k9H>0>bF
3P2][Jd20=^:3@030000003KRPd0fhX=0080fhX=0P0000020=^:3@@00000202iM@/01`000000R5H7
08QF1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F02`h>H01`000000[Jf]0000002GH0/00000
0:f][@0000000`3CQ`h00`000000dhL>0=>73P02000000@0kiP@00<000000:f][@2][Jd00`3_V100
1@000000kiP@0>nH402][Jd0000000D0o:0@0P0000040?bP408000000`3lX1000`2][Jd0oj@A0?nT
4@0>0?nT4@<000000`3oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP408000002`3lX1070:f][@<0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P030000003/UPh0k9H>0080
k9H>00@000000>bF3P3/UPh0[Jf]0P3KRPd00`000000fhX=0=^:3@020=^:3@8000000P2][Jd20000
00040=^:3@2][Jd00000000000H0^GD;00<0000008QF1`28EPL00P28EPL20:f][D80/>3V0@3oool0
05P0/>3V0`000000102GH0/000000:f][@0000030=>73P030000003CQ`h0dhL>008000000`3_V102
000000@0kiP@0P0000020>nH40030:f][@000000o:0@00@0o:0@0P0000090?bP40030:f][@3oY140
oj@A00h0oj@A0`0000020?nT4@D0[Jf]5P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF
3P080>bF3P040000003/UPh0k9H>000000<0k9H>00@0[Jf]0=^:3@3KRPd000001@3KRPd00`000000
fhX=0=^:3@02000000050=^:3@2][Jd0^GD;0;Ue2`000000102iM@/2000000D0R5H700<0[Jf]0;3P
iP2`h>H0@02`h>H10?ooo`00F02`h>H30000000409MP2`000000[Jf]000000<0dhL>00<000000=>7
3P3CQ`h00P0000000`3_V100[Jf]0:f][@02000000@0kiP@00H000000>nH403_V100kiP@0:f][@00
00050?bP408000002@3lX1000`2][Jd0oj@A0?nT4@0>0?nT4@<000000P2][Jd00`3oY140[Jf]0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd000000000
003lX102000001<0o:0@00<000000?bP402][Jd00P3fW0l40:f][A00mY`?00<0[Jf]0>bF3P3/UPh0
2@3/UPh2000000@0k9H>00D0[Jf]0=^:3@3KRPd0fhX=000000040=^:3@040000003KRPd0fhX=0=^:
3@80000000@0[Jf]0;Ue2`2iM@/00000102iM@/2000000030:f][@28EPL0R5H70080R5H70P2][Je1
0;3PiP40oooo001G0;3PiP@0000000@0Uf0;0000002][Jd000000`3CQ`h00`000000dhL>0=>73P02
000000030:f][@3_V100kiP@00800000103_V1001`000000kiP@0>nH403_V100[Jf]0?bP40000000
0P3lX102000000/0o:0@00<0[Jf]0?nT4@3oY1402`3oY1430:f][@<000000`3oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400300000180o:0@0P0000000`3lX100[Jf]0?JL3`050?JL3`D0[Jf]2`3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P050:f][@3KRPd0fhX=0=^:3@000000103KRPd010000000fhX=0=^:3@3KRPd20000
0080[Jf]00<0^GD;0000002iM@/00P2iM@/010000000^GD;0000002][Jd408QF1`80[Jf]@@2`h>H1
0?ooo`00E`2`h>H40000000409MP2`000000[Jf]000000<0dhL>00<000000=>73P3CQ`h00P000003
0>nH40800000103_V1001P000000kiP@0>nH403_V100[Jf]0?bP408000003P3lX1000`2][Jd0oj@A
0?nT4@070?nT4@@0[Jf]0`3oY143000000<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX10010000000o:0@
0000002][Jd;0?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P040:f][@3KRPd0fhX=0=^:
3@8000000P3KRPd2000000<0fhX=0P000000102][Jd0^GD;0:f][@0000030;Ue2`040000002iM@/0
00000:f][@@0R5H70P2][Je10;3PiP40oooo001G0;3PiP@0000000@0Uf0;0000002][Jd000000`3C
Q`h00`000000dhL>0:f][@02000000<0kiP@0P0000030>nH408000000P3_V10300000100o:0@00<0
[Jf]0?nT4@3oY1400`3oY1440:f][@L0oj@A00<000000?nT4@0000000`3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400E0?bP4080000000<0o:0@0:f][@3fW0l03`3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh01@2][Jd0fhX=0=^:3@3KRPd000000080fhX=0P0000030=^:3@80000000/0[Jf]0;Ue2`2iM@/0
00000:f][@2iM@/000000;Ue2`000000^GD;0:f][@0408QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H4
0000000409MP2`000000[Jf]000000<0dhL>00<000000:f][@3CQ`h00P0000020>nH40800000103_
V1000`000000kiP@000000020>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd00`2]
[Jd;0?nT4@800000103oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400F0?bP40030000003lX100[Jf]01@0mY`?102]
[JdA0>bF3P030:f][@3KRPd0fhX=0080fhX=0P0000000`3KRPd000000=^:3@020=^:3@80000000H0
[Jf]0;Ue2`2iM@/000000;Ue2`2][Jd200000080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40
/>3V0@3oool005L0/>3V1P0000001P2][Jd000000=>73P3CQ`h0[Jf]00000080dhL>0P0000020>nH
40800000103_V102000000<0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][A00oj@A00<000000?nT
4@3oY1400P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@000000103KRPd20000
0080^GD;00@000000;Ue2`2iM@/000000`2iM@/00`2][Jd0R5H70000000208QF1`80[Jf]@@2`h>H1
0?ooo`00E`2`h>H50000000709MP2`2][Jd000000=>73P2][Jd0dhL>000000020=>73P8000000P3_
V102000000<0kiP@00<000000>nH403_V1000`3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0
o:0@0:f][@3oY140403oY1400`000000oj@A0?nT4@020?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:
3@050=^:3@030000003KRPd0fhX=0080fhX=0P0000020;Ue2`040000002iM@/0^GD;00000080[Jf]
00@0^GD;0:f][@28EPL000000P28EPL20:f][D40/>3V0@3oool005L0/>3V1@0000001@2GH0/0[Jf]
0000002][Jd0dhL>008000000`3CQ`h4000000X0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd00`000000
fhX=0=^:3@030=^:3@040000002iM@/0^GD;00000080^GD;00<000000;Ue2`2iM@/00P2][Jd01028
EPL0000008QF1`28EPL20:f][D40/>3V0@3oool005L0/>3V1@0000000`2GH0/0[Jf]000000020=>7
3P8000000`3CQ`h3000000/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]0?nT
4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF
3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd00`000000fhX=0=^:3@030=^:
3@040000002iM@/0^GD;00000080^GD;00L000000;Ue2`2iM@/0^GD;00000028EPL000000080R5H7
0P2][Je10;3PiP40oooo001G0;3PiPD0000000<0Uf0;0:f][@0000000P3CQ`h2000000<0dhL>00<0
[Jf]0000003_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:
3@050=^:3@030000003KRPd0fhX=00<0fhX=00@0[Jf]0000002iM@/000000P2iM@/01`000000^GD;
0;Ue2`2iM@/000000:f][@0000000P28EPL20:f][D40/>3V0@3oool005L0/>3V00<000000:f][@00
00000P0000020:f][@030000003CQ`h0dhL>008000000P3CQ`h00`2][Jd0kiP@0>nH400<0>nH4004
0:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f]
[@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00H0fhX=0P0000050=^:
3@030:f][@000000^GD;0080^GD;00L000000;Ue2`2iM@/0^GD;0000002][Jd000000080R5H70P2]
[Je10;3PiP40oooo001G0;3PiP050000002][Jd0000009MP2`0000000P2][Jd00`000000dhL>0=>7
3P0200000080dhL>00<0[Jf]0>nH403_V100303_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]
CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>0`2][Jd60=^:3@8000001@3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`060000
002iM@/0^GD;00000028EPL000000P28EPL20:f][D40/>3V0@3oool005H0/>3V00P000000;3PiP2]
[Jd0000009MP2`000000Uf0;0:f][@80000000<0dhL>0000000000000P3CQ`h00`2][Jd0kiP@0>nH
400;0>nH40<0[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0[Jf]0:f][@@0fhX=
0P0000050=^:3@030:f][@2iM@/0^GD;00<0^GD;00H000000;Ue2`2iM@/0000008QF1`00000208QF
1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000060:f][@000000[Jf]0000002GH0/0[Jf]1@000002
0=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:
0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0
fhX=0=^:3@80[Jf]0P3KRPd2000000D0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/020000000^GD;0000
00000000R5H70000002][Jd0R5H70P2][Je10;3PiP40oooo001F0;3PiP80000000H0[Jf]0000002]
[Jd0000009MP2`2][Jd500000080dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE
0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd00`3KRPd20:f][@8000001@3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`070000002iM@/0
000000000028EPL0000008QF1`030:f][D40/>3V0@3oool005H0/>3V0P0000002@2][Jd0000009MP
2`000000Uf0;0:f][@3CQ`h000000=>73P0200000080dhL>00<0[Jf]0>nH403_V1001@3_V1020:f]
[@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd2000000D0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/30000
000308QF1`000000R5H700<0[Jf]@@2`h>H10?ooo`00EP2`h>H2000000060:f][@000000Uf0;0000
002GH0/0[Jf]0`3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00D0kiP@0P2][Jd70>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`
h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00D0fhX=0P0000020:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`000000R5H70000
000208QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000060:f][@000000Uf0;0000002GH0/0[Jf]
0`3CQ`h01@000000dhL>0=>73P3CQ`h0[Jf]00<0kiP@0P2][Jd90>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP
40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:
3@8000000P3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;00@0[Jf]000000000000R5H70P2][Je1
0;3PiP40oooo001F0;3PiP80000000D0[Jf]0000002GH0/000000:f][@040=>73P060000003CQ`h0
dhL>0=>73P2][Jd0kiP@0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
4@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
1@3KRPd2000000@0fhX=0P2][Jd90;Ue2`040:f][@000000000008QF1`80[Jf]@@2`h>H10?ooo`00
EP2`h>H2000000050:f][@00000000000000002][Jd0103CQ`h010000000dhL>0=>73P3CQ`h20:f]
[@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f]
[A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@<000001@3KRPd30:f]
[@L0^GD;00@0[Jf]000000000000R5H70P2][Je10;3PiP40oooo001F0;3PiP80000000D0[Jf]0000
00000000Uf0;0:f][@040=>73P030000003CQ`h0dhL>0080[Jf]3P3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P0000050=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00@0
[Jf]000000000000R5H70P2][Je10;3PiP40oooo001F0;3PiP040000002][Jd0[Jf]00000080Uf0;
00<0[Jf]0=>73P3CQ`h00P3CQ`h01@000000[Jf]0:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403l
X100403lX1000`2][Jd0oj@A0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/0102]
[Jd0000000000028EPL20:f][D40/>3V0@3oool005H0/>3V00@000000:f][@00000000000P2GH0/0
0`2][Jd0dhL>0=>73P020=>73P050000003CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP
400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Jd30;Ue2`040:f][@00
0000000008QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H00`000000[Jf]0000000309MP2`060:f][@3C
Q`h0dhL>0=>73P2][Jd000000`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0
o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0
^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0P0000000`28EPL0[Jf]0:f][@110;3PiP40oooo001F0;3PiP03
0000002][Jd0[Jf]00<0Uf0;00H0[Jf]0=>73P2][Jd0[Jf]0=>73P0000030=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@80000000<0R5H70:f][@2][Jd0@@2`h>H1
0?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`80[Jf]0`3CQ`h01@000000dhL>0=>73P3CQ`h0
[Jf]00d0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk
0:f][@2][Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0
[Jf]0000000000000P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP800000102GH0/0
0`2][Jd0dhL>0=>73P020=>73P050000003CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP
40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0000000000000P28EPL00`2][Jd0/>3V0;3P
iP0o0;3PiP40oooo001F0;3PiP8000000`2GH0/20:f][@<0dhL>0P0000030=>73P030:f][@3_V100
kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^
0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@00000000000080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H20000
00<0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f]
[@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m
^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@00000000000080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H200000080
Uf0;00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080
[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@00000000000080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00
EP2`h>H20000000509MP2`2][Jd0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0
[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0
[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`000000[Jf]08QF1`2][Je10;3PiP40oooo001F0;3P
iP80000000D0Uf0;0:f][@2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<
0<K0_0030:f][@33_K/0`kfk00h0`kfk00D0[Jf]0;ji^02n^KP0_[Vh045Yh@050;ji^080[Jf]2@3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0000008QF1`80[Jf]@@2`h>H10?ooo`00E@2`
h>H3000000050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40060>nH40@0[Jf]
2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jg80;3PiP@0[Jf]
4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`040:f][@2n^KP0@FWQ045Yh@H0_[Vh102][Jd70=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`000000R5H70P2][Je10;3PiP40oooo001E0;3PiP<0
000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102T
WXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?
0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`<0@FWQ1@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]
08QF1`28EPL00P28EPL20:f][D00/>3V0@3oool005D0/>3V0`00000409MP2`030:f][@3CQ`h0dhL>
00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd01@2TWXl0@FWQ045Yh@2TWXl0[Jf]00@0/J^M0P2]
[Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh045Yh@030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f][@2][Jd30=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D00/>3V0@3oool005D0/>3V0`00
000309MP2`030:f][@3CQ`h0dhL>00L0dhL>00@0[Jf]0>nH402][Jd0[Jf]0`2TWXl3045Yh@030:f]
[@2aZid0/J^M00@0/J^M0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0@FWQ0;ji^080[Jf]1`2n^KP2045Yh@80
];2a00D0@FWQ0:f][@2][Jd0fhX=0:f][@0:0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H1
0?ooo`00E@2`h>H3000000<0Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@030:BNS`11JN40Y9j?
0080Y9j?0P11JN400`2TWXl0[Jf]0;6[W@070;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh045Yh@2][Jd7
0;ji^0<0@FWQ00@0[Jf]0;B`/@2d/;40@FWQ0P2d/;420:f][@X0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001E0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@11
JN40Y9j?0:BNS`80@FWQ0P2TWXl2045Yh@030:BNS`2][Jd0/J^M00T0/J^M0P2][Jd00`2aZid0[Jf]
0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V
1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0<0<>m^`<0[Jf]00<0@FWQ0;ji^02n^KP01`2n^KP2045Yh@040:f][@2d/;40];2a045Yh@<0
];2a00<0@FWQ0:f][@2][Jd0202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0
/>3V0`00000309MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd2045Yh@80Y9j?0P11JN420:BNS`80
@FWQ00<0Y9j?0:f][@2aZid02`2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd01033
_K/0[Jf]0;ji^011JN490;ji^080@FWQ00@0[Jf]0;B`/@2d/;40@FWQ0`2d/;42045Yh@030;B`/@2]
[Jd0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP80000000D0
[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P<0[Jf]0P11JN420:BNS`80@FWQ0P2TWXl2045Yh@030:f]
[@2aZid0/J^M00<0/J^M1011JN450;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V
1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`060<>m^`<0[Jf]1033_K/0102][Jd0_[Vh045Yh@2n^KP2045Yh@H0_[Vh0P11JN40102n^KP0
[Jf]0;B`/@11JN440;B`/@03045Yh@2d/;40@FWQ0080[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL2
0:f][D00/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00@0[Jf]
08Z5M@2:QGD0[Jf]0P11JN420:BNS`80@FWQ0P2TWXl2045Yh@030:f][@2aZid0/J^M00<0/J^M0P11
JN400`2aZid0@FWQ0;6[W@040;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`
h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk0080`kfk102][Jd70<>m^`040:f][@2n^KP0@FWQ045Yh@80_[Vh0P11JN440;ji^080@FWQ
00D0_[Vh0:f][@2d/;40];2a045Yh@030;B`/@04045Yh@2d/;40@FWQ045Yh@<0[Jf]0`2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/01@2]
[Jd0dhL>0=>73P3CQ`h0[Jf]00<0RXEe00<0[Jf]045Yh@11JN400`2TWXl00`11JN40Y9j?0:BNS`02
045Yh@030:f][@2aZid0/J^M00<0/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@020;6[W@03045Yh@2a
Zid0[Jf]00P0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00@0[Jf]0;ji^011JN40@FWQ0P2n^KP00`11JN40_[Vh
045Yh@030;ji^080@FWQ00D0_[Vh0:f][@2d/;40];2a045Yh@030;B`/@08045Yh@2][Jd0];2a045Y
h@2][Jd0Wi^P045Yh@2][Jd20;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`
h>H00`000000/>3V0:f][@0309MP2`040:f][@3CQ`h0[Jf]0:f][@@0RXEe00@0[Jf]045Yh@2TWXl0
[Jf]0P2TWXl00`11JN40Y9j?0:BNS`02045Yh@030:f][@2aZid0/J^M00<0/J^M00L0@FWQ0;6[W@2a
Zid0/J^M045Yh@2aZid0@FWQ0080/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0
_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@d0`kfk00<0@FWQ0:f][@2n^KP00P11JN43
0;ji^080@FWQ0`2n^KP2045Yh@050;ji^02][Jd0];2a0;B`/@11JN400P2d/;402@2][Jd0@FWQ0;B`
/@2d/;40@FWQ0:f][@2OVj00@FWQ09nKX0030:f][@@0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?oo
o`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]1P2:QGD0102][Jd0@FWQ0:BNS`2TWXl20:f]
[@06045Yh@2TWXl0Y9j?045Yh@2TWXl0[Jf]1@2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ0P2a
Zid0102][Jd0^K:V0;VbYP11JN4<0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]
2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02@33_K/02011JN40`kfk
0<>m^`11JN40`kfk0:f][@2n^KP0@FWQ102n^KP2045Yh@<0_[Vh0P11JN401@2n^KP0[Jf]0;B`/@2d
/;40@FWQ0080[Jf]00@0];2a045Yh@2d/;40];2a0`11JN4409nKX0030:f][@28EPL0R5H70080R5H7
00<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@2:
QGD0RXEe00D0RXEe00<0[Jf]045Yh@2TWXl00`2TWXl01P11JN40[Jf]0:BNS`11JN40Y9j?0:f][@D0
/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@80/J^M00@0[Jf]0;VbYP2i/ZH0@FWQ3@2i/ZH00`2]
[Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m
^`33_K/01P33_K/2045Yh@080<>m^`11JN40`kfk045Yh@33_K/0[Jf]0;ji^011JN450;ji^080@FWQ
0P2n^KP2045Yh@050;ji^02][Jd0];2a0;B`/@11JN400`2d/;400`11JN40];2a0;B`/@02045Yh@H0
Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP
2`80[Jf]1`2:QGD00`2][Jd0@FWQ0:BNS`020:BNS`80@FWQ00D0Y9j?0:f][@11JN40Y9j?0:f][@05
0;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN420;6[W@040:f][@2i/ZH0^K:V045Yh@@0^K:V00<0
@FWQ0;VbYP2i/ZH01P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j
/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0
_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`050<>m^`04045Yh@33_K/0`kfk0<>m^`<0@FWQ
0P33_K/00`2][Jd0@FWQ045Yh@040;ji^080@FWQ0P2n^KP2045Yh@050;ji^02][Jd0[Jf]0:f][@11
JN400`2d/;401@11JN40];2a0;B`/@2d/;40[Jf]00H0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@10
0;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`2:QGD00`2][Jd0@FWQ0:BNS`02
0:BNS`80@FWQ0P2TWXl00`11JN40[Jf]0:f][@050;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN42
0;6[W@040:f][@2i/ZH0@FWQ045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH01P2i/ZH00`2][Jd0_[N/0;jg
[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0:f][@030:f][@d0a/2l00<0[Jf]0<>m^`33_K/01033
_K/2045Yh@@0`kfk0P11JN420<>m^`030:f][@11JN40@FWQ00@0_[Vh0P11JN420;ji^080@FWQ0P2]
[Jd20;B`/@05045Yh@2d/;40];2a0;B`/@11JN400`2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f]
[@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00`2][Jd708Z5M@030:f]
[@11JN40Y9j?0080Y9j?0P11JN420:BNS`80@FWQ0P2][Jd40;6[W@03045Yh@2aZid0/J^M0080/J^M
0P11JN420;6[W@040:f][@2i/ZH0@FWQ045Yh@@0^K:V00<0@FWQ0;VbYP2i/ZH01P2i/ZH00`2][Jd0
_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004031^[03045YhAD0`kfc00<0[Jf]0<Fn]@35
_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`03`37`K`40:f][@l0a/2l0P11JN400`2][Jd0`kfk0<>m^`040<>m^`80@FWQ1033_K/2045Yh@80
`kfk00<0[Jf]045Yh@11JN40102n^KP2045Yh@80_[Vh0P11JN401@2n^KP0[Jf]0;B`/@2d/;40@FWQ
00<0];2a00D0@FWQ0;B`/@2d/;40];2a0:f][@0709nKX080[Jf]00<0R5H70:f][@2`h>H0?`2`h>H1
0?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]045Yh@11JN400`2TWXl2
045Yh@80Y9j?0P11JN40102][Jd0/J^M0:f][@2][Jd30;6[W@05045Yh@2aZid0/J^M0;6[W@11JN40
0`2aZid00`2][Jd0^K:V045Yh@02045Yh@80^K:V0P11JN480;VbYP040:f][@2n]j`0@FWQ045Yh@h0
_[N/102][JdA0<6j/0@0@FWQ4P33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0
a/2l0<K0_00;0<K0_0<0@FWQ0P36`;`00`2][Jd0`kfk0<>m^`040<>m^`80@FWQ1033_K/2045Yh@80
`kfk00<0[Jf]045Yh@11JN40102n^KP2045Yh@80[Jf]0P11JN400`2n^KP0[Jf]0;B`/@02045Yh@80
];2a00<0@FWQ0;B`/@2d/;400P2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0[Jf]0:f]
[D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]045Yh@11
JN400`2TWXl2045Yh@80Y9j?0P11JN40102][Jd0/J^M045Yh@2aZid30:f][@050;6[W@11JN40/J^M
0;6[W@11JN400`2aZid00`2][Jd0^K:V045Yh@02045Yh@80^K:V0P11JN480;VbYP80@FWQ0P2n]j`0
1011JN40_[N/045Yh@11JN4;0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[02045YhA@0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`01P36`;`2045Yh@D0a/2l00@0
@FWQ0<K0_036`;`0[Jf]1P33_K/2045Yh@@0`kfk0P11JN420<>m^`030:f][@11JN40@FWQ00<0_[Vh
00<0[Jf]045Yh@2][Jd00`2n^KP2045Yh@040:f][@2d/;40@FWQ045Yh@L0];2a00<0[Jf]09nKX02O
Vj00102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]
1@2:QGD00`2][Jd0@FWQ045Yh@030:BNS`04045Yh@2TWXl0@FWQ0:BNS`80@FWQ00<0[Jf]045Yh@11
JN40102aZid20:f][@03045Yh@2aZid0@FWQ00<0/J^M00D0[Jf]0;VbYP11JN40^K:V045Yh@020;Vb
YP<0@FWQ1P2i/ZH00`11JN40[Jf]0;jg[0030;jg[0<0@FWQ0`2n]j`2045Yh@H0_[N/00<0[Jf]0<6j
/031^[001@31^[050:f][@L0`KZ`0P11JN4D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2]
[Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l0080@FWQ1@36`;`01011JN40a/2l0<K0_02][Jd6
0<>m^`80@FWQ1033_K/2045Yh@80`kfk00@0[Jf]045Yh@11JN40_[Vh0P2][Jd00`2n^KP0@FWQ0;ji
^0030;ji^080@FWQ00<0[Jf]045Yh@11JN40202d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2O
Vj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]
08Z5M@2][Jd0102:QGD00`2][Jd0@FWQ045Yh@030:BNS`03045Yh@2TWXl0Y9j?00<0@FWQ00<0[Jf]
045Yh@11JN400`2aZid01011JN40/J^M0;6[W@2][Jd2045Yh@<0/J^M00D0[Jf]045Yh@11JN40^K:V
045Yh@020;VbYP03045Yh@2i/ZH0@FWQ00D0^K:V0P11JN450;jg[0<0@FWQ1@2n]j`3045Yh@<0_[N/
00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`0P11JN4D0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`00`2][Jd0a/2l
0<K0_0020<K0_003045Yh@36`;`0@FWQ00<0@FWQ1@36`;`01011JN40a/2l0<K0_02][Jd60<>m^`80
@FWQ1033_K/2045Yh@80`kfk00@0[Jf]045Yh@11JN40[Jf]0`2n^KP00`11JN40_[Vh0;ji^0020;ji
^0@0@FWQ2@2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo
0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0`2:QGD0
0`2][Jd0@FWQ045Yh@030:BNS`03045Yh@2TWXl0Y9j?00<0Y9j?0`11JN430;6[W@03045Yh@2aZid0
/J^M0080/J^M00D0@FWQ0:f][@2][Jd0/J^M0:f][@02045Yh@070;VbYP11JN40^K:V0;VbYP11JN40
^K:V045Yh@050;VbYP03045Yh@2][Jd0_[N/00D0_[N/0P11JN450;jg[003045Yh@2n]j`0_[N/00<0
_[N/00<0[Jf]0<6j/031^[003`31^[020:f][@80@FWQ102][Jd@0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0
al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l0080@FWQ0`36`;`3045Yh@D0a/2l00@0@FWQ0<K0_036
`;`0[Jf]1`33_K/00`11JN40`kfk0<>m^`030<>m^`04045Yh@33_K/0[Jf]0:f][@80@FWQ102n^KP0
0`11JN40_[Vh0;ji^0020;ji^080@FWQ00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P09nKX002
0:f][@<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C
0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@030:f][@11JN40@FWQ0080Y9j?0P11JN45
0:BNS`030:f][@11JN40/J^M00<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`11JN40/J^M0;6[W@02
0:f][@80@FWQ00<0^K:V045Yh@2i/ZH00P11JN400`2i/ZH0@FWQ0;VbYP040;VbYP03045Yh@2][Jd0
_[N/00D0_[N/0P11JN450;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0[Jf]0<6j/031^[004@31^[02
045Yh@@0`kfc2`2][Jd50<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0
102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`02@37`K`00`11JN40al6l0<O1
_0050<O1_0040:f][@36`;`0@FWQ045Yh@D0a/2l0P11JN450<K0_004045Yh@36`;`0a/2l0:f][@L0
`kfk1`11JN400`2][Jd0`kfk0:f][@02045Yh@<0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP2045Yh@03
0:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f]
[@2:QGD0@FWQ0080@FWQ0P2TWXl2045Yh@D0Y9j?00<0[Jf]0;6[W@2aZid00`2aZid00`11JN40/J^M
0;6[W@020;6[W@05045Yh@2aZid0/J^M0;6[W@2][Jd00P11JN400`2][Jd0@FWQ0;VbYP02045Yh@03
0;VbYP11JN40^K:V00@0^K:V00<0@FWQ0:f][@2n]j`01@2n]j`00`11JN40_[N/0;jg[0040;jg[003
045Yh@2n]j`0_[N/00<0_[N/00<0[Jf]0<6j/031^[001@31^[03045Yh@T0`KZ`0P11JN4?0<>m/`/0
[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0030<O1_003
045Yh@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01@37`K`00`2][Jd0a/2l045Yh@060<K0_080
@FWQ1@36`;`01011JN40a/2l0<K0_02][Jd90<>m^`<0[Jf]0P11JN420<>m^`030:f][@11JN40@FWQ
00<0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP2045Yh@030:f][@2d/;40];2a00@0];2a00@0@FWQ0;B`
/@2d/;40];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2]
[Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd2045Yh@80Y9j?00<0@FWQ0:BN
S`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@030;6[W@03045Yh@2aZid0/J^M0080/J^M00D0@FWQ0;6[
W@2aZid0/J^M0:f][@02045Yh@070;VbYP11JN40[Jf]045Yh@2][Jd0^K:V045Yh@040;VbYP80@FWQ
00<0[Jf]0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00<0_[N/
00<0[Jf]0<6j/031^[000`31^[02045Yh@<0`KZ`00<0@FWQ0<6j/031^[000P31^[001011JN40`KZ`
0<6j/031^[02045YhA@0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`11JN40al6l0<O1_0030<O1_003
045Yh@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01@37`K`00`2][Jd0@FWQ045Yh@060<K0_080
@FWQ1@36`;`01011JN40a/2l0<K0_02][Jd70<>m^`80[Jf]1033_K/01011JN40`kfk0<>m^`2][Jd3
045Yh@030;ji^011JN40_[Vh00D0_[Vh0P11JN400`2][Jd0];2a0;B`/@040;B`/@05045Yh@2d/;40
];2a0;B`/@2][Jd01`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00<0@FWQ1P2T
WXl00`2][Jd0/J^M0;6[W@040;6[W@@0@FWQ102aZid00`2][Jd0@FWQ0;VbYP020;VbYP80@FWQ00<0
^K:V0:f][@11JN400P2][Jd20;VbYP80@FWQ00<0[Jf]0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg
[0040;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]0<6j/031^[000`31^[02045Yh@D0`KZ`00@0
@FWQ0<6j/011JN40@FWQ1031^[02045Yh@80`kfc00<0@FWQ0<>m/`33_K<03`33_K<00`2][Jd0aKje
0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j
4@2][JdA0<S1^`030:f][@38`K/0b<6k00d0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`11JN40[Jf]
0<O1_0040<O1_003045Yh@37`K`0al6l00<0al6l0P11JN460<O1_0030:f][@11JN40a/2l00H0a/2l
0P11JN450<K0_004045Yh@36`;`0a/2l0:f][@@0`kfk0`2][Jd60<>m^`04045Yh@33_K/0`kfk0:f]
[@80@FWQ00<0_[Vh045Yh@11JN401P2n^KP2045Yh@030:f][@2d/;40];2a00@0];2a00<0@FWQ0;B`
/@2][Jd00P2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2]
[Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
045Yh@2i/ZH00P2i/ZH2045Yh@80^K:V00<0@FWQ0;VbYP2i/ZH00P2][Jd2045Yh@030:f][@2n]j`0
_[N/00@0_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0020;jg[0030:f][@31^[00
`KZ`00<0`KZ`0P11JN450<6j/0<0@FWQ1@31^[04045Yh@030<>m/`11JN40`kfc00l0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00X0b<6k0`11JN401`38`K/0@FWQ0<S1^`38`K/0@FWQ0<S1^`2][Jd0
1@37`K`2045Yh@@0al6l0P11JN460<O1_0030:f][@11JN40a/2l00H0a/2l0P11JN450<K0_080@FWQ
00<0a/2l0:f][@33_K/00`2][Jd30<>m^`03045Yh@33_K/0`kfk00<0`kfk00@0@FWQ0<>m^`33_K/0
[Jf]0P11JN490;ji^080@FWQ00<0[Jf]0;B`/@2d/;401@2d/;40102][Jd0];2a0;B`/@2][Jd709nK
X0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0
[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd70:BNS`030:f][@2aZid0/J^M00/0/J^M00<0@FWQ
0:f][@11JN400`2i/ZH2045Yh@<0^K:V00@0@FWQ0;VbYP2i/ZH0^K:V0P11JN420:f][@<0_[N/0`11
JN460;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]0<6j/031^[000`31^[02045Yh@H0`KZ`0P11
JN450<6j/080@FWQ1033_K<2045Yh@H0`kfc1`11JN400`33_K<0[Jf]0<Fn]@0E0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01<0b<6k0`11JN490<S1^`<0@FWQ1038`K/3045Yh@030<S1^`2][Jd0al6l00@0al6l0P11
JN430<O1_0<0@FWQ1P37`K`00`2][Jd0@FWQ0<K0_0060<K0_0@0@FWQ0`36`;`2045Yh@<0[Jf]1P33
_K/00`11JN40`kfk0<>m^`020<>m^`04045Yh@33_K/0`kfk0<>m^`80@FWQ2P2n^KP2045Yh@030:f]
[@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0
L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2T
WXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f][@2aZid0/J^M00`0/J^M0P11JN430;VbYP03
045Yh@2i/ZH0^K:V0080^K:V00P0@FWQ0;VbYP2i/ZH0^K:V045Yh@2i/ZH0[Jf]0;jg[0@0[Jf]00@0
_[N/045Yh@11JN40@FWQ0`2n]j`2045Yh@@0_[N/00<0[Jf]0<6j/031^[000`31^[02045Yh@H0`KZ`
0P11JN450<6j/080@FWQ1@33_K<2045Yh@P0`kfc00<0@FWQ0<>m/`33_K<00P33_K<00`2][Jd0@FWQ
045Yh@04045YhA00aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/4045Yh@030<S1^`2][Jd0b<6k00T0b<6k
00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l00<0@FWQ0<O1_011JN40
0`37`K`3045Yh@H0al6l0P11JN450<K0_0@0@FWQ00<0a/2l0:f][@2][Jd00P2][Jd2045Yh@050<K0
_02][Jd0`kfk0<>m^`11JN401033_K/01@11JN40`kfk0<>m^`33_K/0@FWQ00@0`kfk00<0[Jf]0;ji
^02n^KP02@2n^KP2045Yh@040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX005
09nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:
QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@060:f][@2i
/ZH0@FWQ045Yh@2i/ZH0@FWQ102i/ZH01`11JN40^K:V0;VbYP2i/ZH0@FWQ0;VbYP2][Jd01@2n]j`4
0:f][@<0_[N/0P11JN440;jg[0030:f][@31^[00`KZ`00<0`KZ`0P11JN460<6j/080@FWQ1@31^[00
0`11JN40`kfc0<>m/`050<>m/`03045Yh@33_K<0`kfc00H0`kfc00<0@FWQ0<>m/`33_K<00P33_K<0
0`2][Jd0aKje0<Fn]@02045Yh@D0aKje1P11JN470<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@11JN40@FWQ00P0@FWQ2@38`K/2
045Yh@030<S1^`2][Jd0b<6k00T0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0
al6l00<0al6l00<0@FWQ0<O1_011JN400`37`K`3045Yh@H0al6l0P11JN460<K0_0@0[Jf]1036`;`2
045Yh@030<K0_02][Jd0`kfk0080@FWQ1@33_K/4045Yh@@0`kfk00<0[Jf]0;ji^02n^KP02@2n^KP2
045Yh@040:f][@2d/;40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^
N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2T
WXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP03045Yh@2i
/ZH0^K:V00<0@FWQ0`2i/ZH00`11JN40^K:V0:f][@090;jg[0<0[Jf]0P11JN440;jg[0030:f][@31
^[00`KZ`00@0`KZ`0P11JN450<6j/080@FWQ1@31^[000`11JN40`kfc0<>m/`050<>m/`80@FWQ1`33
_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@35_[D0aKje0080@FWQ1`35_[D2045Yh@T0aKje0`11
JN490<Jo]`03045Yh@36_kL0a[ng00@0@FWQ1@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00@0[Jf]0<S1^`38`K/0b<6k0P11JN440<S1^`<0@FWQ1`38`K/2045Yh@030<S1
^`2][Jd0b<6k00T0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l
00@0@FWQ0<O1_011JN40@FWQ0P37`K`00`11JN40al6l045Yh@060<O1_080@FWQ00<0a/2l0:f][@2]
[Jd00`2][Jd80<K0_0<0@FWQ00@0[Jf]0<>m^`33_K/0@FWQ3@33_K/00`2][Jd0_[Vh0;ji^0090;ji
^080@FWQ0`2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?oo
o`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd=0;6[W@03
0:f][@2i/ZH0^K:V00P0^K:V0P11JN420;VbYP03045Yh@2i/ZH0[Jf]00`0_[N/0P11JN430:f][@03
0;jg[02][Jd0`KZ`00H0`KZ`00<0@FWQ0<6j/031^[000`31^[02045Yh@D0`KZ`00<0@FWQ0<>m/`33
_K<01@33_K<2045Yh@L0`kfc00<0@FWQ0<>m/`33_K<00P33_K<00`2][Jd0aKje0<Fn]@02045Yh@L0
aKje0P11JN470<Fn]@80@FWQ00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`<0@FWQ1036_kL00`11JN40
a[ng0<Jo]`020<Jo]`040:f][@37`KP0al6h045YhA<0al6h00<0[Jf]0<O1^P37`KX05@37`KX0102]
[Jd0b<6k0<S1^`38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0
b<6k00T0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l0P11JN40
1@37`K`0@FWQ0<O1_037`K`0@FWQ0080al6l00@0@FWQ0<O1_037`K`0al6l0P2][Jd2045Yh@030:f]
[@36`;`0a/2l00/0a/2l0P11JN401@36`;`0@FWQ0<>m^`33_K/0@FWQ00d0`kfk00<0[Jf]0;ji^02n
^KP0202n^KP2045Yh@80[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440
/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@030:f]
[@2i/ZH0^K:V00`0^K:V00<0@FWQ0;VbYP2][Jd0302n]j`3045Yh@80_[N/1@2][Jd50<6j/003045Y
h@31^[00`KZ`0080`KZ`0P11JN450<6j/003045Yh@33_K<0`kfc00H0`kfc0P11JN460<>m/`03045Y
h@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80@FWQ1P35_[D2045Yh@030<Fn
]@2][Jd0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`11JN40a[ng0<Jo]`050<Jo]`09045Y
h@36_kL0a[ng0<Jo]`2][Jd0al6h045Yh@37`KP0@FWQ0180al6h00<0[Jf]0<O1^P37`KX05@37`KX0
102][Jd0b<6k0<S1^`38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@030<S1^`2]
[Jd0b<6k00T0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l0P11
JN402037`K`0@FWQ0<O1_037`K`0@FWQ0<O1_02][Jd0@FWQ0`2][Jd20<O1_080@FWQ3P36`;`2045Y
h@030<K0_02][Jd0@FWQ0080@FWQ3@33_K/00`2][Jd0_[Vh0;ji^0080;ji^080[Jf]00<0_[Vh0:f]
[@2d/;402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`h>H20:f][@L0
RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M00<0[Jf]0;VbYP2i
/ZH0302i/ZH00`11JN40^K:V0:f][@0<0;jg[0<0@FWQ0`2n]j`0102][Jd0`KZ`0<6j/031^[060:f]
[@80@FWQ0P31^[02045Yh@D0`KZ`00<0@FWQ0<>m/`33_K<01P33_K<2045Yh@H0`kfc00<0@FWQ0<>m
/`33_K<00P33_K<00`2][Jd0aKje0<Fn]@02045Yh@L0aKje0P11JN450<Fn]@80@FWQ0P35_[D00`2]
[Jd0a[ng0<Jo]`030<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL01P36_kL01011
JN40a[ng0<Jo]`2][Jd20<O1^003045Yh@37`KP0al6h0140al6h00<0[Jf]0<O1^P37`KX05@37`KX0
102][Jd0b<6k0<S1^`38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@030<S1^`2]
[Jd0b<6k00T0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@030<S1^`2][Jd0al6l00<0al6l0P11
JN402037`K`0@FWQ0:f][@2][Jd0@FWQ0:f][@37`K`0@FWQ1@37`K`2045Yh@h0a/2l0P11JN400`36
`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a
00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:
QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@03
0:f][@2i/ZH0^K:V00`0^K:V0P11JN400`2][Jd0_[N/0;jg[00:0;jg[0<0@FWQ0`2n]j`00`2][Jd0
@FWQ0<6j/0080<6j/0030:f][@11JN40@FWQ0080@FWQ0P2][Jd30<6j/003045Yh@33_K<0`kfc00H0
`kfc0P11JN460<>m/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80
@FWQ1@35_[D2045Yh@80aKje00<0[Jf]0<Jo]`36_kL02@36_kL00`11JN40a[ng0<Jo]`060<Jo]`04
045Yh@36_kL0a[ng0:f][AL0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2
045Yh@L0b<6k0P11JN450<S1^`80@FWQ00<0b<6k0:f][@38`K/02P38`K/00`11JN40b<6k0<S1^`04
0<S1^`80@FWQ00@0b<6k0:f][@37`K`0al6l0P2][Jd2045Yh@050:f][@37`K`0@FWQ0<O1_011JN40
0P37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ3036`;`2045Yh@<0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5
M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0
[Jf]0;VbYP2i/ZH0302i/ZH2045Yh@030:f][@2n]j`0_[N/00P0_[N/1011JN40102n]j`0@FWQ0;jg
[02n]j`2045Yh@D0`KZ`0P11JN450<6j/080@FWQ0P31^[030:f][@04045Yh@2][Jd0[Jf]0:f][@D0
`kfc0P11JN460<>m/`03045Yh@33_K<0`kfc0080`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80
@FWQ1035_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL02@36_kL00`11JN40a[ng0<Jo]`060<Jo]`04
045Yh@36_kL0a[ng0:f][AL0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2
045Yh@L0b<6k0P11JN450<S1^`80@FWQ00<0b<6k0:f][@38`K/02`38`K/8045Yh@@0[Jf]0P37`K`2
045Yh@80al6l0`11JN420<O1_003045Yh@37`K`0al6l00<0al6l0P11JN4B0<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0
[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0
RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M
0:f][@2i/ZH03@2i/ZH2045Yh@030:f][@2n]j`0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`2
045Yh@040;jg[011JN40_[N/0;jg[080@FWQ1@31^[02045Yh@D0`KZ`00<0@FWQ0<6j/031^[001031
^[001011JN40`kfc0<>m/`33_K<50:f][@80@FWQ1P33_K<00`11JN40`kfc0<>m/`020<>m/`030:f]
[@35_[D0aKje0080@FWQ1`35_[D2045Yh@@0aKje0P11JN430<Fn]@030:f][@36_kL0a[ng0140a[ng
0P11JN420<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k
0<S1^`38`K/2045Yh@P0b<6k0P11JN440<S1^`80@FWQ00<0b<6k0:f][@38`K/02P38`K/70:f][@80
@FWQ00<0b<6k0:f][@37`K`00P37`K`00`11JN40al6l045Yh@020<O1_080@FWQ1037`K`00`11JN40
al6l0<O1_0020<O1_080@FWQ2036`;`00`11JN40a/2l0<K0_0070<K0_0030:f][@33_K/0`kfk00d0
`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P
0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@03
0:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@h0^K:V0P11JN460;jg[003
045Yh@2n]j`0_[N/00L0_[N/0`11JN460<6j/003045Yh@31^[00`KZ`00@0`KZ`00<0@FWQ0<6j/031
^[001031^[000`11JN40`kfc0<>m/`050<>m/`80@FWQ00<0`kfc0:f][@2][Jd0102][Jd00`11JN40
[Jf]0<>m/`020<>m/`030:f][@35_[D0aKje0080@FWQ1`35_[D2045Yh@@0aKje0P11JN430<Fn]@03
0:f][@36_kL0a[ng00l0a[ng0`11JN430<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2045Yh@P0b<6k0P11JN450<S1^`03045Yh@38`K/0[Jf]
00<0b<6k202][Jd70<S1^`80@FWQ00<0b<6k0:f][@37`K`00P37`K`2045Yh@<0al6l0P11JN440<O1
_0<0@FWQ0P37`K`2045Yh@P0a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0`kfk0<>m^`0<0<>m
^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?oo
o`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@03
0:f][@2i/ZH0[Jf]00<0[Jf]2P2i/ZH2045Yh@H0_[N/00<0@FWQ0;jg[02n]j`02@2n]j`00`2][Jd0
`KZ`0<6j/0050<6j/003045Yh@31^[00`KZ`0080`KZ`00<0@FWQ0<6j/031^[001@31^[02045Yh@H0
`kfc0P11JN470<>m/`03045Yh@33_K<0[Jf]00D0[Jf]0P11JN400`2][Jd0aKje0<Fn]@040<Fn]@80
@FWQ1035_[D2045Yh@<0aKje00<0[Jf]0<Jo]`36_kL03@36_kL4045Yh@@0a[ng00@0[Jf]0<O1^037
`KP0@FWQ5037`KP00`2][Jd0al6j0<O1^P0D0<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ2038`K/2
045Yh@80b<6k0`2][Jd00`11JN40[Jf]0:f][@030:f][@P0b<6k00<0@FWQ0<S1^`38`K/01038`K/0
1011JN40b<6k0<S1^`2][Jd30<O1_080@FWQ1037`K`00`11JN40al6l0<O1_003045Yh@@0al6l00<0
[Jf]045Yh@11JN401`36`;`00`11JN40a/2l0<K0_0070<K0_0030:f][@33_K/0`kfk00T0`kfk0`2]
[Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`
h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]
0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V0P11JN450;jg[003045Yh@2n]j`0_[N/00T0_[N/00<0[Jf]
0<6j/031^[001P31^[04045Yh@P0`KZ`0P11JN460<>m/`80@FWQ1P33_K<2045Yh@@0`kfc00<0[Jf]
0<Fn]@35_[D00P11JN400`35_[D0[Jf]0:f][@040:f][@80@FWQ102][Jd2045Yh@<0aKje00<0[Jf]
0<Jo]`36_kL02`36_kL4045Yh@H0a[ng00@0[Jf]0<O1^037`KP0@FWQ5037`KP00`2][Jd0al6j0<O1
^P0D0<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ202][Jd2045Yh@80[Jf]0`38`K/2045Yh@030:f]
[@38`K/0b<6k0080b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`040<S1^`04045Y
h@38`K/0b<6k0:f][@<0al6l1011JN420<O1_003045Yh@37`K`0al6l00P0al6l0P11JN470<K0_003
045Yh@36`;`0a/2l00L0a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n
^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH2045Yh@@0_[N/
0P11JN4;0;jg[0030:f][@31^[00`KZ`00l0`KZ`0P11JN401031^[00@FWQ0<>m/`11JN440<>m/`80
@FWQ1`33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D00P11JN470<Fn]@80@FWQ1035_[D2045Yh@P0
[Jf]00<0@FWQ0:f][@2][Jd0102][Jd4045Yh@P0a[ng00@0[Jf]0<O1^037`KP0@FWQ5037`KP00`2]
[Jd0al6j0<O1^P090<O1^Pl0[Jf]0P11JN480<S1^`80@FWQ1@38`K/2045Yh@040:f][@38`K/0b<6k
0<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`030<S1^`06045Yh@38`K/0b<6k0<S1^`2][Jd0al6l
1011JN4?0<O1_080@FWQ1`36`;`2045Yh@P0a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk
00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`h>H0/>3V04P0/>3V
0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V00T0^K:V102][Jd0102i/ZH0[Jf]045Yh@11JN420;jg[003045Yh@2n]j`0@FWQ00/0_[N/
00<0[Jf]0<6j/031^[004@31^[02045Yh@80`kfc00<0@FWQ0<>m/`33_K<00P11JN480<>m/`<0@FWQ
0`33_K<00`2][Jd0aKje0<Fn]@02045Yh@L0aKje0P11JN450<Fn]@80@FWQ0P35_[D01`2][Jd0a[ng
0<Jo]`36_kL0@FWQ0<Jo]`11JN401@36_kL2045Yh@d0[Jf]00<0@FWQ0:f][@2][Jd07P2][Jd;0<O1
^P040:f][@38`K/0b<6k0<S1^`80@FWQ2038`K/2045Yh@D0b<6k00<0@FWQ0<S1^`11JN400`38`K/2
045Yh@H0b<6k00@0@FWQ0<S1^`38`K/0b<6k0P11JN440<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]045Yh@36`;`01@36`;`3045Yh@P0a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd8
0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@030;jg[011JN40
@FWQ0080_[N/00<0@FWQ0;jg[02n]j`02@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0
`kfc0<>m/`<0@FWQ2@33_K<2045Yh@060<>m/`11JN40`kfc0<>m/`2][Jd0aKje0P11JN480<Fn]@80
@FWQ1@35_[D2045Yh@80aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045Yh@D0a[ng00<0@FWQ0<Jo]`36
_kL01P36_kL01011JN40a[ng0<Jo]`2][Jd20<O1^003045Yh@37`KP0al6h0180al6h00<0[Jf]0<O1
^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2045Yh@P0b<6k0P11JN450<S1^`04045Yh@38`K/0
[Jf]045Yh@<0b<6k00<0@FWQ0<S1^`38`K/01@38`K/3045Yh@H0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0@FWQ045Yh@050<K0_003045Yh@36`;`0@FWQ00H0a/2l102][Jd>0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U
0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd00`2n]j`0@FWQ0;jg[00:0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<03@33_K<2045Yh@80`kfc0P11JN40102][Jd0aKje045Yh@11JN480<Fn]@80@FWQ1P35
_[D2045Yh@030<Fn]@2][Jd0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`11JN40a[ng0<Jo
]`050<Jo]`80@FWQ0P36_kL0102][Jd0al6h0<O1^011JN4D0<O1^0030:f][@37`KX0al6j01@0al6j
00@0[Jf]0<S1^`38`K/0b<6k0P11JN480<S1^`80@FWQ1038`K/2045Yh@030<S1^`2][Jd0b<6k00@0
@FWQ4038`K/00`2][Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0@FWQ045Yh@<0a/2l00D0@FWQ0<K0
_036`;`0@FWQ0<K0_0050:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<
0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2]
[Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[@T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0=0<>m/`80@FWQ1033_K<3045Y
h@H0aKje0P11JN400`35_[D0@FWQ045Yh@070<Fn]@80@FWQ00D0[Jf]0<Jo]`36_kL0a[ng045Yh@07
0<Jo]`03045Yh@36_kL0a[ng00D0a[ng0P11JN420<Jo]`040:f][@37`KP0al6h045YhA@0al6h00<0
[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2045Yh@P0b<6k0P11JN420<S1^`80@FWQ
00@0b<6k045Yh@38`K/0[Jf]5@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00@0
@FWQ00<0a/2l0:f][@2][Jd00P2][Jd70<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP0102][Jd0];2a0;B`/@2d/;420:f][E00/>3V0@3oool006T0/>3V0P2][Jd20:BNS`03
0:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0
[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00d0`kfc0P11JN440<>m/`03
0:f][@35_[D0aKje00P0aKje0`11JN480<Fn]@<0@FWQ00<0a[ng045Yh@36_kL01`36_kL00`11JN40
a[ng0<Jo]`040<Jo]`<0@FWQ0P36_kL0102][Jd0al6h045Yh@11JN4D0<O1^0030:f][@37`KX0al6j
01@0al6j00@0[Jf]0<S1^`38`K/0b<6k0P11JN480<S1^`03045Yh@38`K/0b<6k00H0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`
h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;
0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`0=0<>m/`80@FWQ1033_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@040:f][@36_kL0@FWQ045Yh@T0a[ng1P11JN420<Jo]`05045Yh@36
_kL0a[ng0:f][@37`KP00`11JN4C0<O1^0030:f][@37`KX0al6j01@0al6j00@0[Jf]0<S1^`38`K/0
b<6k0P11JN480<S1^`03045Yh@38`K/0b<6k00H0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0
_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33_K<0`kfc00d0`kfc0P11JN440<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h045Yh@02045YhA<0al6h
00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2045Yh@P0b<6k00<0@FWQ0<S1^`38
`K/01P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080
[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0=0<>m/`80
@FWQ1033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^011
JN400P11JN4C0<O1^0030:f][@37`KX0al6j01@0al6j00@0[Jf]0<S1^`38`K/0b<6k0P11JN470<S1
^`80@FWQ2038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji
^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc00d0
`kfc0P11JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h045Yh@02045YhA<0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2045Y
h@L0b<6k0P11JN480<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1
_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji
^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][Jd<0<>m/`80@FWQ1033_K<00`2][Jd0
aKje0<Fn]@090<Fn]@03045Yh@35_[D0aKje00P0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h045Yh@02045YhA<0al6h00<0[Jf]0<O1^P37`KX05037`KX0102][Jd0b<6k0<S1^`38`K/2045Y
h@H0b<6k0P11JN490<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?oo
o`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd30<>m/`@0@FWQ1033_K<00`2]
[Jd0aKje0<Fn]@080<Fn]@80@FWQ2P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0@FWQ
0080@FWQ4`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ1@38`K/2
045Yh@X0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO
0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn
]@35_[D02035_[D00`11JN40aKje045Yh@090<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^011JN400P11JN4C0<O1^0030:f][@37`KX0al6j01@0al6j00@0[Jf]0<S1^`38`K/0b<6k0P11JN44
0<S1^`80@FWQ2`38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k
0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04033_K<90:f][@H0aKje00<0@FWQ0<Fn]@35_[D02035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`040:f][@37`KP0@FWQ045YhA@0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k045Y
h@08045Yh@L0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0102][Jd0al6h0<O1^011
JN4D0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0
[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f]
[H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038
`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f]
[@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k
0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f]
[Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52578 .3309 m
.51575 .33088 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50572 .33078 m
.49571 .33059 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49905 .33066 m
.49917 .33141 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5183 .34086 m
.52161 .33862 L
s
.52161 .33862 m
.52823 .3386 L
s
.52823 .3386 m
.53155 .34084 L
s
.51499 .33859 m
.51664 .34311 L
s
.51498 .34761 m
.51499 .33859 L
s
.51664 .34311 m
.5183 .34086 L
s
.53155 .34084 m
.53321 .34308 L
s
.54643 .33837 m
.54809 .34059 L
s
.54479 .34066 m
.54643 .33837 L
s
.49514 .33829 m
.50009 .34065 L
s
.49184 .3382 m
.49514 .33829 L
s
.51498 .34761 m
.51664 .34311 L
s
.54479 .34066 m
.54645 .34288 L
s
.50009 .34065 m
.50339 .34522 L
s
.48853 .34036 m
.49184 .3382 L
s
.48688 .34031 m
.49184 .3382 L
s
.53321 .34308 m
.53321 .34985 L
s
.54645 .34288 m
.54809 .34059 L
s
.48521 .34477 m
.48853 .34036 L
s
.48356 .34472 m
.48688 .34031 L
s
.53156 .34986 m
.53321 .34759 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52824 .35214 m
.53156 .34986 L
s
.53156 .35212 m
.53321 .34985 L
s
.46389 .3371 m
.47537 .33764 L
s
.51995 .35667 m
.52824 .35214 L
s
.52824 .3544 m
.53156 .35212 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48353 .3515 m
.48521 .34477 L
s
.48188 .35144 m
.48356 .34472 L
s
.51995 .35893 m
.52824 .3544 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47024 .36913 m
.47045 .33742 L
s
.4686 .36905 m
.46881 .33735 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51663 .35892 m
.51995 .35667 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5106 .38868 m
.51065 .38896 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54648 .35417 m
.54822 .38137 L
s
.5449 .38143 m
.54648 .35417 L
s
.51663 .36118 m
.51995 .35893 L
s
.51496 .36117 m
.51663 .35892 L
s
.48351 .35602 m
.48353 .3515 L
s
.48186 .35597 m
.48188 .35144 L
s
.5017 .35875 m
.50335 .36104 L
s
.50003 .36098 m
.5017 .35875 L
s
.51496 .36344 m
.51663 .36118 L
s
.51496 .36571 m
.51496 .36117 L
s
.44598 .33603 m
.45736 .33675 L
s
.53157 .3657 m
.53323 .36115 L
s
.53323 .36115 m
.53324 .37022 L
s
.50334 .36331 m
.50335 .36104 L
s
.50003 .36098 m
.50168 .36328 L
s
.48351 .35602 m
.48513 .36287 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50001 .36778 m
.50334 .36331 L
s
.48186 .35597 m
.48347 .36282 L
s
.51496 .36571 m
.51662 .36798 L
s
.52991 .36798 m
.53157 .3657 L
s
.53157 .3657 m
.53324 .37022 L
s
.51662 .36798 m
.51994 .37026 L
s
.52659 .37026 m
.52991 .36798 L
s
.51994 .37026 m
.52659 .37026 L
s
.49669 .36999 m
.50001 .36778 L
s
.48513 .36287 m
.48841 .36751 L
s
.54652 .36776 m
.54656 .3814 L
s
.48347 .36282 m
.48676 .36746 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49172 .36987 m
.49669 .36999 L
s
.48841 .36751 m
.49172 .36987 L
s
.48676 .36746 m
.49172 .36987 L
s
.42825 .33466 m
.43951 .33556 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45161 .35895 m
.45192 .35723 L
s
.45346 .35792 m
.45356 .35736 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45226 .36137 m
.45248 .33645 L
s
.45063 .36127 m
.45085 .33635 L
s
.43416 .38299 m
.43468 .33519 L
s
.43254 .38287 m
.43307 .33506 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5449 .38143 m
.54657 .38595 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46367 .36882 m
.47024 .36913 L
s
.54657 .38595 m
.54822 .38137 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45059 .36582 m
.45226 .36137 L
s
.44896 .36572 m
.45063 .36127 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44568 .36779 m
.45059 .36582 L
s
.44568 .36779 m
.44896 .36572 L
s
.46852 .38044 m
.47015 .38279 L
s
.46686 .38264 m
.46852 .38044 L
s
.46849 .385 m
.47015 .38279 L
s
.39377 .31519 m
.40468 .31648 L
s
.46686 .38264 m
.46849 .385 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44243 .36757 m
.44568 .36779 L
s
.43759 .36495 m
.44243 .36757 L
s
.40917 .33285 m
.41388 .33561 L
s
.41388 .33561 m
.417 .34046 L
s
.43441 .36016 m
.43759 .36495 L
s
.417 .34046 m
.4185 .34742 L
s
.40917 .33285 m
.4123 .33545 L
s
.4123 .33545 m
.41541 .3403 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41541 .3403 m
.41691 .34728 L
s
.63573 .3329 m
.65139 .33115 L
s
.40602 .33252 m
.40917 .33285 L
s
.41844 .35198 m
.4185 .34742 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41685 .35183 m
.41691 .34728 L
s
.40285 .33445 m
.40602 .33252 L
s
.64045 .3324 m
.64115 .38038 L
s
.41676 .35867 m
.41844 .35198 L
s
.41517 .35852 m
.41685 .35183 L
s
.39965 .33865 m
.40285 .33445 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39927 .36377 m
.39999 .31594 L
s
.3977 .3636 m
.39843 .31576 L
s
.41352 .36293 m
.41676 .35867 L
s
.41193 .36278 m
.41517 .35852 L
s
.4277 .38249 m
.43416 .38299 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64202 .33223 m
.64273 .38022 L
s
.65139 .33115 m
.65607 .33285 L
s
.65139 .33115 m
.65453 .33304 L
s
.40873 .36476 m
.41352 .36293 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40873 .36476 m
.41193 .36278 L
s
.38887 .33051 m
.39042 .33071 L
s
.65453 .33304 m
.6577 .33722 L
s
.38575 .3324 m
.38887 .33051 L
s
.38729 .3326 m
.38887 .33051 L
s
.65607 .33285 m
.65924 .33702 L
s
.40556 .36444 m
.40873 .36476 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38567 .33696 m
.38729 .3326 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38413 .33676 m
.38575 .3324 L
s
.40244 .36182 m
.40556 .36444 L
s
.6577 .33722 m
.65931 .34159 L
s
.39937 .3569 m
.40244 .36182 L
s
.65924 .33702 m
.66086 .34139 L
s
.3854 .35297 m
.38567 .33696 L
s
.38114 .33179 m
.38413 .33676 L
s
.38378 .35736 m
.38413 .33676 L
s
.37813 .32909 m
.38114 .33179 L
s
.39301 .36307 m
.39927 .36377 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37356 .32845 m
.37813 .32909 L
s
.66831 .32894 m
.6789 .3274 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63639 .38085 m
.65215 .37921 L
s
.66086 .34139 m
.66251 .34805 L
s
.65931 .34159 m
.66097 .34825 L
s
.66097 .34825 m
.66117 .35971 L
s
.3705 .33029 m
.37356 .32845 L
s
.36899 .33007 m
.37356 .32845 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67287 .3283 m
.67346 .3604 L
s
.66251 .34805 m
.66271 .35952 L
s
.38378 .35736 m
.3854 .35297 L
s
.67438 .32808 m
.67498 .36019 L
s
.38236 .35028 m
.38386 .35277 L
s
.37323 .34676 m
.38236 .35028 L
s
.3689 .33465 m
.3705 .33029 L
s
.3822 .35946 m
.38378 .35736 L
s
.36739 .33442 m
.36899 .33007 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65974 .36679 m
.66117 .35971 L
s
.66128 .3666 m
.66271 .35952 L
s
.37909 .36136 m
.3822 .35946 L
s
.36881 .33923 m
.3689 .33465 L
s
.65215 .37921 m
.65523 .37655 L
s
.65215 .37921 m
.65679 .37637 L
s
.65827 .37158 m
.65974 .36679 L
s
.36731 .339 m
.36739 .33442 L
s
.65523 .37655 m
.65827 .37158 L
s
.65982 .37139 m
.66128 .3666 L
s
.37024 .34403 m
.37323 .34676 L
s
.36873 .34381 m
.37323 .34676 L
s
.36881 .33923 m
.37024 .34403 L
s
.65679 .37637 m
.65982 .37139 L
s
.37298 .36054 m
.37909 .36136 L
s
.36731 .339 m
.36873 .34381 L
s
.67472 .34639 m
.67637 .35307 L
s
.66889 .36102 m
.67498 .36019 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36855 .353 m
.37007 .35322 L
s
.37002 .35552 m
.37007 .35322 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36998 .35782 m
.37298 .36054 L
s
.67637 .35307 m
.67947 .35724 L
s
.36851 .3553 m
.36855 .353 L
s
.36851 .3553 m
.36998 .35782 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67947 .35724 m
.68253 .3591 L
s
.33814 .32256 m
.34826 .32441 L
s
.68253 .3591 m
.68701 .35842 L
s
.68543 .35404 m
.68697 .35611 L
s
.68543 .35404 m
.68687 .3515 L
s
.68687 .3515 m
.68841 .35357 L
s
.69964 .32627 m
.70393 .32318 L
s
.69828 .33113 m
.69964 .32627 L
s
.68841 .35357 m
.68846 .35588 L
s
.69828 .33113 m
.69838 .33573 L
s
.34319 .35594 m
.3439 .32363 L
s
.35508 .35096 m
.35652 .3535 L
s
.35647 .35581 m
.35652 .3535 L
s
.35355 .35303 m
.35508 .35096 L
s
.68701 .35842 m
.68846 .35588 L
s
.70109 .32601 m
.70393 .32318 L
s
.69974 .33087 m
.70109 .32601 L
s
.35494 .35788 m
.35647 .35581 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69974 .33087 m
.69984 .33548 L
s
.34174 .35569 m
.34246 .32337 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69838 .33573 m
.69994 .34009 L
s
.70393 .32318 m
.70824 .32237 L
s
.35355 .35303 m
.35499 .35557 L
s
.69984 .33548 m
.70139 .33983 L
s
.35051 .35717 m
.35494 .35788 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69994 .34009 m
.70434 .34162 L
s
.70824 .32237 m
.71114 .32412 L
s
.70139 .33983 m
.70434 .34162 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34762 .35437 m
.35051 .35717 L
s
.3435 .34206 m
.3448 .34925 L
s
.3448 .34925 m
.34762 .35437 L
s
.70014 .34933 m
.70019 .35164 L
s
.70014 .34933 m
.70159 .34907 L
s
.70019 .35164 m
.7017 .3537 L
s
.70434 .34162 m
.71299 .34234 L
s
.71114 .32412 m
.71409 .32818 L
s
.70159 .34907 m
.70165 .35139 L
s
.7017 .3537 m
.70465 .35551 L
s
.3374 .35491 m
.34319 .35594 L
s
.32918 .33939 m
.32962 .32089 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32136 .31167 m
.32136 .31146 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71539 .32328 m
.71815 .3204 L
s
.71409 .32818 m
.71539 .32328 L
s
.71409 .32818 m
.71458 .34902 L
s
.32777 .33911 m
.32821 .3206 L
s
.7168 .323 m
.71815 .3204 L
s
.7155 .3279 m
.7168 .323 L
s
.70465 .35551 m
.71041 .35447 L
s
.71815 .3204 m
.71955 .32011 L
s
.7155 .3279 m
.71588 .34411 L
s
.32356 .33825 m
.33343 .34021 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32535 .32233 m
.32804 .32753 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32124 .31913 m
.32535 .32233 L
s
.71299 .34234 m
.71447 .34438 L
s
.71041 .35447 m
.71321 .35162 L
s
.31848 .31853 m
.32124 .31913 L
s
.71458 .34902 m
.71588 .34411 L
s
.71321 .35162 m
.71458 .34902 L
s
.31568 .32024 m
.31848 .31853 L
s
.31432 .31993 m
.31848 .31853 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32061 .34173 m
.32064 .34054 L
s
.5 Mabswid
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32846 .36963 m
.32879 .35564 L
s
.32721 .36236 m
.32879 .35564 L
s
.31284 .32426 m
.31568 .32024 L
s
.31148 .32395 m
.31432 .31993 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7273 .35115 m
.73195 .3174 L
s
.32428 .36648 m
.32721 .36236 L
s
.32721 .36236 m
.32846 .36963 L
s
.72868 .35086 m
.73213 .32436 L
s
.31136 .3286 m
.31284 .32426 L
s
.31001 .32829 m
.31148 .32395 L
s
.30982 .33528 m
.31136 .3286 L
s
0 0 0 r
.31979 .37447 m
.32113 .37809 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32002 .36799 m
.32428 .36648 L
s
.30848 .33497 m
.31001 .32829 L
s
.30952 .34695 m
.30982 .33528 L
s
.31725 .36743 m
.32002 .36799 L
s
.30817 .34665 m
.30848 .33497 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73821 .34877 m
.74267 .31484 L
s
.74267 .31484 m
.74882 .34626 L
s
.72313 .35201 m
.73279 .34998 L
s
.73195 .3174 m
.73821 .34877 L
s
.31455 .36451 m
.31725 .36743 L
s
.31318 .36422 m
.31725 .36743 L
s
.73955 .34847 m
.74286 .32183 L
s
.30952 .34695 m
.31069 .35427 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31193 .35925 m
.31455 .36451 L
s
.31069 .35427 m
.31193 .35925 L
s
.30817 .34665 m
.30934 .35397 L
s
.31057 .35895 m
.31318 .36422 L
s
.30934 .35397 m
.31057 .35895 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29448 .31273 m
.29878 .3468 L
s
.28842 .34419 m
.29448 .31273 L
s
.29486 .34584 m
.30275 .34775 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28969 .34453 m
.29428 .31973 L
s
.74488 .34722 m
.75272 .34529 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28433 .30993 m
.28842 .34419 L
s
.75963 .31742 m
.76199 .31203 L
s
.7585 .32246 m
.75963 .31742 L
s
.75744 .32985 m
.7585 .32246 L
s
.75744 .32985 m
.75778 .34161 L
s
.76199 .31203 m
.76563 .3086 L
s
.76088 .31707 m
.76323 .31167 L
s
.75976 .32211 m
.76088 .31707 L
s
.75871 .3295 m
.75976 .32211 L
s
.75871 .3295 m
.75905 .34127 L
s
.76323 .31167 m
.76563 .3086 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27839 .34145 m
.28433 .30993 L
s
.27962 .3418 m
.28412 .31696 L
s
.76563 .3086 m
.76808 .30786 L
s
.75778 .34161 m
.75926 .34834 L
s
0 0 0 r
.76604 .33802 m
.76686 .32904 L
s
.255 .412 .882 r
.75905 .34127 m
.76052 .348 L
s
0 0 0 r
.76586 .33859 m
.76604 .33802 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76808 .30786 m
.77178 .30909 L
s
.75926 .34834 m
.76066 .35273 L
s
.76052 .348 m
.76192 .35239 L
s
.27471 .34039 m
.28336 .34284 L
s
.76066 .35273 m
.76331 .35679 L
s
.27212 .30625 m
.27331 .30663 L
s
.77178 .30909 m
.77431 .31305 L
s
.76192 .35239 m
.76456 .35645 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26967 .30784 m
.27212 .30625 L
s
.27085 .30822 m
.27212 .30625 L
s
.26952 .31256 m
.27085 .30822 L
s
.26834 .31218 m
.26967 .30784 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76331 .35679 m
.76712 .35814 L
s
.76456 .35645 m
.76712 .35814 L
s
.77108 .32596 m
.7794 .32336 L
s
.77528 .30561 m
.77587 .32448 L
s
.77409 .30599 m
.77468 .32486 L
s
.269 .3291 m
.26952 .31256 L
s
.26615 .30669 m
.26834 .31218 L
s
.26767 .33347 m
.26834 .31218 L
s
.76712 .35814 m
.76958 .35746 L
s
.26391 .30355 m
.26615 .30669 L
s
.76958 .35746 m
.77316 .35403 L
s
.26048 .30236 m
.26391 .30355 L
s
.26767 .33347 m
.269 .3291 L
s
.78228 .30328 m
.79016 .30047 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26672 .32599 m
.26782 .32873 L
s
.25986 .32132 m
.26672 .32599 L
s
.26642 .33548 m
.26767 .33347 L
s
.77542 .34857 m
.77639 .34108 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77639 .34108 m
.77683 .35535 L
s
.77316 .35403 m
.77542 .34857 L
s
.25814 .30393 m
.26048 .30236 L
s
.25702 .30353 m
.26048 .30236 L
s
.77542 .34857 m
.77683 .35535 L
s
.78569 .30209 m
.78677 .33534 L
s
.26401 .33711 m
.26642 .33548 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78682 .30169 m
.78791 .33495 L
s
.25687 .30827 m
.25814 .30393 L
s
.2594 .3356 m
.26401 .33711 L
s
.25575 .30787 m
.25702 .30353 L
s
.25768 .31817 m
.25986 .32132 L
s
.25656 .31777 m
.25986 .32132 L
s
.25671 .31302 m
.25687 .30827 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78334 .33648 m
.78791 .33495 L
s
.2556 .31262 m
.25575 .30787 L
s
.25671 .31302 m
.25768 .31817 L
s
.78744 .32066 m
.7888 .32741 L
s
.2556 .31262 m
.25656 .31777 L
s
.25721 .33245 m
.2594 .3356 L
s
.25624 .32729 m
.25737 .32768 L
s
.25729 .33007 m
.25737 .32768 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7888 .32741 m
.79119 .3314 L
s
.25616 .32968 m
.25624 .32729 L
s
.25616 .32968 m
.25721 .33245 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79119 .3314 m
.79347 .33301 L
s
.79347 .33301 m
.79674 .33182 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7955 .32743 m
.79666 .32943 L
s
.7955 .32743 m
.7965 .32464 L
s
.7965 .32464 m
.79765 .32663 L
s
.79674 .33182 m
.79773 .32903 L
s
.79765 .32663 m
.79773 .32903 L
s
.24642 .32371 m
.2474 .32651 L
s
.24732 .3289 m
.2474 .32651 L
s
.23509 .29226 m
.2421 .29532 L
s
.24617 .3309 m
.24732 .3289 L
s
.24528 .32569 m
.24642 .32371 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24528 .32569 m
.24626 .3285 L
s
.24301 .32968 m
.24617 .3309 L
s
.80424 .30219 m
.80509 .29698 L
s
.80424 .30219 m
.80441 .30697 L
s
.80509 .29698 m
.80802 .29328 L
s
.23788 .32762 m
.23906 .29402 L
s
.80526 .30176 m
.8061 .29654 L
s
.80526 .30176 m
.80543 .30655 L
s
.8061 .29654 m
.80802 .29328 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80441 .30697 m
.80559 .31134 L
s
.23687 .3272 m
.23806 .29358 L
s
.80543 .30655 m
.80661 .31091 L
s
.80802 .29328 m
.81097 .29195 L
s
.24102 .32646 m
.24301 .32968 L
s
.80559 .31134 m
.8087 .31246 L
s
.80661 .31091 m
.8087 .31246 L
s
.23914 .32081 m
.24102 .32646 L
s
.23838 .31318 m
.23914 .32081 L
s
.80593 .32094 m
.80601 .32335 L
s
.80593 .32094 m
.80694 .32052 L
s
.80601 .32335 m
.80711 .32534 L
s
.81097 .29195 m
.81299 .29346 L
s
.80694 .32052 m
.80703 .32293 L
s
.8087 .31246 m
.81464 .31227 L
s
.80711 .32534 m
.80921 .32691 L
s
.23389 .32594 m
.23788 .32762 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81299 .29346 m
.81506 .29737 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80921 .32691 m
.81314 .32522 L
s
.81506 .29737 m
.81583 .29211 L
s
.81506 .29737 m
.81585 .31909 L
s
.81583 .29211 m
.8176 .2888 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81601 .29693 m
.81677 .29166 L
s
.81601 .29693 m
.81662 .31381 L
s
.81677 .29166 m
.8176 .2888 L
s
.22909 .29679 m
.22986 .30205 L
s
.22986 .30205 m
.23054 .30973 L
s
.22741 .29106 m
.22909 .29679 L
s
.8176 .2888 m
.81852 .28834 L
s
.23011 .32181 m
.23054 .30973 L
s
.81464 .31227 m
.81567 .31425 L
s
.81314 .32522 m
.81498 .32194 L
s
.22816 .29634 m
.22892 .3016 L
s
.22892 .3016 m
.2296 .30929 L
s
.22649 .29061 m
.22816 .29634 L
s
.22477 .28728 m
.22741 .29106 L
s
.22916 .32137 m
.2296 .30929 L
s
.22477 .28728 m
.22649 .29061 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81498 .32194 m
.81585 .31909 L
s
.22889 .32864 m
.23011 .32181 L
s
.81585 .31909 m
.81662 .31381 L
s
.82238 .26916 m
.82427 .31998 L
s
0 0 0 r
.82575 .27734 m
.82743 .27644 L
s
.255 .412 .882 r
.21616 .28257 m
.22477 .28728 L
s
.22795 .32821 m
.22916 .32137 L
s
.82325 .26868 m
.82515 .31953 L
s
.22777 .33307 m
.22889 .32864 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81972 .27058 m
.82583 .26724 L
s
.22684 .33264 m
.22795 .32821 L
s
.22573 .33708 m
.22777 .33307 L
s
.22481 .33665 m
.22684 .33264 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82415 .29282 m
.8257 .28704 L
s
.82159 .32131 m
.82515 .31953 L
s
.8257 .28704 m
.82731 .28367 L
s
.22289 .33822 m
.22573 .33708 L
s
.22289 .33822 m
.22481 .33665 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82731 .28367 m
.82897 .28272 L
s
.82488 .31223 m
.82679 .31619 L
s
.82897 .28272 m
.8307 .28419 L
s
.82897 .28272 m
.8315 .28371 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21422 .33383 m
.22289 .33822 L
s
.21674 .33516 m
.21866 .284 L
s
.21759 .3356 m
.21951 .28447 L
s
.8307 .28419 m
.83249 .28809 L
s
.8315 .28371 m
.83328 .28761 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82679 .31619 m
.82859 .31772 L
s
.82859 .31772 m
.83026 .31681 L
s
.83249 .28809 m
.83356 .29493 L
s
.83026 .31681 m
.83181 .31345 L
s
.83026 .31681 m
.83262 .31298 L
s
.83328 .28761 m
.83434 .29445 L
s
.83356 .29493 m
.83375 .29981 L
s
.83181 .31345 m
.83324 .30762 L
s
.83324 .30762 m
.83375 .29981 L
s
.83434 .29445 m
.83453 .29934 L
s
.83262 .31298 m
.83403 .30715 L
s
.83403 .30715 m
.83453 .29934 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8383 .27687 m
.8432 .27335 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84045 .27537 m
.84249 .3271 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84115 .27487 m
.8432 .32663 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84222 .3019 m
.8438 .30586 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84032 .32849 m
.8432 .32663 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8438 .30586 m
.84591 .30688 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84878 .29316 m
.84879 .29347 L
s
.85008 .32541 m
.85057 .33756 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84769 .26977 m
.84879 .29697 L
s
.84582 .27132 m
.85007 .26769 L
s
.8483 .26925 m
.8494 .29647 L
s
.84591 .30688 m
.84721 .3059 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84721 .3059 m
.84837 .30243 L
s
.84721 .3059 m
.84899 .30194 L
s
.84837 .30243 m
.84879 .29697 L
s
.84899 .30194 m
.8494 .29647 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8523 .2656 m
.85586 .26188 L
s
.85388 .26401 m
.85532 .29891 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85439 .26348 m
.85583 .2984 L
s
.85373 .30043 m
.85583 .2984 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85541 .31446 m
.85583 .31145 L
s
.85541 .31446 m
.85604 .31647 L
s
.85583 .31145 m
.85645 .31346 L
s
.85604 .31647 m
.85645 .31346 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85844 .26669 m
.85907 .2606 L
s
.85832 .27473 m
.85844 .26669 L
s
.85832 .27473 m
.85853 .27974 L
s
.85887 .26615 m
.85948 .26006 L
s
.85875 .2742 m
.85887 .26615 L
s
.85853 .27974 m
.85928 .28675 L
s
.85907 .2606 m
.86016 .25647 L
s
.85875 .2742 m
.85896 .27921 L
s
.85896 .27921 m
.8597 .28622 L
s
.85948 .26006 m
.86016 .25647 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85928 .28675 m
.86033 .29074 L
s
.86016 .25647 m
.86091 .25538 L
s
.8597 .28622 m
.86074 .29022 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86091 .25538 m
.86206 .25624 L
s
.86033 .29074 m
.86164 .2917 L
s
.86074 .29022 m
.86164 .2917 L
s
.18346 .25913 m
.18391 .25717 L
s
.18367 .25411 m
.18391 .25717 L
s
.18322 .25607 m
.18367 .25411 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18322 .25607 m
.18346 .25913 L
s
.86206 .25624 m
.86292 .26018 L
s
.86164 .2917 m
.86275 .29012 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18199 .30264 m
.18292 .27173 L
s
.1813 .30161 m
.18292 .27173 L
s
.86275 .29012 m
.86334 .28654 L
s
.86302 .27894 m
.86324 .27588 L
s
.86302 .27894 m
.86346 .28094 L
s
.86324 .27588 m
.86367 .27787 L
s
.18164 .30213 m
.18229 .2869 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86334 .28654 m
.86378 .2804 L
s
.86367 .27787 m
.86378 .2804 L
s
.18143 .30721 m
.18199 .30264 L
s
.18088 .25164 m
.18103 .25473 L
s
.18071 .26232 m
.18103 .25473 L
s
.1813 .30161 m
.18143 .30721 L
s
.18051 .248 m
.18088 .25164 L
s
.86457 .24873 m
.86503 .25323 L
s
.86457 .24873 m
.865 .25886 L
s
.18045 .26177 m
.18082 .25979 L
s
.18035 .26431 m
.18071 .26232 L
s
.17965 .24575 m
.18051 .248 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17986 .26321 m
.18045 .26177 L
s
.865 .25886 m
.86503 .25323 L
s
.86503 .25323 m
.86515 .25014 L
s
.17975 .26575 m
.18035 .26431 L
s
.86515 .25014 m
.86547 .24649 L
s
.1797 .27956 m
.18017 .27501 L
s
.17974 .28519 m
.18017 .27501 L
s
.1786 .26555 m
.17986 .26321 L
s
.86547 .24649 m
.86621 .24423 L
s
.86565 .2741 m
.86578 .27101 L
s
.86565 .2741 m
.86586 .27919 L
s
.1797 .27956 m
.17974 .28519 L
s
.17849 .26811 m
.17975 .26575 L
s
.17934 .28157 m
.1797 .27956 L
s
.86576 .27664 m
.86589 .27355 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86578 .27101 m
.86613 .26737 L
s
.86586 .27919 m
.86622 .2812 L
s
.86589 .27355 m
.86624 .26992 L
s
.17918 .24716 m
.17965 .24575 L
s
.17876 .28305 m
.17934 .28157 L
s
.86613 .26737 m
.86687 .25952 L
s
.86622 .2812 m
.86678 .28268 L
s
.86624 .26992 m
.86698 .26207 L
s
0 0 0 r
.17529 .23391 m
.17405 .22456 L
s
.255 .412 .882 r
.1789 .24915 m
.17918 .24716 L
s
.86621 .24423 m
.86663 .24565 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17794 .2809 m
.17876 .28305 L
s
.86678 .28268 m
.86757 .28052 L
s
.1789 .24915 m
.17897 .24349 L
s
.17853 .25368 m
.1789 .24915 L
s
.17853 .25368 m
.17897 .24349 L
s
.17814 .26701 m
.1786 .26555 L
s
.17803 .26957 m
.17849 .26811 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86663 .24565 m
.86688 .24763 L
s
.86687 .25952 m
.86707 .25585 L
s
.86698 .26207 m
.86718 .2584 L
s
.86688 .24763 m
.86721 .25529 L
s
.86707 .25585 m
.8671 .25274 L
s
.17787 .26902 m
.17814 .26701 L
s
.1777 .27725 m
.17794 .2809 L
s
.86718 .2584 m
.86721 .25529 L
s
.17776 .27158 m
.17803 .26957 L
s
.86757 .28052 m
.8678 .27688 L
s
.17765 .27414 m
.17787 .26902 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17765 .27414 m
.1777 .27725 L
s
.8678 .27688 m
.86784 .27377 L
s
.86776 .26809 m
.86784 .27377 L
s
.86784 .27377 m
.8682 .27836 L
s
.86776 .26809 m
.8682 .27836 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17791 .24093 m
.17783 .24719 L
s
0 0 0 r
.17298 .27177 m
.17244 .26844 L
s
.255 .412 .882 r
.86741 .23798 m
.86746 .24111 L
s
.17789 .23666 m
.17791 .24093 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .23798 m
.86756 .23997 L
s
.86746 .24111 m
.86763 .2431 L
s
.86756 .23997 m
.86763 .2431 L
s
0 0 0 r
.17196 .31077 m
.17067 .30228 L
s
.255 .412 .882 r
.17694 .26774 m
.17705 .26516 L
s
.17705 .26516 m
.17709 .26204 L
s
.17658 .27179 m
.17694 .26774 L
s
.17691 .26406 m
.17709 .26204 L
s
.17786 .23551 m
.17789 .23666 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17151 .30919 m
.17485 .23217 L
s
.17138 .30866 m
.17473 .23159 L
s
.1718 .28321 m
.17308 .25372 L
s
.255 .412 .882 r
.17687 .26719 m
.17691 .26406 L
s
0 0 0 r
.17309 .24661 m
.17404 .22515 L
s
.255 .412 .882 r
.17776 .23693 m
.17786 .23551 L
s
.17778 .23636 m
.17786 .23551 L
s
0 0 0 r
.17405 .22456 m
.17309 .24661 L
s
.255 .412 .882 r
.17658 .27179 m
.17637 .27328 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86884 .27141 m
.86951 .28694 L
s
.86818 .25595 m
.86945 .28748 L
s
.86818 .25595 m
.86956 .2864 L
s
.17759 .24095 m
.17776 .23693 L
s
.86945 .28748 m
.86973 .29213 L
s
.17637 .27328 m
.1763 .27163 L
s
.17763 .24037 m
.17778 .23636 L
s
.86956 .2864 m
.86973 .29213 L
s
.1773 .24813 m
.17759 .24095 L
s
.1763 .27163 m
.17642 .26794 L
s
.1763 .27163 m
.17644 .26739 L
s
.17735 .24756 m
.17763 .24037 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17707 .25331 m
.1773 .24813 L
s
.17642 .26794 m
.1767 .26164 L
s
.1767 .26164 m
.17707 .25331 L
s
.17713 .25275 m
.17735 .24756 L
s
.17644 .26739 m
.17674 .26109 L
s
0 0 0 r
.17164 .27992 m
.17067 .30281 L
s
.17067 .30228 m
.17164 .27992 L
s
.255 .412 .882 r
.17674 .26109 m
.17713 .25275 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1745 .22235 m
.17506 .21688 L
s
.17407 .23033 m
.1745 .22235 L
s
.17229 .27121 m
.17407 .23033 L
s
.17462 .22176 m
.17506 .21688 L
s
.17418 .22974 m
.17462 .22176 L
s
.1724 .27066 m
.17418 .22974 L
s
.17506 .21688 m
.17538 .2157 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17203 .27288 m
.1724 .27066 L
s
.17538 .2157 m
.17579 .21763 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17726 .26391 m
.17804 .24586 L
s
.17712 .26447 m
.17791 .24606 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17579 .21763 m
.1759 .22389 L
s
.17638 .21273 m
.17738 .21036 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17411 .26509 m
.17638 .21273 L
s
.17435 .26453 m
.17661 .21214 L
s
.255 .412 .882 r
.17645 .28027 m
.17648 .28227 L
s
.17648 .28227 m
.17667 .27992 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17348 .26676 m
.17435 .26453 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17873 .21803 m
.17975 .20936 L
s
.17791 .22988 m
.17873 .21803 L
s
.17975 .20936 m
.18105 .20383 L
s
.17759 .23741 m
.17791 .22988 L
s
.17907 .21745 m
.18012 .20877 L
s
.17824 .2293 m
.17907 .21745 L
s
.18012 .20877 m
.18105 .20383 L
s
.17792 .23683 m
.17824 .2293 L
s
.17744 .24816 m
.17759 .23741 L
s
.18105 .20383 m
.18187 .20265 L
s
.17778 .24759 m
.17792 .23683 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17744 .24816 m
.17781 .2546 L
s
.18187 .20265 m
.18257 .20523 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17778 .24759 m
.17818 .25404 L
s
.18257 .20523 m
.18316 .21161 L
s
.17781 .2546 m
.17879 .25673 L
s
.18364 .20029 m
.18559 .19793 L
s
.18025 .28021 m
.18364 .20029 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17818 .25404 m
.17879 .25673 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17879 .25673 m
.17961 .25561 L
s
.17961 .25561 m
.18064 .25069 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18064 .25069 m
.18187 .24195 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18778 .2312 m
.18786 .23501 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1789 .28182 m
.18072 .27967 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18839 .2058 m
.18989 .19704 L
s
.18734 .2178 m
.18839 .2058 L
s
.18989 .19704 m
.19191 .19149 L
s
.18702 .22543 m
.18734 .2178 L
s
.18898 .20523 m
.1905 .19646 L
s
.18791 .21723 m
.18898 .20523 L
s
.1905 .19646 m
.19191 .19149 L
s
.18759 .22487 m
.18791 .21723 L
s
.18702 .22543 m
.18711 .23635 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18072 .27967 m
.18411 .1997 L
s
.5 Mabswid
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19191 .19149 m
.19321 .19033 L
s
.18759 .22487 m
.1877 .23579 L
s
.19321 .19033 m
.1944 .19298 L
s
.19321 .19033 m
.19509 .19241 L
s
.18711 .23635 m
.18798 .24292 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1877 .23579 m
.18859 .24237 L
s
.1944 .19298 m
.19548 .19949 L
s
.18798 .24292 m
.18969 .24512 L
s
.19509 .19241 m
.19619 .19892 L
s
.18859 .24237 m
.18969 .24512 L
s
.19548 .19949 m
.19572 .21044 L
s
.19619 .19892 m
.19645 .20987 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18969 .24512 m
.19099 .24403 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19541 .21813 m
.19572 .21044 L
s
.84554 .19241 m
.84615 .18915 L
s
.84523 .18474 m
.84615 .18915 L
s
.19099 .24403 m
.1925 .23907 L
s
.19099 .24403 m
.1932 .23853 L
s
.8446 .18801 m
.84523 .18474 L
s
.19613 .21758 m
.19645 .20987 L
s
.19422 .23025 m
.19541 .21813 L
s
.1925 .23907 m
.19422 .23025 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8446 .18801 m
.84554 .19241 L
s
.19493 .2297 m
.19613 .21758 L
s
.1932 .23853 m
.19493 .2297 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20487 .21717 m
.20513 .21684 L
s
0 0 0 r
.20118 .18399 m
.20612 .18058 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84632 .21167 m
.84897 .25878 L
s
.84632 .21167 m
.84742 .25773 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83717 .21432 m
.83779 .23016 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84726 .23489 m
.8482 .25825 L
s
.83796 .18349 m
.83898 .18791 L
s
.83898 .18791 m
.83944 .19951 L
s
.83603 .17851 m
.83796 .18349 L
s
.255 .412 .882 r
.83779 .23016 m
.8383 .23049 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21115 .23022 m
.21123 .23066 L
s
.20278 .18285 m
.21115 .23022 L
s
.83857 .19896 m
.83929 .19564 L
s
.255 .412 .882 r
.83662 .22146 m
.83712 .21424 L
s
0 0 0 r
.20964 .17834 m
.21526 .175 L
s
.83872 .20283 m
.83944 .19951 L
s
.84852 .26607 m
.84897 .25878 L
s
.20061 .237 m
.2124 .17666 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83694 .20174 m
.83857 .19896 L
s
.83709 .20562 m
.83872 .20283 L
s
.83234 .17628 m
.83603 .17851 L
s
.20143 .23647 m
.21323 .17669 L
s
.21323 .17669 m
.21334 .17611 L
s
.84742 .25773 m
.84852 .26607 L
s
.83057 .17905 m
.83234 .17628 L
s
.83964 .22617 m
.84021 .21891 L
s
.84021 .21891 m
.84083 .2345 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.199 .23807 m
.20396 .23487 L
s
.83891 .22954 m
.83964 .22617 L
s
.83964 .22617 m
.84083 .2345 L
s
.82975 .18238 m
.83057 .17905 L
s
.82846 .17407 m
.82975 .18238 L
s
.82846 .17407 m
.82906 .18961 L
s
.82906 .18961 m
.82975 .18238 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83726 .23239 m
.83891 .22954 L
s
.83274 .21072 m
.83709 .20562 L
s
.83259 .20682 m
.83694 .20174 L
s
.2075 .23276 m
.21316 .22962 L
s
.8308 .20966 m
.83259 .20682 L
s
.8335 .2303 m
.83726 .23239 L
s
.83095 .21357 m
.83274 .21072 L
s
.82996 .21305 m
.8308 .20966 L
s
.83011 .21696 m
.83095 .21357 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22326 .17453 m
.22664 .16902 L
s
.2219 .18286 m
.22326 .17453 L
s
.8314 .22533 m
.8335 .2303 L
s
.82996 .21305 m
.83026 .22089 L
s
.22028 .22602 m
.2219 .18286 L
s
.22432 .17399 m
.22664 .16902 L
s
.22296 .18233 m
.22432 .17399 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22134 .22551 m
.22296 .18233 L
s
.83026 .22089 m
.8314 .22533 L
s
.81923 .17308 m
.82169 .18196 L
s
.22664 .16902 m
.22885 .16795 L
s
.81576 .16758 m
.81923 .17308 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22885 .16795 m
.23212 .17027 L
s
.81349 .16652 m
.81576 .16758 L
s
.21716 .22755 m
.22134 .22551 L
s
.82242 .20154 m
.82272 .2094 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81131 .16939 m
.81349 .16652 L
s
.81013 .16887 m
.81349 .16652 L
s
.82134 .20102 m
.82179 .21282 L
s
.82193 .21676 m
.82272 .2094 L
s
.23212 .17027 m
.23416 .17707 L
s
.23458 .16531 m
.23937 .16323 L
s
.82099 .2202 m
.82179 .21282 L
s
.80923 .1762 m
.81131 .16939 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82099 .2202 m
.82193 .21676 L
s
.80803 .17569 m
.81013 .16887 L
s
.81891 .22314 m
.82099 .2202 L
s
.80845 .18751 m
.80923 .1762 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23258 .22051 m
.23458 .16531 L
s
.23377 .22002 m
.23576 .16479 L
s
.8155 .22165 m
.81891 .22314 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80845 .18751 m
.80874 .1954 L
s
.80874 .1954 m
.82131 .20104 L
s
.82131 .20104 m
.82242 .20154 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80724 .187 m
.80803 .17569 L
s
.79634 .15932 m
.80145 .16134 L
s
.22909 .22199 m
.23377 .22002 L
s
.80724 .187 m
.80752 .1949 L
s
.81302 .21669 m
.8155 .22165 L
s
.81184 .2162 m
.8155 .22165 L
s
.24559 .16068 m
.24659 .16805 L
s
.24504 .17645 m
.24559 .16068 L
s
.80874 .1954 m
.81036 .20777 L
s
.81036 .20777 m
.81302 .21669 L
s
.80752 .1949 m
.80916 .20728 L
s
.80916 .20728 m
.81184 .2162 L
s
.24504 .17645 m
.24659 .16805 L
s
.24659 .16805 m
.24802 .16361 L
s
.24802 .16361 m
.25076 .15867 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25076 .15867 m
.25611 .15669 L
s
.79385 .16227 m
.79674 .17116 L
s
.79105 .15734 m
.79385 .16227 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78834 .15636 m
.79105 .15734 L
s
.25611 .15669 m
.25871 .15968 L
s
.24421 .20022 m
.24563 .19576 L
s
.24393 .20818 m
.24421 .20022 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24563 .19576 m
.24837 .19082 L
s
.78572 .15935 m
.78834 .15636 L
s
.78433 .15887 m
.78834 .15636 L
s
.24407 .2042 m
.2455 .19974 L
s
.2455 .19974 m
.24823 .1948 L
s
.24837 .19082 m
.25531 .18047 L
s
.24393 .20818 m
.24508 .21168 L
s
.24823 .1948 m
.25518 .18445 L
s
.25871 .15968 m
.25996 .16316 L
s
.78319 .16633 m
.78572 .15935 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24508 .21168 m
.24754 .21473 L
s
.79547 .20994 m
.79784 .20291 L
s
.78178 .16585 m
.78433 .15887 L
s
.25957 .17507 m
.25996 .16316 L
s
.25531 .18047 m
.25818 .17555 L
s
.25518 .18445 m
.25805 .17952 L
s
.25818 .17555 m
.2597 .1711 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79634 .15932 m
.79922 .24294 L
s
.79763 .15982 m
.80052 .2434 L
s
.24754 .21473 m
.25288 .21286 L
s
.25805 .17952 m
.25957 .17507 L
s
.78217 .1778 m
.78319 .16633 L
s
.79293 .21301 m
.79547 .20994 L
s
.78074 .17733 m
.78178 .16585 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27007 .15589 m
.27166 .15145 L
s
.27007 .15589 m
.27141 .15941 L
s
.27166 .15145 m
.27301 .15497 L
s
.7902 .21209 m
.79293 .21301 L
s
.78217 .1778 m
.78243 .18578 L
s
.25288 .21286 m
.25574 .20794 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25726 .20347 m
.25891 .19501 L
s
.25838 .21103 m
.25891 .19501 L
s
.79523 .24158 m
.80052 .2434 L
s
.78074 .17733 m
.781 .18532 L
s
.25574 .20794 m
.25726 .20347 L
s
.25726 .20347 m
.25838 .21103 L
s
.27141 .15941 m
.27301 .15497 L
s
.78243 .18578 m
.78423 .19823 L
s
.7873 .20716 m
.7902 .21209 L
s
.78591 .20671 m
.7902 .21209 L
s
.781 .18532 m
.78282 .19778 L
s
.78423 .19823 m
.7873 .20716 L
s
.78282 .19778 m
.78591 .20671 L
s
.76684 .15329 m
.7701 .16217 L
s
.76212 .14796 m
.76684 .15329 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27252 .18793 m
.27272 .18968 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76656 .18352 m
.76672 .1843 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76672 .1843 m
.76678 .18619 L
s
.76822 .1852 m
.76826 .18656 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75901 .14708 m
.76212 .14796 L
s
.75598 .1502 m
.75901 .14708 L
s
.75439 .14977 m
.75901 .14708 L
s
.77073 .18217 m
.77098 .1902 L
s
.76922 .18173 m
.76959 .19379 L
s
.76972 .19781 m
.77098 .1902 L
s
.75302 .15736 m
.75598 .1502 L
s
.75141 .15694 m
.75439 .14977 L
s
.76832 .20141 m
.76959 .19379 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27074 .22724 m
.27078 .17936 L
s
.26778 .2281 m
.27078 .17936 L
s
.26925 .22767 m
.27002 .20344 L
s
.76832 .20141 m
.76972 .19781 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75176 .169 m
.75302 .15736 L
s
.26778 .2281 m
.269 .23578 L
s
.75013 .16858 m
.75141 .15694 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76537 .20461 m
.76832 .20141 L
s
.75199 .17705 m
.77073 .18217 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73104 .14003 m
.74288 .14283 L
s
.269 .23578 m
.27074 .22724 L
s
.76069 .20336 m
.76537 .20461 L
s
.75176 .169 m
.75199 .17705 L
s
.75013 .16858 m
.75036 .17664 L
s
.73786 .14161 m
.73907 .18602 L
s
.75199 .17705 m
.75395 .18958 L
s
.73617 .14121 m
.73737 .18563 L
s
.75036 .17664 m
.75234 .18917 L
s
.7574 .19849 m
.76069 .20336 L
s
.7558 .19808 m
.76069 .20336 L
s
.75395 .18958 m
.7574 .19849 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75234 .18917 m
.7558 .19808 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7116 .13593 m
.72409 .13849 L
s
.73758 .19376 m
.73907 .18602 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73587 .19339 m
.73737 .18563 L
s
.73253 .19672 m
.73758 .19376 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71878 .13738 m
.71989 .18198 L
s
.717 .13701 m
.71809 .18163 L
s
.73253 .19672 m
.73587 .19339 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69118 .13222 m
.70428 .13453 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72905 .196 m
.73253 .19672 L
s
.72366 .19084 m
.72905 .196 L
s
.71989 .18198 m
.72366 .19084 L
s
.71829 .18979 m
.71989 .18198 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71295 .19287 m
.71829 .18979 L
s
.71649 .18945 m
.71809 .18163 L
s
.69684 .13319 m
.69809 .19029 L
s
.69871 .13352 m
.69998 .1906 L
s
.71295 .19287 m
.71649 .18945 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67773 .13008 m
.67885 .18736 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6699 .12894 m
.68354 .13098 L
s
.5 Mabswid
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67578 .12979 m
.67689 .18709 L
s
.70928 .1922 m
.71295 .19287 L
s
.70363 .18713 m
.70928 .1922 L
s
.6997 .1783 m
.70363 .18713 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64784 .12609 m
.66196 .12785 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6924 .18938 m
.69998 .1906 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65594 .12707 m
.6567 .17215 L
s
.65393 .12682 m
.65468 .17191 L
s
.62513 .12371 m
.63965 .12517 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67096 .18629 m
.67885 .18736 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60831 .12637 m
.61264 .13491 L
s
.60187 .1218 m
.60831 .12637 L
s
.5976 .12151 m
.60187 .1218 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65278 .17993 m
.65468 .17191 L
s
.65481 .18016 m
.6567 .17215 L
s
.59334 .12533 m
.5976 .12151 L
s
.59119 .1252 m
.5976 .12151 L
s
.67729 .20775 m
.67934 .21217 L
s
.67539 .21164 m
.67729 .20775 L
s
.67745 .21605 m
.67934 .21217 L
s
.64875 .18361 m
.65481 .18016 L
s
.64875 .18361 m
.65278 .17993 L
s
.67539 .21164 m
.67745 .21605 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58695 .13316 m
.59119 .1252 L
s
.58911 .13328 m
.59334 .12533 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64464 .18317 m
.64875 .18361 L
s
.54545 .11926 m
.56078 .11967 L
s
.58705 .14552 m
.58911 .13328 L
s
.63409 .16971 m
.63837 .17839 L
s
.58488 .1454 m
.58695 .13316 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63837 .17839 m
.64464 .18317 L
s
.50149 .11923 m
.51467 .11906 L
s
.52787 .11904 m
.54106 .11918 L
s
.6108 .15945 m
.61297 .16375 L
s
.60871 .16343 m
.6108 .15945 L
s
.58705 .14552 m
.58711 .15378 L
s
.61297 .16375 m
.61302 .16789 L
s
.58488 .1454 m
.58495 .15366 L
s
.60871 .16343 m
.61089 .16773 L
s
.255 .412 .882 r
.5018 .15744 m
.50277 .15794 L
s
0 0 0 r
.60884 .17586 m
.61302 .16789 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63138 .12431 m
.63258 .21106 L
s
.63346 .12452 m
.63467 .21125 L
s
.255 .412 .882 r
.55069 .1639 m
.55205 .15841 L
s
.50644 .15743 m
.50712 .15788 L
s
.50712 .16077 m
.50277 .15794 L
s
.5093 .16075 m
.50712 .15788 L
s
0 0 0 r
.51024 .14382 m
.53009 .14378 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52126 .19367 m
.53447 .11909 L
s
.255 .412 .882 r
.55039 .1643 m
.55069 .1639 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6046 .17971 m
.60884 .17586 L
s
.58495 .15366 m
.58721 .1662 L
s
.58711 .15378 m
.58938 .16632 L
s
.55422 .11947 m
.55445 .17737 L
s
.55203 .11941 m
.55224 .17732 L
s
.58938 .16632 m
.59378 .17487 L
s
.58721 .1662 m
.59162 .17475 L
s
.55435 .15245 m
.5566 .16495 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59814 .17929 m
.6046 .17971 L
s
.59378 .17487 m
.59814 .17929 L
s
.59162 .17475 m
.59814 .17929 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5698 .16955 m
.57196 .16548 L
s
.57196 .16548 m
.57417 .16972 L
s
.62625 .21051 m
.63467 .21125 L
s
.57417 .16972 m
.5742 .17388 L
s
.5698 .16955 m
.57201 .17379 L
s
.5566 .16495 m
.56104 .1734 L
s
.57204 .17795 m
.5742 .17388 L
s
.56104 .1734 m
.56545 .17771 L
s
.56545 .17771 m
.57204 .17795 L
s
.54562 .17718 m
.55445 .17737 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50588 .11916 m
.52126 .20625 L
s
.52126 .20625 m
.53666 .11912 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00103o
YQ07000000H0ojH@1`0000020?nV40@000007@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40503oYQ4@0:f][@030000002][Jd0
[Jf]00/0[Jf]0P0000070:f][@D000002P2][Jd?0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Je[
0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@l0[Jf]1`3oYQ400`2]
[Jd0ojH@0?nV40060?nV40030000003oYQ00ojH@00/0ojH@0P0000060?nV40030:f][@0000000000
00d0ojD@1`2][Jd4000000T0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0
[Jf]5P3oYQ400`2][Jd0ojH@0?nV40070?nV40030000003oYQ00ojH@00X0ojH@0P0000060?nV4003
0:f][@00000000000140ojD@0`0000040?nU408000000P3oYA000`2][Jd0oj<@0?nS40020?nS4003
0:f][@000000000000L000003@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]
103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@00L0ojH@00<000000?nV403oYQ00
2@3oYQ02000000L0ojH@00<0[Jf]000000000000403oYA02000000P0ojD@00<000000?nU402][Jd0
203oXa02000000<0oj<@102][Jd5000000030:f][@3oXa00oj<@0080oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo
001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
40070?nV40030000003oYQ00ojH@00T0ojH@0P0000070?nV40030:f][@00000000000100ojD@0P00
00080?nU40030000003oYA00[Jf]00P0oj<@0P00000:0?nS40D000000`2][Jd3000001L0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H2
0:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ40
0`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@00L0ojH@00<000000?nV403oYQ002@3oYQ02
000000L0ojH@00<0[Jf]0000000000003`3oYA02000000X0ojD@00<000000:f][@3oXa001`3oXa02
000000X0oj<@0P0000050?nS40030:f][@3lX100o:0@00D0000000<0[Jf]0?bP403lX100403lX100
0`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3P
iP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1@2][Jd20?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV40070?nV
40030000003oYQ00ojH@00T0ojH@0P0000070?nV40030:f][@000000000000l0ojD@0P00000:0?nU
40030000002][Jd0oj<@00L0oj<@0P00000:0?nS408000001@3oXa000`2][Jd0o:0@0?bP40020000
00@0o:0@0P2][Jd4000000`0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00/0ojHA1@2][Jd70?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV40070?nV4003
0000003oYQ00ojH@00T0ojH@0P0000070?nV40030:f][@000000000000l0ojD@0P00000;0?nU4003
0000003oXa00oj<@00H0oj<@0P00000:0?nS408000001@3oXa000`2][Jd0o:0@0?bP4002000000T0
o:0@1@0000080?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0ojHA1P2][Jd<0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV40080?nV40030000
003oYQ00ojH@00P0ojH@0P0000070?nV40030:f][@000000000000l0ojD@0P00000;0?nU40030:f]
[@3oXa00oj<@00H0oj<@0P00000:0?nS408000001@3oXa000`2][Jd0o:0@0?bP4002000000T0o:0@
0P0000030?bP4080[Jf]1@0000000`3lX100[Jf]0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@2]
[JdB0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
40080?nV40030000003oYQ00ojH@00L0ojH@0P0000080?nV40030:f][@000000000000h0ojD@0P00
000<0?nU40030:f][@3oXa00oj<@00H0oj<@0P00000:0?nS408000001@3oXa000`2][Jd0o:0@0?bP
4002000000T0o:0@0P0000080?bP40D000005@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A01<0oj@A102][JdG0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV40080?nV40030000003oYQ00ojH@00L0ojH@0P000008
0?nV40030:f][@000000000000h0ojD@0P00000<0?nU40030:f][@3oXa00oj<@00H0oj<@0P00000:
0?nS408000001@3oXa000`2][Jd0o:0@0?bP4002000000T0o:0@0P0000080?bP4080000000<0o:0@
0:f][@3fW0l00P2][Jd4000000l0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@08
0=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00203oYQ000`000000ojH@0?nV40070?nV
40800000203oYQ000`2][Jd000000000000>0?nU40800000303oYA000`2][Jd0oj<@0?nS40060?nS
408000002P3oXa02000000D0oj<@00<0[Jf]0?bP403lX1000P0000090?bP40800000203lX1020000
00030?bP402][Jd0mY`?00@0mY`?00<0[Jf]0000000000000P00000<0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2][Jd;0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00203oYQ0<000000P0ojH@00<0[Jf]0000000000003P3oYA02000000`0ojD@00<0[Jf]0?nS403o
Xa001P3oXa02000000X0oj<@0P0000050?nS40030:f][@3lX100o:0@008000002@3lX102000000P0
o:0@0P0000000`3lX100[Jf]0?JL3`050?JL3`030000003fW0l0mY`?00@0[Jf]2@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00
I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
1`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ002@3oYQ000`000000ojH@0?nV40060?nV40800000
203oYQ000`2][Jd000000000000>0?nU40800000303oYA000`2][Jd0oj<@0?nS40060?nS40800000
2P3oXa02000000D0oj<@00<0[Jf]0?bP403lX1000P0000090?bP40800000203lX102000000030?bP
402][Jd0mY`?00D0mY`?00<000000?JL3`3fW0l0103fW0l40:f][@030000003fW0l0mY`?0080mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`
h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV40090?nV40030000003oYQ00ojH@00H0ojH@0P0000080?nV40030:f][@00
0000000000h0ojD@0P00000<0?nU40030:f][@3oXa00oj<@00H0oj<@0P00000:0?nS408000001P3o
Xa00102][Jd0o:0@0000000000090?bP40800000203lX102000000030?bP402][Jd0mY`?00D0mY`?
00<000000?JL3`3fW0l01`3fW0l00`000000[Jf]000000020:f][@030?JL3`2][Jd0k9H>0140k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0:f][@1@0;3PiP40oooo001U0;3PiP030:f][@3C
Q`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`000000oj@A0:f][@030:f][A40oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ002@3oYQ000`000000ojH@0?nV40050?nV408000002@3oYQ000`2][Jd000000000
000>0?nU40800000303oYA000`2][Jd0oj<@0?nS40060?nS408000002P3oXa02000000H0oj<@00@0
[Jf]0?bP4000000000002@3lX102000000P0o:0@0P0000000`3lX100[Jf]0?JL3`050?JL3`030000
003fW0l0mY`?00H0mY`?00@000000?JL3`3fW0l0mY`?0P0000030:f][A40k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd0102][Jd0^GD;0;Ue2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f]
[@d0kiP@00<0[Jf]0?bP403lX1003P3lX1000`2][Jd000000:f][@0E0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
00T0ojH@00<000000?nV403oYQ001@3oYQ02000000T0ojH@00<0[Jf]0000000000003P3oYA020000
00`0ojD@00<0[Jf]0?nS403oXa001P3oXa02000000X0oj<@0P0000060?nS40040:f][@3lX1000000
000000T0o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l01@3fW0l00`000000mY`?0?JL3`05
0?JL3`8000001@3fW0l00`000000[Jf]0>bF3P030:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
1@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f]
[@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX10000000000000E0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@00T0ojH@00<000000?nV403oYQ001@3oYQ02000000T0ojH@00<0[Jf]0000000000003P3o
YA02000000`0ojD@00<0[Jf]0?nS403oXa001P3oXa02000000X0oj<@0P0000060?nS40040:f][@3l
X1000000000000T0o:0@0P0000080?bP4080000000<0o:0@0:f][@3fW0l01@3fW0l00`000000mY`?
0?JL3`050?JL3`030000003fW0l0mY`?00@0mY`?00<000000:f][@3/UPh00`3/UPh20:f][@`0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`
h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3l
X102000000<0[Jf]0`3lX1000`000000oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4A<0[Jf]00<000000:f][@2][Jd01@2]
[Jd2000000X0[Jf]0P0000050:f][@T0ojD@0P00000<0?nU40030:f][@3oXa00oj<@00H0oj<@0P00
000:0?nS408000001P3oXa00102][Jd0o:0@0000000000090?bP40800000203lX102000000030?bP
402][Jd0mY`?00D0mY`?00<000000?JL3`3fW0l0103fW0l2000000H0mY`?00<000000:f][@3/UPh0
1@3/UPh30:f][@8000001`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;
00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001@3lX102000000030:f][@000000o:0@00D0o:0@00<0
00000?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ002P3oYQ000`000000ojH@0?nV
40040?nV408000002@3oYQ000`2][Jd00000000000050?nU40T0[Jf]0P0000050:f][@H0ojD@00<0
00000:f][@3oXa001`3oXa02000000X0oj<@0P0000060?nS40040:f][@3lX1000000000000T0o:0@
0P0000080?bP4080000000<0o:0@0:f][@3fW0l01@3fW0l00`000000mY`?0?JL3`040?JL3`800000
1`3fW0l00`000000k9H>0>bF3P050>bF3P80000000D0[Jf]0000002][Jd0k9H>000000040>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3PiP40
oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP40020?bP40030000003lX10000000080[Jf]0P3lX1000`000000o:0@0?bP40030?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@`0[Jf]
5`3oYQ400`2][Jd0ojH@0?nV400:0?nV40030000003oYQ00ojH@00@0ojH@0P0000090?nV40040:f]
[@0000000000000000d0ojD@0P0000050?nU40D0[Jf]0P0000050:f][@@0oj<@0P00000:0?nS4080
00001P3oXa000`2][Jd0o:0@0?bP4002000000P0o:0@0P0000090?bP40030000003lX100[Jf]00H0
mY`?00<000000?JL3`3fW0l0103fW0l2000000L0mY`?00<000000>bF3P3/UPh0103/UPh2000000<0
k9H>00<000000:f][@0000000P0000020>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>
00<0[Jf]0>nH403_V1002`3_V100202][Jd0o:0@0000003lX100[Jf]0000002][Jd000001@3lX100
0`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@00X0ojH@00<000000?nV403oYQ000`3oYQ02000000X0ojH@00@0[Jf]00000000000000003P3o
YA02000000T0ojD@00<000000?nU40000000103oXa040:f][@800000102][Jd60?nS408000001P3o
Xa000`2][Jd0o:0@0?bP4002000000T0o:0@00<000000?bP403lX1001`3lX1000`000000o:0@0:f]
[@060?JL3`030000003fW0l0mY`?00@0mY`?00<000000?JL3`3fW0l01P3fW0l00`000000k9H>0>bF
3P040>bF3P030000003/UPh0k9H>0080k9H>00<000000>bF3P0000000`2][Jd00`3/UPh0[Jf]0=^:
3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H0
0`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@0P0000020:f][@040?bP40000000
o:0@000000D0o:0@00<000000?bP403lX1000P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@d0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400:0?nV40030000003oYQ00ojH@00<0ojH@0P00000:0?nV40040:f][@00
00000000000000L0ojD@00<000000?nU403oYA00103oYA02000000T0ojD@00<000000?nU40000000
203oXa02000000@0oj<@1P2][Jd200000080[Jf]103oXa000`2][Jd0o:0@0?bP4002000000T0o:0@
0P0000080?bP40030000003lX100[Jf]00H0mY`?00<000000?JL3`3fW0l0103fW0l00`000000mY`?
0?JL3`060?JL3`030:f][@3/UPh0k9H>00<0k9H>0P0000040>bF3P030000003/UPh0000000<0k9H>
0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030000002][Jd0o:0@0080o:0@0P0000060?bP40030000003l
X100o:0@0080o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]5`3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00X0ojH@00<000000?nV403oYQ000`3o
YQ02000000X0ojH@00@0[Jf]00000000000000001P3oYA02000000H0ojD@0P00000:0?nU40800000
203oXa02000000X0oj<@0P0000020?nS40L0[Jf]0P0000090?bP40800000203lX1000`000000o:0@
0:f][@060?JL3`8000001@3fW0l00`000000mY`?0?JL3`060?JL3`030:f][@3/UPh0k9H>00<0k9H>
0P0000050>bF3P800000103/UPh30:f][@8000002@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]
A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1001`3_V10200000080[Jf]00<0
00000?bP403lX1000P3lX102000000D0o:0@00<000000?bP403lX1000`3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1P2][Jd20?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400;0?nV40030000003oYQ00ojH@0080ojH@0P00
000:0?nV40050:f][@00000000000?nU400000001@3oYA000`000000ojD@000000060?nU40800000
2@3oYA02000000T0oj<@0P0000090?nS408000001P3oXa000`2][Jd0o:0@0?bP4002000000D0[Jf]
103lX102000000P0o:0@00<000000?bP402][Jd01P3fW0l2000000D0mY`?00<000000?JL3`3fW0l0
1P3fW0l00`2][Jd0k9H>0>bF3P030>bF3P8000001@3/UPh2000000@0k9H>00<0[Jf]000000000000
0P2][Jd00`000000fhX=0=^:3@060=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0
AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00H0kiP@0P00
0000102][Jd000000000000000040?bP408000001@3lX1000`000000o:0@0?bP40030?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@P0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00/0ojH@00<000000?nV403oYQ00
0P3oYQ02000000X0ojH@00D0[Jf]000000000000ojD@000000050?nU40030000003oYA00000000H0
ojD@0P0000090?nU40030000002][Jd0oj<@00P0oj<@0P0000090?nS408000001P3oXa000`2][Jd0
o:0@0?bP4002000000D0o:0@102][Jd2000000030:f][@3lX100o:0@00D0o:0@00<000000?bP402]
[Jd01P3fW0l2000000D0mY`?00<000000?JL3`3fW0l01P3fW0l00`2][Jd0k9H>0>bF3P030>bF3P80
00001P3/UPh00`000000k9H>0>bF3P020>bF3P030:f][@00000000000080fhX=00<000000:f][@3K
RPd01P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V
00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH40030:f][@000000kiP@0080
kiP@0P0000040?bP40030000003lX100o:0@00@0o:0@00<000000?bP403lX1000`3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00H0ojHA1@2][Jd=0?nV4@030:f][@3oYQ40ojHA01T0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400;0?nV40030000003oYQ00ojH@0080
ojH@0P00000:0?nV40030:f][@00000000000080ojD@00<000000?nU403oYA000`3oYA02000000L0
ojD@0P0000080?nU40030000002][Jd0oj<@00P0oj<@0P0000090?nS408000001P3oXa000`2][Jd0
o:0@0?bP4002000000T0o:0@0P0000000`3lX100[Jf]0:f][@040:f][@040?bP40000000o:0@0:f]
[@H0mY`?0P0000050?JL3`030000003fW0l0mY`?00H0mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh00`00
0000k9H>0>bF3P050>bF3P030000003/UPh0k9H>0080k9H>0P0000040=^:3@030000002][Jd0fhX=
00D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40oooo001K0;3P
iP040:f][@2GH0/0Uf0;0:f][@P0dhL>00D0[Jf]0>nH403_V100kiP@000000020>nH40030:f][@00
0000000000@0kiP@00<000000?bP403lX1000P3lX1000`000000o:0@0?bP40040?bP40030000003l
X100o:0@00<0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060:f][A80ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00/0ojH@00L0
00000?nV403oYQ00ojH@0000003oYQ00000000X0ojH@00<0[Jf]0000000000000`3oYA000`000000
ojD@0?nU40020?nU40800000203oYA02000000H0ojD@00<000000?nU402][Jd02@3oXa03000000P0
oj<@0P0000060?nS40030:f][@3lX100o:0@008000002@3lX102000000L0o:0@00<0[Jf]0000002]
[Jd00P2][Jd50?JL3`8000001@3fW0l00`000000mY`?0?JL3`060?JL3`030:f][@3/UPh0k9H>00<0
k9H>00<000000>bF3P3/UPh01@3/UPh00`000000k9H>0>bF3P020>bF3P800000103KRPd01@000000
fhX=0:f][@2][Jd0000000<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0
[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P050:f][@3_V100
00000000003_V1000P2][Jd00`3_V1000000000000040>nH40030000003lX100o:0@0080o:0@00<0
00000?bP403lX1000`3lX102000000D0o:0@00<0[Jf]0?nT4@3oY1404P3oY1440:f][AP0ojHA00<0
[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00/0ojH@00@0
00000?nV403oYQ00ojH@0P0000090?nV40D00000103oYA001@000000ojD@0?nU403oYA00000000X0
ojD@0P0000050?nU40030000003oYA00[Jf]00T0oj<@0`0000070?nS408000001`3oXa000`2][Jd0
o:0@0?bP4002000000T0o:0@0P0000080?bP40040000003lX100[Jf]0?JL3`@0[Jf]00<0mY`?0000
000000001@3fW0l2000000L0mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P050>bF
3P030000003/UPh0k9H>0080k9H>0P0000040=^:3@090000003KRPd0fhX=0=^:3@000000[Jf]0000
003KRPd0[Jf]00T0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd0203CQ`h01@2][Jd000000>nH40000000[Jf]00<0kiP@00<000000>nH
403_V1000`3_V1000`000000o:0@0?bP40080?bP408000001@3lX1000`000000oj@A0?nT4@0>0?nT
4@@0[Jf]00<0oj@A0:f][@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ002`3oYQ0010000000ojH@0?nV403oYQ02000000/0ojH@00<0[Jf]
0?nU403oYA001@3oYA04000000`0ojD@0P0000020?nU40040000003oYA00ojD@0:f][@T0oj<@0P00
00000`3oXa0000000?nS40050?nS408000001`3oXa000`2][Jd0o:0@0?bP4002000000T0o:0@0P00
00080?bP40030000003lX100[Jf]00D0mY`?00@0[Jf]000000000000[Jf]103fW0l00`000000mY`?
00000002000000@0mY`?00<0[Jf]0>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P050>bF3P030000
003/UPh0k9H>0080k9H>0P0000050=^:3@050000003KRPd0fhX=0000003KRPd00`0000090;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;
09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00@000000:f][@2][Jd00000103_V1000`000000
kiP@0>nH40030>nH40030000003lX100o:0@00L0o:0@0P0000060?bP40030000003oY140oj@A00X0
oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00`0ojH@00<000000?nV403oYQ000P00000;0?nV4003
0:f][@3oYA00ojD@01L0ojD@0P0000030?nU40030:f][@3oXa00oj<@00L0oj<@0P0000020?nS4080
0000103oXa02000000L0oj<@00<0[Jf]0?bP403lX1000P0000090?bP40800000203lX1000`000000
o:0@0:f][@060?JL3`80000000<0mY`?0:f][@2][Jd00P2][Jd00`000000mY`?0?JL3`020?JL3`@0
000000<0[Jf]0>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P050>bF3P030000003/UPh0k9H>0080
k9H>0P0000050=^:3@030000003KRPd0fhX=008000000P3KRPd00`000000^GD;0;Ue2`070;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00L0dhL>0P0000000`2][Jd0kiP@000000050>nH40030000003_V100kiP@00<0
kiP@00<000000?bP403lX1001P3lX1000`000000o:0@000000060?bP40030000003oY140oj@A00L0
oj@A0`2][Jd90?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00`0ojH@00<000000?nV403oYQ000P00000;0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001`3oXa02000000@0oj<@100000090?nS4003
0:f][@3lX100o:0@008000002@3lX102000000P0o:0@00<000000?bP402][Jd01P3fW0l2000000D0
mY`?00@000000:f][@2][Jd0[Jf]103fW0l00`11JN400000000000040>bF3P030000003/UPh0k9H>
00D0k9H>0P0000030>bF3P8000001@3KRPd01@000000fhX=0=^:3@3KRPd000000080fhX=00<0[Jf]
0000002iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool0
05T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P8000000P2][Jd00`3_V10000000>nH4004
0>nH40030000003_V100kiP@0080kiP@00<0[Jf]0000003lX1001`3lX102000000L0o:0@00<00000
0?nT4@3oY1400`3oY1440:f][@`0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00303oYQ000`000000ojH@0?nV4002
000000/0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40070?nS408000004@3oXa00
0`2][Jd0o:0@0?bP4002000000T0o:0@0P0000070?bP4080000000<0o:0@0:f][@3fW0l01@3fW0l2
000000H0mY`?00<000000?JL3`3fW0l0102][Jd00`3fW0l00000000000040>bF3P8000001P3/UPh2
000000<0k9H>0P0000090=^:3@050000003KRPd0fhX=0:f][@0000000P2][Jd00`2iM@/000000;Ue
2`030;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>00H0[Jf]0000003CQ`h0[Jf]0>nH400000050>nH4003
0000003_V100kiP@0080kiP@00<0[Jf]0000003lX1001P3lX102000000P0o:0@00<000000?nT4@2]
[Jd00`2][Jd@0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@00`0ojH@00D000000?nV40000000ojH@0000000;0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001`3oXa0200000140oj<@1@0000090?bP
40<000001P3lX103000000030:f][@3fW0l0mY`?00@0mY`?0P0000060?JL3`030000003fW0l0mY`?
00@0mY`?00<0[Jf]000000000000103/UPh2000000H0k9H>0P0000030>bF3P8000002@3KRPd02@00
0000fhX=0=^:3@2][Jd0^GD;0000002iM@/0[Jf]000000040;Ue2`030:f][@28EPL0R5H70080R5H7
00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>
00L0[Jf]0=>73P000000dhL>0:f][@3_V100000000D0kiP@00<000000>nH403_V1000P3_V1000`2]
[Jd000000?bP40060?bP408000001`3lX1000`2][Jd000000:f][@0D0?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
00`0ojH@00@000000?nV400000000000303oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@00L0oj<@0P00000A0?nS40030:f][@3lX100o:0@00P0o:0@0P0000001@3lX10000000000003l
X100000000D0o:0@0`0000000`2][Jd0mY`?0?JL3`030?JL3`030000003fW0l0000000H0mY`?00<0
00000?JL3`3fW0l01@3fW0l2000000<0[Jf]00<0k9H>0000000000001P3/UPh2000000<0k9H>0P00
00090=^:3@060000003KRPd0fhX=0:f][@2iM@/000000P2iM@/00`000000^GD;0;Ue2`020;Ue2`03
0:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00P3CQ`h00`000000dhL>0:f][@030=>73P040000002][Jd0kiP@000000D0kiP@00<000000>nH
403_V1000P3_V1000`2][Jd000000?bP40050?bP408000001@3lX1030:f][@030?bP40000000oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ003@3oYQ03000000`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS40070?nS408000004@3oXa000`2][Jd0o:0@0?bP400:0?bP40<000000P3lX1001000
0000o:0@0?bP403lX103000000030?bP40000000mY`?00@0mY`?0P0000070?JL3`030000003fW0l0
mY`?00D0mY`?0P0000030>bF3P030:f][@000000000000H0k9H>0P0000030>bF3P800000303KRPd0
0`2][Jd0^GD;000000020;Ue2`030000002][Jd0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL2
0:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P800000103CQ`h0
0`000000[Jf]000000060>nH40030000003_V100kiP@0080kiP@00<000000?bP403lX100103lX100
0`000000o:0@000000030?bP4080[Jf]0`3lX102000001D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ003@3oYQ03
000000`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40070?nS408000004@3oXa00
0`2][Jd0o:0@0?bP400@0?bP40@000000`3lX1000`2][Jd000000?JL3`030?JL3`8000001`3fW0l2
000000H0mY`?0P0000050>bF3P030000002][Jd0[Jf]00@0k9H>0P0000030>bF3P800000303KRPd0
0`2][Jd0^GD;000000020;Ue2`060000002iM@/0[Jf]0:f][@2iM@/0[Jf]1028EPL20:f][D80/>3V
0@3oool005T0/>3V00T0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h000000:f][@000000103CQ`h00`00
0000[Jf]000000060>nH40030000003_V100kiP@0080kiP@00<000000?bP403lX100103lX1020000
00050?bP402][Jd0[Jf]0:f][@000000103lX102000001D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA5`2][Jd00`000000[Jf]0000000D
0:f][AL0ojD@00<0[Jf]0?nS403oXa001`3oXa0200000140oj<@00<0[Jf]0?bP403lX100603lX100
1`2][Jd000000?JL3`3fW0l000000?JL3`000000203fW0l00`000000mY`?0?JL3`040?JL3`030000
003/UPh0k9H>00@0k9H>00<000000>bF3P3/UPh00`2][Jd00`3/UPh00000000000030>bF3P800000
303KRPd00`2][Jd0^GD;000000060;Ue2`80[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V00@0
[Jf]09MP2`2GH0/0Uf0;0P2][Jd010000000dhL>0000000000030=>73P030000002][Jd0000000H0
kiP@00<000000>nH403_V1000P3_V1000`000000o:0@0?bP40030?bP408000000P2][Jd30?bP4003
0000003lX100o:0@0080o:0@0P00000E0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400=0?nV4003
0000003oYQ00000000`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403o
Xa001`3oXa0200000140oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?00000003000000T0
mY`?0P0000050?JL3`030000003/UPh0k9H>00@0k9H>00<000000>bF3P3/UPh00`3/UPh00`2][Jd0
0000000000030>bF3P@000002P3KRPd00`2][Jd0^GD;000000070;Ue2`030:f][@28EPL0R5H700<0
R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H0202][Jd0Uf0;09MP2`000000[Jf]0=>7
3P000000dhL>0P0000030=>73P030000002][Jd0000000H0kiP@00<000000>nH403_V1000P3_V100
0`000000o:0@0?bP40020?bP40030:f][@000000o:0@00@0o:0@0P0000040?bP408000005@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdG0?nV4@030:f][@3oYQ00
ojH@00d0ojH@00<000000?nV40000000303oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]1@3oXa02
00000140oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0<0?JL3`8000001@3fW0l0
0`000000k9H>0>bF3P040>bF3P030000003/UPh0k9H>00@0k9H>0P0000020:f][@030>bF3P000000
00000080fhX=0P0000090=^:3@030:f][@000000^GD;00H0^GD;0P2][Jd408QF1`030:f][@2`h>H0
/>3V0400/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/000000:f][@0000020=>73P8000000`3C
Q`h00`000000kiP@000000060>nH40030000003_V100kiP@0080kiP@00<000000?bP402][Jd00P2]
[Jd00`3lX10000000?bP40040?bP40800000103lX102000001D0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@00d0ojH@0P00000=0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3o
Xa050:f][@8000000`2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03@3f
W0l2000000@0mY`?00<000000>bF3P3/UPh0103/UPh00`000000k9H>0>bF3P040>bF3P8000000P3/
UPh00`2][Jd00000000000040=^:3@8000001`3KRPd2000000L0^GD;0P2][Jd408QF1`030:f][@2`
h>H0/>3V0400/>3V0@3oool005T0/>3V00H0[Jf]09MP2`00000000000:f][@0000020=>73P800000
0`3CQ`h00`2][Jd000000>nH40060>nH40030000003_V100kiP@0080kiP@00<000000:f][@3lX100
0`3lX1000`000000o:0@0?bP40030?bP40800000103lX102000001D0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@00h0ojH@00<000000?nV403oYQ002`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@00L0oj<@0P0000030?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f]
[@3fW0l0mY`?00l0mY`?00D000000?JL3`3fW0l000000:f][@060>bF3P8000001@3/UPh2000000<0
k9H>00@0[Jf]0000002][Jd0[Jf]0`3KRPd00`000000fhX=0=^:3@040=^:3@030000002][Jd00000
00L0^GD;00<0[Jf]08QF1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP06
0:f][@00000000000000002][Jd000000P3CQ`h2000000<0dhL>00<0[Jf]0000003_V1001@3_V100
10000000kiP@0>nH403_V1020:f][@030000003lX100o:0@00<0o:0@00<000000?bP403lX1000`3l
X102000000@0o:0@0P00000E0?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdH0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ003P3oYQ000`000000ojH@0?nV400;0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001`3oXa02000000d0oj<@202][JdG0?bP40030:f][@3f
W0l0mY`?0100mY`?0P0000000`3fW0l0[Jf]0>bF3P060>bF3P030000003/UPh0k9H>00<0k9H>0P00
00030>bF3P040:f][@000000fhX=0=^:3@80[Jf]00<0fhX=0000003KRPd01@3KRPd2000000P0^GD;
00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP060:f]
[@00000000000000002][Jd000000`3CQ`h01P000000dhL>0=>73P3CQ`h0[Jf]000000H0kiP@00@0
00000>nH402][Jd0[Jf]0P3_V1000`000000o:0@0?bP40030?bP40030000003lX100o:0@0080o:0@
0`0000040?bP408000005@3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ003P3oYQ000`000000ojH@
0?nV400;0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001`3oXa0200000140oj<@
00@0[Jf]0?bP403lX10000001`2][Jd@0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh0103/UPh2000000<0k9H>00<000000>bF3P0000000`3/UPh00`2][Jd000000=^:3@030=^:3@03
0:f][@000000000000@0fhX=0P0000000`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H708QF
1`2][Jd0R5H70:f][@120;3PiP40oooo001I0;3PiP060:f][@00000000000000002][Jd000000`3C
Q`h01P000000dhL>0=>73P3CQ`h0[Jf]000000H0kiP@00<000000:f][@3_V1000`3_V1000`000000
o:0@0?bP40030?bP40030000003lX100o:0@0080o:0@00<000000?bP40000000103lX102000001D0
oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS40070?nS408000004@3oXa00102][Jd0o:0@0000000000070?bP40H0[Jf]2P3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00D0k9H>00L000000>bF3P3/UPh0k9H>0000003/
UPh0000000<0k9H>00<0[Jf]0000003KRPd0103KRPd2000000070:f][@3KRPd0fhX=0000003KRPd0
00000:f][@080;Ue2`070:f][@28EPL0R5H708QF1`2][Jd0R5H70:f][@120;3PiP40oooo001H0;3P
iP030000002][Jd0000000@000000`3CQ`h01P000000dhL>0=>73P3CQ`h0[Jf]000000@0kiP@0P2]
[Jd00`000000kiP@0>nH40030>nH40030000003lX100o:0@00<0o:0@00D000000?bP403lX100o:0@
000000020?bP40030000003lX100o:0@0080o:0@0P00000E0?nT4@040:f][@3oYQ40ojHA0?nV4@H0
[Jf]403oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00@0oj<@1@00000A0?nS4005
0:f][@3lX10000000?bP40000000303lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P050>bF3P8000000P3/UPh00`000000k9H>000000030>bF3P030:f][@0000000000
00@0fhX=0P0000001`3KRPd0[Jf]0000003KRPd000000=^:3@2][Jd00`2iM@/00`000000^GD;0;Ue
2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001H0;3PiP<0000000@0Uf0;
00000000000000000`3CQ`h010000000dhL>0=>73P3CQ`h200000080kiP@0P2][Jd20>nH40030000
003_V100kiP@00<0kiP@00<000000?bP403lX1000`3lX1000`000000o:0@0?bP4002000000L0o:0@
0P00000D0?nT4@D0[Jf]5P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00D0[Jf]0?bP40000000o:0@0000000C0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P060>bF3P<0
00000P3/UPh01`000000k9H>0>bF3P3/UPh0[Jf]0=^:3@000000103KRPd010000000fhX=0=^:3@3K
RPd2000000030:f][@3KRPd0[Jf]00<0^GD;00<000000;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF
1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005L0/>3V0`00000209MP2`<000000P3CQ`h2
000000<0dhL>00@000000>nH40000000[Jf]103_V1000`000000kiP@0>nH40030>nH40030000003l
X100o:0@00@0o:0@0P0000090?bP40800000403oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@000001L0o:0@
00<0[Jf]0?JL3`3fW0l0102][Jd@0?JL3`030:f][@3/UPh0k9H>00/0k9H>00H000000>bF3P3/UPh0
k9H>0:f][@3KRPd2000000<0fhX=00D000000=^:3@3KRPd0fhX=000000020=^:3@80[Jf]0`2iM@/0
0`000000^GD;0;Ue2`030;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3P
iP<000000P2GH0/300000080dhL>0P0000030=>73P030000002][Jd0000000D0kiP@00<000000>nH
403_V1000`3_V1000`000000o:0@0?bP400>0?bP40<00000303oY1440:f][@D0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP
403lX10000005`3lX1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l00`2][Jd0k9H>0>bF3P0;
0>bF3P060000003/UPh0k9H>0>bF3P2][Jd0fhX=0P0000030=^:3@050000003KRPd0fhX=0=^:3@00
00000`3KRPd20:f][@80^GD;00<000000;Ue2`2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80
[Jf]@@2`h>H10?ooo`00E`2`h>H30000000309MP2`0000000000008000000P3CQ`h200000080dhL>
00@0[Jf]0000003_V10000001@3_V1000`000000kiP@0>nH40030>nH40030000003lX100o:0@00h0
o:0@0`0000080?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0
mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>00/0k9H>00D000000>bF3P3/UPh0k9H>0:f][@020=^:
3@050000003KRPd0fhX=0=^:3@0000000`3KRPd01P000000fhX=0=^:3@3KRPd0[Jf]00000080[Jf]
00<000000;Ue2`2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H30000000409MP2`000000Uf0;000000<0dhL>0P0000001P3CQ`h0[Jf]0=>73P000000kiP@0000
00D0kiP@00<000000>nH403_V1000`3_V1000`000000o:0@0?bP400>0?bP40<00000103oY1440:f]
[@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`@0[Jf]0P3fW0l00`2]
[Jd0k9H>0>bF3P0;0>bF3P030000003/UPh0k9H>0080k9H>00@0[Jf]0=^:3@3KRPd000000P3KRPd0
1@000000fhX=0=^:3@3KRPd0000000<0fhX=00D0[Jf]0000002iM@/0^GD;000000050;Ue2`030:f]
[@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000@0Uf0;0000002GH0/00000
0`3CQ`h020000000dhL>0:f][@3CQ`h000000:f][@3_V10000001@3_V10010000000kiP@0>nH403_
V102000000030:f][@3lX100o:0@00h0o:0@0`0000040:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0B0?JL3`@0[Jf]303/UPh2000000<0k9H>00@0[Jf]0=^:3@3KRPd0fhX=
0P0000040=^:3@060000003KRPd0fhX=0=^:3@2][Jd000000P2iM@/00`000000[Jf]0;Ue2`030;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000@0Uf0;0000002G
H0/000000`3CQ`h020000000[Jf]0=>73P3CQ`h000000:f][@3_V10000001@3_V1000`000000kiP@
0>nH40030>nH40030:f][@3lX100o:0@00h0o:0@0`00000E0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@T0k9H>0P0000030>bF3P030:f]
[@3KRPd0fhX=00P0fhX=00D000000=^:3@3KRPd0[Jf]000000020;Ue2`80000000D0[Jf]0;Ue2`2i
M@/0^GD;0:f][@0408QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;0000
0080dhL>00<0[Jf]0000003CQ`h00P3CQ`h01@000000[Jf]0>nH403_V10000000080kiP@0`000005
0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd3000001D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd70>bF3P8000000`3/UPh0
0`2][Jd0fhX=0=^:3@080=^:3@050000003KRPd0fhX=0:f][@0000000P2iM@/2000000050;Ue2`2]
[Jd0[Jf]0;Ue2`2][Jd01028EPL20:f][D40/>3V0@3oool005L0/>3V0`000000202GH0/0000009MP
2`000000dhL>0:f][@3CQ`h000000`3CQ`h010000000[Jf]0>nH403_V102000000T0kiP@00<0[Jf]
0?bP403lX1002@3lX1030:f][@80o:0@00<000000:f][@0000005@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@@0k9H>0P000003
0>bF3P030:f][@3KRPd0fhX=00T0fhX=00<000000=^:3@2][Jd00P0000000`2iM@/0000000000003
0;Ue2`80[Jf]1028EPL20:f][D40/>3V0@3oool005L0/>3V0`0000000`2GH0/0000009MP2`020000
0080dhL>00L000000=>73P3CQ`h0dhL>0000002][Jd0kiP@008000002P3_V1000`2][Jd0o:0@0?bP
40070?bP4080[Jf]1@3lX102000001H0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd00`3/UPh00000000000030>bF3P030:f][@3K
RPd0fhX=00T0fhX=00<000000=^:3@0000000P0000000`2iM@/00000000000040;Ue2`030:f][@28
EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000<0Uf0;0000002GH0/00P000002
0=>73P070000003CQ`h0dhL>0000003CQ`h0[Jf]0000000<0>nH40030:f][@3lX100o:0@00@0o:0@
0`2][Jd80?bP40030000003oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>
00<0[Jf]0000000000000`3/UPh00`2][Jd0fhX=0=^:3@0:0=^:3@80000000<0^GD;0000002iM@/0
0P0000040;Ue2`80[Jf]0`28EPL20:f][D40/>3V0@3oool005L0/>3V0`0000000`2GH0/000000:f]
[@02000000030=>73P000000dhL>0080dhL>00<000000:f][@0000003@3_V100102][Jd0o:0@0?bP
403lX1030:f][@/0o:0@00<000000?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00/0k9H>0P0000020:f][@030>bF3P2][Jd0fhX=00d0fhX=00D0[Jf]0000002iM@/0
^GD;000000040;Ue2`80[Jf]0`28EPL20:f][D40/>3V0@3oool005H0/>3V100000000`2GH0/00000
0:f][@02000000030=>73P000000dhL>0080dhL>0P00000>0>nH40040:f][@3lX100[Jf]0:f][@h0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0
ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh200000080k9H>0`2][Jd=0=^:3@050:f][@2iM@/0^GD;0;Ue
2`000000102iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H200000005
0:f][@000000Uf0;0000002GH0/00P0000001`3CQ`h000000=>73P3CQ`h000000=>73P2][Jd03@3_
V1030:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3o
YQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh2000000<0k9H>00@0[Jf]0=^:3@2][Jd0[Jf]
2`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0000000@0^GD;00<0[Jf]08QF1`2][Jd00P28EPL20:f][D40
/>3V0@3oool005H0/>3V0P0000002@2][Jd000000:f][@000000Uf0;0:f][@000000dhL>00000004
0=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:
0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P090>bF3P@000000`3/UPh0
102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;000000040;Ue2`050:f]
[@28EPL0R5H70:f][@28EPL00P2][Je10;3PiP40oooo001F0;3PiP@0000000@0[Jf]0000002GH0/0
[Jf]0P0000050=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80
o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P8000000`3/UPh00`2][Jd0
fhX=0=^:3@030=^:3@80[Jf]1`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0000000@0^GD;00@0[Jf]08QF
1`28EPL0R5H70`2][Je10;3PiP40oooo001F0;3PiP@0000000H0Uf0;0000002GH0/0[Jf]0=>73P00
00050=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd50>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0
[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2]
[Jd50=^:3@050:f][@2iM@/0^GD;0;Ue2`000000102iM@/0102][Jd0R5H708QF1`28EPL30:f][D40
/>3V0@3oool005H0/>3V1P0000000`2GH0/0[Jf]0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@
0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@050:f][@2iM@/0^GD;0;Ue2`00
0000102iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H50000000309MP
2`2][Jd0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd90>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP
40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:
3@80[Jf]00<0fhX=0:f][@2iM@/00P2iM@/2000000@0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je1
0;3PiP40oooo001F0;3PiPH0000000<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0:f][@2][Jd;
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@<0^GD;0P000004
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000050:f][@000000
00000000002][Jd0203CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT
4@0=0?nT4@@0[Jf]dP2`h>H50:f][A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0<0=^:3@<0[Jf]00<0^GD;000000000000102iM@/0102][Jd0R5H708QF1`28EPL20:f][D40/>3V
0@3oool005H0/>3V0P0000001@2][Jd00000000000000000[Jf]00L0dhL>0P2][Jd>0>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2][Jd2000000@0
^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP80000000D0[Jf]0000002G
H0/000000:f][@050=>73P80[Jf]00<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP
40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0P0000040;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000050:f][@2GH0/000000000002][Jd0103C
Q`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A
0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd0102][Jd0^GD;0;Ue2`2iM@/2000000050:f][@2iM@/0^GD;0;Ue2`2][Jd00`28EPL20:f]
[D40/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;0000002GH0/0[Jf]00<0dhL>00<0[Jf]0=>7
3P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3P
iP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0;Ue2`80000000D0^GD;
0:f][@2iM@/0^GD;0:f][@0308QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000060:f][@2GH0/0
000009MP2`2][Jd0dhL>0P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0
^GD;000000030;Ue2`<0[Jf]0`28EPL20:f][D40/>3V0@3oool005H0/>3V0P000000102][Jd0Uf0;
0000002GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080
[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;000000050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]
0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2GH0/0000009MP2`2][Jd0203C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`
h>H40:f][@L0`kfk102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/20:f][@<0R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H01@000000[Jf]09MP2`2G
H0/000000080[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2]
[Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`h>H30:f][@l0`kfk0`2][Jd40>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0[Jf]0;3PiP2`h>H0?`2`
h>H10?ooo`00EP2`h>H01@000000[Jf]09MP2`2GH0/000000080[Jf]203CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2]
[JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2]
[Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@2`
h>H0/>3V03l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0Uf0;0000002GH0/0[Jf]00P0dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH0
3@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H7
0:f][@0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0[Jf]
0000002GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`06
0:f][@28EPL0R5H70:f][@28EPL0[Jf]@@2`h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2][Jd0
000009MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP070000002][Jd0[Jf]09MP2`000000
Uf0;0:f][@080=>73P030:f][@3_V100kiP@00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0
R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00P0000000`2GH0/0
[Jf]0=>73P070=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f]
[@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f]
[@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh
00D0_[Vh0P2][Jd20;ji^080@FWQ0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`28EPL00P28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/00`2][Jd0
dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080[Jf]00D0Y9j?045Yh@11JN40Y9j?0:f][@04
0;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@@0_[Vh0P11JN40102][Jd0@FWQ0:f][@2]
[Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D00/>3V0@3o
ool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P040:f][@3_V100
[Jf]0:f][@@0Y9j?0P11JN400`2][Jd0/J^M0;6[W@040;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2]
[Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji
^02n^KP20:f][@H0_[Vh0`11JN420;B`/@05045Yh@2][Jd0[Jf]0=^:3@2][Jd02P2iM@/0102][Jd0
R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P070=>73P80[Jf]1P2TWXl01011JN40Y9j?045Yh@11JN470;6[W@80[Jf]0`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f]
[Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102]
[Jd0_[Vh0:f][@2][Jd80;ji^0<0@FWQ0`2d/;401011JN40];2a0:f][@2][Jd:0;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3C
Q`h0dhL>00H0dhL>00<0[Jf]0:BNS`2TWXl01P2TWXl01011JN40Y9j?0:f][@11JN490;6[W@80[Jf]
00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`
1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03033_K/30:f][@P0_[Vh1@11JN430;B`/@04045Yh@2d/;40];2a045Yh@80
[Jf]202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2]
[Jd00`2GH0/00`2][Jd0dhL>0=>73P040=>73P80[Jf]2@2TWXl01@11JN40Y9j?0:f][@2aZid0@FWQ
00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102]
[Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01@2n^KP0
1@11JN40_[Vh045Yh@11JN40_[Vh0080@FWQ00D0[Jf]0;B`/@2d/;40];2a045Yh@020;B`/@80@FWQ
00<0];2a0:f][@2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V
00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P030=>73P<0[Jf]2@2TWXl01@11JN40[Jf]
0;6[W@2aZid0@FWQ00<0/J^M0`11JN450;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0
/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^0020;ji^080@FWQ00D0_[Vh045Yh@11
JN40@FWQ0;ji^002045Yh@050;ji^02][Jd0];2a0;B`/@11JN400P2d/;42045Yh@80];2a0P2][Jd5
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@03
09MP2`030:f][@3CQ`h0dhL>0080dhL>00@0[Jf]08Z5M@2:QGD0[Jf]2@2TWXl00`11JN40[Jf]0;6[
W@020;6[W@03045Yh@2aZid0/J^M0080/J^M0`11JN430;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2]
[Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`050:f][@2n^KP0_[Vh0;ji^011JN40
0`2n^KP2045Yh@<0_[Vh0P11JN40102][Jd0];2a0;B`/@11JN420;B`/@80@FWQ00@0];2a0:f][@2]
[Jd0@FWQ0P2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`050:f][@3CQ`h0dhL>0=>73P2][Jd00`2:QGD30:f][@L0Y9j?00<0@FWQ
0:f][@2aZid00P2aZid00`11JN40/J^M0;6[W@020;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]
0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd5
0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/01@2][Jd0_[Vh0;ji^02n^KP0@FWQ00@0_[Vh00@0
@FWQ0;ji^02n^KP0_[Vh0P11JN40102][Jd0];2a0;B`/@11JN420;B`/@80@FWQ00@0[Jf]0;B`/@2d
/;40@FWQ0P2OVj00102][Jd0^GD;0;Ue2`2][Jd308QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`040:f][@3CQ`h0[Jf]0:f][@@0RXEe00@0[Jf]0:BNS`2TWXl0[Jf]1P2T
WXl00`11JN40[Jf]0;6[W@020;6[W@03045Yh@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid00`2a
Zid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2]
[JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00?0<K0_0<0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^002045Yh@@0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh
0P11JN400`2][Jd0];2a0;B`/@02045Yh@030;B`/@11JN40@FWQ00<0];2a00@0@FWQ09nKX02OVj00
@FWQ0`2][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/0
0`2GH0/20:f][@H0RXEe00@0[Jf]0:BNS`2TWXl0Y9j?0P2][Jd40:BNS`03045Yh@2][Jd0/J^M0080
/J^M0P11JN430;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@03
0<K0_02][Jd0`kfk00P0`kfk0`11JN430<>m^`030:f][@2n^KP0_[Vh0080@FWQ102n^KP01011JN40
_[Vh0;ji^02n^KP2045Yh@030:f][@2d/;40];2a0080@FWQ00<0[Jf]045Yh@11JN400P2d/;42045Y
h@0309nKX011JN40Wi^P0080Wi^P00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP0n0;3P
iP40oooo001E0;3PiP030000002][Jd0Uf0;00<0Uf0;00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0
Y9j?0:BNS`030:BNS`80[Jf]0P2TWXl00`11JN40[Jf]0;6[W@020;6[W@80@FWQ0`2aZid00`11JN40
/J^M0;6[W@030;6[W@030:f][@2i/ZH0^K:V00@0@FWQ2P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140
al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/01P33_K/3045Yh@@0
`kfk00<0[Jf]0;ji^02n^KP00P11JN440;ji^004045Yh@2n^KP0_[Vh0;ji^080@FWQ00@0[Jf]0;B`
/@2d/;40@FWQ0`2d/;42045Yh@030;B`/@11JN40[Jf]00H0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f]
[@100;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd708Z5M@030:f][@2TWXl0
Y9j?00D0Y9j?00@0[Jf]0:BNS`11JN40[Jf]0`2aZid2045Yh@<0/J^M00<0@FWQ0;6[W@2aZid00`2a
Zid01@2][Jd0^K:V045Yh@2i/ZH0@FWQ0080^K:V00D0@FWQ0;VbYP2i/ZH0^K:V045Yh@050;VbYP03
0:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33
_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd90<K0_004
0:f][@33_K/0`kfk0<>m^`80@FWQ1033_K/2045Yh@D0`kfk00@0[Jf]0;ji^02n^KP0@FWQ102n^KP0
1011JN40_[Vh0;ji^02n^KP2045Yh@<0[Jf]00@0@FWQ0;B`/@2d/;40];2a0P11JN400`2d/;40@FWQ
0:f][@0609nKX0050:f][@28EPL0R5H708QF1`2][Jd0@02`h>H10?ooo`00E@2`h>H00`000000[Jf]
09MP2`0209MP2`80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`060:BNS`030:f][@11JN40[Jf]00<0/J^M
0P11JN430;6[W@03045Yh@2aZid0/J^M00<0/J^M00@0[Jf]0;VbYP11JN40@FWQ102i/ZH4045Yh@D0
^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0
`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0
al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_004
0:f][@11JN40`kfk0<>m^`80@FWQ1033_K/2045Yh@D0`kfk00@0[Jf]0;ji^02n^KP0@FWQ102n^KP2
045Yh@80_[Vh0P11JN40102][Jd0];2a0;B`/@11JN430;B`/@<0@FWQ00<0];2a0:f][@2OVj001P2O
Vj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001E0;3PiP040000002][Jd0Uf0;09MP2`<0[Jf]
1`2:QGD00`2][Jd0Y9j?0:BNS`060:BNS`80@FWQ0P2][Jd20;6[W@80@FWQ0`2aZid00`11JN40/J^M
0;6[W@030;6[W@040:f][@2i/ZH0@FWQ045Yh@@0^K:V0`11JN460;VbYP03045Yh@2n]j`0_[N/00/0
_[N/102][Jd00`2n]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`03`37`K`40:f][A40a/2l00<0@FWQ0<>m^`11JN400`11JN440<>m^`80@FWQ1@33_K/0102][Jd0
_[Vh0;ji^011JN440;ji^080@FWQ00D0_[Vh0:f][@11JN40@FWQ0:f][@020;B`/@04045Yh@2d/;40
];2a0;B`/@80@FWQ0P2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]00<0R5H70:f][@2`h>H0?`2`
h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]0:BNS`2TWXl01`2T
WXl01011JN40Y9j?0:f][@2aZid20:f][@80@FWQ0P2aZid2045Yh@D0/J^M00@0[Jf]0;VbYP11JN40
@FWQ1@2i/ZH00`11JN40^K:V0;VbYP050;VbYP03045Yh@2n]j`0_[N/00l0_[N/102][JdA0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036
`;`03P36`;`2045Yh@040:f][@33_K/0`kfk0<>m^`80@FWQ1033_K/2045Yh@D0`kfk00<0[Jf]0;ji
^02n^KP00P11JN420;ji^0<0@FWQ00H0[Jf]0;ji^011JN40@FWQ0:f][@2d/;42045Yh@<0];2a0P11
JN420;B`/@040:f][@2OVj00Wi^P045Yh@@0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00
EP2`h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`070:BNS`03045Y
h@2TWXl0[Jf]00<0/J^M0P11JN40102][Jd0/J^M045Yh@11JN450;6[W@040:f][@2i/ZH0@FWQ045Y
h@D0^K:V00<0@FWQ0;VbYP2i/ZH01@2i/ZH00`11JN40_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/
00/0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`03P36`;`2045Yh@040:f][@33_K/0`kfk
0<>m^`80@FWQ1033_K/2045Yh@D0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0`11JN400`2][Jd0@FWQ045Y
h@020;ji^080@FWQ00@0[Jf]0;B`/@11JN40@FWQ0`2d/;42045Yh@80];2a00@0[Jf]09nKX02OVj00
@FWQ0`2OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]
1@2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`03045Yh@2TWXl0[Jf]00<0/J^M0P11JN40102aZid0[Jf]
045Yh@11JN450;6[W@040:f][@2i/ZH0@FWQ045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH2045Y
h@@0_[N/00<0@FWQ0;jg[02n]j`02`2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2]
[Jd0`kfc0<>m/`0<0<>m/`@0@FWQ0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0
_036`;`01@36`;`00`11JN40a/2l0<K0_0050<K0_080@FWQ00<0a/2l0:f][@33_K/00P33_K/2045Y
h@@0`kfk0P11JN450<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]0P2n^KP2045Yh@80_[Vh1@11JN44
0;B`/@80@FWQ0P2d/;40102][Jd0Wi^P09nKX011JN4209nKX0030:f][@2OVj00[Jf]0080L6ii0P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD0
0`2][Jd0Y9j?0:BNS`070:BNS`03045Yh@2TWXl0[Jf]00<0/J^M0P11JN420;6[W@80@FWQ0P2][Jd3
0;6[W@040:f][@2i/ZH0^K:V045Yh@D0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH2045Yh@@0_[N/00<0
@FWQ0;jg[02n]j`02`2n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m
/`0>0<>m/`D0@FWQ00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k0100b<6k1P2][JdA0<O1_0030:f][@36`;`0@FWQ00D0a/2l00<0@FWQ0<K0_036`;`01@36
`;`2045Yh@030<K0_02][Jd0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@D0`kfk00@0
[Jf]0;ji^02][Jd0[Jf]102n^KP01011JN40_[Vh0;ji^02n^KP2045Yh@030:f][@11JN40];2a00@0
];2a0P11JN420;B`/@060:f][@2OVj00Wi^P045Yh@2OVj00[Jf]0P2OVj000`2][Jd0L6ii071^N@02
0:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd3
08Z5M@030:f][@2TWXl0Y9j?00L0Y9j?00<0@FWQ0:BNS`2][Jd00`2aZid2045Yh@80/J^M0P11JN42
0;6[W@80[Jf]00D0/J^M0:f][@2i/ZH0^K:V045Yh@050;VbYP03045Yh@2i/ZH0^K:V00@0^K:V0`11
JN420;jg[080@FWQ2@2n]j`4045Yh@030:f][@31^[00`KZ`00l0`KZ`202][Jd;0<>m/`80@FWQ0`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38
`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`03@37`K`01`11JN40al6l0<O1_037`K`0[Jf]0<K0_011
JN401@36`;`00`11JN40a/2l0<K0_0050<K0_004045Yh@36`;`0a/2l0:f][@@0`kfk00<0@FWQ0<>m
^`33_K/00`33_K/00`11JN40`kfk0<>m^`020<>m^`<0[Jf]1P2n^KP01011JN40_[Vh0;ji^02n^KP2
045Yh@030:f][@2d/;40];2a00@0];2a0P11JN420;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2OVj00
0`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2]
[Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl00`11JN40Y9j?0:f][@03
0;6[W@80@FWQ0P2aZid2045Yh@@0/J^M0`2][Jd20;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0@FWQ
0;VbYP2i/ZH0102i/ZH00`11JN40_[N/045Yh@020;jg[080@FWQ202n]j`00`11JN40_[N/0;jg[002
0;jg[004045Yh@31^[00@FWQ045YhA00`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@80@FWQ0`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k
202][Jd:0<S1^`030:f][@37`K`0al6l00d0al6l00L0@FWQ0<O1_037`K`0al6l0:f][@36`;`0@FWQ
00D0a/2l0P11JN460<K0_004045Yh@36`;`0a/2l0:f][@@0`kfk00<0@FWQ0<>m^`33_K/00`33_K/0
0`11JN40`kfk0:f][@020:f][@040<>m^`2][Jd0_[Vh0;ji^080@FWQ0`2n^KP00`11JN40_[Vh0;ji
^002045Yh@030;ji^02][Jd0];2a00D0];2a0P11JN420;B`/@030:f][@2OVj00[Jf]00D0Wi^P00<0
[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]
08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@090:BNS`03045Yh@2TWXl0[Jf]00<0/J^M0P11JN42
0;6[W@80@FWQ0`2aZid01011JN40/J^M0:f][@2i/ZH30:f][@80@FWQ00<0^K:V045Yh@11JN401P2i
/ZH00`11JN40_[N/045Yh@020;jg[0<0@FWQ1P2n]j`2045Yh@@0_[N/00@0[Jf]045Yh@11JN40@FWQ
0`31^[04045Yh@T0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<2045Yh@T0[Jf]4@35_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0050<O1_0D0@FWQ00<0al6l045Yh@11JN40
1037`K`0102][Jd0a/2l045Yh@11JN440<K0_080@FWQ1P36`;`01011JN40a/2l0<K0_02][Jd40<>m
^`<0@FWQ0P33_K/00`2][Jd0@FWQ0:f][@040<>m^`030:f][@2n^KP0_[Vh0080@FWQ0P2n^KP00`11
JN40_[Vh0;ji^0040;ji^0030:f][@2d/;40];2a00@0];2a0P11JN420;B`/@80[Jf]1P2OVj000`2]
[Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0
RXEe08Z5M@0308Z5M@80[Jf]2@2TWXl00`11JN40Y9j?0:f][@030;6[W@03045Yh@2aZid0/J^M00@0
@FWQ00D0/J^M045Yh@11JN40/J^M0:f][@040;VbYP80[Jf]0`11JN450;VbYP80@FWQ00L0_[N/045Y
h@2n]j`0_[N/045Yh@2n]j`0@FWQ00D0_[N/00<0@FWQ0;jg[011JN40102n]j`0102][Jd0@FWQ045Y
h@11JN460<6j/0<0@FWQ1`31^[000`2][Jd0`kfc0<>m/`0>0<>m/`80@FWQ0`33_K<00`2][Jd0aKje
0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00<0al6l0`11JN440<O1_080@FWQ1@37`K`0102][Jd0a/2l
045Yh@11JN430<K0_0<0@FWQ1P36`;`01011JN40a/2l0<K0_02][Jd20<>m^`<0@FWQ0P33_K/20:f]
[@030<>m^`11JN40@FWQ00<0`kfk00<0@FWQ0:f][@2n^KP00P2n^KP01011JN40_[Vh0;ji^011JN46
0;ji^0030:f][@2d/;40];2a00@0];2a0P11JN420;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]
071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]
08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`070:BNS`03045Yh@2TWXl0[Jf]00<0/J^M00@0@FWQ
0;6[W@2aZid0/J^M0`11JN401@2aZid0@FWQ045Yh@2aZid0[Jf]0080^K:V00<0@FWQ0;VbYP2i/ZH0
0P2i/ZH2045Yh@80[Jf]0`2i/ZH2045Yh@070;jg[011JN40_[N/0;jg[011JN40_[N/045Yh@050;jg
[080@FWQ102n]j`00`2][Jd0`KZ`0<6j/002045Yh@H0`KZ`00<0@FWQ0<6j/031^[001`31^[000`2]
[Jd0`kfc0<>m/`0>0<>m/`80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k
00`0b<6k1011JN430<S1^`030:f][@37`K`0al6l00<0al6l0P11JN460<O1_003045Yh@37`K`0al6l
00<0al6l00@0[Jf]045Yh@36`;`0@FWQ0`36`;`3045Yh@D0a/2l0P11JN420<K0_0030:f][@33_K/0
`kfk0080`kfk0`2][Jd30<>m^`80@FWQ0P33_K/2045Yh@030:f][@2n^KP0_[Vh0080_[Vh0P11JN47
0;ji^0030:f][@2d/;40];2a00@0];2a0P11JN430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f]
[@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@L0Y9j?00<0
@FWQ0:BNS`2][Jd00`2aZid00`11JN40/J^M0;6[W@040;6[W@05045Yh@2aZid0@FWQ0;6[W@2][Jd0
0P2i/ZH00`11JN40^K:V0;VbYP020;VbYP80@FWQ0P2i/ZH30:f][@05045Yh@2][Jd0_[N/045Yh@2n
]j`00P11JN400`2n]j`0@FWQ0;jg[0040;jg[080@FWQ102n]j`00`2][Jd0`KZ`0<6j/002045Yh@H0
`KZ`00<0@FWQ0<6j/031^[001`31^[000`2][Jd0`kfc0<>m/`05045Yh@T0`kfc0P11JN430<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0:0<S1^`@0@FWQ1@38`K/00`2][Jd0al6l0<O1_0030<O1_003
045Yh@37`K`0al6l00D0al6l00<0@FWQ0<O1_037`K`00`37`K`0102][Jd0@FWQ0<K0_011JN430<K0
_003045Yh@36`;`0@FWQ00D0a/2l0P11JN420<K0_0030:f][@33_K/0[Jf]0080[Jf]1P33_K/2045Y
h@<0`kfk00<0@FWQ0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@030;B`/@80@FWQ00@0[Jf]0;B`
/@2d/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]
06=PD`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1@2TWXl00`11JN40Y9j?0:f]
[@020;6[W@03045Yh@2aZid0/J^M00H0/J^M0P11JN401@2aZid0[Jf]0;VbYP2i/ZH0@FWQ00@0^K:V
00<0@FWQ0;VbYP2i/ZH0102i/ZH01@11JN40[Jf]0:f][@11JN40_[N/0080@FWQ00<0_[N/045Yh@2n
]j`0102n]j`2045Yh@@0_[N/00<0[Jf]0<6j/031^[000P11JN460<6j/003045Yh@31^[00`KZ`00L0
`KZ`00<0[Jf]0<>m/`33_K<00P11JN430<>m/`80@FWQ0`33_K<01011JN40`kfc0<>m/`33_K<2045Y
h@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030000002][Jd0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`H0@FWQ2@38`K/2045Y
h@D0b<6k00<0[Jf]0<O1_037`K`00`37`K`00`11JN40al6l0<O1_0050<O1_003045Yh@37`K`0al6l
00<0al6l00<0[Jf]045Yh@36`;`00P11JN420<K0_004045Yh@36`;`0a/2l045Yh@@0a/2l0P11JN44
0:f][@T0`kfk00<0@FWQ0<>m^`11JN400P33_K/00`11JN40[Jf]0;ji^00<0;ji^0030:f][@2d/;40
];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f]
[@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2T
WXl0102][Jd0Y9j?0:BNS`2TWXl2045Yh@050:BNS`2][Jd0/J^M0;6[W@11JN402`2aZid0102][Jd0
^K:V0;VbYP11JN440;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00T0@FWQ0:f][@2n]j`0@FWQ0:f][@11
JN40[Jf]0;jg[011JN401@2n]j`00`11JN40_[N/0;jg[0030;jg[0030:f][@31^[00`KZ`0080@FWQ
1P31^[000`11JN40`KZ`0<6j/0070<6j/0040:f][@33_K<0@FWQ045Yh@D0`kfc00@0@FWQ0<>m/`11
JN40@FWQ1033_K<2045Yh@80`kfc0`11JN4E0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k0140b<6k1011JN440<S1
^`<0@FWQ1`38`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`00`37`K`00`11JN40al6l0<O1_0050<O1
_003045Yh@37`K`0al6l00<0al6l00D0[Jf]045Yh@11JN40a/2l045Yh@020<K0_005045Yh@36`;`0
a/2l045Yh@36`;`00`2][Jd2045Yh@80a/2l00<0[Jf]0<>m^`33_K/02033_K/00`11JN40`kfk0<>m
^`02045Yh@030<>m^`2][Jd0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f]
[@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C
06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd20:BNS`80@FWQ00<0[Jf]0;6[W@11
JN40302aZid0102][Jd0^K:V0;VbYP2i/ZH2045Yh@80^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH01011
JN40[Jf]0;jg[02n]j`2045Yh@030;jg[02][Jd0@FWQ0080[Jf]0`2n]j`00`11JN40_[N/0;jg[003
0;jg[0030:f][@31^[00`KZ`0080@FWQ1P31^[000`11JN40`KZ`0<6j/0070<6j/0040:f][@33_K<0
@FWQ045Yh@H0`kfc0P11JN450<>m/`80@FWQ00D0`kfc045Yh@33_K<0[Jf]0<Fn]@02045Yh@H0aKje
1`11JN420<Fn]@@0@FWQ00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/04`38`K/2045Yh@D0b<6k0P11JN470<S1^`80@FWQ
1@38`K/00`2][Jd0al6l0<O1_0030<O1_003045Yh@37`K`0al6l00D0al6l00<0@FWQ0<O1_037`K`0
0`37`K`01@2][Jd0@FWQ045Yh@36`;`0@FWQ0080a/2l00D0@FWQ0:f][@2][Jd0@FWQ0:f][@030<K0
_080@FWQ0P36`;`00`2][Jd0`kfk0<>m^`080<>m^`03045Yh@33_K/0`kfk00<0`kfk00<0[Jf]0;ji
^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]
071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0
Y9j?00D0Y9j?0P2][Jd20:BNS`<0@FWQ2`2aZid00`2][Jd0^K:V0;VbYP040;VbYP80@FWQ1P2i/ZH0
0`11JN40^K:V0:f][@020;jg[080@FWQ0P2n]j`00`11JN40_[N/0;jg[0030:f][@03045Yh@2n]j`0
_[N/00<0_[N/00<0[Jf]045Yh@11JN400P11JN460<6j/003045Yh@31^[00`KZ`00L0`KZ`00@0[Jf]
0<>m/`11JN40@FWQ1P33_K<2045Yh@D0`kfc0`11JN420<>m/`030:f][@35_[D0aKje0080@FWQ2035
_[D00`11JN40aKje0<Fn]@060<Fn]@@0@FWQ0P36_kL7045Yh@H0a[ng1011JN420<Jo]`030:f][@37
`KP0al6h01<0al6h00<0@FWQ0:f][@37`KX05P37`KX00`2][Jd0b<6k0<S1^`0C0<S1^`80@FWQ1P38
`K/2045Yh@H0b<6k0P11JN450<S1^`030:f][@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`01@37
`K`00`11JN40al6l0<O1_0030<O1_0050:f][@11JN40@FWQ0:f][@11JN400P2][Jd01011JN40a/2l
0<K0_011JN440<K0_080@FWQ0P36`;`00`2][Jd0`kfk0<>m^`060<>m^`80@FWQ1P33_K/00`2][Jd0
_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440
/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]
3@2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP05045Yh@2i/ZH0@FWQ0;VbYP2][Jd00P2n]j`2045Yh@<0
_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40[Jf]0:f][@020:f][@040;jg[02][Jd0`KZ`0<6j
/0@0@FWQ0`31^[02045Yh@T0`KZ`00@0[Jf]0<>m/`11JN40@FWQ1P33_K<2045Yh@D0`kfc0P11JN43
0<>m/`050:f][@35_[D0aKje0<Fn]@11JN402035_[D00`11JN40aKje0<Fn]@060<Fn]@03045Yh@2]
[Jd0a[ng00D0a[ng0P11JN470<Jo]`<0@FWQ0`36_kL00`11JN40a[ng0:f][@050<O1^004045Yh@37
`KP0al6h0<O1^0@0@FWQ1`37`KP2045Yh@030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
4`38`K/2045Yh@H0b<6k0P11JN460<S1^`80@FWQ1@38`K/00`2][Jd0al6l0<O1_0040<O1_003045Y
h@37`K`0al6l00@0al6l00@0@FWQ0<O1_037`K`0al6l0`2][Jd2045Yh@80a/2l00<0@FWQ0<K0_011
JN400P36`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ0P36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00X0_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2]
[Jd0@@2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@`0/J^M
00<0[Jf]0;VbYP2i/ZH02`2i/ZH2045Yh@050;VbYP2][Jd0_[N/0;jg[011JN40102n]j`00`11JN40
_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/0080_[N/1@2][Jd60<6j/080@FWQ2@31^[00102][Jd0
`kfc045Yh@11JN460<>m/`80@FWQ1@33_K<2045Yh@<0`kfc00@0[Jf]0<Fn]@35_[D0aKje0P11JN47
0<Fn]@03045Yh@35_[D0aKje00H0aKje00<0@FWQ0:f][@36_kL01@36_kL2045Yh@L0a[ng0P11JN45
0<Jo]`03045Yh@2][Jd0al6h00@0al6h00@0@FWQ0<O1^011JN40@FWQ1037`KP2045Yh@D0al6h00<0
@FWQ0<O1^011JN405`37`KX00`2][Jd0b<6k0<S1^`0C0<S1^`80@FWQ1`38`K/2045Yh@D0b<6k0P11
JN450<S1^`030:f][@37`K`0al6l00D0al6l1`11JN430:f][@80al6l00<0[Jf]045Yh@11JN400P36
`;`3045Yh@<0a/2l00@0@FWQ0<K0_036`;`0a/2l0P11JN420<K0_0030:f][@33_K/0`kfk00<0`kfk
00<0@FWQ0<>m^`33_K/02033_K/00`2][Jd0_[Vh0;ji^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03@2i
/ZH2045Yh@80_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0020;jg[003045Yh@2n
]j`0_[N/00<0_[N/00@0[Jf]0<6j/031^[00`KZ`1P2][Jd2045Yh@T0`KZ`00@0[Jf]0<>m/`33_K<0
@FWQ1P33_K<2045Yh@D0`kfc0P11JN430<>m/`040:f][@35_[D0aKje0<Fn]@80@FWQ1`35_[D00`11
JN40aKje0<Fn]@060<Fn]@03045Yh@2][Jd0a[ng00D0a[ng0P11JN460<Jo]`80@FWQ1`36_kL00`11
JN40al6h0<O1^0030<O1^080@FWQ2037`KP00`11JN40al6h0<O1^0030<O1^003045Yh@2][Jd0al6j
01H0al6j00<0[Jf]0<S1^`38`K/04`38`K/2045Yh@L0b<6k0P11JN450<S1^`80@FWQ1@38`K/00`2]
[Jd0al6l0<O1_0050<O1_0D0[Jf]00<0al6l045Yh@37`K`01037`K`00`11JN40a/2l045Yh@020<K0
_080@FWQ1036`;`01011JN40a/2l0<K0_036`;`2045Yh@80a/2l00<0[Jf]0<>m^`33_K/00`33_K/0
0`11JN40`kfk0<>m^`080<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40
];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5
M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00@0[Jf]0;jg[02n]j`0@FWQ0P2n]j`3045Yh@@0_[N/00<0@FWQ
0;jg[02n]j`00`2n]j`00`2][Jd0`KZ`0<6j/0070<6j/080@FWQ1P2][Jd30<6j/0050:f][@33_K<0
`kfc0<>m/`11JN401@33_K<2045Yh@D0`kfc0P11JN430<>m/`030:f][@35_[D0aKje0080aKje00<0
@FWQ0<Fn]@35_[D01@35_[D00`11JN40aKje0<Fn]@060<Fn]@03045Yh@2][Jd0a[ng00D0a[ng0P11
JN460<Jo]`80@FWQ1`36_kL00`2][Jd0@FWQ0<O1^0030<O1^003045Yh@37`KP0al6h00L0al6h00<0
@FWQ0<O1^037`KP01@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01<0b<6k0P11
JN480<S1^`80@FWQ1038`K/2045Yh@D0b<6k00<0[Jf]0<O1_037`K`01@2][Jd60<O1_003045Yh@37
`K`0al6l00<0al6l0P11JN430<K0_080@FWQ1036`;`3045Yh@80a/2l0P11JN400`36`;`0[Jf]0<>m
^`030<>m^`80@FWQ2P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H0
0`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid3
0:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0050;jg[0<0@FWQ0P2n]j`0
0`11JN40_[N/0;jg[0030;jg[0030:f][@31^[00`KZ`00L0`KZ`0`11JN450<6j/0L0[Jf]00<0`kfc
045Yh@11JN400`33_K<2045Yh@D0`kfc0P11JN430<>m/`030:f][@35_[D0aKje0080aKje00<0@FWQ
0<Fn]@35_[D01@35_[D00`11JN40aKje0<Fn]@060<Fn]@03045Yh@2][Jd0a[ng00D0a[ng0P11JN46
0<Jo]`80@FWQ1`36_kL00`2][Jd0al6h0<O1^0030<O1^003045Yh@37`KP0al6h00L0al6h00<0@FWQ
0<O1^037`KP01@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01<0b<6k0P11JN48
0<S1^`80@FWQ1038`K/2045Yh@80b<6k1P2][Jd;0<O1_003045Yh@37`K`0al6l00<0al6l0P11JN44
0<K0_003045Yh@36`;`0a/2l00<0@FWQ1036`;`2045Yh@80a/2l00@0[Jf]0<>m^`33_K/0`kfk0P11
JN4:0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H00`2][Jd0RXEe08Z5
M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid30:f][@030;6[W@2]
[Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`02P2n]j`00`11JN40_[N/0;jg[0030;jg[0030:f][@31
^[00`KZ`00L0`KZ`0`11JN480<6j/0040:f][@33_K<0`kfc0<>m/`<0[Jf]1@11JN450<>m/`80@FWQ
0`33_K<00`2][Jd0aKje0<Fn]@020<Fn]@03045Yh@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D0
1@35_[D2045Yh@030:f][@36_kL0a[ng00@0a[ng0P11JN450<Jo]`80@FWQ2036_kL00`2][Jd0al6h
0<O1^00<0<O1^080@FWQ1`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01<0b<6k
0P11JN480<S1^`80@FWQ00@0b<6k0:f][@2][Jd0[Jf]0P11JN420:f][@<0b<6k00<0[Jf]0<O1_037
`K`01037`K`00`11JN40al6l0<O1_0040<O1_003045Yh@37`K`0al6l00<0al6l1011JN420<K0_003
045Yh@36`;`0a/2l00L0a/2l0P11JN420<K0_0040:f][@33_K/0`kfk0<>m^`80@FWQ2P33_K/0102]
[Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj00
0`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BN
S`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00:0;jg
[080@FWQ102n]j`00`2][Jd0`KZ`0<6j/0070<6j/0<0@FWQ1031^[001@11JN40`KZ`0<6j/031^[00
[Jf]00P0`kfc0`11JN450:f][@80@FWQ0`33_K<00`2][Jd0aKje0<Fn]@020<Fn]@03045Yh@35_[D0
aKje00D0aKje00<0@FWQ0<Fn]@35_[D01@35_[D2045Yh@030:f][@36_kL0a[ng00@0a[ng0P11JN45
0<Jo]`80@FWQ2036_kL00`2][Jd0al6h0<O1^00:0<O1^0<0@FWQ2037`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01<0b<6k0P11JN430<S1^`D0[Jf]0P11JN40102][Jd0b<6k0<S1^`38
`K/3045Yh@@0b<6k00<0@FWQ0<O1_037`K`01037`K`00`11JN40al6l0<O1_0030<O1_003045Yh@37
`K`0al6l0080al6l1011JN4?0<K0_004045Yh@36`;`0a/2l0:f][@80`kfk0`11JN490<>m^`<0[Jf]
302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`
h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i
/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00:0;jg[080@FWQ102n]j`00`2][Jd0`KZ`0<6j
/0070<6j/080@FWQ00L0`KZ`045Yh@31^[00`KZ`045Yh@31^[00@FWQ0080`KZ`00@0[Jf]0<>m/`33
_K<0@FWQ1P33_K<2045Yh@D0`kfc0P11JN480:f][@03045Yh@35_[D0aKje00D0aKje00<0@FWQ0<Fn
]@35_[D01@35_[D2045Yh@030:f][@36_kL0a[ng00@0a[ng0P11JN450<Jo]`80@FWQ2036_kL00`2]
[Jd0al6h0<O1^0090<O1^0<0@FWQ1`37`KP00`11JN40al6h0:f][@0F0<O1^P030:f][@38`K/0b<6k
00l0b<6k102][Jd2045Yh@<0[Jf]1@38`K/2045Yh@@0b<6k0`11JN430<S1^`03045Yh@2][Jd0@FWQ
00D0al6l00<0@FWQ0<O1_037`K`00P37`K`00`11JN40al6l0<O1_0050<O1_0030:f][@36`;`0a/2l
00h0a/2l0P11JN401`36`;`0[Jf]0<>m^`33_K/0@FWQ0<>m^`11JN401P33_K/30:f][@030<>m^`2]
[Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P
0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP03
0;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00:0;jg[080@FWQ102n]j`01@2][Jd0`KZ`0<6j/031
^[00@FWQ00<0`KZ`1011JN420<6j/003045Yh@31^[00`KZ`0080@FWQ0P31^[00102][Jd0`kfc0<>m
/`11JN460<>m/`03045Yh@33_K<0`kfc00@0`kfc0P11JN430<>m/`040:f][@35_[D0aKje0<Fn]@80
@FWQ1`2][Jd00`11JN40[Jf]0:f][@020:f][@<0aKje0P11JN400`2][Jd0a[ng0<Jo]`040<Jo]`80
@FWQ1@36_kL2045Yh@P0a[ng00<0[Jf]0<O1^037`KP01`37`KP3045Yh@T0al6h00<0@FWQ0<O1^02]
[Jd05P37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1038`K/2045Yh@P0b<6k0P11JN440<S1^`<0
@FWQ1038`K/2045Yh@H0al6l1@11JN480<O1_0030:f][@36`;`0a/2l00d0a/2l00H0@FWQ0<K0_011
JN40[Jf]0<>m^`11JN420<>m^`04045Yh@33_K/0`kfk0<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl0
0`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0
_[N/00/0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`01@2][Jd0`KZ`0<6j/031^[00@FWQ00X0`KZ`0`11
JN430<6j/0040:f][@33_K<0`kfc045Yh@H0`kfc00<0@FWQ0<>m/`33_K<01033_K<2045Yh@<0`kfc
00@0[Jf]0<Fn]@35_[D0aKje0P11JN470<Fn]@03045Yh@35_[D0aKje0080aKje0`2][Jd2045Yh@L0
[Jf]0P11JN430:f][@80a[ng0P11JN480<Jo]`030:f][@37`KP0al6h00H0al6h0`11JN4:0<O1^003
045Yh@37`KP0[Jf]00/0al6j4@2][Jd@0<S1^`80@FWQ2038`K/2045Yh@@0b<6k0P11JN400`38`K/0
@FWQ0<S1^`020<S1^`03045Yh@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03P36`;`4045Yh@<0
`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0
/>3V0;3PiP180;3PiP40oooo001R0;3PiP030:f][@2TWXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0
302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f][@2n]j`0302n]j`00`11JN40_[N/
0;jg[0020;jg[0030:f][@31^[00`KZ`0080@FWQ4031^[001@2][Jd0`kfc0<>m/`33_K<0@FWQ00@0
`kfc00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@<0`kfc00@0[Jf]0<Fn]@35_[D0aKje0P11JN460<Fn
]@80@FWQ1`35_[D2045Yh@030:f][@36_kL0a[ng00@0a[ng0P11JN430<Jo]`80[Jf]0P11JN480:f]
[@03045Yh@2][Jd0[Jf]00@0[Jf]0`11JN4<0:f][@03045Yh@2][Jd0[Jf]00/0[Jf]2`37`KX00`2]
[Jd0b<6k0<S1^`0C0<S1^`80@FWQ2038`K/2045Yh@@0b<6k0P11JN420<S1^`<0@FWQ00<0[Jf]0<O1
_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2]
[Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80
[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][Jd<0;jg[080
@FWQ0`2n]j`00`2][Jd0`KZ`0<6j/002045YhA00`KZ`00<0[Jf]0<>m/`33_K<00P33_K<4045Yh@P0
`kfc0`11JN420<>m/`030:f][@35_[D0aKje0080@FWQ1`35_[D3045Yh@H0aKje0P11JN400`2][Jd0
a[ng0<Jo]`040<Jo]`80@FWQ1P36_kL2045Yh@H0a[ng00<0@FWQ0:f][@11JN401037`KP3045Yh@L0
al6h00<0@FWQ0<O1^037`KP00`37`KP00`11JN40al6h0:f][@0F0<O1^P030:f][@38`K/0b<6k01<0
b<6k0P11JN480<S1^`80@FWQ0P38`K/2045Yh@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0
];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0
302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]2@2n]j`2045Yh@80_[N/
00<0[Jf]0<6j/011JN400P11JN4@0<6j/0030:f][@33_K<0`kfc00`0`kfc1011JN401@33_K<0@FWQ
045Yh@2][Jd0aKje0080@FWQ2035_[D3045Yh@H0aKje00<0@FWQ0<Fn]@2][Jd01P36_kL2045Yh@H0
a[ng0P11JN470<Jo]`80@FWQ1037`KP00`11JN40al6h0<O1^0060<O1^080@FWQ1@37`KP00`11JN40
al6h0:f][@0F0<O1^P030:f][@38`K/0b<6k01<0b<6k0P11JN480<S1^`03045Yh@38`K/0b<6k00X0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0
/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]1P2n]j`01011JN40_[N/0;jg[02][Jd4045YhA00
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<3045Yh@T0aKje0P11JN400`35_[D0@FWQ0<Fn]@040<Fn]@03
045Yh@35_[D0[Jf]00H0a[ng0P11JN460<Jo]`80@FWQ1`36_kL00`11JN40al6h0<O1^0030<O1^003
045Yh@37`KP0al6h00H0al6h0P11JN450<O1^003045Yh@37`KP0[Jf]01H0al6j00<0[Jf]0<S1^`38
`K/04`38`K/2045Yh@P0b<6k00<0@FWQ0<S1^`38`K/02P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l00D0a/2l102][Jd70<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP0102][Jd0];2a0;B`/@2d/;420:f][E00/>3V0@3oool006T0/>3V0P2][Jd20:BNS`03
0:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0
[Jf]0`2n]j`3045Yh@<0`KZ`00<0@FWQ0<6j/031^[003P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00T0aKje0P11JN420<Fn]@D0@FWQ0P35_[D00`2][Jd0a[ng0<Jo]`040<Jo]`80
@FWQ1`36_kL2045Yh@D0a[ng00<0@FWQ0:f][@37`KP01@37`KP00`11JN40al6h0<O1^0040<O1^0<0
@FWQ1037`KP2045Yh@030<O1^02][Jd0al6j01D0al6j00<0[Jf]0<S1^`38`K/04`38`K/2045Yh@P0
b<6k00<0@FWQ0<S1^`38`K/02P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00D0
[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d
/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[000P31^[000`11JN40`KZ`0<6j/00>0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D02@35_[D2045Yh@T0aKje00<0[Jf]0<Jo]`36
_kL00P36_kL4045Yh@T0a[ng1@11JN400`36_kL0[Jf]0<O1^0060<O1^0H0@FWQ0P37`KP00`11JN40
al6h0<O1^0020<O1^0<0@FWQ00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0C0<S1^`80
@FWQ1`38`K/2045Yh@`0b<6k00<0[Jf]0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00T0aKje0P11JN490<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP04P37`KP3045Yh@030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
4`38`K/2045Yh@L0b<6k0P11JN4<0<S1^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]
E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00T0aKje0P11JN490<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
4P37`KP3045Yh@030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/04`38`K/2045Yh@H0b<6k
0P11JN4=0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`
h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D02@35
_[D2045Yh@T0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00B0<O1^0<0@FWQ00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0C0<S1^`80@FWQ1@38`K/2045Yh@h0b<6k00<0
[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB
0<>m/`030:f][@35_[D0aKje00T0aKje0P11JN490<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP04P37`KP3045Yh@030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/04`38`K/2
045Yh@@0b<6k0P11JN4<0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@090<Fn]@80@FWQ2@35_[D0
0`2][Jd0a[ng0<Jo]`040<Jo]`03045Yh@36_kL0a[ng00h0a[ng00<0[Jf]0<O1^037`KP04P37`KP3
045Yh@030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/04`38`K/2045Yh@030<S1^`11JN40
@FWQ0080@FWQ1P38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3P
iP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D01`35_[D4045Y
h@T0aKje00<0[Jf]0<Jo]`36_kL01036_kL00`11JN40a[ng0<Jo]`0>0<Jo]`030:f][@37`KP0al6h
0180al6h0`11JN400`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k0140b<6k1@11JN420<S1
^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]1P35_[D2045Yh@T0
aKje00<0[Jf]0<Jo]`36_kL01036_kL2045Yh@l0a[ng00<0[Jf]0<O1^037`KP04P37`KP2045Yh@03
0<O1^02][Jd0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40
oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng
0<Jo]`040<Jo]`03045Yh@36_kL0a[ng00h0a[ng00<0[Jf]0<O1^037`KP04`37`KP00`11JN40al6h
0:f][@0F0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk
0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036
_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`
h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`09
0<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l
102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`
h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3P
iPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3P
iP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0
al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f]
[@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo
002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3o
ool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3P
iP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
0 0 0 r
1 Mabswid
[ ] 0 setdash
.53052 .3085 m
.51885 .30852 L
s
.5 Mabswid
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51717 .33089 m
.52051 .33411 L
s
.51382 .33087 m
.51717 .33089 L
s
.51048 .33405 m
.51382 .33087 L
s
.5088 .33403 m
.51382 .33087 L
s
.5439 .33071 m
.53388 .33085 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56389 .33016 m
.55391 .33048 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44909 .32852 m
.45458 .32885 L
s
.255 .412 .882 r
.52633 .34086 m
.52964 .3386 L
s
.52964 .3386 m
.53295 .33857 L
s
.52467 .34087 m
.52964 .3386 L
s
.5015 .33842 m
.51308 .33858 L
s
.53295 .33857 m
.53792 .34077 L
s
.52136 .34538 m
.52467 .34087 L
s
.52301 .34538 m
.52633 .34086 L
s
.53792 .34077 m
.54124 .34523 L
s
.48334 .33794 m
.49489 .33828 L
s
.55279 .33822 m
.55446 .34269 L
s
.55279 .33822 m
.55282 .34725 L
s
.52136 .35215 m
.52301 .34538 L
s
.5197 .35215 m
.52136 .34538 L
s
0 0 0 r
.50587 .3592 m
.50707 .36622 L
s
.255 .412 .882 r
.5561 .34039 m
.55939 .33803 L
s
.55939 .33803 m
.56597 .3378 L
s
0 0 0 r
.5042 .35921 m
.50539 .3662 L
s
.255 .412 .882 r
.55446 .34269 m
.5561 .34039 L
s
.55282 .34725 m
.55446 .34269 L
s
.56597 .3378 m
.56927 .33993 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46528 .33717 m
.47676 .3377 L
s
.52135 .35667 m
.52136 .35215 L
s
.5197 .35667 m
.5197 .35215 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56927 .33993 m
.57093 .34212 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48984 .36301 m
.48994 .33815 L
s
.48818 .36297 m
.48829 .3381 L
s
.47154 .38513 m
.47184 .33749 L
s
.46989 .38506 m
.4702 .33741 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57093 .34212 m
.57097 .34889 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5197 .35667 m
.52135 .36346 L
s
.52135 .35667 m
.52301 .36346 L
s
0 0 0 r
.54907 .38859 m
.5491 .38875 L
s
.255 .412 .882 r
.50806 .37018 m
.50811 .33853 L
s
.5064 .37016 m
.50646 .3385 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58401 .33697 m
.58566 .33914 L
s
.58239 .33931 m
.58401 .33697 L
s
.42979 .31896 m
.44104 .31987 L
s
.58239 .33931 m
.58404 .34149 L
s
.56932 .34896 m
.57096 .34663 L
s
.53961 .35882 m
.54127 .36105 L
s
.53796 .3611 m
.53961 .35882 L
s
.56604 .35135 m
.56932 .34896 L
s
.58404 .34149 m
.58566 .33914 L
s
.55782 .35615 m
.56604 .35135 L
s
.56934 .35122 m
.57097 .34889 L
s
.53796 .3611 m
.53962 .36334 L
s
.54127 .36105 m
.54128 .36332 L
s
.55452 .35851 m
.55782 .35615 L
s
.52301 .36346 m
.52634 .36799 L
s
.52135 .36346 m
.52468 .368 L
s
.56606 .35361 m
.56934 .35122 L
s
.55287 .36082 m
.55452 .35851 L
s
.55783 .35842 m
.56606 .35361 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53797 .3679 m
.54128 .36332 L
s
.55453 .36077 m
.55783 .35842 L
s
.55287 .36082 m
.55289 .36535 L
s
.55288 .36308 m
.55453 .36077 L
s
.52468 .368 m
.52966 .37025 L
s
.52634 .36799 m
.52966 .37025 L
s
.44574 .33601 m
.45058 .33859 L
s
.45058 .33859 m
.4538 .34332 L
s
.48816 .3675 m
.48984 .36301 L
s
.53465 .37021 m
.53797 .3679 L
s
.48651 .36745 m
.48818 .36297 L
s
.44574 .33601 m
.44896 .33849 L
s
.44896 .33849 m
.45217 .34322 L
s
.52966 .37025 m
.53465 .37021 L
s
.4425 .33578 m
.44574 .33601 L
s
.55289 .36535 m
.55455 .36758 L
s
.4538 .34332 m
.45537 .35021 L
s
.50141 .37008 m
.50806 .37018 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45217 .34322 m
.45374 .35011 L
s
.43924 .33781 m
.4425 .33578 L
s
.55455 .36758 m
.55787 .36976 L
s
.56942 .36482 m
.57104 .36022 L
s
.48319 .36962 m
.48816 .3675 L
s
.48319 .36962 m
.48651 .36745 L
s
.45534 .35474 m
.45537 .35021 L
s
.55787 .36976 m
.56449 .36954 L
s
.47168 .36237 m
.47495 .36705 L
s
.56778 .36715 m
.56942 .36482 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45377 .35774 m
.45378 .35738 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4357 .36709 m
.43621 .3195 L
s
.43409 .36697 m
.4346 .31937 L
s
.4537 .35464 m
.45374 .35011 L
s
.43597 .34209 m
.43924 .33781 L
s
.47988 .36951 m
.48319 .36962 L
s
.56449 .36954 m
.56778 .36715 L
s
.47495 .36705 m
.47988 .36951 L
s
.45365 .36145 m
.45534 .35474 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56942 .36482 m
.57109 .3693 L
s
.58269 .38016 m
.58413 .3528 L
s
.58413 .3528 m
.58597 .38 L
s
.57104 .36022 m
.57109 .3693 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45201 .36136 m
.4537 .35464 L
s
.50637 .38152 m
.50803 .38382 L
s
.50471 .38378 m
.50637 .38152 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50636 .38608 m
.50803 .38382 L
s
.50471 .38378 m
.50636 .38608 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40699 .32814 m
.40852 .32677 L
s
.255 .412 .882 r
.58423 .36642 m
.58433 .38008 L
s
.42481 .33436 m
.42641 .3345 L
s
.45034 .36581 m
.45365 .36145 L
s
.44871 .36571 m
.45201 .36136 L
s
.42159 .33634 m
.42481 .33436 L
s
.42318 .33649 m
.42481 .33436 L
s
.42153 .34088 m
.42318 .33649 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44543 .36777 m
.45034 .36581 L
s
.41994 .34073 m
.42159 .33634 L
s
.44543 .36777 m
.44871 .36571 L
s
.46495 .38484 m
.47154 .38513 L
s
.58269 .38016 m
.58437 .38465 L
s
.42133 .3568 m
.42153 .34088 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41681 .33589 m
.41994 .34073 L
s
.41367 .33331 m
.41681 .33589 L
s
.44218 .36756 m
.44543 .36777 L
s
.41968 .36122 m
.41994 .34073 L
s
.58437 .38465 m
.58597 .38 L
s
.40893 .33283 m
.41367 .33331 L
s
.43577 .36026 m
.43896 .36505 L
s
.43896 .36505 m
.44218 .36756 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45352 .38731 m
.45353 .38694 L
s
.5 Mabswid
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40575 .33476 m
.40893 .33283 L
s
.40418 .33459 m
.40893 .33283 L
s
.42925 .3666 m
.4357 .36709 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40411 .33914 m
.40575 .33476 L
s
.41968 .36122 m
.42133 .3568 L
s
.40254 .33897 m
.40418 .33459 L
s
.40868 .35103 m
.41817 .35423 L
s
.41817 .35423 m
.41974 .35666 L
s
.40405 .3437 m
.40411 .33914 L
s
.41805 .36336 m
.41968 .36122 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40247 .34352 m
.40254 .33897 L
s
.40405 .3437 m
.40555 .34842 L
s
.41484 .36535 m
.41805 .36336 L
s
.40555 .34842 m
.40868 .35103 L
s
.40398 .34825 m
.40868 .35103 L
s
.40247 .34352 m
.40398 .34825 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40848 .36473 m
.41484 .36535 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40385 .35739 m
.40542 .35755 L
s
.40539 .35984 m
.40542 .35755 L
s
.40381 .35967 m
.40385 .35739 L
s
.40536 .36212 m
.40848 .36473 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40381 .35967 m
.40536 .36212 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37182 .32819 m
.38248 .32968 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37732 .36113 m
.37789 .32906 L
s
.37579 .36092 m
.37637 .32885 L
s
.38977 .3558 m
.39129 .35827 L
s
.39125 .36057 m
.39129 .35827 L
s
.38818 .3579 m
.38977 .3558 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38966 .36268 m
.39125 .36057 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38818 .3579 m
.3897 .36038 L
s
.38501 .36211 m
.38966 .36268 L
s
.67566 .32789 m
.67657 .37616 L
s
.67717 .32766 m
.67809 .37595 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67112 .32855 m
.68614 .32626 L
s
.5 Mabswid
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37757 .34735 m
.37898 .35444 L
s
.38197 .35943 m
.38501 .36211 L
s
.37898 .35444 m
.38197 .35943 L
s
.37122 .3603 m
.37732 .36113 L
s
.68614 .32626 m
.68915 .32807 L
s
.68614 .32626 m
.69063 .32783 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35829 .32841 m
.36117 .33347 L
s
.3539 .32538 m
.35829 .32841 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35648 .34425 m
.36695 .34585 L
s
.36095 .34495 m
.36131 .32659 L
s
.36244 .34518 m
.3628 .32683 L
s
.35097 .32488 m
.3539 .32538 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69063 .32783 m
.69367 .33192 L
s
.68915 .32807 m
.6922 .33217 L
s
.34799 .32667 m
.35097 .32488 L
s
.34653 .32641 m
.35097 .32488 L
s
.6922 .33217 m
.69376 .33652 L
s
.672 .37678 m
.68711 .37465 L
s
.69367 .33192 m
.69523 .33627 L
s
.34498 .33075 m
.34799 .32667 L
s
.69376 .33652 m
.69538 .34319 L
s
.36049 .36801 m
.36212 .3613 L
s
.34353 .33049 m
.34653 .32641 L
s
.69523 .33627 m
.69684 .34294 L
s
.70226 .32349 m
.71229 .32158 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36185 .37518 m
.36212 .3613 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34343 .3351 m
.34498 .33075 L
s
.3574 .37219 m
.36049 .36801 L
s
.36049 .36801 m
.36185 .37518 L
s
.34198 .33484 m
.34353 .33049 L
s
.34183 .34176 m
.34343 .3351 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70659 .32269 m
.70732 .35503 L
s
.69684 .34294 m
.69709 .35448 L
s
.69538 .34319 m
.69562 .35473 L
s
.70802 .32241 m
.70876 .35477 L
s
.34038 .3415 m
.34198 .33484 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6943 .36191 m
.69562 .35473 L
s
.3529 .37382 m
.3574 .37219 L
s
.68711 .37465 m
.69005 .37188 L
s
.68711 .37465 m
.69153 .37165 L
s
.69577 .36167 m
.69709 .35448 L
s
.69292 .36678 m
.6943 .36191 L
s
.69005 .37188 m
.69292 .36678 L
s
.34157 .35333 m
.34183 .34176 L
s
.6944 .36654 m
.69577 .36167 L
s
.69153 .37165 m
.6944 .36654 L
s
.34012 .35307 m
.34038 .3415 L
s
.34994 .37336 m
.3529 .37382 L
s
.70844 .34087 m
.71003 .34755 L
s
.34705 .37056 m
.34994 .37336 L
s
.34558 .37032 m
.34994 .37336 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32114 .31178 m
.32115 .31141 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34157 .35333 m
.34287 .36054 L
s
.70298 .3558 m
.70876 .35477 L
s
.34012 .35307 m
.34141 .36029 L
s
.34422 .36543 m
.34705 .37056 L
s
.34287 .36054 m
.34422 .36543 L
s
.34276 .36518 m
.34558 .37032 L
s
.34141 .36029 m
.34276 .36518 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71003 .34755 m
.71299 .35166 L
s
.3252 .31998 m
.33004 .35355 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32581 .35272 m
.33432 .35435 L
s
.71299 .35166 m
.71589 .35344 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32183 .34105 m
.32183 .34082 L
s
.32039 .34185 m
.32042 .34049 L
s
.5 Mabswid
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31883 .35131 m
.3252 .31998 L
s
.32022 .3516 m
.32503 .32691 L
s
.71589 .35344 m
.72012 .35261 L
s
.7186 .34824 m
.72006 .35029 L
s
.7186 .34824 m
.71995 .34564 L
s
.71995 .34564 m
.72141 .34768 L
s
.31417 .31757 m
.31883 .35131 L
s
.3079 .34894 m
.31417 .31757 L
s
.72141 .34768 m
.72147 .35001 L
s
.72012 .35261 m
.72147 .35001 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7318 .31977 m
.7358 .31651 L
s
.73056 .32471 m
.7318 .31977 L
s
.73056 .32471 m
.73068 .32936 L
s
.30925 .34924 m
.31399 .32453 L
s
.73316 .31945 m
.7358 .31651 L
s
.73192 .32441 m
.73316 .31945 L
s
.73192 .32441 m
.73204 .32905 L
s
.73068 .32936 m
.73216 .3337 L
s
.7358 .31651 m
.73982 .31554 L
s
.73204 .32905 m
.73352 .3334 L
s
.73216 .3337 m
.73629 .33511 L
s
.73352 .3334 m
.73629 .33511 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73982 .31554 m
.74253 .31722 L
s
.7324 .34302 m
.73246 .34536 L
s
.7324 .34302 m
.73376 .34272 L
s
.73376 .34272 m
.73383 .34506 L
s
.30388 .34802 m
.31333 .35014 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73629 .33511 m
.74436 .33556 L
s
.73246 .34536 m
.73389 .34739 L
s
.74253 .31722 m
.74529 .32122 L
s
.30079 .31436 m
.30211 .31469 L
s
.73389 .34739 m
.73666 .34912 L
s
.29811 .31602 m
.30079 .31436 L
s
.29942 .31636 m
.30079 .31436 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29798 .32069 m
.29942 .31636 L
s
.73666 .34912 m
.74202 .3479 L
s
.74648 .31623 m
.74902 .31323 L
s
.74529 .32122 m
.74648 .31623 L
s
.74529 .32122 m
.74587 .34226 L
s
.29668 .32036 m
.29811 .31602 L
s
.74778 .3159 m
.74902 .31323 L
s
.7466 .32089 m
.74778 .3159 L
s
.7466 .32089 m
.74706 .33725 L
s
.74902 .31323 m
.75031 .31289 L
s
.29753 .33705 m
.29798 .32069 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74436 .33556 m
.74574 .33758 L
s
.29422 .31501 m
.29668 .32036 L
s
.29609 .34142 m
.29668 .32036 L
s
.29172 .31199 m
.29422 .31501 L
s
.74202 .3479 m
.74462 .34492 L
s
0 0 0 r
.28356 .30542 m
.28479 .30275 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2879 .31094 m
.29172 .31199 L
s
.74462 .34492 m
.74587 .34226 L
s
.74587 .34226 m
.74706 .33725 L
s
.29609 .34142 m
.29753 .33705 L
s
0 0 0 r
.28356 .30542 m
.28461 .30874 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29499 .33406 m
.29622 .33673 L
s
.28736 .32969 m
.29499 .33406 L
s
.29472 .34344 m
.29609 .34142 L
s
.28532 .31258 m
.2879 .31094 L
s
.28407 .31222 m
.2879 .31094 L
s
0 0 0 r
.76484 .30455 m
.766 .30084 L
s
.255 .412 .882 r
.29207 .34514 m
.29472 .34344 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28393 .31691 m
.28532 .31258 L
s
.75766 .34401 m
.76173 .30974 L
s
.28268 .31655 m
.28407 .31222 L
s
.28695 .34381 m
.29207 .34514 L
s
.75382 .34501 m
.7627 .34265 L
s
.28491 .32665 m
.28736 .32969 L
s
.75893 .34368 m
.76194 .31677 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28177 .36589 m
.282 .36215 L
s
.28387 .33185 m
.28387 .33179 L
s
.5 Mabswid
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28254 .32125 m
.28268 .31655 L
s
.28379 .3216 m
.28393 .31691 L
s
.28365 .3263 m
.28736 .32969 L
s
.28379 .3216 m
.28491 .32665 L
s
.28254 .32125 m
.28365 .3263 L
s
.28449 .34077 m
.28695 .34381 L
s
.28338 .33571 m
.28463 .33606 L
s
.28456 .33841 m
.28463 .33606 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76699 .32888 m
.76707 .33018 L
s
.76665 .36509 m
.76666 .36119 L
s
.76669 .3303 m
.7667 .32925 L
s
.5 Mabswid
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76173 .30974 m
.76766 .34126 L
s
.28331 .33807 m
.28338 .33571 L
s
.28331 .33807 m
.28449 .34077 L
s
0 0 0 r
.76777 .35976 m
.76792 .36475 L
s
.255 .412 .882 r
.76766 .34126 m
.77152 .3068 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76889 .34091 m
.77174 .31386 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76881 .35842 m
.76894 .36059 L
s
.5 Mabswid
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77152 .3068 m
.77732 .33839 L
s
.25917 .3019 m
.26721 .30466 L
s
.27233 .33252 m
.27346 .33525 L
s
.27339 .33761 m
.27346 .33525 L
s
.27106 .33452 m
.27233 .33252 L
s
.27211 .33962 m
.27339 .33761 L
s
.27106 .33452 m
.27218 .33725 L
s
.26853 .33853 m
.27211 .33962 L
s
.77374 .33948 m
.78084 .33728 L
s
.26267 .33668 m
.26373 .30349 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26151 .3363 m
.26258 .3031 L
s
.26624 .33542 m
.26853 .33853 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26406 .32992 m
.26624 .33542 L
s
.26312 .32242 m
.26406 .32992 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78688 .30885 m
.78896 .30331 L
s
.78591 .31399 m
.78688 .30885 L
s
.785 .3215 m
.78591 .31399 L
s
.785 .3215 m
.78539 .33339 L
s
.78896 .30331 m
.7922 .29972 L
s
.788 .30846 m
.79007 .30291 L
s
.78704 .3136 m
.788 .30846 L
s
.78614 .32111 m
.78704 .3136 L
s
.25809 .33516 m
.26267 .33668 L
s
.78614 .32111 m
.78652 .33301 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79007 .30291 m
.7922 .29972 L
s
.78539 .33339 m
.78676 .34017 L
s
.7922 .29972 m
.79437 .29889 L
s
.78652 .33301 m
.78789 .33979 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79437 .29889 m
.79767 .30002 L
s
.78676 .34017 m
.78805 .34457 L
s
.25027 .30101 m
.25228 .30659 L
s
.25228 .30659 m
.25322 .31175 L
s
.25322 .31175 m
.25408 .3193 L
s
.25369 .33122 m
.25408 .3193 L
s
.78789 .33979 m
.78917 .34419 L
s
.2512 .30618 m
.25212 .31135 L
s
.25212 .31135 m
.25298 .3189 L
s
.2492 .3006 m
.2512 .30618 L
s
.24715 .29738 m
.25027 .30101 L
s
.25258 .33083 m
.25298 .3189 L
s
.78805 .34457 m
.79045 .3486 L
s
.24715 .29738 m
.2492 .3006 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78917 .34419 m
.79157 .34822 L
s
.25235 .33801 m
.25369 .33122 L
s
.23691 .29307 m
.24715 .29738 L
s
.25125 .33762 m
.25258 .33083 L
s
.79045 .3486 m
.79387 .34985 L
s
.25109 .34241 m
.25235 .33801 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79969 .2968 m
.80035 .31589 L
s
.79767 .30002 m
.79994 .30395 L
s
.79157 .34822 m
.79387 .34985 L
s
.80074 .29637 m
.8014 .31548 L
s
.24999 .34202 m
.25125 .33762 L
s
.79387 .34985 m
.79606 .34908 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24766 .34604 m
.24999 .34202 L
s
.24875 .34644 m
.25109 .34241 L
s
.23917 .34527 m
.24093 .29482 L
s
.79606 .34908 m
.79921 .3455 L
s
.24544 .34767 m
.24875 .34644 L
s
.23815 .34487 m
.23991 .29439 L
s
.24544 .34767 m
.24766 .34604 L
s
.80687 .29378 m
.81371 .29068 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79717 .31713 m
.8045 .31422 L
s
.79921 .3455 m
.80117 .33989 L
s
.80197 .33227 m
.80247 .34672 L
s
.80117 .33989 m
.80197 .33227 L
s
.80117 .33989 m
.80247 .34672 L
s
.23512 .34364 m
.24544 .34767 L
s
.80984 .29246 m
.81104 .32613 L
s
.81082 .29202 m
.81202 .32571 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80805 .32739 m
.81202 .32571 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81151 .31124 m
.81274 .31803 L
s
.81274 .31803 m
.81484 .32201 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81484 .32201 m
.81683 .32356 L
s
0 0 0 r
.82583 .27932 m
.8273 .27651 L
s
.255 .412 .882 r
.81683 .32356 m
.81962 .32225 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81852 .31784 m
.81953 .31983 L
s
.81852 .31784 m
.81936 .31498 L
s
.81936 .31498 m
.82036 .31696 L
s
.81962 .32225 m
.82045 .31939 L
s
.82036 .31696 m
.82045 .31939 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82575 .29196 m
.82642 .28664 L
s
.82575 .29196 m
.82593 .2968 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82593 .2968 m
.82697 .3012 L
s
.82642 .28664 m
.82885 .28279 L
s
.82661 .29149 m
.82727 .28617 L
s
.82661 .29149 m
.82679 .29634 L
s
.82727 .28617 m
.82885 .28279 L
s
.82679 .29634 m
.82782 .30073 L
s
.82885 .28279 m
.83129 .28135 L
s
.82697 .3012 m
.82958 .30224 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82782 .30073 m
.82958 .30224 L
s
.82734 .31093 m
.82743 .31337 L
s
.82734 .31093 m
.82819 .31047 L
s
.82743 .31337 m
.82837 .31535 L
s
.82819 .31047 m
.82828 .31291 L
s
.83129 .28135 m
.83297 .28282 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82837 .31535 m
.83014 .31688 L
s
.82958 .30224 m
.83451 .30186 L
s
.83297 .28282 m
.83472 .28672 L
s
.83014 .31688 m
.8334 .31504 L
s
.83472 .28672 m
.8353 .28136 L
s
.83472 .28672 m
.83557 .30873 L
s
.8353 .28136 m
.83671 .27793 L
s
.83549 .28623 m
.83606 .28087 L
s
.83549 .28623 m
.83615 .30336 L
s
.83606 .28087 m
.83671 .27793 L
s
.83825 .25937 m
.84309 .25578 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83671 .27793 m
.83746 .27744 L
s
.83451 .30186 m
.83538 .30383 L
s
.8334 .31504 m
.83489 .31166 L
s
.83489 .31166 m
.83557 .30873 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83557 .30873 m
.83615 .30336 L
s
.84037 .25784 m
.84241 .30937 L
s
.84106 .25733 m
.8431 .30889 L
s
0 0 0 r
.84758 .26695 m
.84762 .26699 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84785 .27365 m
.8479 .274 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84203 .2818 m
.8432 .27589 L
s
0 0 0 r
.84762 .26699 m
.84857 .27348 L
s
.255 .412 .882 r
.84027 .31081 m
.8431 .30889 L
s
.8432 .27589 m
.84443 .27242 L
s
.84443 .27242 m
.84572 .27139 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84281 .30149 m
.84437 .30545 L
s
.84572 .27139 m
.84708 .27283 L
s
.84572 .27139 m
.8477 .27232 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84437 .30545 m
.84581 .30695 L
s
.84708 .27283 m
.84851 .27674 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84869 .29349 m
.84869 .29357 L
s
.84929 .29135 m
.84935 .2929 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8477 .27232 m
.84911 .27622 L
s
.84581 .30695 m
.84711 .30597 L
s
.84851 .27674 m
.84941 .28365 L
s
.84711 .30597 m
.84828 .30251 L
s
.84711 .30597 m
.8489 .30201 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84911 .27622 m
.85 .28314 L
s
.84941 .28365 m
.84961 .2886 L
s
.84828 .30251 m
.84931 .29655 L
s
.84931 .29655 m
.84961 .2886 L
s
.85 .28314 m
.8502 .2881 L
s
.8489 .30201 m
.84991 .29605 L
s
.19373 .27136 m
.19439 .2694 L
s
.19393 .26641 m
.19439 .2694 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84991 .29605 m
.8502 .2881 L
s
.19328 .26836 m
.19393 .26641 L
s
.19328 .26836 m
.19373 .27136 L
s
.85275 .26515 m
.85626 .26142 L
s
.19256 .3142 m
.19322 .28377 L
s
.19145 .31321 m
.19322 .28377 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85431 .26356 m
.85647 .31605 L
s
.192 .3137 m
.19261 .29871 L
s
.85481 .26303 m
.85698 .31556 L
s
.19179 .31871 m
.19256 .3142 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18921 .26412 m
.18958 .26715 L
s
.18927 .27462 m
.18958 .26715 L
s
.19145 .31321 m
.19179 .31871 L
s
.18838 .26056 m
.18921 .26412 L
s
.18879 .2741 m
.18937 .27213 L
s
.18869 .2766 m
.18927 .27462 L
s
.18664 .2584 m
.18838 .26056 L
s
.85594 .29046 m
.85713 .29444 L
s
.18776 .27554 m
.18879 .2741 L
s
.8549 .31754 m
.85698 .31556 L
s
.18766 .27804 m
.18869 .2766 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18807 .29162 m
.18875 .28712 L
s
.18834 .29715 m
.18875 .28712 L
s
.85806 .25927 m
.86085 .25546 L
s
.18539 .27791 m
.18776 .27554 L
s
.85713 .29444 m
.85864 .29541 L
s
.18807 .29162 m
.18834 .29715 L
s
.18529 .28042 m
.18766 .27804 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18749 .29361 m
.18807 .29162 L
s
.18572 .25981 m
.18664 .2584 L
s
.18647 .29509 m
.18749 .29361 L
s
.85931 .25764 m
.86047 .28525 L
s
0 0 0 r
.17664 .23786 m
.17669 .23795 L
s
.255 .412 .882 r
.85864 .29541 m
.85952 .29437 L
s
.85971 .2571 m
.86087 .28473 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18523 .26178 m
.18572 .25981 L
s
.18476 .29302 m
.18647 .29509 L
s
.18505 .25622 m
.18523 .26178 L
s
.18463 .26625 m
.18523 .26178 L
s
.18463 .26625 m
.18505 .25622 L
s
.85952 .29437 m
.86027 .29082 L
s
.85952 .29437 m
.86068 .2903 L
s
.18449 .27937 m
.18539 .27791 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18438 .28188 m
.18529 .28042 L
s
.86027 .29082 m
.86047 .28525 L
s
.184 .28135 m
.18449 .27937 L
s
.86068 .2903 m
.86087 .28473 L
s
.18407 .28945 m
.18476 .29302 L
s
.18389 .28388 m
.18438 .28188 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18379 .2864 m
.184 .28135 L
s
.18379 .2864 m
.18407 .28945 L
s
.86223 .25326 m
.86428 .24937 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18193 .25378 m
.18232 .25993 L
s
.86317 .2516 m
.86467 .28703 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86346 .25104 m
.86496 .2865 L
s
.18121 .24959 m
.18193 .25378 L
s
0 0 0 r
.17334 .31436 m
.17339 .31444 L
s
.255 .412 .882 r
.18146 .28016 m
.18157 .27762 L
s
.18137 .27455 m
.18157 .27762 L
s
.86373 .28862 m
.86496 .2865 L
s
.18064 .28417 m
.18146 .28016 L
s
.18097 .27655 m
.18137 .27455 L
s
.18071 .24847 m
.18121 .24959 L
s
.18097 .27655 m
.18116 .27962 L
s
0 0 0 r
.1757 .25957 m
.17595 .25504 L
s
.1757 .25957 m
.17664 .23786 L
s
.255 .412 .882 r
.18014 .24988 m
.18071 .24847 L
s
.17992 .24933 m
.18071 .24847 L
s
.17997 .28564 m
.18064 .28417 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86501 .30284 m
.86521 .29977 L
s
.86501 .30284 m
.86542 .30487 L
s
.1795 .25384 m
.18014 .24988 L
s
.86521 .29977 m
.86561 .3018 L
s
.17919 .28404 m
.17997 .28564 L
s
.86542 .30487 m
.86561 .3018 L
s
.1793 .25329 m
.17992 .24933 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86577 .25419 m
.86594 .24799 L
s
.86577 .25419 m
.86588 .26236 L
s
.86588 .26236 m
.86609 .26745 L
s
.17897 .26092 m
.1795 .25384 L
s
.86597 .25363 m
.86613 .24742 L
s
.86597 .25363 m
.86609 .26181 L
s
.86609 .26745 m
.86663 .27456 L
s
.86594 .24799 m
.86635 .24375 L
s
.86609 .26181 m
.86631 .26691 L
s
.17884 .28041 m
.17919 .28404 L
s
.17862 .27988 m
.17919 .28404 L
s
.17879 .26037 m
.1793 .25329 L
s
.86631 .26691 m
.86684 .27401 L
s
.86613 .24742 m
.86635 .24375 L
s
.17863 .27422 m
.17884 .28041 L
s
.17876 .26602 m
.17897 .26092 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86663 .27456 m
.86725 .27859 L
s
.86635 .24375 m
.86664 .24262 L
s
.17863 .27422 m
.17876 .26602 L
s
.17843 .27368 m
.17862 .27988 L
s
.17857 .26547 m
.17879 .26037 L
s
0 0 0 r
.17414 .29716 m
.17429 .29235 L
s
.17334 .31436 m
.17429 .29235 L
s
.255 .412 .882 r
.86684 .27401 m
.86743 .27804 L
s
.17843 .27368 m
.17857 .26547 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17807 .23886 m
.1788 .24284 L
s
0 0 0 r
.17467 .23571 m
.17449 .23033 L
s
.17449 .24357 m
.17467 .23571 L
s
.255 .412 .882 r
.86725 .27859 m
.86788 .27953 L
s
0 0 0 r
.17455 .23513 m
.17449 .23033 L
s
.17436 .24299 m
.17455 .23513 L
s
.255 .412 .882 r
.86743 .27804 m
.86788 .27953 L
s
.17689 .27702 m
.17842 .24114 L
s
0 0 0 r
.17449 .23033 m
.17432 .22916 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86664 .24262 m
.86711 .24347 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86711 .24347 m
.86752 .24745 L
s
.17678 .27648 m
.17832 .24057 L
s
.86788 .27953 m
.86831 .2779 L
s
0 0 0 r
.17322 .28545 m
.17261 .28327 L
s
.17432 .22916 m
.17398 .23106 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17261 .28327 m
.17436 .24299 L
s
.17275 .28381 m
.17449 .24357 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86831 .2779 m
.86843 .27424 L
s
.86809 .2634 m
.8681 .26652 L
s
.8681 .26652 m
.86831 .26854 L
s
.86809 .2634 m
.86829 .26542 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17398 .23106 m
.17359 .23722 L
s
.255 .412 .882 r
.86841 .26799 m
.86843 .27424 L
s
.17653 .27484 m
.17689 .27702 L
s
.86829 .26542 m
.86841 .26799 L
s
0 0 0 r
.17407 .22624 m
.17406 .22388 L
s
.17183 .27778 m
.17407 .22624 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17797 .23255 m
.17789 .23657 L
s
0 0 0 r
.17181 .27723 m
.17405 .22565 L
s
.255 .412 .882 r
.17622 .2925 m
.176 .29455 L
s
.17623 .28938 m
.17622 .2925 L
s
.17602 .29143 m
.17623 .28938 L
s
.86753 .23577 m
.86775 .24034 L
s
.86753 .23577 m
.86797 .24606 L
s
.176 .29455 m
.17602 .29143 L
s
.17664 .26323 m
.17786 .23485 L
s
.86775 .24034 m
.86797 .24606 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86764 .2372 m
.86775 .24034 L
s
.86748 .23348 m
.86764 .2372 L
s
.17665 .26267 m
.17787 .23427 L
s
0 0 0 r
.17195 .27943 m
.17181 .27723 L
s
.255 .412 .882 r
.86727 .23117 m
.86748 .23348 L
s
.86853 .2584 m
.86863 .26154 L
s
.86863 .26154 m
.86886 .26671 L
s
.86864 .26098 m
.86875 .26412 L
s
.8684 .25469 m
.86853 .2584 L
s
.86886 .26671 m
.86897 .26875 L
s
.86851 .25728 m
.86864 .26098 L
s
.17643 .26786 m
.17664 .26323 L
s
.86794 .24669 m
.8684 .25469 L
s
.86897 .26875 m
.86907 .27024 L
s
.86805 .24929 m
.86851 .25728 L
s
.17645 .2673 m
.17665 .26267 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86721 .2326 m
.86727 .23117 L
s
.17641 .2688 m
.17643 .26786 L
s
.8689 .26804 m
.86907 .27024 L
s
.17641 .2688 m
.17645 .2673 L
s
0 0 0 r
.1739 .23141 m
.17441 .22285 L
s
.17333 .24308 m
.1739 .23141 L
s
.255 .412 .882 r
.86721 .2326 m
.86722 .23462 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17441 .22285 m
.17494 .21738 L
s
.17301 .25049 m
.17333 .24308 L
s
.255 .412 .882 r
.86766 .24297 m
.86794 .24669 L
s
0 0 0 r
.17399 .23082 m
.17452 .22226 L
s
.17341 .2425 m
.17399 .23082 L
s
.255 .412 .882 r
.86777 .24556 m
.86805 .24929 L
s
0 0 0 r
.17452 .22226 m
.17494 .21738 L
s
.17309 .24992 m
.17341 .2425 L
s
.255 .412 .882 r
.17653 .2677 m
.17641 .2688 L
s
0 0 0 r
.17261 .26106 m
.17301 .25049 L
s
.255 .412 .882 r
.86722 .23462 m
.86755 .2424 L
s
.86744 .2398 m
.86766 .24297 L
s
.86755 .2424 m
.86777 .24556 L
s
0 0 0 r
.1727 .2605 m
.17309 .24992 L
s
.17494 .21738 m
.17524 .2162 L
s
.255 .412 .882 r
.86864 .26433 m
.8689 .26804 L
s
.17653 .2677 m
.1769 .26343 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86844 .26116 m
.86864 .26433 L
s
0 0 0 r
.17247 .2674 m
.17261 .26106 L
s
.17524 .2162 m
.17543 .21872 L
s
.255 .412 .882 r
.86811 .2554 m
.86844 .26116 L
s
.86844 .26116 m
.86856 .26583 L
s
.86811 .2554 m
.86856 .26583 L
s
0 0 0 r
.17258 .26684 m
.1727 .2605 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17623 .28327 m
.17782 .24622 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1769 .26343 m
.17735 .2571 L
s
0 0 0 r
.17543 .21872 m
.17549 .22497 L
s
.17268 .26946 m
.17247 .2674 L
s
.255 .412 .882 r
.86579 .22481 m
.86609 .22799 L
s
0 0 0 r
.17268 .26946 m
.17258 .26684 L
s
.17598 .21383 m
.17689 .21145 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17298 .26835 m
.17268 .26946 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17623 .28327 m
.17681 .28111 L
s
.17636 .28273 m
.17646 .28025 L
s
.17766 .25229 m
.17793 .24603 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17349 .26348 m
.17298 .26835 L
s
.1742 .25486 m
.17349 .26348 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86782 .27217 m
.86792 .27454 L
s
.86657 .24306 m
.86662 .24418 L
s
.868 .27295 m
.86811 .27509 L
s
.86657 .24306 m
.86661 .24416 L
s
.86762 .27137 m
.86772 .274 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86811 .27509 m
.86814 .27982 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17257 .29252 m
.17598 .21383 L
s
.17278 .29198 m
.17619 .21323 L
s
.255 .412 .882 r
.86772 .274 m
.86814 .27982 L
s
0 0 0 r
.172 .29414 m
.17278 .29198 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17812 .21912 m
.1791 .21045 L
s
.17732 .23095 m
.17812 .21912 L
s
.1791 .21045 m
.18034 .20493 L
s
.177 .23847 m
.17732 .23095 L
s
.17844 .21853 m
.17945 .20986 L
s
.17764 .23037 m
.17844 .21853 L
s
.17945 .20986 m
.18034 .20493 L
s
.17731 .23789 m
.17764 .23037 L
s
.17683 .2492 m
.177 .23847 L
s
.18034 .20493 m
.18111 .20374 L
s
.17715 .24864 m
.17731 .23789 L
s
.17683 .2492 m
.17716 .25564 L
s
.18111 .20374 m
.18177 .20632 L
s
.18111 .20374 m
.1822 .20573 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17715 .24864 m
.17751 .25508 L
s
.18177 .20632 m
.18232 .21269 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17716 .25564 m
.17808 .25776 L
s
.1822 .20573 m
.18277 .2121 L
s
.17751 .25508 m
.17808 .25776 L
s
.255 .412 .882 r
.18675 .21187 m
.18685 .21174 L
s
.18685 .21174 m
.18765 .21323 L
s
.18685 .21174 m
.18719 .2138 L
s
0 0 0 r
.18229 .22345 m
.18232 .21269 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17808 .25776 m
.17885 .25664 L
s
.18275 .22287 m
.18277 .2121 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18665 .23711 m
.18687 .23195 L
s
0 0 0 r
.18196 .23103 m
.18229 .22345 L
s
.17885 .25664 m
.17984 .25172 L
s
.17885 .25664 m
.18026 .25116 L
s
.255 .412 .882 r
.18691 .24189 m
.18734 .23156 L
s
0 0 0 r
.18243 .23046 m
.18275 .22287 L
s
.18103 .24299 m
.18196 .23103 L
s
.17984 .25172 m
.18103 .24299 L
s
.18619 .19725 m
.18954 .19373 L
s
.18148 .24243 m
.18243 .23046 L
s
.18026 .25116 m
.18148 .24243 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18691 .24189 m
.18665 .23711 L
s
.18713 .23656 m
.18773 .23333 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1896 .21722 m
.19245 .24286 L
s
.18726 .19608 m
.1896 .21722 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18394 .25054 m
.18731 .24723 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19201 .1914 m
.19606 .18792 L
s
.18502 .24944 m
.19398 .18966 L
s
.18557 .24888 m
.19466 .18908 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18979 .24504 m
.19385 .24177 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20194 .18718 m
.20455 .18163 L
s
.20084 .19543 m
.20194 .18718 L
s
.19912 .23799 m
.20084 .19543 L
s
.20275 .18661 m
.20455 .18163 L
s
.20163 .19487 m
.20275 .18661 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20469 .23203 m
.20529 .21676 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19992 .23746 m
.20163 .19487 L
s
.20455 .18163 m
.20625 .1805 L
s
.20625 .1805 m
.20873 .18267 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19679 .23961 m
.19992 .23746 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20873 .18267 m
.21023 .1893 L
s
.21069 .17769 m
.21445 .17547 L
s
.20856 .23215 m
.21069 .17769 L
s
.20948 .23163 m
.21161 .17713 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83552 .21161 m
.83562 .21414 L
s
.83691 .24711 m
.83696 .24833 L
s
.83642 .21309 m
.83648 .21458 L
s
.83781 .24858 m
.83782 .24884 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20584 .23373 m
.20948 .23163 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2194 .17272 m
.22013 .17996 L
s
.2188 .18829 m
.2194 .17272 L
s
.82486 .17975 m
.82574 .1764 L
s
.82457 .17196 m
.82574 .1764 L
s
.82367 .17531 m
.82457 .17196 L
s
.2188 .18829 m
.22013 .17996 L
s
.22013 .17996 m
.22131 .17552 L
s
.22131 .17552 m
.22356 .17055 L
s
.82367 .17531 m
.82486 .17975 L
s
.22356 .17055 m
.22791 .1684 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8256 .19927 m
.82843 .24702 L
s
.8256 .19927 m
.82635 .24602 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21791 .21175 m
.21909 .20731 L
s
.21761 .21961 m
.21791 .21175 L
s
.21909 .20731 m
.22133 .20234 L
s
.22791 .1684 m
.23001 .17125 L
s
.21776 .21568 m
.21894 .21123 L
s
.21894 .21123 m
.22118 .20626 L
s
.21761 .21961 m
.21849 .22302 L
s
.22133 .20234 m
.22704 .19189 L
s
.22118 .20626 m
.22689 .19581 L
s
.23001 .17125 m
.231 .17463 L
s
.21849 .22302 m
.22044 .22594 L
s
.81494 .17104 m
.81622 .17548 L
s
.81622 .17548 m
.81665 .18724 L
s
.81251 .16608 m
.81494 .17104 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8265 .22283 m
.82739 .24652 L
s
.81552 .18672 m
.81651 .18332 L
s
.23057 .1864 m
.231 .17463 L
s
.22704 .19189 m
.22943 .18692 L
s
.81566 .19065 m
.81665 .18724 L
s
.22689 .19581 m
.22928 .19085 L
s
.22044 .22594 m
.22476 .22392 L
s
.22943 .18692 m
.23071 .18248 L
s
.81337 .18962 m
.81552 .18672 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80779 .16399 m
.81251 .16608 L
s
.5 Mabswid
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22928 .19085 m
.23057 .1864 L
s
.82769 .25445 m
.82843 .24702 L
s
.81351 .19356 m
.81566 .19065 L
s
.8055 .16688 m
.80779 .16399 L
s
.82635 .24602 m
.82769 .25445 L
s
.81653 .2143 m
.81738 .20691 L
s
.81738 .20691 m
.81796 .22272 L
s
.22476 .22392 m
.22714 .21896 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23941 .16708 m
.24078 .16264 L
s
.23941 .16708 m
.2405 .1705 L
s
.22842 .2145 m
.22985 .20609 L
s
.22927 .22192 m
.22985 .20609 L
s
.24078 .16264 m
.24187 .16606 L
s
.80441 .1703 m
.8055 .16688 L
s
.22714 .21896 m
.22842 .2145 L
s
.22842 .2145 m
.22927 .22192 L
s
.81553 .21776 m
.81653 .2143 L
s
.81653 .2143 m
.81796 .22272 L
s
.8029 .16193 m
.80441 .1703 L
s
.2405 .1705 m
.24187 .16606 L
s
.81335 .22073 m
.81553 .21776 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80771 .19498 m
.81337 .18962 L
s
.80785 .19894 m
.81351 .19356 L
s
.80345 .17768 m
.80441 .1703 L
s
.8029 .16193 m
.80345 .17768 L
s
.80539 .19795 m
.80771 .19498 L
s
.80856 .21878 m
.81335 .22073 L
s
.80553 .20191 m
.80785 .19894 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23687 .23842 m
.2398 .19022 L
s
.23935 .23748 m
.2398 .19022 L
s
.80429 .20142 m
.80539 .19795 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80595 .21383 m
.80856 .21878 L
s
.80429 .20142 m
.80457 .20936 L
s
.80443 .20539 m
.80553 .20191 L
s
.23811 .23795 m
.23896 .21401 L
s
.79139 .16136 m
.79432 .17025 L
s
.80457 .20936 m
.80595 .21383 L
s
.78718 .15594 m
.79139 .16136 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78441 .15498 m
.78718 .15594 L
s
.23687 .23842 m
.23782 .24596 L
s
.795 .19008 m
.79527 .19804 L
s
.77834 .18448 m
.795 .19008 L
s
.78173 .15798 m
.78441 .15498 L
s
.78031 .15751 m
.78441 .15498 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79367 .1896 m
.79407 .20155 L
s
.79421 .20555 m
.79527 .19804 L
s
.23782 .24596 m
.23935 .23748 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77914 .16499 m
.78173 .15798 L
s
.793 .20908 m
.79407 .20155 L
s
.7777 .16452 m
.78031 .15751 L
s
.793 .20908 m
.79421 .20555 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79041 .21215 m
.793 .20908 L
s
.77808 .17648 m
.77914 .16499 L
s
.77662 .17603 m
.7777 .16452 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78625 .21079 m
.79041 .21215 L
s
.255 .412 .882 r
.27053 .18907 m
.27226 .188 L
s
0 0 0 r
.7639 .14848 m
.76996 .15028 L
s
.77808 .17648 m
.77834 .18448 L
s
.77662 .17603 m
.77688 .18402 L
s
.77834 .18448 m
.78017 .19694 L
s
.78329 .20587 m
.78625 .21079 L
s
.78187 .20542 m
.78625 .21079 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77688 .18402 m
.77872 .1965 L
s
.78017 .19694 m
.78329 .20587 L
s
.77872 .1965 m
.78187 .20542 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7656 .18253 m
.76621 .18605 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76093 .15158 m
.76426 .16045 L
s
.75768 .14671 m
.76093 .15158 L
s
.75451 .14584 m
.75768 .14671 L
s
.75142 .14899 m
.75451 .14584 L
s
.74981 .14857 m
.75451 .14584 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74841 .15617 m
.75142 .14899 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74677 .15576 m
.74981 .14857 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76543 .14892 m
.76801 .23347 L
s
.7639 .14848 m
.76647 .23307 L
s
.76237 .19979 m
.76524 .19256 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74711 .16783 m
.74841 .15617 L
s
.74546 .16742 m
.74677 .15576 L
s
.75935 .20301 m
.76237 .19979 L
s
.74711 .16783 m
.74734 .1759 L
s
.74546 .16742 m
.74569 .17549 L
s
.75616 .20219 m
.75935 .20301 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74734 .1759 m
.74932 .18843 L
s
.74569 .17549 m
.74768 .18803 L
s
.75282 .19733 m
.75616 .20219 L
s
.75119 .19693 m
.75616 .20219 L
s
.74932 .18843 m
.75282 .19733 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76177 .23186 m
.76801 .23347 L
s
.72969 .14372 m
.73334 .15255 L
s
.72436 .13855 m
.72969 .14372 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74768 .18803 m
.75119 .19693 L
s
.72083 .1378 m
.72436 .13855 L
s
.71737 .1411 m
.72083 .1378 L
s
.71558 .14074 m
.72083 .1378 L
s
.73388 .17276 m
.73409 .18087 L
s
.73216 .17238 m
.73248 .18456 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73258 .18863 m
.73409 .18087 L
s
.73095 .19234 m
.73248 .18456 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71264 .16842 m
.73388 .17276 L
s
.71216 .14811 m
.71558 .14074 L
s
.71397 .14847 m
.71737 .1411 L
s
.71245 .16028 m
.71397 .14847 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73095 .19234 m
.73258 .18863 L
s
.71063 .15994 m
.71216 .14811 L
s
.68957 .13195 m
.70271 .13425 L
s
.72756 .19569 m
.73095 .19234 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71245 .16028 m
.71264 .16842 L
s
.255 .412 .882 r
.72078 .20999 m
.72121 .20984 L
s
0 0 0 r
.71063 .15994 m
.71082 .16807 L
s
.72225 .19463 m
.72756 .19569 L
s
.255 .412 .882 r
.72078 .20999 m
.72113 .20977 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71264 .16842 m
.71475 .18099 L
s
.71857 .18984 m
.72225 .19463 L
s
.71475 .18099 m
.71857 .18984 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71676 .1895 m
.72225 .19463 L
s
.71082 .16807 m
.71294 .18065 L
s
.69525 .13292 m
.69622 .17772 L
s
.69712 .13324 m
.69811 .17803 L
s
.71294 .18065 m
.71676 .1895 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66822 .1287 m
.6819 .13072 L
s
.67608 .12983 m
.67695 .17478 L
s
.67412 .12955 m
.67498 .17451 L
s
.6964 .18592 m
.69811 .17803 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6945 .18562 m
.69622 .17772 L
s
.64611 .12589 m
.66027 .12763 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69077 .18913 m
.6964 .18592 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69077 .18913 m
.6945 .18562 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68693 .18854 m
.69077 .18913 L
s
.68102 .18357 m
.68693 .18854 L
s
.62336 .12354 m
.63791 .12498 L
s
.67695 .17478 m
.68102 .18357 L
s
.67514 .18274 m
.67695 .17478 L
s
.67317 .18247 m
.67498 .17451 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66928 .18606 m
.67514 .18274 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66928 .18606 m
.67317 .18247 L
s
.60006 .12167 m
.61494 .12281 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66528 .18555 m
.66928 .18606 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65917 .18068 m
.66528 .18555 L
s
.65498 .17195 m
.65917 .18068 L
s
.62962 .12414 m
.6304 .18177 L
s
.6317 .12434 m
.63249 .18196 L
s
.65221 .12661 m
.65315 .1841 L
s
.65423 .12686 m
.65519 .18433 L
s
.45178 .12125 m
.46472 .12051 L
s
.57635 .12029 m
.59148 .12111 L
s
.64701 .18342 m
.65519 .18433 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47776 .11992 m
.49086 .11947 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47074 .19474 m
.4843 .11968 L
s
.55236 .11942 m
.55894 .12371 L
s
.54798 .11931 m
.55236 .11942 L
s
.49524 .11936 m
.51061 .1191 L
s
.5436 .12333 m
.54798 .11931 L
s
.5414 .12329 m
.54798 .11931 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60859 .1223 m
.60908 .16759 L
s
.60646 .12214 m
.60694 .16744 L
s
.55894 .12371 m
.56336 .13209 L
s
.53922 .13149 m
.5436 .12333 L
s
.53702 .13146 m
.5414 .12329 L
s
.4602 .14542 m
.4798 .14454 L
s
.62409 .18121 m
.63249 .18196 L
s
.53704 .14384 m
.53922 .13149 L
s
.53484 .14382 m
.53702 .13146 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60703 .17573 m
.60908 .16759 L
s
.53704 .14384 m
.53706 .15212 L
s
.53484 .14382 m
.53485 .15209 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50167 .17714 m
.50182 .11922 L
s
.50388 .17711 m
.50402 .11918 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60063 .17945 m
.60703 .17573 L
s
.60488 .17558 m
.60694 .16744 L
s
.60063 .17945 m
.60488 .17558 L
s
.58537 .16611 m
.58978 .17464 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45608 .12098 m
.47066 .20731 L
s
.47066 .20731 m
.48649 .1196 L
s
.56129 .1568 m
.56351 .16102 L
s
.55911 .16088 m
.56129 .1568 L
s
.50394 .15218 m
.50612 .16459 L
s
.63068 .20256 m
.63284 .20691 L
s
.62863 .20654 m
.63068 .20256 L
s
.53706 .15212 m
.53929 .16459 L
s
.53485 .15209 m
.53708 .16456 L
s
.59631 .17918 m
.60063 .17945 L
s
.63079 .2109 m
.63284 .20691 L
s
.56351 .16102 m
.56353 .16517 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58978 .17464 m
.59631 .17918 L
s
.55911 .16088 m
.56133 .16509 L
s
.62863 .20654 m
.63079 .2109 L
s
.55917 .17334 m
.56353 .16517 L
s
.53929 .16459 m
.54373 .17298 L
s
.50612 .16459 m
.51053 .17286 L
s
.53708 .16456 m
.54152 .17294 L
s
.51939 .16864 m
.5216 .16448 L
s
.5216 .16448 m
.52381 .16864 L
s
.55478 .17738 m
.55917 .17334 L
s
.51939 .16864 m
.5216 .1728 L
s
.52381 .16864 m
.52381 .1728 L
s
.54373 .17298 m
.54816 .17723 L
s
.54152 .17294 m
.54816 .17723 L
s
.51053 .17286 m
.51495 .17699 L
s
.5216 .17696 m
.52381 .1728 L
s
.54816 .17723 m
.55478 .17738 L
s
.49504 .17727 m
.50388 .17711 L
s
.51495 .17699 m
.5216 .17696 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58285 .12062 m
.58352 .2077 L
s
.58502 .12074 m
.5857 .2078 L
s
.57695 .2074 m
.5857 .2078 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00@0[Jf]0?nV403oYQ00ojH@
2000000B0?nV40030000002][Jd0ojD@01d0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][Fh0/>3V
0@3oool00880/>3V0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00T0ojHA1`0000040?nV4@80[Jf]1`00
00050:f][@8000004`2][Jd2000000030:f][@000000000000/0[Jf]2@0000090?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@05
0?nV4@H0[Jf]00<000000:f][@2][Jd01P2][Jd50?nV4@80000000<0[Jf]0?nV403oYQ00103oYQ02
00000180ojH@0P0000020?nV40040:f][@3oYA000000000000`0ojD@0P0000070:f][@P000000`2]
[JdG0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF
3P070>bF3P<0[Jf]J02`h>H10?ooo`00O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Jd60?nV4@030000003oYQ40
ojHA00/0ojHA0P0000000`2][Jd0ojH@0?nV40040?nV408000004@3oYQ000`000000ojH@00000002
0?nV40050:f][@3oYA00ojD@0?nU400000002`3oYA02000000X0ojD@0P0000000`3oYA00[Jf]0?nS
40030?nS40T000003P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ40
0`2][Jd0ojHA0?nV4@0;0?nV4@030000003oYQ40ojHA00X0ojHA0P0000000`3oYQ40[Jf]0?nV4005
0?nV40800000403oYQ000`000000ojH@000000030?nV40030:f][@3oYA00ojD@0080ojD@00<00000
0?nU403oYA00203oYA02000000X0ojD@0P0000000`3oYA00[Jf]0?nS40070?nS408000000`3oXa03
0:f][@D000000P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV
4@030:f][@3oYQ40ojHA00`0ojHA00<000000?nV4@3oYQ402@3oYQ42000000030?nV4@2][Jd0ojH@
00D0ojH@0P00000@0?nV40030000003oYQ00000000<0ojH@00<0[Jf]0?nU403oYA000P3oYA000`00
0000ojD@0?nU40080?nU408000002P3oYA02000000030?nU402][Jd0oj<@00L0oj<@0P0000090?nS
40D000000`2][Jd4000001L0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0E0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@030000003oYQ40ojHA00T0
ojHA0P0000000`3oYQ40[Jf]0?nV40050?nV408000003`3oYQ000`000000ojH@000000040?nV4003
0:f][@3oYA00ojD@00<0ojD@00<000000?nU403oYA001`3oYA02000000X0ojD@0P0000000`3oYA00
[Jf]0?nS40070?nS408000002@3oXa02000000H0oj<@00<0[Jf]0?bP403lX1001@0000000`2][Jd0
o:0@0?bP400@0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0
/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
403oYQ450:f][@80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@030000
003oYQ40ojHA00T0ojHA0P0000000`3oYQ40[Jf]0?nV40050?nV408000003`3oYQ000`000000ojH@
000000040?nV40030:f][@3oYA00ojD@00@0ojD@00<000000?nU403oYA001P3oYA02000000X0ojD@
0P0000000`3oYA00[Jf]0?nS40070?nS408000002@3oXa02000000H0oj<@00<0[Jf]0?bP403lX100
0P0000040?bP40030:f][@000000000000<00000303lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3o
YQ450:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@030000003o
YQ40ojHA00T0ojHA0P0000000`3oYQ40[Jf]0?nV40050?nV408000003`3oYQ000`000000ojH@0000
00040?nV40030:f][@3oYA00ojD@00d0ojD@0P00000:0?nU4080000000<0ojD@0:f][@3oXa001`3o
Xa02000000T0oj<@0P0000060?nS40030:f][@3lX100o:0@00800000203lX105000000030:f][@3l
X100o:0@00H0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3K
RPd0fhX=0080fhX=0P2][JeK0;3PiP40oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@030000003oYQ40ojHA00P0ojHA00D00000
0?nV4@000000ojHA0:f][@060?nV408000003`3oYQ02000000D0ojH@00<0[Jf]0?nU403oYA003@3o
YA02000000X0ojD@0P0000000`3oYA00[Jf]0?nS40070?nS408000002@3oXa02000000H0oj<@00<0
[Jf]0?bP403lX1000P0000080?bP40800000103lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^
0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D
0?nT4@030:f][@3oYQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA00`0ojHA00<000000?nV4@3oYQ40203oYQ4200000080ojHA00<0[Jf]0?nV403oYQ00103oYQ02
000000h0ojH@00<000000?nV400000001@3oYQ000`2][Jd0ojD@0?nU400=0?nU408000002P3oYA02
000000030?nU402][Jd0oj<@00L0oj<@0P0000090?nS408000001P3oXa000`2][Jd0o:0@0?bP4002
000000P0o:0@0P00000:0?bP40@000005@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A01<0oj@A102][JdG0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ403@3oYQ400`000000ojHA0?nV4@070?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40040?nV
408000003P3oYQ000`000000ojH@000000050?nV40030:f][@3oYA00ojD@00d0ojD@0P00000:0?nU
4080000000<0ojD@0:f][@3oXa001`3oXa02000000T0oj<@0P0000060?nS40030:f][@3lX100o:0@
00800000203lX102000000P0o:0@0`000000103lX100[Jf]0?JL3`0000030:f][A40mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f]
[@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f]
[@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00h0ojHA00<000000?nV
4@3oYQ401`3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000h0ojH@0P0000060?nV
40030:f][@3oYA00ojD@00d0ojD@0P00000:0?nU4080000000<0ojD@0:f][@3oXa001`3oXa020000
00T0oj<@0P0000060?nS40030:f][@3lX100o:0@00800000203lX102000000P0o:0@0P0000020?bP
40030:f][@3fW0l0000000<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00h0ojHA300000020?nV4@030:f][@3oYQ00ojH@00@0
ojH@0P00000>0?nV408000001P3oYQ000`2][Jd0ojD@0?nU400=0?nU408000002P3oYA0200000003
0?nU402][Jd0oj<@00L0oj<@0P0000090?nS408000001P3oXa000`2][Jd0o:0@0?bP4002000000P0
o:0@0P0000070?bP408000000`3lX100102][Jd0mY`?0?JL3`0000060?JL3`@0[Jf]2@3fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?oo
o`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1401`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@03
0:f][@3oYQ40ojHA00h0ojHA00<000000?nV4@3oYQ401`3oYQ4200000080ojHA00<0[Jf]0?nV403o
YQ00103oYQ02000000h0ojH@0P0000060?nV40030:f][@3oYA00ojD@00d0ojD@0P00000:0?nU4080
000000<0ojD@0:f][@3oXa001`3oXa02000000T0oj<@0P0000060?nS40030:f][@3lX100o:0@0080
0000203lX102000000L0o:0@0P0000030?bP40040:f][@3fW0l0mY`?000000X0mY`?00@0[Jf]0000
0000000000001@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA
0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2]
[Jd0ojHA0?nV4@0>0?nV4@030000003oYQ40ojHA00H0ojHA0P0000030?nV4@030:f][@3oYQ00ojH@
00@0ojH@0P00000>0?nV408000001P3oYQ000`2][Jd0ojD@0?nU400=0?nU408000002P3oYA020000
00030?nU402][Jd0oj<@00L0oj<@0P0000090?nS408000001`3oXa00102][Jd0o:0@000000000008
0?bP408000001`3lX102000000<0o:0@00D0[Jf]0?JL3`3fW0l0mY`?000000080?JL3`<000000P3f
W0l01P000000[Jf]000000000000mY`?0:f][A80k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0:f][@1@0;3PiP40oooo001U0;3PiP030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00h0ojHA00<000000?nV4@3oYQ401P3oYQ42000000<0ojHA
00<0[Jf]0?nV403oYQ00103oYQ02000000h0ojH@0P0000060?nV40030:f][@3oYA00ojD@00d0ojD@
0P00000:0?nU4080000000<0ojD@0:f][@3oXa001`3oXa02000000T0oj<@0P0000070?nS40040:f]
[@3lX1000000000000P0o:0@0P0000070?bP408000000`3lX1001@2][Jd0mY`?0?JL3`3fW0l00000
00P0mY`?0P0000030?JL3`030000003fW0l0000000<0000000<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>7
3P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ403`3oYQ400`000000ojHA0?nV4@05
0?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV40040?nV408000003P3oYQ02000000H0ojH@00<0[Jf]
0?nU403oYA003@3oYA02000000X0ojD@0P0000000`3oYA00[Jf]0?nS40070?nS408000002@3oXa02
000000L0oj<@00@0[Jf]0?bP400000000000203lX102000000L0o:0@0P0000030?bP40030:f][@3f
W0l0mY`?0080mY`?00<000000?JL3`3fW0l0103fW0l2000000D0mY`?0`0000000`3fW0l0[Jf]0>bF
3P030:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V
0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@
0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@030000003oYQ40ojHA00D0ojHA0P0000030?nV4@030:f]
[@3oYQ00ojH@00@0ojH@0P00000>0?nV408000001P3oYQ000`2][Jd0ojD@0?nU400=0?nU40800000
2P3oYA02000000030?nU402][Jd0oj<@00L0oj<@0P0000090?nS408000001`3oXa00102][Jd0o:0@
0000000000080?bP408000001P3lX102000000@0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l2000000D0
mY`?0`0000000`3fW0l0[Jf]0>bF3P030>bF3P80[Jf]00<0k9H>0000003/UPh02@3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f]
[@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]
0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6@3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@030000003oYQ40ojHA00<0ojHA0P2][Jd2000000X0[Jf]
0P00000>0:f][@030000002][Jd0000000/0[Jf]00<000000:f][@3oYA001`3oYA02000000X0ojD@
0P0000000`3oYA00[Jf]0?nS40070?nS408000002@3oXa02000000L0oj<@00@0[Jf]0?bP40000000
00002@3lX102000000D0o:0@0P0000040?bP40030:f][@3fW0l0mY`?00T0mY`?0P0000060?JL3`80
000000<0mY`?0:f][@3/UPh0103/UPh2000000030:f][@000000k9H>00P0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640/>3V
00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@
0P2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA00D0ojHA2P2][Jd00`000000[Jf]0:f][@030:f][@030?nV
4@000000000000@0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000h0ojH@00<000000?nV40000000
1@3oYQ000`2][Jd0ojD@0?nU40020?nU4080000000<0ojD@0:f][@2][Jd01P2][Jd2000000H0[Jf]
103oYA02000000030?nU402][Jd0oj<@00L0oj<@0P0000090?nS408000001`3oXa00102][Jd0o:0@
0000000000090?bP408000001@3lX102000000@0o:0@00<0[Jf]0?JL3`3fW0l02@3fW0l2000000H0
mY`?0P0000000`3fW0l0[Jf]0>bF3P030>bF3P8000000`3/UPh00`000000[Jf]0:f][@060>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3PiP40
oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA
00<0[Jf]0?nV4@3oYQ405@3oYQ4<0:f][@X0ojHA00<000000?nV4@3oYQ40103oYQ42000000@0ojHA
00<0[Jf]0?nV403oYQ00103oYQ03000000h0ojH@0P0000050?nV40050:f][@3oYA00ojD@0?nU4000
00000P3oYA000`000000ojD@0?nU40060?nU408000001P3oYA040:f][@8000001P2][Jd40?nS4080
00002@3oXa02000000L0oj<@00@0[Jf]0?bP4000000000002@3lX102000000D0o:0@0P0000040?bP
40030:f][@3fW0l0mY`?00T0mY`?0P0000060?JL3`80000000<0mY`?0:f][@3/UPh00`3/UPh20000
00@0k9H>00@000000>bF3P2][Jd0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>7
3P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX10000000`2][Jd;0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@T0[Jf]103oYQ40
0`2][Jd0ojHA0?nV4@0?0?nV4@030000003oYQ40ojHA00@0ojHA0P0000040?nV4@030:f][@3oYQ00
ojH@00@0ojH@0`00000>0?nV40030000003oYQ00000000@0ojH@00<0[Jf]0?nU403oYA000P3oYA00
0`000000ojD@000000080?nU408000002P3oYA02000000030?nU402][Jd0oj<@00<0oj<@102][Jd2
000000@0[Jf]1@3oXa02000000L0oj<@00@0[Jf]0?bP4000000000002@3lX102000000D0o:0@0P00
00040?bP40030:f][@3fW0l0mY`?00P0mY`?0P0000070?JL3`80000000<0mY`?0:f][@3/UPh00P3/
UPh2000000D0k9H>00@000000>bF3P3/UPh0k9H>0P2][Jd00`000000k9H>0:f][@0=0=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP4000000000003P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@d0ojHA
00<0[Jf]0?nV4@3oYQ40403oYQ400`000000ojHA0?nV4@030?nV4@800000103oYQ400`2][Jd0ojH@
0?nV40040?nV40<000001`3oYQ000`000000ojH@0?nV40040?nV40030000003oYQ00000000@0ojH@
00<0[Jf]0?nU403oYA000`3oYA02000000T0ojD@0P0000090?nU4080000000<0ojD@0:f][@3oXa00
1`3oXa02000000@0oj<@1@2][Jd2000000<0[Jf]103oXa00102][Jd0o:0@0000000000090?bP4080
00001@3lX102000000@0o:0@00<0[Jf]0?JL3`3fW0l0203fW0l2000000L0mY`?0P0000000`3fW0l0
[Jf]0>bF3P020>bF3P8000001P3/UPh00`000000k9H>0>bF3P020>bF3P040000002][Jd000000000
00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P03
0:f][@3_V100kiP@00/0kiP@0P2][Jd00`000000o:0@0000000=0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405P3oYQ470:f][AL0ojHA00<0[Jf]0?nV4@3oYQ40403oYQ400`000000
ojHA0?nV4@030?nV4@800000103oYQ400`2][Jd0ojH@0?nV40040?nV40<000001P3oYQ02000000L0
ojH@0P0000040?nV40030:f][@3oYA00ojD@00<0ojD@00<000000?nU403oYA00203oYA02000000T0
ojD@0P0000000`3oYA00[Jf]0?nS40070?nS408000002@3oXa02000000<0oj<@1P2][Jd2000000T0
o:0@0P0000050?bP40800000103lX1000`2][Jd0mY`?0?JL3`080?JL3`8000001`3fW0l200000003
0?JL3`2][Jd0k9H>0080k9H>0P0000060>bF3P030000003/UPh0k9H>0080k9H>0P0000020:f][@80
00002P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>
00<0[Jf]0>nH403_V1001`3_V102000000<0[Jf]00<0o:0@0000000000003P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1P2][Jd20?nV4@030:f][@3oYQ40ojHA01T0ojHA
00<0[Jf]0?nV4@3oYQ40403oYQ400`000000ojHA0?nV4@020?nV4@030000003oYQ40000000@0ojHA
00<0[Jf]0?nV403oYQ00103oYQ02000000030?nV40000000ojH@00@0ojH@00<000000?nV40000000
1P3oYQ000`000000ojH@000000030?nV40030:f][@3oYA00ojD@0080ojD@00<000000?nU403oYA00
2@3oYA02000000T0ojD@0P0000000`3oYA00[Jf]0?nS40070?nS408000002@3oXa02000000L0oj<@
00@0[Jf]0?bP4000000000001P2][Jd30?bP408000001@3lX10400000080o:0@00<0[Jf]0?JL3`3f
W0l0203fW0l2000000L0mY`?0P0000000`3fW0l0[Jf]0>bF3P020>bF3P8000001`3/UPh010000000
k9H>0>bF3P3/UPh2000000050:f][@3KRPd0fhX=0000002][Jd02@3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2]
[Jd0kiP@0>nH40050>nH408000000P2][Jd00`000000kiP@0:f][@020?bP40030000003lX100o:0@
00`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203oYQ400`2]
[Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA0100ojHA00<000000?nV4@3oYQ400P3oYQ420000
00D0ojHA00<0[Jf]0?nV403oYQ00103oYQ02000000030?nV40000000ojH@00@0ojH@00<000000?nV
400000001`3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA000P3oYA000`000000ojD@0?nU40090?nU
40800000203oYA001@000000ojD@0000003oYA00[Jf]00P0oj<@0P0000090?nS408000001`3oXa00
102][Jd0o:0@0000000000060?bP40<0[Jf]0P0000020:f][@<0o:0@0P0000020?bP40D00000203f
W0l2000000P0mY`?00<000000?JL3`2][Jd00`3/UPh00`000000k9H>0>bF3P060>bF3P040000003/
UPh0k9H>0>bF3P80000000D0[Jf]0=^:3@3KRPd0fhX=000000020:f][@L0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0
dhL>00<0[Jf]0>nH403_V1000`3_V10200000080[Jf]0P3_V1000`000000kiP@0:f][@0A0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0@0?nV4@030000003oYQ40ojHA0080ojHA0P0000050?nV4@03
0:f][@3oYQ00ojH@00@0ojH@0P0000020?nV40030000003oYQ00ojH@00<0ojH@0P0000080?nV4080
00000P3oYQ001@2][Jd0ojD@0?nU403oYA00000000`0ojD@0`0000070?nU408000000P3oYA000`2]
[Jd0oj<@0?nS40060?nS408000002@3oXa02000000L0oj<@00@0[Jf]0?bP4000000000002@3lX102
00000080o:0@0`2][Jd2000000050:f][@3lX100o:0@0?bP402][Jd00P3fW0l3000000D0mY`?0P00
00080?JL3`030000003fW0l0[Jf]00<0k9H>00<000000>bF3P3/UPh02P3/UPh2000000050:f][@3K
RPd0fhX=0=^:3@0000000P3KRPd00`2][Jd0fhX=000000040=^:3@030:f][@2iM@/0^GD;00L0^GD;
00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P06
0:f][@3_V100kiP@0>nH40000000kiP@0P0000040>nH40030000003_V100[Jf]0140o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@060:f][A80ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ40
0`2][Jd0ojHA0?nV4@0@0?nV4@030000003oYQ40ojHA0080ojHA0P0000050?nV4@030:f][@3oYQ00
ojH@00@0ojH@0P0000030?nV40030000003oYQ00ojH@0080ojH@00<000000?nV403oYQ00203oYQ02
000000050?nV402][Jd0ojD@0?nU400000003@3oYA02000000030?nU40000000ojD@00D0ojD@0P00
00020?nU40030:f][@3oXa00oj<@00H0oj<@0P0000090?nS408000001`3oXa00102][Jd0o:0@0000
000000090?bP408000001@3lX102000000030?bP402][Jd0[Jf]00<0[Jf]0`3fW0l00`000000mY`?
0?JL3`030?JL3`800000203fW0l00`000000mY`?0:f][@030>bF3P030000003/UPh0k9H>00X0k9H>
00<000000>bF3P2][Jd00`3KRPd010000000fhX=0=^:3@3KRPd2000000@0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@080=>73P060:f][@3_V10000000000003_V100[Jf]0P0000040>nH40030000003_
V100[Jf]0140o:0@00<0[Jf]0?nT4@3oY1404P3oY1440:f][AP0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0A0?nV4@040000003oYQ40ojHA0?nV4@8000001@3oYQ40102][Jd0ojH@
0?nV403oYQ05000000@0ojH@1@00000<0?nV40@000003P3oYA0200000080ojD@0P0000030?nU40<0
00000P3oYA000`2][Jd0oj<@0?nS40060?nS408000002@3oXa03000000H0oj<@00@0[Jf]0?bP4000
000000002@3lX102000000H0o:0@0P0000030?bP40030:f][@3fW0l0[Jf]0080[Jf]00<000000?JL
3`3fW0l00`3fW0l2000000P0mY`?00<000000?JL3`2][Jd00`3/UPh00`000000k9H>0>bF3P0:0>bF
3P030000003/UPh0[Jf]00<0fhX=00@000000=^:3@3KRPd0fhX=0P0000020:f][@80fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V10000000080[Jf]00<0kiP@000000000000103_
V1000`000000kiP@0:f][@0A0?bP40030:f][@3oY140oj@A00h0oj@A102][Jd00`3oY140[Jf]0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ404@3oYQ4010000000ojHA0?nV
4@3oYQ42000000D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400>0?nU40800000
103oYA04000000@0ojD@00<0[Jf]0?nS403oXa001P3oXa02000000T0oj<@0`0000060?nS40050:f]
[@00000000000?bP40000000203lX102000000H0o:0@0P0000030?bP40030:f][@3fW0l0mY`?0080
mY`?0P0000030:f][@030?JL3`000000000000P0mY`?00<000000?JL3`2][Jd00`3/UPh00`000000
k9H>0>bF3P0:0>bF3P030000003/UPh0[Jf]00<0fhX=00<000000=^:3@3KRPd00P3KRPd00`000000
fhX=0=^:3@030:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40
oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h2000000030:f]
[@000000kiP@0080kiP@0P0000040>nH40030000003_V100[Jf]0140o:0@00<0[Jf]0?nT4@3oY140
2P3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA0140ojHA00<000000?nV4@3oYQ400P0000060?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA003P3oYA02000000`0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000030?nS
40000000000000T0oj<@0P0000000`3oXa0000000?nS40040?nS40050:f][@00000000000?bP4000
0000203lX102000000H0o:0@0P0000030?bP40030:f][@3fW0l0mY`?0080mY`?0P0000030?JL3`04
0:f][@00000000000:f][@L0mY`?00<000000?JL3`2][Jd00`3/UPh00`000000k9H>0>bF3P0<0>bF
3P050:f][@3KRPd0fhX=0=^:3@000000103KRPd00`000000fhX=0=^:3@020=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h010000000[Jf]0000000000030>nH40800000103_
V1000`000000kiP@0:f][@0A0?bP40030:f][@3oY140oj@A00L0oj@A0`2][Jd90?nT4@030:f][@3o
YQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0A0?nV4@030000003o
YQ40ojHA008000001P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0ojD@0P00
000<0?nU40030:f][@3oXa00oj<@00D0oj<@0`0000060?nS4080000000<0oj<@0000000000000P3o
Xa02000000<0oj<@00<0[Jf]0000000000000P3lX1000`000000o:0@0?bP40040?bP408000001`3l
X102000000<0o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l2000000D0mY`?00<000000?JL3`2][Jd00`2]
[Jd30?JL3`030000003fW0l0[Jf]00<0k9H>0P00000=0>bF3P030:f][@3KRPd0fhX=0080fhX=00<0
00000=^:3@3KRPd01P3KRPd20:f][@P0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3P
iP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01`3CQ`h00`000000[Jf]0:f]
[@02000000<0kiP@00<000000>nH403_V1000P3_V102000000030:f][@3lX100o:0@0100o:0@00<0
[Jf]0?nT4@3oY1400`3oY1440:f][@`0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA0140ojHA00<000000?nV4@3oYQ400P0000060?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003P3oYA02000000`0ojD@00<0[Jf]0?nS403oXa00403o
Xa03000000@0oj<@00<000000?nS403oXa000P0000040?bP40030000003lX100o:0@00<0o:0@0P00
00080?bP408000000P3lX1000`2][Jd0mY`?0?JL3`020?JL3`030000003fW0l0mY`?00@0mY`?0P00
00040?JL3`<0[Jf]00<000000?JL3`2][Jd00`3/UPh3000000`0k9H>00@0[Jf]0=^:3@3KRPd0fhX=
0P0000080=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0
/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h01P2][Jd0
00000=>73P2][Jd0kiP@000000<0kiP@00<000000>nH403_V1000P3_V102000000030:f][@3lX100
o:0@0100o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd@0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0A0?nV4@030000003oYQ40ojHA008000001P3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0ojD@0P00000<0?nU40030:f][@3oXa00
oj<@01P0oj<@0P0000000`2][Jd0o:0@0?bP40040?bP40040000003lX100o:0@0?bP40<00000203l
X10200000080o:0@00<0[Jf]0?JL3`3fW0l00P3fW0l00`000000mY`?0?JL3`040?JL3`8000001`3f
W0l010000000[Jf]0:f][@2][Jd20>bF3P80000000<0k9H>0000000000002P3/UPh0102][Jd0fhX=
0=^:3@3KRPd2000000P0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H7
0080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00<0dhL>0P0000001`2][Jd0dhL>0000003CQ`h0[Jf]0>nH400000000`3_V1000`000000kiP@0>nH
40020>nH40030000003_V100[Jf]0140o:0@0`2][JdD0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0B0?nV4@040000003oYQ400000000000H0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400>0?nU40800000303oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@1000000;0?bP4080000000<0o:0@0:f][@3fW0l0
0P3fW0l2000000H0mY`?0P0000070?JL3`040000003fW0l0[Jf]0>bF3P80[Jf]0P0000030>bF3P@0
00001P3/UPh00`2][Jd0fhX=0=^:3@02000000T0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0
^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h2000000030:f][@3CQ`h000000080dhL>00<0[Jf]0>nH4000
00001`3_V102000000050>nH402][Jd0o:0@0?bP400000002`3lX1030:f][@030?bP402][Jd0oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
0180ojHA0`0000070?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003P3oYA020000
00`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40030000003lX100[Jf]
00<0mY`?00<000000?JL3`3fW0l01@3fW0l2000000L0mY`?00<000000?JL3`2][Jd00`3/UPh20000
00030:f][@3/UPh0k9H>00<0k9H>0P0000050>bF3P050:f][@3KRPd000000=^:3@0000002@3KRPd0
0`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3o
ool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@0000020=>73P040000003CQ`h0dhL>00000080
dhL>00<0[Jf]0>nH400000001`3_V102000000050>nH402][Jd0o:0@0?bP400000002@3lX1020:f]
[@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ43000000L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400>0?nU40800000303oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01H0o:0@00<000000:f][@3fW0l00P3fW0l00`000000mY`?0?JL3`060?JL3`8000001P3fW0l20000
00030:f][@3/UPh0k9H>0080k9H>00<000000>bF3P2][Jd00P2][Jd20>bF3P8000001@3/UPh0102]
[Jd000000=^:3@00000:0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`03
08QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0202][Jd0Uf0;09MP2`2GH0/000000=>73P2][Jd00000
0`3CQ`h01P000000dhL>0=>73P2][Jd0kiP@000000H0kiP@0P0000020>nH40040:f][@3lX100o:0@
000000H0o:0@0`2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA0180ojHA0`00000^0:f][@T0ojD@0P00000<
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX104000000T0mY`?0P000006
0?JL3`80000000<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P020>bF3P80[Jf]0P000005
0>bF3P030000003KRPd0000000/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H70P2][Je2
0;3PiP40oooo001I0;3PiP080:f][@2GH0/0Uf0;09MP2`000000[Jf]0=>73P0000030=>73P060000
003CQ`h0dhL>0:f][@3_V10000001P3_V10200000080kiP@00@0[Jf]0?bP403lX10000000`3lX103
0:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4=0:f][@030000002][Jd0000000L0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40T0[Jf]0P0000050:f][@L0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00X0mY`?0P000004
0?JL3`<0000000<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P040>bF3P80000000L0[Jf]
0>bF3P3/UPh0k9H>0000002][Jd0000000`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H7
08QF1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
000000020=>73P050000003CQ`h0dhL>0=>73P0000000P3CQ`h00`2][Jd0kiP@000000050>nH4080
00000`3_V1001@2][Jd0o:0@0?bP40000000o:0@0080[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][@d0ojHA00<000000?nV
4@0000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0ojD@0P0000050?nU
40`0[Jf]603oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?0P0000030?JL
3`<0000000<0[Jf]0>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P040>bF3P80000000@0k9H>0:f]
[@2][Jd0[Jf]0P0000080=^:3@030000003KRPd0fhX=00<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/2
0:f][@@0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2][Jd0
00000080dhL>00L000000=>73P3CQ`h0dhL>0000003CQ`h0[Jf]0080kiP@00<000000>nH403_V100
0`3_V102000000<0kiP@00D0[Jf]0?bP402][Jd000000:f][@0>0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0
ojHA0?nV4@0C0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0
ojD@0P00000<0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0303fW0l010000000mY`?0?JL3`3fW0l3000000030:f][@3/UPh0k9H>
0080k9H>0P0000050>bF3P8000000`3/UPh200000080[Jf]1`3KRPd00`000000fhX=0=^:3@030=^:
3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0
/>3V00D0[Jf]0000002GH0/0[Jf]000000020=>73P070000003CQ`h0dhL>0=>73P000000dhL>0:f]
[@020>nH40030000003_V100kiP@0080kiP@0P0000040>nH4080[Jf]00<0o:0@0000003lX1003P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3o
YQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ404`3oYQ400`000000ojHA0?nV4@060?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003P3oYA02000000`0ojD@00<0[Jf]0?nS403oXa001P3o
Xa000`000000oj<@0?nS40030?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?00d0mY`?0`000000103fW0l000000000002][Jd50>bF3P030000003/UPh0k9H>00<0k9H>
00<000000>bF3P3/UPh00P3/UPh2000000040:f][@3KRPd0[Jf]0:f][@D0fhX=00<000000=^:3@3K
RPd00`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0[Jf]00<0R5H700<0[Jf]0;3PiP2`
h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd000000000002GH0/000000080dhL>00P000000=>73P3C
Q`h0dhL>0000003CQ`h0[Jf]0>nH408000000`3_V1000`000000kiP@000000020>nH40<0[Jf]0P3l
X1000`000000o:0@0?bP400=0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40503o
YQ480:f][AP0ojHA00<0[Jf]0?nV4@3oYQ404`3oYQ400`000000ojHA0?nV4@060?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003P3oYA02000000`0ojD@00<0[Jf]0?nS403oXa001@3o
Xa02000000l0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?0140mY`?0P0000000`2][Jd0k9H>0>bF
3P030>bF3P800000103/UPh00`000000k9H>0>bF3P020>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=
0P2][Jd30=^:3@030000003KRPd0fhX=00<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H7
08QF1`2][Jd208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00L0[Jf]000000000000
Uf0;0000003CQ`h0000000@0dhL>00D000000=>73P2][Jd0kiP@000000040>nH4080000000H0kiP@
0:f][@2][Jd0kiP@0000002][Jd20?bP40030000003lX100o:0@00`0o:0@00<0[Jf]0?nT4@3oY140
503oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01<0ojHA00<000000?nV4@3oYQ401P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@00X0ojD@1P00000<0?nU40030:f][@3oXa00oj<@00D0oj<@00<000000?nS40000000
4P3oXa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0[Jf]0?JL3`3fW0l04@3fW0l200000003
0?JL3`2][Jd0k9H>00@0k9H>00<000000>bF3P3/UPh00P3/UPh00`000000k9H>0>bF3P030>bF3P03
0000002][Jd0fhX=00<0fhX=00D000000:f][@2][Jd0fhX=000000050=^:3@030:f][@2iM@/0^GD;
00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005T0/>3V00D00000
0:f][@000000Uf0;0:f][@02000000@0dhL>00D000000=>73P2][Jd0kiP@000000040>nH40030000
002][Jd0[Jf]00<0kiP@00D000000:f][@3lX100o:0@0000000>0?bP40030:f][@3oY140oj@A01@0
oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS40050?nS408000004`3oXa000`2][Jd0o:0@0?bP40080?bP40H0[Jf]203lX1000`11JN40
o:0@0:f][@0C0?JL3`80000000<0mY`?0:f][@3/UPh0103/UPh00`000000k9H>0>bF3P020>bF3P03
0000003/UPh0k9H>00<0k9H>00<000000:f][@3KRPd00`3KRPd01@000000fhX=0=^:3@2][Jd00000
00D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0R5H708QF1`28EPL0[Jf]08QF1`2][Jd0@P2`
h>H10?ooo`00F02`h>H2000000040:f][@000000Uf0;0:f][@800000103CQ`h01@000000dhL>0:f]
[@3_V100000000<0kiP@00<0[Jf]0000003_V1000`3_V102000000040:f][@3lX100o:0@000000h0
o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS40060?nS40030000003oXa00oj<@0140oj<@00<0[Jf]0?bP
403lX1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l04@3fW0l2000000030?JL3`2][Jd0k9H>
00D0k9H>0P0000000`3/UPh000000>bF3P050>bF3P030000002][Jd0fhX=00<0fhX=00D000000=^:
3@3KRPd0fhX=000000020:f][@80fhX=00<0@FWQ0:f][@2iM@/01`2iM@/00`2][Jd0R5H708QF1`02
08QF1`80[Jf]@P2`h>H10?ooo`00F02`h>H20000000409MP2`000000Uf0;0:f][@800000103CQ`h0
1P000000dhL>0:f][@3_V10000000>nH4080[Jf]00<0kiP@0000003_V1000`3_V102000000040:f]
[@3lX100o:0@000000h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01D0o:0@1P2][JdB0?JL3`03
0000003fW0l0[Jf]00P0k9H>0P0000060>bF3P030000002][Jd0fhX=00<0fhX=00D000000=^:3@3K
RPd0fhX=000000020=^:3@80[Jf]00<0fhX=0:f][@2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF
1`030:f][@2`h>H0/>3V0400/>3V0@3oool005P0/>3V0P000000102GH0/0000009MP2`2][Jd20000
00@0dhL>00H000000=>73P2][Jd0kiP@0000002][Jd20>nH40800000103_V10010000000kiP@0:f]
[@3lX102000000h0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0102][Jd>0?JL3`030000003fW0l0[Jf]0140k9H>00<000000=^:3@3KRPd0
0P3KRPd01@000000fhX=0=^:3@3KRPd0000000@0fhX=0P2][Jd90;Ue2`030:f][@28EPL0R5H70080
R5H70P2][Je10;3PiP40oooo001G0;3PiP<0000000@0Uf0;0000002GH0/0[Jf]0P0000030=>73P80
000000@0dhL>0:f][@2][Jd000000`3_V1000`000000kiP@0>nH40020>nH4080000000<0kiP@0:f]
[@3lX1000P00000>0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l50:f][@T0mY`?00<000000?JL3`2][Jd04@3/UPh01000
0000fhX=0=^:3@3KRPd2000000<0fhX=00<000000=^:3@3KRPd00`3KRPd20:f][@P0^GD;00<0[Jf]
08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V0`0000001@2GH0/0000009MP2`2][Jd0
000000@0dhL>0P0000020:f][@030>nH40000000kiP@0080kiP@00<000000>nH403_V1000P3_V102
000000030>nH402][Jd0o:0@008000003P3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd40?JL3`030000003fW0l0
[Jf]0140k9H>00H0[Jf]0000003KRPd000000=^:3@0000030=^:3@030000003KRPd0fhX=00<0fhX=
00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00
E`2`h>H30000000509MP2`000000Uf0;0:f][@000000103CQ`h2000000040=>73P2][Jd0kiP@0000
00<0kiP@00<000000>nH403_V1000P3_V102000000030>nH402][Jd0o:0@008000003P3lX1000`2]
[Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00h0mY`?102][Jd00`000000mY`?0:f][@0B0>bF3P050:f][@00000000000=^:3@0000000`3KRPd0
0`000000fhX=0=^:3@030=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF
1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000509MP2`000000Uf0;0:f][@000000103C
Q`h2000000040=>73P2][Jd0kiP@000000@0kiP@00T000000>nH403_V10000000>nH40000000kiP@
0:f][@3lX1000P00000>0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H
0?bP40030:f][@3fW0l0mY`?0180mY`?00@000000:f][@2][Jd0[Jf]4@3/UPh01@2][Jd0fhX=0=^:
3@3KRPd0000000<0fhX=0P0000040=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/0
0P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000409MP2`00
0000Uf0;0:f][@80000000<0dhL>0:f][@2][Jd00P000000103CQ`h0[Jf]0>nH400000040>nH4004
0000003_V100kiP@000000<0kiP@00@0[Jf]0?bP4000000000003@3lX1030:f][AD0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`040000003fW0l0[Jf]0>bF3P<0[Jf]3P3/
UPh00`2][Jd0fhX=0=^:3@050=^:3@800000103KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2i
M@/0^GD;0;Ue2`2][Jd01028EPL20:f][D40/>3V0@3oool005L0/>3V0`000000102GH0/0000009MP
2`2][Jd2000000030:f][@3CQ`h0dhL>0080000000@0dhL>0:f][@3_V10000001@3_V102000000@0
kiP@00@0[Jf]0?bP4000000000002`3lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV
4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`030000003fW0l0[Jf]00@0k9H>0P2][Jd<0>bF
3P030:f][@3KRPd0fhX=00D0fhX=0P0000040=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2i
M@/0[Jf]08QF1`0308QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H30000000409MP2`000000Uf0;0:f]
[@8000000`3CQ`h2000000040=>73P2][Jd0kiP@000000/0kiP@00@0[Jf]0?bP400000000000203l
X1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?0180mY`?00<000000?JL3`2][Jd01P3/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd01@3K
RPd2000000@0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H70P2][Je10;3PiP40oooo001G
0;3PiP<0000000H0Uf0;0000002GH0/000000:f][@0000030=>73P80000000@0dhL>0:f][@3_V100
00002`3_V100102][Jd0o:0@0000000000060?bP4080[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0D0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l2000000040?JL3`000000mY`?
0:f][@T0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00D0fhX=0P0000040=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V0`0000001P2G
H0/0000009MP2`000000dhL>000000<0dhL>0P000000103CQ`h0[Jf]00000000000;0>nH40040:f]
[@3lX1000000000000<0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0ojHA;P2][JdG0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0A0?JL3`80
000000<0mY`?0:f][@3/UPh02`3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd2000000@0
fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H70P2][Je10;3PiP40oooo001G0;3PiP800000
0P2GH0/01@000000[Jf]0000003CQ`h0000000<0dhL>0P0000000`2][Jd0kiP@0>nH400<0>nH4004
0:f][@3lX1000000000000<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f]
[@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00H0fhX=0P0000050=^:
3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H300000005
09MP2`000000Uf0;0:f][@0000000P3CQ`h00`000000dhL>0=>73P02000000030:f][@3_V100kiP@
00`0kiP@00@0[Jf]0?bP4000000000003P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]1P3KRPd2
000000D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`h>H1
0?ooo`00EP2`h>H30000000509MP2`000000[Jf]09MP2`0000000P3CQ`h01P000000dhL>00000000
0000dhL>0:f][@d0kiP@0`2][Jd2000000h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=
0:f][@2][Jd40=^:3@8000001@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0[Jf]0080
R5H70P2][Je10;3PiP40oooo001F0;3PiP<0000000D0Uf0;0000002GH0/0Uf0;000000020=>73P80
00000`3CQ`h00`2][Jd0kiP@0>nH40090>nH4080[Jf]00<0kiP@0:f][@3lX1000P00000>0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P04
0:f][@3KRPd0fhX=0=^:3@80[Jf]0P3KRPd2000000D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01@2]
[Jd0R5H708QF1`2][Jd0R5H70080[Jf]@@2`h>H10?ooo`00EP2`h>H30000000509MP2`000000Uf0;
0000002][Jd00P3CQ`h00`000000dhL>0=>73P020=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd3
0>nH40040:f][@3lX100o:0@000000h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd2000000D0fhX=00<0[Jf]0;Ue2`2iM@/01P2i
M@/0102][Jd0R5H708QF1`28EPL30:f][D40/>3V0@3oool005H0/>3V0`0000001`2][Jd0000009MP
2`000000[Jf]0=>73P0000001@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V100102][Jd0
o:0@0?bP4000000>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f]
[J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@050=^:3@8000001@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H7
08QF1`<0[Jf]@@2`h>H10?ooo`00EP2`h>H3000000030:f][@000000Uf0;008000001`3CQ`h00`2]
[Jd0kiP@0>nH40030>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?
01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@8000000P2][Jd20=^:
3@03045Yh@2][Jd0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005H0
/>3V0`0000001@2GH0/0000009MP2`000000[Jf]00L0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd9
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3o
YQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@050=^:3@8000000P3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP<0000000@0Uf0;0000002GH0/00000
203CQ`h0102][Jd0kiP@0:f][@2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd01@3KRPd2000000@0fhX=0P2][Jd90;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?oo
o`00EP2`h>H30000000409MP2`000000Uf0;0:f][@P0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd00`000000fhX=0=^:3@030=^:3@<0[Jf]1`2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V1000000209MP2`030:f][@3CQ`h0dhL>
00D0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f]
[M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd00`00
0000fhX=0=^:3@030=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2]
[Je10;3PiP40oooo001F0;3PiP80000000D0[Jf]0000002GH0/0Uf0;0:f][@050=>73P80[Jf]00<0
dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2]
[JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0
[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00
EP2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]
00d0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue
2`80[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V0P0000001@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL20:f][D40/>3V0@3o
ool005H0/>3V0P0000001P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1@3CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;0`2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00EP2`
h>H2000000040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080
R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H2000000@0Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]
m02`h>H40:f][@L0`kfk102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][@<0R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H2000000<0Uf0;0P2]
[Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2]
[Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F
0;3PiP8000000`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP4002
0?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0
`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0
^GD;00L0^GD;00H0[Jf]08QF1`2][Jd0R5H7045Yh@2][Je10;3PiP40oooo001F0;3PiP070000002]
[Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402]
[Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0
[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40
oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0
kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0
_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0
_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2][Je1
0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;0:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0
0`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2]
[Je10;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0
0`2][Jd0kiP@0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/00/0_[N/102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00L0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2]
[Je10;3PiP40oooo001F0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0
0`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36
`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n
^KP20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@02`
h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]
0>nH403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2]
[Jd70<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0030;ji^080[Jf]1P2n^KP0102][Jd0];2a0:f][@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;
00<0[Jf]08QF1`28EPL00P28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2G
H0/00`2][Jd0dhL>0=>73P070=>73P040:f][@3_V100[Jf]0:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0
102aZid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0040:f][@11JN40];2a0;B`
/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool0
05H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]202TWXl00`2]
[Jd0/J^M0;6[W@060;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^080@FWQ0`2d/;40
0`11JN40[Jf]0:f][@0:0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H0
0`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0:BNS`2TWXl0202TWXl0
0`2][Jd0/J^M0;6[W@080;6[W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@`0_[Vh0P11JN43
0;B`/@03045Yh@2d/;40];2a0080[Jf]202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3o
ool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P040=>73P80[Jf]2`2TWXl0
0`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2]
[Jd0_[Vh00D0_[Vh0P11JN450;ji^080@FWQ0`2d/;400`11JN40];2a0;B`/@02045Yh@030:f][@2i
M@/0^GD;00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002]
[Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h30:f][@X0Y9j?00<0[Jf]0;6[W@2aZid01@2a
Zid2045Yh@D0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2]
[Jd40<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`11JN460;ji^080@FWQ0`2d/;400`11JN40];2a0;B`
/@02045Yh@030;B`/@2][Jd0[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo
001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0RXEe08Z5M@2][Jd:0:BNS`03
0:f][@2aZid0/J^M00L0/J^M0P11JN430;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0
[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P11JN460;ji^080
@FWQ0`2d/;400`11JN40];2a0;B`/@02045Yh@80[Jf]00<0@FWQ0:f][@2][Jd00`2iM@/0102][Jd0
R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>7
3P040:f][@11JN40RXEe08Z5M@<0[Jf]202TWXl00`2][Jd0/J^M0;6[W@070;6[W@06045Yh@2aZid0
@FWQ045Yh@2aZid0[Jf]202i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V
302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0@FWQ045Yh@030;ji^080@FWQ
1P2n^KP2045Yh@<0];2a00<0@FWQ0;B`/@2d/;400P11JN420;B`/@04045Yh@2OVj00Wi^P0:f][@80
^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP
2`2][Jd0dhL>0P2][Jd2045Yh@80RXEe00@0[Jf]0:BNS`2TWXl0[Jf]1`2TWXl00`2][Jd0/J^M0;6[
W@070;6[W@03045Yh@2aZid0/J^M0080@FWQ00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2]
[Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][@/0`kfk1P11JN430;ji^080@FWQ1P2n
^KP2045Yh@<0];2a00<0@FWQ0;B`/@2][Jd00P11JN420;B`/@04045Yh@2OVj00Wi^P045Yh@<0[Jf]
1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2]
[Jd208Z5M@80@FWQ0P2:QGD0102][Jd0Y9j?0:BNS`2TWXl20:f][@D0Y9j?00<0[Jf]0;6[W@2aZid0
1`2aZid01011JN40/J^M0;6[W@2aZid2045Yh@<0^K:V00<0@FWQ0;VbYP2i/ZH02@2i/ZH30:f][A40
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@03
0<K0_02][Jd0`kfk00X0`kfk00@0@FWQ0<>m^`33_K/0`kfk0`11JN430;ji^080@FWQ1`2n^KP00`11
JN40];2a0;B`/@02045Yh@050:f][@2d/;40@FWQ045Yh@2d/;400P11JN4209nKX080@FWQ00<0Wi^P
0:f][@28EPL00`28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;
0080Uf0;00@0[Jf]08Z5M@2:QGD0RXEe0P11JN4208Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd3
0:BNS`030:f][@2aZid0/J^M00L0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN440;VbYP80@FWQ2P2i
/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0
[Jf]0<>m^`33_K/02@33_K/01@11JN40`kfk0<>m^`33_K/0[Jf]0080@FWQ0`2n^KP2045Yh@L0_[Vh
00D0[Jf]045Yh@11JN40[Jf]045Yh@020;B`/@80@FWQ00<0];2a045Yh@2][Jd00P2OVj02045Yh@80
Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP
2`80[Jf]0`2:QGD2045Yh@80RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl0102][Jd0Y9j?0:BNS`2][Jd9
0;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN440;VbYP<0@FWQ202i/ZH00`2][Jd0_[N/0;jg[003
0;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`09
0<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN430;ji^080@FWQ1`2n^KP30:f][@040;B`/@11JN40
];2a0;B`/@80@FWQ00<0];2a045Yh@2][Jd00P2OVj02045Yh@80Wi^P00D0[Jf]08QF1`28EPL0R5H7
0:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]0`2:QGD2045Yh@80RXEe
00<0[Jf]0:BNS`2TWXl01P2TWXl30:f][@T0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@@0^K:V
00<0@FWQ0;VbYP2i/ZH0202i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`
0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l
0:f][@030:f][@d0a/2l00@0[Jf]0<>m^`33_K/0@FWQ1`33_K/00`11JN40`kfk0<>m^`030<>m^`03
0:f][@11JN40_[Vh0080_[Vh0P11JN460;ji^080[Jf]0`2d/;400`11JN40];2a0;B`/@03045Yh@04
0;B`/@2][Jd0Wi^P09nKX080@FWQ0`2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3P
iP030:f][@2GH0/0Uf0;00<0[Jf]0`2:QGD2045Yh@80RXEe00<0[Jf]0:BNS`2TWXl0202TWXl20:f]
[@P0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`2][Jd0@FWQ0;VbYP030;VbYP03045Yh@2i/ZH0^K:V
00P0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]3`36`;`00`11JN40a/2l0:f][@020<>m
^`03045Yh@33_K/0`kfk00D0`kfk00<0@FWQ0<>m^`33_K/00`33_K/00`2][Jd0@FWQ0;ji^0020;ji
^080@FWQ102n^KP20:f][@030;ji^02][Jd0];2a0080];2a00<0@FWQ0;B`/@2d/;400P11JN420;B`
/@030:f][@2OVj00Wi^P0080@FWQ0`2OVj020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0
/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd308Z5M@80@FWQ00<0RXEe0:f][@2TWXl02P2TWXl0102]
[Jd0/J^M0:f][@2][Jd60;6[W@03045Yh@2aZid0/J^M0080/J^M00<0[Jf]045Yh@2i/ZH00`2i/ZH0
0`11JN40^K:V0;VbYP080;VbYP@0@FWQ3P2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00>0<K0_003045Yh@36`;`0
[Jf]0080`kfk00<0@FWQ0<>m^`33_K/01033_K/2045Yh@D0`kfk00<0[Jf]045Yh@2n^KP00`2n^KP0
0`11JN40_[Vh0;ji^0020:f][@<0_[Vh00H0@FWQ0;B`/@2d/;40];2a045Yh@2d/;42045Yh@<0];2a
00<0[Jf]09nKX02OVj000P11JN4309nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V
0P2][Jd306=PD`040:f][@2:QGD0RXEe08Z5M@80@FWQ00<0RXEe0:f][@2TWXl02P2TWXl0102][Jd0
/J^M0;6[W@2aZid30:f][@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`2][Jd0@FWQ0;VbYP030;Vb
YP03045Yh@2i/ZH0^K:V00P0^K:V00D0@FWQ0;jg[02n]j`0_[N/045Yh@0>0;jg[0030:f][@31^[00
`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd7
0<O1_0030:f][@36`;`0a/2l00P0a/2l0P11JN440<K0_003045Yh@36`;`0[Jf]0080`kfk0P11JN45
0<>m^`80@FWQ1@33_K/0102][Jd0@FWQ0;ji^011JN420;ji^003045Yh@2][Jd0[Jf]00D0_[Vh00@0
@FWQ0;B`/@2d/;40@FWQ1`2d/;400`2][Jd0Wi^P09nKX002045Yh@80Wi^P0P2][Jd00`1`KWT0[Jf]
0:f][@100;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<20:f][@80RXEe0P11JN400`2:QGD0[Jf]0:BN
S`0:0:BNS`030:f][@2aZid0/J^M00@0/J^M0P2][Jd00`2aZid0@FWQ0;6[W@030;6[W@030:f][@11
JN40^K:V00<0^K:V00<0@FWQ0;VbYP2i/ZH01`2i/ZH00`11JN40[Jf]0;jg[0030;jg[003045Yh@2n
]j`0@FWQ0080@FWQ2@2n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00D0[Jf]3037`K`00`2][Jd0a/2l0<K0_0030<K0_005045Yh@36
`;`0a/2l0<K0_011JN401P36`;`2045Yh@030:f][@33_K/0`kfk0080@FWQ1@33_K/2045Yh@D0`kfk
00@0[Jf]045Yh@11JN40_[Vh0P2][Jd2045Yh@80_[Vh00D0@FWQ0;ji^02n^KP0_[Vh045Yh@020;B`
/@03045Yh@2d/;40];2a00D0];2a00<0[Jf]09nKX02OVj000P11JN40102OVj00[Jf]09nKX02][Jd2
071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0[Jf]
0080RXEe00<0@FWQ08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@060;6[W@030:f][@11JN40[Jf]
00<0/J^M00<0[Jf]045Yh@11JN400`2i/ZH00`11JN40^K:V0;VbYP070;VbYP03045Yh@2n]j`0_[N/
00<0_[N/00<0@FWQ0;jg[011JN401`2n]j`01@11JN40_[N/0;jg[02n]j`0[Jf]00`0`KZ`1@2][Jd2
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdA0<O1_0040:f][@36`;`0a/2l0<K0_080@FWQ00D0
a/2l045Yh@11JN40a/2l045Yh@060<K0_080@FWQ00<0[Jf]0<>m^`11JN400P11JN450<>m^`03045Y
h@33_K/0`kfk00<0`kfk0P11JN400`2n^KP0[Jf]0:f][@020;ji^080@FWQ0P2n^KP01@11JN40_[Vh
0;ji^02n^KP0[Jf]0080@FWQ202d/;401P2][Jd0Wi^P09nKX011JN40Wi^P0:f][@80Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00P0[Jf]08Z5
M@2:QGD0[Jf]08Z5M@11JN40RXEe0:f][@/0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid01P11JN40/J^M
0:f][@2][Jd0/J^M0:f][@80@FWQ0P2i/ZH2045Yh@T0^K:V00<0@FWQ0;jg[02n]j`0102n]j`00`11
JN40_[N/0;jg[0060;jg[006045Yh@2n]j`0_[N/0;jg[02][Jd0@FWQ4031^[080:f][A00`kfc00<0
[Jf]0<Fn]@35_[D02035_[D7045Yh@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00A0<O1_0040:f][@36`;`0@FWQ045Yh@@0a/2l
0`11JN450<K0_0<0@FWQ00<0[Jf]0<>m^`11JN400P11JN450<>m^`03045Yh@33_K/0`kfk00<0`kfk
0`2][Jd40;ji^080@FWQ0P2n^KP2045Yh@80_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P
09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1S
H5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0[Jf]0;6[W@2aZid01P2aZid00`11JN40/J^M0;6[W@020;6[W@80[Jf]0P11JN420;VbYP80@FWQ
2@2i/ZH00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00D0_[N/0P11JN430;jg[0030:f]
[@11JN40`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D0
2P35_[D2045Yh@P0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0
b<6k00<0[Jf]0<O1_037`K`02037`K`3045Yh@H0al6l00@0[Jf]0<K0_011JN40@FWQ1@36`;`2045Y
h@D0a/2l0`11JN400`2][Jd0`kfk045Yh@02045Yh@D0`kfk00<0@FWQ0<>m^`33_K/00`2][Jd00`33
_K/0[Jf]0;ji^0040;ji^005045Yh@2n^KP0@FWQ0;ji^011JN400`2n^KP00`2][Jd0];2a0;B`/@08
0;B`/@030:f][@2OVj00[Jf]00D0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3P
iP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0RXEe0:f][@0;0:BN
S`030:f][@2aZid0/J^M00H0/J^M00<0@FWQ0;6[W@2aZid00`2aZid00`2][Jd0@FWQ045Yh@020:f]
[@80@FWQ2@2i/ZH00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00D0_[N/0P11JN430;jg
[0030:f][@11JN40`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][@L0aKje0P11JN480<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00D0al6l1011JN480<O1
_0030:f][@36`;`0@FWQ00H0a/2l0P11JN450<K0_0<0@FWQ00H0[Jf]0<>m^`11JN40@FWQ0<>m^`11
JN440<>m^`03045Yh@2][Jd0[Jf]00@0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP01011JN40_[Vh0;ji
^011JN440;ji^0030:f][@2d/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]
?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2]
[Jd;0:BNS`030:f][@2aZid0/J^M00H0/J^M00<0@FWQ0;6[W@2aZid00`2aZid00`2][Jd0@FWQ0;Vb
YP020;VbYP80@FWQ00<0[Jf]0;VbYP2i/ZH01P2i/ZH2045Yh@D0_[N/00<0@FWQ0;jg[02n]j`01@2n
]j`2045Yh@<0_[N/0P11JN4<0<6j/080@FWQ1031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00<0aKje1`2][Jd2045Yh@<0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ2@37`K`2045Yh@P0al6l00<0[Jf]0<K0_011JN401P36
`;`2045Yh@D0a/2l0`11JN401P2][Jd0`kfk045Yh@11JN40`kfk045Yh@80`kfk0P2][Jd00`11JN40
`kfk0<>m^`040<>m^`030:f][@2n^KP0_[Vh00<0_[Vh00<0@FWQ0;ji^02n^KP01@2n^KP00`2][Jd0
];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3P
iP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00H0/J^M00<0@FWQ0;6[W@2aZid00`2aZid00`2][Jd0
@FWQ0;VbYP020;VbYP<0@FWQ102][Jd40;VbYP030:f][@11JN40_[N/00@0_[N/00<0@FWQ0;jg[02n
]j`01@2n]j`01@11JN40_[N/045Yh@2n]j`0[Jf]0080@FWQ2P31^[02045Yh@80`KZ`00<0@FWQ0<6j
/031^[000P11JN430<>m/`<0@FWQ3`33_K<00`2][Jd0aKje0<Fn]@0:0<Fn]@80@FWQ0`35_[DA0:f]
[@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2]
[Jd0b<6k0<S1^`0=0<S1^`D0@FWQ00@0b<6k0:f][@11JN40@FWQ1`37`K`2045Yh@P0al6l00<0[Jf]
0<K0_011JN401P36`;`2045Yh@D0a/2l0P11JN401036`;`0@FWQ0<>m^`11JN420<>m^`03045Yh@2]
[Jd0[Jf]0080`kfk00<0@FWQ0<>m^`33_K/01033_K/0102][Jd0_[Vh0;ji^02n^KP2045Yh@P0_[Vh
00<0[Jf]0;B`/@2d/;401P2d/;430:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40
oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2a
Zid01P2aZid00`11JN40/J^M0;6[W@030;6[W@030:f][@11JN40^K:V0080^K:V0`11JN440;VbYP<0
[Jf]00@0^K:V0000002n]j`0@FWQ102n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ00@0_[N/045Y
h@2n]j`0[Jf]0`11JN480<6j/003045Yh@31^[00`KZ`00<0`KZ`00@0@FWQ0<6j/011JN40@FWQ1@33
_K<5045Yh@/0`kfc00<0[Jf]0<Fn]@35_[D02P35_[D2045Yh@P0aKje00<0[Jf]0<Jo]`36_kL02@36
_kL`0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0;0<S1^`@0@FWQ1038
`K/00`2][Jd0al6l045Yh@070<O1_080@FWQ2037`K`0102][Jd0a/2l045Yh@11JN450<K0_080@FWQ
1@36`;`2045Yh@040<K0_011JN40`kfk045Yh@80[Jf]00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@D0
`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f]
[@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid01P2aZid0
0`11JN40/J^M0;6[W@030;6[W@030:f][@11JN40^K:V0080^K:V0`11JN470;VbYP<0[Jf]00<0_[N/
045Yh@11JN400P2n]j`00`11JN40_[N/0;jg[0040;jg[006045Yh@2n]j`0_[N/045Yh@2n]j`0[Jf]
0`11JN470<6j/080@FWQ1P31^[03045Yh@D0`kfc0P11JN4>0<>m/`030:f][@35_[D0aKje00X0aKje
0P11JN480<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03@38`K/2045Yh@@0b<6k
00@0[Jf]0<O1_037`K`0@FWQ1P37`K`2045Yh@P0al6l00@0[Jf]0<K0_011JN40@FWQ1@36`;`2045Y
h@D0a/2l00H0@FWQ0:f][@2][Jd0@FWQ0:f][@11JN420<>m^`03045Yh@33_K/0`kfk0080`kfk0P11
JN450<>m^`030:f][@11JN40_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][@<0];2a00<0
[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0
[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?
00<0[Jf]0;6[W@2aZid01P2aZid00`11JN40/J^M0;6[W@030;6[W@030:f][@11JN40^K:V0080^K:V
0P11JN401@2i/ZH0@FWQ0;VbYP2i/ZH0@FWQ00@0^K:V00<0[Jf]0;jg[02][Jd00P2][Jd3045Yh@H0
_[N/00T0@FWQ0;jg[02n]j`0@FWQ0;jg[02][Jd0@FWQ0<6j/011JN401P31^[02045Yh@P0`KZ`0P11
JN450<>m/`80@FWQ3P33_K<4045Yh@D0aKje00@0@FWQ0<Fn]@35_[D0aKje0P11JN480<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03@38`K/2045Yh@@0b<6k00@0[Jf]0<O1_037`K`0
@FWQ1P37`K`2045Yh@P0al6l00@0[Jf]0<K0_036`;`0@FWQ1@36`;`2045Yh@030<K0_02][Jd0[Jf]
0080[Jf]00<0@FWQ0<K0_036`;`00`11JN430<>m^`04045Yh@33_K/0`kfk0<>m^`80@FWQ1@33_K/0
0`2][Jd0@FWQ0;ji^00;0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nK
X00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]
1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0/J^M0;6[W@060;6[W@03045Y
h@2aZid0/J^M00<0/J^M0P11JN420;VbYP<0@FWQ00<0^K:V045Yh@2i/ZH00P11JN440;VbYP80@FWQ
102n]j`2045Yh@80[Jf]102n]j`01@11JN40_[N/0;jg[011JN40_[N/0080@FWQ00<0`KZ`045Yh@31
^[001@31^[02045Yh@P0`KZ`0P11JN450<>m/`80@FWQ3033_K<3045Yh@<0aKje0P11JN401035_[D0
@FWQ045Yh@11JN430<Fn]@80@FWQ0P35_[D3045Yh@<0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0=0<S1^`80@FWQ1038`K/00`2][Jd0al6l0<O1_002045Yh@D0al6l0P11JN480<O1
_0040:f][@36`;`0a/2l0<K0_0L0@FWQ00@0[Jf]0<K0_036`;`0a/2l0P11JN420<K0_0<0@FWQ0`33
_K/01011JN40`kfk0<>m^`33_K/2045Yh@D0`kfk00<0[Jf]045Yh@2n^KP02`2n^KP0102][Jd0];2a
0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?oo
o`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`03
0:f][@2aZid0/J^M00H0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`2][Jd0@FWQ045Yh@030;VbYP80
@FWQ00D0^K:V045Yh@2i/ZH0^K:V045Yh@040;VbYP80@FWQ1@2n]j`00`11JN40_[N/0;jg[0030:f]
[@80@FWQ0P2n]j`01P11JN40_[N/045Yh@11JN40`KZ`045Yh@H0`KZ`0P11JN480<6j/080@FWQ1@33
_K<2045Yh@/0`kfc0P11JN400`33_K<0[Jf]0<Fn]@030<Fn]@04045Yh@35_[D0@FWQ045Yh@@0aKje
0P11JN400`35_[D0@FWQ0<Fn]@020<Fn]@04045Yh@35_[D0aKje0:f][@D0a[ng1P11JN430<Jo]`H0
@FWQ0`36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0@FWQ00<0al6j1011JN480<O1^P03
045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0=0<S1^`80
@FWQ1038`K/00`2][Jd0al6l0<O1_002045Yh@D0al6l0P11JN480<O1_0030:f][@36`;`0a/2l00D0
[Jf]00<0a/2l045Yh@11JN401036`;`2045Yh@80a/2l00<0[Jf]045Yh@11JN400`33_K/3045Yh@80
`kfk00<0@FWQ0<>m^`33_K/00`33_K/00`2][Jd0@FWQ0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0
Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd0
1`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]202aZid00`11JN40/J^M0;6[W@020;6[W@030:f]
[@11JN40^K:V00L0^K:V0`11JN440;VbYP80@FWQ1@2n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ
0P2][Jd01P11JN40_[N/045Yh@11JN40`KZ`045Yh@H0`KZ`00<0@FWQ0<6j/031^[001`31^[02045Y
h@D0`kfc0P11JN4;0<>m/`80@FWQ00<0`kfc0:f][@35_[D01035_[D2045Yh@D0aKje0`11JN450<Fn
]@03045Yh@35_[D0[Jf]00L0a[ng0P11JN470<Jo]`80@FWQ1@36_kL7045Yh@H0al6h1011JN460<O1
^0040:f][@37`KX0@FWQ0<O1^P80@FWQ1037`KX00`11JN40al6j0<O1^P040<O1^P03045Yh@37`KX0
@FWQ00@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0=0<S1^`80@FWQ1038`K/0
0`2][Jd0al6l0<O1_002045Yh@D0al6l0P11JN460<O1_0D0[Jf]1P36`;`00`11JN40a/2l0<K0_003
0<K0_080@FWQ0P36`;`0102][Jd0@FWQ045Yh@33_K/3045Yh@@0`kfk00<0@FWQ0<>m^`33_K/00`33
_K/00`2][Jd0@FWQ0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`
KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd7
0;6[W@03045Yh@2aZid0/J^M0080/J^M00<0[Jf]045Yh@2i/ZH03P2i/ZH00`2][Jd0@FWQ0;jg[004
0;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11JN420;jg[006045Yh@2][Jd0@FWQ045Yh@2][Jd0@FWQ
1P31^[000`11JN40`KZ`0<6j/0070<6j/080@FWQ1@33_K<2045Yh@/0`kfc0P11JN400`33_K<0[Jf]
0<Fn]@040<Fn]@80@FWQ1@35_[D2045Yh@H0aKje0P11JN400`2][Jd0a[ng0<Jo]`050<Jo]`80@FWQ
1`36_kL2045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ1`37`KP3045Yh@<0al6h0P11JN440<O1^004
0:f][@37`KX0@FWQ045Yh@L0al6j00<0@FWQ0<O1^P37`KX01037`KX00`11JN40al6j0<O1^P030<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03@38`K/2045Yh@@0b<6k00@0[Jf]0<O1
_037`K`0al6l0P11JN440<O1_080@FWQ00<0al6l0:f][@2][Jd00`2][Jd20<O1_0030:f][@36`;`0
a/2l00H0a/2l00<0@FWQ0<K0_036`;`00`36`;`2045Yh@80a/2l00<0[Jf]045Yh@11JN402033_K/0
0`11JN40`kfk0<>m^`030<>m^`030:f][@11JN40@FWQ00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@09
0;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2]
[Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]0P2aZid3045Yh@@0/J^M0P11JN4?0;Vb
YP040:f][@2n]j`0@FWQ045Yh@80_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[002
0;jg[0<0@FWQ00<0`KZ`045Yh@2][Jd01@2][Jd00`11JN40`KZ`0<6j/0050<6j/0@0@FWQ1@33_K<2
045Yh@/0`kfc0P11JN400`33_K<0[Jf]0<Fn]@040<Fn]@80@FWQ1@35_[D2045Yh@L0aKje0P11JN47
0<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ1P37`KP2045Yh@L0al6h00H0
@FWQ0<O1^037`KP0al6h0:f][@37`KX2045Yh@L0al6j00<0@FWQ0<O1^P37`KX02P37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00d0b<6k0P11JN440<S1^`040:f][@37`K`0al6l0<O1
_080@FWQ0P37`K`20:f][@80@FWQ00<0[Jf]0<O1_037`K`01@37`K`0102][Jd0a/2l0<K0_011JN45
0<K0_003045Yh@36`;`0a/2l00<0a/2l1011JN400`2][Jd0`kfk0<>m^`080<>m^`80@FWQ1033_K/3
045Yh@H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj02
0:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M0080/J^M0P2][Jd20;6[W@80@FWQ0P2aZid2045YhA00^K:V00@0[Jf]0;jg
[02n]j`0_[N/0P11JN460;jg[080@FWQ102n]j`2045Yh@<0`KZ`00<0@FWQ0<6j/031^[000`31^[00
0`11JN40[Jf]0:f][@050:f][@80`KZ`1011JN430<>m/`80@FWQ2`33_K<2045Yh@030<>m/`2][Jd0
aKje00@0aKje0P11JN450<Fn]@80@FWQ1`35_[D2045Yh@L0a[ng0P11JN470<Jo]`80@FWQ1@36_kL0
102][Jd0al6h045Yh@11JN460<O1^003045Yh@37`KP0al6h00L0al6h00H0@FWQ0<O1^037`KP0al6h
0:f][@11JN480<O1^P03045Yh@37`KX0al6j00X0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0=0<S1^`80@FWQ1038`K/0102][Jd0al6l0<O1_02][Jd2045Yh@80[Jf]0P37`K`3045Y
h@<0al6l00D0@FWQ0<O1_037`K`0al6l0:f][@020<K0_003045Yh@36`;`0a/2l00<0a/2l00@0@FWQ
0<K0_036`;`0a/2l0`11JN430<K0_0030:f][@33_K/0`kfk00P0`kfk0P11JN440<>m^`03045Yh@2n
^KP0@FWQ00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102O
Vj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]00<0/J^M045Yh@11JN400P11JN4@
0;VbYP030:f][@2n]j`0_[N/00L0_[N/1011JN440;jg[080@FWQ0`31^[000`11JN40`KZ`0<6j/002
0<6j/080@FWQ1`31^[070:f][@80`kfc0P11JN4<0<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D00`35_[D2
045Yh@D0aKje0P11JN480<Fn]@80@FWQ1P36_kL2045Yh@L0a[ng0P11JN450<Jo]`040:f][@37`KP0
@FWQ045Yh@H0al6h00<0@FWQ0<O1^037`KP02`37`KP00`2][Jd0@FWQ0<O1^P070<O1^P03045Yh@37
`KX0al6j00X0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0=0<S1^`80@FWQ00<0
b<6k0:f][@2][Jd0102][Jd00`37`K`0@FWQ045Yh@040<O1_0<0@FWQ0`37`K`2045Yh@80al6l00@0
[Jf]0<K0_036`;`0@FWQ0`36`;`2045Yh@/0a/2l00<0[Jf]0<>m^`33_K/02033_K/2045Yh@80`kfk
00D0@FWQ0:f][@2n^KP0@FWQ0;ji^0020:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0
Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD0
0`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]
0;VbYP0?0;VbYP030:f][@2n]j`0_[N/00T0_[N/1011JN420;jg[080@FWQ0`31^[000`11JN40`KZ`
0<6j/0020<6j/080@FWQ2P31^[00102][Jd0`kfc0<>m/`33_K<20:f][@80@FWQ0`2][Jd:0<>m/`80
@FWQ1@35_[D2045Yh@D0aKje0P11JN480<Fn]@80@FWQ1P36_kL2045Yh@L0a[ng0P11JN450<Jo]`04
0:f][@37`KP0@FWQ045Yh@D0al6h0P11JN4=0<O1^0030:f][@37`KX0al6j00L0al6j00<0@FWQ0<O1
^P37`KX02P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k102][Jd2045Y
h@050:f][@38`K/0b<6k0<S1^`2][Jd00`37`K`2045Yh@@0al6l0`11JN440<O1_004045Yh@37`K`0
al6l0:f][@<0a/2l0`11JN4=0<K0_0030:f][@33_K/0`kfk00T0`kfk0`11JN400`33_K/0[Jf]0;ji
^0020:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00209nKX0030:f][@2`
h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]08Z5M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`09
0:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/00l0_[N/0P11JN43
0<6j/003045Yh@31^[00`KZ`0080`KZ`0P11JN4:0<6j/0030:f][@33_K<0`kfc00<0`kfc0`11JN42
0<>m/`P0[Jf]0`33_K<00`2][Jd0@FWQ045Yh@030<Fn]@80@FWQ1@35_[D2045Yh@P0aKje0P11JN46
0<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ1@37`KP2045Yh@d0al6h00<0
[Jf]0<O1^P37`KX01@37`KX3045Yh@`0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1
^`38`K/80:f][@@0b<6k0P11JN440<S1^`040:f][@37`K`0al6l0<O1_080@FWQ1037`K`2045Yh@03
0<O1_011JN40al6l0080al6l00@0@FWQ0<O1_037`K`0[Jf]4`36`;`00`2][Jd0`kfk0<>m^`0<0<>m
^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?oo
o`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@03
0:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00@FWQ00D0
@FWQ00<0`KZ`045Yh@11JN402P31^[000`2][Jd0`kfc0<>m/`030<>m/`<0@FWQ2P33_K<60:f][@D0
@FWQ1@35_[D2045Yh@P0aKje0P11JN460<Jo]`80@FWQ1`36_kL2045Yh@D0a[ng00@0[Jf]0<O1^011
JN40@FWQ1@37`KP2045Yh@d0al6h00<0[Jf]0<O1^P37`KX00`37`KX4045Yh@L0al6j00<0@FWQ0<O1
^P37`KX00`37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]3@38`K/2045Yh@<0b<6k00@0[Jf]0<O1
_037`K`0al6l0P11JN440<O1_080@FWQ0P37`K`4045Yh@80al6l00<0[Jf]0<K0_036`;`04@36`;`0
0`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@09
0;B`/@030:f][@2OVj00[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2]
[Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[001P31^[02045Yh@X0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<3045Y
h@@0`kfc00<0@FWQ0<>m/`33_K<01P33_K<00`2][Jd0aKje0<Fn]@020<Fn]@<0@FWQ1@2][Jd2045Y
h@<0[Jf]1@35_[D2045Yh@H0a[ng0P11JN470<Jo]`80@FWQ1@36_kL0102][Jd0al6h045Yh@11JN45
0<O1^080@FWQ3@37`KP0102][Jd0al6j0<O1^P37`KX4045Yh@T0al6j00<0@FWQ0<O1^P37`KX00`37
`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ0`38
`K/0102][Jd0al6l0<O1_037`K`2045Yh@80al6l1011JN490<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a
0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302a
Zid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00L0`KZ`00<0@FWQ0<6j/031^[002031^[000`2][Jd0`kfc0<>m/`030<>m/`80@FWQ00L0
`kfc045Yh@33_K<0`kfc045Yh@33_K<0@FWQ00D0`kfc0P11JN400`2][Jd0aKje0<Fn]@030<Fn]@80
@FWQ1@35_[D2045Yh@<0aKje1@2][Jd2045Yh@H0[Jf]0P11JN420:f][@D0a[ng0P11JN450<Jo]`04
0:f][@37`KP0@FWQ045Yh@D0al6h0P11JN4=0<O1^0030:f][@37`KX0al6j00<0@FWQ1P37`KX50:f]
[@03045Yh@2][Jd0[Jf]00T0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ0`38`K/0102]
[Jd0al6l0<O1_037`K`2045Yh@l0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd000000<>m^`02
0<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]
0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0/J^M
00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j
/031^[001`31^[02045Yh@T0`KZ`00@0[Jf]0<>m/`33_K<0`kfc1011JN400`33_K<0@FWQ0<>m/`02
0<>m/`80@FWQ1@33_K<2045Yh@030:f][@35_[D0aKje00<0aKje00<0@FWQ0<Fn]@35_[D01035_[D2
045Yh@L0aKje0P11JN470<Jo]`80@FWQ0P36_kL50:f][@80@FWQ1`2][Jd2045Yh@D0[Jf]0P11JN48
0:f][@03045Yh@2][Jd0[Jf]00@0[Jf]0P11JN460:f][@03045Yh@2][Jd0al6j00@0al6j00<0@FWQ
0<O1^P37`KX00`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00h0b<6k0P11JN43
0<S1^`050:f][@37`K`0al6l0<O1_011JN404037`K`00`2][Jd0a/2l0<K0_00@0<K0_00300000033
_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00H0];2a0P2]
[Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0
^K:V00d0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`00L0`KZ`0P11JN480<6j/003045Yh@2][Jd0
`kfc00@0`kfc0P11JN420<>m/`80@FWQ0P33_K<00`11JN40`kfc0<>m/`040<>m/`03045Yh@2][Jd0
aKje00@0aKje00<0@FWQ0<Fn]@35_[D01035_[D3045Yh@H0aKje0P11JN470<Jo]`80@FWQ1`36_kL2
045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ1P37`KP00`11JN40al6h0<O1^0050<O1^003045Yh@37
`KP0@FWQ00<0al6h00<0[Jf]045Yh@11JN401`37`KX00`11JN40al6j0<O1^P040<O1^P03045Yh@37
`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ0`38
`K/01@2][Jd0al6l0<O1_037`K`0@FWQ0100al6l00<0[Jf]0<K0_036`;`03P36`;`40:f][@h0`kfk
00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0/>3V
0@3oool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[002031^[000`11JN40`KZ`0<6j
/0060<6j/003045Yh@2][Jd0`kfc00X0`kfc0P11JN470<>m/`03045Yh@2][Jd0aKje00<0aKje00<0
@FWQ0<Fn]@35_[D01@35_[D3045Yh@D0aKje0P11JN400`2][Jd0a[ng0<Jo]`050<Jo]`<0@FWQ1P36
_kL2045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ1P37`KP00`11JN40al6h0<O1^0060<O1^080@FWQ
0`37`KP00`2][Jd0@FWQ0<O1^P070<O1^P03045Yh@37`KX0al6j00@0al6j00<0@FWQ0<O1^P37`KX0
0`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00h0b<6k0P11JN430<S1^`050:f]
[@37`K`0al6l0<O1_011JN404037`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0
/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/0080<6j/003045Y
h@31^[00`KZ`00H0`KZ`00<0@FWQ0:f][@33_K<05033_K<5045Yh@P0aKje0P11JN400`35_[D0@FWQ
0<Fn]@020<Fn]@80@FWQ00<0aKje0:f][@36_kL01P36_kL3045Yh@D0a[ng0P11JN460<Jo]`040:f]
[@37`KP0@FWQ045Yh@H0al6h0P11JN470<O1^003045Yh@37`KP0al6h0080al6h00<0[Jf]045Yh@37
`KX01`37`KX00`11JN40al6j0<O1^P040<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0>0<S1^`80@FWQ0`38`K/00`2][Jd0al6l0<O1_002045YhA00
al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?ooo`00J@2`h>H20:f][@80
Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0
_[N/102][Jd50;jg[0030:f][@31^[00`KZ`00P0`KZ`0P11JN470<6j/003045Yh@2][Jd0`kfc01@0
`kfc00<0[Jf]0<Fn]@35_[D02035_[D4045Yh@80aKje1011JN420<Fn]@030:f][@36_kL0a[ng00D0
a[ng0P11JN400`36_kL0@FWQ0<Jo]`030<Jo]`80@FWQ1P36_kL0102][Jd0al6h045Yh@11JN470<O1
^080@FWQ1@37`KP00`11JN40al6h0<O1^0030<O1^0030:f][@37`KX0@FWQ00H0al6j0P11JN450<O1
^P<0@FWQ1037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00h0b<6k0P11JN430<S1
^`030:f][@37`K`0al6l0080@FWQ4037`K`00`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][E80/>3V0@3oool0
06/0/>3V0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f]
[@030;jg[02][Jd0`KZ`00X0`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`050<Jo]`80@FWQ0P36_kL5045Y
h@L0a[ng1011JN490<O1^0D0@FWQ1P37`KP00`2][Jd0al6j0<O1^P06045Yh@030<O1^P11JN40al6j
00@0al6j0`11JN440<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03P38`K/2045Y
h@<0b<6k00@0[Jf]0<O1_011JN40@FWQ3`37`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]2@31^[000`11JN40`KZ`0<6j/0020<6j
/004045Yh@31^[00@FWQ0:f][AD0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`05
0<Jo]`80@FWQ3P36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00d0al6j0`11JN44
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03P38`K/2045Yh@<0b<6k00<0[Jf]
0<O1_011JN402`37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd3
0<6j/0@0@FWQ0P31^[000`11JN40[Jf]0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL01@36_kL2045Yh@h0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0=
0<O1^P<0@FWQ1037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00h0b<6k0P11JN43
0<S1^`030:f][@11JN40al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f]
[@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
00P0`KZ`1`2][Jd20<6j/003045Yh@2][Jd0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`050<Jo]`80@FWQ3P36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
00d0al6j0`11JN440<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03P38`K/6045Y
h@80al6l1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL01@36_kL2045Yh@h0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0=0<O1^P<0@FWQ1037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k00`0b<6k1011JN460:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]
0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`050<Jo]`80@FWQ3P36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00d0
al6j0`11JN440<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH0
3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
2033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`050<Jo]`80@FWQ
3P36_kL00`2][Jd0al6h045Yh@0E0<O1^0030:f][@37`KX0al6j00d0al6j00<0@FWQ0<O1^P11JN40
1037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80
/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`050<Jo]`80@FWQ
3P36_kL0102][Jd0@FWQ0<O1^011JN4D0<O1^0030:f][@37`KX0al6j00h0al6j00<0@FWQ0<O1^P37
`KX00`37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V
102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng00<0a[ng
1011JN4>0<Jo]`030:f][@37`KP0@FWQ01D0al6h00<0[Jf]0<O1^P37`KX03P37`KX00`11JN40al6j
0<O1^P030<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk
0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036
_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`
h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`09
0<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00L0a/2l
102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`
h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40oooo002N0;3P
iPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l1@2][Jf60;3P
iP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0
al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f]
[@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI0;3PiP40oooo
002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][JL0/>3V0@3o
ool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40oooo003A0;3P
iP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5236 .33411 m
.52025 .3309 L
s
.52025 .3309 m
.51691 .33089 L
s
.52527 .33411 m
.52025 .3309 L
s
.51691 .33089 m
.51357 .33407 L
s
.51691 .33089 m
.51189 .33406 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49854 .33065 m
.48687 .33034 L
s
.54866 .33382 m
.55199 .33053 L
s
.55199 .33053 m
.55532 .33044 L
s
.547 .33385 m
.55199 .33053 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46678 .32148 m
.47824 .322 L
s
.52111 .33862 m
.5327 .33857 L
s
.5029 .33845 m
.51448 .33859 L
s
.53932 .3385 m
.55089 .33827 L
s
0 0 0 r
.59492 .3286 m
.60159 .32816 L
s
.52696 .36631 m
.5282 .35915 L
s
.52864 .36631 m
.52987 .35915 L
s
.50896 .3592 m
.51017 .36626 L
s
.50729 .3592 m
.50849 .36624 L
s
.45048 .32861 m
.45456 .33153 L
s
.45374 .33203 m
.45048 .32861 L
s
.45374 .33203 m
.45454 .33366 L
s
.255 .412 .882 r
.48309 .33793 m
.48638 .3403 L
s
.4798 .33781 m
.48309 .33793 L
s
.48309 .33793 m
.48803 .34035 L
s
.48803 .34035 m
.49131 .34495 L
s
.48638 .3403 m
.48966 .34491 L
s
.4765 .33994 m
.4798 .33781 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56409 .34013 m
.56737 .33775 L
s
.56737 .33775 m
.57065 .33761 L
s
.56244 .34018 m
.56737 .33775 L
s
.55917 .34481 m
.56244 .34018 L
s
.49131 .34495 m
.49294 .35177 L
s
.48966 .34491 m
.49128 .35173 L
s
.47319 .34432 m
.4765 .33994 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55754 .35163 m
.55917 .34481 L
s
.57065 .33761 m
.57559 .33965 L
s
.56081 .34475 m
.56409 .34013 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5592 .35158 m
.56081 .34475 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47303 .36924 m
.47332 .32179 L
s
.47139 .36918 m
.47169 .32172 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54468 .36195 m
.54542 .36611 L
s
.54317 .36289 m
.54374 .36614 L
s
.255 .412 .882 r
.57559 .33965 m
.5789 .34401 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52607 .33861 m
.52608 .36346 L
s
.52773 .33861 m
.52774 .36345 L
s
.50944 .38611 m
.50952 .33854 L
s
.50778 .38609 m
.50786 .33852 L
s
.54428 .33842 m
.54436 .37007 L
s
.54593 .33838 m
.54602 .37004 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49292 .3563 m
.49294 .35177 L
s
.49127 .35626 m
.49128 .35173 L
s
.46176 .33699 m
.4634 .33708 L
s
.45848 .33907 m
.46176 .33699 L
s
.46011 .33916 m
.46176 .33699 L
s
.55754 .35163 m
.55756 .35616 L
s
.5592 .35158 m
.55922 .35611 L
s
.49124 .36305 m
.49292 .3563 L
s
.45844 .34359 m
.46011 .33916 L
s
.48958 .36301 m
.49127 .35626 L
s
.45681 .3435 m
.45848 .33907 L
s
.55756 .35616 m
.55925 .36291 L
s
.59028 .33661 m
.59195 .34103 L
s
.59028 .33661 m
.59036 .34565 L
s
.52442 .368 m
.52608 .36346 L
s
.52609 .36799 m
.52774 .36345 L
s
.55922 .35611 m
.5609 .36285 L
s
.50948 .36339 m
.51279 .36796 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45359 .33878 m
.45681 .3435 L
s
.45036 .33632 m
.45359 .33878 L
s
.44549 .33599 m
.45036 .33632 L
s
.45832 .35945 m
.45844 .34359 L
s
.59195 .34103 m
.59356 .33867 L
s
.59356 .33867 m
.59679 .3362 L
s
.5211 .37027 m
.52442 .368 L
s
.5211 .37027 m
.52609 .36799 L
s
.59679 .3362 m
.60327 .33576 L
s
.51279 .36796 m
.51777 .37026 L
s
.45665 .3639 m
.45681 .3435 L
s
.48791 .3675 m
.49124 .36305 L
s
.59036 .34565 m
.59195 .34103 L
s
.48626 .36745 m
.48958 .36301 L
s
.51777 .37026 m
.5211 .37027 L
s
.55925 .36291 m
.56257 .36734 L
s
.44223 .33803 m
.44549 .33599 L
s
.44061 .33791 m
.44549 .33599 L
s
.5609 .36285 m
.56423 .36728 L
s
.53938 .37015 m
.54602 .37004 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60327 .33576 m
.60652 .33778 L
s
.48294 .36961 m
.48791 .3675 L
s
.57735 .35767 m
.57901 .35986 L
s
.57572 .36001 m
.57735 .35767 L
s
.48294 .36961 m
.48626 .36745 L
s
.44057 .34244 m
.44223 .33803 L
s
.57572 .36001 m
.57738 .36221 L
s
.56257 .36734 m
.56754 .36943 L
s
.47308 .36243 m
.47635 .3671 L
s
.56423 .36728 m
.56754 .36943 L
s
.43895 .34232 m
.44061 .33791 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57901 .35986 m
.57902 .36213 L
s
.47963 .3695 m
.48294 .36961 L
s
.47635 .3671 m
.47963 .3695 L
s
.44052 .34697 m
.44057 .34244 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56754 .36943 m
.57249 .36924 L
s
.57577 .36682 m
.57902 .36213 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60652 .33778 m
.60816 .33992 L
s
.60816 .33992 m
.60823 .34672 L
s
.57249 .36924 m
.57577 .36682 L
s
.4389 .34685 m
.43895 .34232 L
s
.45665 .3639 m
.45832 .35945 L
s
.46645 .36895 m
.47303 .36924 L
s
.44532 .35411 m
.45507 .35699 L
s
.45507 .35699 m
.45668 .35936 L
s
.54439 .38144 m
.54606 .38369 L
s
.54273 .38374 m
.54439 .38144 L
s
.59209 .35689 m
.59533 .35442 L
s
.59047 .35926 m
.59209 .35689 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59533 .35442 m
.6034 .34934 L
s
.59047 .35926 m
.59051 .3638 L
s
.54273 .38374 m
.5444 .38599 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58668 .3934 m
.58735 .39715 L
s
.58735 .39715 m
.5881 .39245 L
s
.255 .412 .882 r
.44052 .34697 m
.44209 .35162 L
s
.54606 .38369 m
.5444 .38599 L
s
.50278 .38602 m
.50944 .38611 L
s
.59211 .35916 m
.59535 .35669 L
s
.59049 .36153 m
.59211 .35916 L
s
.60662 .34684 m
.60821 .34445 L
s
.6034 .34934 m
.60662 .34684 L
s
.59535 .35669 m
.60343 .35161 L
s
.4389 .34685 m
.44048 .35151 L
s
.44209 .35162 m
.44532 .35411 L
s
.44048 .35151 m
.44532 .35411 L
s
.45499 .36608 m
.45665 .3639 L
s
.60664 .34911 m
.60823 .34672 L
s
.60343 .35161 m
.60664 .34911 L
s
.59051 .3638 m
.59216 .36598 L
s
.62095 .33433 m
.62258 .33645 L
s
.61938 .33674 m
.62095 .33433 L
s
.61938 .33674 m
.62101 .33886 L
s
.45171 .36817 m
.45499 .36608 L
s
.59216 .36598 m
.59545 .36806 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40519 .32605 m
.40521 .32471 L
s
.40679 .32519 m
.4068 .32488 L
s
.5 Mabswid
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62101 .33886 m
.62258 .33645 L
s
.44519 .36776 m
.45171 .36817 L
s
.40712 .33264 m
.41819 .33375 L
s
.44038 .3606 m
.442 .36071 L
s
.44198 .36298 m
.442 .36071 L
s
.59545 .36806 m
.60196 .36764 L
s
.44036 .36287 m
.44038 .3606 L
s
.60678 .36275 m
.60835 .35808 L
s
.60835 .35808 m
.60845 .36719 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44036 .36287 m
.44196 .36526 L
s
.44196 .36526 m
.44519 .36776 L
s
.413 .36517 m
.41343 .33329 L
s
.60518 .36514 m
.60678 .36275 L
s
.60678 .36275 m
.60845 .36719 L
s
.60196 .36764 m
.60518 .36514 L
s
.41141 .36502 m
.41185 .33313 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61987 .37773 m
.62114 .35022 L
s
.62114 .35022 m
.62308 .37746 L
s
.42424 .36162 m
.42587 .35947 L
s
.42587 .35947 m
.42745 .36189 L
s
.42742 .36417 m
.42745 .36189 L
s
.42579 .36631 m
.42742 .36417 L
s
.42424 .36162 m
.42581 .36403 L
s
.62131 .36389 m
.62148 .3776 L
s
.42098 .3659 m
.42579 .36631 L
s
.41319 .35148 m
.41468 .35847 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40637 .35471 m
.40639 .35354 L
s
.40476 .35559 m
.40479 .35334 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39743 .34982 m
.39771 .33159 L
s
.41781 .36333 m
.42098 .3659 L
s
.39587 .34964 m
.39616 .3314 L
s
.41468 .35847 m
.41781 .36333 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61987 .37773 m
.62153 .38218 L
s
.39301 .33331 m
.39605 .33823 L
s
.3884 .33045 m
.39301 .33331 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40666 .36455 m
.413 .36517 L
s
.62153 .38218 m
.62308 .37746 L
s
.3912 .34909 m
.40213 .35034 L
s
.38532 .33006 m
.3884 .33045 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38221 .33193 m
.38532 .33006 L
s
.38068 .33173 m
.38532 .33006 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37907 .33609 m
.38221 .33193 L
s
.37754 .33588 m
.38068 .33173 L
s
0 0 0 r
.36329 .31918 m
.36436 .31935 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39697 .37962 m
.39719 .36584 L
s
.39551 .37255 m
.39719 .36584 L
s
.37746 .34045 m
.37907 .33609 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37593 .34024 m
.37754 .33588 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37581 .34711 m
.37746 .34045 L
s
.39232 .3768 m
.39551 .37255 L
s
.39551 .37255 m
.39697 .37962 L
s
.37429 .3469 m
.37593 .34024 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3756 .35859 m
.37581 .34711 L
s
.38761 .37856 m
.39232 .3768 L
s
.37408 .35839 m
.37429 .3469 L
s
.38451 .37819 m
.38761 .37856 L
s
.3756 .35859 m
.37701 .3657 L
s
.37408 .35839 m
.37548 .3655 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38146 .37551 m
.38451 .37819 L
s
.37991 .37531 m
.38451 .37819 L
s
.37701 .3657 m
.37846 .37051 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35811 .32608 m
.36344 .35919 L
s
.35153 .35734 m
.35811 .32608 L
s
.37846 .37051 m
.38146 .37551 L
s
.37548 .3655 m
.37693 .37031 L
s
.37693 .37031 m
.37991 .37531 L
s
.35301 .35758 m
.35797 .33296 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35895 .35851 m
.36796 .35984 L
s
.34636 .32407 m
.35153 .35734 L
s
.33985 .35535 m
.34636 .32407 L
s
.3413 .35561 m
.34621 .33097 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70493 .323 m
.71912 .3202 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33201 .32137 m
.33343 .32165 L
s
.33553 .35457 m
.34566 .35636 L
s
.32913 .32311 m
.33201 .32137 L
s
.33054 .32339 m
.33201 .32137 L
s
.32902 .32773 m
.33054 .32339 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32762 .32744 m
.32913 .32311 L
s
.32864 .34394 m
.32902 .32773 L
s
.71912 .3202 m
.72197 .32193 L
s
.71912 .3202 m
.72336 .32163 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71065 .3219 m
.71178 .37058 L
s
.70923 .32218 m
.71035 .37083 L
s
.32493 .32224 m
.32762 .32744 L
s
.32711 .34831 m
.32762 .32744 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3222 .31934 m
.32493 .32224 L
s
.72197 .32193 m
.72486 .32596 L
s
.31806 .31844 m
.3222 .31934 L
s
.72336 .32163 m
.72624 .32567 L
s
.70602 .3716 m
.7203 .36898 L
s
.32711 .34831 m
.32864 .34394 L
s
.32588 .34106 m
.32723 .34366 L
s
.31527 .32015 m
.31806 .31844 L
s
.3139 .31984 m
.31806 .31844 L
s
.72486 .32596 m
.72635 .3303 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31759 .337 m
.32588 .34106 L
s
.32565 .35035 m
.32711 .34831 L
s
.72624 .32567 m
.72773 .33001 L
s
.32279 .35212 m
.32565 .35035 L
s
.31378 .32448 m
.31527 .32015 L
s
.31242 .32417 m
.3139 .31984 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72635 .3303 m
.72791 .33698 L
s
.72773 .33001 m
.72928 .33668 L
s
.31366 .32912 m
.31378 .32448 L
s
.31724 .35098 m
.32279 .35212 L
s
.31491 .33408 m
.31759 .337 L
s
.31354 .33377 m
.31759 .337 L
s
.73425 .31687 m
.74359 .31461 L
s
.72791 .33698 m
.7282 .34862 L
s
.3123 .32882 m
.31242 .32417 L
s
.72928 .33668 m
.72958 .34833 L
s
.31366 .32912 m
.31491 .33408 L
s
.3123 .32882 m
.31354 .33377 L
s
.7203 .36898 m
.72305 .3661 L
s
.7203 .36898 m
.72445 .36582 L
s
.727 .35591 m
.7282 .34862 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72305 .3661 m
.72573 .36086 L
s
.31455 .34806 m
.31724 .35098 L
s
.3133 .34309 m
.31467 .34339 L
s
.31461 .34572 m
.31467 .34339 L
s
.72573 .36086 m
.727 .35591 L
s
.72838 .35562 m
.72958 .34833 L
s
.72445 .36582 m
.72711 .36058 L
s
.31324 .34543 m
.3133 .34309 L
s
.72711 .36058 m
.72838 .35562 L
s
.31324 .34543 m
.31455 .34806 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73961 .31559 m
.74049 .34825 L
s
.73828 .31592 m
.73915 .34856 L
s
.7351 .34947 m
.74049 .34825 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74011 .33422 m
.74163 .34092 L
s
.74163 .34092 m
.74441 .34497 L
s
.28645 .31054 m
.29538 .31297 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30121 .34031 m
.30247 .34297 L
s
.30241 .34531 m
.30247 .34297 L
s
.29983 .34234 m
.30121 .34031 L
s
.30102 .34734 m
.30241 .34531 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29983 .34234 m
.30108 .345 L
s
.74441 .34497 m
.74712 .34668 L
s
.29059 .34476 m
.29152 .31194 L
s
.29707 .34639 m
.30102 .34734 L
s
.2893 .34442 m
.29025 .31159 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74712 .34668 m
.75103 .34571 L
s
.7496 .34134 m
.75097 .34336 L
s
.7496 .34134 m
.75084 .33867 L
s
.29453 .34339 m
.29707 .34639 L
s
.75084 .33867 m
.7522 .34069 L
s
.29207 .33804 m
.29453 .34339 L
s
.29099 .33066 m
.29207 .33804 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7522 .34069 m
.75226 .34304 L
s
.75103 .34571 m
.75226 .34304 L
s
.76161 .31214 m
.76526 .30871 L
s
.7605 .31718 m
.76161 .31214 L
s
.7605 .31718 m
.76064 .32187 L
s
.76286 .31178 m
.76526 .30871 L
s
.76175 .31682 m
.76286 .31178 L
s
.76175 .31682 m
.76189 .32152 L
s
.76064 .32187 m
.76203 .32622 L
s
.28549 .34342 m
.29059 .34476 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76189 .32152 m
.76327 .32586 L
s
.27649 .30998 m
.27879 .31541 L
s
.27879 .31541 m
.27988 .32048 L
s
.27988 .32048 m
.2809 .32789 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76203 .32622 m
.76582 .32751 L
s
.76327 .32586 m
.76582 .32751 L
s
.76526 .30871 m
.76892 .3076 L
s
.76892 .3076 m
.77141 .30921 L
s
.7623 .33563 m
.76237 .33799 L
s
.7623 .33563 m
.76355 .33528 L
s
.28055 .33968 m
.2809 .32789 L
s
.27295 .30651 m
.27649 .30998 L
s
.27528 .30961 m
.27757 .31505 L
s
.27757 .31505 m
.27865 .32012 L
s
.76237 .33799 m
.76369 .34 L
s
.27865 .32012 m
.27967 .32754 L
s
.76355 .33528 m
.76362 .33764 L
s
.27931 .33933 m
.27967 .32754 L
s
.27295 .30651 m
.27528 .30961 L
s
.76369 .34 m
.76624 .34167 L
s
.77141 .30921 m
.77395 .31317 L
s
.26127 .30264 m
.27295 .30651 L
s
.2791 .34643 m
.28055 .33968 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27787 .34608 m
.27931 .33933 L
s
.77499 .30808 m
.77728 .30496 L
s
.77395 .31317 m
.77499 .30808 L
s
.27773 .35082 m
.2791 .34643 L
s
.2765 .35047 m
.27787 .34608 L
s
.77618 .3077 m
.77728 .30496 L
s
.77514 .31279 m
.77618 .3077 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77514 .31279 m
.77566 .32933 L
s
.77395 .31317 m
.77461 .33443 L
s
.76624 .34167 m
.77114 .34026 L
s
.76582 .32751 m
.77319 .3277 L
s
.77728 .30496 m
.77845 .30457 L
s
.27513 .35487 m
.27773 .35082 L
s
.77319 .3277 m
.77446 .3297 L
s
.77114 .34026 m
.77349 .33717 L
s
.27391 .35452 m
.2765 .35047 L
s
.26429 .35405 m
.26587 .30421 L
s
.77349 .33717 m
.77461 .33443 L
s
.26312 .35368 m
.26471 .30382 L
s
.77461 .33443 m
.77566 .32933 L
s
.27141 .3562 m
.27513 .35487 L
s
.27141 .3562 m
.27391 .35452 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25965 .35258 m
.27141 .3562 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78872 .301 m
.79424 .33274 L
s
.78529 .33583 m
.78872 .301 L
s
.78183 .33696 m
.78981 .3343 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78643 .33545 m
.78895 .30812 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79424 .33274 m
.79742 .2977 L
s
.79533 .33234 m
.79767 .30485 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79962 .33074 m
.80587 .32829 L
s
.79742 .2977 m
.80278 .32952 L
s
.81012 .30452 m
.81093 .29928 L
s
.80939 .31216 m
.81012 .30452 L
s
.81093 .29928 m
.81269 .2936 L
s
.80939 .31216 m
.80981 .3242 L
s
.8111 .30409 m
.8119 .29884 L
s
.81038 .31173 m
.8111 .30409 L
s
.8119 .29884 m
.81365 .29315 L
s
.81269 .2936 m
.81546 .28985 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81038 .31173 m
.8108 .32378 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81365 .29315 m
.81546 .28985 L
s
.80981 .3242 m
.81106 .33103 L
s
.81546 .28985 m
.81732 .28894 L
s
.8108 .32378 m
.81205 .33061 L
s
.81106 .33103 m
.81222 .33545 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81732 .28894 m
.82015 .28997 L
s
.81205 .33061 m
.8132 .33503 L
s
.81222 .33545 m
.81434 .33946 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8132 .33503 m
.8153 .33904 L
s
.82015 .28997 m
.82212 .29388 L
s
.81434 .33946 m
.8173 .34062 L
s
.82186 .28664 m
.82257 .30598 L
s
.8153 .33904 m
.8173 .34062 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81987 .30734 m
.82608 .30416 L
s
.82274 .28617 m
.82346 .30553 L
s
.8173 .34062 m
.81918 .33978 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81918 .33978 m
.82185 .33605 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82789 .28334 m
.83354 .27997 L
s
.82185 .33605 m
.82347 .3303 L
s
.82409 .32255 m
.82464 .33719 L
s
.82347 .3303 m
.82409 .32255 L
s
.82347 .3303 m
.82464 .33719 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82828 .34465 m
.82889 .34645 L
s
.82844 .34877 m
.82889 .34645 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83117 .28143 m
.83247 .31557 L
s
.83036 .28191 m
.83166 .31603 L
s
.82918 .31741 m
.83247 .31557 L
s
.83191 .3009 m
.83299 .30776 L
s
.83299 .30776 m
.83477 .31173 L
s
.20866 .28293 m
.20951 .28098 L
s
.20885 .27805 m
.20951 .28098 L
s
.20801 .28 m
.20885 .27805 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20801 .28 m
.20866 .28293 L
s
.83477 .31173 m
.83641 .31325 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20779 .32512 m
.20818 .29516 L
s
.20629 .3242 m
.20818 .29516 L
s
.83641 .31325 m
.83868 .31183 L
s
.83774 .30739 m
.83859 .30937 L
s
.83774 .30739 m
.8384 .30445 L
s
.20704 .32466 m
.20761 .30988 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8384 .30445 m
.83923 .30643 L
s
.83868 .31183 m
.83933 .30889 L
s
0 0 0 r
.84752 .26544 m
.84818 .26655 L
s
.84749 .2648 m
.84884 .26603 L
s
.255 .412 .882 r
.83923 .30643 m
.83933 .30889 L
s
.20684 .3296 m
.20779 .32512 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20235 .276 m
.20293 .27896 L
s
.20263 .28633 m
.20293 .27896 L
s
.20629 .3242 m
.20684 .3296 L
s
.20111 .27253 m
.20235 .276 L
s
.20195 .28583 m
.20273 .28387 L
s
.20186 .2883 m
.20263 .28633 L
s
.84329 .28087 m
.84377 .27546 L
s
.84329 .28087 m
.84349 .28579 L
s
.84377 .27546 m
.84563 .27147 L
s
.19855 .27049 m
.20111 .27253 L
s
.20052 .2873 m
.20195 .28583 L
s
.84349 .28579 m
.84436 .29022 L
s
.84396 .28037 m
.84443 .27495 L
s
.84396 .28037 m
.84416 .28529 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84443 .27495 m
.84563 .27147 L
s
.20042 .28976 m
.20186 .2883 L
s
.84416 .28529 m
.84502 .28972 L
s
.20127 .30309 m
.20215 .29864 L
s
.20176 .30852 m
.20215 .29864 L
s
.84563 .27147 m
.84751 .26993 L
s
.84436 .29022 m
.84642 .29119 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19714 .28973 m
.20052 .2873 L
s
.19704 .29221 m
.20042 .28976 L
s
.20127 .30309 m
.20176 .30852 L
s
.84502 .28972 m
.84642 .29119 L
s
.2005 .30508 m
.20127 .30309 L
s
.84475 .30009 m
.84485 .30257 L
s
.84475 .30009 m
.84541 .2996 L
s
.19722 .27192 m
.19855 .27049 L
s
.84485 .30257 m
.84561 .30455 L
s
.19908 .30658 m
.2005 .30508 L
s
.84541 .2996 m
.84551 .30208 L
s
0 0 0 r
.18451 .25073 m
.18458 .25081 L
s
.255 .412 .882 r
.84561 .30455 m
.84701 .30605 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84751 .26993 m
.84882 .27136 L
s
.19652 .27387 m
.19722 .27192 L
s
.19654 .30461 m
.19908 .30658 L
s
.84882 .27136 m
.85019 .27527 L
s
.19613 .26842 m
.19652 .27387 L
s
.19573 .2783 m
.19652 .27387 L
s
.19573 .2783 m
.19613 .26842 L
s
.84701 .30605 m
.84952 .30408 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19582 .2912 m
.19714 .28973 L
s
.19572 .29368 m
.19704 .29221 L
s
.85019 .27527 m
.85057 .2698 L
s
.85057 .2698 m
.85159 .26628 L
s
.19512 .29318 m
.19582 .2912 L
s
.19542 .30114 m
.19654 .30461 L
s
.19502 .29566 m
.19572 .29368 L
s
.85077 .27475 m
.85113 .26928 L
s
.85113 .26928 m
.85159 .26628 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85077 .27475 m
.85147 .29213 L
s
.85019 .27527 m
.8511 .29761 L
s
.84642 .29119 m
.85021 .29065 L
s
.85021 .29065 m
.8509 .29263 L
s
.85249 .24738 m
.85593 .24357 L
s
.85159 .26628 m
.85214 .26576 L
s
.84952 .30408 m
.85061 .3006 L
s
.19492 .29815 m
.19512 .29318 L
s
.19492 .29815 m
.19542 .30114 L
s
.85061 .3006 m
.8511 .29761 L
s
.8511 .29761 m
.85147 .29213 L
s
.85402 .24575 m
.85618 .29805 L
s
.85451 .24521 m
.85667 .29754 L
s
.19109 .26617 m
.19192 .27219 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18971 .26209 m
.19109 .26617 L
s
0 0 0 r
.18134 .32605 m
.18142 .32612 L
s
.255 .412 .882 r
.1911 .29212 m
.19121 .28962 L
s
.19079 .28661 m
.19121 .28962 L
s
.18986 .2961 m
.1911 .29212 L
s
.19017 .28859 m
.19079 .28661 L
s
.18877 .26101 m
.18971 .26209 L
s
.85554 .27004 m
.85629 .264 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18361 .27211 m
.18382 .26889 L
s
.255 .412 .882 r
.19017 .28859 m
.19058 .2916 L
s
.85463 .29957 m
.85667 .29754 L
s
.85629 .264 m
.85711 .26043 L
s
0 0 0 r
.18361 .27211 m
.18451 .25073 L
s
.255 .412 .882 r
.18776 .26243 m
.18877 .26101 L
s
.18732 .26189 m
.18877 .26101 L
s
.18875 .29758 m
.18986 .2961 L
s
.85711 .26043 m
.858 .25935 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85636 .29002 m
.85754 .294 L
s
.18669 .26636 m
.18776 .26243 L
s
.18732 .29604 m
.18875 .29758 L
s
.858 .25935 m
.85895 .26077 L
s
.858 .25935 m
.85936 .26023 L
s
.18627 .26582 m
.18732 .26189 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85754 .294 m
.85857 .29549 L
s
.18595 .27334 m
.18669 .26636 L
s
.85895 .26077 m
.85997 .2647 L
s
.18651 .2925 m
.18732 .29604 L
s
.18607 .29198 m
.18732 .29604 L
s
.18554 .27281 m
.18627 .26582 L
s
.85936 .26023 m
.86036 .26416 L
s
.85857 .29549 m
.85946 .29445 L
s
0 0 0 r
.86424 .29932 m
.86435 .29919 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18585 .28643 m
.18651 .2925 L
s
.18574 .27836 m
.18595 .27334 L
s
.85997 .2647 m
.86067 .27169 L
s
.18574 .27836 m
.18585 .28643 L
s
.18543 .2859 m
.18607 .29198 L
s
.18533 .27783 m
.18554 .27281 L
s
0 0 0 r
.18219 .3078 m
.18226 .30439 L
s
.86529 .26153 m
.86553 .26719 L
s
.255 .412 .882 r
.85946 .29445 m
.86021 .2909 L
s
.85946 .29445 m
.86062 .29037 L
s
.86036 .26416 m
.86106 .27116 L
s
.18533 .27783 m
.18543 .2859 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18134 .32605 m
.18189 .31321 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86537 .2608 m
.86553 .26719 L
s
.255 .412 .882 r
.18229 .25173 m
.18462 .25559 L
s
.86021 .2909 m
.86081 .28481 L
s
.86067 .27169 m
.86089 .27672 L
s
.86081 .28481 m
.86089 .27672 L
s
.86062 .29037 m
.8612 .28428 L
s
.86106 .27116 m
.86127 .27619 L
s
.8612 .28428 m
.86127 .27619 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8691 .23686 m
.86924 .23657 L
s
.255 .412 .882 r
.18207 .28927 m
.18356 .25394 L
s
.18174 .28875 m
.18323 .25339 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86251 .25279 m
.86449 .2489 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86342 .25113 m
.86568 .30443 L
s
.18079 .28716 m
.18207 .28927 L
s
.8637 .25057 m
.86596 .30391 L
s
0 0 0 r
.17638 .2372 m
.17669 .23794 L
s
.255 .412 .882 r
.1796 .24558 m
.18117 .2495 L
s
.18099 .30654 m
.18143 .30451 L
s
.1812 .30145 m
.18143 .30451 L
s
.18077 .30348 m
.1812 .30145 L
s
.18077 .30348 m
.18099 .30654 L
s
.86488 .27842 m
.86564 .28244 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87241 .31345 m
.87255 .31319 L
s
.255 .412 .882 r
.86475 .30598 m
.86596 .30391 L
s
.17925 .27577 m
.18044 .24783 L
s
.17902 .27523 m
.18021 .24727 L
s
.86541 .24666 m
.86662 .24271 L
s
.86564 .28244 m
.86649 .28338 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1788 .28033 m
.17925 .27577 L
s
.86599 .24497 m
.86719 .27301 L
s
.17858 .27979 m
.17902 .27523 L
s
.86649 .28338 m
.86693 .28231 L
s
.86616 .2444 m
.86736 .27246 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17807 .28127 m
.1788 .28033 L
s
.17807 .28127 m
.17858 .27979 L
s
0 0 0 r
.17477 .24463 m
.17479 .2362 L
s
.17446 .25611 m
.17477 .24463 L
s
.255 .412 .882 r
.17813 .23934 m
.17892 .24332 L
s
.86693 .28231 m
.86722 .27867 L
s
.86693 .28231 m
.86741 .27813 L
s
0 0 0 r
.17414 .26341 m
.17446 .25611 L
s
.17479 .2362 m
.17458 .23083 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17461 .24405 m
.17465 .23563 L
s
.17429 .25555 m
.17461 .24405 L
s
.255 .412 .882 r
.86719 .27301 m
.86722 .27867 L
s
0 0 0 r
.17398 .26285 m
.17429 .25555 L
s
.17465 .23563 m
.17458 .23083 L
s
.1735 .27382 m
.17414 .26341 L
s
.255 .412 .882 r
.17771 .28019 m
.17807 .28127 L
s
.86736 .27246 m
.86741 .27813 L
s
0 0 0 r
.17335 .27327 m
.17398 .26285 L
s
.255 .412 .882 r
.17621 .29553 m
.17852 .24162 L
s
0 0 0 r
.17458 .23083 m
.17439 .22966 L
s
.255 .412 .882 r
.17735 .276 m
.17771 .28019 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17289 .28006 m
.1735 .27382 L
s
.17439 .22966 m
.17408 .23214 L
s
.17275 .27951 m
.17335 .27327 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17609 .295 m
.17841 .24105 L
s
.17731 .26977 m
.17735 .276 L
s
0 0 0 r
.17408 .23214 m
.17365 .23829 L
s
.17235 .28209 m
.17289 .28006 L
s
.17235 .28209 m
.17275 .27951 L
s
.17413 .22732 m
.17404 .22497 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86733 .23872 m
.86888 .27471 L
s
.86709 .24043 m
.86751 .23643 L
s
0 0 0 r
.17216 .281 m
.17235 .28209 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17076 .30478 m
.17413 .22732 L
s
.17072 .30425 m
.17409 .22673 L
s
.255 .412 .882 r
.17581 .2934 m
.17621 .29553 L
s
0 0 0 r
.17216 .2762 m
.17216 .281 L
s
.17237 .26771 m
.17216 .2762 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86863 .27635 m
.86894 .27416 L
s
.86739 .23815 m
.86894 .27416 L
s
.17752 .24305 m
.17776 .23676 L
s
.1772 .25134 m
.17752 .24305 L
s
.17698 .2565 m
.1772 .25134 L
s
.86943 .28764 m
.86947 .29077 L
s
.86947 .29077 m
.86965 .29283 L
s
.86943 .28764 m
.86961 .2897 L
s
.17753 .24248 m
.17779 .23619 L
s
.17719 .25078 m
.17753 .24248 L
s
.17664 .2637 m
.17698 .2565 L
s
.17776 .23676 m
.17798 .23246 L
s
.17697 .25594 m
.17719 .25078 L
s
.86961 .2897 m
.86965 .29283 L
s
.17664 .26314 m
.17697 .25594 L
s
.17779 .23619 m
.17798 .23246 L
s
.86752 .23499 m
.86782 .2413 L
s
.86782 .2413 m
.86818 .24961 L
s
.86818 .24961 m
.8684 .25478 L
s
.17643 .26777 m
.17664 .2637 L
s
0 0 0 r
.17095 .30638 m
.17072 .30425 L
s
.255 .412 .882 r
.17798 .23246 m
.1781 .23131 L
s
.86746 .23442 m
.86779 .24073 L
s
.86779 .24073 m
.86815 .24904 L
s
.8672 .23068 m
.86752 .23499 L
s
.8684 .25478 m
.86871 .26199 L
s
.86815 .24904 m
.86838 .25421 L
s
.17645 .26722 m
.17664 .26314 L
s
.8672 .23068 m
.86746 .23442 L
s
.86838 .25421 m
.86868 .26143 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1781 .23131 m
.17815 .23274 L
s
0 0 0 r
.17376 .23249 m
.17423 .22394 L
s
.17322 .24414 m
.17376 .23249 L
s
.255 .412 .882 r
.17642 .26872 m
.17643 .26777 L
s
.86871 .26199 m
.86885 .26607 L
s
0 0 0 r
.17423 .22394 m
.1747 .21848 L
s
.17289 .25154 m
.17322 .24414 L
s
.17383 .2319 m
.17432 .22335 L
s
.17328 .24357 m
.17383 .2319 L
s
.255 .412 .882 r
.86701 .22953 m
.8672 .23068 L
s
.17642 .26872 m
.17645 .26722 L
s
.86868 .26143 m
.8688 .26552 L
s
0 0 0 r
.17432 .22335 m
.1747 .21848 L
s
.17295 .25097 m
.17328 .24357 L
s
.17247 .2621 m
.17289 .25154 L
s
.255 .412 .882 r
.17815 .23274 m
.17814 .23677 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86676 .23039 m
.86701 .22953 L
s
0 0 0 r
.17254 .26154 m
.17295 .25097 L
s
.1747 .21848 m
.17496 .21729 L
s
.255 .412 .882 r
.86876 .26702 m
.86885 .26607 L
s
.17654 .26761 m
.17642 .26872 L
s
.86876 .26702 m
.8688 .26552 L
s
0 0 0 r
.1723 .26843 m
.17247 .2621 L
s
.17496 .21729 m
.1751 .21981 L
s
.17496 .21729 m
.17527 .21922 L
s
.17239 .26787 m
.17254 .26154 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17654 .26761 m
.17682 .2639 L
s
.86676 .23039 m
.86668 .23443 L
s
.86847 .26536 m
.86876 .26702 L
s
.17682 .2639 m
.17725 .25757 L
s
0 0 0 r
.1751 .21981 m
.17513 .22606 L
s
.17244 .27049 m
.1723 .26843 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17691 .2654 m
.17773 .24637 L
s
.17895 .21794 m
.17919 .21245 L
s
.17703 .26485 m
.17783 .24619 L
s
.17904 .21813 m
.17929 .21227 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17527 .21922 m
.17532 .22547 L
s
.17244 .27049 m
.17239 .26787 L
s
.255 .412 .882 r
.8681 .26164 m
.86847 .26536 L
s
.86751 .25063 m
.86776 .2538 L
s
.86773 .25585 m
.86776 .2538 L
s
.86747 .25268 m
.86751 .25063 L
s
0 0 0 r
.17513 .22606 m
.17484 .23664 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86758 .25529 m
.8681 .26164 L
s
0 0 0 r
.1727 .26938 m
.17244 .27049 L
s
.17532 .22547 m
.17504 .23607 L
s
.255 .412 .882 r
.86747 .25268 m
.86758 .25529 L
s
0 0 0 r
.17316 .26451 m
.1727 .26938 L
s
.17333 .26395 m
.1727 .26938 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17484 .23664 m
.17452 .24411 L
s
.17504 .23607 m
.17472 .24354 L
s
.17452 .24411 m
.17384 .2559 L
s
.17384 .2559 m
.17316 .26451 L
s
.17403 .25533 m
.17472 .24354 L
s
.17719 .21077 m
.17898 .20721 L
s
.17403 .25533 m
.17333 .26395 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17774 .20958 m
.17974 .25545 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17492 .26324 m
.17671 .2599 L
s
.1804 .20484 m
.18287 .20129 L
s
.17547 .26213 m
.18158 .20306 L
s
.17577 .26157 m
.182 .20247 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17813 .25767 m
.18061 .25433 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18545 .24266 m
.18558 .24347 L
s
.18537 .2447 m
.18558 .24347 L
s
.18519 .24901 m
.18628 .24769 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18664 .20036 m
.18846 .19482 L
s
.18579 .20852 m
.18664 .20036 L
s
.18718 .19978 m
.18846 .19482 L
s
.18632 .20794 m
.18718 .19978 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18402 .25046 m
.18579 .20852 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18456 .2499 m
.18632 .20794 L
s
.18846 .19482 m
.18963 .19365 L
s
.18963 .19365 m
.19131 .1957 L
s
.18249 .25212 m
.18456 .2499 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19131 .1957 m
.19228 .20217 L
s
.19275 .19073 m
.19546 .18841 L
s
.19053 .24441 m
.19275 .19073 L
s
.1912 .24386 m
.19341 .19015 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18862 .24605 m
.1912 .24386 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1991 .18553 m
.19955 .19263 L
s
.19848 .20089 m
.1991 .18553 L
s
.19848 .20089 m
.19955 .19263 L
s
.19955 .19263 m
.20048 .18823 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20048 .18823 m
.20222 .18325 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20222 .18325 m
.20553 .18098 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19754 .22402 m
.19846 .21961 L
s
.19722 .23177 m
.19754 .22402 L
s
.19846 .21961 m
.20018 .21464 L
s
.19738 .22789 m
.1983 .22347 L
s
.1983 .22347 m
.20003 .21851 L
s
.20553 .18098 m
.20709 .18371 L
s
.19722 .23177 m
.19783 .2351 L
s
.20018 .21464 m
.2046 .20414 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20492 .22924 m
.20541 .2167 L
s
0 0 0 r
.19783 .2351 m
.19924 .23791 L
s
.20709 .18371 m
.20782 .18701 L
s
.255 .412 .882 r
.20416 .23507 m
.20492 .22924 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20615 .21797 m
.20622 .21627 L
s
0 0 0 r
.20003 .21851 m
.20445 .20802 L
s
.5 Mabswid
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2046 .20414 m
.20648 .19917 L
s
.20736 .19862 m
.20782 .18701 L
s
.19924 .23791 m
.20252 .23577 L
s
.20445 .20802 m
.20633 .20304 L
s
.20648 .19917 m
.20751 .19474 L
s
.20633 .20304 m
.20736 .19862 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20252 .23577 m
.20438 .23081 L
s
.20541 .22637 m
.2066 .21804 L
s
.20598 .23365 m
.2066 .21804 L
s
.20438 .23081 m
.20541 .22637 L
s
.20541 .22637 m
.20598 .23365 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21444 .17926 m
.21556 .17483 L
s
.21444 .17926 m
.21526 .18259 L
s
.21556 .17483 m
.21639 .17816 L
s
.21526 .18259 m
.21639 .17816 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21368 .24865 m
.21451 .20205 L
s
.21172 .24966 m
.21451 .20205 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2127 .24915 m
.21361 .22553 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21172 .24966 m
.21239 .25706 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21239 .25706 m
.21368 .24865 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80727 .23403 m
.80781 .23426 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7983 .16786 m
.79944 .16442 L
s
.79802 .15998 m
.79944 .16442 L
s
.79687 .16342 m
.79802 .15998 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79687 .16342 m
.7983 .16786 L
s
.255 .412 .882 r
.80544 .23129 m
.80727 .23403 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78614 .15949 m
.78765 .16394 L
s
.78765 .16394 m
.78805 .17584 L
s
.78323 .15457 m
.78614 .15949 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77753 .15267 m
.78323 .15457 L
s
.78667 .17536 m
.78792 .17187 L
s
.7868 .17934 m
.78805 .17584 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79981 .2115 m
.80064 .2355 L
s
.79898 .18764 m
.79934 .23504 L
s
.79898 .18764 m
.80193 .23597 L
s
.78401 .1784 m
.78667 .17536 L
s
.78414 .18239 m
.7868 .17934 L
s
.77475 .15571 m
.77753 .15267 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80092 .24354 m
.80193 .23597 L
s
.7771 .18409 m
.78401 .1784 L
s
.78759 .20329 m
.78871 .19576 L
s
.78871 .19576 m
.78925 .21177 L
s
.77723 .1881 m
.78414 .18239 L
s
.79934 .23504 m
.80092 .24354 L
s
.77341 .15923 m
.77475 .15571 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77168 .15081 m
.77341 .15923 L
s
.77168 .15081 m
.77218 .16675 L
s
.78633 .20684 m
.78759 .20329 L
s
.78759 .20329 m
.78925 .21177 L
s
.77218 .16675 m
.77341 .15923 L
s
.78364 .20995 m
.78633 .20684 L
s
.255 .412 .882 r
.27197 .19463 m
.2733 .18773 L
s
.27024 .19831 m
.27197 .19463 L
s
0 0 0 r
.77429 .1872 m
.7771 .18409 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77442 .19121 m
.77723 .1881 L
s
.77787 .20818 m
.78364 .20995 L
s
.77293 .19077 m
.77429 .1872 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77306 .19479 m
.77442 .19121 L
s
.77293 .19077 m
.77318 .19881 L
s
.75804 .15077 m
.7614 .15964 L
s
.75316 .14548 m
.75804 .15077 L
s
.7748 .20327 m
.77787 .20818 L
s
.77318 .19881 m
.7748 .20327 L
s
.74994 .14463 m
.75316 .14548 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74679 .14779 m
.74994 .14463 L
s
.74515 .14738 m
.74994 .14463 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76201 .1797 m
.76225 .18775 L
s
.74372 .155 m
.74679 .14779 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76092 .1954 m
.76225 .18775 L
s
.76044 .17927 m
.7608 .19136 L
s
.74261 .17476 m
.76201 .1797 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74206 .1546 m
.74515 .14738 L
s
.75947 .19902 m
.7608 .19136 L
s
.75947 .19902 m
.76092 .1954 L
s
.74239 .16668 m
.74372 .155 L
s
.74071 .16628 m
.74206 .1546 L
s
.7564 .20225 m
.75947 .19902 L
s
.72637 .13899 m
.73328 .14054 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74239 .16668 m
.74261 .17476 L
s
.75155 .20105 m
.7564 .20225 L
s
.74071 .16628 m
.74094 .17437 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72811 .13937 m
.73032 .22478 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74261 .17476 m
.74462 .1873 L
s
.72637 .13899 m
.72857 .22443 L
s
.74094 .17437 m
.74295 .18691 L
s
.74816 .1962 m
.75155 .20105 L
s
.74651 .1958 m
.75155 .20105 L
s
.74462 .1873 m
.74816 .1962 L
s
.72297 .14226 m
.72668 .15108 L
s
.71933 .13749 m
.72297 .14226 L
s
.74295 .18691 m
.74651 .1958 L
s
.71575 .13676 m
.71933 .13749 L
s
.71224 .14008 m
.71575 .13676 L
s
.71043 .13972 m
.71575 .13676 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72106 .17512 m
.7213 .17361 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70696 .14713 m
.71043 .13972 L
s
.70879 .14747 m
.71224 .14008 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7242 .19095 m
.72752 .18351 L
s
.70724 .15931 m
.70879 .14747 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7054 .15897 m
.70696 .14713 L
s
.72073 .19433 m
.7242 .19095 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70724 .15931 m
.70743 .16745 L
s
.68804 .13575 m
.69202 .1445 L
s
.6822 .13077 m
.68804 .13575 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71714 .19364 m
.72073 .19433 L
s
.70743 .16745 m
.70956 .18003 L
s
.7054 .15897 m
.70559 .16712 L
s
.70559 .16712 m
.70772 .17969 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67832 .13017 m
.6822 .13077 L
s
.71341 .18887 m
.71714 .19364 L
s
.71158 .18854 m
.71714 .19364 L
s
.70956 .18003 m
.71341 .18887 L
s
.6745 .13366 m
.67832 .13017 L
s
.67254 .13337 m
.67832 .13017 L
s
.70772 .17969 m
.71158 .18854 L
s
.72324 .2234 m
.73032 .22478 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67072 .14124 m
.6745 .13366 L
s
.66875 .14097 m
.67254 .13337 L
s
.69245 .16488 m
.69263 .17306 L
s
.69059 .1646 m
.69245 .16488 L
s
.255 .412 .882 r
.66417 .16198 m
.66421 .16372 L
s
0 0 0 r
.69055 .16457 m
.69081 .17685 L
s
.255 .412 .882 r
.66218 .16051 m
.66224 .16346 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69089 .18095 m
.69263 .17306 L
s
.66897 .15323 m
.67072 .14124 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66699 .15296 m
.66875 .14097 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68906 .18476 m
.69081 .17685 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68906 .18476 m
.69089 .18095 L
s
.68529 .18829 m
.68906 .18476 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66912 .16142 m
.69059 .1646 L
s
.65252 .12665 m
.65326 .17175 L
s
.66897 .15323 m
.66912 .16142 L
s
.66699 .15296 m
.66714 .16115 L
s
.64438 .12569 m
.65857 .12741 L
s
.4037 .12539 m
.41611 .1241 L
s
.66912 .16142 m
.67134 .17401 L
s
.66714 .16115 m
.66935 .17374 L
s
.62158 .12338 m
.63616 .1248 L
s
.67945 .18745 m
.68529 .18829 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67134 .17401 m
.67544 .18278 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67544 .18278 m
.67945 .18745 L
s
.67347 .18251 m
.67945 .18745 L
s
.66935 .17374 m
.67347 .18251 L
s
.255 .412 .882 r
.66284 .19795 m
.66289 .20094 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42868 .12296 m
.4414 .12195 L
s
.255 .412 .882 r
.66289 .20094 m
.66344 .19839 L
s
0 0 0 r
.59825 .12155 m
.61315 .12266 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40782 .12495 m
.42127 .21033 L
s
.41161 .14911 m
.43051 .14741 L
s
.44567 .12165 m
.46072 .12072 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65136 .17977 m
.65326 .17175 L
s
.62785 .12397 m
.62845 .16919 L
s
.62994 .12417 m
.63055 .16938 L
s
.65049 .12641 m
.65122 .17151 L
s
.64931 .17954 m
.65122 .17151 L
s
.255 .412 .882 r
.42642 .16457 m
.42849 .16158 L
s
.43055 .16429 m
.42849 .16158 L
s
0 0 0 r
.64527 .18323 m
.65136 .17977 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64527 .18323 m
.64931 .17954 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57451 .12021 m
.58966 .121 L
s
.255 .412 .882 r
.42843 .16735 m
.43055 .16429 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45159 .17903 m
.45211 .12123 L
s
.45376 .1789 m
.45426 .12109 L
s
.255 .412 .882 r
.49255 .16395 m
.49257 .15747 L
s
0 0 0 r
.5505 .11937 m
.56581 .11985 L
s
.255 .412 .882 r
.49472 .1639 m
.49474 .15747 L
s
0 0 0 r
.64114 .18281 m
.64527 .18323 L
s
.49337 .12352 m
.49777 .1193 L
s
.49777 .1193 m
.50216 .11922 L
s
.49118 .12357 m
.49777 .1193 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50216 .11922 m
.50874 .12323 L
s
.52634 .11904 m
.54173 .11919 L
s
.63055 .16938 m
.63484 .17805 L
s
.62856 .17746 m
.63055 .16938 L
s
.48676 .13193 m
.49118 .12357 L
s
.62646 .17727 m
.62845 .16919 L
s
.48895 .13186 m
.49337 .12352 L
s
.63484 .17805 m
.64114 .18281 L
s
.50874 .12323 m
.51313 .13141 L
s
.48452 .14437 m
.48676 .13193 L
s
.48671 .1443 m
.48895 .13186 L
s
.6223 .18106 m
.62856 .17746 L
s
.6223 .18106 m
.62646 .17727 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45397 .15402 m
.45603 .16632 L
s
.60727 .16746 m
.61163 .17607 L
s
.61806 .18071 m
.6223 .18106 L
s
.48448 .15264 m
.48452 .14437 L
s
.48667 .15258 m
.48671 .1443 L
s
.61163 .17607 m
.61806 .18071 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58102 .12052 m
.58145 .17837 L
s
.58318 .12064 m
.58363 .17848 L
s
.60466 .122 m
.60525 .17976 L
s
.60678 .12216 m
.6074 .17991 L
s
.55926 .11962 m
.55947 .16504 L
s
.55707 .11955 m
.55727 .16497 L
s
.48448 .15264 m
.48661 .16501 L
s
.48667 .15258 m
.48881 .16495 L
s
.45603 .16632 m
.4603 .17439 L
s
.5988 .17933 m
.6074 .17991 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42127 .21033 m
.43715 .12227 L
s
.42143 .19781 m
.43503 .12244 L
s
.44511 .17943 m
.45376 .1789 L
s
.46905 .16982 m
.47127 .16557 L
s
.47127 .16557 m
.47343 .16963 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51089 .15623 m
.51309 .16036 L
s
.50868 .16041 m
.51089 .15623 L
s
.46905 .16982 m
.47121 .17388 L
s
.4603 .17439 m
.46463 .17834 L
s
.4734 .17379 m
.47343 .16963 L
s
.5573 .17329 m
.55947 .16504 L
s
.48661 .16501 m
.49098 .17321 L
s
.50868 .16041 m
.51088 .16454 L
s
.5551 .17323 m
.55727 .16497 L
s
.51309 .16452 m
.51309 .16036 L
s
.48881 .16495 m
.49319 .17315 L
s
.57489 .17807 m
.58363 .17848 L
s
.47119 .17804 m
.4734 .17379 L
s
.46463 .17834 m
.47119 .17804 L
s
.53521 .16454 m
.53964 .17291 L
s
.50865 .17288 m
.51309 .16452 L
s
.55071 .17728 m
.5573 .17329 L
s
.55071 .17728 m
.5551 .17323 L
s
.49098 .17321 m
.49759 .17722 L
s
.49319 .17315 m
.49759 .17722 L
s
.53964 .17291 m
.54629 .17719 L
s
.50422 .1771 m
.50865 .17288 L
s
.54629 .17719 m
.55071 .17728 L
s
.49759 .17722 m
.50422 .1771 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53514 .1191 m
.53527 .20631 L
s
.53294 .11908 m
.53305 .20629 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5816 .19923 m
.58382 .20352 L
s
.57944 .20332 m
.5816 .19923 L
s
.58166 .20761 m
.58382 .20352 L
s
.57944 .20332 m
.58166 .20761 L
s
.52638 .20625 m
.53527 .20631 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P3o
YQ03000000/0ojH@2@0000030?nV40@000006`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ45000000H0ojHA2`2][Jd0
10000000[Jf]0:f][@2][Jd2000000`0[Jf]0P00000:0:f][@H000000`2][Jd9000000X0ojD@00<0
[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@000000
000000D0000000<0[Jf]0000000000000`0000090:f][@L0ojHA00<0[Jf]0?nV403oYQ000P000005
0?nV40030000003oYQ00ojH@00T0ojH@0P0000070?nV40030:f][@3oYA00ojD@008000002P3oYA02
000000L0[Jf]200000040:f][@@000004`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0>0?nV
4@L0000000<0ojHA0:f][@2][Jd01P2][Jd200000080[Jf]103oYQ4200000100ojHA00@0[Jf]0?nV
4000000000001`3oYQ000`000000ojH@0?nV40080?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002
000000X0ojD@0P00000:0?nU408000000P3oYA000`2][Jd0oj<@0?nS40020?nS40<0[Jf]1@000000
0`2][Jd0oj<@0?nS400<0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0ojHA102][Jd00`00
0000[Jf]0:f][@030:f][@@0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000060?nV4@800000403oYQ40
0`2][Jd00000000000080?nV40030000003oYQ00ojH@00P0ojH@0P0000070?nV40030:f][@3oYA00
ojD@008000002P3oYA02000000X0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P000004
0?nS4080[Jf]200000040?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd40?nV
4@030000003oYQ40ojHA00L0ojHA00<0[Jf]0?nV4@3oYQ400P0000070?nV4@800000403oYQ400`00
0000ojH@000000090?nV40030000003oYQ00ojH@00L0ojH@0P0000070?nV40030:f][@3oYA00ojD@
008000002P3oYA02000000X0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000090?nS
408000000`3oXa070:f][AP0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0E0?nV4@L0[Jf]3P3oYQ400`000000ojHA0?nV4@070?nV4@030:f][@3oYQ40ojHA0080
00001`3oYQ4200000100ojHA0P00000;0?nV40030000003oYQ00ojH@00H0ojH@0P0000070?nV4003
0:f][@3oYA00ojD@008000002P3oYA02000000X0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0
oj<@0P0000090?nS408000001`3oXa00102][Jd0o:0@0?bP402][Jd4000000030:f][@3lX100o:0@
0100o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?oo
o`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@D0
[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@0A0?nV4@030000003oYQ40ojHA00H0ojHA00<0[Jf]0?nV4@3o
YQ400P0000070?nV4@8000003`3oYQ400`000000[Jf]0000000D0?nV408000001`3oYQ000`2][Jd0
ojD@0?nU4002000000X0ojD@0P00000:0?nU408000000P3oYA000`2][Jd0oj<@0?nS40050?nS4080
00002@3oXa02000000L0oj<@00<0[Jf]0?bP400000000P0000030?bP40030000002][Jd0[Jf]00<0
[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3K
RPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ402`3oYQ450:f][@L0ojHA00<0[Jf]0?nV4@3oYQ40
4@3oYQ400`000000ojHA0?nV4@060?nV4@030:f][@3oYQ40ojHA008000001`3oYQ42000000l0ojHA
00<000000:f][@000000503oYQ02000000L0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU40800000
2P3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa02000000T0oj<@0P0000070?nS40040:f]
[@000000o:0@000000D0o:0@00<000000?bP403lX1000P3lX1050:f][@P0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2][JeK0;3PiP40
oooo001_0;3PiP80[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A
00<0[Jf]0?nV4@3oYQ401@3oYQ460:f][@`0ojHA00<0[Jf]0?nV4@3oYQ404@3oYQ400`000000ojHA
0?nV4@060?nV4@030:f][@3oYQ40ojHA008000001`3oYQ42000000l0ojHA0P00000E0?nV40800000
1`3oYQ000`2][Jd0ojD@0?nU4002000000X0ojD@0P00000:0?nU408000000P3oYA000`2][Jd0oj<@
0?nS40050?nS408000002@3oXa02000000L0oj<@00<0[Jf]0000000000001`3lX1000`000000o:0@
0?bP40060?bP40@0[Jf]0`0000000`3lX100[Jf]0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401@2]
[JdB0?nV4@030:f][@3oYQ40ojHA0140ojHA00<000000?nV4@3oYQ401P3oYQ400`2][Jd0ojHA0?nV
4@02000000L0ojHA0P00000>0?nV4@030000003oYQ40000001D0ojH@0P0000070?nV40030:f][@3o
YA00ojD@008000002P3oYA02000000X0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P00
00090?nS408000001`3oXa000`000000o:0@000000070?bP40030000003lX100o:0@00T0o:0@00D0
00000?bP403lX100[Jf]000000020:f][@8000004`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01<0oj@A102][JdG0?nV4@030:f][@3oYQ40ojHA0140ojHA00<0
00000?nV4@3oYQ401P3oYQ40102][Jd0ojHA0000000000080?nV4@8000003P3oYQ400`000000ojHA
0000000E0?nV408000001`3oYQ000`2][Jd0ojD@0?nU4002000000X0ojD@0P00000:0?nU40800000
0P3oYA000`2][Jd0oj<@0?nS40050?nS408000002@3oXa02000000L0oj<@0P0000090?bP40030000
003lX100o:0@00L0o:0@0P0000030?bP40030000002][Jd0mY`?00@000004@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A102][Jd00`3oY140[Jf]0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA0140ojHA00<000000?nV4@3oYQ401@3oYQ400`2][Jd0ojHA0?nV
4@02000000P0ojHA0P00000>0?nV4@80000000<0[Jf]0?nV403oYQ004`3oYQ02000000L0ojH@00<0
[Jf]0?nU403oYA000P00000:0?nU408000002P3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3o
Xa02000000T0oj<@0P0000070?nS408000002@3lX1000`000000o:0@0?bP40060?bP408000001@3l
X10010000000mY`?0000000000020?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ404P3oYQ400`000000ojHA0?nV4@040?nV4@030:f][@3oYQ40ojHA00800000203o
YQ42000000h0ojHA0P0000000`2][Jd0ojH@0?nV400C0?nV408000001`3oYQ00102][Jd0ojD@0?nU
403oYA02000000T0ojD@0P00000:0?nU408000000P3oYA000`2][Jd0oj<@0?nS40050?nS40800000
2@3oXa02000000L0oj<@0P00000:0?bP40030000003lX100o:0@00D0o:0@0P0000050?bP40040000
003fW0l00000000000H0mY`?0`2][Jd3000000L0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ400`000000ojHA0?nV4@020?nV4@L00000
203oYQ42000000h0ojHA0P0000000`2][Jd0ojH@0?nV400C0?nV408000001`3oYQ00102][Jd0ojD@
0?nU403oYA02000000T0ojD@0P00000:0?nU408000000P3oYA000`2][Jd0oj<@0?nS40050?nS4080
00002@3oXa02000000H0oj<@0P00000B0?bP408000001P3lX100102][Jd000000000000000070?JL
3`80000000D0mY`?0:f][@2][Jd000000:f][@050?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0B0?nV4@D000000P3oYQ400`2][Jd0ojHA0?nV4@02000000P0ojHA0P00000>0?nV
4@80000000<0[Jf]0?nV403oYQ004`3oYQ02000000L0ojH@00@0[Jf]0?nU403oYA00ojD@0P000009
0?nU408000002P3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa02000000T0oj<@0P000006
0?nS4080000000<0[Jf]0?bP403lX1003`3lX102000000H0o:0@00@0[Jf]00000000000000001P3f
W0l00`000000mY`?000000030?JL3`030000003fW0l0[Jf]00<0[Jf]00<0mY`?0:f][@3/UPh04@3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]
0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0180ojHA00<000000?nV4@3oYQ40103oYQ40
102][Jd0ojHA0000000000090?nV4@8000003P3oYQ42000000030:f][@3oYQ00ojH@01<0ojH@0P00
00070?nV40040:f][@3oYA00ojD@0?nU408000002P3oYA02000000T0ojD@0P0000020?nU40030:f]
[@3oXa00oj<@00D0oj<@0P0000090?nS408000001P3oXa02000000030:f][@3lX100o:0@00l0o:0@
0P0000060?bP40040:f][@3fW0l00000000000H0mY`?0P0000050?JL3`030000003fW0l0mY`?0080
mY`?0P2][Jd00`000000k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2i
M@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@
00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ404P3oYQ400`00
0000ojHA0?nV4@040?nV4@040:f][@3oYQ400000000000T0ojHA0P00000>0?nV4@80000000<0[Jf]
0?nV403oYQ004`3oYQ02000000L0ojH@00@0[Jf]0?nU403oYA00ojD@0P00000:0?nU408000002@3o
YA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa02000000T0oj<@0P0000060?nS4080000000<0
[Jf]0?bP403lX1003P3lX102000000L0o:0@00@0[Jf]0?JL3`00000000001@3fW0l00`000000mY`?
000000050?JL3`030000003fW0l0mY`?00<0mY`?00@0[Jf]0000002][Jd0[Jf]0P00000=0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP05
0:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f]
[@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0180ojHA00<000000?nV
4@3oYQ40103oYQ40102][Jd0ojHA0000000000090?nV4@8000003P3oYQ42000000030:f][@3oYQ00
ojH@01<0ojH@0P0000070?nV40040:f][@3oYA00ojD@0?nU408000002P3oYA02000000T0ojD@0P00
00020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000090?nS408000001P3oXa02000000030:f][@3l
X100o:0@00h0o:0@0P0000070?bP40040:f][@3fW0l00000000000D0mY`?0P0000070?JL3`030000
003fW0l0mY`?0080mY`?00H0[Jf]0000003/UPh000000>bF3P2][Jd2000000/0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0
dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01<0
ojHA00<000000?nV4@3oYQ400`3oYQ40102][Jd0ojHA0000000000090?nV4@8000002@3oYQ450:f]
[@8000002`2][Jd00`000000[Jf]0:f][@080:f][@8000002`2][Jd200000080[Jf]203oYA020000
00T0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000090?nS408000001P3oXa020000
00030:f][@3lX100o:0@00h0o:0@0P0000070?bP40040:f][@3fW0l00000000000D0mY`?0P000007
0?JL3`030000003fW0l0mY`?0080mY`?00@0[Jf]00000000000000000`3/UPh00`000000[Jf]0:f]
[@090>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3P
iP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ404`3oYQ400`000000ojHA0?nV4@030?nV4@040:f][@3oYQ40
0000000000@0ojHA1@2][Jd2000000T0[Jf]1@3oYQ42000000030:f][@3oYQ00ojH@00L0ojH@00<0
00000?nV400000002@3oYQ02000000L0ojH@00@0[Jf]0?nU403oYA00ojD@0P0000020?nU40P0[Jf]
0P0000060:f][@<0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000090?nS40800000
1P3oXa02000000030:f][@3lX100o:0@00h0o:0@0P0000070?bP40040:f][@3fW0l00000000000D0
mY`?0P0000080?JL3`050000003fW0l0mY`?0?JL3`2][Jd00P0000050>bF3P030000003/UPh0[Jf]
0080[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3P
iP2`h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01<0ojHA00<000000?nV4@2][Jd0102][Jd00`000000
[Jf]000000040:f][@D0ojHA0P00000?0?nV4@8000002@3oYQ0010000000ojH@0?nV400000080?nV
408000001`3oYQ00102][Jd0ojD@0?nU403oYA02000000X0ojD@0P0000060?nU40<0[Jf]0P000007
0:f][@<0oj<@0P0000090?nS408000001P3oXa04000000l0o:0@0P0000070?bP40040:f][@3fW0l0
0000000000D0mY`?0P0000080?JL3`050000003fW0l0mY`?0?JL3`2][Jd00P0000050>bF3P030000
003/UPh0k9H>0080k9H>00<0[Jf]0000003/UPh00`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>7
3P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@L0[Jf]
00<000000:f][@3oYQ400`3oYQ400`2][Jd000000000000:0?nV4@<000003P3oYQ42000000T0ojH@
00@000000?nV403oYQ000000203oYQ02000000L0ojH@00@0[Jf]0?nU403oYA00ojD@0P00000:0?nU
408000002@3oYA0200000080ojD@00<0[Jf]0?nS403oXa000P3oXa030:f][@8000001@2][Jd40?nS
408000001P3oXa02000000030:f][@3lX100000000D000002@3lX102000000L0o:0@00@0[Jf]0?JL
3`00000000001@3fW0l2000000`0mY`?00<0[Jf]0000003/UPh01P3/UPh00`000000k9H>0>bF3P02
0>bF3P060000002][Jd0[Jf]0:f][@3/UPh0[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f]
[@2`h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH
400;0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd70?nV4@030000003oYQ40ojHA00<0ojHA
00<0[Jf]0000000000002P3oYQ43000000L0ojHA00<000000?nV4@3oYQ40103oYQ42000000X0ojH@
00<000000?nV40000000203oYQ000`000000ojH@000000060?nV40040:f][@3oYA00ojD@0?nU4080
00002P3oYA02000000T0ojD@0P0000020?nU40030:f][@3oXa00oj<@00D0oj<@0P0000050?nS40@0
[Jf]0P0000040:f][@80oj<@0P0000000`2][Jd0o:0@0?bP40050?bP40@000001@3lX102000000L0
o:0@00@0[Jf]0?JL3`00000000001@3fW0l2000000`0mY`?00<0[Jf]0000003/UPh01P3/UPh00`00
0000k9H>0>bF3P020>bF3P8000000P3/UPh20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f]
[DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@0P2][Jd@0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405P3oYQ470:f][A40ojHA00<000000?nV4@3o
YQ400`3oYQ400`2][Jd000000000000:0?nV4@<000001`3oYQ400`000000ojHA0?nV4@050?nV4@80
00002P3oYQ000`000000ojH@0?nV40070?nV40030000003oYQ00000000H0ojH@00H0[Jf]0?nU403o
YA0000000?nU4000000:0?nU408000002@3oYA0200000080ojD@00<0[Jf]0?nS403oXa001@3oXa02
000000T0oj<@0P0000040?nS4080[Jf]0P0000040:f][@H0o:0@0P0000050?bP408000001`3lX100
102][Jd0mY`?0000000000050?JL3`800000303fW0l00`2][Jd000000>bF3P060>bF3P030000003/
UPh0k9H>0080k9H>00<000000>bF3P3/UPh00P3/UPh30:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`2][JdA
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ460:f][@80ojHA00<0[Jf]
0?nV4@3oYQ40503oYQ400`000000ojHA0?nV4@020?nV4@030:f][@000000000000X0ojHA0`000006
0?nV4@030000003oYQ40000000H0ojHA0P0000090?nV40030000003oYQ00ojH@00P0ojH@00@00000
0?nV4000000000001@3oYQ000`2][Jd0ojD@0?nU4002000000/0ojD@0P0000090?nU40<0000000<0
ojD@0:f][@3oXa001P3oXa02000000T0oj<@0P0000070?nS408000000`3lX1060:f][@8000001@3l
X102000000L0o:0@00@0[Jf]0?JL3`00000000001@3fW0l2000000`0mY`?00<0[Jf]0>bF3P3/UPh0
1P3/UPh00`000000k9H>0>bF3P020>bF3P030000003/UPh0k9H>0080k9H>00<0[Jf]0=^:3@3KRPd0
0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`
h>H00`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]203o
YQ400`2][Jd0ojHA0?nV4@0D0?nV4@030000003oYQ40ojHA0080ojHA00<0[Jf]0000000000002P3o
YQ42000000030?nV4@000000ojHA00@0ojHA00<000000?nV4@0000001P3oYQ400`2][Jd000000000
00080?nV40030000003oYQ00ojH@00P0ojH@00@000000?nV4000000000001@3oYQ001@2][Jd0ojD@
0000003oYA00000000/0ojD@0P0000090?nU40<0000000<0ojD@0:f][@3oXa001P3oXa02000000T0
oj<@0P0000070?nS408000002@3lX102000000D0[Jf]0P0000070?bP40040:f][@3fW0l000000000
00D0mY`?0P00000<0?JL3`030:f][@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh01`3/UPh00`2]
[Jd0fhX=0=^:3@020=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]
04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH
4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV
4@3oYQ401P3oYQ450:f][@d0ojHA00<0[Jf]0?nV4@3oYQ40503oYQ400`000000ojHA0?nV4@020?nV
4@8000002`3oYQ42000000030?nV4@000000ojHA00@0ojHA00<000000?nV4@0000001P3oYQ40102]
[Jd0ojH@0000000000060?nV40030000003oYQ00ojH@00T0ojH@00D000000?nV40000000ojH@0000
00040?nV40050:f][@3oYA0000000?nU400000002`3oYA02000000T0ojD@0P0000000`3oYA000000
0:f][@060?nS4080000000<0oj<@0000003oXa001`3oXa02000000L0oj<@0P0000090?bP40800000
1@3lX102000000@0[Jf]0P3lX1000`11JN40[Jf]0?JL3`02000000D0mY`?0P00000<0?JL3`030:f]
[@3/UPh0k9H>00H0k9H>00<000000>bF3P3/UPh01`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@030:f]
[@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3PiP40
oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00D0[Jf]0>nH403_V100kiP@000000020>nH
40030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA00H0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4@030000003oYQ40ojHA
0080ojHA0P00000;0?nV4@8000000P3oYQ400`000000ojHA0?nV4@030?nV4@8000001P3oYQ400`2]
[Jd0ojH@0?nV4002000000@0ojH@00<000000?nV403oYQ002P3oYQ000`000000ojH@000000020?nV
408000000P3oYQ00102][Jd0000000000000000<0?nU408000002@3oYA02000000030?nU40000000
[Jf]00H0oj<@0P0000000`3oXa0000000?nS40060?nS40030000003oXa00000000L0oj<@0P000009
0?bP408000001P3lX102000000<0o:0@1@2][Jd2000000D0mY`?0`00000;0?JL3`030:f][@3/UPh0
k9H>00H0k9H>00<000000>bF3P3/UPh01`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]103KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00D0[Jf]0>nH403_V100kiP@000000020:f][@L0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]603oYQ400`2][Jd0ojHA
0?nV4@0D0?nV4@030000003oYQ40ojHA0080ojHA0P00000;0?nV4@8000000`3oYQ400`000000ojHA
0?nV4@020?nV4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0?nV403oYQ000P3oYQ04000000d0ojH@
00<000000?nV40000000103oYQ04000000h0ojD@0P0000090?nU408000000P3oYA000`000000oj<@
0?nS40040?nS408000000P3oXa000`000000oj<@0?nS40040?nS40800000203oXa02000000T0o:0@
00<000000?bP403lX1001@3lX102000000H0o:0@00@0[Jf]0?JL3`00000000000P2][Jd30?JL3`80
000000@0mY`?0000000000000000203fW0l00`2][Jd0k9H>0>bF3P050>bF3P8000002@3/UPh00`2]
[Jd0fhX=0=^:3@070=^:3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H7
08QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@0[Jf]
0>nH403_V100[Jf]0P0000080>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403P3o
Y1440:f][@030?nT4@2][Jd0ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40503oYQ400`000000ojHA0?nV
4@020?nV4@800000203oYQ45000000@0ojHA1@0000070?nV4@030:f][@3oYQ00ojH@01<0ojH@00<0
00000?nV400000001P3oYQ000`2][Jd0ojD@0?nU40090?nU40H000001P3oYA02000000030?nU4000
000000000080ojD@00<0[Jf]0000000000000`3oXa02000000<0oj<@00<000000?nS403oXa00103o
Xa02000000T0oj<@0P0000080?bP40030000003lX100o:0@00D0o:0@0P0000060?bP40040:f][@3f
W0l0000000000080mY`?0`2][Jd2000000@0mY`?0`0000000`3fW0l000000?JL3`020?JL3`030:f]
[@3/UPh0k9H>00@0k9H>00<000000>bF3P0000002@3/UPh00`2][Jd0fhX=0=^:3@090=^:3@<0[Jf]
2@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00<0
[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P050=>73P060000002][Jd0[Jf]0:f][@3_V100
00002@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00X0oj@A102][Jd50?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4010000000ojHA0?nV4@3oYQ420000
01d0ojHA00<0[Jf]0?nV403oYQ004`3oYQ000`000000ojH@000000060?nV40030:f][@3oYA00ojD@
01L0ojD@0`0000020?nU40030:f][@3oXa00oj<@00<000001P3oXa02000000<0oj<@0`0000090?nS
408000001`3lX102000000L0o:0@0P0000060?bP40040:f][@3fW0l00000000000D0mY`?0P000003
0:f][@@0mY`?0P0000030?JL3`030:f][@3/UPh0k9H>00<0k9H>00<000000>bF3P0000002P3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01`3CQ`h2
000000050:f][@3_V100kiP@0>nH400000002@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A00L0oj@A0`2][Jd90?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405@3o
YQ401P000000ojHA0?nV4@000000[Jf]000001d0ojHA00<0[Jf]0?nV403oYQ004`3oYQ000`000000
ojH@000000060?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa04000000/0
oj<@00<0[Jf]0000000000001P3lX1000`000000o:0@0?bP40060?bP408000001P3lX1000`2][Jd0
mY`?00000002000000D0mY`?0P0000020?JL3`@0[Jf]00<0mY`?0000003fW0l00P3fW0l00`2][Jd0
k9H>0>bF3P020>bF3P030000003/UPh0000000/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@P0
^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h01@000000dhL>0000002][Jd0000000`0kiP@00<0[Jf]0?bP
403lX100403lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]303oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030:f][@3oYQ40ojHA01D0ojHA00<000000?nV4@3oYQ400P00000N0?nV4@030:f][@3oYQ00ojH@
01<0ojH@00<000000?nV400000001P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00@0[Jf]0?bP4000000000001@3lX1000`000000o:0@0?bP40070?bP408000001@3lX100
0`2][Jd0mY`?00000002000000D0mY`?0P0000060?JL3`060:f][@000000[Jf]0:f][@3fW0l0[Jf]
0`3/UPh00`000000k9H>0000000<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2][Jd0
[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80000000@0[Jf]0=>73P2][Jd000002`3_V1000`2]
[Jd0o:0@0?bP400@0?bP40030:f][@3oY140[Jf]00<0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01H0ojHA00<000000?nV4@3oYQ400P00000N0?nV4@030:f][@3oYQ00ojH@
01<0ojH@00<000000?nV400000001P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00@0[Jf]0?bP403lX100o:0@0P0000020?bP40030000003lX100o:0@00P0o:0@0P000005
0?bP40030:f][@000000mY`?008000001@3fW0l2000000L0mY`?0P000000203fW0l0[Jf]0:f][@2]
[Jd0k9H>0000003/UPh000002@3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00d0fhX=00D0[Jf]0;Ue
2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00@000000=>73P00000000000P3C
Q`h00`2][Jd000000>nH400:0>nH40030:f][@3lX100o:0@00l0o:0@0`2][JdD0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ400`000000ojHA0?nV4@02000001h0ojHA00<0
[Jf]0?nV403oYQ004`3oYQ000`000000ojH@000000060?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40030?bP40800000303lX102000000@0o:0@00<0
[Jf]0000003fW0l00P0000050?JL3`8000001`3fW0l200000080mY`?00D0[Jf]0>bF3P000000[Jf]
0000000:0>bF3P050000003/UPh0k9H>0>bF3P2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`03
0:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P040000003CQ`h0[Jf]000000<0dhL>00<0[Jf]0000
003_V1002P3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]00<0o:0@0:f][@3oY140503oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA00<000000?nV4@3oYQ400P00000N0?nV
4@030:f][@3oYQ00ojH@01<0ojH@00<000000?nV400000001P3oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1004P3lX102000000<0o:0@00<0[Jf]0000
003fW0l00P0000060?JL3`8000001P3fW0l200000080mY`?00D0[Jf]0>bF3P00000000000>bF3P02
0:f][@P0k9H>00D000000>bF3P3/UPh0k9H>0:f][@0=0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0
[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;09MP
2`2GH0/0[Jf]0=>73P80000000<0[Jf]0=>73P0000000`3CQ`h00`000000kiP@0>nH400:0>nH4003
0:f][@3lX100o:0@00X0o:0@0P2][Jd40?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0G0?nV4@040000003oYQ400000000001h0ojHA00<0[Jf]0?nV
403oYQ004`3oYQ000`000000ojH@000000060?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400D0?bP40040000003lX100o:0@00000080mY`?0P000006
0?JL3`8000001P3fW0l01`000000mY`?0?JL3`3fW0l0[Jf]0>bF3P000000103/UPh30:f][@D0k9H>
00D000000>bF3P3/UPh0k9H>0:f][@0=0=^:3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0
[Jf]08QF1`0308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0
00000P3CQ`h01@000000dhL>0=>73P3CQ`h0000000`0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f]
[@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01L0ojHA0`0000000`2][Jd0ojHA0?nV4@0E0?nV4Ad0[Jf]00<000000:f][@0000003P2][JdG0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX102000000030?bP402][Jd0mY`?
008000001`3fW0l2000000@0mY`?0P0000030?JL3`030:f][@3/UPh0000000L0k9H>0`2][Jd20>bF
3P050000003/UPh0k9H>0>bF3P2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL2
0:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@0300000080dhL>00D00000
0=>73P3CQ`h0dhL>0000000<0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd90?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0G0?nV4@<0000000<0
[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA00<0[Jf]0?nV403oYQ004`3oYQ000`000000ojH@0000
00060?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100603lX100102][Jd0mY`?0000000000070?JL3`800000103fW0l00`000000mY`?
0?JL3`020?JL3`030:f][@3/UPh0000000L0k9H>00<000000>bF3P3/UPh00P2][Jd01@000000k9H>
0>bF3P3/UPh0[Jf]00d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`03
0:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0000003CQ`h20000
0080dhL>00D000000=>73P3CQ`h0dhL>0000000<0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd<
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F
0?nV4@040:f][@0000000000000000P0[Jf]5`3oYQ400`2][Jd0ojH@0?nV400C0?nV40030000003o
YQ00000000H0ojH@00<0[Jf]0?nU403oYA003@3oYA000`000000ojD@0?nU40050?nU40`0[Jf]603o
Xa000`2][Jd0o:0@0?bP400H0?bP40040:f][@3fW0l00000000000P0mY`?00<000000?JL3`3fW0l0
0P3fW0l00`000000mY`?0?JL3`020?JL3`030:f][@3/UPh0000000L0k9H>00<000000>bF3P3/UPh0
0P3/UPh01@000000[Jf]0:f][@3/UPh0[Jf]00h0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0
R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0000002][Jd000000080
dhL>00@000000=>73P3CQ`h000000P3CQ`h00`2][Jd000000>nH400;0>nH40030:f][@3lX100[Jf]
0080[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV
4@3oYQ40303oYQ4:0:f][@050?nV4@000000ojHA0000002][Jd07P3oYQ400`2][Jd0ojH@0?nV400C
0?nV40030000003oYQ00000000H0ojH@00<0[Jf]0?nU403oYA00303oYA02000000h0ojD@00<0[Jf]
0?nS403oXa000P3oXa0:0:f][@h0oj<@00<0[Jf]0?bP403lX100603lX100102][Jd0mY`?00000000
00090?JL3`80000000<0mY`?0000003fW0l0103fW0l00`2][Jd0k9H>000000060>bF3P800000103/
UPh00`000000k9H>0>bF3P030:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H700<0
[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd000000000002][Jd000000080dhL>00<0
00000=>73P3CQ`h00`3CQ`h2000000<0kiP@00<000000>nH403_V1001P3_V1020:f][A40o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2]
[Jd;0?nV4@040000003oYQ4000000:f][Ah0ojHA00<0[Jf]0?nV403oYQ004`3oYQ000`000000ojH@
000000060?nV40030:f][@3oYA00ojD@00`0ojD@00<000000?nU400000003@3oYA000`2][Jd0oj<@
0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40040:f][@3fW0l00000000000/0
mY`?0P0000050?JL3`040:f][@3/UPh0k9H>000000D0k9H>0P0000040>bF3P060000003/UPh0k9H>
0>bF3P2][Jd0fhX=0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00`28
EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@000000000009MP2`0000000P3C
Q`h00`000000dhL>0=>73P030=>73P8000000`3_V1000`000000kiP@0>nH40040>nH40<0[Jf]4P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdF0?nV4@80000000<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400C0?nV40030000003oYQ00000000H0ojH@00<0
[Jf]0?nU403oYA00303oYA02000000h0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AL0o:0@00@0
[Jf]0?JL3`00000000004P3fW0l0102][Jd0k9H>0>bF3P0000050>bF3P800000103/UPh01@000000
k9H>0>bF3P3/UPh0[Jf]00<0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF
1`28EPL0[Jf]0P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050000002GH0/00000
09MP2`0000000P3CQ`h00`000000dhL>0=>73P030=>73P030000003_V100kiP@0080kiP@00<00000
0>nH403_V1000P3_V1020:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D
0?nT4@030:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA01P0ojHA00<00000
0?nV4@2][Jd07P3oYQ400`2][Jd0ojH@0?nV400@0?nV40H000001P3oYQ000`2][Jd0ojD@0?nU400=
0?nU40030000003oYA00ojD@00`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403l
X1070:f][A00o:0@00@0[Jf]0?JL3`00000000004`3fW0l0102][Jd0k9H>0>bF3P0000040>bF3P80
0000103/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00D0fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;
00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005P0/>3V0P000000
102][Jd0000009MP2`0000020=>73P030000003CQ`h0dhL>0080dhL>0P0000040>nH40030000003_
V100kiP@0080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0
[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ40603oYQ400`000000ojHA0:f]
[@0N0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@00P0o:0@1P2][Jd:0?bP40040:f][@3fW0l00000000001<0mY`?
00<0[Jf]0>bF3P3/UPh00P0000020>bF3P030000003/UPh0000000@0k9H>00D000000>bF3P3/UPh0
k9H>0:f][@070=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H708QF
1`2][Jd0R5H70:f][@120;3PiP40oooo001H0;3PiP@0000000D0Uf0;0000003CQ`h0dhL>00000004
0=>73P800000103_V1000`000000[Jf]0:f][@060>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ40603o
YQ400`000000ojHA0:f][@0N0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1`2][Jd30?bP40040:f][@3f
W0l00000000001<0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh200000080k9H>00<000000>bF3P3/UPh0
0P3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00T0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V0P00000209MP2`040000
003CQ`h0dhL>000000<0dhL>0P0000001P2][Jd0kiP@0>nH403_V100[Jf]000000P0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@D0[Jf]5P3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1050:f][@8000004`3fW0l0
0`2][Jd0k9H>0>bF3P0;0>bF3P8000000P3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=
0:f][@2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool0
05P0/>3V00<0[Jf]0000000000000P2GH0/010000000dhL>0=>73P0000030=>73P80000000H0[Jf]
0>nH402][Jd0[Jf]0>nH400000080>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
3`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00@0[Jf]0?JL3`00000000000`2][Jd@0?JL3`03
0:f][@3/UPh0k9H>00/0k9H>0P0000020>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue2`03
0:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP040000002][Jd0000000000080
Uf0;00@000000=>73P00000000000P3CQ`h2000000030=>73P2][Jd0[Jf]00<0kiP@00<000000>nH
403_V1001P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00@0[Jf]0?JL3`00000000000`3fW0l50:f][@/0mY`?00<0[Jf]
0>bF3P3/UPh02`3/UPh200000080k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][@P0^GD;00<0[Jf]
08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V00@000000:f][@00000000000P2GH0/0
0`000000dhL>000000030=>73P8000000P2][Jd01@000000kiP@0>nH403_V100000000P0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40040:f][@3fW0l00000000000P0mY`?1@2][Jd60?JL3`030:f][@3/UPh0k9H>00/0k9H>
0P0000020>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0
R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H010000000[Jf]00000000000209MP2`03
0000003CQ`h0000000<0dhL>00D000000:f][@3CQ`h0[Jf]000000030>nH40030000003_V100kiP@
00H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40040:f][@3fW0l00000000000d0mY`?102][Jd20?JL3`030:f][@3/UPh0
k9H>00/0k9H>0P0000030>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f]
[@050;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP040000002][Jd0
000000000080Uf0;00<000000=>73P0000000P3CQ`h200000080dhL>0P0000030>nH40030000003_
V100kiP@00H0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1005`3lX102000000030?JL3`00000000000140mY`?102][Jd<0>bF3P8000000`3/
UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H010000000[Jf]00000000
000209MP2`060000003CQ`h000000=>73P2][Jd000000`3CQ`h200000080kiP@0P0000080>nH4003
0:f][@3lX100o:0@00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00@0[Jf]00000000
000000004`3fW0l00`2][Jd0k9H>0:f][@020:f][@T0k9H>0P0000030>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je1
0;3PiP40oooo001G0;3PiP040000002][Jd0000000000080Uf0;00H000000=>73P000000[Jf]0=>7
3P0000030=>73P8000000P3_V1000`000000kiP@0>nH40070>nH40030:f][@3lX100o:0@00`0o:0@
0P2][Jd00`3lX100[Jf]0?nT4@0E0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]1`3/UPh2000000<0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL00`28EPL20:f][D40/>3V
0@3oool005L0/>3V00D000000:f][@000000000009MP2`02000000050=>73P000000dhL>0=>73P00
00000`3CQ`h200000080kiP@00<000000>nH403_V1001`3_V1000`2][Jd0o:0@0?bP40090?bP40<0
[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]103/UPh2000000<0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL20:f][D40/>3V0@3oool005L0/>3V
00H000000:f][@000000000009MP2`0000020:f][@040000003CQ`h0dhL>000000<0dhL>0P000002
0>nH40030000003_V100kiP@00L0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0[Jf]
0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh01`3/UPh30:f][@070>bF3P00000000000>bF3P11JN40k9H>0:f][@0=0=^:3@030:f]
[@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V00T0
00000:f][@000000000009MP2`000000[Jf]0=>73P0000000P3CQ`h01P000000dhL>0=>73P000000
[Jf]00000080kiP@00<000000>nH403_V1001`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P030:f][@00
0000000000<0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28
EPL20:f][D40/>3V0@3oool005L0/>3V00T000000:f][@000000000009MP2`000000[Jf]0=>73P00
00000`3CQ`h00`000000dhL>000000040>nH40030000003_V100kiP@00L0kiP@00@0[Jf]0?bP403l
X100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0;0>bF3P8000000P2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/0^GD;
00H0^GD;0P2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000080:f][@000000000009MP
2`000000[Jf]0=>73P0000030=>73P80000000<0[Jf]0>nH403_V1000P3_V1000`000000kiP@0>nH
40070>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh200000080k9H>
0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00P28EPL20:f][D40/>3V
0@3oool005H0/>3V0P000000202][Jd000000000002][Jd000000:f][@3CQ`h000001@3CQ`h00`2]
[Jd0kiP@0>nH40020>nH40030000003_V100kiP@00H0kiP@0`2][Jd@0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f]
[@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00/0k9H>0P0000030>bF3P040:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0
0`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H50000000509MP2`000000[Jf]
0=>73P0000001@3CQ`h00`2][Jd0kiP@0>nH40020>nH40030000003_V100kiP@00@0kiP@0P2][Jd0
0`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ40
0`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0<0>bF3P050000003/UPh0k9H>0>bF3P2][Jd00`3KRPd20:f][@T0fhX=00<0
[Jf]0;Ue2`2iM@/01P2iM@/01@2][Jd0R5H708QF1`2][Jd0R5H70080[Jf]@@2`h>H10?ooo`00EP2`
h>H50000000509MP2`000000[Jf]0=>73P0000001@3CQ`h00`2][Jd0kiP@0>nH40020>nH40030000
003_V100kiP@0080kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l0
5@3fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P050000003/UPh0k9H>0>bF3P2][Jd01@3KRPd20:f][@L0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL30:f][D40/>3V0@3oool005H0
/>3V1@0000000`2GH0/000000:f][@02000000D0dhL>00<0[Jf]0>nH403_V1000P3_V1000`000000
kiP@0>nH40020:f][@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2i
M@/01P2iM@/0102][Jd0R5H708QF1`28EPL30:f][D40/>3V0@3oool005H0/>3V1@000000102GH0/0
00000:f][@0000060=>73P030:f][@3_V100kiP@0080kiP@00<000000:f][@2][Jd01`3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f]
[Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0R5H7
0080R5H70P2][Je10;3PiP40oooo001F0;3PiPD0000000<0Uf0;0000002][Jd01`3CQ`h01P2][Jd0
kiP@0>nH403_V100[Jf]000000T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue
2`080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H7000000P0dhL>00H0
[Jf]0>nH402][Jd0[Jf]0>nH400000090>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd20:f][@T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP<0
000000@0Uf0;000000000000[Jf]203CQ`h20:f][@<0kiP@00<000000>nH403_V1001`3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd70;Ue2`040:f][@28EPL0R5H7
08QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H30000000409MP2`000000Uf0;0:f][@L0dhL>0P2][Jd4
0>nH40030000003_V100kiP@00L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@09
0?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<
0=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo
001F0;3PiP@000000P2GH0/00`2][Jd0dhL>0=>73P030=>73P80[Jf]00<0dhL>0:f][@3_V1000`3_
V1000`000000kiP@0>nH40060>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103o
Y1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40
oooo001F0;3PiP<000000`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0dhL>0=>73P2]
[Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080
^GD;0P2][Jd30;Ue2`060:f][@28EPL0R5H708QF1`2][Jd0@FWQ@@2`h>H10?ooo`00EP2`h>H30000
00<0Uf0;00D0[Jf]0=>73P3CQ`h0dhL>0:f][@040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/0102iM@/0102][Jd0^GD;0;Ue2`2][Jd308QF1`030:f][@11JN40/>3V0400/>3V0@3o
ool005H0/>3V0P0000001P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1@3CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;0`2][Jd308QF1`030:f][@11JN40/>3V0400/>3V
0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f]
[@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2G
H0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3l
X1030:f][@P0^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F
0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]
0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/3
0:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL0
0`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd80=>7
3P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;Vb
YP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh
00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]
0080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H01`000000[Jf]09MP2`2GH0/0[Jf]
09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]1P2aZid0
0`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@28EPL0[Jf]0080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H01000
0000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V103
0:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H4
0:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL0R5H70:f][@28EPL0[Jf]@@2`h>H10?ooo`00EP2`
h>H010000000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]
d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080[Jf]
2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00
EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
1P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]
b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]
1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00
EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
0`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D00/>3V0@3oool005H0/>3V
00<000000:f][@2GH0/00`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080
[Jf]102TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0
a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0
_[Vh00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H7
0080R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3C
Q`h01`3CQ`h0102][Jd0kiP@0:f][@2][Jd60:BNS`030:f][@2aZid0/J^M00@0/J^M0P2][Jd50;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j
/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a045Yh@11JN420:f][@030=^:3@2]
[Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`
h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01`3CQ`h20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid01P2a
Zid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]202n^KP2045Yh@040:f][@2d/;40@FWQ045Yh@80
];2a0P2][Jd:0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`000000
/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]045Yh@2TWXl0202TWXl00`2][Jd0
/J^M0;6[W@080;6[W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@L0_[Vh1@11JN40102][Jd0
];2a045Yh@11JN440;B`/@80[Jf]202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool0
05D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P040=>73P80[Jf]2`2TWXl00`2]
[Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0
_[Vh00H0_[Vh00<0@FWQ0;ji^02n^KP00`11JN40102][Jd0];2a045Yh@11JN450;B`/@03045Yh@2]
[Jd0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`
h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0@FWQ0:f][@0:0:BNS`030:f][@2a
Zid0/J^M00`0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2]
[Jd40<>m^`030:f][@2n^KP0_[Vh00D0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN40102n^KP0[Jf]
045Yh@11JN470;B`/@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0
/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P020=>73P040:f][@11JN40RXEe0:f]
[@@0Y9j?00<0@FWQ0:BNS`2TWXl00`2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V
00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f][A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh
00D0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN40102n^KP0[Jf]045Yh@11JN460;B`/@D0[Jf]0`2i
M@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2G
H0/0202][Jd0dhL>0=>73P3CQ`h0[Jf]08Z5M@11JN40RXEe0`2][Jd20:BNS`03045Yh@2TWXl0Y9j?
00<0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m
^`03045Yh@2n^KP0_[Vh00@0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP00`11JN40_[Vh0:f][@02045Y
h@D0];2a00L0[Jf]0;B`/@2d/;40[Jf]045Yh@2OVj00[Jf]0080^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]
0P2:QGD02011JN40RXEe0:f][@2TWXl0@FWQ0:f][@2TWXl0@FWQ1@2TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA
0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00l0a/2l0`2][Jd>0<>m^`03045Yh@2n^KP0_[Vh00@0_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP0
1@11JN40_[Vh0:f][@2d/;40@FWQ00<0];2a0P2][Jd01`2d/;40@FWQ0;B`/@2][Jd0@FWQ09nKX011
JN400`2][Jd408QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/0
0`2GH0/20:f][@@0RXEe00<0@FWQ08Z5M@2][Jd00P11JN400`2TWXl0[Jf]045Yh@050:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
2@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0_02][Jd0`kfk00X0`kfk
00D0@FWQ0<>m^`33_K/0`kfk045Yh@060;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00H0@FWQ0;ji^02]
[Jd0];2a045Yh@2d/;420:f][@<0];2a00@0@FWQ0;B`/@2][Jd0@FWQ102OVj000`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00`2GH0/0
0`2][Jd0RXEe08Z5M@0308Z5M@03045Yh@2:QGD0[Jf]0080@FWQ0P2TWXl00`11JN40[Jf]0:f][@03
0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH00P2i/ZH3045Yh@T0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jd50<K0_0030:f][@33_K/0
`kfk00T0`kfk00@0@FWQ0<>m^`33_K/0`kfk0P11JN440;ji^080@FWQ1@2n^KP2045Yh@040:f][@2d
/;40@FWQ0:f][@D0];2a00<0@FWQ0;B`/@11JN401P2OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400
/>3V0@3oool005D0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@H0RXEe00@0@FWQ0:f][@11JN40
@FWQ0P2TWXl01011JN40Y9j?0:BNS`2][Jd20:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;Vb
YP2i/ZH0102i/ZH3045Yh@L0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j
/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/00`33_K/2045Yh@@0`kfk00@0@FWQ0<>m
^`33_K/0`kfk0P11JN440;ji^080@FWQ102n^KP2045Yh@030;ji^02][Jd0[Jf]0080@FWQ00<0];2a
045Yh@2d/;400P2d/;42045Yh@030:f][@2OVj00Wi^P00@0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f]
[@100;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd708Z5M@03045Yh@2TWXl0
@FWQ0080Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?0`2][Jd>0;6[W@030:f][@2i/ZH0^K:V00@0^K:V00<0
@FWQ0;VbYP2i/ZH00P11JN450;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31
^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36
`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk045Yh@020<>m^`03045Yh@33_K/0`kfk00@0`kfk00<0
@FWQ0<>m^`33_K/00`11JN440;ji^003045Yh@2n^KP0_[Vh0080_[Vh00<0@FWQ0;ji^02n^KP00P2]
[Jd0102d/;40@FWQ045Yh@2d/;42045Yh@@0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0R5H7
08QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1`2:QGD0102][Jd0Y9j?
045Yh@2TWXl2045Yh@D0Y9j?0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V00@0^K:V00<0@FWQ0;VbYP2i
/ZH00P2i/ZH2045Yh@<0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]4@36`;`2045Yh@04
0<>m^`11JN40`kfk045Yh@H0`kfk00<0@FWQ0<>m^`33_K/00`11JN440;ji^003045Yh@2n^KP0_[Vh
00<0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@02045Yh@80];2a00<0@FWQ0;B`/@2d/;400P2d/;400`2]
[Jd0Wi^P09nKX00509nKX080[Jf]00<0R5H70:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102][Jd0
Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl2045Yh@D0Y9j?00@0[Jf]0;6[
W@2][Jd0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP040;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN43
0;VbYP040:f][@11JN40@FWQ045Yh@h0_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`03P36`;`2045Yh@030:f][@33
_K/0`kfk00<0@FWQ1@33_K/3045Yh@040<>m^`11JN40@FWQ045Yh@@0_[Vh00@0@FWQ0;ji^02n^KP0
_[Vh0P2][Jd30;ji^0070:f][@2d/;40@FWQ0;B`/@11JN40];2a045Yh@040;B`/@030:f][@2OVj00
Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C00<0[Jf]
08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`020:BNS`80@FWQ1@2TWXl0102][Jd0/J^M0;6[W@2a
Zid30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ0P2i
/ZH00`2][Jd0_[N/0;jg[003045Yh@d0_[N/00<0[Jf]0<6j/031^[001@2][Jd<0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`03P36
`;`2045Yh@040:f][@33_K/0`kfk0<>m^`80@FWQ1@33_K/3045Yh@040<>m^`11JN40@FWQ045Yh@@0
_[Vh00@0@FWQ0:f][@2][Jd0[Jf]1@2n^KP0102][Jd0];2a045Yh@2d/;42045Yh@D0];2a00<0[Jf]
09nKX02OVj00102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=P
D`80[Jf]1@2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`80@FWQ1@2TWXl00`2][Jd0/J^M0;6[W@040;6[
W@80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP040;VbYP03045Yh@2i/ZH0^K:V00<0^K:V0P11JN420;Vb
YP040:f][@2n]j`0_[N/045Yh@l0_[N/00<0[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]0<K0_036`;`00`36`;`3
045Yh@P0a/2l00<0@FWQ0<K0_02][Jd00`33_K/2045Yh@D0`kfk0`11JN401@33_K/0@FWQ045Yh@2]
[Jd0@FWQ0080_[Vh00<0[Jf]045Yh@2n^KP01`2n^KP00`2][Jd0];2a045Yh@080;B`/@030:f][@2O
Vj00Wi^P00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?0080Y9j?0P11JN45
0:BNS`030:f][@2aZid0/J^M00H0/J^M0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00@0^K:V00<0@FWQ
0;VbYP2i/ZH00`2i/ZH2045Yh@030;VbYP2][Jd0_[N/0080_[N/00<0@FWQ0;jg[02n]j`03@2n]j`0
0`2][Jd0`KZ`0<6j/00:0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`0
102][Jd0a/2l0<K0_036`;`3045Yh@X0a/2l00<0@FWQ0<K0_02][Jd00`33_K/2045Yh@D0`kfk0`11
JN401@33_K/0@FWQ045Yh@2][Jd0@FWQ0080[Jf]00<0_[Vh045Yh@2n^KP01`2n^KP00`2][Jd0@FWQ
0;B`/@080;B`/@030:f][@2OVj00Wi^P0080Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@03
0:f][@2TWXl0Y9j?0080Y9j?0P11JN450:BNS`030:f][@2aZid0/J^M00T0/J^M0P2][Jd00`2aZid0
[Jf]0;VbYP050;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00<0@FWQ0;VbYP2][Jd00`2n]j`00`11JN40
_[N/0;jg[0080;jg[0H0@FWQ4@31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00`0
al6l0P11JN430<O1_0030:f][@36`;`0a/2l00<0a/2l00<0@FWQ0<K0_036`;`02036`;`00`11JN40
a/2l0:f][@030<>m^`80@FWQ1@33_K/3045Yh@050<>m^`11JN40[Jf]0:f][@11JN400`2n^KP2045Y
h@L0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^
N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:
QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?0080Y9j?0P11JN450:BNS`030:f][@2aZid0/J^M
00/0/J^M0`2][Jd50;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00<0@FWQ0;VbYP2][Jd00`2n]j`00`11
JN40_[N/0;jg[0080;jg[080@FWQ0`2n]j`0102][Jd0@FWQ0<6j/031^[02045Yh@h0`KZ`00<0[Jf]
0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`03
0<Jo]`L0@FWQ2`36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`02037
`K`4045Yh@80al6l0P11JN400`37`K`0[Jf]0<K0_0040<K0_003045Yh@36`;`0a/2l00P0a/2l00<0
@FWQ0<K0_02][Jd00`33_K/2045Yh@D0`kfk00P0@FWQ0<>m^`11JN40[Jf]045Yh@33_K/0[Jf]045Y
h@<0_[Vh0P11JN470;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2]
[Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0
RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00@0Y9j?0P11JN450:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2][Jd00P2][Jd20;VbYP03045Yh@2i/ZH0^K:V00@0^K:V00<0@FWQ0;VbYP2]
[Jd00`2n]j`00`11JN40_[N/0;jg[0080;jg[003045Yh@2n]j`0_[N/0080_[N/00<0[Jf]045Yh@31
^[000P11JN470<6j/003045Yh@31^[00`KZ`00D0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40
aKje00<0[Jf]0<Jo]`36_kL01P36_kL2045Yh@d0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00H0
al6l1011JN450<O1_080@FWQ00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0080<K0_003
045Yh@36`;`0[Jf]00<0`kfk0P11JN440<>m^`090:f][@11JN40[Jf]045Yh@33_K/0@FWQ0<>m^`2]
[Jd0@FWQ00<0_[Vh0P11JN450;ji^003045Yh@2n^KP0[Jf]00X0];2a0P2][Jd609nKX0030:f][@1`
KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0
RXEe00<0RXEe0P2][Jd40:BNS`80@FWQ1@2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0
^K:V0080^K:V0P2][Jd00`11JN40^K:V0;VbYP040;VbYP80@FWQ00D0[Jf]0;jg[02n]j`0_[N/045Y
h@0:0;jg[003045Yh@2n]j`0_[N/0080_[N/00@0[Jf]0<6j/011JN40@FWQ2031^[000`11JN40`KZ`
0<6j/0020<6j/004045Yh@31^[00`KZ`0:f][A@0`kfc0P0000050<Fn]@`0[Jf]1@35_[D00`2][Jd0
a[ng0<Jo]`060<Jo]`80@FWQ3@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_0080<O1_080@FWQ1P37`K`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`02036`;`2045Yh@03
0:f][@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`33_K/00P2][Jd00`33_K/0@FWQ0<>m^`03045Yh@04
0<>m^`2][Jd0_[Vh045Yh@80_[Vh0P11JN450;ji^003045Yh@2n^KP0[Jf]00X0];2a00<0[Jf]09nK
X02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=P
D`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0@FWQ0:BN
S`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00@0^K:V00<0@FWQ0:f]
[@2][Jd00P2][Jd20;VbYP80@FWQ00<0[Jf]0;jg[02n]j`00P11JN4:0;jg[005045Yh@2n]j`0_[N/
0;jg[02][Jd00P31^[02045Yh@L0`KZ`0P11JN440<6j/004045Yh@31^[00`KZ`0:f][AD0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[D>0:f][@80@FWQ00<0[Jf]0<Jo]`36_kL02P36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02037`K`2045Yh@H0al6l0P11JN450<K0_003045Yh@36`;`0a/2l00T0a/2l1`11
JN420:f][@80`kfk0P11JN420<>m^`80@FWQ00<0`kfk0:f][@2n^KP00P11JN400`2n^KP0@FWQ045Y
h@050;ji^003045Yh@2n^KP0[Jf]00P0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0
?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd20:BNS`03045Y
h@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP030;VbYP80@FWQ
102i/ZH20:f][@80@FWQ00<0[Jf]0;jg[02n]j`00P11JN4:0;jg[005045Yh@2n]j`0_[N/0;jg[02]
[Jd00P31^[02045Yh@L0`KZ`0P11JN440<6j/004045Yh@31^[00`KZ`0:f][@X0`kfc00<0@FWQ0<>m
/`33_K<02033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00H0a[ng0P11JN400`36
_kL0[Jf]0:f][@0^0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l00P0al6l0P11JN470<O1_003045Yh@36`;`0a/2l00<0a/2l00<0@FWQ0<K0
_036`;`02P36`;`00`2][Jd0`kfk0:f][@020:f][@03045Yh@33_K/0`kfk0080`kfk0P11JN420<>m
^`80@FWQ00@0`kfk0:f][@11JN40@FWQ0`2n^KP00`11JN40_[Vh0;ji^0030;ji^003045Yh@2n^KP0
[Jf]00L0];2a00@0[Jf]0;B`/@2d/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V
0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]
1`2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11JN460;VbYP80@FWQ
0P2][Jd00`2n]j`0@FWQ045Yh@0:0;jg[005045Yh@2n]j`0_[N/0;jg[02][Jd00P31^[02045Yh@L0
`KZ`0P11JN430<6j/005045Yh@31^[00@FWQ0<6j/02][Jd02033_K<2045Yh@030<>m/`11JN40@FWQ
0080`kfc0P11JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL01P36_kL2045Y
h@d0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0080<O1_080@FWQ1`37`K`00`11
JN40a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l00P0a/2l102][Jd30<>m^`03045Yh@33_K/0`kfk
0080`kfk0P11JN420<>m^`80@FWQ00<0`kfk045Yh@2n^KP0102n^KP00`11JN40_[Vh0;ji^0030;ji
^080@FWQ00<0[Jf]0;B`/@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2]
[Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD0
0`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP030;VbYP80@FWQ1P2i/ZH2045Yh@030:f][@2n]j`0[Jf]0080@FWQ00<0[Jf]
0;jg[02n]j`01`2n]j`2045Yh@80_[N/00<0[Jf]0<6j/031^[000P11JN470<6j/003045Yh@31^[00
@FWQ0080`KZ`0`11JN400`31^[00[Jf]0<>m/`060<>m/`03045Yh@33_K<0`kfc00<0`kfc1011JN44
0<>m/`H0@FWQ4@35_[D00`2][Jd0a[ng0<Jo]`060<Jo]`80@FWQ3@36_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/02@38`K/00`11JN40b<6k0<S1^`08
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`2045Yh@L0al6l00<0@FWQ
0<K0_036`;`00`36`;`2045Yh@@0a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk0080`kfk00<0@FWQ
0<>m^`33_K/00P33_K/3045Yh@050<>m^`11JN40`kfk0<>m^`2][Jd01@2n^KP00`11JN40_[Vh0;ji
^0020;ji^0<0@FWQ00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@03
0:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH00`2i/ZH2045Yh@H0^K:V0P11JN400`2][Jd0_[N/0;jg[003045Yh@@0[Jf]1P2n]j`01011JN40
_[N/0;jg[02][Jd20<6j/080@FWQ1P31^[02045Yh@040<6j/011JN40`KZ`0<6j/0<0@FWQ00<0`KZ`
0:f][@33_K<01@33_K<2045Yh@H0`kfc0`11JN440<>m/`040:f][@35_[D0@FWQ045Yh@h0aKje1011
JN400`35_[D0[Jf]0<Jo]`070<Jo]`80@FWQ3@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j1011JN470<S1^`80@FWQ2P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l00P0al6l0P11JN470<O1_080@FWQ1036`;`2045Yh@@0[Jf]1P36`;`00`11JN40[Jf]0<>m
^`030<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN450<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P11
JN430;ji^004045Yh@2n^KP0@FWQ0:f][@80];2a00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0Wi^P
09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd0
1`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f]
[@2i/ZH0^K:V00@0^K:V0P11JN460;VbYP80@FWQ00<0[Jf]0;jg[02n]j`00`11JN440;jg[0@0[Jf]
0`2n]j`00`11JN40_[N/0:f][@020<6j/080@FWQ1P31^[001011JN40`KZ`0<6j/011JN420<6j/0<0
@FWQ00<0`KZ`0:f][@33_K<01033_K<00`11JN40`kfc045Yh@070<>m/`80@FWQ1033_K<0102][Jd0
aKje045Yh@11JN4<0<Fn]@<0@FWQ0`35_[D00`11JN40[Jf]0<Jo]`020<Jo]`80@FWQ0`36_kL2045Y
h@80a[ng0`11JN480<Jo]`030:f][@37`KP0al6h01<0al6h0`11JN470<O1^P@0@FWQ2037`KX01011
JN40al6j045Yh@2][Jd30<S1^`80@FWQ1@38`K/00`11JN40b<6k045Yh@090<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`2045Yh@L0al6l0P11JN401036`;`0[Jf]0:f][@2]
[Jd2045Yh@X0a/2l00<0@FWQ0:f][@33_K/00P33_K/01011JN40`kfk0<>m^`33_K/2045Yh@L0`kfk
00<0[Jf]0;ji^02n^KP00`2n^KP2045Yh@80_[Vh00@0@FWQ0;ji^02n^KP0@FWQ0`2][Jd80;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C
0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd=0;6[W@030:f][@2i/ZH0^K:V00@0^K:V
0P11JN460;VbYP80@FWQ00<0[Jf]0;jg[02n]j`00`11JN430;jg[003045Yh@2n]j`0_[N/0080_[N/
102][Jd2045Yh@80`KZ`0P11JN460<6j/004045Yh@31^[00`KZ`045Yh@80`KZ`00D0@FWQ0<6j/011
JN40`KZ`0:f][@050<>m/`80@FWQ2033_K<2045Yh@@0`kfc00@0[Jf]0<Fn]@11JN40@FWQ3035_[D2
045Yh@D0aKje00@0@FWQ0<Jo]`11JN40@FWQ1@36_kL4045Yh@<0a[ng0P11JN460<Jo]`L0@FWQ0`37
`KP6045Yh@<0al6h1011JN400`2][Jd0al6j0<O1^P040<O1^P<0@FWQ0`37`KX2045Yh@H0al6j00@0
@FWQ0<O1^P11JN40[Jf]1@38`K/00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00P0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0080<O1_080@FWQ1@37`K`20:f][@80@FWQ
00@0[Jf]0<K0_036`;`0a/2l0P11JN440<K0_003045Yh@36`;`0a/2l00<0a/2l00D0@FWQ0:f][@33
_K/0`kfk045Yh@0=0<>m^`030:f][@2n^KP0_[Vh00@0_[Vh0P11JN40102n^KP0@FWQ0;ji^02n^KP2
0:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3P
iP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP040;Vb
YP80@FWQ1P2i/ZH2045Yh@030:f][@2n]j`0_[N/0080@FWQ00<0_[N/045Yh@2n]j`00P11JN480;jg
[080[Jf]1011JN460<6j/005045Yh@31^[00`KZ`045Yh@31^[000P11JN401031^[00@FWQ0<6j/02]
[Jd50<>m/`80@FWQ2033_K<2045Yh@@0`kfc00@0[Jf]0<Fn]@11JN40@FWQ3035_[D00`11JN40aKje
0<Fn]@040<Fn]@030:f][@11JN40@FWQ00H0a[ng0P11JN460<Jo]`80@FWQ1@36_kL00`2][Jd0al6h
0<O1^002045Yh@L0al6h0P11JN470<O1^080@FWQ00<0[Jf]0<O1^P37`KX00`37`KX2045Yh@H0al6j
00<0@FWQ0<O1^P37`KX01037`KX2045Yh@030<O1^P2][Jd0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/0
3P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00P0al6l0P11JN450:f][@80al6l
0P11JN440<K0_080@FWQ0`36`;`00`11JN40a/2l045Yh@050<K0_0<0@FWQ3P33_K/00`2][Jd0_[Vh
0;ji^0050;ji^080@FWQ00D0_[Vh0:f][@2][Jd0_[Vh0:f][@0:0;B`/@030:f][@2OVj00Wi^P00D0
Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f]
[@2aZid0[Jf]0080[Jf]2@2aZid00`2][Jd0^K:V0;VbYP040;VbYP80@FWQ1@2i/ZH2045Yh@030;Vb
YP2][Jd0@FWQ00<0@FWQ00H0_[N/045Yh@2n]j`0@FWQ0;jg[011JN440;jg[080@FWQ0P2n]j`00`2]
[Jd0`KZ`0<6j/002045Yh@D0[Jf]0P11JN420<6j/004045Yh@31^[00@FWQ045Yh@80`KZ`00<0@FWQ
0:f][@33_K<00`33_K<00`11JN40`kfc045Yh@080<>m/`80@FWQ1033_K<0102][Jd0aKje045Yh@11
JN4<0<Fn]@03045Yh@35_[D0aKje00@0aKje00<0[Jf]0<Jo]`11JN401P36_kL2045Yh@H0a[ng0P11
JN450<Jo]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@L0al6h0P11JN400`2][Jd0al6j0<O1
^P030<O1^P80@FWQ1`37`KX00`11JN40al6j0<O1^P030<O1^P04045Yh@37`KX0al6j0:f][@D0b<6k
00<0@FWQ0<S1^`38`K/03P38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l
0`2][Jd2045Yh@L0al6l0P11JN440<K0_0<0@FWQ0`36`;`2045Yh@D0a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0060;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;Vb
YP040;VbYP80@FWQ1@2i/ZH2045Yh@040;VbYP2][Jd0_[N/0;jg[080@FWQ0P2n]j`01011JN40_[N/
045Yh@11JN440;jg[080@FWQ0P2n]j`0102][Jd0`KZ`0<6j/011JN460<6j/080@FWQ0P2][Jd01011
JN40[Jf]045Yh@11JN420<6j/003045Yh@2][Jd0`kfc00<0`kfc0P11JN490<>m/`80@FWQ1033_K<0
102][Jd0aKje045Yh@11JN4<0<Fn]@03045Yh@35_[D0aKje00@0aKje00<0[Jf]0<Jo]`11JN401P36
_kL2045Yh@L0a[ng0P11JN440<Jo]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@L0al6h0P11
JN400`37`KP0[Jf]0<O1^P020<O1^P80@FWQ3P37`KX01011JN40al6j0<O1^P2][Jd50<S1^`03045Y
h@38`K/0b<6k00h0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@<0al6l
0P11JN470<O1_0030:f][@11JN40a/2l00<0a/2l0P11JN401@36`;`0@FWQ0<K0_036`;`0@FWQ00H0
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00
F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0102i/ZH2045Yh@D0^K:V0P11JN400`2i/ZH0[Jf]
0;jg[0060;jg[080@FWQ1P2n]j`01011JN40_[N/0;jg[02][Jd20<6j/003045Yh@31^[00`KZ`00@0
`KZ`0P11JN420<6j/004045Yh@31^[00@FWQ045Yh@80[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd00`33
_K<0@FWQ045Yh@090<>m/`80@FWQ1033_K<0102][Jd0aKje045Yh@11JN4<0<Fn]@03045Yh@35_[D0
aKje00@0aKje00<0[Jf]0<Jo]`11JN401P36_kL2045Yh@L0a[ng0P11JN440<Jo]`030:f][@37`KP0
al6h0080@FWQ1`37`KP2045Yh@L0al6h0P11JN400`37`KP0[Jf]0<O1^P020<O1^P80@FWQ4@37`KX0
0`2][Jd0b<6k0<S1^`020<S1^`80@FWQ4038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]2@37`K`0
0`11JN40al6l0<O1_0050<O1_0030:f][@11JN40a/2l00<0a/2l0P11JN420<K0_080@FWQ2036`;`0
0`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`
/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H0
0`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid3
0:f][@030;6[W@2][Jd0^K:V00D0^K:V0P11JN450;VbYP04045Yh@2i/ZH0^K:V0:f][@l0_[N/00H0
@FWQ0;jg[02n]j`0[Jf]0<6j/011JN470<6j/003045Yh@31^[00`KZ`0080`KZ`0`11JN420<6j/003
045Yh@2][Jd0`kfc0080`kfc00<0[Jf]045Yh@11JN40102][Jd30<>m/`H0@FWQ0P33_K<0102][Jd0
aKje045Yh@11JN4<0<Fn]@03045Yh@35_[D0aKje00@0aKje00<0[Jf]0<Jo]`11JN401P36_kL2045Y
h@P0a[ng00<0@FWQ0<Jo]`36_kL00P36_kL00`2][Jd0al6h0<O1^002045Yh@L0al6h0P11JN470<O1
^080@FWQ00<0al6h0:f][@37`KX00P37`KX00`11JN40al6j0<O1^P0@0<O1^P030:f][@38`K/0b<6k
00<0@FWQ1P38`K/00`11JN40b<6k0<S1^`080<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1
^`030:f][@37`K`0al6l00T0al6l00<0@FWQ0<O1_037`K`01@37`K`0102][Jd0@FWQ0<K0_036`;`3
045Yh@d0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d
/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M
0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:
0;6[W@<0[Jf]1@2i/ZH2045Yh@D0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]402n]j`4045Yh@L0`KZ`0P11
JN440<6j/080@FWQ0`31^[000`11JN40[Jf]0<>m/`030<>m/`80@FWQ1033_K<80:f][@<0`kfc00@0
[Jf]0<Fn]@11JN40@FWQ3035_[D2045Yh@D0aKje00<0[Jf]0<Jo]`11JN401P36_kL2045Yh@P0a[ng
00<0@FWQ0<Jo]`36_kL00P36_kL00`2][Jd0al6h0<O1^002045Yh@L0al6h0P11JN470<O1^080@FWQ
00<0al6h0:f][@37`KX00P37`KX00`11JN40al6j0<O1^P0@0<O1^P030:f][@11JN40@FWQ0080@FWQ
1`38`K/00`11JN40b<6k0<S1^`080<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0
al6l0<O1_0090<O1_003045Yh@37`K`0al6l00D0al6l00<0[Jf]045Yh@36`;`04@36`;`00`2][Jd0
`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080
[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]0080[Jf]1011JN440;VbYP05045Yh@2i/ZH0^K:V0;VbYP2]
[Jd04P2n]j`00`2][Jd0`KZ`0<6j/0060<6j/080@FWQ1031^[02045Yh@<0`KZ`00<0@FWQ0:f][@33
_K<00`33_K<2045Yh@`0`kfc1@2][Jd2045Yh@80[Jf]3035_[D3045Yh@80aKje00<0[Jf]045Yh@11
JN401P36_kL2045Yh@P0a[ng00<0@FWQ0<Jo]`36_kL00P36_kL00`2][Jd0al6h0<O1^002045Yh@L0
al6h0P11JN470<O1^080@FWQ00<0al6h0:f][@37`KX00P37`KX00`11JN40al6j0<O1^P0?0<O1^P80
@FWQ00<0b<6k045Yh@38`K/02038`K/00`11JN40b<6k0<S1^`030<S1^`T0[Jf]4P38`K/00`2][Jd0
al6l0<O1_0090<O1_003045Yh@37`K`0al6l00D0al6l0P11JN4B0<K0_0030:f][@33_K/0`kfk00T0
`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02]
[Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M
00<0[Jf]0;VbYP2i/ZH00`2i/ZH20:f][@H0@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`00@0`KZ`1P11JN420<6j/080@FWQ1031^[000`11JN40`kfc0<>m/`020<>m/`80@FWQ
3P33_K<00`000000[Jf]0<Fn]@03045Yh@030<Fn]@2][Jd0[Jf]00X0[Jf]0`35_[D2045Yh@030:f]
[@11JN40@FWQ00H0a[ng0P11JN480<Jo]`03045Yh@36_kL0a[ng0080a[ng00<0[Jf]0<O1^037`KP0
0P11JN470<O1^080@FWQ1`37`KP2045Yh@030<O1^02][Jd0al6j0080al6j00<0@FWQ0<O1^P37`KX0
3P37`KX01011JN40al6j045Yh@11JN440<S1^`H0[Jf]00<0@FWQ0:f][@2][Jd00`2][Jd50<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02@37`K`00`11JN40al6l0<O1_0050<O1_080
@FWQ4P36`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^003
0:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0/J^M
0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[003031^[02045Yh@@0`KZ`00<0@FWQ0<>m/`33_K<00P33_K<2045Yh@l0`kfc
00<0[Jf]0<Fn]@11JN400P11JN4=0<Fn]@D0[Jf]0`11JN460:f][@80@FWQ00<0[Jf]0<Jo]`36_kL0
1@36_kL00`11JN40a[ng0<Jo]`020<Jo]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@L0al6h
0P11JN400`37`KP0[Jf]0<O1^P020<O1^P03045Yh@37`KX0al6j00D0al6j0P2][Jd00`11JN40[Jf]
0:f][@040:f][@80@FWQ1P2][Jd00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00P0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0090<O1_003045Yh@37`K`0al6l00D0al6l
0P11JN4B0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh
00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP030:f][@2T
WXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0
^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0D0@FWQ0P33_K<2045Yh@l0`kfc00<0
[Jf]0<Fn]@11JN400P11JN440<Fn]@03045Yh@35_[D0aKje00/0aKje00<0[Jf]045Yh@11JN401P36
_kL2045Yh@030<Jo]`2][Jd0[Jf]00@0[Jf]0P11JN470:f][@80@FWQ1`2][Jd2045Yh@L0[Jf]0P11
JN450:f][@03045Yh@2][Jd0[Jf]00D0[Jf]00<0al6j045Yh@11JN401@37`KX2045Yh@030<O1^P2]
[Jd0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/00`38`K/00`11JN40b<6k0<S1^`080<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02@37`K`00`11JN40al6l0<O1_0040<O1_080@FWQ00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n
^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc0080`kfc0P11JN4?0<>m/`060:f][@35_[D0@FWQ045Yh@35_[D0@FWQ
0P35_[D00`11JN40aKje045Yh@050<Fn]@80@FWQ1@35_[D00`2][Jd0@FWQ0<Jo]`060<Jo]`80@FWQ
1`36_kL2045Yh@@0a[ng00<0[Jf]0<O1^037`KP00P11JN470<O1^080@FWQ1`37`KP2045Yh@030<O1
^02][Jd0al6j0080al6j0P11JN480<O1^P03045Yh@37`KX0al6j00<0al6j00@0@FWQ0<O1^P37`KX0
[Jf]1038`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/02038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l00T0al6l00<0@FWQ0<O1_037`K`01037`K`2045Yh@030:f][@36`;`0a/2l00h0
a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0
/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<00`33_K<2045Yh@h0`kfc00H0[Jf]0<Fn]@11JN40@FWQ0<Fn]@11JN430<Fn
]@80@FWQ1@35_[D2045Yh@D0aKje00<0[Jf]045Yh@36_kL01P36_kL2045Yh@L0a[ng0P11JN440<Jo
]`030:f][@37`KP0al6h0080@FWQ1`37`KP2045Yh@H0al6h00D00000045Yh@11JN40al6h0:f][@03
0<O1^P80@FWQ2037`KX00`11JN40al6j0<O1^P030<O1^P04045Yh@37`KX0al6j0:f][@@0b<6k0P11
JN450<S1^`03045Yh@38`K/0b<6k00P0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_0090<O1_003045Yh@37`K`0al6l00<0al6l0P11JN400`37`K`0[Jf]0<K0_00:0<K0_0D0[Jf]0P36
`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d
/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc00<0`kfc0P11JN490<>m/`03045Yh@33_K<0`kfc0080`kfc1011JN42
0<Fn]@@0@FWQ1`35_[D00`11JN40aKje0<Fn]@030<Fn]@030:f][@11JN40a[ng00H0a[ng0`11JN45
0<Jo]`80@FWQ1@36_kL00`2][Jd0al6h0<O1^002045Yh@H0al6h0P11JN480<O1^080@FWQ00<0al6h
0:f][@37`KX00`37`KX2045Yh@H0al6j00<0@FWQ0<O1^P37`KX01@37`KX00`11JN40al6j0:f][@03
0<S1^`<0@FWQ1@38`K/2045Yh@T0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_009
0<O1_003045Yh@37`K`0al6l00<0al6l0P11JN400`37`K`0[Jf]0<K0_0060<K0_0@0[Jf]1`36`;`0
0`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2]
[Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`030<>m/`80@FWQ2@33_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@35_[D0
aKje00l0aKje1P11JN480<Jo]`<0@FWQ1036_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP01011JN44
0<O1^080@FWQ2037`KP2045Yh@030<O1^02][Jd0al6j00@0al6j0P11JN450<O1^P03045Yh@37`KX0
al6j00H0al6j1@11JN420<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN490<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`02@37`K`00`11JN40al6l0<O1_0020<O1_080@FWQ0P37`K`0
0`2][Jd0a/2l0<K0_0050:f][@/0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0040:f][@2d/;40];2a0:f][E80/>3V0@3oool006/0/>3V0`2][Jd>0;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`01<0`KZ`00<0[Jf]
0<>m/`33_K<01033_K<2045Yh@L0`kfc0P11JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL00`36_kL5045Yh@030<Jo]`11JN40@FWQ00<0@FWQ1`36_kL00`2][Jd0al6h0<O1^002
045Yh@80al6h1@11JN470<O1^0@0@FWQ00<0al6h0:f][@37`KX01P37`KX5045Yh@X0al6j00<0[Jf]
0<S1^`38`K/02@38`K/2045Yh@T0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_009
0<O1_003045Yh@37`K`0@FWQ00<0@FWQ00<0al6l0:f][@2][Jd00`2][Jd@0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`50:f][A40`KZ`00<0[Jf]0<>m
/`33_K<01033_K<2045Yh@L0`kfc0P11JN440<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^002045YhA<0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`090<S1^`80@FWQ2@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00L0al6l1011JN450:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0_[Vh00X0_[Vh0P2][JeE0;3PiP40oooo001_0;3PiP80[Jf]2`2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd:0<6j
/0030:f][@33_K<0`kfc00D0`kfc0P11JN460<>m/`80@FWQ1033_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP00P11JN4C0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@T0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_0050<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0
[Jf]0`31^[000`2][Jd0`kfc0<>m/`050<>m/`80@FWQ1@33_K<3045Yh@@0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h0080@FWQ4`37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k0P11JN490<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`
1`2][Jd60<>m/`D0@FWQ0P33_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^002045YhA<0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ2@38`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]
4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
0P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]
1P33_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^002045YhA<0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`090<S1^`03045Yh@38`K/0b<6k00P0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033
_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h0080@FWQ4037`KP01011JN40al6h0<O1^02][JdF0<O1^P030:f][@38`K/0b<6k00T0b<6k
00<0@FWQ0<S1^`38`K/02038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40
oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04033_K<90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^002045Yh@l0al6h00D0@FWQ0<O1^011JN40al6h0:f][@0F0<O1^P030:f][@38`K/0b<6k00l0
b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
0`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL5045YhA00al6h00@0@FWQ0<O1^037`KP0
[Jf]5P37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0
[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng
00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00`33_K/30:f][F`0/>3V
0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36
_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j0100al6j00D00000
0<O1^P37`KX0al6j0:f][@0F0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00l0al6j00<00000
0<O1^P37`KX00P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f]
[@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3P
iPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00
`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f]
[@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
2@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I1
0:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53672 .33082 m
.52502 .3309 L
s
.51833 .3309 m
.50663 .33079 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50434 .32274 m
.5159 .32286 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55507 .33045 m
.55175 .33374 L
s
.55507 .33045 m
.55008 .33378 L
s
.5584 .33035 m
.55507 .33045 L
s
.48828 .33039 m
.48496 .33028 L
s
.49327 .33373 m
.48828 .33039 L
s
.5 Mabswid
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54919 .33552 m
.55008 .33378 L
s
.5 Mabswid
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5665 .34759 m
.56682 .34936 L
s
.568 .34659 m
.56848 .3493 L
s
.255 .412 .882 r
.52085 .33862 m
.52417 .34087 L
s
.51754 .33861 m
.52085 .33862 L
s
.52085 .33862 m
.52582 .34087 L
s
.51423 .34084 m
.51754 .33861 L
s
.54072 .33848 m
.55229 .33824 L
s
.52417 .34087 m
.52748 .34537 L
s
.52582 .34087 m
.52914 .34536 L
s
.49934 .33838 m
.50099 .33841 L
s
.51091 .34532 m
.51423 .34084 L
s
.49603 .34056 m
.49934 .33838 L
s
.49768 .3406 m
.49934 .33838 L
s
0 0 0 r
.58169 .33903 m
.58285 .33666 L
s
.58334 .33894 m
.58525 .33506 L
s
.255 .412 .882 r
.49602 .34507 m
.49768 .3406 L
s
.49436 .34503 m
.49603 .34056 L
s
0 0 0 r
.59382 .32933 m
.59646 .33172 L
s
.255 .412 .882 r
.48779 .33809 m
.49108 .34044 L
s
.48284 .33793 m
.48779 .33809 L
s
.52748 .34537 m
.52914 .35213 L
s
.52914 .34536 m
.5308 .35212 L
s
.55888 .33805 m
.5704 .33762 L
s
.49108 .34044 m
.49436 .34503 L
s
.47954 .34006 m
.48284 .33793 L
s
.47789 .34 m
.48284 .33793 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47787 .34451 m
.47954 .34006 L
s
.47622 .34445 m
.47789 .34 L
s
.52914 .35213 m
.52915 .35666 L
s
.5308 .35212 m
.53081 .35665 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6013 .324 m
.60133 .32728 L
s
.59968 .32519 m
.5997 .32743 L
s
.5 Mabswid
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57697 .33733 m
.58841 .33672 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49538 .36287 m
.49606 .359 L
s
.49726 .36177 m
.49773 .35906 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49596 .3609 m
.49602 .34507 L
s
.49429 .36539 m
.49436 .34503 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54597 .36115 m
.54684 .36608 L
s
.255 .412 .882 r
.47784 .34903 m
.47787 .34451 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51087 .37021 m
.51094 .32282 L
s
.50921 .37019 m
.50929 .32281 L
s
.54568 .33839 m
.54581 .38597 L
s
.54733 .33835 m
.54748 .38594 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56383 .33788 m
.56395 .36275 L
s
.56547 .33782 m
.5656 .36269 L
s
.52749 .36345 m
.52915 .35666 L
s
.4762 .34897 m
.47622 .34445 L
s
.52915 .36345 m
.53081 .35665 L
s
.47784 .34903 m
.47947 .35362 L
s
.4762 .34897 m
.47782 .35355 L
s
.44362 .33586 m
.45499 .33661 L
s
.52417 .368 m
.52749 .36345 L
s
.52583 .36799 m
.52915 .36345 L
s
.48275 .356 m
.49266 .35856 L
s
.49266 .35856 m
.49431 .36086 L
s
.51088 .36341 m
.5142 .36797 L
s
.47947 .35362 m
.48275 .356 L
s
.49429 .36539 m
.49596 .3609 L
s
.47782 .35355 m
.48275 .356 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54741 .36321 m
.55074 .36767 L
s
.52085 .37027 m
.52417 .368 L
s
.52085 .37027 m
.52583 .36799 L
s
.5142 .36797 m
.51752 .37026 L
s
.49263 .36762 m
.49429 .36539 L
s
.51752 .37026 m
.52085 .37027 L
s
.50423 .37013 m
.51087 .37021 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55074 .36767 m
.55571 .36982 L
s
0 0 0 r
.58265 .36634 m
.58524 .37119 L
s
.255 .412 .882 r
.56232 .36735 m
.56395 .36275 L
s
.48931 .36981 m
.49263 .36762 L
s
.59981 .33826 m
.60464 .33566 L
s
.5966 .343 m
.59981 .33826 L
s
.56397 .36729 m
.5656 .36269 L
s
0 0 0 r
.58391 .3655 m
.5869 .37111 L
s
.255 .412 .882 r
.47777 .36262 m
.47942 .36268 L
s
.47941 .36495 m
.47942 .36268 L
s
.47776 .36489 m
.47777 .36262 L
s
.60143 .33815 m
.60464 .33566 L
s
.59823 .3429 m
.60143 .33815 L
s
.59504 .3499 m
.5966 .343 L
s
.60464 .33566 m
.60787 .33541 L
s
.55571 .36982 m
.55903 .36972 L
s
.59666 .3498 m
.59823 .3429 L
s
.48269 .3696 m
.48931 .36981 L
s
.55903 .36972 m
.56232 .36735 L
s
.47776 .36489 m
.47939 .36722 L
s
.55903 .36972 m
.56397 .36729 L
s
.47939 .36722 m
.48269 .3696 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44983 .36805 m
.45011 .3363 L
s
.4482 .36795 m
.44849 .3362 L
s
.59504 .3499 m
.59508 .35444 L
s
.43374 .35328 m
.43394 .33513 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58351 .337 m
.58375 .36872 L
s
.58188 .33708 m
.58211 .3688 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59995 .35455 m
.59998 .3568 L
s
.60159 .35335 m
.60162 .35666 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59666 .3498 m
.59671 .35433 L
s
.60787 .33541 m
.61272 .3373 L
s
.46131 .36415 m
.46297 .36196 L
s
.46297 .36196 m
.46459 .36432 L
s
.43213 .35315 m
.43233 .335 L
s
.46457 .36659 m
.46459 .36432 L
s
.61272 .3373 m
.61599 .34157 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59508 .35444 m
.59677 .36115 L
s
.44995 .35441 m
.45152 .36133 L
s
.46131 .36415 m
.46293 .36651 L
s
.46292 .36878 m
.46457 .36659 L
s
.57718 .36903 m
.58375 .36872 L
s
.59671 .35433 m
.5984 .36104 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54082 .38605 m
.54748 .38594 L
s
.4291 .337 m
.43226 .3418 L
s
.42432 .33432 m
.4291 .337 L
s
.458 .36853 m
.46292 .36878 L
s
.45152 .36133 m
.45474 .36607 L
s
.42113 .33403 m
.42432 .33432 L
s
.45474 .36607 m
.458 .36853 L
s
.59677 .36115 m
.60006 .36549 L
s
.5984 .36104 m
.60169 .36538 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41792 .336 m
.42113 .33403 L
s
.41633 .33585 m
.42113 .33403 L
s
.42731 .35276 m
.43859 .35364 L
s
.62709 .33377 m
.62873 .33815 L
s
.62709 .33377 m
.6272 .34284 L
s
.44331 .36763 m
.44983 .36805 L
s
.60006 .36549 m
.60496 .36743 L
s
.58219 .38019 m
.58385 .38239 L
s
.58056 .38255 m
.58219 .38019 L
s
.41468 .34023 m
.41792 .336 L
s
.60169 .36538 m
.60496 .36743 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58056 .38255 m
.58222 .38475 L
s
.4131 .34008 m
.41633 .33585 L
s
.58222 .38475 m
.58385 .38239 L
s
.62873 .33815 m
.63029 .33573 L
s
.63029 .33573 m
.63343 .33314 L
s
.6272 .34284 m
.62873 .33815 L
s
.61453 .35532 m
.61617 .35747 L
s
.61295 .35773 m
.61453 .35532 L
s
.61295 .35773 m
.61458 .35988 L
s
.63343 .33314 m
.63973 .33248 L
s
.60496 .36743 m
.60982 .36708 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61617 .35747 m
.61619 .35975 L
s
.41304 .34462 m
.41468 .34023 L
s
.41145 .34447 m
.4131 .34008 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60982 .36708 m
.61302 .36456 L
s
.61302 .36456 m
.61619 .35975 L
s
.63973 .33248 m
.64291 .33441 L
s
.43342 .38293 m
.43357 .36922 L
s
.43188 .37595 m
.43357 .36922 L
s
.41136 .3513 m
.41304 .34462 L
s
.40978 .35114 m
.41145 .34447 L
s
.64291 .33441 m
.64451 .33651 L
s
.62894 .35407 m
.63209 .35149 L
s
.62738 .3565 m
.62894 .35407 L
s
.62738 .3565 m
.62744 .36106 L
s
.63209 .35149 m
.63993 .34613 L
s
.62897 .35635 m
.63212 .35377 L
s
.62741 .35878 m
.62897 .35635 L
s
.4286 .38027 m
.43188 .37595 L
s
.43188 .37595 m
.43342 .38293 L
s
.63212 .35377 m
.63996 .34841 L
s
.4112 .36271 m
.41136 .3513 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40613 .35485 m
.40615 .35351 L
s
.40774 .35397 m
.40774 .35371 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62744 .36106 m
.62906 .3632 L
s
.40962 .36255 m
.40978 .35114 L
s
.63993 .34613 m
.64304 .34351 L
s
.64304 .34351 m
.64458 .34106 L
s
.62906 .3632 m
.63227 .36518 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63996 .34841 m
.64308 .34579 L
s
.64451 .33651 m
.64461 .34334 L
s
.64308 .34579 m
.64461 .34334 L
s
.39281 .331 m
.39855 .36369 L
s
.38609 .36224 m
.39281 .331 L
s
.42374 .38217 m
.4286 .38027 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63227 .36518 m
.63861 .36456 L
s
.4112 .36271 m
.4127 .36972 L
s
.40962 .36255 m
.41111 .36957 L
s
.65537 .33294 m
.65688 .33047 L
s
.65537 .33294 m
.65695 .33502 L
s
.65688 .33047 m
.65846 .33255 L
s
.38764 .36243 m
.3927 .33783 L
s
.42053 .3819 m
.42374 .38217 L
s
.4127 .36972 m
.41423 .37445 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41111 .36957 m
.41264 .37431 L
s
.41736 .37933 m
.42053 .3819 L
s
.41576 .37918 m
.42053 .3819 L
s
.65695 .33502 m
.65846 .33255 L
s
.64328 .35949 m
.64478 .35475 L
s
.64478 .35475 m
.64492 .3639 L
s
.41423 .37445 m
.41736 .37933 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63861 .36456 m
.64174 .36195 L
s
.41264 .37431 m
.41576 .37918 L
s
.64174 .36195 m
.64328 .35949 L
s
.64328 .35949 m
.64492 .3639 L
s
.39386 .36317 m
.40327 .3642 L
s
.38048 .32941 m
.38609 .36224 L
s
.3738 .36066 m
.38048 .32941 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37533 .36086 m
.38036 .33626 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65604 .37415 m
.65714 .34644 L
s
.65714 .34644 m
.65915 .37378 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65737 .36018 m
.6576 .37397 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36534 .32722 m
.36684 .32745 L
s
.3623 .32905 m
.36534 .32722 L
s
.3638 .32928 m
.36534 .32722 L
s
.65604 .37415 m
.65767 .37857 L
s
.36221 .33363 m
.3638 .32928 L
s
.36925 .36002 m
.37992 .36147 L
s
.65767 .37857 m
.65915 .37378 L
s
.36072 .3334 m
.3623 .32905 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35784 .32833 m
.36072 .3334 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3619 .34971 m
.36221 .33363 L
s
.36031 .35409 m
.36072 .3334 L
s
.35493 .32555 m
.35784 .32833 L
s
.35052 .3248 m
.35493 .32555 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36031 .35409 m
.3619 .34971 L
s
.34755 .32659 m
.35052 .3248 L
s
.34609 .32633 m
.35052 .3248 L
s
.35896 .34695 m
.3604 .34948 L
s
.35013 .34321 m
.35896 .34695 L
s
.35877 .35617 m
.36031 .35409 L
s
.34599 .33093 m
.34755 .32659 L
s
.34454 .33067 m
.34609 .32633 L
s
.35575 .35801 m
.35877 .35617 L
s
.34589 .33554 m
.34599 .33093 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34725 .3404 m
.35013 .34321 L
s
.34579 .34015 m
.35013 .34321 L
s
.34444 .33528 m
.34454 .33067 L
s
.34984 .35706 m
.35575 .35801 L
s
.34589 .33554 m
.34725 .3404 L
s
.34444 .33528 m
.34579 .34015 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34559 .34938 m
.34705 .34963 L
s
.347 .35195 m
.34705 .34963 L
s
.34695 .35426 m
.34984 .35706 L
s
.34554 .3517 m
.34559 .34938 L
s
.34554 .3517 m
.34695 .35426 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31648 .31809 m
.32617 .32018 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33262 .34704 m
.33399 .34963 L
s
.33394 .35195 m
.33399 .34963 L
s
.33114 .34909 m
.33262 .34704 L
s
.33246 .354 m
.33394 .35195 L
s
.33114 .34909 m
.33251 .35168 L
s
.3282 .35319 m
.33246 .354 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32119 .35179 m
.32199 .3193 L
s
.3198 .35151 m
.32061 .319 L
s
.32544 .35031 m
.3282 .35319 L
s
.32153 .33783 m
.32275 .34509 L
s
.32275 .34509 m
.32544 .35031 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31566 .35064 m
.32119 .35179 L
s
.73674 .31628 m
.74992 .31299 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30562 .3179 m
.30817 .32318 L
s
.30817 .32318 m
.30939 .32815 L
s
.30939 .32815 m
.31056 .33545 L
s
.30171 .31459 m
.30562 .3179 L
s
.30429 .31757 m
.30683 .32287 L
s
.30683 .32287 m
.30805 .32784 L
s
.31026 .34711 m
.31056 .33545 L
s
.30805 .32784 m
.30921 .33514 L
s
.30171 .31459 m
.30429 .31757 L
s
.3089 .34681 m
.30921 .33514 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28878 .31119 m
.30171 .31459 L
s
.30872 .35383 m
.31026 .34711 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30737 .35353 m
.3089 .34681 L
s
.30724 .35822 m
.30872 .35383 L
s
.3059 .35791 m
.30737 .35353 L
s
.74992 .31299 m
.75256 .31464 L
s
.74992 .31299 m
.75384 .3143 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30443 .36231 m
.30724 .35822 L
s
.2925 .36186 m
.29389 .31257 L
s
.30309 .362 m
.3059 .35791 L
s
.29121 .36154 m
.29261 .31223 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74207 .31499 m
.7434 .36412 L
s
.74074 .31532 m
.74206 .36442 L
s
.73803 .36533 m
.7513 .36225 L
s
.75256 .31464 m
.75525 .31863 L
s
.75384 .3143 m
.75652 .31828 L
s
.30037 .36374 m
.30443 .36231 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30037 .36374 m
.30309 .362 L
s
.75525 .31863 m
.75666 .32297 L
s
.75652 .31828 m
.75793 .32262 L
s
.28736 .36057 m
.30037 .36374 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75666 .32297 m
.75813 .32966 L
s
.75793 .32262 m
.7594 .32932 L
s
.75813 .32966 m
.75847 .34142 L
s
.7594 .32932 m
.75974 .34108 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7513 .36225 m
.75383 .35925 L
s
.7513 .36225 m
.75512 .35893 L
s
.75741 .34883 m
.75847 .34142 L
s
.75383 .35925 m
.75626 .35388 L
s
.75626 .35388 m
.75741 .34883 L
s
.75512 .35893 m
.75754 .35355 L
s
.75868 .34849 m
.75974 .34108 L
s
.75754 .35355 m
.75868 .34849 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76752 .30803 m
.76852 .34102 L
s
.76384 .30913 m
.77236 .30654 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76931 .32649 m
.77074 .33321 L
s
.76482 .34207 m
.76974 .34066 L
s
.76874 .30766 m
.76974 .34066 L
s
.77074 .33321 m
.7733 .33722 L
s
.7733 .33722 m
.77577 .33887 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77577 .33887 m
.77932 .33777 L
s
.77799 .33339 m
.77924 .33539 L
s
.77799 .33339 m
.77909 .33064 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77909 .33064 m
.78034 .33264 L
s
.78034 .33264 m
.78041 .33502 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77932 .33777 m
.78041 .33502 L
s
.78863 .30343 m
.79186 .29984 L
s
.78766 .30858 m
.78863 .30343 L
s
.78766 .30858 m
.78782 .31332 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78974 .30303 m
.79186 .29984 L
s
.78878 .30818 m
.78974 .30303 L
s
.78878 .30818 m
.78894 .31292 L
s
.78782 .31332 m
.78909 .31768 L
s
.78894 .31292 m
.79021 .31728 L
s
.79186 .29984 m
.79512 .2986 L
s
.78909 .31768 m
.7925 .31886 L
s
.79021 .31728 m
.7925 .31886 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78941 .3272 m
.78949 .32959 L
s
.78941 .3272 m
.79052 .32681 L
s
.79512 .2986 m
.79734 .30015 L
s
.78949 .32959 m
.79068 .33158 L
s
.79052 .32681 m
.7906 .3292 L
s
.79068 .33158 m
.79297 .33319 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79297 .33319 m
.79732 .33161 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7925 .31886 m
.79905 .31882 L
s
.79734 .30015 m
.79962 .30407 L
s
.79962 .30407 m
.8005 .29888 L
s
.79962 .30407 m
.80036 .3256 L
s
.8005 .29888 m
.8025 .29565 L
s
.80067 .30365 m
.80155 .29846 L
s
.80067 .30365 m
.80124 .3204 L
s
.80155 .29846 m
.8025 .29565 L
s
.8025 .29565 m
.80352 .29522 L
s
.79905 .31882 m
.80019 .32081 L
s
.79732 .33161 m
.79938 .3284 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79938 .3284 m
.80036 .3256 L
s
.80036 .3256 m
.80124 .3204 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80673 .32794 m
.81367 .32498 L
s
.81246 .29126 m
.81748 .32326 L
s
.80975 .32668 m
.81246 .29126 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81074 .32626 m
.81272 .29847 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22782 .29372 m
.22884 .29177 L
s
.228 .28891 m
.22884 .29177 L
s
.22699 .29086 m
.228 .28891 L
s
0 0 0 r
.82575 .27733 m
.82703 .27665 L
s
.255 .412 .882 r
.22699 .29086 m
.22782 .29372 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81993 .28763 m
.82475 .31973 L
s
.81748 .32326 m
.81993 .28763 L
s
.22726 .3353 m
.22738 .30578 L
s
.2254 .33445 m
.22738 .30578 L
s
.81841 .32282 m
.82019 .29487 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22632 .33488 m
.22685 .3203 L
s
.22615 .33975 m
.22726 .3353 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21989 .28715 m
.22066 .29004 L
s
.22039 .29731 m
.22066 .29004 L
s
.21828 .28379 m
.21989 .28715 L
s
.2254 .33445 m
.22615 .33975 L
s
.21953 .29684 m
.22048 .29488 L
s
.21943 .29927 m
.22039 .29731 L
s
.21497 .28187 m
.21828 .28379 L
s
.21773 .29834 m
.21953 .29684 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82208 .32107 m
.82735 .31838 L
s
0 0 0 r
.82725 .30651 m
.82727 .30709 L
s
.82844 .33819 m
.82888 .35002 L
s
.82808 .30464 m
.82816 .30653 L
s
.5 Mabswid
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21764 .30077 m
.21943 .29927 L
s
.21889 .31386 m
.21993 .30945 L
s
.21957 .31918 m
.21993 .30945 L
s
.21342 .30087 m
.21773 .29834 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21333 .30331 m
.21764 .30077 L
s
.21889 .31386 m
.21957 .31918 L
s
.21794 .31584 m
.21889 .31386 L
s
.21327 .28334 m
.21497 .28187 L
s
.21615 .31737 m
.21794 .31584 L
s
.8307 .29413 m
.83132 .28879 L
s
.83132 .28879 m
.83273 .28296 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82928 .33633 m
.82935 .33823 L
s
.5 Mabswid
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83016 .30191 m
.8307 .29413 L
s
.83016 .30191 m
.83062 .31412 L
s
.21239 .28529 m
.21327 .28334 L
s
.83151 .29366 m
.83213 .28831 L
s
.83098 .30144 m
.83151 .29366 L
s
.83213 .28831 m
.83352 .28248 L
s
.83273 .28296 m
.83497 .27907 L
s
.21286 .31554 m
.21615 .31737 L
s
.83098 .30144 m
.83144 .31366 L
s
.21179 .27994 m
.21239 .28529 L
s
.21141 .28968 m
.21239 .28529 L
s
.21141 .28968 m
.21179 .27994 L
s
.83352 .28248 m
.83497 .27907 L
s
.21173 .30237 m
.21342 .30087 L
s
.83062 .31412 m
.83172 .321 L
s
.21164 .30482 m
.21333 .30331 L
s
.83144 .31366 m
.83254 .32054 L
s
.83497 .27907 m
.83649 .27808 L
s
.83172 .321 m
.83272 .32545 L
s
.21085 .30434 m
.21173 .30237 L
s
.21135 .31216 m
.21286 .31554 L
s
.21076 .30679 m
.21164 .30482 L
s
.83649 .27808 m
.83879 .27904 L
s
.83254 .32054 m
.83353 .32499 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21066 .30924 m
.21085 .30434 L
s
.21066 .30924 m
.21135 .31216 L
s
.83272 .32545 m
.83452 .32946 L
s
.83353 .32499 m
.83531 .329 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83879 .27904 m
.84042 .28295 L
s
.83452 .32946 m
.83696 .33055 L
s
.205 .27794 m
.20624 .28383 L
s
.83531 .329 m
.83696 .33055 L
s
.84013 .2756 m
.8409 .29522 L
s
.83873 .29668 m
.84368 .29326 L
s
.20302 .27398 m
.205 .27794 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84084 .2751 m
.84161 .29473 L
s
.83696 .33055 m
.83849 .32963 L
s
.20547 .30346 m
.20557 .301 L
s
.20494 .29806 m
.20557 .301 L
s
.20384 .30743 m
.20547 .30346 L
s
.20413 .30003 m
.20494 .29806 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20167 .27297 m
.20302 .27398 L
s
.20413 .30003 m
.20475 .30298 L
s
.83849 .32963 m
.84062 .32577 L
s
.20026 .27441 m
.20167 .27297 L
s
.19962 .2739 m
.20167 .27297 L
s
.20234 .30893 m
.20384 .30743 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84062 .32577 m
.84187 .31988 L
s
.84229 .31199 m
.84288 .32684 L
s
.84187 .31988 m
.84229 .31199 L
s
.19878 .27831 m
.20026 .27441 L
s
.84187 .31988 m
.84288 .32684 L
s
.2003 .30748 m
.20234 .30893 L
s
.19816 .2778 m
.19962 .2739 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84679 .27052 m
.84819 .30514 L
s
.19786 .28521 m
.19878 .27831 L
s
.19908 .30403 m
.2003 .30748 L
s
.19843 .30354 m
.2003 .30748 L
s
.19724 .2847 m
.19816 .2778 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84741 .27001 m
.84881 .30465 L
s
.84488 .27206 m
.84922 .26845 L
s
.19766 .29016 m
.19786 .28521 L
s
.19799 .29808 m
.19908 .30403 L
s
.84627 .30661 m
.84881 .30465 L
s
.19766 .29016 m
.19799 .29808 L
s
.19704 .28965 m
.19724 .2847 L
s
.19736 .29759 m
.19843 .30354 L
s
.84821 .28977 m
.84912 .2967 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19704 .28965 m
.19736 .29759 L
s
.19163 .26413 m
.19546 .26782 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84912 .2967 m
.85052 .30067 L
s
.19234 .30105 m
.19376 .26625 L
s
.19179 .30055 m
.19321 .26572 L
s
.85052 .30067 m
.85179 .30216 L
s
.85179 .30216 m
.85348 .30066 L
s
.85272 .29617 m
.85337 .29816 L
s
.85272 .29617 m
.85317 .29317 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85317 .29317 m
.85381 .29516 L
s
.19019 .29903 m
.19234 .30105 L
s
0 0 0 r
.18399 .2501 m
.18458 .2508 L
s
.255 .412 .882 r
.85348 .30066 m
.85392 .29766 L
s
.85381 .29516 m
.85392 .29766 L
s
.18652 .25823 m
.18964 .262 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19107 .31807 m
.19173 .31606 L
s
.19128 .31306 m
.19173 .31606 L
s
.19063 .31507 m
.19128 .31306 L
s
.19063 .31507 m
.19107 .31807 L
s
.85643 .26906 m
.85669 .26354 L
s
.85643 .26906 m
.85663 .27405 L
s
.85669 .26354 m
.85793 .25943 L
s
.85663 .27405 m
.85731 .27853 L
s
.1871 .28791 m
.18824 .26039 L
s
0 0 0 r
.86256 .2595 m
.86262 .25981 L
s
.255 .412 .882 r
.8569 .26853 m
.85715 .26301 L
s
.8569 .26853 m
.8571 .27353 L
s
.85715 .26301 m
.85793 .25943 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8571 .27353 m
.85777 .278 L
s
.18665 .28739 m
.1878 .25985 L
s
.85731 .27853 m
.85876 .27945 L
s
.85793 .25943 m
.85919 .25781 L
s
0 0 0 r
.86298 .26949 m
.86307 .27053 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85777 .278 m
.85876 .27945 L
s
0 0 0 r
.86262 .25981 m
.8635 .26999 L
s
.255 .412 .882 r
.85773 .28855 m
.85783 .29106 L
s
.85773 .28855 m
.85819 .28803 L
s
.85783 .29106 m
.85839 .29305 L
s
.85819 .28803 m
.85829 .29054 L
s
.18644 .29242 m
.1871 .28791 L
s
.85919 .25781 m
.86009 .25922 L
s
.85876 .27945 m
.86132 .27879 L
s
.85839 .29305 m
.85939 .29453 L
s
.186 .2919 m
.18665 .28739 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86373 .27556 m
.8638 .27716 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86338 .27876 m
.86338 .27885 L
s
.255 .412 .882 r
.18505 .29338 m
.18644 .29242 L
s
.86009 .25922 m
.86106 .26316 L
s
0 0 0 r
.8638 .27716 m
.86383 .28847 L
s
.8638 .28888 m
.86383 .28847 L
s
.255 .412 .882 r
.18505 .29338 m
.186 .2919 L
s
.85939 .29453 m
.86107 .29246 L
s
.18255 .2522 m
.18494 .25605 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18423 .29234 m
.18505 .29338 L
s
.86106 .26316 m
.86121 .25759 L
s
.86106 .26316 m
.86201 .28583 L
s
.86121 .25759 m
.8618 .25398 L
s
.86142 .26261 m
.86156 .25704 L
s
.86142 .26261 m
.86216 .28025 L
s
.86156 .25704 m
.8618 .25398 L
s
.86132 .27879 m
.8618 .28078 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86107 .29246 m
.86174 .28888 L
s
.8618 .25398 m
.86213 .25343 L
s
.86203 .23474 m
.86395 .23076 L
s
.18319 .28824 m
.18423 .29234 L
s
.86174 .28888 m
.86201 .28583 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18127 .30698 m
.18351 .25386 L
s
.18162 .30749 m
.18385 .25441 L
s
.86201 .28583 m
.86216 .28025 L
s
.18269 .28213 m
.18319 .28824 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86319 .23247 m
.86544 .2856 L
s
.86291 .23304 m
.86516 .28613 L
s
.18029 .30543 m
.18162 .30749 L
s
.86426 .25768 m
.86456 .25151 L
s
.86427 .28773 m
.86544 .2856 L
s
.86456 .25151 m
.86494 .24787 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86494 .24787 m
.86538 .24674 L
s
.18007 .24971 m
.18031 .2559 L
s
.18023 .26406 m
.18031 .2559 L
s
.86512 .27797 m
.86586 .28198 L
s
.18001 .26914 m
.18023 .26406 L
s
.17986 .24915 m
.18008 .25534 L
s
.17999 .26351 m
.18008 .25534 L
s
.17945 .27623 m
.18001 .26914 L
s
.17957 .24549 m
.18007 .24971 L
s
.17977 .26859 m
.17999 .26351 L
s
.86538 .24674 m
.86589 .24816 L
s
.86538 .24674 m
.86607 .2476 L
s
.17921 .27569 m
.17977 .26859 L
s
.17957 .24549 m
.17986 .24915 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86586 .28198 m
.86645 .28346 L
s
.17877 .28025 m
.17945 .27623 L
s
.17921 .24436 m
.17957 .24549 L
s
.17897 .22197 m
.17981 .22603 L
s
.86589 .24816 m
.86646 .25212 L
s
.17855 .27971 m
.17921 .27569 L
s
.86607 .2476 m
.86663 .25156 L
s
.86645 .28346 m
.8669 .28239 L
s
0 0 0 r
.17508 .24568 m
.17506 .23727 L
s
.17479 .25715 m
.17508 .24568 L
s
.255 .412 .882 r
.17879 .24578 m
.17921 .24436 L
s
0 0 0 r
.8713 .2878 m
.87162 .28703 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17804 .28119 m
.17877 .28025 L
s
0 0 0 r
.17448 .26444 m
.17479 .25715 L
s
.17506 .23727 m
.17479 .2319 L
s
.17491 .24511 m
.17491 .2367 L
s
.17461 .25659 m
.17491 .24511 L
s
.255 .412 .882 r
.86646 .25212 m
.86696 .25921 L
s
.17804 .28119 m
.17855 .27971 L
s
0 0 0 r
.17429 .26388 m
.17461 .25659 L
s
.17491 .2367 m
.17479 .2319 L
s
.255 .412 .882 r
.8669 .28239 m
.86719 .27875 L
s
.8669 .28239 m
.86738 .27821 L
s
0 0 0 r
.87043 .23261 m
.87138 .25446 L
s
.8713 .22325 m
.87043 .23261 L
s
.17382 .27484 m
.17448 .26444 L
s
.255 .412 .882 r
.86663 .25156 m
.86711 .25866 L
s
.1783 .24975 m
.17879 .24578 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17697 .2774 m
.17927 .22372 L
s
.17709 .27794 m
.17939 .2243 L
s
0 0 0 r
.87138 .25446 m
.87057 .23203 L
s
.17364 .27429 m
.17429 .26388 L
s
.17479 .2319 m
.17456 .23074 L
s
.255 .412 .882 r
.86719 .27875 m
.86734 .27255 L
s
.86696 .25921 m
.86718 .26432 L
s
.17768 .28011 m
.17804 .28119 L
s
.86718 .26432 m
.86734 .27255 L
s
.86738 .27821 m
.8675 .272 L
s
.86711 .25866 m
.86733 .26377 L
s
0 0 0 r
.17316 .28107 m
.17382 .27484 L
s
.17456 .23074 m
.17422 .23322 L
s
.17456 .23074 m
.17414 .23263 L
s
.255 .412 .882 r
.86733 .26377 m
.8675 .272 L
s
0 0 0 r
.17301 .28052 m
.17364 .27429 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17748 .27646 m
.17768 .28011 L
s
.17742 .27024 m
.17748 .27646 L
s
0 0 0 r
.17422 .23322 m
.17375 .23936 L
s
.17257 .2831 m
.17316 .28107 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17414 .23263 m
.17369 .23879 L
s
.17257 .2831 m
.17301 .28052 L
s
.255 .412 .882 r
.17666 .27576 m
.17709 .27794 L
s
.17799 .23811 m
.17805 .23868 L
s
0 0 0 r
.87281 .28745 m
.87391 .30907 L
s
.87281 .28745 m
.87377 .30959 L
s
.17375 .23936 m
.17322 .24978 L
s
.255 .412 .882 r
.1778 .23953 m
.17799 .23811 L
s
.17783 .2401 m
.17799 .23811 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86717 .23995 m
.86752 .23595 L
s
0 0 0 r
.17234 .28201 m
.17257 .2831 L
s
.17369 .23879 m
.17317 .24921 L
s
.255 .412 .882 r
.17757 .24467 m
.17783 .2401 L
s
.17755 .2441 m
.1778 .23953 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1723 .27722 m
.17234 .28201 L
s
.17222 .27667 m
.17234 .28201 L
s
.17322 .24978 m
.1729 .25713 L
s
.255 .412 .882 r
.1768 .26269 m
.17757 .24467 L
s
0 0 0 r
.8731 .26607 m
.87283 .26942 L
s
.87468 .30108 m
.87377 .30959 L
s
.17317 .24921 m
.17285 .25657 L
s
.1729 .25713 m
.17247 .26874 L
s
.17247 .26874 m
.1723 .27722 L
s
.255 .412 .882 r
.17755 .2441 m
.17774 .23782 L
s
.17655 .26731 m
.17755 .2441 L
s
0 0 0 r
.17285 .25657 m
.17242 .26818 L
s
.17242 .26818 m
.17222 .27667 L
s
.17405 .22429 m
.17432 .22075 L
s
.255 .412 .882 r
.17787 .2341 m
.17774 .23782 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87219 .25472 m
.87347 .28418 L
s
.5 Mabswid
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86949 .29397 m
.86976 .29184 L
s
.86865 .26595 m
.86894 .27002 L
s
.86743 .23767 m
.86976 .29184 L
s
.86738 .23824 m
.86971 .29237 L
s
.17655 .26731 m
.1768 .26269 L
s
.17798 .23237 m
.17787 .2341 L
s
0 0 0 r
.17303 .26818 m
.1741 .22311 L
s
.255 .412 .882 r
.17677 .26214 m
.17687 .259 L
s
.86703 .22962 m
.86749 .23365 L
s
.17687 .259 m
.1771 .25305 L
s
.17642 .26934 m
.17655 .26731 L
s
.86894 .27002 m
.86908 .27096 L
s
.17631 .27083 m
.17642 .26934 L
s
.178 .2338 m
.17798 .23237 L
s
.17808 .23323 m
.17798 .23237 L
s
.86736 .23192 m
.86858 .2604 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87134 .22501 m
.87472 .30269 L
s
.87134 .2256 m
.87471 .30322 L
s
.255 .412 .882 r
.86729 .23135 m
.86852 .25984 L
s
.86905 .26986 m
.86908 .27096 L
s
.17643 .26863 m
.17631 .27083 L
s
.17786 .2384 m
.178 .2338 L
s
.17795 .23783 m
.17808 .23323 L
s
.1771 .25305 m
.17733 .24933 L
s
.1771 .25305 m
.17741 .24877 L
s
0 0 0 r
.1718 .27595 m
.17206 .27263 L
s
.255 .412 .882 r
.86886 .26615 m
.86905 .26986 L
s
.86881 .2656 m
.86905 .26986 L
s
.17763 .24358 m
.17786 .2384 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17733 .24933 m
.17763 .24358 L
s
0 0 0 r
.17472 .21839 m
.17564 .21483 L
s
.255 .412 .882 r
.17772 .24301 m
.17795 .23783 L
s
.86858 .2604 m
.86886 .26615 L
s
0 0 0 r
.17185 .27485 m
.17513 .21661 L
s
.255 .412 .882 r
.17741 .24877 m
.17772 .24301 L
s
.17643 .26863 m
.17666 .26492 L
s
.86852 .25984 m
.86881 .2656 L
s
.17689 .25972 m
.17696 .25916 L
s
.17677 .26232 m
.17689 .25972 L
s
0 0 0 r
.17189 .27429 m
.17529 .21602 L
s
.255 .412 .882 r
.17666 .26492 m
.17685 .26177 L
s
.17685 .26177 m
.17696 .25916 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86641 .23819 m
.86741 .26157 L
s
.86661 .23901 m
.8676 .26212 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17246 .2704 m
.17338 .26706 L
s
.255 .412 .882 r
.86741 .26157 m
.86809 .26378 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86816 .27526 m
.86845 .27843 L
s
.86839 .28052 m
.86845 .27843 L
s
0 0 0 r
.17734 .21381 m
.17838 .20831 L
s
.17675 .22187 m
.17734 .21381 L
s
.255 .412 .882 r
.86809 .27734 m
.86816 .27526 L
s
0 0 0 r
.17496 .26316 m
.17675 .22187 L
s
.255 .412 .882 r
.86809 .27734 m
.86839 .28052 L
s
0 0 0 r
.17762 .21322 m
.17838 .20831 L
s
.17702 .22128 m
.17762 .21322 L
s
.17524 .2626 m
.17702 .22128 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17838 .20831 m
.17903 .20712 L
s
.17422 .26483 m
.17524 .2626 L
s
.17903 .20712 m
.17992 .20909 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17992 .20909 m
.18036 .21543 L
s
.18084 .20416 m
.18249 .20179 L
s
.17858 .25703 m
.18084 .20416 L
s
.17897 .25647 m
.18123 .20356 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18672 .21236 m
.18698 .21156 L
s
0 0 0 r
.17746 .2587 m
.17897 .25647 L
s
.255 .412 .882 r
.18698 .21156 m
.18791 .21041 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18482 .19884 m
.185 .20581 L
s
.18418 .21396 m
.18482 .19884 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85634 .21411 m
.85662 .20939 L
s
.85662 .20939 m
.85706 .21999 L
s
0 0 0 r
.18418 .21396 m
.185 .20581 L
s
.185 .20581 m
.18567 .20144 L
s
.18567 .20144 m
.18688 .19649 L
s
.255 .412 .882 r
.85634 .21411 m
.85706 .21999 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18688 .19649 m
.18913 .19414 L
s
.255 .412 .882 r
.85712 .23273 m
.85773 .23595 L
s
.85773 .23595 m
.85795 .24129 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18461 .26739 m
.18464 .26741 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85723 .23539 m
.85784 .23862 L
s
.85597 .22894 m
.85712 .23273 L
s
0 0 0 r
.18321 .23676 m
.18387 .23239 L
s
.18289 .24439 m
.18321 .23676 L
s
.255 .412 .882 r
.85756 .2434 m
.85795 .24129 L
s
.85608 .23161 m
.85723 .23539 L
s
0 0 0 r
.18387 .23239 m
.18507 .22744 L
s
.255 .412 .882 r
.18464 .26741 m
.18477 .26726 L
s
0 0 0 r
.18305 .24057 m
.18371 .2362 L
s
.18371 .2362 m
.18491 .23126 L
s
.18289 .24439 m
.18323 .24765 L
s
.18913 .19414 m
.19017 .19677 L
s
.18507 .22744 m
.18818 .21697 L
s
.18491 .23126 m
.18802 .22079 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18323 .24765 m
.1841 .25037 L
s
.19017 .19677 m
.19062 .2 L
s
.18818 .21697 m
.18953 .21201 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1841 .25037 m
.18632 .24817 L
s
.19015 .21144 m
.19062 .2 L
s
.18802 .22079 m
.18937 .21583 L
s
.18953 .21201 m
.19031 .20762 L
s
.18937 .21583 m
.19015 .21144 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18632 .24817 m
.18765 .24322 L
s
.18765 .24322 m
.18842 .23882 L
s
.18842 .23882 m
.18935 .23059 L
s
.18871 .24597 m
.18935 .23059 L
s
.18842 .23882 m
.18871 .24597 L
s
.19541 .19215 m
.19627 .18775 L
s
.19541 .19215 m
.19596 .1954 L
s
.19627 .18775 m
.19683 .191 L
s
.19596 .1954 m
.19683 .191 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.194 .26049 m
.19517 .21459 L
s
.19256 .26155 m
.19517 .21459 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19327 .26102 m
.19423 .23773 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19256 .26155 m
.19296 .26881 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19296 .26881 m
.194 .26049 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20507 .21688 m
.20508 .21713 L
s
.5 Mabswid
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23294 .20987 m
.23339 .20868 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7674 .1845 m
.76741 .18439 L
s
0 0 0 r
.76614 .15703 m
.76753 .1535 L
s
.76589 .14906 m
.76753 .1535 L
s
.76449 .1526 m
.76589 .14906 L
s
.255 .412 .882 r
.76591 .18407 m
.76607 .18302 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27235 .18946 m
.27239 .18797 L
s
.27094 .18866 m
.27095 .18834 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76449 .1526 m
.76614 .15703 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7674 .1845 m
.76745 .18636 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74856 .14427 m
.75191 .14912 L
s
.75191 .14912 m
.75363 .15355 L
s
.75363 .15355 m
.75398 .16558 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74198 .14261 m
.74856 .14427 L
s
.75238 .16516 m
.75387 .16157 L
s
.75249 .16919 m
.75398 .16558 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76675 .17704 m
.76976 .22589 L
s
.76669 .22506 m
.76675 .17704 L
s
.76749 .20118 m
.76823 .22547 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74925 .16836 m
.75238 .16516 L
s
.73874 .14581 m
.74198 .14261 L
s
.74936 .17239 m
.75249 .16919 L
s
.74119 .17443 m
.74925 .16836 L
s
.73716 .14943 m
.73874 .14581 L
s
.76848 .2336 m
.76976 .22589 L
s
.7413 .17847 m
.74936 .17239 L
s
.75319 .1934 m
.75457 .18572 L
s
.75457 .18572 m
.75504 .20191 L
s
.73525 .141 m
.73716 .14943 L
s
.73525 .141 m
.73568 .1571 L
s
.73568 .1571 m
.73716 .14943 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76669 .22506 m
.76848 .2336 L
s
.75168 .19705 m
.75319 .1934 L
s
.75319 .1934 m
.75504 .20191 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74852 .20032 m
.75168 .19705 L
s
.73792 .1777 m
.74119 .17443 L
s
.73803 .18175 m
.7413 .17847 L
s
.74186 .19877 m
.74852 .20032 L
s
.73633 .18137 m
.73792 .1777 L
s
.255 .412 .882 r
.72039 .173 m
.72053 .17295 L
s
0 0 0 r
.7197 .14158 m
.72344 .15039 L
s
.71423 .13645 m
.7197 .14158 L
s
.73644 .18543 m
.73803 .18175 L
s
.255 .412 .882 r
.72039 .173 m
.72051 .17293 L
s
0 0 0 r
.73633 .18137 m
.73655 .18949 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71061 .13574 m
.71423 .13645 L
s
.73836 .19394 m
.74186 .19877 L
s
.73655 .18949 m
.73836 .19394 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70521 .13874 m
.71061 .13574 L
s
.70705 .13908 m
.71061 .13574 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72395 .17064 m
.72416 .17878 L
s
.70355 .1465 m
.70705 .13908 L
s
.72218 .17028 m
.72249 .18249 L
s
.7017 .14617 m
.70521 .13874 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72259 .18657 m
.72416 .17878 L
s
.72091 .1903 m
.72249 .18249 L
s
.70197 .15836 m
.70355 .1465 L
s
.7001 .15803 m
.7017 .14617 L
s
.72091 .1903 m
.72259 .18657 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68441 .13112 m
.69205 .13237 L
s
.70197 .15836 m
.70215 .16651 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71741 .1937 m
.72091 .1903 L
s
.70215 .16651 m
.72395 .17064 L
s
.7001 .15803 m
.70029 .16619 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35833 .13154 m
.36992 .12974 L
s
.71196 .19268 m
.71741 .1937 L
s
.70215 .16651 m
.70429 .17909 L
s
.70029 .16619 m
.70243 .17877 L
s
.68064 .13458 m
.68466 .14331 L
s
.67667 .12992 m
.68064 .13458 L
s
.67276 .12935 m
.67667 .12992 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70819 .18793 m
.71196 .19268 L
s
.70634 .1876 m
.71196 .19268 L
s
.70429 .17909 m
.70819 .18793 L
s
.6689 .13286 m
.67276 .12935 L
s
.66692 .13258 m
.67276 .12935 L
s
.70243 .17877 m
.70634 .1876 L
s
.66508 .14047 m
.6689 .13286 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38176 .12807 m
.39381 .12654 L
s
.66309 .1402 m
.66692 .13258 L
s
.36555 .15477 m
.38332 .15231 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68441 .13112 m
.68617 .21726 L
s
.68633 .13143 m
.68811 .21754 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68162 .18365 m
.68533 .17601 L
s
.39788 .12605 m
.41227 .12449 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66354 .16582 m
.66424 .16203 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6613 .15221 m
.66309 .1402 L
s
.6633 .15247 m
.66508 .14047 L
s
.40315 .18292 m
.40401 .12536 L
s
.6633 .15247 m
.66345 .16067 L
s
.40522 .18271 m
.40607 .12513 L
s
.64271 .12958 m
.64693 .13822 L
s
.63647 .12483 m
.64271 .12958 L
s
.6613 .15221 m
.66144 .16042 L
s
.63233 .12441 m
.63647 .12483 L
s
.67779 .18721 m
.68162 .18365 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62823 .12809 m
.63233 .12441 L
s
.62614 .12789 m
.63233 .12441 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66345 .16067 m
.66567 .17326 L
s
.66144 .16042 m
.66367 .17301 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67385 .18667 m
.67779 .18721 L
s
.62415 .13589 m
.62823 .12809 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62205 .1357 m
.62614 .12789 L
s
.66567 .17326 m
.66981 .18202 L
s
.66981 .18202 m
.67385 .18667 L
s
.66781 .18176 m
.67385 .18667 L
s
.66367 .17301 m
.66781 .18176 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36217 .13093 m
.37421 .21523 L
s
.37421 .21523 m
.38977 .12703 L
s
.37444 .20278 m
.38776 .12729 L
s
.59643 .12143 m
.61135 .12251 L
s
.62231 .15626 m
.64725 .15873 L
s
.62221 .14803 m
.62415 .13589 L
s
.6201 .14784 m
.62205 .1357 L
s
.68031 .21644 m
.68811 .21754 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6452 .15851 m
.64539 .17087 L
s
.64725 .15873 m
.64738 .16697 L
s
.40559 .15793 m
.40748 .17009 L
s
.44382 .12587 m
.44814 .12148 L
s
.44814 .12148 m
.45243 .12121 L
s
.44169 .12603 m
.44814 .12148 L
s
.43734 .13455 m
.44169 .12603 L
s
.64545 .175 m
.64738 .16697 L
s
.43947 .13439 m
.44382 .12587 L
s
.45243 .12121 m
.45886 .12492 L
s
.43508 .14705 m
.43734 .13455 L
s
.64345 .17891 m
.64539 .17087 L
s
.43721 .14689 m
.43947 .13439 L
s
.62221 .14803 m
.62231 .15626 L
s
.6201 .14784 m
.6202 .15608 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45886 .12492 m
.46312 .13291 L
s
.64345 .17891 m
.64545 .175 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57267 .12013 m
.58783 .1209 L
s
.47624 .11998 m
.49153 .11946 L
s
.40748 .17009 m
.41152 .17795 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54864 .11933 m
.56396 .11978 L
s
.62231 .15626 m
.62457 .16884 L
s
.39697 .18357 m
.40522 .18271 L
s
.43498 .1553 m
.43508 .14705 L
s
.63938 .18263 m
.64345 .17891 L
s
.6202 .15608 m
.62246 .16866 L
s
.43712 .15514 m
.43721 .14689 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60498 .12202 m
.60545 .16733 L
s
.60285 .12187 m
.60331 .16719 L
s
.5003 .11925 m
.51568 .11905 L
s
.52447 .11903 m
.53986 .11916 L
s
.43498 .1553 m
.43698 .16754 L
s
.63313 .18202 m
.63938 .18263 L
s
.43712 .15514 m
.43912 .16739 L
s
.62457 .16884 m
.62888 .17749 L
s
.41152 .17795 m
.41565 .18171 L
s
.255 .412 .882 r
.53426 .15735 m
.53427 .16073 L
s
0 0 0 r
.41996 .17305 m
.42212 .16872 L
s
.42212 .16872 m
.42418 .17268 L
s
.62246 .16866 m
.62678 .1773 L
s
.41996 .17305 m
.42202 .17701 L
s
.62888 .17749 m
.63313 .18202 L
s
.62678 .1773 m
.63313 .18202 L
s
.42413 .17683 m
.42418 .17268 L
s
.41565 .18171 m
.42196 .18115 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4891 .15748 m
.49071 .164 L
s
0 0 0 r
.42196 .18115 m
.42413 .17683 L
s
.255 .412 .882 r
.49128 .15748 m
.49288 .16395 L
s
.53862 .15788 m
.54136 .15732 L
s
0 0 0 r
.43698 .16754 m
.44118 .17554 L
s
.43912 .16739 m
.44333 .17539 L
s
.255 .412 .882 r
.53645 .16075 m
.53862 .15788 L
s
0 0 0 r
.46076 .15778 m
.46291 .16181 L
s
.45856 .16204 m
.46076 .15778 L
s
.255 .412 .882 r
.55819 .1641 m
.55821 .167 L
s
.55603 .16404 m
.55819 .1641 L
s
.55603 .16404 m
.55604 .16694 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50679 .16458 m
.50688 .11914 L
s
.509 .16456 m
.50908 .11911 L
s
.53327 .11908 m
.53335 .17701 L
s
.53107 .11906 m
.53113 .17699 L
s
.45856 .16204 m
.4607 .16607 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60124 .17534 m
.60331 .16719 L
s
.60339 .17548 m
.60545 .16733 L
s
.57918 .12043 m
.57951 .16581 L
s
.58135 .12054 m
.58169 .16592 L
s
.5574 .11956 m
.55766 .17746 L
s
.55522 .11949 m
.55545 .1774 L
s
.46287 .16596 m
.46291 .16181 L
s
.44118 .17554 m
.4476 .17927 L
s
.59697 .17922 m
.60339 .17548 L
s
.44333 .17539 m
.4476 .17927 L
s
.59697 .17922 m
.60124 .17534 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48234 .20688 m
.48278 .11973 L
s
.48455 .20682 m
.48497 .11965 L
s
.45846 .17449 m
.46287 .16596 L
s
.58169 .16592 m
.5861 .17445 L
s
.57957 .17412 m
.58169 .16592 L
s
.57738 .17402 m
.57951 .16581 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4476 .17927 m
.45409 .17888 L
s
.59264 .17896 m
.59697 .17922 L
s
.45409 .17888 m
.45846 .17449 L
s
.5861 .17445 m
.59264 .17896 L
s
.48475 .16507 m
.48911 .17326 L
s
.5576 .16498 m
.56204 .17343 L
s
.57304 .17799 m
.57957 .17412 L
s
.57304 .17799 m
.57738 .17402 L
s
.50457 .17293 m
.50679 .16458 L
s
.50678 .1729 m
.509 .16456 L
s
.56204 .17343 m
.56865 .17782 L
s
.56865 .17782 m
.57304 .17799 L
s
.48911 .17326 m
.49571 .17726 L
s
.50013 .17717 m
.50457 .17293 L
s
.50013 .17717 m
.50678 .1729 L
s
.54883 .17724 m
.55766 .17746 L
s
.49571 .17726 m
.50013 .17717 L
s
.52449 .17697 m
.53335 .17701 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53116 .19789 m
.53338 .2021 L
s
.52894 .20207 m
.53116 .19789 L
s
.47573 .20711 m
.48455 .20682 L
s
.53116 .20628 m
.53338 .2021 L
s
.52894 .20207 m
.53116 .20628 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000`3o
YQ09000000<0ojH@2@0000030?nV40@00000703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV4@08
0?nV4@030:f][@000000000000L000001P2][Jd00`000000[Jf]000000090:f][@030000002][Jd0
000000T0[Jf]1P0000030:f][@T000002`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100
o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H1
0?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ420:f][@80000000<0[Jf]0000
00000000202][Jd40?nV4@040000003oYQ4000000:f][@P0ojH@00<000000?nV400000002@3oYQ00
0`000000ojH@000000070?nV40050:f][@3oYA0000000?nU400000002@3oYA02000000L0[Jf]2000
00050:f][AL0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/
UPh0k9H>00L0k9H>0`2][JeX0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ403P3oYQ45000000<0ojHA302][Jd2
000000D0ojHA0P00000:0?nV4@040000003oYQ4000000:f][@P0ojH@00<000000?nV400000002@3o
YQ000`000000ojH@000000070?nV40050:f][@3oYA0000000?nU400000002@3oYA02000000X0ojD@
0P0000030?nU40030:f][@3oXa00oj<@0080oj<@1@2][Jd3000000030:f][@3oXa00oj<@00`0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>
0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ44000000030?nV4@000000000000<000001P2]
[Jd40?nV4@030:f][@3oYQ40ojHA00@0ojHA0P0000070?nV4@030000003oYQ40ojHA00P0ojHA00@0
00000?nV4@000000[Jf]203oYQ000`000000ojH@000000090?nV40030000003oYQ00000000L0ojH@
00D0[Jf]0?nU40000000ojD@000000090?nU408000002P3oYA02000000<0ojD@00<0[Jf]0?nS403o
Xa001@3oXa02000000<0oj<@00<000000:f][@2][Jd0202][Jd40?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00
M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA0080ojHA00<0[Jf]0000000000000`0000040:f][@80ojHA0P00000:0?nV4@030:f]
[@3oYQ40ojHA00<0ojHA0P0000090?nV4@030000003oYQ40ojHA00L0ojHA00@000000?nV4@000000
[Jf]203oYQ000`000000ojH@000000090?nV40030000003oYQ00000000L0ojH@00D0[Jf]0?nU4000
0000ojD@000000090?nU408000002P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa00103oXa020000
00D0oj<@00<000000?nS403oXa001`3oXa060:f][@030000003lX100o:0@01H0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0C0?nV4@030000003oYQ4000000080
0000102][Jd40?nV4@8000001P3oYQ42000000X0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000T0
ojHA00<000000?nV4@3oYQ401`3oYQ4010000000ojHA0000002][Jd80?nV40030000003oYQ000000
00T0ojH@00<000000?nV400000001`3oYQ001@2][Jd0ojD@0000003oYA00000000T0ojD@0P00000:
0?nU408000000`3oYA000`2][Jd0oj<@0?nS40030?nS408000001`3oXa000`000000oj<@0?nS400:
0?nS4080000000<0o:0@0000000000000`2][Jd200000140o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0@0?nV4@030:f][@0000000000008000000P3oYQ400`2]
[Jd0ojHA0?nV4@060?nV4@030000003oYQ40ojHA00D0ojHA0P00000:0?nV4@030:f][@3oYQ40ojHA
0080ojHA0P00000;0?nV4@030000003oYQ40ojHA00H0ojHA00@000000?nV4@000000[Jf]203oYQ00
0`000000ojH@000000090?nV40030000003oYQ00000000L0ojH@00D0[Jf]0?nU40000000ojD@0000
00090?nU408000002P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa000`3oXa02000000L0oj<@00<0
00000?nS403oXa002@3oXa02000000@0o:0@00<000000?bP403lX1001@0000000`2][Jd0o:0@0?bP
400;0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:
3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0;0?nV4@D0[Jf]0`3oYQ401@000000ojHA0?nV4@3o
YQ40[Jf]00L0ojHA0P0000070?nV4@8000002P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000503o
YQ4010000000ojHA0000002][Jd80?nV40030000003oYQ00000000T0ojH@00<000000?nV40000000
1`3oYQ001@2][Jd0ojD@0000003oYA00000000T0ojD@0P00000:0?nU408000000`3oYA000`2][Jd0
oj<@0?nS40020?nS408000002@3oXa000`000000oj<@0?nS40070?nS4080000000<0[Jf]0?bP403l
X1000`3lX10010000000o:0@0000000000040?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0
/>3V0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0
ojHA0?nV4@050?nV4@H0[Jf]203oYQ401@000000ojHA0?nV4@3oYQ40[Jf]00L0ojHA0P0000070?nV
4@8000002P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@800000503oYQ4010000000ojHA0000002][Jd8
0?nV40030000003oYQ00000000T0ojH@00<000000?nV400000001`3oYQ001@2][Jd0ojD@0000003o
YA00000000T0ojD@0P00000:0?nU408000000`3oYA000`2][Jd0oj<@0?nS40020?nS408000002@3o
Xa000`000000oj<@0?nS40070?nS4080000000<0[Jf]0?bP403lX1000`3lX10010000000o:0@0000
000000090?bP40030:f][@00000000000080000000@0[Jf]0?bP403lX100[Jf]5P3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f]
[@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f]
[@3oYQ40ojHA00D0[Jf]3`3oYQ4010000000ojHA0?nV4@2][Jd70?nV4@8000001`3oYQ42000000X0
ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000001@0ojHA00@000000?nV4@000000[Jf]203oYQ000`00
0000ojH@000000090?nV40030000003oYQ00000000L0ojH@00D0[Jf]0?nU40000000ojD@00000009
0?nU408000002P3oYA02000000<0ojD@00<0[Jf]0?nS403oXa000P3oXa02000000X0oj<@00<00000
0?nS403oXa001@3oXa02000000030?nS402][Jd0o:0@00D0o:0@0`0000080?bP40<000000`3lX100
0`000000[Jf]0:f][@020:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@06
0=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@@0[Jf]503oYQ4010000000ojHA0?nV4@2][Jd70?nV4@8000001`3oYQ42
000000X0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P00000E0?nV4@040000003oYQ4000000:f][@P0ojH@
00<000000?nV400000002@3oYQ000`000000ojH@000000070?nV40050:f][@3oYA0000000?nU4000
00002@3oYA02000000X0ojD@0P0000030?nU40030:f][@3oXa00oj<@0080oj<@0P00000B0?nS4080
000000<0oj<@0:f][@3lX1001@3lX103000000L0o:0@0P0000050?bP40050000003lX100o:0@0:f]
[@3fW0l0102][Jd00`000000mY`?0?JL3`0>0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd0203KRPd20:f][ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01D0ojHA00@000000?nV4@3o
YQ40[Jf]1`3oYQ42000000L0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA0080ojHA0P00000E0?nV
4@040000003oYQ4000000:f][@P0ojH@0P00000:0?nV40030000003oYQ00000000L0ojH@00D0[Jf]
0?nU40000000ojD@000000090?nU408000002P3oYA02000000<0ojD@00@0[Jf]0?nS403oXa00oj<@
0P00000C0?nS4080000000<0oj<@0:f][@3lX1001P3lX102000000L0o:0@0P0000060?bP40030000
003lX100[Jf]00D0mY`?00<000000:f][@2][Jd00P00000<0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ40503o
YQ4010000000ojHA0?nV4@2][Jd70?nV4@030000003oYQ40ojHA00H0ojHA0P0000090?nV4@030:f]
[@3oYQ40ojHA0080ojHA0P00000E0?nV4@040000003oYQ4000000:f][@P0ojH@0P00000:0?nV4003
0000003oYQ00000000L0ojH@00D0[Jf]0?nU40000000ojD@0000000:0?nU408000002@3oYA020000
00<0ojD@00@0[Jf]0?nS403oXa00oj<@0P00000C0?nS4080000000<0oj<@0:f][@3lX1001P3lX102
000000H0o:0@0P0000070?bP40030000003lX100[Jf]00D0mY`?00D000000?JL3`000000mY`?0:f]
[@03000000T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@030:f][@2`
h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01@0ojHA00@00000
0?nV4@3oYQ40[Jf]1P3oYQ42000000P0ojHA0P0000090?nV4@030:f][@3oYQ40ojHA0080ojHA0P00
000E0?nV4@040000003oYQ4000000:f][@P0ojH@0P00000:0?nV40030000003oYQ00000000L0ojH@
00D0[Jf]0?nU40000000ojD@0000000:0?nU408000002@3oYA02000000<0ojD@00@0[Jf]0?nS403o
Xa00oj<@0P00000B0?nS408000000P3oXa000`2][Jd0o:0@0?bP40050?bP408000001P3lX1020000
00P0o:0@00<000000:f][@3fW0l0103fW0l3000000@0mY`?00<000000:f][@2][Jd00P2][Jd50?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0
/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0
oj@A00<0[Jf]0?nV4@3oYQ40503oYQ4010000000ojHA0?nV4@2][Jd60?nV4@800000203oYQ420000
00T0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000001D0ojHA00@000000?nV4@000000[Jf]203oYQ02
000000X0ojH@00<000000?nV400000001`3oYQ001@2][Jd0ojD@0000003oYA00000000X0ojD@0P00
00090?nU408000000`3oYA00102][Jd0oj<@0?nS403oXa0200000180oj<@0P0000030?nS40030:f]
[@3lX100o:0@00@0o:0@0P0000060?bP40800000203lX1000`000000[Jf]0?JL3`040?JL3`800000
1P3fW0l010000000mY`?0?JL3`3fW0l30:f][@030000003fW0l0[Jf]0180k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0:f][@1@0;3PiP40oooo001U0;3PiP030:f][@3CQ`h0[Jf]00d0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0:f][@030:f][A40oj@A00<0[Jf]0?nV4@3oYQ40
503oYQ4010000000ojHA0?nV4@2][Jd60?nV4@800000203oYQ42000000T0ojHA00<0[Jf]0?nV4@3o
YQ400P3oYQ42000001D0ojHA00@000000?nV4@000000[Jf]203oYQ02000000X0ojH@00<000000?nV
400000001`3oYQ000`2][Jd0ojD@0?nU4002000000X0ojD@0P0000090?nU408000000`3oYA00102]
[Jd0oj<@0?nS403oXa0200000180oj<@0P0000030?nS40030:f][@3lX100o:0@00@0o:0@0P000006
0?bP408000002@3lX1000`000000mY`?0?JL3`030?JL3`8000001P3fW0l00`000000mY`?0?JL3`04
0?JL3`040000002][Jd0[Jf]0:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue
2`2][Je?0;3PiP40oooo001T0;3PiP040:f][@3CQ`h0dhL>0:f][@d0kiP@00<0[Jf]0?bP403lX100
3P3lX1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ400`000000ojHA0:f][@020?nV4@H00000
203oYQ42000000T0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000001D0ojHA00@000000?nV4@000000
[Jf]203oYQ02000000X0ojH@00<000000?nV400000001`3oYQ000`2][Jd0ojD@0?nU4002000000X0
ojD@0P0000090?nU408000000`3oYA00102][Jd0oj<@0?nS403oXa0200000180oj<@0P0000030?nS
40030:f][@3lX100o:0@00@0o:0@0P0000060?bP408000002@3lX1000`2][Jd0mY`?0?JL3`030?JL
3`030000003fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l00`3fW0l2000000030:f][@3/UPh0[Jf]
0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H1
0?ooo`00H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100303lX102
0:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ45000000@0ojHA00<00000
0?nV4@3oYQ401`3oYQ42000000T0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ42000001D0ojHA00@00000
0?nV4@000000[Jf]203oYQ02000000X0ojH@00<000000?nV400000001`3oYQ000`2][Jd0ojD@0?nU
4002000000X0ojD@0P0000090?nU408000000`3oYA00102][Jd0oj<@0?nS403oXa0200000180oj<@
0P0000030?nS40030:f][@3lX100o:0@00@0o:0@0P0000060?bP408000002@3lX1000`2][Jd0mY`?
0?JL3`030?JL3`030000003fW0l0mY`?00H0mY`?00<000000?JL3`3fW0l00`3fW0l00`000000mY`?
0:f][@040>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;
0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA01D0ojHA00<000000?nV4@2][Jd01P3oYQ400`000000ojHA0?nV4@070?nV4@8000002@3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@8000004@3oYQ440:f][@030000002][Jd0000000T0[Jf]0P00
000:0:f][@030000002][Jd0000000X0[Jf]0P0000030:f][@L0ojD@0P0000090?nU408000000`3o
YA00102][Jd0oj<@0?nS403oXa07000000d0oj<@0P0000030?nS40030:f][@3lX100o:0@00@0o:0@
0P0000060?bP408000002@3lX1000`2][Jd0mY`?0?JL3`030?JL3`030000003fW0l0mY`?00H0mY`?
00<000000?JL3`3fW0l00`3fW0l00`000000mY`?0:f][@060>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`
h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3l
X1020:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0F0?nV4@030000003o
YQ40[Jf]00D0ojHA0P0000090?nV4@8000002@3oYQ400`2][Jd0ojHA0?nV4@020?nV4@80000000<0
ojHA0:f][@2][Jd01`2][Jd00`000000[Jf]0:f][@040:f][@@0ojHA00@000000?nV4@000000[Jf]
203oYQ02000000X0ojH@00<000000?nV400000001`3oYQ000`2][Jd0ojD@0?nU4002000000<0ojD@
1`2][Jd2000000L0[Jf]0P3oYA02000000<0ojD@00@0[Jf]0?nS403oXa00oj<@0P0000050?nS40L0
00001P3oXa02000000<0oj<@00<0[Jf]0?bP403lX100103lX102000000H0o:0@0P0000090?bP4003
0:f][@3fW0l0mY`?00`0mY`?00<000000?JL3`3fW0l01@3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0
[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`
h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0F0?nV4@030000003oYQ40[Jf]00D0ojHA0P0000090?nV4@8000001@3oYQ490:f][@800000
00<0[Jf]0?nV4@3oYQ401P3oYQ400`000000ojHA000000090?nV4@040000003oYQ4000000:f][@P0
ojH@0P00000:0?nV40030000003oYQ00000000L0ojH@00<0[Jf]0?nU403oYA000P00000:0?nU4080
00001`3oYA020:f][@8000001`2][Jd2000000X0oj<@0P0000060?nS408000000`3oXa000`2][Jd0
o:0@0?bP40040?bP408000001P3lX102000000T0o:0@00<0[Jf]0?JL3`3fW0l0303fW0l00`000000
mY`?0?JL3`050?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f]
[@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@/0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0F0?nV4@030000003oYQ40[Jf]00D0
ojHA0P0000070?nV4@80[Jf]0P0000050:f][@@0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000P0
ojHA00@000000?nV4@3oYQ400000203oYQ4010000000ojHA0000002][Jd80?nV408000002P3oYQ00
0`000000ojH@000000070?nV40030:f][@3oYA00ojD@008000002P3oYA02000000T0ojD@0P000003
0?nU40040:f][@3oXa00oj<@0?nS408000002@2][Jd00`3oXa000000000000060?nS408000000`3o
Xa000`2][Jd0o:0@0?bP40040?bP408000001P3lX102000000T0o:0@00<0[Jf]0?JL3`3fW0l0303f
W0l00`000000mY`?0?JL3`050?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:
3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H0
0`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01H0ojHA00<000000?nV4@2][Jd0103o
YQ400`2][Jd00000000000070:f][@80ojHA0P0000090?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00
00080?nV4@040000003oYQ40ojHA000000P0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV40800000
2P3oYQ000`000000ojH@000000070?nV40030:f][@3oYA00ojD@008000002P3oYA02000000T0ojD@
0P0000030?nU40030:f][@3oXa00oj<@0080oj<@0P0000080?nS40030:f][@000000000000H0[Jf]
0P0000030?nS40030:f][@3lX100o:0@00@0o:0@0P0000060?bP408000002@3lX1000`2][Jd0mY`?
0?JL3`0<0?JL3`030000003fW0l0mY`?00D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][@d0fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_
V100kiP@00/0kiP@0P2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405P3o
YQ400`2][Jd000000:f][@040:f][@030?nV4@000000ojHA00T0ojHA0`0000080?nV4@030:f][@3o
YQ40ojHA00<0ojHA0P0000090?nV4@030000003oYQ40000000P0ojHA0`0000000`2][Jd0ojH@0?nV
40060?nV408000002P3oYQ000`000000ojH@000000070?nV40030:f][@3oYA00ojD@008000002P3o
YA02000000T0ojD@0P0000030?nU40030:f][@3oXa00oj<@0080oj<@0P0000090?nS408000001P3o
Xa02000000L0[Jf]0`3lX102000000H0o:0@100000070?bP40030:f][@3fW0l0mY`?00/0mY`?0P00
00070?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2]
[Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4@3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA0100ojHA1P2][Jd00`3oYQ4000000:f][@05
0?nV4@030000003oYQ40ojHA00P0ojHA0`0000060?nV4@030000003oYQ40[Jf]00D0ojHA0P00000:
0?nV4@030000003oYQ40ojHA00L0ojHA0`0000000`2][Jd0ojH@0?nV40050?nV408000002`3oYQ00
0`000000ojH@000000070?nV40030:f][@3oYA00ojD@00<000002@3oYA02000000T0ojD@0P000003
0?nU40030:f][@3oXa00oj<@0080oj<@0P0000090?nS408000001`3oXa0200000080oj<@00@0[Jf]
0?bP403lX100o:0@0`2][Jd2000000030:f][@3lX100o:0@00<0o:0@0P0000020?bP40D000000P3l
X1000`2][Jd0mY`?0?JL3`0:0?JL3`030000003fW0l0000000L0mY`?00<0[Jf]0>bF3P3/UPh0403/
UPh00`2][Jd0fhX=0=^:3@020:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f]
[@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V102
0:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA00/0ojHA1@2][Jd70?nV4@030000002][Jd0ojHA00@0ojHA00<000000?nV4@3oYQ40203oYQ43
000000D0ojHA0P0000000`3oYQ40[Jf]0?nV4@050?nV4@800000203oYQ400`000000ojHA0?nV4@08
0?nV4@80000000<0ojHA0000003oYQ001P3oYQ02000000/0ojH@00<000000?nV400000001`3oYQ00
0`2][Jd0ojD@0?nU4003000000P0ojD@0P0000000`3oYA0000000?nU40060?nU40800000103oYA00
0`2][Jd0oj<@0?nS40020?nS408000002@3oXa000`000000oj<@0?nS40060?nS408000000P3oXa00
0`2][Jd0o:0@0?bP40040?bP4080000000<0o:0@0:f][@2][Jd00`2][Jd2000000L0o:0@0`00000;
0?JL3`030000003fW0l0000000P0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@02
0=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool0
05/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ401P3oYQ45
0:f][@`0ojHA00<000000:f][@3oYQ400`3oYQ42000000X0ojHA0`0000050?nV4@040000003oYQ40
00000:f][@H0ojHA0P0000080?nV4@030000003oYQ40ojHA00P0ojHA0P0000000`3oYQ40[Jf]0000
00060?nV408000002`3oYQ000`000000ojH@000000070?nV40030:f][@3oYA00ojD@0080000000<0
ojD@0000003oYA001P3oYA02000000030?nU40000000ojD@00H0ojD@0P0000040?nU40030:f][@3o
Xa00oj<@00<0oj<@0P0000080?nS40030000003oXa00oj<@00H0oj<@0P0000020?nS40030:f][@3l
X100o:0@00@0o:0@0P0000060?bP408000001P2][Jd20?bP4003045Yh@000000mY`?00P0mY`?0P00
00000`3fW0l000000?JL3`080?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0103K
RPd00`2][Jd0fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]
A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00@0kiP@
00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ401P2][JdA0?nV4@030000002][Jd0ojHA00<0ojHA0P00000:0?nV4@800000
00<0ojHA0000003oYQ400`3oYQ4010000000ojHA0000002][Jd70?nV4@8000001P3oYQ400`000000
ojHA0?nV4@090?nV4@80000000<0ojHA0:f][@3oYQ000P0000030?nV40800000303oYQ000`000000
ojH@000000070?nV40030:f][@3oYA00ojD@008000000P3oYA000`000000ojD@0?nU40040?nU4080
00000P3oYA000`000000ojD@0?nU40040?nU40800000103oYA000`2][Jd0oj<@0?nS40030?nS4080
00001`3oXa02000000T0oj<@0P0000000`3oXa00[Jf]0?bP40060?bP408000001P3lX102000000D0
o:0@0`2][Jd00`000000[Jf]0?JL3`060?JL3`040000003fW0l0mY`?000000X0mY`?00<0[Jf]0>bF
3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]103KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0B0?nT4@@0[Jf]5`3oYQ400`000000[Jf]0?nV4@030?nV4@030000003oYQ40
ojHA00T0ojHA0P0000000`3oYQ4000000?nV4@040?nV4@80000000<0[Jf]0?nV4@3oYQ401P3oYQ42
000000@0ojHA00<000000?nV4@3oYQ402P3oYQ42000000030?nV4@2][Jd0ojH@0080ojH@0`00000;
0?nV40H000001P3oYQ06000000<0ojD@00@000000?nU403oYA00ojD@0`0000040?nU408000000`3o
YA02000000D0ojD@00<0[Jf]0?nS403oXa00103oXa02000000H0oj<@00<000000?nS403oXa00203o
Xa02000000030?nS402][Jd0o:0@00D0o:0@0`0000060?bP40800000203lX102000000@0[Jf]0P3f
W0l010000000mY`?00000000000:0?JL3`030000002][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3KRPd0
1`3KRPd20:f][@80fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0
/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080
[Jf]2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00h0oj@A102][Jd00`3oY140
[Jf]0?nV4@0H0?nV4@030000002][Jd0ojHA00<0ojHA00<000000?nV4@3oYQ402@3oYQ4200000080
ojHA00<000000?nV4@3oYQ400P3oYQ400`000000ojHA0:f][@0:0?nV4@@000003@3oYQ4200000003
0?nV4@2][Jd0ojH@01d0ojH@00<0[Jf]0?nU403oYA001P3oYA04000000P0ojD@0`0000070?nU4003
0:f][@3oXa00oj<@00D0oj<@0P0000050?nS40030000003oXa00oj<@00T0oj<@0P0000000`2][Jd0
o:0@0?bP40030?bP40040000003lX1000000000000H0o:0@0P0000080?bP40800000103fW0l0102]
[Jd000000:f][@00000<0?JL3`030000002][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd3
0:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f][@/0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0:0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030000003oYQ40ojHA0080ojHA00<000000?nV4@3oYQ402@3oYQ42000000<0ojHA00<000000?nV
4@3oYQ400P0000000`3oYQ40[Jf]0?nV4@0J0?nV4@80000000<0ojHA0:f][@3oYQ007@3oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00H0oj<@00<000000?nS403oXa000P3oXa000`00
0000oj<@0?nS400:0?nS4080000000<0[Jf]0?bP403lX1000`3lX10010000000o:0@000000000006
0?bP40800000203lX102000000D0mY`?0P0000000`3fW0l0[Jf]0:f][@020:f][@P0mY`?00<00000
0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`000000ojHA0?nV4@02
0?nV4@030000003oYQ40ojHA00H0ojHA1@0000040?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@0I
0?nV4@80000000<0ojHA0:f][@3oYQ007@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@00L0oj<@1000000>0?nS40800000103lX1000`000000o:0@0?bP4002000000L0o:0@0P000007
0?bP40030000003fW0l0mY`?00@0mY`?00<000000?JL3`3fW0l0103fW0l40:f][@@0mY`?00<00000
0:f][@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`02
08QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@08
0=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0oj@A102][Jd<
0?nT4@030:f][@3oYQ40ojHA01P0ojHA00@000000?nV4@3oYQ40ojHA0P00000F0?nV4@030:f][@3o
YQ40ojHA01T0ojHA0P0000000`3oYQ40[Jf]0?nV400M0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa0200000080o:0@00@000000?bP403lX100o:0@0P0000070?bP40800000
1`3lX1000`000000mY`?0?JL3`040?JL3`030000003fW0l0mY`?00P0mY`?102][Jd00`000000[Jf]
0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@060=>73P80[Jf]00<0dhL>0:f][@3_V1002`3_V1000`2][Jd0o:0@0?bP400@0?bP4003
0:f][@3oY140[Jf]00<0[Jf]403oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@000000ojHA0080
ojHA0P00000F0?nV4@030:f][@3oYQ40ojHA01T0ojHA0P0000000`3oYQ40[Jf]0?nV400M0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0000000000040?bP
40800000203lX102000000D0o:0@0P0000060?JL3`030000003fW0l0mY`?00H0mY`?00<000000?JL
3`3fW0l00`3fW0l00`000000[Jf]0:f][@0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue
2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00<000000:f][@3CQ`h00P3CQ`h0
0`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00l0o:0@0`2][JdD0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0000003oYQ400P3oYQ400`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ40
ojHA01T0ojHA0P0000000`3oYQ40[Jf]0?nV400M0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP408000002@3lX1000`000000o:0@0?bP4003
0?bP40030000002][Jd0mY`?00D0mY`?00<000000?JL3`3fW0l01P3fW0l00`000000mY`?0?JL3`03
0?JL3`030000002][Jd0k9H>00<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>0P0000040=>73P030:f][@3_V100
kiP@00X0kiP@00<0[Jf]0?bP403lX100303lX1030:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd000000?nV4@020?nV4@030000003oYQ40ojHA01D0ojHA00<0[Jf]
0?nV4@3oYQ406@3oYQ42000000030?nV4@2][Jd0ojH@01d0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000:0?bP40030000003lX100
o:0@0080o:0@00<000000:f][@3fW0l01@3fW0l00`000000mY`?0?JL3`050?JL3`8000001@3fW0l0
0`000000[Jf]0>bF3P030>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00<0^GD;00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>0P0000040=>73P030:f][@3_V100kiP@00X0kiP@00<0
[Jf]0?bP403lX1002P3lX1020:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@000000ojHA0080ojHA00<000000?nV4@3oYQ405@3oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@80000000<0ojHA0:f][@3oYQ007@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001@3lX102000000/0o:0@100000000`3lX100[Jf]0?JL
3`060?JL3`030000003fW0l0mY`?00@0mY`?0P0000050?JL3`030000002][Jd0k9H>00D0k9H>0`2]
[Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/20:f][@030;Ue2`2]
[Jd0R5H700<0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd00000
0P2][Jd00`3CQ`h000000=>73P030=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100
1`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ4000000080ojHA00<000000?nV4@3oYQ405@3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@@0[Jf]
0P00000X0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP40800000
4@3lX1000`2][Jd0mY`?0?JL3`040?JL3`030000003fW0l0mY`?00<0mY`?0`0000050?JL3`030000
002][Jd0k9H>00P0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/20:f][@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP070:f][@2GH0/0Uf0;09MP2`000000
[Jf]000000070=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@T0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@040:f][@3oYQ4000000?nV
4@8000005`3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]103oYQ42000000030?nV4@2][Jd0ojH@
01d0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP40050?bP408000004@3lX1000`2][Jd0mY`?0?JL3`040?JL3`030000003fW0l0mY`?
00<0mY`?0`0000050?JL3`030000002][Jd0k9H>00/0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V
0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P0000000`3CQ`h000000=>73P060=>73P03
0:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@`0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@050:f][@3oYQ4000000?nV4@000000503oYQ4<0:f]
[A@0ojHA0P0000000`3oYQ40[Jf]0?nV400D0?nV40030000003oYQ00ojH@00H0ojH@00<0[Jf]0?nU
403oYA005@3oYA0<0:f][AP0oj<@00<0[Jf]0?bP403lX1001@3lX10200000140o:0@00<0[Jf]0?JL
3`3fW0l01@3fW0l200000080mY`?00@000000?JL3`3fW0l000001@3fW0l00`000000[Jf]0>bF3P0=
0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL0
0`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080000000<0dhL>0000
003CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]0080[Jf]3P3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00D0[Jf]0?nV4@000000ojHA0000000:
0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@80000000<0ojHA0:f][@3oYQ004`3oYQ02
000000P0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3oXa00
0`2][Jd0o:0@0?bP40050?bP408000004@3lX1000`2][Jd0mY`?0?JL3`070?JL3`<000000P3fW0l0
0`000000mY`?0?JL3`030?JL3`030000002][Jd0k9H>0100k9H>0`2][Jd=0=^:3@030:f][@2iM@/0
^GD;00H0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]0000
000000000P0000000`3CQ`h000000=>73P050=>73P030:f][@3_V100kiP@00/0kiP@0P2][JdA0?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ401@2][Jd0ojHA0000003oYQ40
000000X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@80000000<0ojHA0:f][@3oYQ004P3oYQ00
10000000ojH@0?nV400000070?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303o
Xa0:0:f][@@0oj<@00<0[Jf]0?bP403lX1001@3lX10200000140o:0@00<0[Jf]0?JL3`3fW0l0303f
W0l00`000000mY`?0?JL3`030?JL3`8000004P3/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo
001I0;3PiP070:f][@000000[Jf]0000002][Jd0dhL>000000060=>73P030:f][@3_V100kiP@00T0
kiP@0`2][JdB0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ450:f][@03
0000002][Jd0000001P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ42000000030?nV4@2][Jd0ojH@01<0
ojH@0P0000080?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][@@0
o:0@0P00000A0?bP40030:f][@3fW0l0mY`?0180mY`?0P00000B0>bF3P040:f][@3KRPd0fhX=0=^:
3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H70:f][@80R5H700<0[Jf]
0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H2000000050:f][@000000[Jf]0=>73P0000001P3CQ`h0
0`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ460:f][@<0ojHA00D0[Jf]0?nV4@000000ojHA0000
000H0?nV4@030:f][@3oYQ40ojHA01H0ojHA1@0000000`3oYQ40[Jf]0?nV400D0?nV40030000003o
YQ00ojH@00H0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3l
X100o:0@0?bP40@0[Jf]0P0000000`2][Jd0o:0@0?bP400>0?bP40030:f][@3fW0l0mY`?0180mY`?
0P0000000`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005T0
/>3V0P0000001@2GH0/000000:f][@3CQ`h0000000H0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f]
[@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA
00L0ojHA1`2][Jd90?nV4@030:f][@3oYQ40ojHA00800000603oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@00D0o:0@0P0000000`3lX100[Jf]0:f][@040:f][@X0o:0@00<0[Jf]0?JL
3`3fW0l04P3fW0l2000000030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f]
[@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0@FWQ08QF1`28EPL0[Jf]08QF1`2][Jd0@P2`
h>H10?ooo`00F02`h>H30000000309MP2`000000[Jf]008000001P3CQ`h00`2][Jd0kiP@0>nH4003
0>nH4080[Jf]1P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]
0?nV4@3oYQ40ojHA1P2][Jd@0?nV4@040:f][@3oYQ40ojHA000001T0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP40050?bP408000001`3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l0
4P3fW0l2000000030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0@FWQ08QF1`0208QF1`80[Jf]@P2`h>H10?ooo`00F02`
h>H30000000409MP2`000000[Jf]000000L0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd80>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1450:f][AH0ojHA00@0[Jf]0?nV4@3o
YQ4000006@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000>0?bP
40H0[Jf]4P3fW0l2000000030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02@3KRPd20:f]
[@030=^:3@2][Jd0^GD;00L0^GD;00<0[Jf]045Yh@28EPL00`28EPL00`2][Jd0/>3V0;3PiP100;3P
iP40oooo001H0;3PiP<0000000@0Uf0;0000002][Jd000000P3CQ`h00`000000dhL>0=>73P020=>7
3P040:f][@3_V100[Jf]0:f][@X0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?
0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ40102][Jd0ojHA0?nV4@00000I0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001@3lX10200000140o:0@00<0[Jf]0?JL3`3fW0l0102]
[Jd>0?JL3`80000000<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000060:f][@000000
Uf0;09MP2`2][Jd000000P3CQ`h00`000000dhL>0=>73P020=>73P80[Jf]303_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@0080o:0@
1@00000A0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd90?JL3`80000000<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]202iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@@2`h>H10?ooo`00E`2`h>H2000000060:f][@000000Uf0;09MP2`2][Jd000000P3CQ`h010000000
dhL>0=>73P3CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT
4@@0[Jf]2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd40?JL
3`80000000<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0[Jf]
0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V0P000000102]
[Jd0000009MP2`2GH0/200000080dhL>00H000000=>73P3CQ`h0[Jf]0=>73P2][Jd=0>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`@0[Jf]0P0000000`2][Jd0k9H>0>bF3P0@0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`030:f][@28EPL0R5H70080
R5H70P2][Je10;3PiP40oooo001G0;3PiP80000000@0[Jf]0000002GH0/0Uf0;0P0000020=>73P03
0000003CQ`h0[Jf]0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180
mY`?0P0000020:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`03
0:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`h>H0/>3V03h0
/>3V0@3oool005L0/>3V0P0000000`2][Jd0000009MP2`02000000<0dhL>00<000000:f][@3CQ`h0
0P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00h0o:0@0`2][JdE0?nT4@030:f]
[@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000030:f][@3/UPh0[Jf]0080[Jf]
3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0^GD;00D0[Jf]0;Ue2`2iM@/0
^GD;0:f][@0408QF1`80[Jf]00<000000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H2000000030:f]
[@000000Uf0;008000000P3CQ`h00`2][Jd000000=>73P030=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX100303lX1020:f][@030?bP402][Jd0oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`80000000<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]00<0^GD;0:f][@28EPL0
0`28EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V0P0000002@2][Jd0000009MP
2`000000[Jf]0=>73P2][Jd0dhL>000000040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?0180mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80[Jf]00<000000;3P
iP2`h>H0?P2`h>H10?ooo`00E`2`h>H300000080Uf0;00<000000:f][@0000000P3CQ`h00`000000
dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0
o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<000000:f][@3/UPh0203/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40
oooo001G0;3PiP<000000P2GH0/00`000000[Jf]000000020=>73P030000003CQ`h0dhL>0080dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l04`3fW0l00`000000[Jf]0>bF3P0;0>bF3P80[Jf]103/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`80[Jf]00<000000;3PiP2`h>H0
?P2`h>H10?ooo`00E`2`h>H30000000509MP2`00000000000:f][@0000000P3CQ`h01@000000dhL>
0=>73P3CQ`h0[Jf]00h0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f]
[@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]0`28EPL20:f][@030000002`h>H0/>3V
03h0/>3V0@3oool005L0/>3V0`0000001@2GH0/000000000002][Jd000000080dhL>00D000000=>7
3P3CQ`h0dhL>0:f][@0>0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]00<0
00000;3PiP2`h>H0?P2`h>H10?ooo`00E`2`h>H30000000609MP2`000000Uf0;0:f][@000000dhL>
0P0000030=>73P030:f][@3_V100kiP@00/0kiP@0`2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>
00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0[Jf]0080
R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001G0;3PiP<0000000H0[Jf]0000002GH0/0
[Jf]0000003CQ`h2000000<0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH402][Jd0o:0@
0100o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA
0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00D0[Jf]
08QF1`28EPL0[Jf]08QF1`020:f][@030000002`h>H0/>3V03h0/>3V0@3oool005L0/>3V00T00000
0:f][@000000[Jf]0000002GH0/0[Jf]0000003CQ`h00P0000030=>73P030:f][@3_V100kiP@00L0
kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00H0
^GD;00@0[Jf]08QF1`28EPL0R5H70`2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP80
000000P0[Jf]0000002GH0/0000009MP2`2][Jd000000=>73P8000000`3CQ`h00`2][Jd0kiP@0>nH
40050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`040:f][@28EPL0R5H708QF1`<0[Jf]0P00000o0;3PiP40oooo001F0;3PiP80000000H0
[Jf]0000002GH0/0000009MP2`0000020=>73P8000000`3CQ`h00`2][Jd0kiP@0>nH40030>nH4080
[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`03
0:f][@28EPL0R5H70080R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000001P2][Jd00000
09MP2`000000Uf0;00000080dhL>0P0000030=>73P040:f][@3_V100kiP@0>nH4080[Jf]2@3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2]
[Jfj0;3PiPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd02@3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0000009MP2`2GH0/0000000<0dhL>
0P0000030=>73P040:f][@3_V100[Jf]0:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0
oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`h>H10?oo
o`00EP2`h>H2000000050:f][@000000Uf0;09MP2`2][Jd00`3CQ`h2000000<0dhL>0P2][Jd=0>nH
40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd30:f][@L0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Jd2000003l0/>3V0@3oool005H0/>3V0P0000001@2][Jd0000009MP2`2GH0/0
[Jf]00<0dhL>0P0000020=>73P80[Jf]3P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]1P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000
?`2`h>H10?ooo`00EP2`h>H2000000050:f][@000000Uf0;09MP2`2][Jd00`3CQ`h200000080[Jf]
00<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A
1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3P
iP40oooo001F0;3PiP<000000`2GH0/0102][Jd0dhL>0=>73P3CQ`h2000000<0dhL>00<0[Jf]0>nH
403_V1002`3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f]
[@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
0080^GD;0P2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]0P00000o0;3PiP40oooo001F0;3P
iP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P8000000`3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL20:f][@800000?`2`
h>H10?ooo`00EP2`h>H2000000060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd2000000<0dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0[Jf]0`28EPL0102][Jd0@FWQ
00000000000o0;3PiP40oooo001F0;3PiP80000000H0[Jf]09MP2`2GH0/0Uf0;045Yh@2][Jd20=>7
3P030000003CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP
4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@000000
000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0
000000@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH2
0:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00L0^GD;0P2][Jd308QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00<000000:f]
[@2GH0/00P2GH0/20:f][@<0dhL>00<000000=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`h>H30:f]
[@l0`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f]
[@<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`80
[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@03
0:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0
_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
R5H70:f][@0208QF1`030:f][@2`h>H0000003l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0
Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f]
[@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@2`h>H0000003l0/>3V0@3oool005H0
/>3V00@000000:f][@2GH0/0[Jf]0P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00X0kiP@0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f]
[@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0202][Jd0R5H708QF1`2][Jd0R5H70:f][@2`h>H00000
?`2`h>H10?ooo`00EP2`h>H010000000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80
[Jf]00<0/>3V0000002`h>H0?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]00<0/>3V0000002`h>H0?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]
0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BN
S`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0
_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0
`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005H0/>3V
00<000000:f][@2GH0/00`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100kiP@0>nH4080
[Jf]00D0Y9j?045Yh@11JN40Y9j?0:f][@040;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2]
[Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f]
[@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0:f][@2][Jd2045Yh@80Y9j?00<0@FWQ0:BNS`2][Jd01P2a
Zid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0040:f][@2d/;40];2a0;B`/@80
[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?P2`h>H10?oo
o`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd20:BNS`03045Yh@2TWXl0Y9j?
0080Y9j?00<0@FWQ0:f][@2aZid01`2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]1`2n^KP0
1011JN40_[Vh0;ji^02][Jd20;B`/@03045Yh@2d/;40];2a0080[Jf]2P2iM@/0102][Jd0R5H708QF
1`28EPL20:f][@800000?P2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>
00<0[Jf]0:BNS`2TWXl00P2TWXl00`11JN40Y9j?0:BNS`020:BNS`05045Yh@2][Jd0/J^M0;6[W@11
JN401`2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd90;ji^004045Yh@2n^KP0_[Vh0:f]
[@80];2a00<0@FWQ0;B`/@2d/;400P2d/;420:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2
000003h0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]2P2TWXl0
0`11JN40[Jf]0;6[W@02045Yh@T0/J^M0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0
`kfk0:f][@2n^KP01P2n^KP01011JN40_[Vh0;ji^011JN420;ji^0040:f][@2d/;40];2a045Yh@@0
];2a00<0@FWQ0;B`/@2][Jd01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?P2`h>H10?oo
o`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>00<0[Jf]045Yh@11JN402P2TWXl01@11
JN40/J^M0;6[W@2aZid0@FWQ00X0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H5
0:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00D0_[Vh00<0@FWQ0;ji^02n^KP00P11JN42
0;ji^0030:f][@2d/;40@FWQ00@0];2a0P11JN400`2d/;40[Jf]0:f][@050;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]0P00000n0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103C
Q`h0102][Jd0RXEe045Yh@11JN4:0:BNS`03045Yh@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
0`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00@0[Jf]0;ji^02n^KP0
@FWQ102n^KP00`11JN40_[Vh0;ji^002045Yh@80_[Vh00<0[Jf]0;B`/@11JN40102d/;400`11JN40
];2a0:f][@02045Yh@80[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?P2`h>H10?oo
o`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]045Yh@2:QGD00P11JN420:f]
[@03045Yh@2TWXl0Y9j?00@0Y9j?0P11JN4>0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0B0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f]
[@/0`kfk00<0[Jf]0;ji^011JN401@2n^KP00`11JN40_[Vh0;ji^002045Yh@80_[Vh00<0[Jf]045Y
h@11JN400`2d/;401011JN40];2a0:f][@2d/;42045Yh@0309nKX011JN40[Jf]0080^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Jd2000003h0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f]
[@3CQ`h20:f][@80@FWQ00<0RXEe045Yh@11JN400P2TWXl00`11JN40Y9j?0:BNS`030:BNS`80@FWQ
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f][@2n]j`0
4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
3`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]2`33_K/4045Yh@030;ji^011JN40_[Vh00@0_[Vh
00<0@FWQ0;ji^02n^KP00P11JN420;ji^0030:f][@11JN40@FWQ00<0];2a0P2][Jd20;B`/@80@FWQ
00<0Wi^P045Yh@2OVj000`2][Jd408QF1`030:f][@000000000003h0/>3V0@3oool005H0/>3V00<0
[Jf]09MP2`2GH0/00P2GH0/20:f][@<0RXEe00@0@FWQ08Z5M@2:QGD0@FWQ0P2TWXl01011JN40[Jf]
0:f][@2TWXl3045Yh@030:BNS`2][Jd0/J^M00d0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@03
0<K0_02][Jd0`kfk00X0`kfk00@0@FWQ0<>m^`33_K/0`kfk0`11JN440;ji^0<0@FWQ00<0_[Vh045Y
h@11JN400P2n^KP0102][Jd0@FWQ045Yh@2d/;420:f][@@0];2a1011JN4309nKX0030:f][@28EPL0
R5H70080R5H700<0[Jf]000000000000?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP
2`030:f][@2:QGD0RXEe00D0RXEe00@0@FWQ0:BNS`2TWXl0@FWQ0P2TWXl00`2][Jd0@FWQ045Yh@02
0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0:f][@03
0:f][@d0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0140al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/02@33_K/0
1@11JN40`kfk0<>m^`33_K/0[Jf]0080@FWQ102n^KP3045Yh@030;ji^011JN40@FWQ0080_[Vh00@0
[Jf]045Yh@11JN40[Jf]1P2d/;42045Yh@H0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@02000003h0
/>3V0@3oool005H0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@11JN4708Z5M@04045Yh@2TWXl0Y9j?
045Yh@80Y9j?00<0@FWQ0:BNS`2][Jd00P2TWXl0102][Jd0/J^M0;6[W@11JN4;0;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31
^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038
`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`00`36
`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/02@33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ102n
^KP5045Yh@040;ji^011JN40_[Vh00000080@FWQ1`2d/;42045Yh@H0Wi^P00H0[Jf]08QF1`28EPL0
R5H70:f][@00000o0;3PiP40oooo001F0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0@FWQ1`2:QGD0
102][Jd0@FWQ0:BNS`11JN420:BNS`03045Yh@2TWXl0Y9j?00<0[Jf]0P2aZid00`11JN40/J^M0;6[
W@090;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0
[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0
[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f][@11JN40@FWQ0080@FWQ1P33_K/2045Yh@@0`kfk0P11
JN440;ji^0D0@FWQ00@0_[Vh045Yh@2][Jd0[Jf]0P11JN460;B`/@80@FWQ00<0[Jf]09nKX02OVj00
1@2OVj001@2][Jd0R5H708QF1`2][Jd0000003l0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/0
0`2][Jd708Z5M@030:f][@2TWXl0@FWQ00<0Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl01011JN40[Jf]
0;6[W@11JN4;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@03
0;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@03
0:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0
[Jf]4036`;`4045Yh@P0`kfk0P11JN440<>m^`80@FWQ102n^KP4045Yh@070;ji^02][Jd0@FWQ0;ji
^02][Jd0];2a045Yh@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Jd00`28EPL0[Jf]0000000o
0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]1P2:QGD00`2][Jd0Y9j?0:BNS`04
0:BNS`04045Yh@2TWXl0Y9j?0:BNS`80@FWQ00<0/J^M0:f][@11JN402`2aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0@FWQ0080@FWQ3@2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@11
JN40@FWQ00P0`kfk0P11JN440<>m^`80@FWQ102n^KP4045Yh@070:f][@2n^KP0@FWQ0;ji^02][Jd0
];2a045Yh@040;B`/@05045Yh@2d/;40];2a0;B`/@2][Jd01`2OVj00102][Jd0L6ii0:f][@2][Je0
0;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<01@2][Jd0RXEe08Z5M@2:QGD0@FWQ0080RXEe00<0[Jf]
0:BNS`2TWXl0102TWXl01011JN40Y9j?0:BNS`2TWXl2045Yh@80/J^M00@0@FWQ0:f][@2][Jd0[Jf]
202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP040:f][@2n]j`0_[N/0;jg[0<0@FWQ302n]j`00`2][Jd0
`KZ`0<6j/0050:f][@`0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0
[Jf]1`37`K`00`2][Jd0a/2l0<K0_0060<K0_0<0@FWQ1`36`;`00`2][Jd0@FWQ045Yh@080<>m^`80
@FWQ1033_K/2045Yh@@0_[Vh00@0@FWQ0:f][@11JN40@FWQ0P2n^KP01@11JN40_[Vh0:f][@2d/;40
@FWQ00@0];2a00D0@FWQ0;B`/@2d/;40];2a0:f][@0609nKX080[Jf]00<0L6ii0:f][@2][Jd0@02`
h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd208Z5M@80@FWQ00<0RXEe0:f][@2TWXl01P2TWXl0
1@11JN40Y9j?0:BNS`11JN40[Jf]0080/J^M00@0@FWQ0;6[W@2aZid0/J^M0P2][Jd60;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00D0[Jf]0;jg[02n]j`0_[N/045Yh@020;jg[080@FWQ2P2n]j`00`2][Jd0
`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0
[Jf]3037`K`00`2][Jd0a/2l0<K0_0020<K0_0@0@FWQ0`36`;`2045Yh@D0a/2l00<0[Jf]045Yh@11
JN402033_K/2045Yh@@0`kfk00@0[Jf]045Yh@2n^KP0_[Vh0P2][Jd01011JN40_[Vh045Yh@11JN43
0;ji^004045Yh@2][Jd0];2a045Yh@@0];2a00D0@FWQ0;B`/@2d/;40];2a0:f][@0509nKX0030:f]
[@2OVj00[Jf]0080L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0
[Jf]08Z5M@2][Jd0RXEe045Yh@0208Z5M@030:f][@2TWXl0Y9j?00H0Y9j?0`11JN40102][Jd0/J^M
0;6[W@11JN450;6[W@<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0_[N/0080
_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@D0_[N/0P11JN400`2n]j`0[Jf]0<6j/00;0<6j/0D0
[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4@37`K`00`2][Jd0a/2l0<K0_0040<K0_003
045Yh@36`;`0a/2l00<0a/2l0`11JN430<K0_0030:f][@11JN40@FWQ00T0`kfk00<0@FWQ0<>m^`33
_K/00P33_K/0102][Jd0@FWQ0:f][@2][Jd20;ji^004045Yh@2n^KP0_[Vh045Yh@<0_[Vh00@0@FWQ
0:f][@2d/;40@FWQ102d/;401@11JN40];2a0;B`/@2d/;40[Jf]00@0Wi^P00@0[Jf]09nKX02OVj00
[Jf]0P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe
08Z5M@2][Jd308Z5M@030:f][@2TWXl0Y9j?00P0Y9j?00D0@FWQ0:f][@2aZid0/J^M045Yh@080;6[
W@80[Jf]00<0/J^M0:f][@2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/
00<0_[N/0P11JN460;jg[0<0@FWQ4031^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l
0140al6l00<0[Jf]0<K0_036`;`01036`;`00`11JN40a/2l0<K0_0040<K0_080@FWQ0`36`;`00`2]
[Jd0@FWQ045Yh@0:0<>m^`H0@FWQ0`2n^KP2045Yh@80_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN40
0`2d/;40@FWQ045Yh@030;B`/@05045Yh@2d/;40];2a0;B`/@2][Jd00P2OVj020:f][@<0Wi^P00<0
[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]
08Z5M@2:QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00@0[Jf]0;6[W@11JN40@FWQ
2P2aZid30:f][@h0^K:V00<0[Jf]0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0040;jg[003045Y
h@2n]j`0_[N/00@0_[N/00<0@FWQ0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]
1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0
b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01036`;`00`11JN40
a/2l0<K0_0040<K0_080@FWQ0`36`;`00`2][Jd0@FWQ045Yh@0:0<>m^`<0[Jf]00<0`kfk045Yh@11
JN400`2n^KP2045Yh@80_[Vh00L0@FWQ0;ji^011JN40@FWQ0;ji^02][Jd0];2a0080@FWQ0`2d/;42
045Yh@80];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]
00/0Y9j?00@0[Jf]0;6[W@11JN40@FWQ2`2aZid00`2][Jd0^K:V0:f][@020:f][@/0^K:V00<0[Jf]
0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ1@2n]j`00`11JN40[Jf]0<6j/00B
0<6j/0030:f][@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
045Yh@11JN401@11JN4?0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`0000003`38`K/9
0:f][A80b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0040<K0_003045Yh@36`;`0
a/2l00D0a/2l00D0@FWQ0<K0_036`;`0a/2l0:f][@02045Yh@L0`kfk0`2][Jd40<>m^`030:f][@11
JN40_[Vh0080_[Vh0P11JN420;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0[Jf]0;B`/@11JN40@FWQ
0`2d/;42045Yh@80];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`
h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`040:f][@2a
Zid0@FWQ045Yh@/0/J^M00<0[Jf]0;VbYP2i/ZH00P2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0
0P2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ1@2n]j`00`11JN40[Jf]0<6j/0090<6j/0H0@FWQ
0`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00D0[Jf]0<O1^037`KP0al6h045Yh@0B0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00@0a/2l00<0@FWQ0<K0_036`;`01@36`;`01`11JN40
a/2l0<K0_036`;`0[Jf]0<>m^`11JN401@33_K/20:f][@L0`kfk00<0[Jf]045Yh@2n^KP00P2n^KP3
045Yh@H0_[Vh00@0[Jf]0;B`/@2d/;40@FWQ0`2d/;42045Yh@80];2a00<0[Jf]09nKX02OVj001@2O
Vj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1S
H5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00@0[Jf]0;6[W@11JN40@FWQ
2`2aZid00`2][Jd0^K:V0;VbYP050;VbYP@0[Jf]102i/ZH00`2][Jd0_[N/0;jg[0020;jg[003045Y
h@2n]j`0_[N/00@0_[N/0P11JN450;jg[003045Yh@31^[00`KZ`00T0`KZ`0`11JN430<6j/004045Y
h@31^[00`KZ`0:f][@80@FWQ4`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL01@2][Jd0
al6h0<O1^037`KP0@FWQ0180al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0a/2l00@0a/2l00<0@FWQ0<K0
_036`;`01@36`;`2045Yh@80a/2l00<0[Jf]0<>m^`11JN400P33_K/30:f][@@0`kfk0P11JN430<>m
^`04045Yh@2n^KP0_[Vh0;ji^080@FWQ202n^KP0102][Jd0];2a0;B`/@11JN420;B`/@03045Yh@2d
/;40@FWQ00<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0
[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]2@2TWXl0102][Jd0/J^M045Yh@11JN4;0;6[W@03
0:f][@2i/ZH0^K:V00T0^K:V0`2][Jd00`2i/ZH0[Jf]0;jg[0030;jg[003045Yh@2n]j`0_[N/00@0
_[N/0P11JN450;jg[003045Yh@31^[00`KZ`00T0`KZ`00<0@FWQ0<6j/031^[001031^[03045Yh@P0
`kfc00<0@FWQ0<>m/`33_K<02P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0
a[ng402][Jd00`11JN40[Jf]0:f][@0M0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01036`;`00`11JN40
a/2l0<K0_0050<K0_080@FWQ0P36`;`00`2][Jd0`kfk045Yh@020:f][@L0`kfk0P11JN430<>m^`03
045Yh@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P11JN420;B`/@040:f][@2d/;40];2a
0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0
Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00@0[Jf]0;6[W@11JN40@FWQ
2`2aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]0`2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ
1@2n]j`00`11JN40`KZ`0<6j/0090<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN400`2][Jd0`kfc
0<>m/`060<>m/`03045Yh@33_K<0`kfc00<0`kfc00<0@FWQ0<>m/`33_K<01033_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00D0[Jf]0<O1^037`KP0al6h045Yh@0B0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1^`03
045Yh@38`K/0b<6k00`0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0040<K0_003
045Yh@36`;`0a/2l00D0a/2l0P11JN440:f][@80@FWQ0`33_K/00`11JN40`kfk0<>m^`030<>m^`05
045Yh@33_K/0`kfk045Yh@2][Jd03@2n^KP00`2][Jd0];2a0;B`/@020;B`/@03045Yh@2][Jd0[Jf]
00<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool0
05L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0
Y9j?00@0Y9j?00@0[Jf]0;6[W@11JN40@FWQ2`2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n
]j`0[Jf]0080[Jf]00<0@FWQ0;jg[02n]j`01@2n]j`2045Yh@@0_[N/00<0@FWQ0<6j/031^[002@31
^[000`11JN40`KZ`0<6j/0050<6j/003045Yh@2][Jd0`kfc00H0`kfc0P11JN450<>m/`03045Yh@33
_K<0`kfc00@0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D3045Yh@h0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL01@2][Jd0al6h0<O1^037`KP0@FWQ0180al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0<0<S1^`03045Yh@38`K/0b<6k00D0@FWQ00<0[Jf]0<S1^`38`K/00`38`K/00`11JN40b<6k
045Yh@0=0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_036`;`01036`;`00`11JN40a/2l
0<K0_0020<K0_0<0[Jf]0P11JN420<K0_0040:f][@33_K/0@FWQ045Yh@80`kfk00<0@FWQ0<>m^`11
JN401@33_K/2045Yh@030<>m^`2][Jd0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`
/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102]
[Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`040:f][@2aZid0
@FWQ045Yh@/0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0;jg[0020;jg[003045Yh@2]
[Jd0[Jf]0080[Jf]0`2n]j`2045Yh@<0_[N/0P11JN4;0<6j/003045Yh@31^[00`KZ`00D0`KZ`00<0
@FWQ0:f][@33_K<01P33_K<2045Yh@@0`kfc0P11JN460<>m/`040:f][@35_[D0aKje0<Fn]@<0@FWQ
0P35_[D2045Yh@030<Fn]@11JN40@FWQ00@0aKje1011JN400`35_[D0[Jf]0<Jo]`0F0<Jo]`050:f]
[@37`KP0al6h0<O1^011JN404P37`KP00`2][Jd0al6j0<O1^P0?0<O1^P0300000037`KX0al6j00<0
al6j00@0[Jf]0<S1^`38`K/0b<6k0`11JN480<S1^`03045Yh@38`K/0@FWQ00D0b<6k00<0@FWQ0<S1
^`38`K/01038`K/00`11JN40b<6k0<S1^`0<0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`01036`;`00`11JN40[Jf]0:f][@020:f][@<0a/2l0P11JN420<K0_0040:f][@33_K/0@FWQ
045Yh@<0`kfk0P11JN480<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d
/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0
[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl0102][Jd0/J^M045Y
h@11JN4:0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00@0[Jf]0;jg[02n]j`0_[N/0P11JN440;jg[0<0
[Jf]0P11JN430;jg[080@FWQ2`31^[000`11JN40`KZ`0<6j/0050<6j/003045Yh@2][Jd0`kfc00H0
`kfc0P11JN440<>m/`<0@FWQ1@33_K<00`2][Jd0aKje0<Fn]@02045Yh@H0aKje0`11JN460<Fn]@D0
@FWQ3036_kL4045Yh@D0a[ng00<0@FWQ0:f][@37`KP00P37`KP00`11JN40al6h0<O1^00?0<O1^0@0
@FWQ0P37`KX7045Yh@80al6j1`11JN430<O1^P040:f][@38`K/0@FWQ045Yh@<0b<6k0P11JN460<S1
^`80@FWQ1P38`K/00`2][Jd0@FWQ0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`0102][Jd00`11JN40a/2l0<K0_0060<K0_008045Yh@36`;`0a/2l0:f][@33_K/0@FWQ0<>m
^`11JN420<>m^`03045Yh@33_K/0`kfk00L0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`000000[Jf]
0:f][@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`
h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd20;6[W@03045Yh@2a
Zid0/J^M00P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0102][Jd0_[N/0;jg[02n]j`2045Yh@L0_[N/
0P11JN430:f][@80@FWQ2`31^[02045Yh@H0`KZ`00<0@FWQ0:f][@33_K<01P33_K<00`11JN40`kfc
045Yh@030<>m/`<0@FWQ1@33_K<00`2][Jd0aKje0<Fn]@02045Yh@H0aKje0`11JN460<Fn]@80@FWQ
00<0aKje0:f][@36_kL02P36_kL2045Yh@@0a[ng00@0@FWQ0<Jo]`36_kL0a[ng0P11JN401@2][Jd0
al6h0<O1^037`KP0@FWQ00<0al6h0`11JN480<O1^0D0@FWQ1`37`KX2045Yh@L0al6j0P11JN450<O1
^P030:f][@11JN40@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/00`38`K/2045Yh@H0b<6k00<0[Jf]045Y
h@38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]1036`;`00`11JN40a/2l0<K0_0060<K0
_006045Yh@36`;`0a/2l0:f][@33_K/0@FWQ0P33_K/2045Yh@X0`kfk00<0[Jf]0;ji^02n^KP02P2n
^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I
0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP040:f][@2n]j`0_[N/0;jg[080@FWQ1`2n]j`2045Yh@<0_[N/0P11JN430:f][@T0`KZ`00<0
@FWQ0<6j/031^[001031^[000`11JN40[Jf]0<>m/`050<>m/`80@FWQ00<0`kfc045Yh@33_K<00P33
_K<00`11JN40`kfc045Yh@050<>m/`030:f][@35_[D0aKje0080@FWQ1`35_[D2045Yh@H0aKje0P11
JN400`35_[D0[Jf]0<Jo]`0:0<Jo]`80@FWQ1@36_kL01P11JN40a[ng045Yh@11JN40a[ng0:f][@<0
al6h00@0@FWQ0<O1^011JN40@FWQ0P37`KP3045Yh@T0al6h0P11JN470<O1^P80@FWQ1`37`KX2045Y
h@D0al6j00<0[Jf]045Yh@38`K/01`38`K/00`11JN40b<6k0<S1^`020<S1^`03045Yh@38`K/0b<6k
00D0b<6k00<0[Jf]045Yh@38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2]
[Jd0a/2l0<K0_0040<K0_080@FWQ1`36`;`00`11JN40a/2l0<K0_003045Yh@h0`kfk00<0[Jf]0;ji
^02n^KP0202n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f]
[D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2]
[Jd00P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00@0[Jf]0;jg[02n]j`0_[N/0P11JN470;jg
[080@FWQ0`2n]j`3045Yh@80`KZ`1`2][Jd30<6j/080@FWQ0`31^[02045Yh@030:f][@33_K<0`kfc
00@0`kfc00@0@FWQ0<>m/`33_K<0@FWQ0P33_K<2045Yh@030<>m/`11JN40`kfc00@0`kfc00@0[Jf]
0<Fn]@11JN40@FWQ2035_[D2045Yh@H0aKje0P11JN400`35_[D0[Jf]0<Jo]`090<Jo]`80@FWQ1P36
_kL3045Yh@80a[ng00@0[Jf]0<O1^037`KP0al6h0P11JN460<O1^080@FWQ2037`KP2045Yh@L0al6j
0P11JN470<O1^P80@FWQ1@37`KX2045Yh@d0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045YhA@0b<6k
00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`01036`;`2045Yh@L0a/2l
00@0@FWQ0<K0_036`;`0[Jf]4033_K/00`2][Jd0_[Vh0;ji^0060;ji^080[Jf]0`2n^KP00`2][Jd0
];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f]
[@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]
1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP040:f][@2n]j`0_[N/0;jg[080@FWQ1`2n]j`2045Yh@<0
_[N/0`11JN490<6j/0D0[Jf]0P11JN401031^[00@FWQ045Yh@2][Jd60<>m/`04045Yh@33_K<0`kfc
045Yh@80`kfc0P11JN400`33_K<0@FWQ0<>m/`040<>m/`040:f][@35_[D0@FWQ045Yh@P0aKje0P11
JN460<Fn]@80@FWQ00<0aKje0:f][@36_kL02@36_kL2045Yh@L0a[ng0P11JN420<Jo]`050:f][@37
`KP0al6h0<O1^011JN402037`KP2045Yh@L0al6h0P11JN400`2][Jd0al6j0<O1^P040<O1^P80@FWQ
1`37`KX2045Yh@D0al6j0P11JN4D0<S1^`80@FWQ5@38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l
00<0[Jf]0<K0_036`;`01036`;`2045Yh@H0a/2l0P11JN420<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP00`2n^KP30:f][@D0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P
09nKX00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3oool005/0/>3V00<0[Jf]08Z5M@2:QGD0102:
QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M0`2][Jd40;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00@0[Jf]0;jg[02n]j`0_[N/0P11JN470;jg[080@FWQ0`2n]j`3045Yh@@0`KZ`
00<0@FWQ0<6j/031^[002@31^[03045Yh@@0[Jf]0`33_K<01011JN40`kfc0<>m/`11JN420<>m/`80
@FWQ00<0`kfc045Yh@33_K<01033_K<0102][Jd0aKje045Yh@11JN480<Fn]@80@FWQ1P35_[D2045Y
h@030<Fn]@2][Jd0a[ng00T0a[ng0P11JN470<Jo]`80@FWQ0P36_kL01@2][Jd0al6h0<O1^037`KP0
@FWQ00P0al6h0P11JN470<O1^080@FWQ00<0[Jf]0<O1^P37`KX01037`KX2045Yh@L0al6j0P11JN44
0<O1^P80@FWQ5038`K/2045Yh@030:f][@38`K/0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/02@38`K/6
0:f][A40al6l00<0[Jf]0<K0_036`;`01036`;`2045Yh@H0a/2l0P11JN430<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0
[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0
RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M
0:f][@2i/ZH03`2i/ZH0102][Jd0_[N/0;jg[02n]j`2045Yh@L0_[N/0P11JN430;jg[080@FWQ00@0
`KZ`045Yh@31^[00`KZ`0P11JN450<6j/080@FWQ1@31^[02045Yh@040:f][@33_K<0`kfc0<>m/`80
[Jf]0P11JN420:f][@04045Yh@33_K<0`kfc045Yh@<0`kfc00<0@FWQ0<>m/`33_K<00P33_K<00`2]
[Jd0@FWQ045Yh@090<Fn]@80@FWQ1P35_[D2045Yh@030<Fn]@2][Jd0a[ng00T0a[ng0P11JN470<Jo
]`80@FWQ0P36_kL01@2][Jd0al6h0<O1^037`KP0@FWQ00T0al6h00<0@FWQ0<O1^037`KP01@37`KP2
045Yh@030:f][@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1037`KX2045YhA80b<6k0`11JN40
0`38`K/0[Jf]0<S1^`050<S1^`03045Yh@38`K/0b<6k0080b<6k1`2][Jd30<S1^`030:f][@37`K`0
al6l0140al6l00<0[Jf]0<K0_036`;`01036`;`2045Yh@H0a/2l0P11JN430<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2O
Vj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@02
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00@0[Jf]
0;jg[02n]j`0_[N/0P11JN460;jg[080@FWQ0P2n]j`4045Yh@030<6j/011JN40`KZ`0080`KZ`00<0
@FWQ0<6j/031^[000`31^[02045Yh@D0`KZ`00<0@FWQ0<6j/02][Jd01@33_K<2045Yh@80`kfc00@0
@FWQ0:f][@11JN40@FWQ0`2][Jd00`11JN40[Jf]0<>m/`020<>m/`030:f][@11JN40@FWQ00T0aKje
0P11JN460<Fn]@80@FWQ00<0aKje0:f][@36_kL02@36_kL2045Yh@L0a[ng0P11JN420<Jo]`050:f]
[@37`KP0al6h0<O1^011JN402@37`KP00`11JN40al6h0<O1^0050<O1^080@FWQ00<0[Jf]0<O1^P37
`KX01037`KX2045Yh@L0al6j0P11JN440<O1^P80@FWQ4@38`K/3045Yh@80b<6k00@0[Jf]0<S1^`38
`K/0b<6k0`2][Jd00`11JN40[Jf]0:f][@020:f][@X0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2]
[Jd0a/2l0<K0_0040<K0_080@FWQ1P36`;`00`11JN40a/2l0<K0_0020<K0_0030:f][@33_K/0`kfk
00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3P
iP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0
/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP040:f][@2n]j`0_[N/0;jg[080@FWQ1P2n]j`2045Y
h@D0_[N/00<0[Jf]0<6j/031^[001011JN460<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j
/02][Jd01@33_K<2045Yh@80`kfc00@0@FWQ0<>m/`11JN40@FWQ0`33_K<00`11JN40`kfc0:f][@03
0:f][@80@FWQ0`2][Jd40<Fn]@H0@FWQ1035_[D2045Yh@030<Fn]@2][Jd0a[ng00X0a[ng0P11JN46
0<Jo]`80@FWQ0P36_kL01@2][Jd0al6h0<O1^037`KP0@FWQ00T0al6h00<0@FWQ0<O1^037`KP01@37
`KP2045Yh@030:f][@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1037`KX2045Yh@l0b<6k0`11
JN480:f][@<0b<6k00<0@FWQ0<S1^`38`K/03038`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36
`;`0a/2l00@0a/2l0P11JN460<K0_003045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/02@33
_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f]
[@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid0
0`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH0102][Jd0_[N/0;jg[02n]j`2045Yh@D0_[N/0P11
JN460;jg[0030:f][@31^[00`KZ`00X0`KZ`00<0@FWQ0<6j/031^[000`31^[000`11JN40`KZ`0:f]
[@050<>m/`03045Yh@33_K<0`kfc0080`kfc0`11JN430<>m/`06045Yh@33_K<0`kfc0<>m/`000000
[Jf]0P11JN430<Fn]@`0[Jf]0P35_[D2045Yh@030<Fn]@2][Jd0a[ng00/0a[ng0`11JN440<Jo]`80
@FWQ0P36_kL01@2][Jd0al6h0<O1^037`KP0@FWQ00T0al6h00<0@FWQ0<O1^037`KP01@37`KP2045Y
h@030:f][@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1037`KX2045Yh@D0b<6k0`2][Jd00`11
JN40[Jf]0:f][@030:f][@<0@FWQ1@38`K/00`2][Jd0@FWQ0<S1^`040<S1^`03045Yh@38`K/0b<6k
00`0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0_080@FWQ1@36`;`2045Y
h@@0a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2]
[Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH0102][Jd0_[N/0;jg[02n]j`2045Y
h@D0_[N/0P11JN460;jg[0030:f][@31^[00`KZ`00/0`KZ`1@11JN420<6j/0030:f][@33_K<0`kfc
0080`kfc0P11JN440<>m/`80@FWQ1033_K<00`11JN40`kfc0<>m/`020<>m/`030:f][@11JN40@FWQ
00l0aKje0P2][Jd2045Yh@d0[Jf]1036_kL2045Yh@80a[ng0P11JN420<Jo]`050:f][@37`KP0al6h
0<O1^011JN402@37`KP00`11JN40al6h0<O1^0050<O1^080@FWQ00<0[Jf]0<O1^P37`KX01037`KX2
045Yh@<0al6j102][Jd2045Yh@@0[Jf]0P11JN450:f][@80b<6k00<0@FWQ0<S1^`11JN401038`K/0
0`11JN40b<6k0<S1^`050<S1^`80@FWQ1@38`K/00`11JN40b<6k0<S1^`0<0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`00`36`;`0
0`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40
];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BN
S`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/
0080_[N/0P11JN440;jg[080@FWQ1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
00@0@FWQ1033_K<2045Yh@D0`kfc00D0@FWQ0<>m/`33_K<0`kfc0:f][@02045YhA40aKje0`11JN40
0`2][Jd0a[ng0<Jo]`090<Jo]`H0[Jf]1011JN460:f][@03045Yh@2][Jd0[Jf]00L0[Jf]00<0@FWQ
0:f][@2][Jd01@2][Jd2045Yh@L0[Jf]0P11JN430:f][@@0al6j0P11JN450<O1^P80@FWQ1`38`K/2
045Yh@@0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/03038`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l0P11JN440<K0_080@FWQ1@36`;`0
0`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@06
0;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP0=0;VbYP<0[Jf]1011JN440;jg[080@FWQ1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc0080`kfc1011JN420<>m/`80@FWQ1@33_K<01@11JN40`kfc0<>m/`33_K<0
[Jf]0080@FWQ4@35_[D3045Yh@030:f][@36_kL0a[ng0080a[ng00<0@FWQ0<Jo]`36_kL03036_kL2
045Yh@80a[ng00D0[Jf]0<O1^037`KP0al6h045Yh@080<O1^080@FWQ1`37`KP2045Yh@030:f][@37
`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1@37`KX2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00`38
`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ1@38`K/2045Yh@d0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_0030<K0_080@FWQ0P36`;`3045Yh@@0a/2l102][Jd>0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U
0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd5045Yh@P0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0<
0<>m/`H0@FWQ00@0`kfc0:f][@11JN40@FWQ4@35_[D3045Yh@040:f][@36_kL0a[ng0<Jo]`80@FWQ
1P36_kL2045Yh@H0a[ng00D0@FWQ00000036_kL0a[ng0:f][@030<O1^003045Yh@37`KP0al6h00H0
al6h0P11JN470<O1^080@FWQ00<0[Jf]0<O1^P37`KX01037`KX2045Yh@L0al6j0P11JN450<O1^P03
0:f][@11JN40@FWQ00H0b<6k00<0@FWQ0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`030<S1^`03
045Yh@2][Jd0@FWQ00D0b<6k0P11JN4=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`00`36`;`4045Yh@80a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP00`2][Jd0];2a0;B`/@030;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/
102][Jd90;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0@FWQ
045Yh@0A0<Fn]@80@FWQ00<0aKje045Yh@36_kL00`36_kL00`11JN40a[ng0<Jo]`040<Jo]`80@FWQ
1P36_kL01@11JN40a[ng0<Jo]`36_kL0[Jf]00<0al6h0P11JN460<O1^080@FWQ2037`KP2045Yh@03
0:f][@37`KX0al6j00<0al6j0P11JN480<O1^P80@FWQ1@37`KX0102][Jd0b<6k045Yh@11JN440<S1
^`03045Yh@38`K/0b<6k00H0b<6k1@11JN400`38`K/0[Jf]0<S1^`050<S1^`80@FWQ3@38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0040:f][@36`;`0a/2l0<K0_080@FWQ0P36`;`40:f][@L0a/2l00<0[Jf]
0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`
h>H10?ooo`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<0102][Jd0aKje045Yh@11JN4>0<Fn]@@0@FWQ00<0aKje0:f][@11JN400P11
JN400`36_kL0@FWQ0<Jo]`060<Jo]`03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL00P36
_kL01`2][Jd0al6h0<O1^037`KP0@FWQ0<O1^011JN401037`KP2045Yh@T0al6h1011JN440<O1^P80
@FWQ2037`KX2045Yh@D0al6j00<0[Jf]0<S1^`38`K/01@11JN4?0<S1^`030:f][@38`K/0b<6k00@0
b<6k0P11JN4=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3P
iP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0
_[N/102][Jd00`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33_K<0`kfc01<0`kfc00@0[Jf]0<Fn]@11
JN40@FWQ2@35_[D00`11JN40aKje0<Fn]@070<Fn]@040:f][@36_kL0a[ng0<Jo]`80@FWQ2036_kL5
045Yh@D0a[ng00<0[Jf]045Yh@11JN400P11JN420<O1^0@0@FWQ2`37`KP2045Yh@030:f][@37`KX0
@FWQ00<0@FWQ1`37`KX5045Yh@D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`04
0<S1^`80@FWQ3@38`K/00`2][Jd0al6l0<O1_00@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33_K<0`kfc
01<0`kfc00@0[Jf]0<Fn]@11JN40@FWQ2@35_[D00`11JN40aKje0<Fn]@070<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP04`37`KP2045Yh@030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ3@38`K/00`2][Jd0al6l0<O1_00;
0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V
00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<0102][Jd0aKje0<Fn]@11JN480<Fn]@80@FWQ2@35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01<0al6h0P11JN400`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01038`K/2045Yh@d0b<6k00<0[Jf]0<O1_037`K`01@37
`K`60:f][@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40oooo001a0;3PiP<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002031^[070:f][@<0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@02045Yh@L0aKje0P11JN490<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP04`37`KP2045Yh@030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1^`03045Yh@38`K/0b<6k00`0b<6k00<0[Jf]
0<O1_037`K`01@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m
/`050:f][@35_[D0aKje0<Fn]@11JN401P35_[D3045Yh@T0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00C0<O1^080@FWQ00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/02@38`K/60:f][A80al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL
0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00@0[Jf]
0<Fn]@35_[D0aKje0P11JN440<Fn]@04045Yh@35_[D0@FWQ045Yh@T0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00C0<O1^080@FWQ00<0[Jf]0<O1^P37`KX03@37`KX00`11JN40al6j
0<O1^P040<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02][Jd00P2][JeO0;3PiP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033
_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D00P35_[D5045Yh@<0aKje00<0@FWQ0<Fn]@35_[D01`35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01<0al6h0P11JN400`2][Jd0al6j0<O1
^P0<0<O1^P03045Yh@37`KX0@FWQ00D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1
^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][@L0aKje00<0
@FWQ0<Fn]@35_[D01`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01<0al6h0P11
JN400`2][Jd0al6j0<O1^P0<0<O1^P80@FWQ1P37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33
_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd5
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP04037`KP5045Yh@030:f][@37`KX0
al6j00d0al6j00<0@FWQ0<O1^P37`KX01037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/00`33_K/30:f][F`0/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL02@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0
a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;Vb
YP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102]
[Jd@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`00`36`;`40:f][Gh0/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180
`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0
[Jf]PP2`h>H10?ooo`00WP2`h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00?0<O1_0D0[Jf]QP2`h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_0080<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/0102][Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@
0<S1^`L0[Jf]V@2`h>H10?ooo`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0
[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38
`K/0b<6k202][JfW0;3PiP40oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0
[Jf][`2`h>H10?ooo`00d@2`h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52309 .3309 m
.51975 .33411 L
s
.52309 .3309 m
.51807 .3341 L
s
.52643 .3309 m
.52309 .3309 L
s
.52978 .33409 m
.52643 .3309 L
s
.53145 .33408 m
.52643 .3309 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50471 .33076 m
.49303 .33052 L
s
.55648 .3304 m
.54481 .33069 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54208 .32272 m
.55363 .32246 L
s
.5 Mabswid
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49803 .33208 m
.49803 .33064 L
s
.4997 .33111 m
.4997 .33067 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51729 .34086 m
.5206 .33862 L
s
.5206 .33862 m
.52557 .33861 L
s
.51563 .34085 m
.5206 .33862 L
s
.52557 .33861 m
.52888 .34085 L
s
.53716 .33853 m
.53881 .33851 L
s
.53385 .34082 m
.53716 .33853 L
s
.53551 .3408 m
.53716 .33853 L
s
.51563 .34536 m
.51729 .34086 L
s
.52888 .34085 m
.5322 .34534 L
s
.51397 .34535 m
.51563 .34085 L
s
.5322 .34534 m
.53385 .34082 L
s
.53386 .34533 m
.53551 .3408 L
s
.48095 .33786 m
.49248 .33822 L
s
0 0 0 r
.58474 .33887 m
.58727 .33371 L
s
.255 .412 .882 r
.55204 .3405 m
.55534 .33815 L
s
.55534 .33815 m
.55863 .33805 L
s
0 0 0 r
.51515 .35918 m
.51638 .36631 L
s
.51348 .35918 m
.5147 .3663 L
s
.58963 .33215 m
.58969 .33209 L
s
.59491 .3286 m
.59618 .32852 L
s
.53316 .36628 m
.53439 .35914 L
s
.53484 .36626 m
.53606 .35913 L
s
.58639 .33878 m
.58963 .33215 L
s
.255 .412 .882 r
.54875 .34509 m
.55204 .3405 L
s
.55863 .33805 m
.56194 .3402 L
s
.55863 .33805 m
.56359 .34014 L
s
.51563 .34987 m
.51563 .34536 L
s
.51397 .34986 m
.51397 .34535 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51563 .34987 m
.51728 .3544 L
s
.51397 .34986 m
.51562 .35439 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56359 .34014 m
.5669 .34454 L
s
.56194 .3402 m
.56526 .3446 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47097 .35554 m
.47109 .33745 L
s
.46933 .35546 m
.46945 .33738 L
s
.51728 .3544 m
.5206 .35667 L
s
.51562 .35439 m
.5206 .35667 L
s
.56526 .3446 m
.56694 .35132 L
s
.57835 .33726 m
.58979 .33664 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49962 .36039 m
.49962 .35914 L
s
.49794 .36137 m
.49794 .35907 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4874 .36975 m
.48753 .33808 L
s
.48574 .3697 m
.48589 .33803 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5669 .34454 m
.56859 .35125 L
s
.5206 .35667 m
.53056 .35891 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.54868 .32258 m
.54883 .36998 L
s
.54703 .32262 m
.54718 .37002 L
s
.5322 .34534 m
.53222 .36569 L
s
.53386 .34533 m
.53388 .36115 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46616 .33948 m
.4694 .34415 L
s
.46127 .33696 m
.46616 .33948 L
s
.458 .33678 m
.46127 .33696 L
s
.53056 .35891 m
.53222 .36116 L
s
.45472 .33885 m
.458 .33678 L
s
.45309 .33875 m
.458 .33678 L
s
.53222 .36569 m
.53388 .36115 L
s
.56694 .35132 m
.56696 .35584 L
s
.48746 .35615 m
.48908 .36299 L
s
.56859 .35125 m
.56861 .35578 L
s
.51561 .36344 m
.51727 .36345 L
s
.51727 .36572 m
.51727 .36345 L
s
.51561 .36571 m
.51561 .36344 L
s
0 0 0 r
.58644 .3638 m
.58659 .36463 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45143 .34317 m
.45472 .33885 L
s
.51561 .36571 m
.51727 .36799 L
s
.49901 .3655 m
.50068 .36326 L
s
.50068 .36326 m
.50233 .36556 L
s
.53057 .36797 m
.53222 .36569 L
s
.4498 .34307 m
.45309 .33875 L
s
.54881 .36318 m
.55214 .36764 L
s
.56535 .3627 m
.56696 .35584 L
s
.59629 .33624 m
.60762 .33543 L
s
.50232 .36783 m
.50233 .36556 L
s
.567 .36264 m
.56861 .35578 L
s
.51727 .36799 m
.52059 .37027 L
s
.52724 .37026 m
.53057 .36797 L
s
.46441 .35523 m
.47591 .35574 L
s
.49901 .3655 m
.50066 .3678 L
s
.48908 .36299 m
.49237 .36762 L
s
.50066 .37007 m
.50232 .36783 L
s
.52059 .37027 m
.52724 .37026 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5422 .37011 m
.54883 .36998 L
s
.55214 .36764 m
.55546 .36982 L
s
.44976 .3476 m
.45143 .34317 L
s
.49568 .36997 m
.50066 .37007 L
s
.49237 .36762 m
.49568 .36997 L
s
.56207 .36735 m
.56535 .3627 L
s
0 0 0 r
.60459 .35115 m
.60462 .35379 L
s
.255 .412 .882 r
.56372 .3673 m
.567 .36264 L
s
.44814 .34749 m
.4498 .34307 L
s
0 0 0 r
.60622 .34996 m
.60626 .35367 L
s
.255 .412 .882 r
.55546 .36982 m
.55877 .36973 L
s
.55877 .36973 m
.56207 .36735 L
s
.48078 .36954 m
.4874 .36975 L
s
.55877 .36973 m
.56372 .3673 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44807 .35429 m
.44976 .3476 L
s
.44645 .35419 m
.44814 .34749 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5849 .33692 m
.58526 .3846 L
s
.58326 .33701 m
.58362 .38468 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6042 .35644 m
.60462 .35379 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60116 .33591 m
.6014 .36085 L
s
.60278 .33579 m
.60302 .36073 L
s
.61406 .33492 m
.62525 .33394 L
s
.58509 .36183 m
.5884 .36619 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42888 .33472 m
.43496 .36704 L
s
.42209 .366 m
.42888 .33472 L
s
.44797 .36566 m
.44807 .35429 L
s
.47079 .3851 m
.47087 .37143 L
s
.46918 .37818 m
.47087 .37143 L
s
.44634 .36555 m
.44645 .35419 L
s
0 0 0 r
.40631 .32483 m
.40851 .32732 L
s
.255 .412 .882 r
.5884 .36619 m
.59332 .36819 L
s
.42369 .36614 m
.4288 .34152 L
s
.46586 .3826 m
.46918 .37818 L
s
.46918 .37818 m
.47079 .3851 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59982 .3655 m
.6014 .36085 L
s
.59332 .36819 m
.59658 .36799 L
s
.44797 .36566 m
.44954 .37259 L
s
.60144 .3654 m
.60302 .36073 L
s
.44634 .36555 m
.44791 .37249 L
s
.59658 .36799 m
.59982 .3655 L
s
.59658 .36799 m
.60144 .3654 L
s
.41612 .33356 m
.42209 .366 L
s
.40935 .36482 m
.41612 .33356 L
s
.46091 .38464 m
.46586 .3826 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57868 .38492 m
.58526 .3846 L
s
.44954 .37259 m
.45113 .37725 L
s
.44791 .37249 m
.4495 .37715 L
s
.45762 .38447 m
.46091 .38464 L
s
.45113 .37725 m
.45436 .38201 L
s
.43012 .36667 m
.43982 .36739 L
s
.41093 .36497 m
.41603 .34036 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4495 .37715 m
.45273 .38191 L
s
.45762 .38447 m
.45436 .38201 L
s
.45273 .38191 m
.45762 .38447 L
s
.63638 .33511 m
.64107 .33233 L
s
.63328 .33998 m
.63638 .33511 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62047 .33437 m
.62085 .36621 L
s
.61887 .33451 m
.61924 .36634 L
s
.63179 .34696 m
.63328 .33998 L
s
.63795 .33494 m
.64107 .33233 L
s
.63486 .33982 m
.63795 .33494 L
s
.63337 .3468 m
.63486 .33982 L
s
.64107 .33233 m
.6442 .33199 L
s
.61442 .36673 m
.62085 .36621 L
s
.63179 .34696 m
.63185 .35151 L
s
0 0 0 r
.40749 .35419 m
.40812 .3549 L
s
.255 .412 .882 r
.40036 .33189 m
.40193 .33207 L
s
0 0 0 r
.40686 .3536 m
.40749 .35419 L
s
.255 .412 .882 r
.63337 .3468 m
.63343 .35136 L
s
.6442 .33199 m
.64892 .33372 L
s
.3972 .33381 m
.40036 .33189 L
s
.39877 .33399 m
.40036 .33189 L
s
.63185 .35151 m
.63353 .3582 L
s
.63343 .35136 m
.63511 .35804 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39713 .33836 m
.39877 .33399 L
s
.39558 .33818 m
.3972 .33381 L
s
.63353 .3582 m
.63676 .36246 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64892 .33372 m
.65211 .3379 L
s
.39689 .35433 m
.39713 .33836 L
s
.61938 .37777 m
.62102 .37993 L
s
.6178 .38019 m
.61938 .37777 L
s
.63511 .35804 m
.63834 .3623 L
s
.4046 .36434 m
.4157 .36543 L
s
.6178 .38019 m
.61943 .38235 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39254 .33325 m
.39558 .33818 L
s
.38948 .33059 m
.39254 .33325 L
s
.39525 .35873 m
.39558 .33818 L
s
.61943 .38235 m
.62102 .37993 L
s
.38485 .33 m
.38948 .33059 L
s
.63676 .36246 m
.64153 .36426 L
s
.63834 .3623 m
.64153 .36426 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38174 .33187 m
.38485 .33 L
s
.38021 .33166 m
.38485 .33 L
s
.64153 .36426 m
.64625 .36376 L
s
.6628 .3297 m
.66441 .33405 L
s
.6628 .3297 m
.66296 .33883 L
s
.39525 .35873 m
.39689 .35433 L
s
.65077 .35178 m
.65236 .35389 L
s
.64924 .35425 m
.65077 .35178 L
s
.64924 .35425 m
.65084 .35636 L
s
.38454 .34827 m
.3938 .35169 L
s
.3938 .35169 m
.39533 .35416 L
s
.38013 .33623 m
.38174 .33187 L
s
.3786 .33602 m
.38021 .33166 L
s
.65236 .35389 m
.6524 .35618 L
s
.64625 .36376 m
.64935 .36112 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66296 .33883 m
.66441 .33405 L
s
.66441 .33405 m
.6659 .33157 L
s
.6659 .33157 m
.66891 .32886 L
s
.39366 .36085 m
.39525 .35873 L
s
.64935 .36112 m
.6524 .35618 L
s
.66891 .32886 m
.67497 .32799 L
s
.38005 .3408 m
.38013 .33623 L
s
.39051 .36278 m
.39366 .36085 L
s
.37852 .3406 m
.3786 .33602 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3815 .34558 m
.38454 .34827 L
s
.37997 .34538 m
.38454 .34827 L
s
.38005 .3408 m
.3815 .34558 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37852 .3406 m
.37997 .34538 L
s
.38431 .36202 m
.39051 .36278 L
s
.67497 .32799 m
.67803 .32982 L
s
.66319 .35256 m
.66469 .35007 L
s
.66319 .35256 m
.66327 .35715 L
s
.66469 .35007 m
.66771 .34737 L
s
.66323 .35485 m
.66473 .35236 L
s
.66473 .35236 m
.66775 .34966 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66771 .34737 m
.67523 .34172 L
s
.37981 .35455 m
.38135 .35475 L
s
.38131 .35704 m
.38135 .35475 L
s
.66327 .35715 m
.66485 .35924 L
s
.66775 .34966 m
.67527 .34401 L
s
.67803 .32982 m
.67958 .33189 L
s
.38127 .35934 m
.38431 .36202 L
s
.37977 .35684 m
.37981 .35455 L
s
.37977 .35684 m
.38127 .35934 L
s
.66485 .35924 m
.66796 .36114 L
s
.67958 .33189 m
.67971 .33876 L
s
.67523 .34172 m
.6782 .33899 L
s
.67527 .34401 m
.67825 .34128 L
s
.6782 .33899 m
.67966 .33647 L
s
.66796 .36114 m
.67406 .36032 L
s
.67825 .34128 m
.67971 .33876 L
s
.34883 .32451 m
.35915 .32625 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67406 .36032 m
.67705 .35759 L
s
.35404 .35774 m
.35471 .32552 L
s
.68995 .32794 m
.69138 .3254 L
s
.67851 .35507 m
.67993 .35024 L
s
.67993 .35024 m
.68011 .35946 L
s
.36613 .35265 m
.36759 .35517 L
s
.36755 .35747 m
.36759 .35517 L
s
.36458 .35473 m
.36613 .35265 L
s
.67705 .35759 m
.67851 .35507 L
s
.35256 .3575 m
.35323 .32527 L
s
.67851 .35507 m
.68011 .35946 L
s
.36599 .35956 m
.36755 .35747 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69138 .3254 m
.6929 .32745 L
s
.68995 .32794 m
.69148 .32999 L
s
.69148 .32999 m
.6929 .32745 L
s
.36458 .35473 m
.36604 .35725 L
s
.36149 .35889 m
.36599 .35956 L
s
.35854 .35613 m
.36149 .35889 L
s
.35432 .3439 m
.35566 .35105 L
s
.35566 .35105 m
.35854 .35613 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34814 .35678 m
.35404 .35774 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.692 .35532 m
.69229 .3692 L
s
.69081 .36943 m
.69172 .34148 L
s
.69172 .34148 m
.69377 .36897 L
s
.33722 .3247 m
.33998 .32985 L
s
.33998 .32985 m
.34132 .33472 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34132 .33472 m
.34261 .3419 L
s
.333 .32156 m
.33722 .3247 L
s
.33579 .32442 m
.33855 .32958 L
s
.33855 .32958 m
.33988 .33446 L
s
.69081 .36943 m
.69239 .37384 L
s
.33988 .33446 m
.34117 .34165 L
s
.34236 .35347 m
.34261 .3419 L
s
.333 .32156 m
.33579 .32442 L
s
.34091 .35321 m
.34117 .34165 L
s
.69239 .37384 m
.69377 .36897 L
s
.34075 .36017 m
.34236 .35347 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31902 .31865 m
.333 .32156 L
s
.33931 .35992 m
.34091 .35321 L
s
.3392 .36456 m
.34075 .36017 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32337 .36865 m
.32456 .31984 L
s
.33776 .36431 m
.33931 .35992 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33621 .3687 m
.3392 .36456 L
s
.33477 .36845 m
.33776 .36431 L
s
.33186 .37026 m
.33621 .3687 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32197 .36837 m
.32317 .31955 L
s
.33186 .37026 m
.33477 .36845 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31779 .36754 m
.33186 .37026 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76611 .30845 m
.77809 .30469 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76977 .30734 m
.77128 .35697 L
s
.77097 .30697 m
.7725 .35663 L
s
.77809 .30469 m
.7805 .30627 L
s
.77809 .30469 m
.78165 .30588 L
s
.7805 .30627 m
.78295 .31022 L
s
.78165 .30588 m
.7841 .30982 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78295 .31022 m
.78425 .31456 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7676 .35801 m
.77967 .35449 L
s
.7841 .30982 m
.78539 .31417 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78425 .31456 m
.78562 .32129 L
s
.78539 .31417 m
.78675 .3209 L
s
.78562 .32129 m
.78601 .33319 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77967 .35449 m
.78193 .35138 L
s
.77967 .35449 m
.7831 .35101 L
s
.78675 .3209 m
.78714 .3328 L
s
.78193 .35138 m
.7841 .34586 L
s
.78509 .34072 m
.78601 .33319 L
s
.7841 .34586 m
.78509 .34072 L
s
.7831 .35101 m
.78525 .34549 L
s
.78624 .34034 m
.78714 .3328 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7906 .30031 m
.79816 .29741 L
s
.5 Mabswid
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79388 .29908 m
.795 .33246 L
s
.25078 .30362 m
.25195 .30165 L
s
.25094 .29886 m
.25195 .30165 L
s
.78525 .34549 m
.78624 .34034 L
s
.24978 .30083 m
.25094 .29886 L
s
.79496 .29867 m
.79608 .33206 L
s
.24978 .30083 m
.25078 .30362 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7917 .33364 m
.79608 .33206 L
s
.25038 .31552 m
.25051 .34463 L
s
.7956 .31772 m
.79692 .32448 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24942 .34424 m
.2499 .32986 L
s
.79692 .32448 m
.79922 .32847 L
s
.24926 .34905 m
.25051 .34463 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24833 .34385 m
.25038 .31552 L
s
.2414 .29744 m
.24234 .30026 L
s
.24209 .30743 m
.24234 .30026 L
s
.23945 .29419 m
.2414 .29744 L
s
.24106 .30701 m
.24217 .30504 L
s
.24833 .34385 m
.24926 .34905 L
s
.24098 .3094 m
.24209 .30743 L
s
.23548 .29243 m
.23945 .29419 L
s
.23895 .30855 m
.24106 .30701 L
s
.23886 .31095 m
.24098 .3094 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79922 .32847 m
.80141 .33005 L
s
.80141 .33005 m
.80453 .32883 L
s
.24048 .3238 m
.24168 .31941 L
s
.24134 .32902 m
.24168 .31941 L
s
.80333 .32443 m
.80445 .32642 L
s
.80333 .32443 m
.80428 .32161 L
s
.80428 .32161 m
.80539 .3236 L
s
.23381 .31121 m
.23895 .30855 L
s
.23373 .31361 m
.23886 .31095 L
s
.24048 .3238 m
.24134 .32902 L
s
.23937 .32579 m
.24048 .3238 L
s
.23344 .29394 m
.23548 .29243 L
s
.80453 .32883 m
.80548 .32601 L
s
.80539 .3236 m
.80548 .32601 L
s
.23727 .32736 m
.23937 .32579 L
s
.23239 .2959 m
.23344 .29394 L
s
.81161 .29898 m
.8124 .29373 L
s
.81161 .29898 m
.81178 .30378 L
s
.8124 .29373 m
.81517 .28998 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2333 .32568 m
.23727 .32736 L
s
.81178 .30378 m
.81292 .30816 L
s
.81257 .29853 m
.81336 .29329 L
s
.81257 .29853 m
.81275 .30334 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23161 .29065 m
.23239 .2959 L
s
.23126 .30026 m
.23239 .2959 L
s
.81336 .29329 m
.81517 .28998 L
s
.23126 .30026 m
.23161 .29065 L
s
.23179 .31275 m
.23381 .31121 L
s
.81275 .30334 m
.81388 .30772 L
s
.2317 .31516 m
.23373 .31361 L
s
.81517 .28998 m
.81796 .28862 L
s
.81292 .30816 m
.81587 .30925 L
s
.81388 .30772 m
.81587 .30925 L
s
.23074 .31472 m
.23179 .31275 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23144 .32241 m
.2333 .32568 L
s
.81326 .3178 m
.81335 .32022 L
s
.81326 .3178 m
.81423 .31737 L
s
.23066 .31714 m
.2317 .31516 L
s
.81335 .32022 m
.8144 .3222 L
s
.81796 .28862 m
.81988 .29011 L
s
.81423 .31737 m
.81431 .31978 L
s
.23057 .31956 m
.23074 .31472 L
s
.23057 .31956 m
.23144 .32241 L
s
.81587 .30925 m
.82149 .309 L
s
.8144 .3222 m
.8164 .32376 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81988 .29011 m
.82185 .29402 L
s
.8164 .32376 m
.82012 .32202 L
s
.22325 .28895 m
.22486 .2947 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22071 .28513 m
.22325 .28895 L
s
.82185 .29402 m
.82256 .28873 L
s
.82185 .29402 m
.82266 .31583 L
s
.82256 .28873 m
.82422 .28538 L
s
.82274 .29356 m
.82344 .28826 L
s
.82274 .29356 m
.82337 .31052 L
s
.82344 .28826 m
.82422 .28538 L
s
.82422 .28538 m
.82509 .28491 L
s
.22414 .31406 m
.22423 .31163 L
s
.22342 .30876 m
.22423 .31163 L
s
.82149 .309 m
.82248 .31097 L
s
.82012 .32202 m
.82185 .3187 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.219 .28419 m
.22071 .28513 L
s
.22217 .31803 m
.22414 .31406 L
s
.22244 .31074 m
.22342 .30876 L
s
.22244 .31074 m
.22324 .31361 L
s
.82185 .3187 m
.82266 .31583 L
s
.82266 .31583 m
.82337 .31052 L
s
.21722 .28566 m
.219 .28419 L
s
.21639 .28519 m
.219 .28419 L
s
.22031 .31957 m
.22217 .31803 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21539 .28957 m
.21722 .28566 L
s
.21772 .31821 m
.22031 .31957 L
s
.21457 .28909 m
.21639 .28519 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21429 .29639 m
.21539 .28957 L
s
.21612 .31486 m
.21772 .31821 L
s
.21528 .3144 m
.21772 .31821 L
s
.21348 .29592 m
.21457 .28909 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82807 .318 m
.83383 .31479 L
s
.83252 .2806 m
.83695 .31292 L
s
.83059 .31663 m
.83252 .2806 L
s
.21411 .30127 m
.21429 .29639 L
s
.21464 .30906 m
.21612 .31486 L
s
.21411 .30127 m
.21464 .30906 L
s
.2133 .3008 m
.21348 .29592 L
s
.83141 .31617 m
.8328 .28791 L
s
.21383 .30859 m
.21528 .3144 L
s
.2133 .3008 m
.21383 .30859 L
s
.2057 .27591 m
.2109 .27937 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20729 .3122 m
.20862 .2779 L
s
.20654 .31173 m
.20788 .27741 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83859 .27667 m
.84279 .30911 L
s
.83695 .31292 m
.83859 .27667 L
s
.83771 .31245 m
.83887 .28401 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20435 .3103 m
.20729 .3122 L
s
0 0 0 r
.84748 .26455 m
.84784 .2632 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19849 .26507 m
.19854 .26397 L
s
.5 Mabswid
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19836 .27033 m
.20291 .2739 L
s
0 0 0 r
.84784 .2632 m
.84915 .26216 L
s
.255 .412 .882 r
.20587 .329 m
.20671 .32699 L
s
.20606 .32405 m
.20671 .32699 L
s
.20522 .32606 m
.20606 .32405 L
s
.84066 .31055 m
.84484 .30766 L
s
.20522 .32606 m
.20587 .329 L
s
.19983 .29949 m
.20091 .27238 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19918 .299 m
.20026 .27187 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19794 .2963 m
.19802 .29441 L
s
.1972 .29708 m
.19734 .29377 L
s
.5 Mabswid
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19898 .30395 m
.19983 .29949 L
s
.84719 .28293 m
.84762 .27748 L
s
.84686 .29085 m
.84719 .28293 L
s
.84762 .27748 m
.84863 .27152 L
s
.19833 .30346 m
.19918 .299 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84686 .29085 m
.84736 .30323 L
s
.84782 .28242 m
.84823 .27697 L
s
.84749 .29034 m
.84782 .28242 L
s
.19697 .30496 m
.19898 .30395 L
s
.84823 .27697 m
.84923 .271 L
s
.84863 .27152 m
.85029 .26749 L
s
.84749 .29034 m
.84799 .30273 L
s
.19697 .30496 m
.19833 .30346 L
s
.84923 .271 m
.85029 .26749 L
s
.19207 .26458 m
.19595 .26826 L
s
.84736 .30323 m
.84829 .31019 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84799 .30273 m
.84892 .3097 L
s
.85029 .26749 m
.85142 .26644 L
s
.19574 .30397 m
.19697 .30496 L
s
.84829 .31019 m
.84912 .31467 L
s
.1921 .31898 m
.19423 .26669 L
s
.84892 .3097 m
.84973 .31419 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85142 .26644 m
.85315 .26734 L
s
.19154 .31849 m
.19368 .26617 L
s
.19406 .29999 m
.19574 .30397 L
s
.84912 .31467 m
.85054 .31869 L
s
.84973 .31419 m
.85114 .3182 L
s
.19312 .294 m
.19406 .29999 L
s
.85315 .26734 m
.85439 .27126 L
s
.85408 .2638 m
.8549 .28371 L
s
.85332 .28526 m
.85687 .28163 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85114 .3182 m
.85242 .31973 L
s
.85054 .31869 m
.85242 .31973 L
s
.85459 .26327 m
.85541 .2832 L
s
.85242 .31973 m
.85355 .31875 L
s
.18992 .31701 m
.1921 .31898 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85355 .31875 m
.85509 .31476 L
s
.85509 .31476 m
.85593 .30874 L
s
.18763 .26227 m
.18832 .26833 L
s
.18832 .26833 m
.18847 .27636 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85742 .26006 m
.86031 .25626 L
s
.18827 .28136 m
.18847 .27636 L
s
.85613 .30071 m
.85675 .31578 L
s
.85593 .30874 m
.85613 .30071 L
s
.85593 .30874 m
.85675 .31578 L
s
.18719 .26173 m
.18787 .2678 L
s
.18787 .2678 m
.18801 .27583 L
s
.18749 .28835 m
.18827 .28136 L
s
.18645 .25815 m
.18763 .26227 L
s
.1878 .28083 m
.18801 .27583 L
s
.18703 .28783 m
.1878 .28083 L
s
.18645 .25815 m
.18719 .26173 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85872 .25843 m
.86018 .29357 L
s
.18638 .29234 m
.18749 .28835 L
s
.18565 .25706 m
.18645 .25815 L
s
.18355 .23509 m
.18599 .23902 L
s
.85913 .25789 m
.8606 .29306 L
s
.18594 .29182 m
.18703 .28783 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18478 .25848 m
.18565 .25706 L
s
0 0 0 r
.18143 .27696 m
.18144 .27678 L
s
.255 .412 .882 r
.85888 .29513 m
.8606 .29306 L
s
.18498 .2933 m
.18638 .29234 L
s
.18498 .2933 m
.18594 .29182 L
s
.85997 .27795 m
.86069 .28497 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18267 .29017 m
.18489 .23734 L
s
.18231 .28964 m
.18454 .23678 L
s
.18383 .26241 m
.18478 .25848 L
s
.18417 .29226 m
.18498 .2933 L
s
.86069 .28497 m
.86168 .28896 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86368 .276 m
.86376 .2779 L
s
.86507 .30888 m
.86572 .32415 L
s
.864 .27313 m
.86416 .27698 L
s
.86539 .30604 m
.86614 .32365 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18351 .28869 m
.18417 .29226 L
s
.86168 .28896 m
.86253 .29044 L
s
.18299 .28258 m
.18351 .28869 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86253 .29044 m
.86358 .28886 L
s
.18131 .28806 m
.18267 .29017 L
s
.18191 .25101 m
.1822 .25156 L
s
.86302 .28432 m
.86347 .28633 L
s
.86302 .28432 m
.86326 .28126 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18125 .25242 m
.18191 .25101 L
s
.18152 .25297 m
.18191 .25101 L
s
.86326 .28126 m
.86369 .28326 L
s
.86358 .28886 m
.8638 .2858 L
s
.18103 .25747 m
.18152 .25297 L
s
.86369 .28326 m
.8638 .2858 L
s
.18077 .25692 m
.18125 .25242 L
s
.18028 .27522 m
.18103 .25747 L
s
.18049 .25075 m
.18077 .25692 L
s
.1798 .27977 m
.18077 .25692 L
s
.86474 .25666 m
.86477 .25104 L
s
.86474 .25666 m
.86496 .26173 L
s
.86477 .25104 m
.86535 .24683 L
s
0 0 0 r
.17535 .23414 m
.17653 .2376 L
s
.86952 .24657 m
.86965 .2476 L
s
.255 .412 .882 r
.18014 .2471 m
.18049 .25075 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86496 .26173 m
.86542 .26626 L
s
.86499 .25611 m
.86501 .25048 L
s
.86499 .25611 m
.8652 .26118 L
s
.86501 .25048 m
.86535 .24683 L
s
0 0 0 r
.86937 .24297 m
.86986 .24703 L
s
.255 .412 .882 r
.1798 .27977 m
.18028 .27522 L
s
.8652 .26118 m
.86566 .26571 L
s
.17954 .24541 m
.18014 .2471 L
s
.17987 .2716 m
.18001 .27468 L
s
.86542 .26626 m
.86621 .26716 L
s
.86535 .24683 m
.86594 .24514 L
s
.17867 .26577 m
.17987 .2716 L
s
.17944 .28178 m
.1798 .27977 L
s
0 0 0 r
.86965 .2476 m
.87033 .25793 L
s
.255 .412 .882 r
.86566 .26571 m
.86621 .26716 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86585 .27643 m
.86596 .27898 L
s
.86585 .27643 m
.86609 .27589 L
s
0 0 0 r
.86986 .24703 m
.87053 .25736 L
s
.255 .412 .882 r
.17885 .28326 m
.17944 .28178 L
s
.86596 .27898 m
.86631 .28099 L
s
.17908 .24682 m
.17954 .24541 L
s
.17892 .24626 m
.17954 .24541 L
s
.86609 .27589 m
.8662 .27844 L
s
.86594 .24514 m
.86639 .24655 L
s
.86621 .26716 m
.86742 .26641 L
s
.86631 .28099 m
.86686 .28247 L
s
0 0 0 r
.87033 .25793 m
.87064 .2652 L
s
.255 .412 .882 r
.17801 .28111 m
.17885 .28326 L
s
0 0 0 r
.87053 .25736 m
.87084 .26465 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87088 .27812 m
.8709 .27669 L
s
.87064 .2652 m
.8709 .27669 L
s
.255 .412 .882 r
.1787 .25135 m
.17908 .24682 L
s
0 0 0 r
.87079 .23096 m
.87027 .23328 L
s
.255 .412 .882 r
.86639 .24655 m
.86691 .25053 L
s
0 0 0 r
.87104 .28174 m
.87111 .27614 L
s
.87084 .26465 m
.87111 .27614 L
s
.17314 .2852 m
.17434 .28845 L
s
.255 .412 .882 r
.17842 .26211 m
.17867 .26577 L
s
.17826 .26156 m
.17867 .26577 L
s
.86686 .28247 m
.86764 .28031 L
s
.17855 .25079 m
.17892 .24626 L
s
.17848 .25645 m
.1787 .25135 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17842 .26211 m
.17848 .25645 L
s
0 0 0 r
.17477 .23181 m
.17422 .22831 L
s
.255 .412 .882 r
.17833 .2559 m
.17855 .25079 L
s
0 0 0 r
.1739 .28737 m
.17445 .23007 L
s
.255 .412 .882 r
.86683 .24486 m
.86691 .25053 L
s
.86683 .24486 m
.86696 .24118 L
s
.17777 .27746 m
.17801 .28111 L
s
.17826 .26156 m
.17833 .2559 L
s
0 0 0 r
.17369 .28683 m
.17436 .22948 L
s
.255 .412 .882 r
.17782 .27179 m
.17799 .27234 L
s
.17788 .2749 m
.17799 .27234 L
s
.86695 .24429 m
.86704 .24996 L
s
.86695 .24429 m
.86696 .24118 L
s
.86742 .26641 m
.86767 .26842 L
s
.86764 .28031 m
.86786 .27666 L
s
.86696 .24118 m
.86706 .24061 L
s
.17771 .27436 m
.17777 .27746 L
s
.17771 .27436 m
.17782 .27179 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86704 .24996 m
.86781 .26787 L
s
.86691 .25053 m
.86789 .27355 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86647 .22161 m
.86676 .21752 L
s
0 0 0 r
.87114 .23343 m
.87126 .24188 L
s
.255 .412 .882 r
.86786 .27666 m
.86789 .27355 L
s
0 0 0 r
.8712 .22804 m
.87114 .23343 L
s
.255 .412 .882 r
.86781 .26787 m
.86789 .27355 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17213 .28083 m
.1761 .23645 L
s
.87129 .22686 m
.8712 .22804 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87079 .23096 m
.87301 .28221 L
s
.87067 .23154 m
.87289 .28276 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17255 .28302 m
.17198 .27973 L
s
.87149 .22935 m
.87129 .22686 L
s
.8715 .22877 m
.87129 .22686 L
s
.8733 .28057 m
.87289 .28276 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86763 .2386 m
.8678 .24488 L
s
.17679 .26998 m
.17683 .26685 L
s
.17668 .27256 m
.17679 .26998 L
s
0 0 0 r
.87182 .2361 m
.87149 .22935 L
s
.255 .412 .882 r
.1765 .27459 m
.17668 .27256 L
s
.17683 .26685 m
.17666 .26888 L
s
.86753 .23489 m
.86763 .2386 L
s
.17786 .23573 m
.17805 .23171 L
s
0 0 0 r
.87182 .23552 m
.8715 .22877 L
s
.255 .412 .882 r
.17666 .26888 m
.17661 .27201 L
s
.17635 .27295 m
.1765 .27459 L
s
0 0 0 r
.87359 .27671 m
.87182 .2361 L
s
.255 .412 .882 r
.8675 .23374 m
.86753 .23489 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86878 .27542 m
.86902 .27324 L
s
.8667 .21928 m
.86902 .27324 L
s
.86666 .21986 m
.86897 .27378 L
s
.86868 .26548 m
.86896 .26955 L
s
0 0 0 r
.87359 .27616 m
.87182 .23552 L
s
.17391 .22729 m
.1742 .22185 L
s
.17357 .23522 m
.17391 .22729 L
s
.255 .412 .882 r
.17632 .2702 m
.17788 .23401 L
s
0 0 0 r
.17181 .27587 m
.17357 .23522 L
s
.255 .412 .882 r
.8675 .23374 m
.86753 .23517 L
s
.86748 .23459 m
.8675 .23374 L
s
0 0 0 r
.17394 .2267 m
.1742 .22185 L
s
.17359 .23464 m
.17394 .2267 L
s
.255 .412 .882 r
.17642 .26926 m
.17635 .27295 L
s
.17635 .26965 m
.17791 .23344 L
s
0 0 0 r
.17182 .27532 m
.17359 .23464 L
s
.255 .412 .882 r
.86896 .26955 m
.86908 .27104 L
s
0 0 0 r
.1742 .22185 m
.17433 .22066 L
s
.255 .412 .882 r
.17642 .26926 m
.17664 .26297 L
s
.86753 .23517 m
.86764 .23919 L
s
.17664 .26297 m
.17699 .25465 L
s
0 0 0 r
.17182 .27753 m
.17182 .27532 L
s
.255 .412 .882 r
.86748 .23459 m
.86756 .23861 L
s
0 0 0 r
.17433 .22066 m
.17446 .22258 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86905 .26994 m
.86908 .27104 L
s
0 0 0 r
.87352 .2745 m
.87359 .27671 L
s
.255 .412 .882 r
.86764 .23919 m
.8679 .24639 L
s
.17649 .268 m
.17632 .2702 L
s
.86887 .26624 m
.86905 .26994 L
s
.86882 .26569 m
.86905 .26994 L
s
0 0 0 r
.87083 .2192 m
.87179 .24139 L
s
.255 .412 .882 r
.86756 .23861 m
.86781 .24582 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87179 .24139 m
.87071 .21861 L
s
.17446 .22258 m
.17438 .2288 L
s
.255 .412 .882 r
.8679 .24639 m
.86812 .25158 L
s
.86853 .25993 m
.86887 .26624 L
s
.86812 .25158 m
.86853 .25993 L
s
.86781 .24582 m
.86803 .25101 L
s
.86845 .25937 m
.86882 .26569 L
s
0 0 0 r
.17486 .21771 m
.17549 .21534 L
s
.1726 .26976 m
.17486 .21771 L
s
.255 .412 .882 r
.86803 .25101 m
.86845 .25937 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17788 .24846 m
.17799 .24594 L
s
.1774 .25072 m
.17835 .24677 L
s
.17774 .24903 m
.17787 .24614 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17225 .27143 m
.17274 .26921 L
s
.87325 .27491 m
.87412 .29687 L
s
.87423 .29741 m
.87325 .27491 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87112 .24165 m
.87242 .27158 L
s
.17644 .21922 m
.17652 .21237 L
s
.17587 .22727 m
.17652 .21237 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17628 .28302 m
.1764 .28035 L
s
0 0 0 r
.17274 .26921 m
.175 .21711 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17628 .28302 m
.17644 .28029 L
s
0 0 0 r
.87053 .2532 m
.87177 .25659 L
s
.17587 .22727 m
.17644 .21922 L
s
.17644 .21922 m
.17685 .21491 L
s
.17754 .21 m
.17685 .21491 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86804 .27952 m
.86875 .28169 L
s
.86624 .23746 m
.86652 .24402 L
s
.8677 .2717 m
.86804 .27952 L
s
.86644 .23832 m
.8667 .24429 L
s
.86791 .27256 m
.86823 .28006 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86771 .20971 m
.87083 .2192 L
s
.17754 .21 m
.17875 .20762 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1749 .24971 m
.1753 .24539 L
s
.17458 .25722 m
.1749 .24971 L
s
.1753 .24539 m
.17598 .2405 L
s
.17474 .25347 m
.17514 .24914 L
s
.17514 .24914 m
.17582 .24425 L
s
.17465 .26042 m
.17458 .25722 L
s
.17598 .2405 m
.17778 .23011 L
s
.17875 .20762 m
.17926 .21018 L
s
.17582 .24425 m
.17762 .23387 L
s
.17465 .26042 m
.175 .26308 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86876 .21209 m
.87217 .29094 L
s
.86851 .21149 m
.87192 .2904 L
s
.17926 .21018 m
.17945 .21334 L
s
.175 .26308 m
.17617 .26084 L
s
.17778 .23011 m
.17862 .22519 L
s
.17897 .22461 m
.17945 .21334 L
s
.17762 .23387 m
.17845 .22895 L
s
.17862 .22519 m
.17913 .22085 L
s
.17845 .22895 m
.17897 .22461 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87112 .28878 m
.87423 .29741 L
s
.17617 .26084 m
.17698 .25594 L
s
.17698 .25594 m
.17748 .2516 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17748 .2516 m
.17816 .24347 L
s
.17751 .25861 m
.17816 .24347 L
s
.255 .412 .882 r
.18586 .23289 m
.18595 .24807 L
s
0 0 0 r
.17748 .2516 m
.17751 .25861 L
s
.1824 .20546 m
.183 .20111 L
s
.1824 .20546 m
.18268 .20865 L
s
.255 .412 .882 r
.18547 .24214 m
.18549 .24862 L
s
0 0 0 r
.183 .20111 m
.1833 .20429 L
s
.18268 .20865 m
.1833 .20429 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18039 .27274 m
.18188 .22755 L
s
.17949 .27383 m
.18188 .22755 L
s
.255 .412 .882 r
.18595 .24807 m
.18743 .23149 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17993 .27328 m
.18091 .25035 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85595 .22655 m
.85605 .22903 L
s
0 0 0 r
.17949 .27383 m
.17961 .28096 L
s
.255 .412 .882 r
.85538 .22521 m
.85552 .22847 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8555 .22913 m
.85552 .22847 L
s
.85604 .22955 m
.85605 .22903 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17961 .28096 m
.18039 .27274 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83597 .19197 m
.8368 .19254 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31662 .13952 m
.32717 .13726 L
s
.72864 .13949 m
.73047 .1439 L
s
.72701 .14313 m
.72864 .13949 L
s
.72885 .14754 m
.73047 .1439 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31801 .17641 m
.31932 .177 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72701 .14313 m
.72885 .14754 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72937 .16775 m
.73239 .21703 L
s
.72889 .21632 m
.72937 .16775 L
s
.70906 .13544 m
.71279 .14018 L
s
.71279 .14018 m
.7147 .14458 L
s
.32301 .16225 m
.33929 .1591 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7017 .13406 m
.70906 .13544 L
s
.7147 .14458 m
.71499 .15673 L
s
.33801 .13511 m
.34914 .13309 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71318 .15638 m
.71489 .15268 L
s
.71328 .16044 m
.71499 .15673 L
s
.69807 .13744 m
.7017 .13406 L
s
.70964 .15975 m
.71318 .15638 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73001 .19214 m
.73064 .21667 L
s
.70973 .16382 m
.71328 .16044 L
s
.69628 .14117 m
.69807 .13744 L
s
.70057 .16624 m
.70964 .15975 L
s
.69422 .13274 m
.69628 .14117 L
s
.69422 .13274 m
.69457 .14898 L
s
.35291 .13244 m
.36633 .13028 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3201 .13875 m
.3305 .22186 L
s
.3305 .22186 m
.3454 .13375 L
s
.33079 .20951 m
.34354 .13409 L
s
.69457 .14898 m
.69628 .14117 L
s
.35743 .18869 m
.35862 .1315 L
s
.73086 .22488 m
.73239 .21703 L
s
.35936 .1884 m
.36053 .13119 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71548 .17707 m
.71588 .19341 L
s
.71386 .18489 m
.71548 .17707 L
s
.70066 .17032 m
.70973 .16382 L
s
.71214 .18864 m
.71386 .18489 L
s
.71386 .18489 m
.71588 .19341 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72889 .21632 m
.73086 .22488 L
s
.69691 .16968 m
.70057 .16624 L
s
.70856 .19207 m
.71214 .18864 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69699 .17377 m
.70066 .17032 L
s
.67705 .13403 m
.68109 .14276 L
s
.67109 .12911 m
.67705 .13403 L
s
.66715 .12855 m
.67109 .12911 L
s
.6951 .17346 m
.69691 .16968 L
s
.70112 .19079 m
.70856 .19207 L
s
.69519 .17755 m
.69699 .17377 L
s
.66325 .13208 m
.66715 .12855 L
s
.66125 .13182 m
.66715 .12855 L
s
.6951 .17346 m
.69528 .18165 L
s
.255 .412 .882 r
.66682 .16692 m
.67034 .16655 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35987 .16378 m
.36155 .17578 L
s
.65939 .13972 m
.66325 .13208 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69726 .18606 m
.70112 .19079 L
s
.69528 .18165 m
.69726 .18606 L
s
.65738 .13947 m
.66125 .13182 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6815 .16317 m
.68167 .17137 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67956 .16289 m
.6798 .17519 L
s
.35168 .18958 m
.35936 .1884 L
s
.67988 .1793 m
.68167 .17137 L
s
.39406 .13058 m
.40023 .12578 L
s
.38987 .13924 m
.39406 .13058 L
s
.36155 .17578 m
.36528 .18344 L
s
.39609 .13034 m
.40023 .12578 L
s
.39189 .13899 m
.39609 .13034 L
s
.40023 .12578 m
.40433 .12532 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66478 .16243 m
.66484 .16596 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65772 .15996 m
.6815 .16317 L
s
.65557 .1515 m
.65738 .13947 L
s
.63885 .12508 m
.64704 .126 L
s
.65759 .15175 m
.65939 .13972 L
s
.38765 .15177 m
.38987 .13924 L
s
.38967 .15152 m
.39189 .13899 L
s
.40433 .12532 m
.41045 .12875 L
s
.678 .18314 m
.6798 .17519 L
s
.678 .18314 m
.67988 .1793 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38751 .15997 m
.38765 .15177 L
s
.65759 .15175 m
.65772 .15996 L
s
.36528 .18344 m
.36912 .187 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38953 .15973 m
.38967 .15152 L
s
.65557 .1515 m
.6557 .15971 L
s
.63057 .12423 m
.63478 .12874 L
s
.6264 .12383 m
.63057 .12423 L
s
.41045 .12875 m
.41449 .13652 L
s
.63478 .12874 m
.63903 .13735 L
s
.67415 .18671 m
.678 .18314 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37322 .17822 m
.37528 .17384 L
s
.37528 .17384 m
.37719 .1777 L
s
.62227 .12753 m
.6264 .12383 L
s
.62017 .12734 m
.6264 .12383 L
s
.37322 .17822 m
.37513 .18208 L
s
.38751 .15997 m
.38932 .17207 L
s
.65772 .15996 m
.65995 .17254 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36912 .187 m
.37505 .1862 L
s
.38953 .15973 m
.39135 .17184 L
s
.6557 .15971 m
.65793 .1723 L
s
.37712 .18182 m
.37719 .1777 L
s
.42721 .12308 m
.44205 .1219 L
s
.66819 .18592 m
.67415 .18671 L
s
.61816 .13536 m
.62227 .12753 L
s
.61605 .13518 m
.62017 .12734 L
s
.37505 .1862 m
.37712 .18182 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65995 .17254 m
.66412 .18129 L
s
.65793 .1723 m
.66211 .18104 L
s
.66412 .18129 m
.66819 .18592 L
s
.66211 .18104 m
.66819 .18592 L
s
.38932 .17207 m
.39325 .17986 L
s
.39135 .17184 m
.3953 .17963 L
s
.61619 .14752 m
.61816 .13536 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61408 .14734 m
.61605 .13518 L
s
.45061 .12132 m
.46571 .12046 L
s
.58816 .12092 m
.59465 .12541 L
s
.58384 .12067 m
.58816 .12092 L
s
.255 .412 .882 r
.57347 .13578 m
.57413 .13552 L
s
0 0 0 r
.39325 .17986 m
.39934 .18332 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41207 .16139 m
.4141 .16532 L
s
.40993 .16572 m
.41207 .16139 L
s
.3953 .17963 m
.39934 .18332 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57737 .12445 m
.58384 .12067 L
s
.57954 .12455 m
.58384 .12067 L
s
.59465 .12541 m
.59902 .1339 L
s
.61619 .14752 m
.61629 .15576 L
s
.40993 .16572 m
.41195 .16965 L
s
.63548 .17811 m
.63951 .17025 L
s
.47439 .12005 m
.48967 .11951 L
s
.57526 .13257 m
.57954 .12455 L
s
.61408 .14734 m
.61417 .15559 L
s
.57308 .13247 m
.57737 .12445 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45669 .16629 m
.45707 .12093 L
s
.45886 .16617 m
.45922 .1208 L
s
.48063 .17768 m
.48093 .11979 L
s
.48282 .17761 m
.48311 .11972 L
s
.54678 .11929 m
.56211 .11971 L
s
.41404 .16945 m
.4141 .16532 L
s
.39934 .18332 m
.40554 .18268 L
s
.49844 .11929 m
.51381 .11907 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61629 .15576 m
.61856 .16833 L
s
.40975 .17812 m
.41404 .16945 L
s
.52261 .11903 m
.538 .11913 L
s
.61417 .15559 m
.61644 .16816 L
s
.57316 .14484 m
.57526 .13257 L
s
.57098 .14475 m
.57308 .13247 L
s
.40554 .18268 m
.40975 .17812 L
s
.63135 .18186 m
.63548 .17811 L
s
.61856 .16833 m
.62289 .17696 L
s
.59922 .15451 m
.5993 .16278 L
s
.57321 .1531 m
.59922 .15451 L
s
.61644 .16816 m
.62077 .17679 L
s
.62716 .18148 m
.63135 .18186 L
s
.59706 .15437 m
.59718 .16679 L
s
.62289 .17696 m
.62716 .18148 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63885 .12508 m
.64012 .21176 L
s
.6409 .12531 m
.6422 .21197 L
s
.62077 .17679 m
.62716 .18148 L
s
.57316 .14484 m
.57321 .1531 L
s
.43517 .16768 m
.43936 .17566 L
s
.57098 .14475 m
.57103 .15301 L
s
.255 .412 .882 r
.48889 .15826 m
.49208 .15747 L
s
.48777 .15977 m
.48889 .15826 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50489 .17709 m
.50502 .11917 L
s
.50711 .17706 m
.50722 .11914 L
s
.53141 .11907 m
.53146 .16451 L
s
.52921 .11905 m
.52925 .1645 L
s
.43936 .17566 m
.44577 .17939 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57103 .15301 m
.57329 .16554 L
s
.5951 .17495 m
.59718 .16679 L
s
.57321 .1531 m
.57548 .16563 L
s
.59722 .17093 m
.5993 .16278 L
s
.55555 .1195 m
.55574 .16493 L
s
.55336 .11944 m
.55353 .16487 L
s
.5951 .17495 m
.59722 .17093 L
s
.45445 .17471 m
.45669 .16629 L
s
.45662 .17459 m
.45886 .16617 L
s
.63385 .21117 m
.6422 .21197 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43257 .20946 m
.43355 .12255 L
s
.43471 .2093 m
.43567 .12238 L
s
.59081 .17886 m
.5951 .17495 L
s
.57548 .16563 m
.5799 .17414 L
s
.44577 .17939 m
.45009 .17912 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57329 .16554 m
.57772 .17404 L
s
.45009 .17912 m
.45445 .17471 L
s
.45009 .17912 m
.45662 .17459 L
s
.58429 .17851 m
.59081 .17886 L
s
.5799 .17414 m
.58429 .17851 L
s
.55357 .17319 m
.55574 .16493 L
s
.55136 .17313 m
.55353 .16487 L
s
.57772 .17404 m
.58429 .17851 L
s
.50713 .16458 m
.51154 .17285 L
s
.53146 .16451 m
.53589 .17287 L
s
.52925 .17282 m
.53146 .16451 L
s
.52704 .17281 m
.52925 .1645 L
s
.47404 .17793 m
.48282 .17761 L
s
.54696 .1772 m
.55357 .17319 L
s
.42617 .20994 m
.43471 .2093 L
s
.54696 .1772 m
.55136 .17313 L
s
.53589 .17287 m
.54254 .17712 L
s
.51154 .17285 m
.51818 .17697 L
s
.52261 .17696 m
.52925 .17282 L
s
.52261 .17696 m
.52704 .17281 L
s
.49826 .17721 m
.50711 .17706 L
s
.54254 .17712 m
.54696 .1772 L
s
.51818 .17697 m
.52261 .17696 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48052 .19856 m
.4827 .20268 L
s
.47829 .20283 m
.48052 .19856 L
s
.47829 .20283 m
.48047 .20694 L
s
.48047 .20694 m
.4827 .20268 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ000P3o
YQ09000000<0ojH@2@0000030?nV40@000007@3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P020>bF3P80[Jf]KP2`
h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40203oYQ49000000<0ojHA2@000007
0:f][@8000002P2][Jd2000000X0[Jf]1@0000090:f][@040?nU400000000000000000/0ojD@00<0
[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0
[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@P000001`2][Jd2
000000H0[Jf]103oYQ42000000030?nV4@2][Jd0ojH@00L0ojH@0P00000:0?nV40800000203oYQ00
102][Jd0ojD@00000000000;0?nU408000000`2][Jd2000000h0[Jf]5`3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][FP0/>3V0@3o
ool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0>0?nV4@030000003oYQ40ojHA00D0ojHA1`2][Jd2000000<0[Jf]1`3oYQ42
000000X0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV408000002P3oYQ02000000P0ojH@00@0[Jf]
0?nU4000000000002P3oYA02000000H0ojD@00<000000?nU403oYA001P3oYA000`2][Jd0oj<@0?nS
40020?nS40030:f][@0000000000008000000`2][Jd2000000d0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40oooo001j
0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ40303oYQ42000000030:f][@000000000000D0[Jf]103oYQ400`2][Jd0ojHA0?nV4@02
000000X0ojHA0P00000:0?nV4@80000000<0ojHA0:f][@3oYQ001`3oYQ02000000X0ojH@0P000008
0?nV40040:f][@3oYA000000000000T0ojD@0P0000070?nU40030000003oYA00ojD@00H0ojD@00@0
[Jf]0?nS403oXa00oj<@0`0000030?nS40030000003oXa00oj<@00D000001P2][Jd40?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]
H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA202][Jd2000000D0ojHA00<000000?nV4@3oYQ401P3o
YQ400`2][Jd0ojHA0?nV4@02000000X0ojHA0P00000:0?nV4@80000000<0ojHA0:f][@3oYQ001`3o
YQ02000000X0ojH@0P0000080?nV40040:f][@3oYA000000000000P0ojD@0P0000090?nU40030000
003oYA00ojD@00D0ojD@00H0[Jf]0?nS403oXa0000000?nS400000050?nS40040000003oXa000000
000000T0oj<@0`2][Jd3000000030:f][@3lX100o:0@01H0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0C0?nV4@<000001P2][Jd70?nV4@8000001P3oYQ400`00
0000ojHA0?nV4@060?nV4@030:f][@3oYQ40ojHA008000002P3oYQ42000000X0ojHA0P0000000`3o
YQ40[Jf]0?nV40070?nV408000002P3oYQ02000000P0ojH@00@0[Jf]0?nU400000000000203oYA02
000000T0ojD@00<000000?nU403oYA001@3oYA000`2][Jd0oj<@0?nS4002000000H0oj<@00@00000
0?nS4000000000002P3oXa02000000040?nS402][Jd0o:0@000000H0[Jf]4P3lX1000`2][Jd0mY`?
0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00/0ojHA0`0000000`3oYQ4000000000
0003000000040:f][@3oYQ40ojHA0:f][@X0ojHA0P0000080?nV4@030000003oYQ40ojHA00D0ojHA
00<0[Jf]0?nV4@3oYQ400P00000:0?nV4@8000002P3oYQ42000000030?nV4@2][Jd0ojH@00L0ojH@
0P00000:0?nV40800000203oYQ00102][Jd0ojD@0000000000070?nU408000002`3oYA000`000000
ojD@0?nU40040?nU40050:f][@3oXa0000000?nS400000001`3oXa03000000T0oj<@0P0000020?nS
40040:f][@3lX100o:0@000000D0o:0@102][Jd00`000000o:0@0?bP400;0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool0
0740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2]
[Jd0ojHA0?nV4@070?nV4@D00000102][Jd20?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@080?nV
4@800000203oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ40ojHA008000002P3oYQ420000
00X0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV408000002P3oYQ02000000P0ojH@00@0[Jf]0?nU
4000000000001`3oYA02000000/0ojD@00<000000?nU403oYA00103oYA00102][Jd0oj<@00000000
00080?nS40<00000203oXa02000000<0oj<@00D0[Jf]0?bP403lX100o:0@000000080?bP40030000
002][Jd0[Jf]00D000001P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>
00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ4200000080ojHA
1@2][Jd2000000H0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00L0ojHA0P00000:0?nV4@030000
003oYQ40ojHA00@0ojHA00<0[Jf]0?nV4@3oYQ400P00000:0?nV4@8000002P3oYQ42000000030?nV
4@2][Jd0ojH@00L0ojH@0P00000:0?nV40800000203oYQ00102][Jd0ojD@0000000000070?nU4080
00004P3oYA00102][Jd0oj<@0000000000090?nS40800000203oXa02000000<0oj<@00D0[Jf]0?bP
403lX100o:0@000000080?bP40030000003lX100000000<0o:0@0P2][Jd010000000[Jf]0:f][@2]
[Jd20?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@040=^:3@80[Jf]F@2`h>H10?ooo`00KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd000000000000000040:f][@D0ojHA0P00
00060?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@070?nV4@8000004@3oYQ400`2][Jd0ojHA0?nV
4@02000000X0ojHA0P00000:0?nV4@80000000<0ojHA0:f][@3oYQ001`3oYQ02000000X0ojH@0P00
00080?nV40040:f][@3oYA000000000000H0ojD@0P00000C0?nU40040:f][@3oXa000000000000T0
oj<@0P0000070?nS40800000103oXa000`2][Jd0o:0@0?bP40020?bP40030000003lX100o:0@00D0
o:0@0P0000060?bP40040000003lX100o:0@0?bP40@0[Jf]00<0mY`?0000003fW0l04P3fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80
[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00@0[Jf]00000000
0000[Jf]2P3oYQ42000000H0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00L0ojHA0P00000A0?nV
4@030:f][@3oYQ40ojHA008000002P3oYQ42000000X0ojHA0P0000000`3oYQ40[Jf]0?nV40070?nV
408000002P3oYQ02000000P0ojH@00@0[Jf]0?nU4000000000001P3oYA02000001<0ojD@00<0[Jf]
0000000000002P3oXa02000000L0oj<@0P0000040?nS40030:f][@3lX100o:0@0080o:0@00<00000
0?bP403lX1001@3lX102000000L0o:0@00<000000?bP403lX1000P3lX100102][Jd0mY`?00000000
00020:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`
h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?
0?nT4@@0[Jf]00<0oj@A0:f][@0000002P3oYQ42000000L0ojHA0P0000030?nV4@030:f][@3oYQ40
ojHA00L0ojHA0P00000@0?nV4@040:f][@3oYQ40ojHA0?nV4@8000002P3oYQ42000000X0ojHA0P00
00000`3oYQ40[Jf]0?nV40070?nV408000002P3oYQ02000000P0ojH@00@0[Jf]0?nU400000000000
1P3oYA02000001<0ojD@00<0[Jf]0000000000002P3oXa02000000L0oj<@0P0000040?nS40030:f]
[@3lX100o:0@00<0o:0@00<000000?bP403lX100103lX102000000L0o:0@00<000000?bP403lX100
0P3lX1001P2][Jd0mY`?0000003fW0l000000?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@000000ojHA00T0
ojHA0P0000070?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@070?nV4@030000003oYQ40ojHA00l0
ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000090?nV4@030000003oYQ40000000X0ojHA0P0000000`3o
YQ40[Jf]0?nV40070?nV408000002P3oYQ02000000P0ojH@00@0[Jf]0?nU4000000000001P3oYA02
000001<0ojD@00<0[Jf]0000000000002P3oXa02000000H0oj<@00<000000?nS40000000103oXa00
0`2][Jd0o:0@0?bP400:0?bP40030000003lX100o:0@00L0o:0@00T000000?bP403lX100o:0@0:f]
[@3fW0l000000?JL3`0000001@3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f]
[@3oYQ40000000T0ojHA0P0000070?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@800000
4@3oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA00<000000?nV4@0000002P3oYQ4200000003
0?nV4@2][Jd0ojH@00L0ojH@0P00000:0?nV40800000203oYQ00102][Jd0ojD@0000000000060?nU
408000004`3oYA000`2][Jd000000000000:0?nS408000001P3oXa02000000D0oj<@00<0[Jf]0?bP
403lX1002P3lX1000`000000o:0@0?bP40070?bP40050000003lX100o:0@0?bP402][Jd00P3fW0l0
0`000000mY`?0?JL3`080?JL3`@0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A00<0oj@A102][Jd=0?nT4@030:f][@3oYQ40000000T0ojHA0P0000070?nV
4@8000000`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000004@3oYQ40102][Jd0ojHA0?nV4@3oYQ42
000000T0ojHA00<000000?nV4@0000002P3oYQ4010000000ojHA0?nV4@2][Jd70?nV40030000003o
YQ00000000X0ojH@0P0000080?nV40040:f][@3oYA000000000000H0ojD@0P00000C0?nU40030:f]
[@000000000000X0oj<@0P0000060?nS408000001P3oXa000`2][Jd0o:0@0?bP40090?bP40030000
003lX100o:0@00L0o:0@00D000000?bP403lX100o:0@0:f][@020?JL3`030000003fW0l0mY`?00`0
mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2]
[Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@
00<0[Jf]0?nT4@2][Jd00`2][JdA0?nT4@030:f][@3oYQ40000000T0ojHA0P0000070?nV4@800000
0`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000004@3oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0
ojHA00<000000?nV4@0000002@3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ001@3oYQ000`000000
ojH@0000000:0?nV40800000203oYQ00102][Jd0ojD@0000000000060?nU408000004`3oYA000`2]
[Jd000000000000:0?nS408000001P3oXa02000000H0oj<@00<0[Jf]0?bP403lX1004`3lX1001@00
0000o:0@0?bP403lX100[Jf]01D0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]
0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3l
X100o:0@00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40000000T0ojHA0P0000070?nV4@8000000`3o
YQ400`2][Jd0ojHA0?nV4@060?nV4@8000004@3oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA
00<000000?nV4@0000002@3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ001@3oYQ000`000000ojH@
0000000:0?nV40800000203oYQ00102][Jd0ojD@0000000000060?nU40P000003@3oYA000`2][Jd0
00000000000:0?nS408000001P3oXa02000000H0oj<@00<0[Jf]0?bP403lX1004`3lX1001@000000
o:0@0?bP403lX100[Jf]01H0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=
00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP050:f][@3CQ`h0dhL>
0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1405@3oY140
0`2][Jd0ojHA000000080?nV4@800000203oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ42
00000140ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000090?nV4@030000003oYQ40000000T0ojHA0P00
00020?nV4@030:f][@3oYQ00ojH@00D0ojH@00<000000?nV400000002P3oYQ02000000P0ojH@00@0
[Jf]0?nU4000000000001P3oYA02000000H0ojD@1`0000060?nU40030:f][@000000000000X0oj<@
0P0000060?nS408000001P3oXa000`2][Jd0o:0@0?bP400B0?bP408000000`3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd30?bP40030:f][@3o
Y140oj@A01@0oj@A00<0[Jf]0?nV4@000000203oYQ42000000P0ojHA0P0000030?nV4@030:f][@3o
YQ40ojHA00H0ojHA0P00000A0?nV4@040:f][@3oYQ40ojHA0?nV4@8000002@3oYQ400`000000ojHA
000000060?nV4@<0[Jf]0P00000:0:f][@030000002][Jd0000000X0[Jf]0P00000:0:f][@800000
102][Jd20?nU40030000003oYA00000000X0ojD@0P0000060?nU40030:f][@000000000000X0oj<@
0P0000070?nS40030000003oXa00oj<@00@0oj<@00<0[Jf]0?bP403lX1004P3lX102000000<0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=
0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`
h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3l
X1020:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@0000070?nV4@<00000
203oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ4200000140ojHA00@0[Jf]0?nV4@3oYQ40
ojHA0P0000020?nV4@L0[Jf]00<000000:f][@0000001P2][Jd30?nV4@8000000P3oYQ400`2][Jd0
ojH@0?nV40050?nV40030000003oYQ00000000X0ojH@0P0000080?nV40040:f][@3oYA0000000000
00@0ojD@0P2][Jd00`000000[Jf]0000000:0:f][@8000001P3oYA000`2][Jd000000000000:0?nS
408000001`3oXa02000000D0oj<@00<0[Jf]0?bP403lX1004@3lX102000000@0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0
dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@P0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1401@2][Jd0ojHA0?nV4@3oYQ4000000080ojHA100000000`3o
YQ400000000000070?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000002P3oYQ400`00
0000ojHA0?nV4@080:f][@8000000P2][Jd70?nV4@030000003oYQ40000000T0ojHA0P0000020?nV
4@030:f][@3oYQ00ojH@00D0ojH@00<000000?nV400000002P3oYQ02000000P0ojH@00@0[Jf]0?nU
4000000000001`3oYA02000000X0ojD@0P0000070:f][@8000000P2][Jd80?nS408000001`3oXa07
000000030:f][@3lX100o:0@0100o:0@00<000000?bP40000000103lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>
00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0[Jf]
0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ43000000D0ojHA0P0000070?nV4@800000103o
YQ400`2][Jd0ojHA0?nV4@060?nV4@800000103oYQ460:f][@030000002][Jd0[Jf]00@0ojHA00@0
[Jf]0?nV4@3oYQ40ojHA0P0000090?nV4@030000003oYQ40000000T0ojHA0P0000020?nV4@030:f]
[@3oYQ00ojH@00D0ojH@00<000000?nV400000002P3oYQ02000000P0ojH@00@0[Jf]0?nU40000000
00001`3oYA02000000X0ojD@0P0000060?nU40030:f][@00000000000080oj<@202][Jd2000000L0
oj<@0P0000050?nS40H00000303lX1000`000000o:0@000000050?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f][@3oY140oj@A01<0
oj@A00D0[Jf]0?nV4@3oYQ40ojHA000000070?nV4@8000001`3oYQ42000000@0ojHA00<0[Jf]0?nV
4@3oYQ400P3oYQ440:f][@800000102][Jd50?nV4@030000003oYQ40000000D0ojHA00@0[Jf]0?nV
4@3oYQ40ojHA0P0000090?nV4@030000003oYQ40000000T0ojHA0P0000020?nV4@030:f][@3oYQ00
ojH@00D0ojH@00<000000?nV400000002P3oYQ02000000P0ojH@00@0[Jf]0?nU4000000000001`3o
YA000`000000ojD@000000090?nU408000001P3oYA00102][Jd0oj<@0000000000090?nS40800000
1`2][Jd2000000030:f][@3oXa00oj<@0080oj<@00@0[Jf]0?bP403lX100o:0@0P00000:0?bP4080
000000<0o:0@0000003lX1001@3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0
k9H>0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]
203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@050:f]
[@3oYQ40ojHA0?nV4@0000001P3oYQ42000000P0ojHA0P0000020?nV4@L0[Jf]103oYQ42000000T0
ojHA00<000000?nV4@0000001@3oYQ401P2][Jd0ojHA0?nV4@000000ojHA000000T0ojHA00<00000
0?nV4@0000002@3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ001@3oYQ000`000000ojH@00000009
0?nV40030000003oYQ00000000P0ojH@00@0[Jf]0?nU400000000000203oYA02000000T0ojD@00<0
00000?nU403oYA001@3oYA00102][Jd0oj<@0000000000090?nS408000001`3oXa02000000030?nS
402][Jd0[Jf]00H0[Jf]0P0000090?bP40040000003lX100o:0@000000L0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80
[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A40o:0@
00<0[Jf]0?nT4@3oY1404`3oY1401@2][Jd0ojHA0?nV4@3oYQ40000000H0ojHA0P0000060?nV4@80
[Jf]0P0000020:f][@80ojHA00<0[Jf]0?nV4@3oYQ401`3oYQ42000000P0ojHA00<000000?nV4@00
00001@3oYQ401P2][Jd0ojHA0?nV4@000000ojHA000000T0ojHA0P00000:0?nV4@8000000P3oYQ40
0`2][Jd0ojH@0?nV40050?nV40040000003oYQ000000000000P0ojH@0P0000000`3oYQ0000000?nV
40060?nV40030:f][@000000000000T0ojD@0P0000090?nU40030000003oYA00ojD@00D0ojD@00@0
[Jf]0?nS4000000000002P3oXa000`000000oj<@0?nS40060?nS40800000103oXa00102][Jd0o:0@
0?bP403lX102000000@0[Jf]103lX10010000000o:0@0000000000080?bP40040:f][@3fW0l0mY`?
000001<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][@T0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]
00P0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@80kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@050:f][@3oYQ40ojHA0?nV4@0000001P3oYQ42000000030?nV4@2][Jd0
[Jf]00<0[Jf]0P3oYQ42000000@0ojHA00<0[Jf]0?nV4@3oYQ401`3oYQ42000000T0ojHA0P000005
0?nV4@050:f][@3oYQ40ojHA0000003oYQ400P0000070?nV4@030000003oYQ40000000X0ojHA0P00
00020?nV4@030:f][@3oYQ00ojH@00D0ojH@00@000000?nV4000000000001`3oYQ001@000000ojH@
0000003oYQ00000000L0ojH@00<0[Jf]0000000000002P3oYA02000000L0ojD@0P0000070?nU4004
0:f][@3oXa000000000000T0oj<@0`0000070?nS40800000103oXa00102][Jd0o:0@0?bP403lX102
000000@0o:0@0`2][Jd010000000[Jf]0000002][Jd90?bP40040:f][@3fW0l0mY`?000001<0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]
203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00D0[Jf]0?nV4@3oYQ40ojHA000000040?nV4@80[Jf]0P0000000`2][Jd0
ojHA0?nV4@050?nV4@<000000`3oYQ400`2][Jd0ojHA0?nV4@070?nV4@8000002@3oYQ400`000000
ojHA0?nV4@040?nV4@050:f][@3oYQ40ojHA0000003oYQ400P0000070?nV4@8000002`3oYQ420000
0080ojHA00<0[Jf]0?nV403oYQ001@3oYQ001@000000ojH@0000003oYQ00000000H0ojH@00<00000
0?nV400000000P3oYQ000`000000ojH@0?nV40040?nV40030:f][@000000000000X0ojD@0P000007
0?nU40030000003oYA00ojD@00H0ojD@00<0[Jf]0?nS403oXa000P0000070?nS40040000003oXa00
0000000000L0oj<@0P0000040?nS40040:f][@3lX100o:0@0?bP408000001P3lX1000`000000o:0@
000000020?bP40H0[Jf]0`3lX100102][Jd0mY`?0?JL3`00000C0?JL3`030:f][@3/UPh0k9H>0100
k9H>00<0[Jf]0=^:3@3KRPd0103KRPd00`2][Jd0fhX=0=^:3@040=^:3@030:f][@2iM@/0^GD;00L0
^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>7
3P030:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ400P2][Jd010000000[Jf]0:f][@2][Jd2
0?nV4@800000203oYQ43000000<0ojHA00@0[Jf]0?nV4@3oYQ4000001P3oYQ400`000000ojHA0000
00080?nV4@030000003oYQ40ojHA00@0ojHA00P0[Jf]0?nV4@3oYQ4000000?nV4@000000ojHA0000
00H0ojHA0P00000;0?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40050?nV40030000003oYQ000000
0080ojH@0P0000030?nV40<00000103oYQ02000000<0ojH@0`00000<0?nU408000001P3oYA000`00
0000ojD@0?nU40060?nU40030:f][@3oXa00oj<@008000001`3oXa0010000000oj<@000000000007
0?nS40800000103oXa00102][Jd0o:0@0?bP403lX102000000H0o:0@0P0000090?bP40D0[Jf]00<0
mY`?0000003fW0l04P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2]
[Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo
001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]
1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0180oj@A102][Jd20?nV4@030000
003oYQ40ojHA00<0ojHA0P0000080?nV4@<000000`3oYQ40102][Jd0ojHA0000000000070?nV4@80
00001`3oYQ400`000000ojHA0?nV4@050?nV4@060:f][@3oYQ40ojHA0000003oYQ4000000P3oYQ42
000000<0ojHA0P00000<0?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40020?nV40H00000103oYQ04
000000P0ojH@100000000`2][Jd0ojD@0?nU400<0?nU40800000103oYA000`000000ojD@0?nU4007
0?nU40040:f][@3oXa00oj<@0?nS408000001@3oXa000`000000oj<@0?nS4002000000P0oj<@0P00
00030?nS40040:f][@3lX100o:0@0?bP408000001P3lX1000`000000o:0@0?bP40070?bP40080000
003lX100o:0@0?bP402][Jd0mY`?0:f][@0000020:f][A40mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
0`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0
R5H708QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0
[Jf]0>nH403_V1000P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403P3o
Y1440:f][@030?nT4@2][Jd0ojHA00<0ojHA00<000000?nV4@3oYQ400P3oYQ42000000T0ojHA0P00
00002@3oYQ4000000?nV4@3oYQ40[Jf]0?nV4@000000ojHA000000060?nV4@030000003oYQ400000
00H0ojHA00<000000?nV4@3oYQ401@3oYQ401P2][Jd0ojHA0?nV4@000000ojHA000000@0ojHA0`00
000;0?nV4@@000000`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00h0ojD@1000
000:0?nU40030:f][@3oXa00oj<@0080oj<@0P0000040?nS40030000003oXa00oj<@00800000203o
Xa02000000<0oj<@00@0[Jf]0?bP403lX100o:0@0P0000060?bP40030000003lX100o:0@00L0o:0@
00D000000?bP403lX100o:0@0:f][@020?JL3`030000003fW0l0mY`?00@0[Jf]3@3fW0l00`2][Jd0
k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00T0fhX=0`2][Jd90;Ue2`030:f][@28EPL0R5H70080
R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f]
[@3CQ`h0dhL>00H0dhL>0`2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
2P3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@020?nV4@800000
2@3oYQ42000000090?nV4@000000ojHA0?nV4@2][Jd0ojHA0000003oYQ40000000L0ojHA0`000004
0?nV4@030000003oYQ40ojHA00H0ojHA00H0[Jf]0?nV4@3oYQ4000000?nV4@00000I0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40040?nS40040000
003oXa00oj<@000000<0oj<@0P0000090?nS408000000P3oXa001@2][Jd0o:0@0?bP403lX1000000
00L0o:0@00<000000?bP403lX1001P3lX102000000<0o:0@00@0[Jf]0?JL3`3fW0l000001P3fW0l4
0:f][@T0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY1430:f][@T0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ40
0`000000ojHA0?nV4@020?nV4@8000002@3oYQ4200000080ojHA00<000000?nV4@2][Jd00P3oYQ42
000000T0ojHA1@0000090?nV4@060:f][@3oYQ40ojHA0000003oYQ4000006@3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa001@3oXa02000000@0oj<@
0P00000:0?nS4080000000<0oj<@0:f][@3lX1000P3lX1000`000000o:0@0?bP40050?bP40030000
003lX100o:0@00H0o:0@0P0000030?bP40030:f][@3fW0l0mY`?008000002@3fW0l40:f][@D0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@080=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0oj@A
102][Jd<0?nT4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@3oYQ400P3oYQ42000000T0ojHA
0P0000030?nV4@050000002][Jd0ojHA0?nV4@000000603oYQ401P2][Jd0ojHA0?nV4@000000ojHA
000001T0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@00/0oj<@0P00000;0?nS40030000003oXa00[Jf]0080o:0@00<000000?bP403lX1001`3lX100
0`000000o:0@0?bP40050?bP408000000`3lX1000`2][Jd0mY`?0?JL3`02000000d0mY`?102][Jd0
0`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2i
M@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@060=>73P80[Jf]00<0dhL>0:f][@3_V1002`3_V1000`2][Jd0o:0@0?bP
400@0?bP40030:f][@3oY140[Jf]00<0[Jf]403oY1400`2][Jd0ojHA0?nV4@030?nV4@040000003o
YQ40ojHA0?nV4@8000002@3oYQ42000000<0ojHA00<0[Jf]0000000000000P00000H0?nV4@060:f]
[@3oYQ40ojHA0000003oYQ4000006@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa002`3oXa02000000`0oj<@1000000:0?bP40030000003lX100o:0@
00D0o:0@0P0000030?bP40030:f][@3fW0l0mY`?008000004@3fW0l30:f][A40k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h0
1@2][Jd0dhL>0=>73P3CQ`h0[Jf]00`0kiP@00<0[Jf]0?bP403lX1003`3lX1030:f][A@0oj@A00<0
[Jf]0?nV4@3oYQ400`3oYQ4010000000ojHA0?nV4@3oYQ42000000H0ojHA1@0000030?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00H0[Jf]0?nV4@3oYQ4000000?nV4@00000I0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS408000003@3oXa000`2]
[Jd0o:0@0?bP400;0?bP40030000003lX100o:0@00@0o:0@0P0000030?bP40030:f][@3fW0l0mY`?
008000004P3fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2]
[Jd0^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f]
[D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P030:f][@3CQ`h0dhL>
0080dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]00<0o:0@0:f]
[@3oY140503oY1400`2][Jd0ojHA0?nV4@030?nV4@030000003oYQ40ojHA008000003`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@060:f][@3oYQ40ojHA0000003oYQ4000006@3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa02000000d0oj<@00<0
[Jf]0?bP403lX100303lX102000000<0o:0@00<000000?bP400000000`3lX1000`2][Jd0mY`?0?JL
3`0200000180mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0dhL>00<0dhL>
00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]103lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ400P00000?0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00H0[Jf]0?nV4@3oYQ4000000?nV4@00000I0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS408000003@3oXa000`2]
[Jd0o:0@0?bP400>0?bP40<000000P3lX1001@000000o:0@0?bP403lX100[Jf]0080mY`?0P00000B
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
045Yh@2iM@/0102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H70P2][Je20;3PiP40oooo001I0;3P
iP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd60=>73P030:f][@3_V100kiP@00X0kiP@00<0
[Jf]0?bP403lX1001`3lX1030:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@030?nV4@030000003oYQ40ojHA008000003`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@060:f][@3o
YQ40ojHA0000003oYQ4000004P3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa002`3oXa02000000d0
oj<@00<0[Jf]0?bP403lX100603lX100102][Jd0mY`?00000000000B0?JL3`030:f][@3/UPh0k9H>
00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f]
[@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]203CQ`h00`2]
[Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd90?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA0?nV4@02000000l0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ401P2][Jd0ojHA0?nV4@000000ojHA00000080ojHA402][Jd70?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa002`3o
Xa02000000d0oj<@00<0[Jf]0?bP403lX100603lX100102][Jd0mY`?00000000000B0?JL3`030:f]
[@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100
0P3lX1020:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@030?nV4@030000
003oYQ40ojHA008000003`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@L0[Jf]00<000000:f][@000000
0P2][JdC0?nV4@050000003oYQ40ojHA0?nV4@2][Jd07P3oYQ000`2][Jd0ojD@0?nU400E0?nU40`0
[Jf]2@3oXa02000000d0oj<@00<0[Jf]0?bP403lX100603lX100102][Jd0mY`?00000000000B0?JL
3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/0^GD;
00H0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`00
00000P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd>0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40103oYQ4010000000ojHA00000000000?0?nV
4@030:f][@3oYQ40ojHA00`0ojHA2P2][Jd40?nV4@060:f][@3oYQ40ojHA0000003oYQ400000503o
YQ42000000<0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@0080oj<@2@2][Jd2000000d0oj<@00<0[Jf]0?bP403lX100603lX100102][Jd0mY`?0000
0000000B0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;
0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`0000000P2]
[Jd80=>73P030:f][@3_V100kiP@00/0kiP@0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0
[Jf]0?nV4@3oYQ40103oYQ4300000100ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00H0
[Jf]0?nV4@3oYQ4000000?nV4@00000D0?nV4@030000003oYQ4000000080ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@0P0000090:f][@@0
oj<@00<0[Jf]0?bP403lX100603lX100102][Jd0mY`?00000000000B0?JL3`030:f][@3/UPh0k9H>
0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0
[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0000002GH0/0
[Jf]00P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@040?nV4@<000003@3oYQ480:f][AP0ojHA00H0[Jf]0?nV4@3oYQ4000000?nV
4@00000D0?nV4@8000000`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa002`3oXa02000000T0oj<@202][JdG0?bP40040:f][@3fW0l0000000000180
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/0102][Jd0R5H708QF1`2][Jd208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool0
05T0/>3V00D0000009MP2`000000Uf0;0:f][@080=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd2
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@04
0?nV4@<000001`3oYQ460:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ401P2][Jd0ojHA0?nV4@00
0000ojHA000001D0ojHA00D000000?nV4@3oYQ40ojHA0:f][@0N0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa002`3oXa02000000d0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP
40030:f][@3fW0l00000008000004P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00<0fhX=0P2][Jd70=^:3@030:f][@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28
EPL0[Jf]0480/>3V0@3oool005P0/>3V0P000000102][Jd0000009MP2`2][Jd80=>73P030:f][@3_
V100kiP@00D0kiP@0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503o
Y1400`2][Jd0ojHA0?nV4@040?nV4@<000001`2][Jd90?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ400`00000I0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400;0?nS408000003@3oXa000`2][Jd0o:0@0?bP40080?bP40H0[Jf]2P3l
X1000`2][Jd0mY`?0000000200000180mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H708QF1`2][Jd0
R5H7000000120;3PiP40oooo001H0;3PiP80000000@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0
kiP@0>nH40030>nH4080[Jf]1P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0
oj@A00@0[Jf]0?nV4@3oYQ40ojHA0`2][Jd00`000000[Jf]0000000@0?nV4@030:f][@3oYQ40ojHA
01X0ojHA0`00000L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS40080?nS4080000000<0oj<@0000000000003@3oXa000`2][Jd0o:0@0?bP400>0?bP
40L0[Jf]0`3lX1000`2][Jd0mY`?0000000200000180mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0R5H7
0080R5H700<0[Jf]0000002`h>H0@@2`h>H10?ooo`00F02`h>H2000000<0Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@P0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@D0[Jf]0`3oYQ400`000000ojHA0000000@0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa002P3oXa03000000d0oj<@00<0[Jf]0?bP403lX1005@3lX1050:f]
[@<000004P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3K
RPd0[Jf]0;Ue2`070;Ue2`030:f][@28EPL0R5H700<0R5H70P0000110;3PiP40oooo001G0;3PiP<0
00000`2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f][@X0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ401P3oYQ400`00
0000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l00000008000000P2][Jd@0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL20000
0440/>3V0@3oool005L0/>3V0`00000309MP2`030:f][@3CQ`h0dhL>00H0dhL>0P2][Jd<0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3o
YQ401@3oYQ400`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l00000008000000P3fW0l50:f][@/0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]202iM@/00`2][Jd0
R5H708QF1`0208QF1`<00000@02`h>H10?ooo`00E`2`h>H3000000<0Uf0;00<0[Jf]0=>73P3CQ`h0
1@3CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0[Jf]
2@3oY1400`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40ojHA00l0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00D0[Jf]0?JL3`000000
mY`?000000070?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0
fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`<00000@02`h>H10?oo
o`00E`2`h>H3000000<0Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0dhL>0:f][@0=0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3o
YQ401@3oYQ400`000000ojHA0?nV4@0?0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40040:f][@3fW0l00000000000d0mY`?102][Jd20?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0
[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL300000400/>3V0@3oool005L0/>3V0`00000309MP
2`030:f][@3CQ`h0dhL>00<0dhL>00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40040:f][@3fW0l0
mY`?00000140mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2i
M@/00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70`0000100;3PiP40oooo001G
0;3PiP<000000`2GH0/0102][Jd0dhL>0=>73P3CQ`h20:f][@<0dhL>00<0[Jf]0>nH403_V1002`3_
V1000`2][Jd0o:0@0?bP400>0?bP40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40040:f][@3f
W0l0mY`?000001<0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`11JN40[Jf]00@0R5H70`0000100;3PiP40
oooo001G0;3PiP<0000000@0Uf0;0000002GH0/0[Jf]0P3CQ`h00`2][Jd0dhL>0=>73P030=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@030?bP402][Jd0oj@A01D0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080
k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/20:f][@03
0;Ue2`2][Jd0R5H700<0R5H70`0000100;3PiP40oooo001G0;3PiP090000002][Jd0000009MP2`00
0000Uf0;0:f][@3CQ`h0[Jf]00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP4009
0?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`<00000@02`h>H10?ooo`00E`2`h>H02000
0000[Jf]0000002GH0/0000009MP2`11JN40[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`<00000
@02`h>H10?ooo`00E`2`h>H01`000000[Jf]0000002GH0/0000009MP2`2][Jd0203CQ`h00`2][Jd0
kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd80?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0
ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H700<0[Jf]000000000000@02`h>H10?ooo`00
E`2`h>H01@000000[Jf]0000002GH0/000000080[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400<0>nH4004
0:f][@3lX100o:0@0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f]
[@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/20:f][@<0R5H700<0[Jf]000000000000@02`h>H10?ooo`00E`2`h>H300000004
09MP2`000000[Jf]0:f][@L0dhL>00<0[Jf]0>nH403_V100303_V100102][Jd0o:0@0:f][@2][Jd>
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F
0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;00H0[Jf]
08QF1`2][Jd0R5H7045Yh@2][Jd200000400/>3V0@3oool005L0/>3V0P0000001@2GH0/000000000
002GH0/0[Jf]00L0dhL>00<0[Jf]0>nH403_V1002`3_V1030:f][A00o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]
1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2]
[Jd00P28EPL00`2][Jd00000000000100;3PiP40oooo001G0;3PiP80000000D0Uf0;000000000000
Uf0;0:f][@070=>73P030:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0
[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P04
0:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`060:f][@28EPL0R5H7
0:f][@28EPL0[Jf]0P0000100;3PiP40oooo001F0;3PiPH0000000<0@FWQ0:f][@3CQ`h01P3CQ`h0
0`2][Jd0kiP@0>nH40070>nH4080[Jf]0`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB0?bP40030:f][@3fW0l0
mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]1`3KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`060:f][@28EPL0R5H708QF1`2][Jd0@FWQ0P0000100;3PiP40oooo
001F0;3PiPH0000000<0@FWQ0:f][@3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_
V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3o
YQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`060:f][@28
EPL0R5H708QF1`2][Jd0@FWQ0P0000100;3PiP40oooo001F0;3PiPH0000000<0@FWQ0:f][@3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP40030:f]
[@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]
0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]000000000000
@02`h>H10?ooo`00EP2`h>H600000003045Yh@2][Jd0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@
0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA
0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/0202iM@/01@2][Jd0
R5H708QF1`28EPL0[Jf]00800000@02`h>H10?ooo`00EP2`h>H30000000409MP2`000000Uf0;0:f]
[@P0dhL>00@0[Jf]0>nH402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00/0fhX=0P2][Jd90;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P0000100;3PiP40oooo001F
0;3PiP<0000000@0Uf0;0000002GH0/0[Jf]203CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f][A00mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@0<0=^:3@<0[Jf]1`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]00800000
@02`h>H10?ooo`00EP2`h>H30000000409MP2`000000Uf0;0:f][@L0dhL>0P2][Jd>0>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2][Jd60;Ue2`05
0:f][@28EPL0R5H708QF1`2][Jd00P0000100;3PiP40oooo001F0;3PiP<0000000@0Uf0;0000002G
H0/0[Jf]1@3CQ`h20:f][@030=>73P2][Jd0kiP@00`0kiP@00<0[Jf]0?bP403lX100403lX1000`2]
[Jd0oj@A0?nT4@040?nT4@D0[Jf]h`2`h>H50:f][@L0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/01@2][Jd0R5H708QF1`28
EPL0[Jf]00<00000?`2`h>H10?ooo`00EP2`h>H30000000409MP2`000000Uf0;0:f][@@0dhL>00D0
[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140
102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@03000003l0
/>3V0@3oool005H0/>3V0`000000102GH0/0000009MP2`2][Jd30=>73P030:f][@3CQ`h0dhL>0080
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`040:f][@2iM@/0^GD;0:f]
[@<0R5H700@0[Jf]0000000000000000?`2`h>H10?ooo`00EP2`h>H2000000060:f][@0000000000
09MP2`2][Jd0dhL>0P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303l
X1030:f][Oh0/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2i
M@/30:f][@<0R5H700@0[Jf]0000000000000000?`2`h>H10?ooo`00EP2`h>H2000000040:f][@00
0000000009MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00X0o:0@
0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70`00000o0;3PiP40
oooo001F0;3PiP030000002][Jd0Uf0;0080000000<0Uf0;0:f][@3CQ`h01`3CQ`h00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk
102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0R5H7
0`00000o0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;008000000P2][Jd80=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2]
[Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`80[Jf]0`28EPL3000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P000002
0:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid0
0`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]
0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]
08QF1`2][Jd0R5H7045Yh@03000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P000000
0`2GH0/0[Jf]0=>73P070=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd6
0;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd000000000000o0;3PiP40oooo001F0;3P
iP030000002][Jd0Uf0;0080000000<0Uf0;0:f][@3CQ`h01`3CQ`h00`2][Jd0kiP@0>nH400:0>nH
40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3P
iP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:
3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2][Jd2000003l0/>3V0@3o
ool005H0/>3V00<000000:f][@2GH0/00P0000000`2GH0/0[Jf]0=>73P070=>73P030:f][@3_V100
kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`4
0:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP2
0:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`
h>H10?ooo`00EP2`h>H01`000000[Jf]0:f][@2GH0/0000009MP2`2][Jd0203CQ`h00`2][Jd0kiP@
0>nH40060>nH40@0[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/
102][Jg80;3PiP@0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh
102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd2000003l0
/>3V0@3oool005H0/>3V00L000000:f][@2][Jd0Uf0;0000002GH0/0[Jf]00P0dhL>00<0[Jf]0>nH
403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd5
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd000000000000o
0;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102]
[Jd0kiP@0>nH403_V1020:f][@@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H6
0:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H708QF1`0208QF1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00<00000
0:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P040:f][@3_V100[Jf]0:f][@<0Y9j?0`11
JN400`2][Jd0/J^M0;6[W@040;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@L0_[Vh
0P11JN430;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]0080
0000?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00L0dhL>
0P2][Jd01@2TWXl0@FWQ0:BNS`2TWXl0@FWQ0080Y9j?00<0@FWQ0:f][@2aZid01`2aZid20:f][@<0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00/0
`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0
`kfk00@0[Jf]0;ji^02][Jd0[Jf]2@2n^KP00`11JN40[Jf]0;B`/@020;B`/@04045Yh@2d/;40[Jf]
0:f][@X0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@02000003l0/>3V0@3oool005L0/>3V00D0[Jf]
09MP2`2GH0/0Uf0;0:f][@080=>73P050:f][@2TWXl0Y9j?0:BNS`11JN400P2TWXl01@11JN40Y9j?
0:BNS`2TWXl0@FWQ00X0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]1`2n^KP3045Yh@03
0;ji^011JN40[Jf]00<0];2a00@0@FWQ0;B`/@2d/;40@FWQ0P2][Jd80;Ue2`050:f][@28EPL0R5H7
08QF1`2][Jd00P00000o0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@05045Yh@2TWXl0Y9j?0:BNS`11JN400P2TWXl01@11JN40Y9j?0:BNS`2TWXl0@FWQ00<0/J^M
00<0@FWQ0;6[W@2aZid01P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0
[Jf]0;ji^0060;ji^003045Yh@2n^KP0_[Vh00<0@FWQ00@0[Jf]0;B`/@2d/;40];2a0P11JN401@2d
/;40@FWQ045Yh@2d/;40[Jf]00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@02000003l0/>3V0@3o
ool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80[Jf]0P11JN430:BNS`04045Yh@2T
WXl0@FWQ045Yh@80Y9j?00<0[Jf]0;6[W@11JN400P2aZid5045Yh@D0/J^M00<0[Jf]0;VbYP2][Jd0
0`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00D0_[Vh
00@0@FWQ0;ji^02n^KP0_[Vh0P11JN40102n^KP0[Jf]0;B`/@2d/;42045Yh@030;B`/@11JN40@FWQ
0080];2a0P2][Jd50;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00P00000o0;3PiP40oooo001G0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01@2][Jd0RXEe08Z5M@2][Jd0@FWQ0080Y9j?00<0
@FWQ0:BNS`2TWXl00P11JN420:BNS`030:f][@2aZid0@FWQ0080/J^M0P11JN420;6[W@03045Yh@2a
Zid0/J^M00<0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33
_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP01011JN40_[Vh0;ji^02n^KP2045Yh@040;ji
^02][Jd0];2a0;B`/@D0@FWQ00<0];2a0:f][@11JN400`2][Jd30;Ue2`040:f][@28EPL0R5H708QF
1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]
00<0dhL>00T0[Jf]045Yh@11JN40RXEe00000011JN40[Jf]0:BNS`11JN400P2TWXl2045Yh@80Y9j?
00<0[Jf]0;6[W@2aZid00P2aZid2045Yh@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`2][Jd0^K:V
0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k
00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`03045Yh@2n^KP0_[Vh00@0_[Vh0P11JN430;ji^080@FWQ
00@0_[Vh0:f][@2d/;40];2a1@11JN40102][Jd0];2a045Yh@2][Jd209nKX0040:f][@2iM@/0^GD;
0:f][@<0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;
09MP2`2][Jd0dhL>0P2][Jd0102:QGD0@FWQ045Yh@2:QGD2045Yh@030:BNS`2][Jd0@FWQ0080Y9j?
0P11JN420:BNS`030:f][@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`11JN40/J^M
0;6[W@020;6[W@03045Yh@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]
;`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00l0a/2l0`2][Jd<0<>m^`80@FWQ00<0[Jf]0;ji^02n^KP0102n^KP2045Yh@<0_[Vh
0P11JN400`2n^KP0[Jf]0;B`/@04045Yh@060:f][@11JN40];2a0;B`/@11JN40[Jf]0`2OVj030:f]
[@@0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80
[Jf]0`2:QGD2045Yh@0308Z5M@11JN40Y9j?0080Y9j?00<0@FWQ0:f][@2TWXl00P11JN420:BNS`03
0:f][@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid00`2aZid01P11JN40/J^M0;6[W@11JN40[Jf]
045Yh@h0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`0;0<>m^`<0@FWQ00<0[Jf]0;ji^02n^KP0102n^KP2
045Yh@<0_[Vh0P11JN401@2n^KP0[Jf]0;B`/@11JN40];2a0080@FWQ00H0];2a045Yh@2d/;40];2a
045Yh@2][Jd209nKX004045Yh@2OVj00Wi^P0:f][@@0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?oo
o`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@2:QGD0RXEe0080RXEe00@0@FWQ08Z5M@11
JN40@FWQ0`2TWXl00`11JN40Y9j?0:f][@02045Yh@80Y9j?00<0[Jf]0;6[W@2aZid0202aZid01@11
JN40/J^M0;6[W@2aZid0@FWQ0100^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0
a/2l00L0a/2l102][Jd50<K0_0030:f][@33_K/0`kfk00/0`kfk0P11JN400`2][Jd0_[Vh0;ji^004
0;ji^080@FWQ0`2n^KP2045Yh@050;ji^02][Jd0];2a045Yh@2][Jd00P11JN420;B`/@04045Yh@2d
/;40@FWQ0:f][@80Wi^P00D0@FWQ09nKX02OVj00Wi^P0:f][@0308QF1`030:f][@2`h>H0/>3V03h0
/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd408Z5M@04045Yh@2:QGD0@FWQ0:f]
[@<0Y9j?00<0@FWQ0:BNS`2TWXl00P11JN420:BNS`030:f][@2aZid0/J^M00P0/J^M00D0@FWQ0;6[
W@2aZid0/J^M0:f][@0@0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00
`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0
a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk0080`kfk1011JN450<>m^`80@FWQ00<0`kfk
0:f][@2n^KP0102n^KP2045Yh@@0_[Vh00H0@FWQ0;ji^02][Jd0[Jf]045Yh@2d/;42045Yh@80];2a
00@0@FWQ0;B`/@11JN40[Jf]0P2OVj001@11JN40Wi^P09nKX02OVj00[Jf]00<0R5H700<0[Jf]0;3P
iP2`h>H0?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@<0RXEe0P11JN4208Z5
M@050:f][@2TWXl0Y9j?0:BNS`11JN400`2TWXl01011JN40[Jf]0:f][@2][Jd90;6[W@80@FWQ0`2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31
^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36
`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk045Yh@02045Yh@80`kfk0P11JN450<>m^`80@FWQ00<0
`kfk0:f][@2n^KP01@2n^KP00`11JN40_[Vh0;ji^0020;ji^005045Yh@2][Jd0[Jf]0;B`/@11JN40
0P2d/;400`11JN40];2a0;B`/@04045Yh@80Wi^P00<0@FWQ09nKX02OVj000P2OVj00102][Jd0R5H7
08QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]0`2:QGD2045Yh@80RXEe
00D0[Jf]0:BNS`2TWXl0Y9j?045Yh@030:BNS`05045Yh@2TWXl0Y9j?0:f][@11JN401`2aZid2045Y
h@@0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f]
[@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][JdA0<K0
_0@0@FWQ1@33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ00<0`kfk0:f][@2n^KP01P2n^KP5045Y
h@040;ji^02][Jd0];2a045Yh@80];2a00D0@FWQ0;B`/@2d/;40@FWQ0;B`/@02045Yh@80Wi^P0P11
JN4309nKX080[Jf]00<0R5H70:f][@2`h>H0?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1S
H5<20:f][@<0RXEe0P11JN400`2:QGD0[Jf]0:BNS`020:BNS`80@FWQ0`2TWXl01011JN40Y9j?0:BN
S`2][Jd2045Yh@040:f][@2aZid0/J^M0;6[W@<0@FWQ1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00l0_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`04036`;`0102][Jd0`kfk045Yh@11JN450<>m
^`03045Yh@33_K/0`kfk0080`kfk0P11JN400`33_K/0[Jf]0;ji^0070;ji^080[Jf]00H0_[Vh045Y
h@2n^KP0[Jf]0;B`/@11JN420;B`/@03045Yh@2d/;40@FWQ0080];2a0P11JN4209nKX080@FWQ0`2O
Vj00102][Jd0L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<0102][Jd0RXEe08Z5
M@2:QGD2045Yh@0308Z5M@2][Jd0Y9j?00L0Y9j?0P11JN401P2TWXl0[Jf]045Yh@11JN40/J^M0:f]
[@<0@FWQ1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f]
[@L0al6l00<0[Jf]0<K0_036`;`04036`;`0102][Jd0`kfk045Yh@11JN450<>m^`80@FWQ0`33_K/2
045Yh@030<>m^`2][Jd0_[Vh00@0_[Vh0`2][Jd30;ji^005045Yh@2n^KP0[Jf]0;B`/@11JN400P2d
/;400`11JN40];2a0;B`/@030;B`/@03045Yh@2OVj00Wi^P0080@FWQ0P2OVj020:f][@03071^N@2]
[Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]0P2:QGD2045Yh@0308Z5M@2][Jd0
Y9j?00L0Y9j?0P11JN400`2TWXl0[Jf]045Yh@030;6[W@04045Yh@2aZid0[Jf]0:f][@H0/J^M00<0
@FWQ0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2]
[Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36
`;`0a/2l0100a/2l00@0[Jf]0<>m^`11JN40@FWQ1@33_K/2045Yh@<0`kfk0P11JN400`33_K/0[Jf]
0;ji^0020;ji^080[Jf]1P2n^KP01011JN40_[Vh0:f][@2d/;42045Yh@L0];2a00<0@FWQ09nKX02O
Vj000P11JN40102OVj00[Jf]09nKX02][Jd2071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`040:f][@2:QGD0[Jf]08Z5M@80@FWQ00<0RXEe0:f][@2TWXl0202TWXl01011
JN40Y9j?0:f][@11JN430;6[W@04045Yh@2aZid0/J^M0;6[W@<0[Jf]0`2aZid00`11JN40^K:V0;Vb
YP0=0;VbYP030:f][@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`04036`;`0102][Jd0`kfk045Y
h@11JN450<>m^`80@FWQ1033_K/01011JN40`kfk0:f][@2n^KP20:f][@<0_[Vh00D0@FWQ0;ji^02n
^KP0_[Vh045Yh@020;ji^0<0@FWQ202d/;43045Yh@80Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT2
0:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd2
045Yh@0308Z5M@2][Jd0Y9j?00T0Y9j?0P11JN440;6[W@03045Yh@2aZid0/J^M0080/J^M00H0@FWQ
0;6[W@2][Jd0[Jf]0;6[W@11JN4?0;VbYP030:f][@2n]j`0_[N/00l0_[N/1011JN4@0<6j/0P0[Jf]
4033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
2@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0040:f]
[@33_K/0@FWQ045Yh@H0`kfk0P11JN430<>m^`04045Yh@2][Jd0[Jf]0:f][@D0_[Vh00D0@FWQ0;ji
^02n^KP0_[Vh045Yh@020;ji^0030:f][@2d/;40];2a00P0];2a0`11JN420:f][@<0Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5
M@2:QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid0
0`11JN40/J^M0;6[W@020;6[W@07045Yh@2aZid0/J^M0;6[W@2][Jd0@FWQ0:f][@0>0;VbYP030:f]
[@2n]j`0_[N/0140_[N/1P11JN4>0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0
b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0040:f][@33_K/0@FWQ045Y
h@H0`kfk0P11JN402033_K/0[Jf]0:f][@11JN40`kfk0:f][@2n^KP0@FWQ102n^KP01011JN40_[Vh
0;ji^011JN430;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0
L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe
08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00@0Y9j?00<0@FWQ0:BNS`2TWXl0102TWXl00`2][Jd0/J^M
0;6[W@020;6[W@03045Yh@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`11JN40^K:V
0:f][@020:f][@/0^K:V00<0[Jf]0;jg[02n]j`04@2n]j`2045Yh@<0`KZ`0P11JN4=0<6j/0030:f]
[@33_K<0`kfc00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
4@37`KP7045YhA@0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`0
4@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0040:f][@33_K/0@FWQ045Yh@H0`kfk0P11JN400`2][Jd0
`kfk0<>m^`02045Yh@040:f][@2n^KP0@FWQ045Yh@@0_[Vh0P11JN440;ji^0030:f][@2d/;40];2a
00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd30:BNS`80@FWQ1P2TWXl00`2][Jd0
/J^M0;6[W@030;6[W@03045Yh@2aZid0/J^M0080@FWQ102aZid00`11JN40^K:V0;VbYP020;VbYP<0
[Jf]202i/ZH00`2][Jd0_[N/0;jg[00A0;jg[080@FWQ1031^[02045Yh@D0`KZ`1P11JN400`31^[00
[Jf]0<>m/`0D0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP04`37`KP2045YhAL0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l045Yh@0A0<O1_0030:f][@36`;`0a/2l0100
a/2l00@0[Jf]0<>m^`11JN40@FWQ1033_K/20:f][@80@FWQ0`33_K/2045Yh@040:f][@2n^KP0@FWQ
045Yh@X0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0
L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0
RXEe00@0RXEe00@0[Jf]0:BNS`2TWXl0Y9j?0P11JN460:BNS`030:f][@2aZid0/J^M00@0/J^M0P11
JN400`2aZid0@FWQ0;6[W@030;6[W@03045Yh@2i/ZH0^K:V00D0^K:V102][Jd40;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]045Yh@11JN401@31^[000`11JN40`KZ`0<6j/0050<6j/080@FWQ0`31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37
`KP0al6h01<0al6h0P11JN4<0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0<0<S1^`80@FWQ1@38
`K/0102][Jd0al6l045Yh@11JN4@0<O1_0030:f][@36`;`0a/2l0100a/2l00D0[Jf]0<>m^`11JN40
@FWQ0<>m^`030:f][@80`kfk0P11JN430<>m^`80@FWQ00@0[Jf]0;ji^02n^KP0@FWQ2P2n^KP00`2]
[Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool0
05H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]0P2TWXl00`11JN40Y9j?0:BNS`04
0:BNS`030:f][@2aZid0/J^M00L0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN4;0;VbYP<0[Jf]00<0
^K:V0:f][@2n]j`04@2n]j`00`2][Jd0@FWQ045Yh@060<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11
JN430<6j/0030:f][@33_K<0`kfc00L0`kfc0P11JN4:0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02@36_kLR0:f][@80@FWQ302][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/01`38`K/00`11JN40b<6k0<S1^`02045Yh@80b<6k0P11JN430<S1^`030:f][@37
`K`0@FWQ0140al6l00<0[Jf]0<K0_036`;`04036`;`01@2][Jd0`kfk045Yh@11JN40[Jf]00D0`kfk
0P11JN430<>m^`03045Yh@33_K/0@FWQ00<0@FWQ2P2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f]
[@2d/;40];2a0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP05
0:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[
W@2aZid02`2aZid2045Yh@h0^K:V0`2][JdA0;jg[0030:f][@11JN40@FWQ00H0`KZ`00<0@FWQ0<6j
/031^[001031^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<01@33_K<3045Yh@030<>m/`11JN40@FWQ
00@0`kfc0P11JN420<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`00
0000[Jf]0<O1^00D0<O1^080@FWQ5037`KX010000000al6j0<O1^P2][JdE0<S1^`<0@FWQ2038`K/0
0`11JN40b<6k045Yh@050<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd04`37`K`00`2][Jd0a/2l0<K0
_00>0<K0_0@0[Jf]0P11JN460<>m^`80@FWQ0`33_K/00`11JN40`kfk0:f][@0=0;ji^0030:f][@2d
/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii
0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl0
0P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f][@2aZid0/J^M00/0/J^M0P11JN4?0;VbYP030:f]
[@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0@FWQ045Yh@060<6j/080@FWQ1@31^[02045Yh@<0`KZ`
00<0[Jf]0<>m/`33_K<01@33_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ00<0`kfc045Yh@11JN40
0`33_K<01@2][Jd0aKje0<Fn]@35_[D0@FWQ0180aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00C0<O1^080@FWQ4P37`KX00`000000al6j0<O1^P020<O1^P030:f][@38`K/0b<6k00T0
b<6k0`11JN460<S1^`04045Yh@38`K/0[Jf]0<S1^`80@FWQ1P38`K/2045Yh@H0b<6k00D0@FWQ0<S1
^`38`K/0b<6k0:f][@0C0<O1_0030:f][@36`;`0a/2l00T0a/2l1@2][Jd20<K0_0030:f][@33_K/0
`kfk0080@FWQ1@33_K/2045Yh@060<>m^`11JN40@FWQ045Yh@33_K/0[Jf]3@2n^KP0102][Jd0];2a
0;B`/@2d/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3P
iP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f]
[@@0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid2045Yh@l0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[@T0_[N/00<0[Jf]045Yh@11JN401P31^[02045Yh@D0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc
00D0`kfc00<0@FWQ0<>m/`33_K<01033_K<3045Yh@@0`kfc00D0[Jf]0<Fn]@35_[D0aKje045Yh@06
0<Fn]@03045Yh@35_[D0aKje00T0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00C
0<O1^080@FWQ5`37`KX7045Yh@80b<6k1011JN470<S1^`80@FWQ00<0b<6k0:f][@38`K/00P38`K/0
0`11JN40b<6k0<S1^`030<S1^`80@FWQ1P38`K/01@11JN40b<6k0<S1^`38`K/0[Jf]01<0al6l00<0
[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/00P11JN450<>m^`80@FWQ1@33
_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj00
1@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe
00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2aZid02`2aZid2045Yh@l0^K:V
00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]045Yh@11JN401P31^[02045Yh@D0`KZ`
0P11JN430<6j/0030:f][@33_K<0`kfc00D0`kfc00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@@0`kfc
00D0[Jf]0<Fn]@35_[D0aKje045Yh@060<Fn]@03045Yh@35_[D0aKje00T0aKje00<0[Jf]0<Jo]`11
JN400P11JN430<Jo]`80@FWQ1036_kL6045Yh@@0a[ng00<0[Jf]0<O1^037`KP04`37`KP2045Yh@<0
al6j0`11JN480<O1^PL0@FWQ0P37`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1P38`K/2045Y
h@80b<6k00<0[Jf]0<S1^`38`K/00P38`K/00`11JN40b<6k0<S1^`020<S1^`03045Yh@38`K/0b<6k
00D0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@0C0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`0
0`2][Jd0`kfk0<>m^`02045Yh@D0`kfk00<0@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool0
05P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]3@2aZid2045Y
h@l0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@040;jg[02][Jd0@FWQ045Yh@L0`KZ`0P11JN44
0<6j/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`050<>m/`03045Yh@33_K<0`kfc00D0`kfc0P11JN44
0<>m/`030:f][@35_[D0aKje00<0@FWQ1035_[D2045Yh@/0aKje0P11JN430<Jo]`80@FWQ00<0a[ng
045Yh@11JN401P36_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP01P37`KP4045Yh@@0al6h0P11JN43
0<O1^080@FWQ0P37`KX00`11JN40al6j0<O1^P03045Yh@P0al6j0P11JN450<O1^P040:f][@38`K/0
@FWQ045Yh@L0b<6k0P11JN450<S1^`80@FWQ0`38`K/00`2][Jd0b<6k0<S1^`070<S1^`03045Yh@38
`K/0b<6k00D0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@0A0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk
0<>m^`02045Yh@D0`kfk00<0@FWQ0<>m^`33_K/01033_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]
2P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2]
[Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@80@FWQ3`2i/ZH00`2][Jd0_[N/0;jg
[00?0;jg[080[Jf]0P11JN400`2][Jd0`KZ`0<6j/0040<6j/080@FWQ1031^[000`11JN40`KZ`0<6j
/0020<6j/0030:f][@33_K<0`kfc00D0`kfc00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@@0`kfc00<0
[Jf]0<Fn]@35_[D00`11JN440<Fn]@<0@FWQ2@35_[D00`11JN40[Jf]0<Jo]`050<Jo]`<0@FWQ1P36
_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP01037`KP2045Yh@@0al6h00<0@FWQ0<O1^037`KP00P11
JN440<O1^080@FWQ00<0al6j045Yh@37`KX00`37`KX2045Yh@P0al6j0P11JN450<O1^P040:f][@38
`K/0@FWQ045Yh@L0b<6k0P11JN450<S1^`80@FWQ0`38`K/00`2][Jd0b<6k0<S1^`0=0<S1^`<0@FWQ
0`38`K/00`2][Jd0al6l045Yh@0:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk0080@FWQ1@33_K/00`11JN40`kfk0<>m^`040<>m^`030:f][@2n^KP0_[Vh00P0_[Vh
0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40oooo
001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]2@2a
Zid2045Yh@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`01011JN40`KZ`045Yh@31^[060:f][@80@FWQ
1031^[000`11JN40`KZ`0<6j/0020<6j/0030:f][@33_K<0`kfc00D0`kfc00<0@FWQ0<>m/`33_K<0
1@33_K<2045Yh@@0`kfc00<0[Jf]0<Fn]@35_[D00`11JN440<Fn]@<0@FWQ2035_[D2045Yh@030:f]
[@36_kL0a[ng00D0a[ng0P11JN460<Jo]`80@FWQ1P36_kL00`2][Jd0al6h0<O1^0030<O1^080@FWQ
1P37`KP3045Yh@D0al6h0`11JN460<O1^P80@FWQ1`37`KX2045Yh@D0al6j00@0[Jf]0<S1^`11JN40
@FWQ1`38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0b<6k0<S1^`0<0<S1^`<0
@FWQ1038`K/00`2][Jd0al6l045Yh@050<O1_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk0080@FWQ1033_K/2045Yh@H0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0
_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00
FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0
0P2aZid20:f][@L0/J^M0P11JN4?0;VbYP030:f][@2n]j`0_[N/0100_[N/0P11JN480<6j/080@FWQ
102][Jd00`11JN40[Jf]0<6j/0020<6j/0030:f][@33_K<0`kfc00D0`kfc0P11JN460<>m/`80@FWQ
1033_K<00`2][Jd0aKje0<Fn]@03045Yh@@0aKje00<0@FWQ0<Fn]@11JN401`35_[D2045Yh@030<Fn
]@2][Jd0a[ng00H0a[ng0P11JN460<Jo]`80@FWQ1P36_kL00`2][Jd0al6h0<O1^0030<O1^080@FWQ
1`37`KP2045Yh@D0al6h0P11JN400`2][Jd0al6j0<O1^P040<O1^P80@FWQ1`37`KX2045Yh@D0al6j
00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0
b<6k0<S1^`0:0<S1^`<0@FWQ1P38`K/00`2][Jd0al6l045Yh@050:f][@`0al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`02045Yh@@0`kfk0P11JN460<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj000`2][Jd0
/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid00`11JN40^K:V0;VbYP0>0;VbYP030:f]
[@2n]j`0_[N/0100_[N/0P11JN480<6j/080@FWQ1031^[000`11JN40`KZ`0:f][@060:f][@H0`kfc
0P11JN440<>m/`80@FWQ1033_K<01P2][Jd0aKje0<Fn]@11JN40aKje045Yh@<0aKje0P11JN400`35
_[D0@FWQ0<Fn]@060<Fn]@80@FWQ00<0aKje0:f][@36_kL01P36_kL2045Yh@H0a[ng0P11JN460<Jo
]`030:f][@37`KP0al6h00<0al6h0P11JN470<O1^080@FWQ1@37`KP2045Yh@030:f][@37`KX0al6j
00@0al6j0P11JN470<O1^P80@FWQ1@37`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1@38`K/0
0`11JN40b<6k0<S1^`020<S1^`030:f][@38`K/0b<6k00T0b<6k00<0@FWQ0<S1^`11JN401038`K/5
0:f][@03045Yh@37`K`0al6l00l0al6l00<0[Jf]0<K0_036`;`04@36`;`0102][Jd0`kfk045Yh@11
JN440<>m^`80@FWQ1P33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0
[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2]
[Jd00`2aZid0@FWQ0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/0P11JN480<6j/080@FWQ1031
^[02045Yh@<0`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd00`33_K<0@FWQ045Yh@020<>m/`80@FWQ
1033_K<01P2][Jd0aKje045Yh@11JN40aKje045Yh@<0aKje0P11JN400`35_[D0@FWQ0<Fn]@060<Fn
]@80@FWQ00<0aKje0:f][@36_kL01P36_kL2045Yh@H0a[ng0P11JN460<Jo]`030:f][@37`KP0al6h
00<0al6h0P11JN470<O1^080@FWQ1@37`KP2045Yh@030:f][@37`KX0al6j00D0al6j0P11JN460<O1
^P80@FWQ1@37`KX01P2][Jd0b<6k045Yh@11JN40b<6k000000D0b<6k0P11JN450<S1^`03045Yh@38
`K/0b<6k0080b<6k00<0[Jf]0<S1^`38`K/02038`K/00`11JN40[Jf]045Yh@050:f][@06045Yh@38
`K/0b<6k0:f][@37`K`0@FWQ4@37`K`00`2][Jd0a/2l0<K0_00A0<K0_0040:f][@33_K/0@FWQ045Y
h@<0`kfk0P11JN470<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;40
0`2][Jd0Wi^P09nKX00209nKX0030:f][@2`h>H0/>3V04<0/>3V0@3oool005d0/>3V00<0[Jf]08Z5
M@2:QGD00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00X0/J^M0`2][Jd?0;Vb
YP030:f][@2n]j`0_[N/0100_[N/0P11JN480<6j/080@FWQ1031^[02045Yh@<0`KZ`00<0[Jf]0<>m
/`33_K<02033_K<30:f][@@0@FWQ00H0[Jf]0<>m/`33_K<0`kfc0:f][@35_[D2045Yh@80aKje00<0
@FWQ0<Fn]@35_[D00P11JN400`35_[D0@FWQ0<Fn]@050<Fn]@80@FWQ0P35_[D00`2][Jd0a[ng0<Jo
]`050<Jo]`80@FWQ1P36_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP00`37`KP2045Yh@L0al6h0P11
JN450<O1^080@FWQ00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@H0al6j0P11JN450<O1^P050:f][@38
`K/0@FWQ045Yh@0000001P38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/00P38`K/01@2][Jd0b<6k
0<S1^`38`K/0@FWQ00D0[Jf]0`11JN460<S1^`06045Yh@38`K/0b<6k0:f][@37`K`0@FWQ4@37`K`0
0`2][Jd0a/2l0<K0_00A0<K0_0040:f][@33_K/0@FWQ045Yh@<0`kfk0P11JN460<>m^`<0[Jf]302n
^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H2
0:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0
[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[080@FWQ2031^[02045Yh@@0`KZ`00<0@FWQ
0<6j/011JN400P31^[000`2][Jd0@FWQ0<>m/`0=0<>m/`80@FWQ00<0`kfc0:f][@2][Jd00`2][Jd2
045Yh@80[Jf]00@0@FWQ0<Fn]@35_[D0@FWQ0`35_[D00`11JN40aKje0<Fn]@030<Fn]@80@FWQ0P35
_[D00`2][Jd0a[ng0<Jo]`050<Jo]`80@FWQ1P36_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP01037
`KP2045Yh@H0al6h0P11JN450<O1^080@FWQ00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@H0al6j0P11
JN450<O1^P040:f][@38`K/0@FWQ045Yh@L0b<6k0P11JN450<S1^`03045Yh@2][Jd0[Jf]00D0[Jf]
00<0@FWQ0<S1^`11JN401038`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ0P38`K/00`2][Jd0al6l
045Yh@0A0<O1_0030:f][@36`;`0a/2l0140a/2l00@0[Jf]0<>m^`11JN40@FWQ0P33_K/2045Yh@@0
`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02]
[Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M
00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`2045Yh@P0`KZ`
0P11JN440<6j/006045Yh@31^[00`KZ`045Yh@31^[00[Jf]0P11JN450<>m/`80@FWQ1P33_K<2045Y
h@@0`kfc00@0[Jf]0<Fn]@11JN40@FWQ0P35_[D01011JN40[Jf]045Yh@11JN430:f][@03045Yh@2]
[Jd0[Jf]0080[Jf]00<0aKje045Yh@11JN400P35_[D00`2][Jd0a[ng0<Jo]`020<Jo]`L0@FWQ1036
_kL2045Yh@H0a[ng00<0[Jf]0<O1^037`KP01@37`KP00`11JN40al6h0<O1^0040<O1^080@FWQ1@37
`KP2045Yh@030:f][@37`KX0al6j00D0al6j0P11JN460<O1^P80@FWQ1@37`KX0102][Jd0b<6k045Y
h@11JN420<S1^`D0[Jf]0P11JN450:f][@80@FWQ0`38`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@@0
b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@80b<6k00@0[Jf]0<O1_011JN40@FWQ4@37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0@FWQ00@0@FWQ0P33_K/30:f][@@0`kfk00<0[Jf]0;ji
^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0
Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0
_[N/0;jg[00@0;jg[080@FWQ1`31^[02045Yh@80`KZ`1011JN420<6j/003045Yh@31^[00[Jf]0080
@FWQ1@33_K<2045Yh@H0`kfc00<0@FWQ0<>m/`33_K<00`33_K<0102][Jd0aKje045Yh@11JN420<Fn
]@04045Yh@35_[D0@FWQ045Yh@<0aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0@FWQ045Yh@0>
0:f][@@0a[ng0P11JN460<Jo]`030:f][@37`KP0al6h00H0al6h0`11JN430<O1^080@FWQ1@37`KP2
045Yh@030:f][@37`KX0al6j00D0al6j0P11JN420<O1^P@0[Jf]0P11JN470:f][@80@FWQ0P2][Jd5
0<S1^`80@FWQ1@38`K/2045Yh@<0b<6k00D0[Jf]0<S1^`38`K/0b<6k045Yh@050<S1^`03045Yh@38
`K/0b<6k00@0b<6k0`11JN420<S1^`040:f][@37`K`0@FWQ045YhA40al6l00<0[Jf]0<K0_036`;`0
4036`;`4045Yh@030<>m^`2][Jd0[Jf]0080[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f]
[@2d/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BN
S`080:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2]
[Jd0_[N/0140_[N/0P11JN470<6j/080@FWQ2@31^[03045Yh@L0`kfc00<0@FWQ0<>m/`33_K<01033
_K<00`11JN40`kfc0<>m/`030<>m/`030:f][@35_[D0@FWQ00<0aKje00@0@FWQ0<Fn]@11JN40@FWQ
0`35_[D00`11JN40aKje0<Fn]@030<Fn]@80@FWQ0P35_[D00`2][Jd0a[ng0<Jo]`090<Jo]`@0[Jf]
0P11JN4B0:f][@D0@FWQ1@2][Jd2045Yh@P0[Jf]00@0@FWQ0:f][@2][Jd0[Jf]1037`KX2045Yh@D0
al6j00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@H0b<6k0P11JN420<S1^`050:f][@38`K/0b<6k
0<S1^`11JN401P38`K/01011JN40b<6k0<S1^`38`K/2045Yh@80b<6k00D0@FWQ0<S1^`38`K/0[Jf]
0<O1_002045YhA40al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk
00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`
h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]4@2n
]j`2045Yh@H0`KZ`00<0@FWQ0<6j/011JN402P31^[000`2][Jd0`kfc0<>m/`070<>m/`80@FWQ0`33
_K<00`11JN40`kfc0<>m/`040<>m/`030:f][@11JN40@FWQ00@0aKje0P11JN440<Fn]@03045Yh@35
_[D0aKje00<0aKje0P11JN420<Fn]@030:f][@36_kL0a[ng00d0a[ng0`11JN450<Jo]`030:f][@37
`KP0al6h00`0al6h0P11JN450<O1^080@FWQ00<0[Jf]0<O1^P37`KX01@37`KX00`11JN40al6j0<O1
^P050<O1^P80@FWQ1@37`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ1`38`K/2045Yh@050<S1
^`2][Jd0b<6k0<S1^`11JN402038`K/3045Yh@L0b<6k00@0[Jf]0<O1_011JN40@FWQ4@37`K`00`2]
[Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a
00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`2045Yh@H0
`KZ`0P11JN4;0<6j/0030:f][@33_K<0`kfc00T0`kfc0`11JN460<>m/`@0@FWQ1035_[D2045Yh@D0
aKje00<0@FWQ0<Fn]@35_[D00P35_[D2045Yh@80aKje00<0[Jf]0<Jo]`36_kL03@36_kL3045Yh@@0
a[ng00<0@FWQ0:f][@37`KP01@37`KP2045Yh@H0al6h00<0@FWQ0<O1^037`KP01037`KP2045Yh@03
0:f][@37`KX0al6j00D0al6j00<0@FWQ0<O1^P37`KX01P37`KX2045Yh@@0al6j00<0[Jf]0<S1^`11
JN402038`K/2045Yh@P0b<6k1@11JN4C0<S1^`040:f][@37`K`0@FWQ045YhA40al6l00<0[Jf]0<K0
_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji
^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0
_[N/0P11JN450<6j/003045Yh@31^[00@FWQ00/0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
@FWQ045Yh@02045Yh@80aKje0P11JN450<Fn]@03045Yh@35_[D0aKje0080aKje0P11JN420<Fn]@03
0:f][@36_kL0a[ng00d0a[ng0`11JN440<Jo]`80@FWQ1P37`KP2045Yh@H0al6h00<0@FWQ0<O1^037
`KP01037`KP3045Yh@H0al6j00<0@FWQ0<O1^P37`KX01`37`KX00`11JN40al6j045Yh@030<O1^P03
0:f][@38`K/0@FWQ00P0b<6k0P11JN4:0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_011
JN40@FWQ4@37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3P
iP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`01`2n]j`40:f][@<0_[N/1011JN450<6j/080@FWQ3031^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00P0aKje1P11JN420<Fn]@80@FWQ0P35_[D00`2][Jd0a[ng0<Jo]`0=0<Jo
]`80@FWQ00<0a[ng045Yh@36_kL00P36_kL2045Yh@L0al6h00<0@FWQ0<O1^037`KP00`37`KP00`11
JN40al6h0<O1^0050<O1^080@FWQ00<0[Jf]045Yh@37`KX00`37`KX2045Yh@T0al6j00<0@FWQ0<O1
^P37`KX01@11JN470<S1^`80@FWQ3038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0@FWQ
045YhA40al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]045Yh@06
045Yh@d0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0A0<Fn]@04045Yh@35_[D0
aKje0:f][@`0a[ng1@11JN420<Jo]`@0@FWQ00<0[Jf]0<O1^037`KP01P37`KP5045Yh@H0al6h1011
JN400`2][Jd0al6j045Yh@03045Yh@/0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_011JN40@FWQ3`37`K`50:f][A00a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`
h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0140aKje0P11JN400`35_[D0[Jf]0<Jo
]`070<Jo]`03045Yh@36_kL0a[ng00`0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0>0<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`040:f][@37`K`0@FWQ045Yh@X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`
h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31
^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje0140aKje
0P11JN400`35_[D0[Jf]0<Jo]`070<Jo]`03045Yh@36_kL0a[ng00`0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0>0<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l045Yh@@0al6l1P2][Jd70<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0
[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D04P35_[D00`11JN40aKje0:f][@070<Jo]`80@FWQ3P36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j00h0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]
FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f][@35_[D0aKje0180aKje0P11
JN400`2][Jd0a[ng0<Jo]`050<Jo]`80@FWQ3P36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j00h0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k0<S1^`080<S1^`03045Yh@38
`K/0b<6k00T0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A80al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f
0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D04P35
_[D2045Yh@030:f][@36_kL0a[ng00@0a[ng0P11JN4?0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX03P37`KX00`11JN40al6j0<O1^P030<O1^P030:f][@38`K/0b<6k00P0b<6k0P11
JN4:0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]G`2`
h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35_[D0
aKje01<0aKje0P11JN460<Jo]`80@FWQ3`36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j00h0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k0<S1^`080<S1^`03045Yh@38`K/0
b<6k00T0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H3
0:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc0100`kfc2@2][JdA0<Fn]@030:f][@11JN40@FWQ00<0a[ng00<0@FWQ0<Jo]`11JN403`36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00d0al6j0P11JN450<O1^P030:f][@38`K/0
b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL00`11JN420<Jo]`03045Yh@36_kL0a[ng
00d0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0;0<O1^P80@FWQ00<0al6j045Y
h@37`KX01037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m
^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0
a[ng00<0[Jf]0<O1^037`KP02P37`KPX0:f][A40b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00`33_K/30:f][F`0
/>3V0@3oool008D0/>3V0`2][Jd50;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
2@36_kLI0:f][@/0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0[Jf]00<0[Jf]K`2`h>H10?ooo`00R02`h>H40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`03`36`;`30:f][G<0/>3V0@3oool008`0/>3V102][Jd@0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00/0a/2l102][Jef0;3PiP40oooo002@0;3PiPD0[Jf]2`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0070<K0
_0@0[Jf]NP2`h>H10?ooo`00U@2`h>H40:f][@L0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][Gh0
/>3V0@3oool009T0/>3V1@2][Jd20;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0[Jf]00<0[Jf]PP2`h>H10?ooo`00WP2`
h>H60:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00?0<O1_0D0[Jf]QP2`
h>H10?ooo`00Y02`h>H70:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_008
0<O1_0L0[Jf]R`2`h>H10?ooo`00Z`2`h>H70:f][@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102]
[Jd0al6l0<O1_037`K`70:f][I80/>3V0@3oool00;80/>3V1`2][JdB0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`L0[Jf]V@2`h>H10?oo
o`00^@2`h>H70:f][@/0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k00T0b<6k1`2][JfP0;3PiP40oooo00300;3PiPP0[Jf]0`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j
0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][JfW0;3PiP40
oooo00380;3PiPT0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`l0[Jf][`2`h>H10?ooo`00d@2`
h>H<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j00T0al6j5`2][Jfn0;3PiP40oooo003M0;3PiT40[Jf]e@2`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52451 .3309 m
.51281 .33086 L
s
.54289 .33073 m
.53119 .33087 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50612 .33078 m
.49444 .33056 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56122 .33025 m
.55624 .33362 L
s
.5 Mabswid
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49944 .33126 m
.49945 .33067 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51948 .36632 m
.51948 .35917 L
s
.5178 .36631 m
.5178 .35917 L
s
.5 Mabswid
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51869 .33861 m
.53029 .33859 L
s
.50873 .35659 m
.50876 .33853 L
s
.50707 .35657 m
.50711 .33851 L
s
.57963 .32143 m
.59104 .32078 L
s
0 0 0 r
.57203 .3439 m
.57296 .34911 L
s
.57352 .3429 m
.57462 .34904 L
s
.255 .412 .882 r
.49884 .33837 m
.50379 .34072 L
s
.49553 .3383 m
.49884 .33837 L
s
.49222 .34047 m
.49553 .3383 L
s
.49057 .34042 m
.49553 .3383 L
s
.50379 .34072 m
.50709 .34527 L
s
.55509 .34041 m
.55838 .33806 L
s
.55838 .33806 m
.56333 .3379 L
s
.55344 .34046 m
.55838 .33806 L
s
.4889 .34489 m
.49222 .34047 L
s
.55181 .34501 m
.55344 .34046 L
s
.48725 .34484 m
.49057 .34042 L
s
.55346 .34497 m
.55509 .34041 L
s
.56333 .3379 m
.56663 .34003 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48723 .34935 m
.4889 .34489 L
s
.48558 .3493 m
.48725 .34484 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56663 .34003 m
.56994 .34441 L
s
.55346 .34497 m
.55348 .34949 L
s
.55181 .34501 m
.55182 .34953 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57483 .33743 m
.57647 .33735 L
s
.57156 .33983 m
.57483 .33743 L
s
.5732 .33976 m
.57483 .33743 L
s
.56994 .34441 m
.57156 .33983 L
s
.55182 .34953 m
.55349 .35401 L
s
.57159 .34435 m
.5732 .33976 L
s
.55348 .34949 m
.55515 .35396 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50104 .35956 m
.50104 .35919 L
s
.49936 .36054 m
.49936 .35913 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46592 .33721 m
.47228 .36921 L
s
.45914 .36859 m
.46592 .33721 L
s
.48555 .35609 m
.48723 .34935 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52532 .35667 m
.52699 .36346 L
s
.52366 .33862 m
.52367 .37027 L
s
.52532 .33862 m
.52533 .37026 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5021 .35649 m
.51371 .35664 L
s
.4839 .35604 m
.48558 .3493 L
s
.56994 .34441 m
.57006 .36479 L
s
.57159 .34435 m
.57168 .36019 L
s
.55349 .35401 m
.55846 .35613 L
s
.55515 .35396 m
.55846 .35613 L
s
.46078 .36867 m
.46588 .34398 L
s
.55846 .35613 m
.56837 .35805 L
s
.52699 .36346 m
.53031 .36797 L
s
.4855 .36742 m
.48555 .35609 L
s
.48385 .36737 m
.4839 .35604 L
s
.53695 .36565 m
.53861 .36336 L
s
.53861 .36336 m
.54027 .3656 L
s
.58633 .34362 m
.58956 .33891 L
s
.58956 .33891 m
.5928 .33646 L
s
.5928 .33646 m
.59605 .33625 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53695 .36565 m
.53862 .36789 L
s
.54027 .3656 m
.54028 .36787 L
s
.59605 .33625 m
.59931 .33829 L
s
.59605 .33625 m
.60093 .33818 L
s
.53031 .36797 m
.53364 .37022 L
s
.55353 .36307 m
.55354 .36533 L
s
.55353 .36307 m
.55518 .36302 L
s
.55518 .36302 m
.55519 .36529 L
s
.53862 .37016 m
.54028 .36787 L
s
.56837 .35805 m
.57003 .36026 L
s
.51868 .37026 m
.52533 .37026 L
s
.55354 .36533 m
.5552 .36756 L
s
.53364 .37022 m
.53862 .37016 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59931 .33829 m
.6026 .3426 L
s
.50868 .38611 m
.5087 .37246 L
s
.50703 .37926 m
.5087 .37246 L
s
.5552 .36756 m
.55852 .36974 L
s
.60093 .33818 m
.60422 .34248 L
s
.57006 .36479 m
.57168 .36019 L
s
.4855 .36742 m
.48713 .37429 L
s
.48385 .36737 m
.48547 .37424 L
s
0 0 0 r
.44722 .35686 m
.44783 .3575 L
s
.255 .412 .882 r
.55852 .36974 m
.56514 .36952 L
s
.43667 .33535 m
.43828 .33547 L
s
.56843 .36713 m
.57006 .36479 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45287 .33648 m
.45914 .36859 L
s
.44607 .36781 m
.45287 .33648 L
s
.4477 .36792 m
.45281 .34326 L
s
.43343 .33736 m
.43667 .33535 L
s
.43504 .33749 m
.43667 .33535 L
s
.56514 .36952 m
.56843 .36713 L
s
.50369 .38376 m
.50703 .37926 L
s
.50703 .37926 m
.50868 .38611 L
s
.46735 .369 m
.47723 .36941 L
s
.48713 .37429 m
.48876 .37889 L
s
.48547 .37424 m
.48711 .37884 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58616 .32107 m
.58653 .36857 L
s
.58453 .32117 m
.58489 .36866 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60422 .34248 m
.6059 .34916 L
s
.6026 .3426 m
.60428 .34928 L
s
.43338 .34189 m
.43504 .33749 L
s
.43177 .34176 m
.43343 .33736 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61542 .33481 m
.6266 .33381 L
s
.58647 .36175 m
.58978 .36612 L
s
.48876 .37889 m
.49206 .38353 L
s
.4987 .38595 m
.50369 .38376 L
s
.48711 .37884 m
.4904 .38349 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58822 .39238 m
.58826 .39711 L
s
.58987 .39127 m
.58992 .39702 L
s
.255 .412 .882 r
.57996 .3689 m
.58653 .36857 L
s
.60428 .34928 m
.60433 .35382 L
s
.4332 .35779 m
.43338 .34189 L
s
.49206 .38353 m
.49538 .38588 L
s
.42861 .33696 m
.43177 .34176 L
s
.42544 .33442 m
.42861 .33696 L
s
.49538 .38588 m
.4987 .38595 L
s
.4904 .38349 m
.49538 .38588 L
s
.6059 .34916 m
.60595 .3537 L
s
.42065 .33399 m
.42544 .33442 L
s
.43154 .36221 m
.43177 .34176 L
s
.58978 .36612 m
.59307 .3682 L
s
.60278 .36075 m
.60433 .35382 L
s
.6044 .36064 m
.60595 .3537 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41744 .33595 m
.42065 .33399 L
s
.41585 .3358 m
.42065 .33399 L
s
.4412 .36749 m
.45259 .36822 L
s
.59307 .3682 m
.59633 .368 L
s
.59957 .36552 m
.60278 .36075 L
s
.59633 .368 m
.59957 .36552 L
s
.59633 .368 m
.6012 .36541 L
s
.6012 .36541 m
.6044 .36064 L
s
.41579 .34034 m
.41744 .33595 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4142 .34019 m
.41585 .3358 L
s
.43154 .36221 m
.4332 .35779 L
s
.63295 .33319 m
.64396 .33201 L
s
.42042 .35216 m
.43001 .35526 L
s
.43001 .35526 m
.43159 .35766 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41573 .34489 m
.41579 .34034 L
s
.41414 .34473 m
.4142 .34019 L
s
.4299 .36437 m
.43154 .36221 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63768 .3327 m
.63804 .35775 L
s
.62182 .33425 m
.62241 .38211 L
s
.62022 .3344 m
.6208 .38224 L
s
.41573 .34489 m
.41726 .34959 L
s
.63926 .33253 m
.63962 .35759 L
s
.41726 .34959 m
.42042 .35216 L
s
.41567 .34944 m
.42042 .35216 L
s
.41414 .34473 m
.41567 .34944 L
s
.42666 .36639 m
.4299 .36437 L
s
.62213 .35925 m
.62538 .36353 L
s
.42025 .36584 m
.42666 .36639 L
s
0 0 0 r
.64253 .3546 m
.64276 .353 L
s
.255 .412 .882 r
.41555 .35855 m
.41714 .3587 L
s
.41711 .36098 m
.41714 .3587 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62538 .36353 m
.6302 .36538 L
s
.41552 .36084 m
.41555 .35855 L
s
.41708 .36327 m
.42025 .36584 L
s
.41552 .36084 m
.41708 .36327 L
s
.38308 .32976 m
.39389 .33113 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65021 .33129 m
.66103 .32993 L
s
.6302 .36538 m
.63338 .36508 L
s
.61597 .38263 m
.62241 .38211 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63652 .36248 m
.63804 .35775 L
s
.63338 .36508 m
.63652 .36248 L
s
.63338 .36508 m
.6381 .36232 L
s
.38872 .36256 m
.38924 .33056 L
s
.6381 .36232 m
.63962 .35759 L
s
.38717 .36238 m
.3877 .33036 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.39971 .35923 m
.40132 .35711 L
s
.40132 .35711 m
.40285 .35957 L
s
.40282 .36186 m
.40285 .35957 L
s
.40121 .36398 m
.40282 .36186 L
s
.39971 .35923 m
.40125 .36169 L
s
.39651 .36347 m
.40121 .36398 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38894 .34882 m
.39038 .35587 L
s
.39342 .36082 m
.39651 .36347 L
s
.39038 .35587 m
.39342 .36082 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65071 .36326 m
.65693 .36253 L
s
.65641 .33053 m
.65693 .36253 L
s
.65486 .33072 m
.65538 .36272 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6688 .33575 m
.67176 .33075 L
s
.6674 .34282 m
.6688 .33575 L
s
.67176 .33075 m
.67625 .3278 L
s
.67032 .33553 m
.67327 .33053 L
s
.66892 .34261 m
.67032 .33553 L
s
.67327 .33053 m
.67625 .3278 L
s
.6674 .34282 m
.66748 .3474 L
s
.37086 .33035 m
.3738 .33536 L
s
.3738 .33536 m
.37524 .34015 L
s
.38253 .3618 m
.38872 .36256 L
s
.36638 .32738 m
.37086 .33035 L
s
.67625 .3278 m
.67926 .32734 L
s
.37524 .34015 m
.37664 .34723 L
s
.66892 .34261 m
.66901 .34719 L
s
.36935 .33012 m
.37229 .33514 L
s
.37229 .33514 m
.37372 .33993 L
s
.36638 .32738 m
.36935 .33012 L
s
.66748 .3474 m
.66913 .35407 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37372 .33993 m
.37511 .34702 L
s
.37643 .3587 m
.37664 .34723 L
s
.35154 .32498 m
.36638 .32738 L
s
.66901 .34719 m
.67066 .35387 L
s
.67926 .32734 m
.68379 .32894 L
s
.37491 .3585 m
.37511 .34702 L
s
.65405 .37669 m
.65557 .3742 L
s
.65405 .37669 m
.65564 .37881 L
s
.65557 .3742 m
.65716 .37632 L
s
.66913 .35407 m
.67226 .35826 L
s
.65564 .37881 m
.65716 .37632 L
s
.67066 .35387 m
.67378 .35805 L
s
.37478 .3654 m
.37643 .3587 L
s
.68379 .32894 m
.68686 .33305 L
s
.37326 .3652 m
.37491 .3585 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67226 .35826 m
.67686 .35992 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67378 .35805 m
.67686 .35992 L
s
.37317 .36981 m
.37478 .3654 L
s
.37165 .3696 m
.37326 .3652 L
s
.67686 .35992 m
.68138 .35927 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6892 .34503 m
.68954 .34693 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37004 .37401 m
.37317 .36981 L
s
.36852 .3738 m
.37165 .3696 L
s
.6842 .3496 m
.68565 .34707 L
s
.6842 .3496 m
.68574 .35168 L
s
.68565 .34707 m
.68718 .34914 L
s
.68138 .35927 m
.68434 .35651 L
s
.69702 .32443 m
.69858 .32877 L
s
.69702 .32443 m
.69722 .33362 L
s
.68718 .34914 m
.68723 .35144 L
s
.36545 .37569 m
.37004 .37401 L
s
.68434 .35651 m
.68723 .35144 L
s
.36545 .37569 m
.36852 .3738 L
s
.69722 .33362 m
.69858 .32877 L
s
.69858 .32877 m
.69998 .32621 L
s
.69998 .32621 m
.70283 .32339 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35496 .37414 m
.35596 .32573 L
s
.35645 .37437 m
.35744 .32597 L
s
.70283 .32339 m
.70858 .32231 L
s
.35052 .37345 m
.36545 .37569 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69752 .34745 m
.69893 .3449 L
s
.69752 .34745 m
.69762 .35208 L
s
.69893 .3449 m
.70179 .34208 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69757 .34976 m
.69898 .34721 L
s
.70858 .32231 m
.71148 .32406 L
s
.69898 .34721 m
.70184 .34439 L
s
.69762 .35208 m
.69913 .35414 L
s
.70179 .34208 m
.70889 .33615 L
s
.70184 .34439 m
.70895 .33846 L
s
.69913 .35414 m
.7021 .35596 L
s
.71148 .32406 m
.71296 .32609 L
s
.70889 .33615 m
.7117 .33329 L
s
.71296 .32609 m
.71312 .33302 L
s
.70895 .33846 m
.71175 .3356 L
s
.7021 .35596 m
.70788 .35493 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7117 .33329 m
.71306 .3307 L
s
.71175 .3356 m
.71312 .33302 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70788 .35493 m
.7107 .35209 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71207 .3495 m
.71339 .34459 L
s
.71339 .34459 m
.71361 .35388 L
s
.7107 .35209 m
.71207 .3495 L
s
.71207 .3495 m
.71361 .35388 L
s
.72272 .32177 m
.72405 .31916 L
s
.72272 .32177 m
.72417 .32378 L
s
.72405 .31916 m
.72549 .32117 L
s
.72417 .32378 m
.72549 .32117 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72446 .33537 m
.72654 .36305 L
s
.72376 .36361 m
.72446 .33537 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7248 .34933 m
.72515 .36333 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72376 .36361 m
.72527 .36801 L
s
.72527 .36801 m
.72654 .36305 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27708 .31253 m
.27837 .31055 L
s
.27723 .30783 m
.27837 .31055 L
s
.27594 .30981 m
.27723 .30783 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27594 .30981 m
.27708 .31253 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27464 .35233 m
.27673 .3243 L
s
.27673 .3243 m
.27709 .35303 L
s
.27587 .35268 m
.2763 .33847 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26643 .30678 m
.26752 .30953 L
s
.2673 .31661 m
.26752 .30953 L
s
.27572 .35743 m
.27709 .35303 L
s
.26418 .30364 m
.26643 .30678 L
s
.26613 .31623 m
.26737 .31425 L
s
.26605 .3186 m
.2673 .31661 L
s
.25962 .30206 m
.26418 .30364 L
s
.27464 .35233 m
.27572 .35743 L
s
.26373 .31783 m
.26613 .31623 L
s
.26365 .3202 m
.26605 .3186 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2656 .33282 m
.26693 .32845 L
s
.26663 .33794 m
.26693 .32845 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25787 .32064 m
.26373 .31783 L
s
.25779 .32301 m
.26365 .3202 L
s
.25729 .30363 m
.25962 .30206 L
s
.26436 .33482 m
.2656 .33282 L
s
.2656 .33282 m
.26663 .33794 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26197 .33645 m
.26436 .33482 L
s
.2561 .30559 m
.25729 .30363 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24966 .29115 m
.24967 .29085 L
s
.5 Mabswid
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25515 .30045 m
.2561 .30559 L
s
.25483 .30994 m
.25515 .30045 L
s
.25483 .30994 m
.2561 .30559 L
s
.2574 .33493 m
.26197 .33645 L
s
.25555 .32223 m
.25787 .32064 L
s
.25547 .32461 m
.25779 .32301 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25436 .32422 m
.25555 .32223 L
s
.25428 .3266 m
.25547 .32461 L
s
.25524 .33177 m
.2574 .33493 L
s
.2542 .32899 m
.25436 .32422 L
s
.79587 .29831 m
.79757 .34854 L
s
.2542 .32899 m
.25524 .33177 L
s
.79694 .2979 m
.79864 .34815 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24862 .32204 m
.24867 .32048 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24538 .29908 m
.24732 .30469 L
s
.24235 .29542 m
.24538 .29908 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79262 .29956 m
.80321 .29535 L
s
.24667 .3238 m
.24676 .32141 L
s
.24578 .31861 m
.24676 .32141 L
s
.24031 .29456 m
.24235 .29542 L
s
.80321 .29535 m
.80533 .29687 L
s
.80321 .29535 m
.80634 .29644 L
s
.24439 .32778 m
.24667 .3238 L
s
.24464 .32059 m
.24578 .31861 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24756 .35318 m
.24762 .3516 L
s
.5 Mabswid
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24464 .32059 m
.24561 .3234 L
s
.23821 .29608 m
.24031 .29456 L
s
.23721 .29564 m
.24031 .29456 L
s
.80533 .29687 m
.80752 .30079 L
s
.24222 .32937 m
.24439 .32778 L
s
.80634 .29644 m
.80851 .30036 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23605 .29999 m
.23821 .29608 L
s
.23507 .29956 m
.23721 .29564 L
s
.80752 .30079 m
.80868 .30515 L
s
.23914 .32813 m
.24222 .32937 L
s
.80851 .30036 m
.80967 .30472 L
s
.23481 .30676 m
.23605 .29999 L
s
.80868 .30515 m
.80993 .31193 L
s
.23384 .30633 m
.23507 .29956 L
s
.80967 .30472 m
.81091 .3115 L
s
.2372 .32489 m
.23914 .32813 L
s
.2362 .32447 m
.23914 .32813 L
s
.23464 .31157 m
.23481 .30676 L
s
.80993 .31193 m
.81035 .32397 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7943 .3497 m
.80496 .34576 L
s
.23537 .31922 m
.2372 .32489 L
s
.80496 .34576 m
.80693 .34254 L
s
.80496 .34576 m
.80795 .34213 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23464 .31157 m
.23537 .31922 L
s
.23366 .31114 m
.23384 .30633 L
s
.81091 .3115 m
.81134 .32355 L
s
.23439 .3188 m
.2362 .32447 L
s
.81408 .2905 m
.82055 .28731 L
s
.80693 .34254 m
.80879 .33689 L
s
.23366 .31114 m
.23439 .3188 L
s
.22409 .28693 m
.23052 .29013 L
s
.80962 .33164 m
.81035 .32397 L
s
.80795 .34213 m
.80979 .33647 L
s
.80879 .33689 m
.80962 .33164 L
s
.81061 .33122 m
.81134 .32355 L
s
.80979 .33647 m
.81061 .33122 L
s
0 0 0 r
.22147 .27831 m
.22257 .27888 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8169 .28915 m
.81813 .32296 L
s
.22648 .3226 m
.22772 .28877 L
s
.81782 .28869 m
.81906 .32252 L
s
.22556 .32216 m
.2268 .28831 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8153 .32426 m
.81906 .32252 L
s
.81853 .30799 m
.81972 .31481 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81972 .31481 m
.82172 .31877 L
s
.22284 .32083 m
.22648 .3226 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21473 .28173 m
.22058 .28506 L
s
.82172 .31877 m
.8236 .32031 L
s
.22494 .33919 m
.22595 .33718 L
s
.22512 .33431 m
.22595 .33718 L
s
.22411 .33632 m
.22512 .33431 L
s
.22411 .33632 m
.22494 .33919 L
s
.21701 .31037 m
.21802 .28364 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8236 .32031 m
.82623 .31897 L
s
.21618 .30991 m
.21719 .28316 L
s
.82518 .31455 m
.82614 .31653 L
s
.82518 .31455 m
.82596 .31166 L
s
.82596 .31166 m
.82691 .31364 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82623 .31897 m
.827 .31608 L
s
.82691 .31364 m
.827 .31608 L
s
.21599 .31479 m
.21701 .31037 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21516 .31433 m
.21618 .30991 L
s
.83188 .28846 m
.83249 .28311 L
s
.83188 .28846 m
.83207 .29333 L
s
.83249 .28311 m
.83474 .27922 L
s
.21342 .31586 m
.21599 .31479 L
s
.83207 .29333 m
.83305 .29773 L
s
.83268 .28798 m
.83328 .28263 L
s
.83268 .28798 m
.83287 .29285 L
s
.83328 .28263 m
.83474 .27922 L
s
.21342 .31586 m
.21516 .31433 L
s
.20631 .27634 m
.21155 .27979 L
s
.83287 .29285 m
.83384 .29726 L
s
.83474 .27922 m
.83701 .27774 L
s
.83305 .29773 m
.83549 .29875 L
s
.21181 .31494 m
.21342 .31586 L
s
.83384 .29726 m
.83549 .29875 L
s
.20726 .32985 m
.20926 .27832 L
s
.83343 .30751 m
.83352 .30996 L
s
.83343 .30751 m
.83422 .30704 L
s
.83352 .30996 m
.83441 .31194 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2065 .32939 m
.20851 .27782 L
s
.83422 .30704 m
.83431 .30949 L
s
.83701 .27774 m
.83857 .27919 L
s
.20955 .31108 m
.21181 .31494 L
s
.83549 .29875 m
.84007 .29831 L
s
.83441 .31194 m
.83606 .31346 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83857 .27919 m
.8402 .2831 L
s
.20821 .30523 m
.20955 .31108 L
s
.83606 .31346 m
.83909 .31157 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8402 .2831 m
.84072 .2777 L
s
.8402 .2831 m
.84107 .30521 L
s
.84072 .2777 m
.84201 .27425 L
s
.84091 .2826 m
.84142 .2772 L
s
.84091 .2826 m
.84159 .2998 L
s
.84142 .2772 m
.84201 .27425 L
s
.84007 .29831 m
.84088 .30029 L
s
.84201 .27425 m
.84269 .27374 L
s
.83909 .31157 m
.84045 .30816 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20428 .328 m
.20726 .32985 L
s
.84045 .30816 m
.84107 .30521 L
s
.84107 .30521 m
.84159 .2998 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20006 .27425 m
.20118 .28018 L
s
.20118 .28018 m
.20155 .28807 L
s
.20135 .293 m
.20155 .28807 L
s
.19942 .27374 m
.20052 .27968 L
s
.20052 .27968 m
.20088 .28757 L
s
.19827 .27025 m
.20006 .27425 L
s
.20039 .29991 m
.20135 .293 L
s
.20069 .2925 m
.20088 .28757 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19683 .33894 m
.19731 .32715 L
s
.19857 .29563 m
.1986 .29496 L
s
.5 Mabswid
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19827 .27025 m
.19942 .27374 L
s
.19973 .29942 m
.20069 .2925 L
s
0 0 0 r
.19683 .33894 m
.19716 .33915 L
s
.255 .412 .882 r
.19888 .30388 m
.20039 .29991 L
s
.19322 .24772 m
.19715 .25146 L
s
.19705 .26922 m
.19827 .27025 L
s
.19824 .30339 m
.19973 .29942 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84541 .30725 m
.84985 .30381 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19576 .27065 m
.19705 .26922 L
s
.84736 .30578 m
.84844 .26913 L
s
.19687 .30488 m
.19888 .30388 L
s
.19329 .3019 m
.19541 .24986 L
s
.84799 .30529 m
.84874 .27654 L
s
.19687 .30488 m
.19824 .30339 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19273 .3014 m
.19485 .24933 L
s
.19441 .27456 m
.19576 .27065 L
s
.19564 .30389 m
.19687 .30488 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84844 .26913 m
.85219 .30182 L
s
.19455 .30041 m
.19564 .30389 L
s
.1936 .29443 m
.19455 .30041 L
s
.85296 .26494 m
.85645 .29777 L
s
.85219 .30182 m
.85296 .26494 L
s
.85275 .30131 m
.85327 .27239 L
s
.19096 .26344 m
.19147 .26397 L
s
.19109 .29989 m
.19329 .3019 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18987 .26486 m
.19096 .26344 L
s
.19036 .2654 m
.19096 .26344 L
s
.18967 .26984 m
.19036 .2654 L
s
.18918 .26931 m
.18987 .26486 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18894 .28732 m
.18967 .26984 L
s
.85492 .2993 m
.8579 .29624 L
s
.18846 .26326 m
.18918 .26931 L
s
.18825 .29182 m
.18918 .26931 L
s
.18766 .25969 m
.18846 .26326 L
s
0 0 0 r
.86221 .25132 m
.86261 .25229 L
s
.86218 .25061 m
.86303 .25173 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18825 .29182 m
.18894 .28732 L
s
.18639 .25807 m
.18766 .25969 L
s
.18809 .28378 m
.18846 .28681 L
s
.18555 .27812 m
.18809 .28378 L
s
.18768 .29381 m
.18825 .29182 L
s
0 0 0 r
.86261 .25229 m
.86374 .25833 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18321 .25079 m
.18342 .24937 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18665 .29529 m
.18768 .29381 L
s
.18548 .25948 m
.18639 .25807 L
s
.1851 .25894 m
.18639 .25807 L
s
.85918 .27103 m
.85938 .26548 L
s
.85907 .27909 m
.85918 .27103 L
s
.85938 .26548 m
.85997 .25939 L
s
.85907 .27909 m
.85959 .29165 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86456 .26812 m
.86459 .26853 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18492 .29322 m
.18665 .29529 L
s
.85959 .2705 m
.85979 .26494 L
s
.85949 .27856 m
.85959 .2705 L
s
.18489 .26395 m
.18548 .25948 L
s
.85979 .26494 m
.86036 .25885 L
s
.85949 .27856 m
.86001 .29113 L
s
.85997 .25939 m
.86099 .25524 L
s
0 0 0 r
.86481 .26588 m
.86498 .26798 L
s
.255 .412 .882 r
.18485 .27454 m
.18555 .27812 L
s
.18446 .27401 m
.18555 .27812 L
s
.18451 .26341 m
.1851 .25894 L
s
.86036 .25885 m
.86099 .25524 L
s
.85959 .29165 m
.86033 .2987 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18467 .26898 m
.18489 .26395 L
s
0 0 0 r
.86415 .29713 m
.86443 .2953 L
s
.86418 .29784 m
.86485 .29477 L
s
.86459 .26853 m
.8649 .27571 L
s
.255 .412 .882 r
.86001 .29113 m
.86075 .29818 L
s
.18467 .26898 m
.18485 .27454 L
s
.86099 .25524 m
.8617 .25415 L
s
.1843 .26844 m
.18451 .26341 L
s
0 0 0 r
.86498 .26798 m
.86529 .27517 L
s
.8649 .27571 m
.86496 .28704 L
s
.86443 .2953 m
.86496 .28704 L
s
.255 .412 .882 r
.18422 .28966 m
.18492 .29322 L
s
.86033 .2987 m
.86096 .30324 L
s
.1843 .26844 m
.18446 .27401 L
s
.18404 .28408 m
.18443 .28461 L
s
.18432 .28713 m
.18443 .28461 L
s
.86075 .29818 m
.86137 .30272 L
s
.8617 .25415 m
.86279 .25501 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18394 .28661 m
.18422 .28966 L
s
.18394 .28661 m
.18404 .28408 L
s
.86096 .30324 m
.86198 .30728 L
s
.86137 .30272 m
.86237 .30676 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86279 .25501 m
.86361 .25895 L
s
.86198 .30728 m
.86322 .30828 L
s
.86237 .30676 m
.86322 .30828 L
s
.86328 .25138 m
.86414 .2716 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86321 .27322 m
.86524 .26942 L
s
.86357 .25083 m
.86443 .27106 L
s
.86322 .30828 m
.86393 .30725 L
s
.86393 .30725 m
.86482 .30315 L
s
.18097 .2793 m
.18117 .28237 L
s
.18106 .28491 m
.18117 .28237 L
s
.18065 .28692 m
.18106 .28491 L
s
.18058 .2813 m
.18097 .2793 L
s
.17933 .24476 m
.1808 .24869 L
s
.18058 .2813 m
.18076 .28437 L
s
.1798 .28532 m
.18065 .28692 L
s
0 0 0 r
.8691 .23688 m
.87025 .23337 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86482 .30315 m
.86522 .29701 L
s
.86509 .24748 m
.86641 .24353 L
s
0 0 0 r
.17568 .2352 m
.17612 .24055 L
s
.17603 .24835 m
.17612 .24055 L
s
.255 .412 .882 r
.86518 .28884 m
.86583 .30415 L
s
.86518 .28884 m
.86522 .29701 L
s
0 0 0 r
.1743 .28837 m
.17603 .24835 L
s
.255 .412 .882 r
.86522 .29701 m
.86583 .30415 L
s
.17859 .28264 m
.18011 .24701 L
s
0 0 0 r
.17568 .2352 m
.17591 .23997 L
s
.17581 .24779 m
.17591 .23997 L
s
.255 .412 .882 r
.1794 .2817 m
.1798 .28532 L
s
.17838 .2821 m
.1799 .24645 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17533 .23405 m
.17568 .2352 L
s
.255 .412 .882 r
.86572 .24579 m
.86724 .28147 L
s
.17914 .27552 m
.1794 .2817 L
s
.86591 .24523 m
.86743 .28094 L
s
0 0 0 r
.17408 .28783 m
.1745 .28877 L
s
.255 .412 .882 r
.17914 .27552 m
.17924 .26733 L
s
0 0 0 r
.17533 .23405 m
.17472 .23594 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86661 .28309 m
.86743 .28094 L
s
.1778 .28049 m
.17859 .28264 L
s
.86678 .26559 m
.86728 .27271 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17408 .28783 m
.17581 .24779 L
s
.5 Mabswid
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17472 .23594 m
.17416 .24207 L
s
.255 .412 .882 r
.86728 .27271 m
.86783 .27675 L
s
0 0 0 r
.17464 .23114 m
.17427 .22881 L
s
.255 .412 .882 r
.17759 .26182 m
.17847 .24136 L
s
.17722 .2596 m
.17798 .26348 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86974 .23511 m
.87306 .31186 L
s
.86956 .23568 m
.87287 .31238 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17748 .26126 m
.17836 .24079 L
s
.86783 .27675 m
.86823 .27823 L
s
.17803 .24846 m
.17806 .24221 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1723 .28184 m
.17453 .23056 L
s
.17241 .28239 m
.17464 .23114 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87128 .23236 m
.87144 .24082 L
s
.255 .412 .882 r
.17798 .23794 m
.17806 .24221 L
s
0 0 0 r
.87287 .31238 m
.87358 .31028 L
s
.87128 .22695 m
.87128 .23236 L
s
.1728 .28403 m
.1723 .28184 L
s
.255 .412 .882 r
.86826 .272 m
.86847 .27402 L
s
.86825 .26888 m
.86826 .272 L
s
.86825 .26888 m
.86846 .2709 L
s
.1779 .23679 m
.17798 .23794 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86823 .27823 m
.86859 .2766 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87133 .22578 m
.87128 .22695 L
s
.255 .412 .882 r
.17616 .29529 m
.17682 .27981 L
s
.17638 .28701 m
.17682 .27981 L
s
.86857 .27347 m
.86859 .2766 L
s
.86846 .2709 m
.86857 .27347 L
s
0 0 0 r
.87256 .26647 m
.87272 .27015 L
s
.87248 .26223 m
.87256 .26647 L
s
.87272 .26535 m
.87248 .26223 L
s
.87272 .27015 m
.8732 .27641 L
s
.255 .412 .882 r
.17775 .23822 m
.1779 .23679 L
s
.17774 .23764 m
.1779 .23679 L
s
0 0 0 r
.17406 .22588 m
.17373 .23262 L
s
.17342 .24054 m
.17406 .22588 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8715 .22827 m
.87133 .22578 L
s
.87149 .22768 m
.87133 .22578 L
s
.255 .412 .882 r
.17638 .28701 m
.17597 .2911 L
s
.17616 .29529 m
.17638 .28701 L
s
0 0 0 r
.8728 .26959 m
.87272 .26535 L
s
.17373 .23262 m
.17342 .24054 L
s
.17389 .22837 m
.17373 .23262 L
s
.255 .412 .882 r
.17753 .24222 m
.17775 .23822 L
s
.86764 .23812 m
.86785 .24383 L
s
.86785 .24383 m
.86807 .24898 L
s
.8675 .23383 m
.86764 .23812 L
s
0 0 0 r
.17408 .22352 m
.17389 .22837 L
s
.87179 .23445 m
.8715 .22827 L
s
.8732 .27641 m
.87348 .279 L
s
.255 .412 .882 r
.86807 .24898 m
.86831 .25357 L
s
.17755 .24165 m
.17774 .23764 L
s
.86764 .23755 m
.86786 .24326 L
s
.86786 .24326 m
.86808 .24841 L
s
.17597 .2911 m
.17565 .29209 L
s
.8675 .23383 m
.86764 .23755 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87175 .23387 m
.87149 .22768 L
s
.17427 .22116 m
.17408 .22352 L
s
.255 .412 .882 r
.86808 .24841 m
.86831 .25301 L
s
.86831 .25357 m
.86839 .25447 L
s
.86738 .2321 m
.8675 .23383 L
s
.17733 .24681 m
.17753 .24222 L
s
0 0 0 r
.87348 .279 m
.87358 .27735 L
s
.255 .412 .882 r
.86831 .25301 m
.86839 .25447 L
s
0 0 0 r
.87223 .24493 m
.87179 .23445 L
s
.17246 .26264 m
.17261 .25839 L
s
.17214 .27004 m
.17246 .26264 L
s
.255 .412 .882 r
.17736 .24625 m
.17755 .24165 L
s
0 0 0 r
.17261 .25839 m
.17277 .25356 L
s
.1723 .26634 m
.17245 .26208 L
s
.255 .412 .882 r
.86875 .26391 m
.86886 .26649 L
s
.86875 .26391 m
.86875 .26335 L
s
.17565 .29209 m
.17557 .29102 L
s
.17702 .254 m
.17733 .24681 L
s
0 0 0 r
.87219 .24436 m
.87175 .23387 L
s
.17245 .26208 m
.17261 .25725 L
s
.255 .412 .882 r
.86886 .26649 m
.86897 .26853 L
s
0 0 0 r
.17196 .27318 m
.17214 .27004 L
s
.255 .412 .882 r
.86875 .26335 m
.86886 .26594 L
s
0 0 0 r
.17277 .25356 m
.17331 .2433 L
s
.255 .412 .882 r
.17706 .25344 m
.17736 .24625 L
s
.86735 .23353 m
.86738 .2321 L
s
0 0 0 r
.17427 .22367 m
.17427 .22116 L
s
.255 .412 .882 r
.86816 .2537 m
.86839 .25447 L
s
0 0 0 r
.17261 .25725 m
.17315 .24701 L
s
.255 .412 .882 r
.86897 .26853 m
.86906 .27002 L
s
0 0 0 r
.87358 .27735 m
.87343 .27253 L
s
.87358 .27735 m
.87342 .27198 L
s
.255 .412 .882 r
.17557 .29102 m
.17564 .28735 L
s
.17557 .29102 m
.17563 .28681 L
s
0 0 0 r
.87256 .25232 m
.87223 .24493 L
s
.17181 .27578 m
.17196 .27318 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17647 .26697 m
.17702 .254 L
s
0 0 0 r
.87251 .25175 m
.87219 .24436 L
s
.87307 .264 m
.87256 .25232 L
s
.87343 .27253 m
.87307 .264 L
s
.87048 .21752 m
.87094 .21988 L
s
.255 .412 .882 r
.1765 .26642 m
.17706 .25344 L
s
.17564 .28735 m
.17586 .28106 L
s
.86735 .23353 m
.86739 .23756 L
s
0 0 0 r
.17421 .22677 m
.17427 .22367 L
s
.255 .412 .882 r
.86887 .26782 m
.86906 .27002 L
s
0 0 0 r
.87304 .26344 m
.87251 .25175 L
s
.87342 .27198 m
.87304 .26344 L
s
.255 .412 .882 r
.17563 .28681 m
.17588 .28052 L
s
.1761 .27531 m
.17647 .26697 L
s
.17586 .28106 m
.1761 .27531 L
s
0 0 0 r
.17195 .27357 m
.17181 .27578 L
s
.17331 .2433 m
.17363 .23845 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17372 .23787 m
.17421 .22677 L
s
.17315 .24701 m
.17347 .24215 L
s
.255 .412 .882 r
.17613 .27477 m
.1765 .26642 L
s
.17588 .28052 m
.17613 .27477 L
s
0 0 0 r
.17363 .23845 m
.17389 .23417 L
s
.87061 .21811 m
.87287 .27014 L
s
.255 .412 .882 r
.86707 .2318 m
.86739 .23756 L
s
.86739 .23756 m
.8684 .26095 L
s
.86671 .22806 m
.86707 .2318 L
s
0 0 0 r
.17347 .24215 m
.17372 .23787 L
s
.87048 .21752 m
.87274 .26958 L
s
.255 .412 .882 r
.86695 .23123 m
.86729 .23699 L
s
.86729 .23699 m
.86807 .25518 L
s
.86671 .22806 m
.86695 .23123 L
s
.86816 .2537 m
.86818 .25574 L
s
.86657 .22748 m
.86671 .22806 L
s
.86861 .26411 m
.86887 .26782 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17225 .26873 m
.17195 .27357 L
s
.87034 .22003 m
.87096 .22862 L
s
.255 .412 .882 r
.8684 .26095 m
.86861 .26411 L
s
.17666 .26681 m
.17738 .26349 L
s
0 0 0 r
.86965 .21455 m
.87034 .22003 L
s
.1725 .26444 m
.17225 .26873 L
s
.255 .412 .882 r
.86807 .25518 m
.8684 .26095 L
s
0 0 0 r
.17292 .25643 m
.1725 .26444 L
s
.17227 .27135 m
.17292 .25643 L
s
.1725 .26444 m
.17227 .27135 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17697 .26515 m
.17803 .24587 L
s
0 0 0 r
.17535 .21895 m
.1757 .21465 L
s
.17538 .22207 m
.17535 .21895 L
s
.1757 .21465 m
.17574 .21777 L
s
.86925 .21337 m
.86965 .21455 L
s
.17574 .21777 m
.17538 .22207 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86473 .20582 m
.8649 .20975 L
s
.86494 .20642 m
.86509 .21005 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86895 .2159 m
.86925 .21337 L
s
.86871 .21531 m
.86925 .21337 L
s
.87228 .26791 m
.87287 .27014 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86895 .2159 m
.86903 .22276 L
s
.86871 .21531 m
.86878 .22218 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86627 .23759 m
.86655 .24406 L
s
.86605 .23668 m
.86635 .24377 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17262 .28572 m
.1736 .26314 L
s
.17244 .28626 m
.17457 .24069 L
s
.17282 .28517 m
.17457 .24069 L
s
.5 Mabswid
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17229 .29327 m
.17244 .28626 L
s
.17282 .28517 m
.17229 .29327 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86878 .22218 m
.87056 .26345 L
s
.86903 .22276 m
.87082 .26401 L
s
.86973 .26178 m
.87082 .26401 L
s
.8655 .20565 m
.86647 .22819 L
s
.85825 .19621 m
.8655 .20565 L
s
.86513 .20506 m
.86647 .22819 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85677 .20956 m
.85691 .20974 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18675 .21187 m
.18805 .21023 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86793 .26223 m
.86854 .28455 L
s
.86793 .26223 m
.8689 .28509 L
s
.86425 .22851 m
.86554 .25891 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1858 .23442 m
.18697 .23187 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86034 .19856 m
.86372 .27864 L
s
.85983 .19797 m
.86321 .27811 L
s
.8621 .24031 m
.8649 .24368 L
s
.86162 .2765 m
.8689 .28509 L
s
.255 .412 .882 r
.18519 .24903 m
.1865 .24744 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85732 .2457 m
.85838 .24491 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20448 .22953 m
.20498 .21693 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20528 .22899 m
.20578 .2165 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27938 .14909 m
.28869 .14644 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28244 .1482 m
.29102 .23004 L
s
.28483 .17133 m
.2993 .16758 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29833 .14388 m
.30832 .14142 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29137 .2178 m
.30328 .14264 L
s
.29102 .23004 m
.30495 .14223 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31171 .14063 m
.32388 .13794 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.316 .18336 m
.3175 .1765 L
s
.31589 .18357 m
.316 .18336 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31876 .17821 m
.3192 .1762 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31541 .19619 m
.31688 .13946 L
s
.31716 .19583 m
.31862 .13908 L
s
.31779 .17141 m
.31923 .18323 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31021 .19729 m
.31716 .19583 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31923 .18323 m
.32256 .19068 L
s
.34934 .13709 m
.35509 .13207 L
s
.34541 .14586 m
.34934 .13709 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34327 .15839 m
.34541 .14586 L
s
.35122 .13677 m
.35509 .13207 L
s
.34728 .14553 m
.35122 .13677 L
s
.32256 .19068 m
.32604 .19406 L
s
.35509 .13207 m
.35891 .13145 L
s
.34514 .15806 m
.34728 .14553 L
s
.68691 .13152 m
.68891 .13589 L
s
.68508 .13527 m
.68691 .13152 L
s
.35891 .13145 m
.3646 .1346 L
s
.68708 .13964 m
.68891 .13589 L
s
.34309 .16653 m
.34327 .15839 L
s
.32984 .1852 m
.33176 .18078 L
s
.33176 .18078 m
.33348 .18452 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32984 .1852 m
.33156 .18895 L
s
.34496 .16621 m
.34514 .15806 L
s
.32604 .19406 m
.33146 .19304 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68508 .13527 m
.68708 .13964 L
s
.34309 .16653 m
.34468 .17847 L
s
.33339 .18861 m
.33348 .18452 L
s
.34496 .16621 m
.34656 .17815 L
s
.3646 .1346 m
.36833 .14215 L
s
.33146 .19304 m
.33339 .18861 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34468 .17847 m
.34827 .18604 L
s
.34656 .17815 m
.35016 .18573 L
s
.66547 .12832 m
.6695 .13294 L
s
.6695 .13294 m
.67155 .13729 L
s
.65747 .12727 m
.66547 .12832 L
s
.38037 .12826 m
.39443 .12646 L
s
.67155 .13729 m
.67178 .14953 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6698 .14926 m
.6717 .14545 L
s
.65351 .13084 m
.65747 .12727 L
s
.34827 .18604 m
.35388 .18924 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68659 .20906 m
.68751 .16001 L
s
.68751 .16001 m
.69046 .20963 L
s
.66988 .15335 m
.67178 .14953 L
s
.35016 .18573 m
.35388 .18924 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37283 .16975 m
.37288 .16696 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3659 .16696 m
.36777 .17078 L
s
.36387 .17135 m
.3659 .16696 L
s
.36387 .17135 m
.36574 .17517 L
s
.35388 .18924 m
.35966 .18836 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66598 .15691 m
.66988 .15335 L
s
.64939 .12627 m
.64965 .14262 L
s
.64939 .12627 m
.65155 .13468 L
s
.65155 .13468 m
.65351 .13084 L
s
.66591 .15281 m
.6698 .14926 L
s
.68802 .1846 m
.68853 .20934 L
s
.65601 .15975 m
.66591 .15281 L
s
.64965 .14262 m
.65155 .13468 L
s
.40259 .12552 m
.41706 .12401 L
s
.36769 .17489 m
.36777 .17078 L
s
.65608 .16386 m
.66598 .15691 L
s
.36362 .18367 m
.36769 .17489 L
s
.35966 .18836 m
.36362 .18367 L
s
.40811 .17003 m
.40876 .12485 L
s
.67033 .17798 m
.67216 .17002 L
s
.67216 .17002 m
.67247 .18649 L
s
.41019 .16982 m
.41083 .12463 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63094 .12835 m
.63521 .13695 L
s
.62463 .12366 m
.63094 .12835 L
s
.62044 .12328 m
.62463 .12366 L
s
.66842 .18184 m
.67033 .17798 L
s
.67033 .17798 m
.67247 .18649 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65202 .16338 m
.65601 .15975 L
s
.6887 .21763 m
.69046 .20963 L
s
.61627 .12701 m
.62044 .12328 L
s
.61416 .12683 m
.62044 .12328 L
s
.42543 .12324 m
.44025 .12204 L
s
.65209 .1675 m
.65608 .16386 L
s
.6645 .18545 m
.66842 .18184 L
s
.68659 .20906 m
.6887 .21763 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38487 .21393 m
.38636 .12747 L
s
.3869 .2137 m
.38837 .12721 L
s
.61214 .13486 m
.61627 .12701 L
s
.65005 .16726 m
.65202 .16338 L
s
.61001 .1347 m
.61416 .12683 L
s
.38761 .17228 m
.39153 .18005 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65643 .18448 m
.6645 .18545 L
s
.65005 .16726 m
.65018 .17551 L
s
.65011 .17139 m
.65209 .1675 L
s
.59064 .12106 m
.59922 .12162 L
s
.44879 .12144 m
.46387 .12055 L
s
.6355 .15749 m
.63562 .16574 L
s
.63344 .15731 m
.6355 .15749 L
s
.63342 .15729 m
.63359 .16967 L
s
.65018 .17551 m
.65229 .17987 L
s
.39153 .18005 m
.39759 .1835 L
s
.65229 .17987 m
.65643 .18448 L
s
.58201 .12058 m
.58636 .12491 L
s
.57767 .12036 m
.58201 .12058 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58636 .12491 m
.59075 .13338 L
s
.57118 .12417 m
.57767 .12036 L
s
.57336 .12426 m
.57767 .12036 L
s
.60802 .14688 m
.61001 .1347 L
s
.61015 .14704 m
.61214 .13486 L
s
.47255 .12013 m
.48782 .11956 L
s
.63365 .1738 m
.63562 .16574 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43109 .18042 m
.43176 .1227 L
s
.43322 .18025 m
.43387 .12253 L
s
.45475 .17885 m
.45524 .12103 L
s
.45692 .17873 m
.45739 .12091 L
s
.47883 .16527 m
.47908 .11986 L
s
.40591 .1785 m
.40811 .17003 L
s
.48103 .16519 m
.48126 .11978 L
s
.56905 .1323 m
.57336 .12426 L
s
.61015 .14704 m
.61024 .15529 L
s
.40799 .1783 m
.41019 .16982 L
s
.39759 .1835 m
.40171 .18307 L
s
.56687 .13222 m
.57118 .12417 L
s
.60802 .14688 m
.60811 .15513 L
s
.63162 .17774 m
.63359 .16967 L
s
.49658 .11933 m
.51195 .11908 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61024 .15529 m
.63344 .15731 L
s
.40171 .18307 m
.40591 .1785 L
s
.40171 .18307 m
.40799 .1783 L
s
.53834 .11914 m
.54493 .12336 L
s
.53394 .11909 m
.53834 .11914 L
s
.52955 .12316 m
.53394 .11909 L
s
.52735 .12315 m
.53394 .11909 L
s
.63162 .17774 m
.63365 .1738 L
s
.54493 .12336 m
.54935 .13168 L
s
.61024 .15529 m
.61251 .16785 L
s
.37882 .21466 m
.3869 .2137 L
s
.56694 .14459 m
.56905 .1323 L
s
.52515 .13138 m
.52955 .12316 L
s
.52294 .13137 m
.52735 .12315 L
s
.60811 .15513 m
.61038 .16769 L
s
.56475 .14451 m
.56687 .13222 L
s
.62748 .18151 m
.63162 .17774 L
s
.52294 .14376 m
.52515 .13138 L
s
.52074 .14376 m
.52294 .13137 L
s
.61251 .16785 m
.61686 .17647 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62115 .18096 m
.62748 .18151 L
s
.61038 .16769 m
.61473 .1763 L
s
.255 .412 .882 r
.49354 .16393 m
.49517 .15746 L
s
0 0 0 r
.56694 .14459 m
.56699 .15286 L
s
.56475 .14451 m
.5648 .15278 L
s
.61686 .17647 m
.62115 .18096 L
s
.61473 .1763 m
.62115 .18096 L
s
.42472 .18092 m
.43322 .18025 L
s
.52074 .15203 m
.52074 .14376 L
s
.52294 .14376 m
.52295 .15203 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49572 .16225 m
.49573 .15746 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50305 .16464 m
.50316 .1192 L
s
.50526 .1646 m
.50536 .11916 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5648 .15278 m
.56706 .16529 L
s
.56699 .15286 m
.56925 .16537 L
s
.58676 .17448 m
.59103 .16642 L
s
.45702 .16627 m
.4613 .17434 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54942 .15233 m
.54945 .16062 L
s
.52295 .15203 m
.54942 .15233 L
s
.54722 .15228 m
.54726 .16473 L
s
.52074 .15203 m
.52295 .16448 L
s
.52295 .15203 m
.52516 .16448 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44825 .17923 m
.45692 .17873 L
s
.56925 .16537 m
.57368 .17386 L
s
.58244 .17842 m
.58676 .17448 L
s
.56706 .16529 m
.57149 .17377 L
s
.47659 .17367 m
.47883 .16527 L
s
.54727 .16888 m
.54945 .16062 L
s
.48103 .16519 m
.48538 .17337 L
s
.47879 .17358 m
.48103 .16519 L
s
.4613 .17434 m
.46781 .17819 L
s
.54507 .173 m
.54726 .16473 L
s
.57368 .17386 m
.57808 .17821 L
s
.57808 .17821 m
.58244 .17842 L
s
.50082 .17299 m
.50305 .16464 L
s
.50303 .17296 m
.50526 .1646 L
s
.57149 .17377 m
.57808 .17821 L
s
.43085 .20123 m
.43294 .20525 L
s
.42867 .20557 m
.43085 .20123 L
s
.52516 .16448 m
.52959 .17282 L
s
.47218 .178 m
.47659 .17367 L
s
.52295 .16448 m
.52737 .17281 L
s
.46781 .17819 m
.47218 .178 L
s
.47218 .178 m
.47879 .17358 L
s
.54507 .173 m
.54727 .16888 L
s
.42867 .20557 m
.43076 .20959 L
s
.48538 .17337 m
.49197 .17735 L
s
.43076 .20959 m
.43294 .20525 L
s
.54066 .17709 m
.54507 .173 L
s
.49639 .17724 m
.50082 .17299 L
s
.49639 .17724 m
.50303 .17296 L
s
.52959 .17282 m
.53402 .17702 L
s
.52737 .17281 m
.53402 .17702 L
s
.49197 .17735 m
.49639 .17724 L
s
.53402 .17702 m
.54066 .17709 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59064 .12106 m
.59139 .2081 L
s
.59279 .1212 m
.59356 .20822 L
s
.58485 .20776 m
.59356 .20822 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00@0[Jf]0?nV403oYQ00ojH@
2@00000:0?nV40<000001@3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>
0P2][Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0;0?nV4@D000000`3o
YQ49000000L0[Jf]0P00000;0:f][@8000000`2][Jd200000140[Jf]0`0000030?nU408000002@3o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503f
W0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA20000000
103oYQ40[Jf]0:f][@2][Jd5000000L0[Jf]0`3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ001@3o
YQ02000000X0ojH@0P0000060?nV40040000003oYQ00ojH@0:f][@/0ojD@0P0000020?nU40040:f]
[@000000[Jf]0:f][@D000002P2][Jd00`000000oj<@0?nS400E0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?ooo`00
O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA0140ojHA1@0000060:f][@800000102][Jd60?nV4@8000002P3oYQ4200000080ojHA
00<0[Jf]0?nV403oYQ001@3oYQ02000000T0ojH@0P0000080?nV40030000003oYQ00[Jf]00T0ojD@
0`0000050?nU40040000003oYA000000000000T0ojD@00D0[Jf]0?nS4000000000000?nS40020000
00L0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF
3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@@000000P3oYQ420:f][@D0
00000`2][Jd40?nV4@040:f][@3oYQ400000000000X0ojHA0P00000:0?nV4@8000000P3oYQ400`2]
[Jd0ojH@0?nV40050?nV40800000203oYQ000`000000ojH@000000080?nV40030000003oYQ00[Jf]
00P0ojD@00<000000?nU400000001P3oYA0010000000ojD@0000000000090?nU40030:f][@000000
000000@0oj<@0P0000050?nS40@0[Jf]00@000000:f][@2][Jd0[Jf]0P0000040?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`
h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G
0?nV4@030:f][@3oYQ40ojHA0080ojHA1@0000050:f][@D0ojHA0P0000070?nV4@040:f][@3oYQ40
0000000000X0ojHA0P00000:0?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40050?nV40800000203o
YQ02000000X0ojH@00<000000:f][@3oYA001`3oYA02000000P0ojD@0`0000090?nU408000001`3o
Xa000`000000oj<@0?nS40060?nS40040000003oXa00oj<@00000080oj<@0`0000040:f][AP0o:0@
00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`
h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0B0?nV4@030000003o
YQ40ojHA00L0[Jf]0`3oYQ42000000X0ojHA0P0000070?nV4@040:f][@3oYQ400000000000X0ojHA
0P00000:0?nV4@8000000P3oYQ400`2][Jd0ojH@0?nV40050?nV408000001`3oYQ000`000000ojH@
0000000:0?nV40030000002][Jd0ojD@00H0ojD@00<000000?nU40000000203oYA03000000T0ojD@
0P0000070?nS40030000003oXa00oj<@00H0oj<@00<000000?nS400000001P3oXa0010000000[Jf]
0?bP403lX1060:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0
[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0@0?nV4@80000000<0[Jf]0000000000000P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000
2P3oYQ42000000L0ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000X0ojHA0P0000020?nV4@03
0:f][@3oYQ00ojH@00D0ojH@0P0000070?nV40030000003oYQ00000000/0ojH@00<000000?nU403o
YA001@3oYA02000000X0ojD@0P0000080?nU408000002@3oXa000`000000oj<@0?nS40050?nS4080
0000203oXa000`000000o:0@0?bP40060?bP40030000002][Jd0[Jf]0080[Jf]3@3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40
oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A
00<0[Jf]0?nV4@3oYQ402`3oYQ430:f][@8000001@3oYQ400`000000ojHA0:f][@070?nV4@800000
2P3oYQ42000000L0ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000X0ojHA0P0000020?nV4@03
0:f][@3oYQ00ojH@00D0ojH@0P0000070?nV40800000303oYQ000`2][Jd0ojD@0?nU40050?nU4080
00002P3oYA02000000P0ojD@0P0000090?nS40030000003oXa00oj<@00D0oj<@0P0000080?nS4003
0000003lX100o:0@00D0o:0@0P0000040?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V
0P2][Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA
0?nV4@050?nV4@H0[Jf]0P3oYQ42000000H0ojHA00<000000?nV4@2][Jd01`3oYQ42000000X0ojHA
0P0000070?nV4@040:f][@3oYQ400000000000X0ojHA0P00000:0?nV4@8000000P3oYQ400`2][Jd0
ojH@0?nV40050?nV408000001`3oYQ02000000`0ojH@00<0[Jf]0?nU403oYA001@3oYA02000000X0
ojD@0P0000080?nU408000002P3oXa000`000000oj<@0?nS40040?nS40800000203oXa000`2][Jd0
00000?bP40050?bP40030000003lX100000000P0o:0@1P2][Jd20?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@80[Jf]F@2`h>H10?ooo`00
KP2`h>H00`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
503oY144000000@0[Jf]203oYQ42000000H0ojHA00<000000?nV4@2][Jd01`3oYQ42000000X0ojHA
0P0000070?nV4@040:f][@3oYQ400000000000X0ojHA0P00000:0?nV4@8000000P3oYQ400`2][Jd0
ojH@0?nV40050?nV408000001P3oYQ000`000000ojH@0000000<0?nV40030:f][@3oYA00ojD@00@0
ojD@0P00000;0?nU40800000203oYA0200000140oj<@00<000000?nS403oXa001`3oXa000`2][Jd0
00000?bP40060?bP40030000003lX100o:0@00d0o:0@102][JdE0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3oY147000000030:f][@3oYQ40ojHA00X0ojHA
0P0000080?nV4@030000002][Jd0ojHA00H0ojHA0P00000:0?nV4@8000001`3oYQ40102][Jd0ojHA
00000000000:0?nV4@8000002P3oYQ4200000080ojHA00<0[Jf]0?nV403oYQ001@3oYQ02000000H0
ojH@00<000000?nV40000000303oYQ000`2][Jd0ojD@0?nU40040?nU408000002`3oYA02000000L0
ojD@0P0000000`2][Jd0oj<@0?nS400?0?nS40030000003oXa00oj<@00L0oj<@00<0[Jf]0000003l
X1001P3lX1000`000000o:0@0?bP400?0?bP40030:f][@3fW0l0[Jf]00<0[Jf]4@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]
2@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A0P0000040:f][@030?nT
4@000000000000d0ojHA0P0000080?nV4@030000002][Jd0ojHA00H0ojHA0P00000:0?nV4@800000
1P3oYQ400`2][Jd0ojHA0?nV4@02000000X0ojHA0P0000090?nV4@030000003oYQ4000000080ojHA
00<0[Jf]0?nV403oYQ001@3oYQ02000000H0ojH@0P00000=0?nV40030:f][@3oYA00ojD@00@0ojD@
0P00000;0?nU408000001`3oYA02000000030:f][@3oXa00oj<@00l0oj<@00<000000?nS403oXa00
1`3oXa000`2][Jd000000?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V0P2]
[Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY144000000D0oj@A0P00
000<0?nV4@8000002P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002P3oYQ42000000H0ojHA00<0
[Jf]0?nV4@3oYQ400P00000:0?nV4@8000002@3oYQ400`000000ojHA000000020?nV4@030:f][@3o
YQ00ojH@00D0ojH@0P0000060?nV408000003@3oYQ000`2][Jd0ojD@0?nU40040?nU408000002`3o
YA02000000L0ojD@0P0000000`2][Jd0oj<@0?nS400I0?nS40030:f][@000000000001P0o:0@00<0
[Jf]0?JL3`3fW0l01`3fW0l40:f][@T0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00@0oj@A0`0000040:f][@80oj@A0P000005
0?nT4@800000303oYQ42000000X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000X0ojHA0P000006
0?nV4@030:f][@3oYQ40ojHA008000002P3oYQ42000000T0ojHA00<000000?nV4@0000000P3oYQ40
0`2][Jd0ojH@0?nV40050?nV408000001P3oYQ02000000d0ojH@00<0[Jf]0?nU403oYA00103oYA02
000000/0ojD@0P0000070?nU4080000000<0[Jf]0?nS403oXa006@3oXa000`2][Jd000000000000H
0?bP40030:f][@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@
00l0o:0@00@0[Jf]0?nT4@3oY140oj@A0`0000030:f][@H0oj@A0P0000050?nT4@800000303oYQ42
000000X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000070?nV4@030:f][@3oYQ40
ojHA008000002P3oYQ42000000T0ojHA00<000000?nV4@0000000P3oYQ400`2][Jd0ojH@0?nV4005
0?nV408000001P3oYQ02000000d0ojH@00<0[Jf]0?nU403oYA00103oYA02000000/0ojD@0P000007
0?nU4080000000<0[Jf]0?nS403oXa006P3oXa02000001P0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l4
0:f][@030?JL3`2][Jd0k9H>0140k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0:f][@1@
0;3PiP40oooo001U0;3PiP030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0:f][@030:f][@030000003oY140oj@A00H0oj@A0P0000060?nT4@800000303oYQ420000
00X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA
008000002@3oYQ400`000000ojHA000000090?nV4@030000003oYQ4000000080ojHA00<0[Jf]0?nV
403oYQ001@3oYQ02000000H0ojH@0P00000=0?nV40030:f][@3oYA00ojD@00@0ojD@0P00000;0?nU
408000001`3oYA02000000030:f][@3oXa00oj<@01T0oj<@0P00000I0?bP40030:f][@3fW0l0mY`?
01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H1
0?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00h0o:0@0`2][Jd4
0?nT4@030000003oY140oj@A00H0oj@A0P0000060?nT4@8000002`3oYQ42000000/0ojHA00<0[Jf]
0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA008000002@3oYQ40
0`000000ojHA000000090?nV4@030000003oYQ4000000080ojHA00<0[Jf]0?nV403oYQ001@3oYQ02
000000H0ojH@400000060?nU408000002`3oYA02000000L0ojD@0P0000000`2][Jd0oj<@0?nS400H
0?nS40030000003oXa00000001T0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@02
0:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3o
ool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P2]
[Jd00`3lX100[Jf]0?nT4@040?nT4@030000003oY140oj@A00H0oj@A0P0000060?nT4@8000002`3o
YQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P0000070?nV4@030:f][@3o
YQ40ojHA008000002@3oYQ400`000000ojHA000000090?nV4@030000003oYQ4000000080ojHA00<0
[Jf]0?nV403oYQ001@3oYQ02000000H0ojH@0P00000<0?nV408000001P3oYA02000000/0ojD@0P00
00070?nU40L000005@3oXa0010000000oj<@0000002][JdI0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@<0o:0@00<0[Jf]0?nT4@3oY1400`3o
Y1400`000000oj@A0?nT4@060?nT4@8000001P3oY142000000/0ojHA0P00000;0?nV4@030:f][@3o
YQ40ojHA00D0ojHA0P0000090?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@02000000T0ojHA00<0
00000?nV4@0000001`3oYQ420:f][@030000002][Jd0000000X0[Jf]0P0000060:f][@030000002]
[Jd0000000/0[Jf]0P0000060:f][@8000002`3oYA02000000L0ojD@0P0000000`2][Jd0oj<@0?nS
40020?nS40L00000303oXa02000000040?nS40000000oj<@0:f][AT0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>7
3P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f][@H0o:0@00<0
[Jf]0?nT4@3oY1400`3oY1400`000000oj@A0?nT4@060?nT4@8000001@3oY1400`2][Jd000000000
000;0?nV4@8000002`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000002@3oYQ42000000L0ojHA00<0
[Jf]0?nV4@3oYQ400P0000030?nV4@H0[Jf]00<000000:f][@0000001`2][Jd20?nV4@030000003o
YQ4000000080ojHA00<0[Jf]0?nV403oYQ001@3oYQ02000000H0ojH@00<000000?nV400000002`3o
YQ02000000H0ojD@0P00000;0:f][@8000000P2][Jd50?nU4080000000<0[Jf]0?nS403oXa001`3o
Xa02000000/0oj<@00@000000?nS403oXa0000000P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0
[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2]
[Jd80?bP40030:f][@3oY140oj@A00@0oj@A00<000000?nT4@3oY1401@3oY142000000D0oj@A00<0
[Jf]0000000000002`3oYQ42000000/0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000T0ojHA0P00
00030?nV4@L0[Jf]0P0000030:f][@H0ojHA00<000000?nV4@0000002@3oYQ400`000000ojHA0000
00020?nV4@030:f][@3oYQ00ojH@00D0ojH@0P0000070?nV408000002`3oYQ02000000L0ojD@0P00
000:0?nU408000000P3oYA050:f][@8000001@2][Jd50?nS408000002P3oXa0010000000oj<@0000
000000030?nS40030:f][@3lX100o:0@00D0o:0@00<000000?bP403lX1003`3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3C
Q`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@
00<0[Jf]0?nT4@3oY140103oY1400`000000oj@A0?nT4@040?nT4@8000001P3oY1400`2][Jd00000
0000000;0?nV4@8000002`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000001@3oYQ440:f][@800000
0`2][Jd40?nV4@030:f][@3oYQ40ojHA008000002@3oYQ400`000000ojHA000000090?nV4@030000
003oYQ4000000080ojHA00D0[Jf]0?nV403oYQ00ojH@045Yh@030?nV408000001`3oYQ000`000000
ojH@0000000:0?nV408000001`3oYA02000000X0ojD@0P0000080?nU40800000103oXa050:f][@03
0000002][Jd000000080[Jf]1@3oXa02000000030?nS40000000oj<@00@0oj<@00<0[Jf]0?bP403l
X1001@3lX1000`000000o:0@0?bP400?0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
2`3_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f][@3oY140oj@A00@0oj@A00<000000?nT4@3o
Y140103oY142000000H0oj@A00<0[Jf]0000000000002`3oYQ42000000/0ojHA00<0[Jf]0?nV4@3o
YQ400P3oYQ430:f][@8000001@2][Jd40?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@02000000T0
ojHA00<000000?nV4@0000002@3oYQ400`000000ojHA000000020?nV4@030:f][@3oYQ00ojH@00D0
ojH@0P0000070?nV40030000003oYQ00000000X0ojH@00<000000:f][@3oYA001P3oYA02000000X0
ojD@0P0000080?nU408000002@3oXa000`000000oj<@000000020?nS40@0[Jf]00@000000:f][@2]
[Jd000000P2][Jd40?nS40030:f][@3lX100o:0@00D0o:0@00<000000?bP403lX1003`3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][Jd=0=^:3@030:f][@2iM@/0^GD;
00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080
[Jf]403lX1000`2][Jd0oj@A0?nT4@040?nT4@030000003oY140oj@A00<0oj@A0`0000060?nT4@03
0:f][@000000000000/0ojHA0P0000090?nV4@030000002][Jd0[Jf]00@0[Jf]0`3oYQ42000000T0
ojHA0P0000070?nV4@030:f][@3oYQ40ojHA008000002@3oYQ400`000000ojHA000000090?nV4@<0
00000P3oYQ400`2][Jd0ojH@0?nV40040?nV40030000003oYQ00000000P0ojH@0P0000090?nV4080
000000<0[Jf]0?nU403oYA001P3oYA02000000T0ojD@00<000000?nU400000001`3oYA02000000T0
oj<@00<000000?nS400000001P3oXa03000000<0oj<@202][Jd40?bP40030000003lX100o:0@00l0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]2`3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V100
2@3_V1030:f][A40o:0@00<0[Jf]0?nT4@3oY140103oY1400`000000oj@A00000003000000030?nT
4@000000000000H0oj@A0P00000<0?nV4@8000000`3oYQ450:f][@80000000<0ojHA0:f][@3oYQ40
1P3oYQ42000000T0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA008000002@3oYQ400`000000ojHA
000000090?nV4@80000000@0ojHA0000003oYQ40[Jf]1P3oYQ02000000T0ojH@00<000000?nV4000
0000203oYQ02000000030:f][@3oYA00ojD@00H0ojD@0P0000080?nU4080000000<0ojD@0000003o
YA001P3oYA02000000T0oj<@00<000000?nS400000001P3oXa000`000000oj<@0?nS40070?nS4004
0:f][@3lX100o:0@0?bP40@0[Jf]00<000000:f][@3lX1003`3lX1000`2][Jd0mY`?0?JL3`0D0?JL
3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][Jd90=^:3@030:f][@2iM@/0^GD;
00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00G02`h>H00`2][Jd0Uf0;0:f][@080=>73P03
0:f][@3_V100kiP@00L0kiP@0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y140103oY142000000D0oj@A0P0000060?nT4@800000303oYQ42000000<0[Jf]1@3oYQ401P000000
ojHA0000002][Jd0ojHA045Yh@D0ojHA0P0000090?nV4@8000001`3oYQ400`2][Jd0ojHA0?nV4@02
000000T0ojHA00@000000?nV4@00000000001`3oYQ4200000080ojHA00<000000?nV4@2][Jd01@3o
YQ000`000000ojH@0000000:0?nV408000001`3oYQ02000000030?nV402][Jd0ojD@00P0ojD@0P00
00070?nU4080000000<0ojD@0000003oYA001P3oYA02000000T0oj<@0P0000070?nS40030000003o
Xa00oj<@00L0oj<@00<0[Jf]0000003lX1001@3lX1000`000000o:0@0:f][@060:f][@T0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080fhX=0P2]
[Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd0AP2`h>H10?ooo`00F`2`h>H0
102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd40>nH40030:f][@3l
X100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140103oY1400`000000oj@A0?nT4@040?nT4@8000001P3o
Y142000000L0ojHA1@2][Jd2000000P0ojHA00@000000?nV4@000000[Jf]1`3oYQ42000000T0ojHA
0P0000070?nV4@030:f][@3oYQ40ojHA008000002@3oYQ4010000000ojHA0000000000070?nV4@80
00000`3oYQ400`000000[Jf]0?nV40040?nV40030000003oYQ00000000/0ojH@0P0000060?nV4004
0000003oYQ00ojH@0:f][@T0ojD@0P0000060?nU40050000003oYA0000000?nU40000000203oYA02
000000P0oj<@0P0000070?nS40030000003oXa00oj<@00L0oj<@00<0[Jf]0000003lX1001@3lX100
0`000000o:0@0?bP40060?bP40H0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>0100k9H>00<0[Jf]0=^:3@3KRPd0103KRPd00`2][Jd0fhX=0=^:3@040=^:3@030:f][@2iM@/0
^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2]
[Jd80=>73P030:f][@3_V100kiP@00@0kiP@00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00@0oj@A00<000000?nT4@3oY1400`3oY142000000L0oj@A0P00
00000`3oYQ40[Jf]0:f][@040:f][@H0ojHA0P0000080?nV4@80000000<0[Jf]0?nV4@3oYQ401@3o
YQ42000000P0ojHA0P0000080?nV4@030:f][@3oYQ40ojHA008000002@3oYQ401@000000ojHA0000
003oYQ40000000H0ojHA00<000000?nV4@3oYQ400`3oYQ42000000<0ojH@0`00000=0?nV40800000
103oYQ001@000000ojH@0?nV403oYQ00[Jf]00X0ojD@0P0000050?nU40050000003oYA0000000?nU
40000000203oYA02000000P0oj<@0P0000070?nS40030000003oXa00oj<@00L0oj<@0P0000060?bP
408000003@3lX1050:f][AD0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@050=^:
3@80[Jf]103KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0A02`h>H1
0?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1000P3_V102
0:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@040?nT4@030000003oY140
oj@A00<0oj@A0P0000060?nT4@040:f][@00000000000:f][@`0ojHA0P0000080?nV4@030000003o
YQ40[Jf]00L0ojHA0`0000070?nV4@800000203oYQ400`2][Jd0ojHA0?nV4@02000000T0ojHA00<0
00000?nV4@0000000P3oYQ42000000<0ojHA00<000000?nV4@3oYQ40103oYQ400`2][Jd0ojH@0000
000300000140ojH@100000040?nV40030:f][@3oYA00ojD@00T0ojD@0P0000030?nU40060000003o
YA00ojD@0000003oYA000000203oYA000`2][Jd00000000000070?nS40030000003oXa00oj<@00H0
oj<@00<000000?nS403oXa001`3oXa02000000H0o:0@0P00000@0?bP40030:f][@3fW0l0[Jf]00<0
[Jf]4@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd20=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@T0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@040?nT4@030000003oY140oj@A00<0oj@A0P0000020?nT
4@@0[Jf]00@0oj@A0000000000000000303oYQ42000000P0ojHA00<000000?nV4@2][Jd01`3oYQ43
000000L0ojHA0P0000080?nV4@030:f][@3oYQ40ojHA008000001P3oYQ46000000@0ojHA0`000007
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA002`3oYA03000000<0ojD@00<00000
0?nU40000000203oYA00102][Jd0oj<@0000000000050?nS408000002@3oXa000`000000oj<@0?nS
40060?nS408000001P3lX10200000100o:0@00<0[Jf]0?JL3`3fW0l00`3fW0l40:f][@d0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@090=^:3@<0[Jf]2@2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/0
0`2][Jd0dhL>0=>73P060=>73P<0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00D0oj@A00<000000?nT4@3oY1400P3oY14200000080[Jf]1@3oY143000000D0ojHA00<00000
0?nV4@3oYQ40103oYQ42000000L0ojHA00@000000?nV4@3oYQ40[Jf]1`3oYQ42000000030?nV4@00
0000000000@0ojHA0P0000090?nV4@D000006P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@0140ojD@00<000000?nU40000000203oYA00102][Jd0oj<@0?nS403oXa05000000/0oj<@
00<000000?nS403oXa001@3oXa03000000H0o:0@0P00000@0?bP40030:f][@3fW0l0mY`?00L0mY`?
102][Jd90?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`
h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A00D0oj@A00<000000?nT4@2][Jd00P2][Jd2000000L0oj@A
0`0000040?nV4@8000001P3oYQ42000000L0ojHA00@000000?nV4@3oYQ40[Jf]1`3oYQ42000000<0
ojHA1000000;0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400A0?nU40030000003oYA00000000P0ojD@00<0[Jf]0?nS403oXa004P3oXa000`000000
oj<@0?nS40040?nS40<000001P3lX10200000100o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]202iM@/00`2][Jd0
R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@080=>73P80[Jf]303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00<0
oj@A0P2][Jd00`000000[Jf]0?nT4@020?nT4@8000001`3oY143000000@0ojHA00<000000?nV4@00
00001P3oYQ42000000D0ojHA00D000000?nV4@3oYQ40ojHA0:f][@070?nV4@8000004P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA004@3oYA000`00
0000ojD@000000080?nU40030:f][@3oXa00oj<@01<0oj<@1P0000000`3oXa00[Jf]000000060?bP
40800000403lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh04@3/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@030=>73P2][Jd0kiP@00/0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0:f][@03
0:f][@80oj@A00@000000?nT4@3oY140oj@A0P0000080?nT4@80000000<0ojHA0000003oYQ400P3o
YQ400`000000ojHA000000060?nV4@8000001@3oYQ4010000000ojHA0?nV4@2][Jd80?nV4@800000
4P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
4@3oYA000`000000ojD@000000080?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0000003lX100
1@3lX10200000100o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l30:f][A40k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0
/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h01@2][Jd0
dhL>0=>73P3CQ`h0[Jf]00`0kiP@00<0[Jf]0?bP403lX1003`3lX1030:f][@H0oj@A00@000000?nT
4@3oY140oj@A0P0000080?nT4@80000000<0ojHA0000003oYQ400`3oYQ42000000P0ojHA1@000003
0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000B0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400A0?nU40030000003oYA00000000P0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP40800000403lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`h>H1
0?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h0
0`2][Jd0kiP@0>nH400:0>nH40030:f][@3lX100o:0@00`0o:0@0`2][Jd00`3lX100[Jf]0?nT4@06
0?nT4@040000003oY140oj@A0?nT4@800000203oY14200000080ojHA00D000000?nV4@3oYQ40ojHA
0000000A0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000B0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400A0?nU40030000003oYA00000000P0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP40800000403lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je20;3PiP40
oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h00`2][Jd0dhL>0=>73P030=>73P03
0:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@@0o:0@00<0[Jf]0?nT4@3o
Y1401@3oY14010000000oj@A0?nT4@3oY142000000P0oj@A0P0000020?nV4@030000003oYQ40ojHA
008000004@3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000004P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA004@3oYA000`000000ojD@000000080?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001@3lX10200000100o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80[Jf]@P2`h>H10?oo
o`00F@2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1P3CQ`h00`2][Jd0kiP@0>nH400:
0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd60?bP40030:f][@3oY140oj@A00D0oj@A00@00000
0?nT4@3oY140oj@A0P0000080?nT4@8000000`3oYQ42000001<0ojHA00<0[Jf]0?nV4@3oYQ401P3o
YQ4200000180ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][@`0ojD@00<000000?nU40000000203o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000A0?bP40030:f][@3f
W0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]
09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100103l
X1030:f][@T0o:0@00<0[Jf]0?nT4@3oY1401@3oY14010000000oj@A0?nT4@3oY142000000H0oj@A
1000000H0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000B0?nV4@030:f][@3oYQ40ojHA00D0ojHA
402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0<0:f][@040000
002][Jd000000:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP4080
00004@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0000008QF1`0308QF1`03
0:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P03
0:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX1000P3lX1020:f][@`0o:0@00<0[Jf]0?nT4@3o
Y1401@3oY1401P000000oj@A0?nT4@000000oj@A000000P0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@060?nV4@8000003P3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400A0?nU40040000003oYA0000000?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP
40050?bP40<00000403lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2]
[Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd01@000000R5H708QF
1`28EPL0[Jf]0480/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd>0?bP40030:f][@3oY140oj@A00H0oj@A00@0
00000?nT4@00000000002@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00H0ojHA
0P0000040?nV4@X0[Jf]103oYQ40102][Jd0ojHA0?nV4@00000K0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA004@3oYA000`000000ojD@000000080?nU40030:f][@3oXa00oj<@0080
oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@00D0o:0@0`00000@0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@80
00000P28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080[Jf]
203CQ`h00`2][Jd0kiP@0>nH400;0>nH4080[Jf]4@3lX1000`2][Jd0oj@A0?nT4@060?nT4@040000
003oY1400000000000T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@@0
[Jf]0P0000040:f][@h0ojHA00@0[Jf]0?nV4@00000000006`3oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@0140ojD@00<000000?nU40000000203oYA000`2][Jd0oj<@0?nS400<0?nS
40X0[Jf]103oXa000`2][Jd0o:0@0?bP40050?bP40<00000403lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`06
0;Ue2`070:f][@28EPL0000008QF1`000000R5H70:f][@120;3PiP40oooo001I0;3PiP050:f][@2G
H0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40090>nH40<0[Jf]4P3lX1000`2][Jd0oj@A
0?nT4@060?nT4@040000003oY1400000000000T0oj@A00<0[Jf]0?nV4@3oYQ40503oYQ480:f][@@0
ojHA0P00000B0?nV4@050:f][@000000ojHA0?nV4@0000006P3oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@0140ojD@00<000000?nU40000000203oYA000`2][Jd0oj<@0?nS400F0?nS
40P0[Jf]103lX10300000100o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P040:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0
00000:f][@28EPL000000:f][@120;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0
203CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00L0oj@A00@000000?nT4@00000000002@3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@H0
[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000004P3oYQ40102][Jd0ojHA00000000000K0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003P3oYA04000000030?nU40000000ojD@
00L0ojD@00<0[Jf]0?nS403oXa006P3oXa00102][Jd0o:0@0?bP403lX1040:f][@<00000403lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2
0:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01`2][Jd0R5H700000028EPL0[Jf]0000002][Jd0
@P2`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH
40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A00@0
00000?nT4@00000000002@3oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA
0?nV4@060?nV4@8000004P3oYQ40102][Jd0ojHA0?nV4@00000K0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA004@3oYA03000000P0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP40050?bP40<000001P2][Jd:0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`07
0:f][@11JN40000008QF1`2][Jd000000:f][@120;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2]
[Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd60>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY142000000030?nT4@000000oj@A00P0oj@A00@0[Jf]0?nV
4@3oYQ40ojHA1P2][Jd@0?nV4@030:f][@3oYQ40ojHA00H0ojHA0P00000B0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1001@3lX1000`000000o:0@000000060?bP40L0[Jf]0`3lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd2
0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70000000208QF1`030000002][Jd0
/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f][@3_V100
kiP@0>nH4080[Jf]203_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A0`00
00090?nT4@D0[Jf]5P3oYQ400`2][Jd0ojHA0?nV4@060?nV4@8000004P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000>0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`070;Ue2`030:f][@28
EPL000000080R5H700<000000:f][@000000@@2`h>H10?ooo`00F02`h>H00`000000[Jf]09MP2`02
09MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2P3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00L0oj@A0`0000050?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603o
YQ400`2][Jd0ojHA0?nV4@030?nV4@@000004`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@00H0o:0@00<000000?bP403lX1003`3lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/01`2][Jd0000008QF
1`28EPL000000:f][@000000@@2`h>H10?ooo`00E`2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2]
[Jd0203CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@070?nT4@<0
000000<0oj@A0:f][@2][Jd00P2][Jd50?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00H0o:0@00<000000?bP403l
X1003`3lX1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00`0fhX=0P2][Jd80;Ue2`070:f][@000000R5H708QF1`000000[Jf]00000011
0;3PiP40oooo001G0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@070=>73P80[Jf]3@3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A00@000000:f][@000000[Jf]2@3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00T0mY`?1@2][Jd60?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0:f][@2][Jd60;Ue2`070:f]
[@000000000008QF1`000000[Jf]000000110;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]00<0
Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00l0
o:0@00<0[Jf]0?nT4@3oY1400`3oY1440:f][@030?nT4@000000000000X0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`060:f][@28EPL00000
08QF1`000000[Jf]0P0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]00<0Uf0;00<0[Jf]
0=>73P3CQ`h00`3CQ`h0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@2][Jd00`2][Jd50?nT4@8000002P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?0180mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2i
M@/00`2][Jd0^GD;0;Ue2`020;Ue2`070:f][@28EPL0000008QF1`000000[Jf]000000110;3PiP40
oooo001G0;3PiP030000002][Jd0[Jf]00<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P2][Jd30=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003P3lX1030:f][@T0oj@A00<000000?nT4@3o
Y1402@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2]
[Jd00P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/02P2][Jd0
^GD;0;Ue2`2iM@/0[Jf]08QF1`000000R5H70000002][Jd200000400/>3V0@3oool005L0/>3V00<0
00000:f][@2][Jd00`2GH0/0102][Jd0dhL>0=>73P2][Jd50=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX100303lX1020:f][@030?bP402][Jd0oj@A00T0oj@A00<000000?nT4@3oY140
2@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
0P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`80[Jf]
00L0^GD;0:f][@28EPL0000008QF1`000000[Jf]00800000@02`h>H10?ooo`00E`2`h>H00`000000
[Jf]0:f][@0309MP2`030:f][@3CQ`h0[Jf]00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@080?nT4@030000003oY140oj@A00T0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0
k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@05
08QF1`00000000000000002][Jd00P0000100;3PiP40oooo001G0;3PiP030000002][Jd0[Jf]00<0
Uf0;00<0@FWQ0:f][@3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0
o:0@0P2][Jd60?bP40030:f][@3oY140oj@A00P0oj@A00<000000?nT4@3oY1402@3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL000000000
0028EPL0[Jf]0P0000100;3PiP40oooo001F0;3PiP80000000<0[Jf]09MP2`2GH0/00P2GH0/00`2]
[Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f]
[@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f]
[@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0P0000001028
EPL0[Jf]0000000000100;3PiP40oooo001F0;3PiP80000000@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd7
0=>73P030:f][@3_V100kiP@00`0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0
k9H>0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]0P0000001028EPL0[Jf]0000
000000100;3PiP40oooo001F0;3PiP80000000@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd70=>73P030:f]
[@3_V100kiP@00`0kiP@00@0[Jf]0?bP402][Jd0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS4003
0:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0
[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`060:f][@28EPL0000000000011JN40[Jf]0P000010
0;3PiP40oooo001F0;3PiP80000000H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd70=>73P030:f][@3_
V100kiP@00/0kiP@0`2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603o
YQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]
2`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`060:f][@28EPL0000000000028EPL0[Jf]0P0000100;3P
iP40oooo001F0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P050=>73P03
0:f][@3_V100kiP@00T0kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:
3@80[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`060:f][@28EPL0000000000028EPL0[Jf]0P00
00100;3PiP40oooo001F0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P05
0=>73P030:f][@3_V100kiP@00L0kiP@0P2][Jd30>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]
0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]U@2`h>H60:f][A80o:0@00<0[Jf]
0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P2][Jd7
0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`0000000P0000000`2][Jd0000000000010
0;3PiP40oooo001F0;3PiP8000000P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH
403_V1001@3_V1020:f][@D0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA00h0ojHA1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@D0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/01P2][Jd0R5H700000028EPL000000:f][@800000@02`h>H10?ooo`00EP2`h>H2
00000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd7
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@08
0?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00H0[Jf]
08QF1`000000R5H70000002][Jd200000400/>3V0@3oool005H0/>3V0P0000001P2][Jd0Uf0;09MP
2`2GH0/0@FWQ0:f][@L0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd90>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd2
0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@09
0=^:3@80[Jf]00<0fhX=0:f][@2iM@/0202iM@/01@2][Jd0000008QF1`000000[Jf]00800000@02`
h>H10?ooo`00EP2`h>H2000000050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h0102][Jd0kiP@0:f]
[@2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V
1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@T0^GD;
00D0[Jf]00000028EPL000000:f][@0200000400/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0303KRPd30:f][@L0^GD;00D0[Jf]00000028EPL000000:f][@0200000400/>3V0@3oool005H0
/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00L0dhL>0P2][Jd>0>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd0102][Jd0^GD;0;Ue2`2][Jd60;Ue2`050:f][@000000
R5H70000002][Jd00P0000100;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@050=>73P80[Jf]00<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3o
Y140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`050:f][@000000R5H70000002]
[Jd00`00000o0;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P05
0:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A
00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;0080^GD;0P2][Jd30;Ue2`050:f][@00000000000000002][Jd00`00000o
0;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3CQ`h0
dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H4
0:f][A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`080:f][@2iM@/0
^GD;0:f][@28EPL0000008QF1`2][Jd3000003l0/>3V0@3oool005H0/>3V0P0000001P2][Jd0Uf0;
09MP2`2GH0/0[Jf]0=>73P80[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
00D0^GD;0`2][Jd00`28EPL0000008QF1`04000003l0/>3V0@3oool005H0/>3V0P000000102][Jd0
Uf0;09MP2`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP
4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0
fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H700000028EPL000000:f][@800000
?`2`h>H10?ooo`00EP2`h>H2000000@0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f][@L0`kfk102]
[Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@0400000028
EPL000000:f][@800000?`2`h>H10?ooo`00EP2`h>H2000000<0Uf0;0P2][Jd80=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@030;6[W@2][Jd0^K:V00X0^K:V0`2]
[Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`070;Ue2`80[Jf]00@0000008QF1`000000[Jf]0P00000o0;3PiP40oooo001F0;3PiP8000000`2G
H0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102a
Zid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0
[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0
[Jf]08QF1`000000R5H70000002][Jd2000003l0/>3V0@3oool005H0/>3V0P00000209MP2`030:f]
[@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M
00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f]
[@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/01P2][Jd0R5H700000028EPL000000:f][@800000?`2`h>H10?ooo`00EP2`h>H010000000
[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f]
[@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f]
[@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL000000:f][@@00000?`2`h>H10?ooo`00EP2`h>H01000
0000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100203_V102
0:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]d02`h>H4
0:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080[Jf]2@3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@000000000008QF1`@00000?`2`h>H10?ooo`00EP2`h>H0
0`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V104
0:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H4
0:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0000008QF1`@00000?`2`h>H10?ooo`00EP2`h>H0
0`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V103
0:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0_[Vh0P2][Jd50=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00`0000000`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F
0;3PiP030000002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_
V1020:f][@050:BNS`11JN40@FWQ0:BNS`2][Jd0102aZid20:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]]02`h>H60:f][@L0al6l
00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh
0P2][Jd60;ji^0040:f][@2d/;40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0
R5H708QF1`28EPL2000000030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<000000:f][@2G
H0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P040:f][@3_V100[Jf]0:f][@<0Y9j?0`11JN400`2]
[Jd0/J^M0;6[W@040;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00@0[Jf]
0;B`/@2d/;40];2a0P2][Jd00`3KRPd0[Jf]0;Ue2`090;Ue2`030:f][@28EPL0R5H70080000000<0
[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0
dhL>00L0dhL>0P2][Jd00`2TWXl0@FWQ0:BNS`020:BNS`80@FWQ00@0Y9j?0:f][@11JN40@FWQ1P2a
Zid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]202n^KP00`11JN40_[Vh0:f][@020;B`/@80@FWQ
00<0];2a0:f][@2][Jd02P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V
00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P050:f][@2TWXl0Y9j?0:BNS`11
JN400`2TWXl2045Yh@030:BNS`2][Jd0/J^M00<0@FWQ1P2aZid20:f][@030;6[W@2][Jd0^K:V00l0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0
`kfk0`2][Jd80;ji^080@FWQ0P2n^KP00`2][Jd0];2a0;B`/@02045Yh@80];2a00<0@FWQ0:f][@2]
[Jd0202iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f][@2G
H0/00P2GH0/00`2][Jd0dhL>0=>73P040=>73P80[Jf]00D0@FWQ0:BNS`2TWXl0Y9j?045Yh@030:BN
S`80@FWQ00@0Y9j?0:f][@2aZid0@FWQ2P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2]
[Jd00`33_K/0[Jf]0;ji^0060;ji^0<0@FWQ0`2n^KP00`2][Jd0];2a0;B`/@02045Yh@80];2a0P11
JN400`2d/;40[Jf]0;Ue2`060;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`
h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00<0dhL>0`2][Jd01@11JN40Y9j?0:BN
S`2TWXl0@FWQ00<0Y9j?0P11JN40102][Jd0/J^M0;6[W@11JN4;0;6[W@030:f][@2i/ZH0[Jf]00<0
[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^0070;ji^003
045Yh@2n^KP0_[Vh0080_[Vh00@0[Jf]0;B`/@11JN40@FWQ0P2d/;42045Yh@80];2a0P2][Jd50;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2]
[Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00D0[Jf]08Z5M@2:QGD0[Jf]045Yh@030:BNS`04045Yh@2T
WXl0Y9j?0:BNS`80@FWQ00@0[Jf]0;6[W@2aZid0@FWQ102aZid4045Yh@<0/J^M00<0[Jf]0;VbYP2i
/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00@0[Jf]0;ji^011
JN40@FWQ1P2n^KP00`11JN40_[Vh0;ji^0020;ji^0040:f][@2d/;40@FWQ045Yh@<0];2a00@0@FWQ
0;B`/@2][Jd0@FWQ0`2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0
?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00L0[Jf]045Yh@2:QGD0
RXEe0:f][@11JN40[Jf]0080Y9j?00L0@FWQ0:BNS`2TWXl0Y9j?045Yh@2TWXl0[Jf]0080/J^M00@0
@FWQ0;6[W@2aZid0/J^M0P11JN420;6[W@05045Yh@2aZid0/J^M0;6[W@2][Jd0202i/ZH30:f][@D0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080
[Jf]2`33_K/2045Yh@80_[Vh00<0@FWQ0;ji^02n^KP00`2n^KP00`11JN40_[Vh0;ji^0020;ji^004
0:f][@2d/;40];2a045Yh@<0];2a00D0@FWQ0:f][@2d/;40@FWQ0:f][@02045Yh@040:f][@2iM@/0
^GD;0:f][@<0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP060:f][@2GH0/0
Uf0;09MP2`2][Jd0dhL>0P2][Jd3045Yh@0708Z5M@2][Jd0@FWQ0:BNS`2][Jd0Y9j?045Yh@030:BN
S`03045Yh@2TWXl0[Jf]0080/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN430;6[W@04045Yh@2aZid0
/J^M0:f][@/0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0
[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2]
[Jd<0<>m^`<0@FWQ0`2n^KP2045Yh@@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP0102][Jd0];2a0;B`
/@2d/;44045Yh@80];2a00<0@FWQ0:f][@11JN400P11JN430:f][@@0R5H700<0[Jf]0000002`h>H0
?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]0`2:QGD2045Yh@0308Z5M@11
JN40Y9j?0080Y9j?00<0[Jf]045Yh@2TWXl00P2TWXl00`11JN40Y9j?0:f][@020;6[W@04045Yh@2a
Zid0/J^M0;6[W@80@FWQ0`2aZid01`11JN40/J^M0;6[W@2][Jd0^K:V045Yh@2i/ZH00P11JN4:0;Vb
YP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0
_0@0[Jf]00<0a/2l0:f][@33_K/03@33_K/2045Yh@@0_[Vh0P11JN430;ji^003045Yh@2n^KP0_[Vh
0080_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd01P2d/;40@FWQ0;B`/@2d/;40@FWQ0:f][@80@FWQ
0P2OVj000`11JN40[Jf]08QF1`0308QF1`030:f][@000000/>3V03h0/>3V0@3oool005H0/>3V00<0
[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe08Z5M@0408Z5M@80@FWQ0`2TWXl2045Yh@80[Jf]00@0
Y9j?045Yh@2TWXl0[Jf]0P2aZid01@11JN40/J^M0;6[W@2aZid0@FWQ00D0/J^M00@0@FWQ0;6[W@2]
[Jd0^K:V0P11JN420;VbYP80@FWQ2@2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0
_036`;`01`36`;`40:f][@D0a/2l00<0[Jf]0<>m^`33_K/03033_K/2045Yh@@0_[Vh0P11JN430;ji
^003045Yh@2n^KP0_[Vh0080_[Vh00@0[Jf]0;B`/@2d/;40[Jf]0`2d/;400`11JN40];2a0;B`/@02
045Yh@D0Wi^P00<0@FWQ0:f][@28EPL00P28EPL00`2][Jd000000;3PiP0n0;3PiP40oooo001F0;3P
iP040:f][@2GH0/0Uf0;09MP2`80[Jf]1P2:QGD00`11JN40[Jf]0:BNS`020:BNS`80@FWQ0P2TWXl0
1@2][Jd0@FWQ0:BNS`2][Jd0/J^M0080@FWQ0`2aZid00`11JN40/J^M0;6[W@030;6[W@04045Yh@2a
Zid0[Jf]0;VbYP80@FWQ0`2i/ZH00`11JN40^K:V0;VbYP070;VbYP030:f][@2n]j`0_[N/00<0_[N/
102][Jd90;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j
0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00A0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk00`0`kfk
0P11JN400`2][Jd0_[Vh0;ji^0020;ji^005045Yh@2n^KP0_[Vh0;ji^011JN40102n^KP30:f][@@0
];2a00D0@FWQ0;B`/@2d/;40@FWQ0:f][@0509nKX003045Yh@2][Jd0R5H70080R5H700<0[Jf]0000
002`h>H0?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@L0RXEe00@0[Jf]0:BN
S`2TWXl0Y9j?0P11JN430:BNS`04045Yh@2][Jd0[Jf]0;6[W@80@FWQ0`2aZid00`11JN40/J^M0;6[
W@050;6[W@030:f][@2i/ZH0@FWQ00D0^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH01@11JN40^K:V0;Vb
YP2i/ZH0[Jf]00T0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<0
5033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk
0<>m^`0<0<>m^`80@FWQ00<0[Jf]0;ji^02n^KP00P2n^KP01011JN40_[Vh0;ji^02n^KP2045Yh@80
_[Vh0P2][Jd20;B`/@04045Yh@2d/;40];2a045Yh@80];2a00<0@FWQ0;B`/@2][Jd01@2OVj02045Y
h@050:f][@28EPL0R5H70:f][@000000?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`030:f]
[@L0RXEe00@0[Jf]0:BNS`2TWXl0Y9j?0P11JN430:BNS`04045Yh@2TWXl0[Jf]0:f][@80@FWQ0P2a
Zid2045Yh@L0/J^M00<0[Jf]0;VbYP11JN401@2i/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@<0^K:V
00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_00?0<O1_0@0[Jf]4@36`;`00`2][Jd0`kfk0<>m^`0<0<>m^`80@FWQ
00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@80_[Vh0P11JN420:f][@050;ji^02][Jd0];2a0;B`/@11
JN400P2d/;400`11JN40];2a0;B`/@020;B`/@030:f][@2OVj00Wi^P00@0Wi^P00H0@FWQ0:f][@2]
[Jd0R5H70:f][@00000o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]1P2:QGD0
0`2][Jd0Y9j?0:BNS`020:BNS`80@FWQ0`2TWXl01011JN40Y9j?0:f][@2aZid2045Yh@80/J^M0P11
JN470;6[W@030:f][@2i/ZH0^K:V00D0^K:V00L0@FWQ0;VbYP2i/ZH0^K:V045Yh@2i/ZH0@FWQ0080
^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0
al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0
`kfk0P11JN400`2][Jd0_[Vh0;ji^0020;ji^080@FWQ0P2n^KP2045Yh@80_[Vh00D0@FWQ0:f][@2d
/;40];2a045Yh@020;B`/@03045Yh@2d/;40];2a0080];2a00<0[Jf]09nKX02OVj001@2OVj001@2]
[Jd0L6ii0:f][@2][Jd0000003l0/>3V0@3oool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0RXEe
00@0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl01011JN40Y9j?045Yh@2TWXl2045Yh@030:BNS`2][Jd0
/J^M0080@FWQ0P2][Jd2045Yh@L0/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH00`11JN40^K:V0;VbYP02
0;VbYP05045Yh@2i/ZH0^K:V0;VbYP2][Jd04P2n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0
[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050<O1_0D0[Jf]1`37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0P11JN400`2][Jd0_[Vh0;ji^0020;ji^080@FWQ0P2]
[Jd2045Yh@80_[Vh0P11JN430;B`/@80@FWQ1@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00@0
L6ii0:f][@2][Jd00000?`2`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f][@2T
WXl0Y9j?0080Y9j?00<0@FWQ0:BNS`2TWXl00`11JN400`2TWXl0[Jf]0;6[W@02045Yh@80/J^M0P11
JN400`2][Jd0/J^M0;6[W@040;6[W@030:f][@2i/ZH0^K:V00D0^K:V00<0@FWQ0;VbYP2i/ZH01P2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/03033_K/2045Yh@050:f][@2n^KP0_[Vh0;ji^02][Jd00P11JN420;ji^080@FWQ
0P2n^KP2045Yh@X0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]
?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0[Jf]00@0RXEe00<0
[Jf]0:BNS`2TWXl00P2TWXl00`11JN40Y9j?0:BNS`040:BNS`040:f][@2aZid0@FWQ045Yh@<0/J^M
00<0@FWQ0;6[W@2][Jd00P2][Jd30;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`11JN470;VbYP030:f]
[@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`80@FWQ
00D0[Jf]0;ji^02][Jd0[Jf]0;ji^002045Yh@80_[Vh0P11JN420;ji^003045Yh@2][Jd0];2a00T0
];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe0:f][@<0RXEe00<0[Jf]0:BN
S`2TWXl00P2TWXl00`11JN40Y9j?0:BNS`040:BNS`040:f][@2aZid0@FWQ045Yh@<0/J^M00<0@FWQ
0;6[W@2aZid00P2aZid01011JN40[Jf]0;6[W@2][Jd30;VbYPD0@FWQ1`2i/ZH00`2][Jd0_[N/0;jg
[00A0;jg[0030:f][@31^[00`KZ`00l0`KZ`202][Jd@0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1
_00@0<O1_003045Yh@2][Jd0a/2l0140a/2l00<0[Jf]0<>m^`33_K/03033_K/2045Yh@80[Jf]0`2n
^KP2045Yh@80_[Vh1@11JN400`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2O
Vj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0
1@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`11JN40Y9j?0:BN
S`040:BNS`040:f][@11JN40@FWQ045Yh@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@<0[Jf]
1011JN4:0;VbYP030:f][@2n]j`0_[N/0140_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc
0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0=0<O1^PH0@FWQ0P37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_0070<O1_080
@FWQ1P37`K`2045Yh@030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02P33_K/20:f][@80
@FWQ00<0[Jf]0;ji^02n^KP00P2n^KP2045Yh@80_[Vh0P11JN430;ji^0030:f][@2d/;40];2a00P0
];2a00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00@0Y9j?
00<0@FWQ0:BNS`2TWXl0102TWXl0102][Jd0/J^M045Yh@11JN440;6[W@04045Yh@2aZid0/J^M0;6[
W@80@FWQ00<0/J^M0:f][@2i/ZH00P11JN400`2][Jd0^K:V0;VbYP060;VbYP04045Yh@2i/ZH0^K:V
0:f][A<0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0>0<>m/`/0[Jf]4@35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX03`37`KX2
045Yh@@0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`01@37`K`2
045Yh@80al6l00<0@FWQ0<O1_037`K`01037`K`00`11JN40[Jf]0<K0_00A0<K0_0030:f][@33_K/0
`kfk00L0`kfk0`2][Jd20<>m^`03045Yh@33_K/0[Jf]00@0_[Vh0P11JN40102n^KP0@FWQ045Yh@11
JN430;ji^0030:f][@2d/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`
h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd4
0:BNS`03045Yh@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid01@2aZid01@11JN40/J^M0;6[W@2a
Zid0@FWQ0080/J^M00<0[Jf]0;VbYP11JN400P2i/ZH30:f][@D0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]
4`2n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0@0@FWQ0P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ1037`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]
1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0080al6l00<0@FWQ0<O1_011JN40
1@37`K`00`11JN40al6l0<O1_0040<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
1@33_K/20:f][@H0`kfk00<0@FWQ0:f][@2n^KP00`2n^KP2045Yh@L0_[Vh00<0[Jf]0;B`/@2d/;40
202d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00
EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00@0[Jf]0:BNS`2TWXl0
Y9j?0P11JN460:BNS`030:f][@2aZid0/J^M00H0/J^M00@0@FWQ0;6[W@2aZid0@FWQ0P2aZid00`2]
[Jd0^K:V045Yh@050;VbYP@0[Jf]00D0^K:V045Yh@2i/ZH0^K:V0:f][@0B0;jg[0030:f][@31^[00
`KZ`00h0`KZ`1`11JN4C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX02P37`KX50:f][@80@FWQ2P2][JdA0<S1^`030:f][@38`K/0
b<6k00h0b<6k0P11JN430<S1^`030:f][@37`K`0al6l0080al6l0P11JN460<O1_003045Yh@37`K`0
al6l00@0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`<0[Jf]2033_K/0
0`11JN40[Jf]0;ji^0030;ji^080@FWQ1`2n^KP00`2][Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj00
1@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f]
[@0708Z5M@<0[Jf]0P2TWXl00`11JN40Y9j?0:BNS`040:BNS`030:f][@2aZid0/J^M00L0/J^M0P11
JN430;6[W@030:f][@2i/ZH0@FWQ00D0^K:V00T0@FWQ0;VbYP2i/ZH0^K:V0:f][@11JN40[Jf]0;Vb
YP2][Jd04P2n]j`00`2][Jd0`KZ`0<6j/00>0<6j/080@FWQ0P31^[000`2][Jd0`kfc045Yh@02045Y
h@D0`kfc0`11JN490<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f]
[@D0al6j0P11JN440<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/01038`K/3045Y
h@D0b<6k0P11JN420<S1^`80@FWQ00<0b<6k0:f][@37`K`00`37`K`2045Yh@H0al6l00<0@FWQ0<O1
_037`K`01037`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`11
JN40[Jf]0;ji^0030;ji^080@FWQ1`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a
0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0
Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid0302a
Zid00`2][Jd0^K:V045Yh@040;VbYP80@FWQ102i/ZH00`11JN40^K:V0:f][@020:f][A40_[N/00<0
[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<00P11JN470<>m/`@0@FWQ1P33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<000000:f][@37`KP05@37
`KP00`2][Jd0al6j0<O1^P0?0<O1^P80@FWQ1037`KX00`2][Jd0b<6k0<S1^`0C0<S1^`<0@FWQ0P38
`K/4045Yh@H0b<6k0P11JN450<S1^`03045Yh@2][Jd0al6l00<0al6l00<0@FWQ0<O1_037`K`01@37
`K`00`11JN40al6l0<O1_0040<O1_0030:f][@36`;`0a/2l00h0a/2l102][Jd>0<>m^`03045Yh@2]
[Jd0_[Vh00<0_[Vh0P11JN470;ji^0030:f][@2d/;40];2a00<0];2a0P2][Jd30;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1S
H5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`030:f]
[@2aZid0@FWQ00`0/J^M00<0[Jf]0;VbYP11JN40102i/ZH2045Yh@@0^K:V00D0@FWQ0;VbYP2i/ZH0
[Jf]0;jg[0040:f][@d0_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00@0[Jf]0<>m/`33
_K<0`kfc0P11JN460<>m/`80@FWQ2033_K<00`2][Jd0aKje0<Fn]@030<Fn]@80@FWQ3`35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX03`37`KX2045Y
h@@0al6j00<0[Jf]0<S1^`38`K/02P38`K/3045Yh@80b<6k1011JN400`38`K/0[Jf]0<S1^`040<S1
^`80@FWQ1@38`K/2045Yh@L0b<6k00<0@FWQ0<O1_037`K`00P37`K`00`11JN40al6l0<O1_0040<O1
_080@FWQ1P37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`03045Yh@2][Jd0_[Vh00<0_[Vh0P11JN470;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;40
0`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]
06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0/J^M045Y
h@0<0;6[W@030:f][@2i/ZH0^K:V0080@FWQ0P2i/ZH2045Yh@@0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]
1@2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00@0[Jf]0<>m/`33_K<0
`kfc0P11JN460<>m/`80@FWQ2033_K<0102][Jd0aKje0<Fn]@35_[D3045Yh@030<Fn]@11JN40@FWQ
00@0aKje0P11JN470<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0?0<O1^P80@FWQ1037`KX00`11JN40b<6k0<S1^`060<S1^`D0@FWQ1`38`K/00`11
JN40b<6k0:f][@050<S1^`80@FWQ1@38`K/2045Yh@L0b<6k00<0[Jf]0<O1_037`K`02037`K`2045Y
h@H0al6l00<0@FWQ0:f][@36`;`01P36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`11
JN40[Jf]0;ji^0030;ji^003045Yh@2n^KP0_[Vh00H0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;40
0`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl0102][Jd0/J^M045Yh@11
JN4:0;6[W@030:f][@2i/ZH0^K:V00<0^K:V0P11JN400`2i/ZH0@FWQ0;VbYP020;VbYP80@FWQ0P2i
/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00>0<6j/080@FWQ0P31
^[00102][Jd0`kfc0<>m/`33_K<2045Yh@H0`kfc0P11JN480<>m/`030:f][@35_[D0aKje0080@FWQ
1@35_[D00`11JN40aKje0<Fn]@02045Yh@P0aKje00<0@FWQ0<Jo]`36_kL00`36_kL00`11JN40a[ng
0<Jo]`0<0<Jo]`80@FWQ00<0a[ng0:f][@37`KP05@37`KP00`2][Jd0al6j0<O1^P020<O1^P@0@FWQ
1037`KX2045Yh@<0al6j0P11JN420<O1^P80@FWQ00<0[Jf]045Yh@11JN402@38`K/2045Yh@L0b<6k
00<0@FWQ0<S1^`2][Jd01@38`K/2045Yh@D0b<6k0P11JN470<S1^`030:f][@37`K`0al6l00L0al6l
0P11JN470<O1_004045Yh@2][Jd0a/2l0<K0_0D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`03
045Yh@2][Jd0_[Vh00<0_[Vh00<0@FWQ0;ji^02n^KP01P2n^KP30:f][@P0];2a00<0[Jf]09nKX02O
Vj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe
00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@030;6[W@11JN40/J^M00X0/J^M00<0[Jf]0;VbYP2i/ZH0
2P2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f][@030;jg[02][Jd0`KZ`00l0`KZ`
0P11JN420<6j/0030:f][@33_K<0`kfc0080`kfc0P11JN450<>m/`80@FWQ2033_K<00`2][Jd0aKje
0<Fn]@02045Yh@H0aKje0`11JN490<Fn]@03045Yh@36_kL0a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL0
2P36_kL2045Yh@80a[ng0P11JN420<O1^003045Yh@37`KP0al6h0080al6h1`11JN480<O1^0050:f]
[@37`KX0al6j0<O1^P11JN401037`KX01011JN40al6j0<O1^P11JN450<O1^P80@FWQ00H0al6j045Y
h@37`KX0al6j0:f][@38`K/2045Yh@P0b<6k0P11JN470<S1^`03045Yh@38`K/0[Jf]00D0b<6k0P11
JN440<S1^`80@FWQ2038`K/00`2][Jd0al6l0<O1_0050<O1_080@FWQ00<0al6l045Yh@37`K`01@37
`K`00`2][Jd0@FWQ0:f][@020:f][A00a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`11JN40[Jf]0;ji
^0020;ji^080@FWQ1`2n^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f]
[@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid0
0`2][Jd0^K:V0;VbYP0:0;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]3@31^[02
045Yh@80`KZ`00<0[Jf]0<>m/`33_K<00P33_K<2045Yh@D0`kfc0P11JN480<>m/`030:f][@35_[D0
aKje0080@FWQ1`35_[D2045Yh@P0aKje0P11JN450<Jo]`03045Yh@36_kL0a[ng00T0a[ng0P11JN44
0<Jo]`040:f][@11JN40al6h045Yh@L0al6h0P11JN4:0<O1^0040:f][@37`KX0al6j045Yh@H0al6j
0`11JN450<O1^P<0@FWQ0`37`KX0102][Jd0b<6k045Yh@11JN480<S1^`80@FWQ1`38`K/00`11JN40
b<6k0:f][@050<S1^`80@FWQ1038`K/2045Yh@P0b<6k00<0[Jf]0<O1_037`K`01037`K`01011JN40
al6l045Yh@11JN420<O1_0D0[Jf]00<0al6l045Yh@2][Jd04P36`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`03045Yh@2][Jd0_[Vh0080_[Vh00<0@FWQ0;ji^02n^KP0102n^KP20:f][@030;ji^02][Jd0];2a
00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@03
0:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd90;6[W@030:f][@2i/ZH0^K:V00X0
^K:V0P11JN420;VbYP030:f][@2n]j`0_[N/0100_[N/00@0[Jf]0<6j/031^[00`KZ`1`2][Jd60<6j
/080@FWQ0P31^[000`2][Jd0`kfc0<>m/`020<>m/`80@FWQ1@33_K<2045Yh@P0`kfc00<0[Jf]0<Fn
]@35_[D00P11JN470<Fn]@80@FWQ2035_[D3045Yh@<0a[ng0`11JN490<Jo]`80@FWQ1@36_kL0102]
[Jd0al6h045Yh@11JN470<O1^080@FWQ2P37`KP0102][Jd0al6j045Yh@11JN470<O1^P80@FWQ1@37
`KX2045Yh@@0al6j00<0[Jf]0<S1^`38`K/00P11JN470<S1^`80@FWQ1`38`K/00`11JN40b<6k0:f]
[@050<S1^`80@FWQ1038`K/2045Yh@P0b<6k00<0[Jf]0<O1_037`K`00`37`K`3045Yh@@0[Jf]1P37
`K`00`11JN40[Jf]0<K0_00A0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0@FWQ0:f][@2n^KP0_[Vh
0P11JN440;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P
0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2T
WXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP80@FWQ0P2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1P2][Jd2045Yh@80`KZ`00<0
[Jf]0<>m/`33_K<00`33_K<2045Yh@@0`kfc0P11JN480<>m/`030:f][@35_[D0aKje0080@FWQ1`35
_[D2045Yh@P0aKje0`11JN430<Jo]`<0@FWQ2@36_kL00`11JN40a[ng0<Jo]`040<Jo]`040:f][@37
`KP0al6h045Yh@L0al6h0P11JN4;0<O1^0030:f][@11JN40@FWQ00L0al6j0P11JN450<O1^P80@FWQ
1037`KX00`2][Jd0b<6k0<S1^`02045Yh@L0b<6k0P11JN470<S1^`03045Yh@38`K/0[Jf]00D0b<6k
0P11JN440<S1^`80@FWQ2038`K/00`2][Jd000000<O1_0030:f][@03045Yh@2][Jd0al6l00@0al6l
00<0@FWQ0<O1_037`K`00`37`K`00`11JN40[Jf]0<K0_00A0<K0_0030:f][@33_K/0`kfk00d0`kfk
00<0@FWQ0:f][@2n^KP00P11JN420;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5
M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0
[Jf]0;VbYP2i/ZH02P2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00>0<6j/080@FWQ1P2][Jd20<>m/`80@FWQ1033_K<2045Yh@P0`kfc00<0[Jf]0<Fn]@35_[D00P11
JN470<Fn]@80@FWQ2035_[D00`11JN40[Jf]045Yh@030<Jo]`<0@FWQ2036_kL2045Yh@H0a[ng00@0
[Jf]0<O1^037`KP0@FWQ1`37`KP2045Yh@/0al6h00<0[Jf]045Yh@11JN401`37`KX2045Yh@D0al6j
0P11JN440<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ1P38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`2]
[Jd01@38`K/2045Yh@@0b<6k0P11JN450<S1^`80[Jf]00@0@FWQ0:f][@2][Jd0[Jf]0P37`K`2045Y
h@H0al6l00<0@FWQ0<O1_037`K`00`37`K`00`11JN40[Jf]0<K0_00B0<K0_0030:f][@33_K/0`kfk
00`0`kfk0`11JN420;ji^080[Jf]202n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P
00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H10?ooo`00G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@03
0:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid01`2aZid30:f][@030;6[W@2][Jd0^K:V00/0
^K:V0P11JN420;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80
`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P2][Jd2045Yh@<0[Jf]00<0`kfc045Yh@11JN402033_K<0102]
[Jd0aKje0<Fn]@35_[D2045Yh@H0aKje0P11JN470<Fn]@80@FWQ00<0[Jf]045Yh@36_kL00P36_kL0
0`11JN40a[ng045Yh@080<Jo]`80@FWQ1P36_kL0102][Jd0al6h0<O1^011JN470<O1^080@FWQ2`37
`KP00`2][Jd0@FWQ045Yh@070<O1^P80@FWQ1@37`KX2045Yh@@0al6j00@0[Jf]0<S1^`38`K/0b<6k
0P11JN460<S1^`80@FWQ1`38`K/00`11JN40b<6k0:f][@050<S1^`80@FWQ1038`K/2045Yh@D0[Jf]
0P38`K/2045Yh@@0al6l00<0@FWQ0<O1_037`K`01@37`K`00`11JN40al6l0<O1_0020<O1_080@FWQ
00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`0:0<>m^`<0@FWQ00@0[Jf]0;ji^02][Jd0
[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`
h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?
00<0[Jf]0;6[W@2aZid02P2aZid30:f][@/0^K:V0P11JN420;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<00`33_K<2045Yh@<0`kfc
00<0[Jf]045Yh@11JN401@2][Jd30<>m/`030:f][@35_[D0aKje0080aKje0`11JN440<Fn]@80@FWQ
1`35_[D2045Yh@030:f][@11JN40a[ng0080a[ng00<0@FWQ0<Jo]`11JN402036_kL2045Yh@H0a[ng
00@0[Jf]0<O1^037`KP0@FWQ1`37`KP2045Yh@/0al6h00<0[Jf]045Yh@11JN401`37`KX2045Yh@D0
al6j0P11JN440<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ1P38`K/2045Yh@L0b<6k00<0@FWQ0<S1
^`2][Jd00`38`K/20:f][@80@FWQ102][Jd00`38`K/0@FWQ045Yh@060<S1^`80@FWQ1037`K`00`11
JN40al6l0<O1_0040<O1_080@FWQ1037`K`2045Yh@030:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m
^`33_K/03033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f]
[DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2a
Zid02P2aZid00`000000[Jf]0;VbYP040:f][@L0^K:V0P11JN420;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<00`33_K<00`11JN40
`kfc0<>m/`030<>m/`80@FWQ1@33_K<90:f][@80aKje0P11JN420<Fn]@80@FWQ1`35_[D2045Yh@04
0:f][@11JN40a[ng0<Jo]`80@FWQ00<0a[ng045Yh@36_kL01P36_kL2045Yh@L0a[ng00@0[Jf]0<O1
^037`KP0@FWQ1`37`KP2045Yh@/0al6h00<0[Jf]0<O1^P11JN401`37`KX2045Yh@D0al6j0P11JN44
0<O1^P040:f][@38`K/0b<6k0<S1^`80@FWQ1P38`K/2045Yh@@0b<6k0`2][Jd00`11JN40[Jf]0:f]
[@030:f][@80b<6k0P11JN450<S1^`80@FWQ1`38`K/00`11JN40al6l0<O1_0030<O1_003045Yh@37
`K`0al6l0080al6l00<0@FWQ0<O1_011JN401037`K`2045Yh@030:f][@36`;`0a/2l0140a/2l00<0
[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]
0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]102i/ZH01@11JN40^K:V0;VbYP2i
/ZH0[Jf]0180_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<00`33
_K<00`11JN40`kfc0<>m/`030<>m/`80@FWQ2033_K<00`2][Jd0aKje0<Fn]@030<Fn]@@0[Jf]1011
JN440:f][@<0aKje00H0@FWQ0<Fn]@2][Jd0a[ng045Yh@36_kL2045Yh@80a[ng00<0@FWQ0<Jo]`36
_kL01036_kL2045Yh@L0a[ng00@0[Jf]0<O1^037`KP0@FWQ1`37`KP2045Yh@/0al6h00<0[Jf]0<O1
^P37`KX01011JN430<O1^P80@FWQ1@37`KX2045Yh@@0al6j00@0[Jf]0<S1^`38`K/0b<6k0P11JN46
0:f][@80@FWQ102][Jd30<S1^`03045Yh@38`K/0[Jf]00D0b<6k0P11JN460<S1^`80@FWQ1@38`K/0
0`11JN40[Jf]0<O1_0050<O1_0@0@FWQ1`37`K`3045Yh@030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@09
0;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP060;VbYP<0[Jf]00<0^K:V045Yh@2i/ZH00P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00h0`KZ`0P11JN420<6j/0030:f][@33_K<0`kfc00<0`kfc00<0@FWQ0<>m
/`33_K<00`33_K<3045Yh@@0`kfc00@0@FWQ0<>m/`33_K<0[Jf]2`35_[D2045Yh@@0aKje0P2][Jd2
045Yh@<0[Jf]00<0@FWQ0:f][@11JN400`2][Jd01011JN40[Jf]0:f][@2][Jd30<Jo]`80@FWQ1`36
_kL7045Yh@@0al6h0P11JN4;0<O1^0030:f][@37`KX0al6j00@0al6j1@11JN450:f][@80@FWQ1`2]
[Jd2045Yh@030:f][@38`K/0b<6k00@0b<6k0P11JN470<S1^`03045Yh@38`K/0[Jf]00D0b<6k0P11
JN470<S1^`80@FWQ1038`K/00`11JN40[Jf]0<O1_00@0<O1_0<0@FWQ00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d
/;40];2a00P0];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`08
0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0
_[N/0140_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80`KZ`00<0[Jf]0<>m/`33_K<00`33_K<0
0`11JN40`kfc0<>m/`030<>m/`<0@FWQ0`33_K<01@11JN40`kfc045Yh@33_K<0[Jf]00<0aKje0P11
JN460<Fn]@03045Yh@35_[D0aKje00D0aKje0P11JN401P35_[D0[Jf]0<Jo]`11JN40a[ng045Yh@<0
a[ng00@0@FWQ0<Jo]`36_kL0a[ng0`2][Jd2045YhA80[Jf]0P11JN4E0:f][@80@FWQ1@37`KX2045Y
h@@0al6j00<0[Jf]0<S1^`38`K/00P11JN470<S1^`80@FWQ1P38`K/2045Yh@030<S1^`2][Jd0b<6k
00@0b<6k0P11JN480<S1^`D0@FWQ00<0b<6k0:f][@37`K`04037`K`3045Yh@030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`
/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[003P31^[02045Yh@80
`KZ`00<0[Jf]0<>m/`33_K<00`33_K<01011JN40`kfc0<>m/`33_K<4045Yh@030<>m/`11JN40`kfc
0080`kfc0P11JN400`33_K<0[Jf]0<Fn]@020<Fn]@80@FWQ1P35_[D00`11JN40aKje0<Fn]@050<Fn
]@80@FWQ00H0aKje0:f][@36_kL0@FWQ0<Jo]`11JN430<Jo]`03045Yh@36_kL0a[ng00@0a[ng0P11
JN460<Jo]`030000002][Jd0al6h00T0al6h0P11JN4;0<O1^0030:f][@37`KX0al6j00L0al6j0P11
JN450<O1^P80@FWQ1037`KX00`2][Jd0b<6k0<S1^`02045Yh@L0b<6k0P11JN460<S1^`80@FWQ00<0
b<6k0:f][@38`K/01038`K/2045Yh@h0b<6k00<0[Jf]0<O1_037`K`03`37`K`3045Yh@030:f][@36
`;`0a/2l00h0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d
/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd=0;jg[0030:f][@31^[00
`KZ`00h0`KZ`0P11JN420<6j/0030:f][@33_K<0`kfc0080`kfc0P11JN450<>m/`80@FWQ0P33_K<4
045Yh@80`kfc00<0[Jf]0<Fn]@35_[D00P35_[D00`11JN40aKje0<Fn]@030<Fn]@03045Yh@35_[D0
aKje00H0aKje00P0@FWQ0<Fn]@35_[D0[Jf]0<Jo]`11JN40a[ng045Yh@<0a[ng00<0@FWQ0<Jo]`36
_kL01036_kL2045Yh@L0a[ng00<0[Jf]0<O1^037`KP02037`KP2045Yh@D0al6h00<0@FWQ0<O1^037
`KP00`37`KP00`2][Jd0al6j045Yh@070<O1^P03045Yh@37`KX0al6j00@0al6j0`11JN430<O1^P04
0:f][@38`K/0@FWQ045Yh@P0b<6k1011JN430<S1^`80@FWQ0P38`K/0102][Jd0b<6k0<S1^`38`K/4
045Yh@h0b<6k00<0[Jf]0<O1_037`K`03`37`K`3045Yh@030:f][@36`;`0a/2l00T0a/2l1@2][Jd2
0<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@03
0;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31^[00`KZ`
00h0`KZ`0P11JN420<6j/0030:f][@33_K<0`kfc0080`kfc0P11JN4?0<>m/`030:f][@35_[D0aKje
00<0aKje1@11JN480<Fn]@80@FWQ0P35_[D0102][Jd0a[ng0<Jo]`11JN450<Jo]`03045Yh@36_kL0
a[ng00<0a[ng0P11JN470<Jo]`030:f][@37`KP0al6h00P0al6h0`11JN430<O1^003045Yh@37`KP0
@FWQ00@0al6h00<0[Jf]0<O1^P11JN401`37`KX00`11JN40al6j0<O1^P040<O1^P80@FWQ00L0al6j
045Yh@37`KX0al6j0:f][@38`K/0@FWQ00T0b<6k0P11JN420<S1^`<0@FWQ1038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l0P11JN400`37`K`0[Jf]0<K0_0060<K0_0@0[Jf]
1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40
];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[00
3P31^[02045Yh@80`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN4@0<>m/`030:f][@35_[D0aKje00h0
aKje1P11JN40102][Jd0a[ng0<Jo]`11JN450<Jo]`03045Yh@36_kL0a[ng00<0a[ng0P11JN470<Jo
]`030:f][@37`KP0al6h00P0al6h0P11JN400`37`KP0@FWQ0<O1^0020<O1^080@FWQ1037`KP00`2]
[Jd0al6j045Yh@060<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN420<O1^P@0@FWQ2P38`K/2045Y
h@T0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00@0<O1_003045Yh@37`K`0[Jf]
0080a/2l1@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102]
[Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00?0<6j/080@FWQ0P31^[00102]
[Jd0`kfc0<>m/`33_K<2045YhA00`kfc00<0[Jf]0<Fn]@35_[D05035_[D0102][Jd0a[ng0<Jo]`11
JN430<Jo]`H0@FWQ0P36_kL2045Yh@L0a[ng00<0[Jf]0<O1^037`KP01@37`KP5045Yh@80al6h1011
JN450<O1^0030:f][@37`KX0al6j00H0@FWQ1P37`KX4045Yh@@0al6j00<0[Jf]0<S1^`38`K/02@38
`K/2045Yh@T0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00@0<O1_0D0[Jf]4036
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]
0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][Jd=
0<6j/080@FWQ0P31^[000`2][Jd0`kfc0<>m/`02045YhA40`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0=0<Jo]`80@FWQ1P36_kL0102][Jd0al6h0<O1^011JN4D0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@T0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00;0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031
^[070:f][@@0`KZ`1011JN420<6j/0040:f][@33_K<0`kfc045YhA80`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0=0<Jo]`80@FWQ1P36_kL0102][Jd0al6h0<O1^011JN4D0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@T0b<6k00<0[Jf]0<S1^`38
`K/00`38`K/00`11JN40b<6k0<S1^`0=0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0
[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd00`31^[00@FWQ045Yh@03045YhA<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0=0<Jo]`80@FWQ1P36_kL0102][Jd0al6h
0<O1^011JN4D0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@T0
b<6k00<0[Jf]0<S1^`38`K/00`38`K/2045Yh@h0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080
[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL03P36_kL00`11JN40a[ng0<Jo]`040<Jo]`040:f][@37`KP0al6h045YhA@0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ2@38`K/00`2][Jd0
b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00X0b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00
MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL03P36_kL00`11JN40a[ng0<Jo]`040<Jo]`040:f][@37`KP0al6h045Y
hA@0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ2@38`K/00`2]
[Jd0b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k00<0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]
0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL03P36_kL2045Yh@D0a[ng00@0[Jf]0<O1^011
JN40@FWQ5037`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k0P11JN490<S1
^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m
/`T0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0?0<Jo]`80@FWQ1036_kL2045Yh@030<O1^011JN40al6h
01<0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`070<S1^`80@FWQ1P38`K/90:f]
[A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00T0`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0
[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0A0<Jo]`@0@FWQ00@0[Jf]0<O1^037`KP0@FWQ5037`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40
[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m^`<0
[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`04@2n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX04037
`KX01@000000al6j0<O1^P37`KX0[Jf]01H0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80
/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
3`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/7
0:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1
^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0
/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.51756 .3341 m
.51422 .33087 L
s
.51422 .33087 m
.51088 .33084 L
s
.51924 .33411 m
.51422 .33087 L
s
.5443 .3307 m
.53261 .33086 L
s
.51088 .33084 m
.50586 .33399 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50253 .33073 m
.49586 .33059 L
s
.56263 .33021 m
.55098 .33055 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53004 .34085 m
.53334 .33857 L
s
.53334 .33857 m
.53666 .33853 L
s
.52838 .34086 m
.53334 .33857 L
s
.53666 .33853 m
.54162 .34072 L
s
.52507 .34538 m
.52838 .34086 L
s
.52673 .34537 m
.53004 .34085 L
s
.54492 .3384 m
.54497 .35646 L
s
.54658 .33837 m
.54663 .35643 L
s
0 0 0 r
.45439 .33207 m
.45456 .33175 L
s
.255 .412 .882 r
.54162 .34072 m
.54494 .34517 L
s
.55648 .33812 m
.56801 .33772 L
s
.52341 .34989 m
.52507 .34538 L
s
.52507 .34989 m
.52673 .34537 L
s
0 0 0 r
.45439 .33207 m
.45455 .3324 L
s
.59083 .33852 m
.59407 .33188 L
s
.59407 .33188 m
.59896 .32834 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59571 .33177 m
.59896 .32834 L
s
.60223 .32811 m
.59896 .32834 L
s
.255 .412 .882 r
.52175 .35667 m
.52341 .34989 L
s
.52341 .35667 m
.52507 .34989 L
s
.47387 .33758 m
.47551 .33765 L
s
.47057 .33969 m
.47387 .33758 L
s
.47222 .33976 m
.47387 .33758 L
s
0 0 0 r
.48503 .35858 m
.48573 .35929 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47055 .3442 m
.47222 .33976 L
s
.46891 .34413 m
.47057 .33969 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50078 .35971 m
.50078 .35918 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49033 .33816 m
.49684 .36999 L
s
.48359 .36963 m
.49033 .33816 L
s
.48524 .36969 m
.4903 .34493 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52175 .368 m
.52175 .35667 L
s
.52341 .35667 m
.52341 .368 L
s
.50355 .33846 m
.51012 .3702 L
s
.49684 .36999 m
.50355 .33846 L
s
.49849 .37003 m
.50353 .34522 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57451 .37178 m
.57453 .37494 L
s
.57617 .37067 m
.5762 .37487 L
s
.255 .412 .882 r
.56143 .33796 m
.56158 .36964 L
s
.56308 .33791 m
.56323 .36959 L
s
.4624 .33703 m
.46566 .33945 L
s
.45751 .33675 m
.4624 .33703 L
s
.54 .35655 m
.5516 .35632 L
s
.46566 .33945 m
.46891 .34413 L
s
.47044 .36005 m
.47055 .3442 L
s
.46877 .36451 m
.46891 .34413 L
s
.45423 .33882 m
.45751 .33675 L
s
.4526 .33872 m
.45751 .33675 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56316 .35598 m
.56485 .36272 L
s
.59094 .33883 m
.5958 .33627 L
s
.58935 .34345 m
.59094 .33883 L
s
.45256 .34324 m
.45423 .33882 L
s
.59257 .33873 m
.5958 .33627 L
s
.59098 .34335 m
.59257 .33873 L
s
.45093 .34314 m
.4526 .33872 L
s
.5958 .33627 m
.60067 .33594 L
s
0 0 0 r
.59046 .36112 m
.59105 .36438 L
s
.61057 .34677 m
.61059 .34687 L
s
.255 .412 .882 r
.52341 .368 m
.52508 .37481 L
s
.52175 .368 m
.52341 .37481 L
s
0 0 0 r
.59195 .36012 m
.5927 .36429 L
s
.61203 .3457 m
.61222 .34674 L
s
.255 .412 .882 r
.58935 .34345 m
.58939 .34798 L
s
.59098 .34335 m
.59102 .34788 L
s
.50513 .37014 m
.5151 .37024 L
s
.6166 .31888 m
.62774 .31784 L
s
.60067 .33594 m
.60392 .33797 L
s
.45252 .34777 m
.45256 .34324 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56485 .36272 m
.56817 .36714 L
s
.45089 .34767 m
.45093 .34314 L
s
.58939 .34798 m
.59106 .35241 L
s
.52341 .37481 m
.52508 .37935 L
s
.52508 .37481 m
.52674 .37935 L
s
.59102 .34788 m
.59269 .35231 L
s
.45736 .35485 m
.46717 .35763 L
s
.46717 .35763 m
.4688 .35998 L
s
.54668 .3723 m
.54672 .38595 L
s
.54504 .37915 m
.54668 .3723 L
s
.46877 .36451 m
.47044 .36005 L
s
.47863 .36946 m
.49021 .36983 L
s
.45252 .34777 m
.45411 .3524 L
s
.55662 .36979 m
.56323 .36959 L
s
0 0 0 r
.57453 .37494 m
.58119 .37464 L
s
.255 .412 .882 r
.45089 .34767 m
.45248 .3523 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57475 .3646 m
.57638 .36225 L
s
.57638 .36225 m
.57804 .36445 L
s
.52508 .37935 m
.52841 .38389 L
s
.52674 .37935 m
.53007 .38388 L
s
.59106 .35241 m
.59596 .35438 L
s
.45411 .3524 m
.45736 .35485 L
s
.45248 .3523 m
.45736 .35485 L
s
.59269 .35231 m
.59596 .35438 L
s
.60877 .33761 m
.61196 .33509 L
s
0 0 0 r
.53942 .39217 m
.53774 .39544 L
s
.54111 .3954 m
.53942 .39217 L
s
.255 .412 .882 r
.46711 .36671 m
.46877 .36451 L
s
.54172 .38376 m
.54504 .37915 L
s
.54504 .37915 m
.54672 .38595 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57804 .36445 m
.57806 .36672 L
s
.57475 .3646 m
.57641 .3668 L
s
.56817 .36714 m
.57149 .36928 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61038 .33748 m
.61196 .33509 L
s
.61196 .33509 m
.61357 .33496 L
s
.6072 .34226 m
.60877 .33761 L
s
.60392 .33797 m
.6072 .34226 L
s
.60882 .34214 m
.61038 .33748 L
s
.57149 .36928 m
.57643 .36907 L
s
.6072 .34226 m
.60741 .3627 L
s
.52841 .38389 m
.53341 .38614 L
s
.53007 .38388 m
.53341 .38614 L
s
.57643 .36907 m
.57806 .36672 L
s
.46381 .36883 m
.46711 .36671 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4539 .3904 m
.45407 .38699 L
s
.5 Mabswid
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41881 .33381 m
.43 .33481 L
s
.60882 .34214 m
.60898 .35803 L
s
.59596 .35438 m
.60573 .35599 L
s
.53674 .3861 m
.54172 .38376 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53674 .3861 m
.53341 .38614 L
s
.59113 .36149 m
.59115 .36376 L
s
.59113 .36149 m
.59276 .36139 L
s
.4524 .36138 m
.45404 .36148 L
s
.45402 .36375 m
.45404 .36148 L
s
.45725 .36848 m
.46381 .36883 L
s
.59276 .36139 m
.59278 .36367 L
s
.45239 .36365 m
.4524 .36138 L
s
.42481 .36623 m
.42519 .3344 L
s
.59115 .36376 m
.5928 .36594 L
s
.42321 .3661 m
.42359 .33426 L
s
.45239 .36365 m
.454 .36602 L
s
.454 .36602 m
.45725 .36848 L
s
.5928 .36594 m
.59609 .36802 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60573 .35599 m
.60737 .35815 L
s
.59609 .36802 m
.6026 .3676 L
s
.62326 .34093 m
.62639 .3361 L
s
.62639 .3361 m
.62954 .33353 L
s
.62954 .33353 m
.63271 .33321 L
s
.60741 .3627 m
.60898 .35803 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43614 .36257 m
.43778 .36041 L
s
.43778 .36041 m
.43937 .3628 L
s
.43935 .36508 m
.43937 .3628 L
s
.60582 .36509 m
.60741 .3627 L
s
.6026 .3676 m
.60582 .36509 L
s
0 0 0 r
.4539 .3904 m
.45406 .39107 L
s
.255 .412 .882 r
.63271 .33321 m
.6359 .33516 L
s
.63271 .33321 m
.63747 .335 L
s
.43771 .36724 m
.43935 .36508 L
s
.43614 .36257 m
.43773 .36496 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42497 .35256 m
.4265 .35953 L
s
.43286 .36688 m
.43771 .36724 L
s
.6359 .33516 m
.63911 .33937 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62298 .3183 m
.62357 .36598 L
s
.62139 .31845 m
.62197 .36611 L
s
.63747 .335 m
.64069 .33921 L
s
.4265 .35953 m
.42966 .36435 L
s
.42966 .36435 m
.43286 .36688 L
s
.40145 .33202 m
.40613 .33481 L
s
.40613 .33481 m
.40921 .33968 L
s
.40921 .33968 m
.41073 .34439 L
s
.40145 .33202 m
.40455 .33464 L
s
.40455 .33464 m
.40764 .33952 L
s
.40764 .33952 m
.40915 .34423 L
s
.41073 .34439 m
.41222 .35138 L
s
.61715 .36652 m
.62357 .36598 L
s
.62348 .35913 m
.62674 .36341 L
s
.38592 .33014 m
.40145 .33202 L
s
.63911 .33937 m
.64079 .34604 L
s
.40915 .34423 m
.41064 .35123 L
s
.64069 .33921 m
.64236 .34587 L
s
.41841 .36567 m
.42481 .36623 L
s
.41207 .36279 m
.41222 .35138 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41048 .36264 m
.41064 .35123 L
s
.62674 .36341 m
.62996 .3654 L
s
.64079 .34604 m
.64085 .3506 L
s
.64236 .34587 m
.64243 .35043 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64294 .35286 m
.64294 .35315 L
s
.64451 .35157 m
.64453 .35295 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65152 .33113 m
.66233 .32976 L
s
.62996 .3654 m
.63314 .3651 L
s
.63938 .35761 m
.64085 .3506 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41039 .3695 m
.41207 .36279 L
s
.64095 .35745 m
.64243 .35043 L
s
.4088 .36935 m
.41048 .36264 L
s
.63314 .3651 m
.63628 .3625 L
s
.63314 .3651 m
.63786 .36234 L
s
.63628 .3625 m
.63938 .35761 L
s
.63786 .36234 m
.64095 .35745 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40874 .37393 m
.41039 .3695 L
s
.40715 .37377 m
.4088 .36935 L
s
.40392 .37805 m
.40715 .37377 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4055 .37821 m
.40874 .37393 L
s
.38977 .37881 m
.39055 .33072 L
s
.39133 .37899 m
.3921 .33092 L
s
.66845 .32893 m
.67903 .32738 L
s
.40074 .38002 m
.4055 .37821 L
s
.40074 .38002 m
.40392 .37805 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64338 .3826 m
.64338 .38289 L
s
.64495 .38132 m
.64498 .3827 L
s
.5 Mabswid
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65617 .33056 m
.65696 .37866 L
s
.65772 .33036 m
.65852 .37847 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65813 .35549 m
.6613 .3597 L
s
.673 .32828 m
.67347 .35348 L
s
.67451 .32806 m
.67498 .35327 L
s
.38511 .37826 m
.40074 .38002 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6613 .3597 m
.66596 .3614 L
s
.65229 .37919 m
.65852 .37847 L
s
.66596 .3614 m
.66902 .361 L
s
.66902 .361 m
.67203 .35829 L
s
.66902 .361 m
.67355 .35808 L
s
.67203 .35829 m
.67347 .35348 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67355 .35808 m
.67498 .35327 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69086 .34349 m
.69087 .34404 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68946 .34479 m
.68983 .34687 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68946 .32572 m
.69012 .35794 L
s
.69093 .32547 m
.6916 .3577 L
s
.68501 .32645 m
.69534 .32472 L
s
.68565 .35863 m
.6916 .3577 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70276 .33033 m
.70555 .32519 L
s
.70147 .3375 m
.70276 .33033 L
s
.70555 .32519 m
.70979 .32207 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70421 .33007 m
.70698 .32492 L
s
.70292 .33724 m
.70421 .33007 L
s
.70147 .3375 m
.70157 .34212 L
s
.70698 .32492 m
.70979 .32207 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70292 .33724 m
.70302 .34186 L
s
.70157 .34212 m
.70317 .3488 L
s
.68892 .37205 m
.69036 .3695 L
s
.68892 .37205 m
.69045 .37414 L
s
.70979 .32207 m
.71263 .32152 L
s
.69036 .3695 m
.69189 .37159 L
s
.70302 .34186 m
.70462 .34854 L
s
.69045 .37414 m
.69189 .37159 L
s
.71263 .32152 m
.71692 .32297 L
s
.70317 .3488 m
.70617 .35291 L
s
.70462 .34854 m
.70761 .35265 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71692 .32297 m
.71984 .32702 L
s
.70617 .35291 m
.71053 .35445 L
s
.70761 .35265 m
.71053 .35445 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71053 .35445 m
.71481 .35365 L
s
.71742 .34381 m
.71877 .34121 L
s
.71742 .34381 m
.71888 .34585 L
s
.71877 .34121 m
.72023 .34325 L
s
.71481 .35365 m
.71759 .35078 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72023 .34325 m
.72029 .34557 L
s
.71759 .35078 m
.72029 .34557 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72929 .36955 m
.72943 .37035 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72934 .31799 m
.72958 .32727 L
s
.72934 .31799 m
.73083 .32232 L
s
.72958 .32727 m
.73083 .32232 L
s
.73083 .32232 m
.73213 .31969 L
s
.73213 .31969 m
.73478 .31675 L
s
.73478 .31675 m
.74013 .31547 L
s
.72994 .34122 m
.73125 .33859 L
s
.72994 .34122 m
.73006 .34588 L
s
.73125 .33859 m
.73391 .33565 L
s
.30628 .3204 m
.30768 .31839 L
s
.30641 .31575 m
.30768 .31839 L
s
.73 .34355 m
.73131 .34092 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30501 .31775 m
.30641 .31575 L
s
.73131 .34092 m
.73397 .33798 L
s
.73006 .34588 m
.73148 .34792 L
s
.74013 .31547 m
.74285 .31714 L
s
.30501 .31775 m
.30628 .3204 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73085 .36971 m
.73107 .36764 L
s
.5 Mabswid
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73148 .34792 m
.73427 .34966 L
s
.73397 .33798 m
.74057 .33177 L
s
.73391 .33565 m
.74051 .32943 L
s
.74285 .31714 m
.74423 .31914 L
s
.30597 .33204 m
.30657 .36043 L
s
.30388 .35982 m
.30597 .33204 L
s
.73427 .34966 m
.73967 .34844 L
s
.74051 .32943 m
.7431 .32646 L
s
.74423 .31914 m
.74442 .32614 L
s
.74057 .33177 m
.74316 .32879 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7431 .32646 m
.74436 .3238 L
s
.74316 .32879 m
.74442 .32614 L
s
.30522 .36012 m
.3056 .34606 L
s
.73967 .34844 m
.74228 .34548 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29453 .31509 m
.29576 .31777 L
s
.29556 .32477 m
.29576 .31777 L
s
.74228 .34548 m
.74355 .34282 L
s
.29202 .31207 m
.29453 .31509 L
s
.74355 .34282 m
.74474 .33782 L
s
.74474 .33782 m
.745 .34719 L
s
.74355 .34282 m
.745 .34719 L
s
.3051 .36482 m
.30657 .36043 L
s
.29427 .32444 m
.29563 .32244 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2942 .32678 m
.29556 .32477 L
s
.28694 .31068 m
.29202 .31207 L
s
.75326 .31445 m
.75447 .31177 L
s
.75326 .31445 m
.7546 .31645 L
s
.75447 .31177 m
.75581 .31376 L
s
.29162 .3261 m
.29427 .32444 L
s
.30388 .35982 m
.3051 .36482 L
s
.29156 .32845 m
.2942 .32678 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7546 .31645 m
.75581 .31376 L
s
.2938 .34084 m
.29523 .33648 L
s
.29497 .34587 m
.29523 .33648 L
s
.28514 .32908 m
.29162 .3261 L
s
.28507 .33143 m
.29156 .32845 L
s
.28437 .3123 m
.28694 .31068 L
s
.75494 .32815 m
.75703 .35606 L
s
.75446 .35671 m
.75494 .32815 L
s
.29244 .34286 m
.2938 .34084 L
s
.2938 .34084 m
.29497 .34587 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28981 .34456 m
.29244 .34286 L
s
.28305 .31429 m
.28437 .3123 L
s
.28195 .30924 m
.28305 .31429 L
s
.28167 .31863 m
.28195 .30924 L
s
.28167 .31863 m
.28305 .31429 L
s
.75534 .34225 m
.75575 .35639 L
s
.28473 .34321 m
.28981 .34456 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28256 .33074 m
.28514 .32908 L
s
.2825 .33309 m
.28507 .33143 L
s
.75446 .35671 m
.75588 .36111 L
s
.28125 .33274 m
.28256 .33074 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75588 .36111 m
.75703 .35606 L
s
.28118 .3351 m
.2825 .33309 L
s
.28229 .34016 m
.28473 .34321 L
s
.28111 .33746 m
.28125 .33274 L
s
.28111 .33746 m
.28229 .34016 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27096 .30826 m
.2732 .31372 L
s
.26749 .30475 m
.27096 .30826 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26516 .30398 m
.26749 .30475 L
s
.27262 .3326 m
.27269 .33024 L
s
.27156 .32751 m
.27269 .33024 L
s
.2703 .3295 m
.27156 .32751 L
s
.27007 .33661 m
.27262 .3326 L
s
.2703 .3295 m
.27142 .33224 L
s
.26278 .30555 m
.26516 .30398 L
s
.26164 .30516 m
.26516 .30398 L
s
.26763 .33825 m
.27007 .33661 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26035 .3095 m
.26278 .30555 L
s
.25921 .3091 m
.26164 .30516 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26411 .33714 m
.26763 .33825 L
s
.25898 .31622 m
.26035 .3095 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25785 .31582 m
.25921 .3091 L
s
.26187 .33401 m
.26411 .33714 L
s
.26072 .33363 m
.26411 .33714 L
s
.25883 .32097 m
.25898 .31622 L
s
.25973 .32849 m
.26187 .33401 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2577 .32058 m
.25785 .31582 L
s
.25883 .32097 m
.25973 .32849 L
s
.25859 .3281 m
.26072 .33363 L
s
.24635 .29706 m
.25388 .29998 L
s
.2577 .32058 m
.25859 .3281 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24844 .32216 m
.2485 .32041 L
s
.24959 .32141 m
.24961 .32088 L
s
.5 Mabswid
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24949 .33213 m
.25061 .29874 L
s
.24841 .33173 m
.24954 .29832 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24521 .33053 m
.24949 .33213 L
s
.23518 .2923 m
.24219 .29535 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24784 .34854 m
.24901 .34653 L
s
.248 .34373 m
.24901 .34653 L
s
.24685 .34575 m
.248 .34373 L
s
.23822 .32043 m
.23915 .29406 L
s
.24685 .34575 m
.24784 .34854 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23721 .32001 m
.23814 .29362 L
s
.23704 .32483 m
.23822 .32043 L
s
.23604 .3244 m
.23721 .32001 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23398 .32597 m
.23704 .32483 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22485 .28732 m
.23132 .29051 L
s
.23398 .32597 m
.23604 .3244 L
s
0 0 0 r
.22224 .27871 m
.22257 .27888 L
s
.255 .412 .882 r
.81583 .28967 m
.82483 .28505 L
s
.23203 .32512 m
.23398 .32597 L
s
.22665 .33998 m
.2285 .28915 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22572 .33955 m
.22758 .2887 L
s
.22924 .32141 m
.23203 .32512 L
s
.8186 .2883 m
.82047 .33918 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81951 .28784 m
.82138 .33875 L
s
.22754 .3157 m
.22924 .32141 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81767 .34046 m
.82674 .33614 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82483 .28505 m
.82663 .28653 L
s
.22297 .33826 m
.22665 .33998 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82663 .28653 m
.82849 .29043 L
s
.82483 .28505 m
.82747 .28605 L
s
.82747 .28605 m
.82932 .28996 L
s
.21697 .28552 m
.21846 .29131 L
s
.21846 .29131 m
.21904 .29906 L
s
.21886 .30392 m
.21904 .29906 L
s
.21614 .28504 m
.21762 .29084 L
s
.21762 .29084 m
.21819 .29859 L
s
.2146 .28165 m
.21697 .28552 L
s
.21773 .31076 m
.21886 .30392 L
s
.21801 .30346 m
.21819 .29859 L
s
.82849 .29043 m
.8295 .29482 L
s
.2146 .28165 m
.21614 .28504 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21689 .3103 m
.21801 .30346 L
s
.82932 .28996 m
.83033 .29435 L
s
.20759 .25969 m
.21287 .26321 L
s
.21586 .31472 m
.21773 .31076 L
s
.213 .28069 m
.2146 .28165 L
s
.21503 .31426 m
.21689 .3103 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83033 .29435 m
.83142 .30119 L
s
.8295 .29482 m
.8306 .30166 L
s
.21134 .28215 m
.213 .28069 L
s
.82674 .33614 m
.82837 .33281 L
s
.82674 .33614 m
.82922 .33236 L
s
.8306 .30166 m
.83107 .31387 L
s
.2133 .31579 m
.21586 .31472 L
s
.20857 .313 m
.21056 .26171 L
s
.83142 .30119 m
.83189 .31341 L
s
.2133 .31579 m
.21503 .31426 L
s
.83385 .27978 m
.83909 .27633 L
s
.82837 .33281 m
.82987 .32702 L
s
.20781 .31253 m
.2098 .26121 L
s
.20962 .28605 m
.21134 .28215 L
s
.83052 .32167 m
.83107 .31387 L
s
.82922 .33236 m
.83071 .32656 L
s
.82987 .32702 m
.83052 .32167 L
s
.83135 .32121 m
.83189 .31341 L
s
.83071 .32656 m
.83135 .32121 L
s
.21169 .31487 m
.2133 .31579 L
s
.83614 .27831 m
.83748 .31259 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83689 .27782 m
.83823 .31212 L
s
.21021 .31148 m
.21169 .31487 L
s
.20886 .30563 m
.21021 .31148 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83517 .314 m
.83823 .31212 L
s
.83765 .29738 m
.83869 .30427 L
s
.20478 .27526 m
.20548 .27576 L
s
.20558 .31111 m
.20857 .313 L
s
.20329 .27671 m
.20478 .27526 L
s
.20398 .27721 m
.20478 .27526 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83869 .30427 m
.84034 .30823 L
s
.2031 .28161 m
.20398 .27721 L
s
.20242 .28111 m
.20329 .27671 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20242 .29884 m
.2031 .28161 L
s
.84034 .30823 m
.84187 .30974 L
s
.20127 .27519 m
.20242 .28111 L
s
.20154 .30328 m
.20242 .28111 L
s
.20006 .27171 m
.20127 .27519 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84187 .30974 m
.84396 .30829 L
s
.20154 .30328 m
.20242 .29884 L
s
.19817 .27017 m
.20006 .27171 L
s
.84307 .30384 m
.84386 .30582 L
s
.84307 .30384 m
.84366 .30088 L
s
.20115 .29539 m
.20173 .29835 L
s
.84366 .30088 m
.84444 .30286 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19738 .28993 m
.20115 .29539 L
s
.20076 .30527 m
.20154 .30328 L
s
.84396 .30829 m
.84454 .30533 L
s
.84444 .30286 m
.84454 .30533 L
s
.19933 .30677 m
.20076 .30527 L
s
.19685 .27161 m
.19817 .27017 L
s
.19626 .27109 m
.19817 .27017 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19678 .30481 m
.19933 .30677 L
s
.84805 .27713 m
.84845 .27168 L
s
.84805 .27713 m
.84824 .28207 L
s
.84845 .27168 m
.85012 .26765 L
s
.19606 .27603 m
.19685 .27161 L
s
.84824 .28207 m
.84905 .28651 L
s
.84865 .27661 m
.84905 .27116 L
s
.84865 .27661 m
.84885 .28156 L
s
.84905 .27116 m
.85012 .26765 L
s
.19547 .27552 m
.19626 .27109 L
s
.19626 .28644 m
.19738 .28993 L
s
.19566 .28593 m
.19738 .28993 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84885 .28156 m
.84965 .286 L
s
.19586 .28098 m
.19606 .27603 L
s
.85012 .26765 m
.8518 .26608 L
s
.19586 .28098 m
.19626 .28644 L
s
.19527 .28047 m
.19547 .27552 L
s
.19527 .28047 m
.19566 .28593 L
s
.19565 .30133 m
.19678 .30481 L
s
.84945 .29643 m
.84955 .29891 L
s
.19526 .29586 m
.19585 .29636 L
s
.19575 .29885 m
.19585 .29636 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84955 .29891 m
.85025 .3009 L
s
.84945 .29643 m
.85005 .29593 L
s
.84965 .286 m
.85092 .28747 L
s
.84905 .28651 m
.85092 .28747 L
s
.19515 .29835 m
.19565 .30133 L
s
.85005 .29593 m
.85015 .29841 L
s
.19515 .29835 m
.19526 .29586 L
s
.8518 .26608 m
.85298 .2675 L
s
.85092 .28747 m
.85433 .28688 L
s
.85025 .3009 m
.85153 .30239 L
s
.85298 .2675 m
.85423 .27142 L
s
.85153 .30239 m
.85377 .30038 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85423 .27142 m
.85454 .26592 L
s
.85423 .27142 m
.85515 .29386 L
s
.85454 .26592 m
.85542 .26237 L
s
.85474 .27089 m
.85503 .26539 L
s
.85474 .27089 m
.85546 .28835 L
s
.85503 .26539 m
.85542 .26237 L
s
.85433 .28688 m
.85495 .28886 L
s
.85542 .26237 m
.8559 .26183 L
s
.85377 .30038 m
.85474 .29687 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19027 .29129 m
.19068 .2943 L
s
.19058 .2968 m
.19068 .2943 L
s
.85474 .29687 m
.85515 .29386 L
s
.18996 .2988 m
.19058 .2968 L
s
.18965 .29328 m
.19027 .29129 L
s
.85515 .29386 m
.85546 .28835 L
s
.18592 .25744 m
.18895 .26122 L
s
.18965 .29328 m
.19006 .29629 L
s
.18846 .29727 m
.18996 .2988 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18364 .2534 m
.18379 .26108 L
s
.255 .412 .882 r
.18614 .2947 m
.1876 .25961 L
s
0 0 0 r
.18321 .25285 m
.18334 .26053 L
s
.255 .412 .882 r
.1876 .29373 m
.18846 .29727 L
s
.1857 .29418 m
.18717 .25907 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18213 .30047 m
.183 .27988 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1869 .28767 m
.1876 .29373 L
s
.18676 .27962 m
.1869 .28767 L
s
.85829 .2958 m
.86128 .29217 L
s
0 0 0 r
.86401 .24658 m
.86377 .25071 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85981 .25697 m
.86278 .29008 L
s
.85963 .29425 m
.85981 .25697 L
s
.18445 .29262 m
.18614 .2947 L
s
.86006 .29373 m
.86012 .26449 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18242 .28231 m
.18256 .27902 L
s
.5 Mabswid
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18285 .2743 m
.1837 .25416 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86508 .27166 m
.86523 .27456 L
s
.86508 .27166 m
.86518 .27468 L
s
.86603 .30045 m
.86652 .31552 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18155 .27215 m
.18392 .27591 L
s
.18251 .27377 m
.18336 .2536 L
s
.18261 .25502 m
.18304 .26115 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86263 .25257 m
.86278 .29008 L
s
.18182 .25084 m
.18261 .25502 L
s
.86295 .26013 m
.86313 .28955 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86622 .29869 m
.86661 .30766 L
s
.8664 .29713 m
.86691 .30699 L
s
.5 Mabswid
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86263 .25257 m
.86532 .28584 L
s
.18127 .24972 m
.18182 .25084 L
s
.18146 .30726 m
.1821 .29202 L
s
.18144 .29911 m
.1821 .29202 L
s
.18066 .25114 m
.18127 .24972 L
s
.18042 .25058 m
.18127 .24972 L
s
.18057 .30316 m
.18144 .29911 L
s
.18144 .29911 m
.18146 .30726 L
s
0 0 0 r
.86911 .23695 m
.86912 .23692 L
s
.255 .412 .882 r
.86444 .28744 m
.8661 .28424 L
s
.17997 .25509 m
.18066 .25114 L
s
0 0 0 r
.17624 .23685 m
.17653 .24155 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17975 .25453 m
.18042 .25058 L
s
.17956 .30416 m
.18057 .30316 L
s
0 0 0 r
.86912 .23692 m
.86968 .23939 L
s
.86912 .23692 m
.86987 .23882 L
s
.17547 .23454 m
.17624 .23685 L
s
.255 .412 .882 r
.17954 .25962 m
.17997 .25509 L
s
.17933 .25906 m
.17975 .25453 L
s
0 0 0 r
.17521 .26641 m
.17536 .26868 L
s
.86968 .23939 m
.87037 .2455 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17901 .30311 m
.17956 .30416 L
s
0 0 0 r
.17505 .27005 m
.17521 .27232 L
s
.255 .412 .882 r
.179 .2667 m
.17954 .25962 L
s
0 0 0 r
.86987 .23882 m
.87053 .24493 L
s
.17453 .25633 m
.17521 .26641 L
s
.17499 .23701 m
.17547 .23454 L
s
.255 .412 .882 r
.1788 .26615 m
.17933 .25906 L
s
0 0 0 r
.17437 .25998 m
.17505 .27005 L
s
.17427 .28829 m
.17457 .28706 L
s
.255 .412 .882 r
.1786 .29951 m
.17901 .30311 L
s
.17836 .29898 m
.17901 .30311 L
s
.86621 .25294 m
.86623 .25858 L
s
.86623 .25858 m
.86636 .26677 L
s
.86621 .25294 m
.86634 .24673 L
s
.86636 .26677 m
.8669 .27954 L
s
.17846 .27946 m
.179 .2667 L
s
0 0 0 r
.87101 .25585 m
.87037 .2455 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86639 .25238 m
.86642 .25803 L
s
.86642 .25803 m
.86656 .26623 L
s
.86639 .25238 m
.8665 .24616 L
s
0 0 0 r
.8713 .28784 m
.87131 .28782 L
s
.255 .412 .882 r
.86656 .26623 m
.8671 .279 L
s
.86634 .24673 m
.86668 .24248 L
s
.17826 .27892 m
.1788 .26615 L
s
.17834 .29333 m
.1786 .29951 L
s
0 0 0 r
.17468 .24007 m
.17499 .23701 L
s
.87117 .25528 m
.87053 .24493 L
s
.255 .412 .882 r
.8665 .24616 m
.86668 .24248 L
s
.8669 .27954 m
.86743 .28668 L
s
0 0 0 r
.17344 .28612 m
.17427 .28829 L
s
.255 .412 .882 r
.17812 .2928 m
.17836 .29898 L
s
.17834 .28768 m
.17846 .27946 L
s
0 0 0 r
.17453 .25633 m
.17436 .25156 L
s
.255 .412 .882 r
.17834 .28768 m
.17834 .29333 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17437 .25998 m
.1742 .2552 L
s
.17421 .25099 m
.17468 .24007 L
s
.87131 .28782 m
.87157 .28308 L
s
.87131 .28782 m
.87176 .28253 L
s
.255 .412 .882 r
.8671 .279 m
.86762 .28614 L
s
0 0 0 r
.87132 .26314 m
.87101 .25585 L
s
.255 .412 .882 r
.17813 .28714 m
.17826 .27892 L
s
.17812 .2928 m
.17813 .28714 L
s
.86668 .24248 m
.86692 .24135 L
s
0 0 0 r
.17436 .25156 m
.17437 .24735 L
s
.87148 .26258 m
.87117 .25528 L
s
.1742 .2552 m
.17421 .25099 L
s
.255 .412 .882 r
.86743 .28668 m
.86784 .29128 L
s
0 0 0 r
.87157 .28308 m
.87163 .27466 L
s
.87132 .26314 m
.87163 .27466 L
s
.255 .412 .882 r
.86762 .28614 m
.86803 .29074 L
s
0 0 0 r
.87176 .28253 m
.8718 .27411 L
s
.87148 .26258 m
.8718 .27411 L
s
.87131 .22645 m
.87086 .23055 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86692 .24135 m
.86732 .2422 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17325 .28137 m
.17344 .28612 L
s
.255 .412 .882 r
.86784 .29128 m
.86842 .29536 L
s
.86803 .29074 m
.86858 .29483 L
s
0 0 0 r
.17325 .27715 m
.17325 .28137 L
s
.255 .412 .882 r
.17671 .27606 m
.17745 .27932 L
s
0 0 0 r
.17342 .26927 m
.17325 .27715 L
s
.17278 .28395 m
.17342 .26927 L
s
.17325 .27715 m
.17278 .28395 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17703 .27769 m
.17816 .23956 L
s
.17638 .27333 m
.17816 .23956 L
s
0 0 0 r
.1741 .23237 m
.1742 .22813 L
s
.17388 .23544 m
.1741 .23237 L
s
.1742 .22813 m
.17399 .2312 L
s
.255 .412 .882 r
.17642 .27388 m
.17783 .24724 L
s
0 0 0 r
.17399 .2312 m
.17388 .23544 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86858 .29483 m
.86898 .29634 L
s
.86842 .29536 m
.86898 .29634 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86741 .23793 m
.86829 .25847 L
s
.86801 .2607 m
.8684 .2568 L
s
.86736 .2385 m
.86824 .25903 L
s
.86732 .2422 m
.86769 .24619 L
s
.86898 .29634 m
.86923 .29528 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17309 .25377 m
.1711 .29755 L
s
.17123 .29863 m
.17309 .25377 L
s
.255 .412 .882 r
.86923 .29528 m
.86942 .29109 L
s
.17638 .27333 m
.17786 .23499 L
s
.1764 .26893 m
.17786 .23499 L
s
0 0 0 r
.87096 .21997 m
.87133 .2241 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86935 .28484 m
.86942 .29109 L
s
0 0 0 r
.87112 .2288 m
.87335 .28019 L
s
.87118 .22821 m
.87341 .27964 L
s
.87355 .27798 m
.87335 .28019 L
s
.255 .412 .882 r
.86717 .23046 m
.86752 .23449 L
s
0 0 0 r
.17116 .29809 m
.17213 .27587 L
s
.255 .412 .882 r
.86907 .27654 m
.86974 .29208 L
s
.86907 .27654 m
.86935 .28484 L
s
.17636 .26948 m
.17752 .2427 L
s
.86935 .28484 m
.86974 .29208 L
s
0 0 0 r
.17084 .30552 m
.17123 .29863 L
s
.255 .412 .882 r
.86744 .23276 m
.86899 .26901 L
s
0 0 0 r
.87431 .30241 m
.87454 .3056 L
s
.87422 .29816 m
.87431 .30241 L
s
.87444 .30134 m
.87422 .29816 L
s
.255 .412 .882 r
.86739 .23219 m
.86894 .26845 L
s
0 0 0 r
.1711 .29755 m
.17084 .30552 L
s
.87454 .3056 m
.87444 .30134 L
s
.255 .412 .882 r
.17659 .26728 m
.1763 .27113 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87118 .22174 m
.87457 .29972 L
s
.87124 .22234 m
.87463 .30025 L
s
.255 .412 .882 r
.86894 .26845 m
.86908 .27066 L
s
.86828 .25287 m
.86855 .2601 L
s
.17832 .2298 m
.17843 .22923 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17856 .23066 m
.17843 .22923 L
s
.17844 .23124 m
.17843 .22923 L
s
.86855 .2601 m
.86862 .26419 L
s
.17834 .23585 m
.17844 .23124 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17848 .23528 m
.17856 .23066 L
s
.86853 .26569 m
.86862 .26419 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17747 .25873 m
.17803 .24587 L
s
.17756 .25407 m
.1779 .24608 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87003 .21894 m
.87069 .22754 L
s
.86928 .21346 m
.87003 .21894 L
s
.255 .412 .882 r
.86853 .26569 m
.86816 .26403 L
s
0 0 0 r
.87435 .29811 m
.87463 .30025 L
s
.255 .412 .882 r
.17747 .25873 m
.17756 .25407 L
s
.86804 .26142 m
.86807 .25936 L
s
.86782 .25619 m
.86807 .25936 L
s
.1777 .25351 m
.17796 .25034 L
s
.86779 .25825 m
.86782 .25619 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17751 .26079 m
.17747 .25873 L
s
0 0 0 r
.86883 .21227 m
.86928 .21346 L
s
.255 .412 .882 r
.8679 .26086 m
.86816 .26403 L
s
.86779 .25825 m
.8679 .26086 L
s
0 0 0 r
.87182 .25359 m
.87198 .25733 L
s
.8715 .24929 m
.87182 .25359 L
s
.87148 .25246 m
.8715 .24929 L
s
.87198 .25733 m
.87197 .26369 L
s
.8685 .21481 m
.86883 .21227 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87148 .25246 m
.87182 .25676 L
s
.255 .412 .882 r
.86561 .23485 m
.86566 .23599 L
s
0 0 0 r
.87197 .26369 m
.87175 .26633 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86828 .22109 m
.8685 .21481 L
s
.86823 .21421 m
.86883 .21227 L
s
.86799 .22051 m
.86823 .21421 L
s
.8711 .26465 m
.87175 .26633 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86828 .22109 m
.86848 .23174 L
s
.87044 .25977 m
.8711 .26465 L
s
.87017 .25921 m
.8711 .26465 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86848 .23174 m
.8688 .23925 L
s
.86799 .22051 m
.86818 .23117 L
s
.86818 .23117 m
.8685 .23868 L
s
.86442 .20397 m
.86591 .20634 L
s
.8688 .23925 m
.86957 .25111 L
s
.86957 .25111 m
.87044 .25977 L
s
.8685 .23868 m
.86929 .25054 L
s
.86929 .25054 m
.87017 .25921 L
s
.86481 .20456 m
.86707 .25741 L
s
.86442 .20397 m
.86668 .25685 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86377 .20654 m
.8649 .21524 L
s
.86231 .20101 m
.86377 .20654 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86138 .19983 m
.86231 .20101 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86057 .20243 m
.86138 .19983 L
s
.86007 .20184 m
.86138 .19983 L
s
.86545 .25518 m
.86707 .25741 L
s
.255 .412 .882 r
.85695 .2123 m
.85704 .21275 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18563 .24846 m
.18631 .23242 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86039 .20941 m
.86057 .20243 L
s
.255 .412 .882 r
.85584 .2085 m
.85695 .2123 L
s
0 0 0 r
.85987 .20883 m
.86007 .20184 L
s
.86039 .20941 m
.86216 .2513 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85829 .24421 m
.85834 .24391 L
s
0 0 0 r
.85987 .20883 m
.86164 .25075 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8574 .24578 m
.85829 .24421 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86002 .24909 m
.86216 .2513 L
s
.85425 .1922 m
.8552 .21508 L
s
.84279 .18298 m
.85425 .1922 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85362 .19162 m
.8552 .21508 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85663 .24965 m
.8576 .27286 L
s
.85663 .24965 m
.85696 .27233 L
s
.8514 .21553 m
.85266 .24639 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84593 .18526 m
.84922 .26655 L
s
.84516 .18469 m
.84845 .26603 L
s
.84765 .22763 m
.85203 .23093 L
s
.84606 .26447 m
.8576 .27286 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83709 .21419 m
.83739 .22195 L
s
.5 Mabswid
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83739 .22195 m
.83812 .22608 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8068 .20101 m
.80808 .20426 L
s
.807 .20654 m
.80808 .20426 L
s
.80837 .21257 m
.80873 .21313 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24727 .16002 m
.25517 .15703 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24986 .15901 m
.25649 .23953 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25169 .18176 m
.2641 .17751 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25689 .22742 m
.26774 .15271 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26346 .15413 m
.27212 .15131 L
s
.25649 .23953 m
.26919 .15224 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27509 .15039 m
.28578 .14725 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27789 .20519 m
.27961 .14903 L
s
.27943 .20477 m
.28114 .14858 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28017 .18059 m
.28134 .19223 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27334 .20647 m
.27943 .20477 L
s
.28134 .19223 m
.28422 .19947 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28422 .19947 m
.28727 .20269 L
s
.30846 .14538 m
.31369 .14018 L
s
.30488 .15422 m
.30846 .14538 L
s
.30287 .16671 m
.30488 .15422 L
s
.31016 .14498 m
.31369 .14018 L
s
.30656 .15382 m
.31016 .14498 L
s
.30454 .16631 m
.30656 .15382 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2907 .19378 m
.29244 .18933 L
s
.29244 .18933 m
.29394 .19297 L
s
.28727 .20269 m
.29208 .20148 L
s
.2907 .19378 m
.2922 .19742 L
s
.31369 .14018 m
.31714 .1394 L
s
.30265 .17479 m
.30287 .16671 L
s
.30432 .1744 m
.30454 .16631 L
s
.29383 .19702 m
.29394 .19297 L
s
.31714 .1394 m
.32229 .14229 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30265 .17479 m
.30399 .18655 L
s
.29208 .20148 m
.29383 .19702 L
s
.30432 .1744 m
.30568 .18616 L
s
.32229 .14229 m
.32563 .14963 L
s
.30399 .18655 m
.30715 .19391 L
s
.30568 .18616 m
.30886 .19353 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30715 .19391 m
.31219 .19686 L
s
.33674 .13536 m
.34971 .13299 L
s
.30886 .19353 m
.31219 .19686 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31219 .19686 m
.31742 .19577 L
s
.32324 .17432 m
.32492 .17803 L
s
.32136 .17875 m
.32324 .17432 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32136 .17875 m
.32304 .18246 L
s
.32482 .18211 m
.32492 .17803 L
s
.31742 .19577 m
.32106 .19098 L
s
.32106 .19098 m
.32482 .18211 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3403 .22018 m
.34225 .13432 L
s
.34217 .21987 m
.34411 .13398 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36214 .1757 m
.36304 .13079 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37191 .13177 m
.37194 .13006 L
s
.5 Mabswid
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35729 .13171 m
.37082 .12961 L
s
.36408 .17541 m
.36498 .13049 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3431 .17874 m
.34667 .1863 L
s
.37869 .12849 m
.39271 .12667 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34667 .1863 m
.35226 .18949 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3712 .16887 m
.37124 .16715 L
s
.5 Mabswid
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38366 .18511 m
.38466 .12769 L
s
.38568 .18487 m
.38667 .12743 L
s
.35226 .18949 m
.35609 .1889 L
s
.33473 .22112 m
.34217 .21987 L
s
.36004 .1842 m
.36214 .1757 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66934 .1658 m
.66935 .16643 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40085 .12571 m
.41529 .12418 L
s
.36197 .18391 m
.36408 .17541 L
s
.35609 .1889 m
.36004 .1842 L
s
.35609 .1889 m
.36197 .18391 L
s
.64153 .12538 m
.64364 .12969 L
s
.63953 .12924 m
.64153 .12538 L
s
.64165 .13355 m
.64364 .12969 L
s
.40617 .18261 m
.40701 .12503 L
s
.40825 .18241 m
.40907 .12482 L
s
.63953 .12924 m
.64165 .13355 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42365 .1234 m
.43844 .12217 L
s
.6102 .12242 m
.61865 .12312 L
s
.61865 .12312 m
.6229 .12759 L
s
.6229 .12759 m
.62505 .13188 L
s
.62505 .13188 m
.62521 .14419 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60599 .12619 m
.6102 .12242 L
s
.37765 .18587 m
.38568 .18487 L
s
.62311 .144 m
.62516 .14008 L
s
.60169 .12179 m
.6039 .13014 L
s
.6039 .13014 m
.60599 .12619 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44698 .12156 m
.46204 .12065 L
s
.62316 .14811 m
.62521 .14419 L
s
.61895 .14775 m
.62311 .144 L
s
.255 .412 .882 r
.57412 .13581 m
.57435 .13567 L
s
0 0 0 r
.619 .15186 m
.62316 .14811 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57149 .12007 m
.57583 .12027 L
s
.57583 .12027 m
.58237 .1247 L
s
.60843 .15515 m
.61895 .14775 L
s
.60185 .13821 m
.6039 .13014 L
s
.60169 .12179 m
.60185 .13821 L
s
.58237 .1247 m
.58676 .13315 L
s
.56716 .124 m
.57149 .12007 L
s
.56497 .12392 m
.57149 .12007 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42943 .16812 m
.42996 .12285 L
s
.43156 .16795 m
.43208 .12267 L
s
.45302 .16649 m
.45341 .12114 L
s
.45518 .16637 m
.45557 .12101 L
s
.40842 .17 m
.41247 .17786 L
s
.47939 .12396 m
.48378 .11969 L
s
.48378 .11969 m
.48815 .11955 L
s
.47721 .12404 m
.48378 .11969 L
s
.48815 .11955 m
.4947 .12348 L
s
.4728 .13245 m
.47721 .12404 L
s
.56283 .13207 m
.56716 .124 L
s
.47498 .13236 m
.47939 .12396 L
s
.56065 .13199 m
.56497 .12392 L
s
.54087 .11918 m
.54964 .11935 L
s
.39996 .18325 m
.40825 .18241 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60848 .15928 m
.619 .15186 L
s
.62348 .17288 m
.62548 .16479 L
s
.62548 .16479 m
.62569 .18135 L
s
.53208 .11907 m
.53648 .12322 L
s
.52768 .11904 m
.53208 .11907 L
s
.3833 .20582 m
.38525 .20974 L
s
.38121 .21022 m
.3833 .20582 L
s
.52328 .12314 m
.52768 .11904 L
s
.52108 .12314 m
.52768 .11904 L
s
.4947 .12348 m
.49907 .13161 L
s
.38121 .21022 m
.38316 .21413 L
s
.47055 .14491 m
.4728 .13245 L
s
.53648 .12322 m
.54089 .13152 L
s
.47273 .14482 m
.47498 .13236 L
s
.6042 .15898 m
.60843 .15515 L
s
.51667 .13139 m
.52108 .12314 L
s
.51887 .13138 m
.52328 .12314 L
s
.41247 .17786 m
.41871 .18143 L
s
.5607 .14437 m
.56283 .13207 L
s
.38316 .21413 m
.38525 .20974 L
s
.55851 .1443 m
.56065 .13199 L
s
.60424 .16311 m
.60848 .15928 L
s
.62142 .17684 m
.62348 .17288 L
s
.62348 .17288 m
.62569 .18135 L
s
.6021 .16297 m
.6042 .15898 L
s
.42721 .17657 m
.42943 .16812 L
s
.51446 .14379 m
.51667 .13139 L
s
.51666 .14377 m
.51887 .13138 L
s
.43156 .16795 m
.43573 .17592 L
s
.42934 .17641 m
.43156 .16795 L
s
.47049 .15318 m
.47055 .14491 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64233 .1788 m
.64271 .20369 L
s
.64063 .20349 m
.64196 .15405 L
s
.64196 .15405 m
.64478 .2039 L
s
.41871 .18143 m
.42293 .18107 L
s
.47267 .15308 m
.47273 .14482 L
s
.61723 .18064 m
.62142 .17684 L
s
.60214 .16711 m
.60424 .16311 L
s
.6021 .16297 m
.60218 .17125 L
s
.58692 .15377 m
.58699 .16205 L
s
.56074 .15264 m
.58692 .15377 L
s
.42293 .18107 m
.42721 .17657 L
s
.42293 .18107 m
.42934 .17641 L
s
.64283 .21203 m
.64478 .2039 L
s
.5607 .14437 m
.56074 .15264 L
s
.55851 .1443 m
.55855 .15257 L
s
.47049 .15318 m
.4726 .16552 L
s
.64063 .20349 m
.64283 .21203 L
s
.47267 .15308 m
.47478 .16543 L
s
.47267 .15308 m
.49901 .15227 L
s
.43573 .17592 m
.44212 .17962 L
s
.51445 .15206 m
.51446 .14379 L
s
.51666 .15205 m
.51666 .14377 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45078 .17492 m
.45302 .16649 L
s
.5 Mabswid
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58488 .17023 m
.58699 .16205 L
s
.60218 .17125 m
.60437 .17555 L
s
.6087 .18 m
.61723 .18064 L
s
.58476 .15365 m
.58485 .16608 L
s
.56074 .15264 m
.563 .16515 L
s
.60437 .17555 m
.6087 .18 L
s
.45294 .1748 m
.45518 .16637 L
s
.55855 .15257 m
.5608 .16508 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.58274 .17427 m
.58485 .16608 L
s
.49676 .16476 m
.4968 .15231 L
s
.49898 .16056 m
.49901 .15227 L
s
.44212 .17962 m
.44642 .17934 L
s
.51445 .15206 m
.51665 .16449 L
s
.51666 .15205 m
.51886 .16448 L
s
.44642 .17934 m
.45078 .17492 L
s
.58274 .17427 m
.58488 .17023 L
s
.44642 .17934 m
.45294 .1748 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4726 .16552 m
.47693 .17365 L
s
.47478 .16543 m
.47912 .17357 L
s
.563 .16515 m
.56744 .17361 L
s
.49675 .16891 m
.49898 .16056 L
s
.57841 .17823 m
.58274 .17427 L
s
.5608 .16508 m
.56524 .17354 L
s
.49453 .17312 m
.49676 .16476 L
s
.53657 .17288 m
.54097 .16462 L
s
.51665 .16449 m
.52107 .1728 L
s
.51886 .16448 m
.52328 .1728 L
s
.47693 .17365 m
.48349 .17759 L
s
.57185 .17795 m
.57841 .17823 L
s
.56744 .17361 m
.57185 .17795 L
s
.47912 .17357 m
.48349 .17759 L
s
.56524 .17354 m
.57185 .17795 L
s
.49453 .17312 m
.49675 .16891 L
s
.4901 .17739 m
.49453 .17312 L
s
.48349 .17759 m
.4901 .17739 L
s
.53214 .177 m
.53657 .17288 L
s
.52107 .1728 m
.52771 .17697 L
s
.52328 .1728 m
.52771 .17697 L
s
.52771 .17697 m
.53214 .177 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54306 .11921 m
.54329 .20641 L
s
.54087 .11918 m
.54107 .20638 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5344 .2063 m
.54329 .20641 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ004@3o
YQ03000000<0ojH@1P00000N0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@D000001@3oYQ450:f][@<000004@2][Jd2
000000<0[Jf]00<000000:f][@2][Jd00P00000>0:f][@<000000P2][Jd?0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00@0k9H>0`2][Je[0;3PiP40oooo001o0;3PiP<0[Jf]1P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40603oYQ4800000080ojHA0P2][Jd50000
00P0[Jf]0`3oYQ4200000080ojHA00<0[Jf]0000000000003@3oYQ03000000D0ojH@00@000000?nV
4000000000000`3oYQ000`2][Jd0ojD@0?nU40060?nU408000000`3oYA02000000X0[Jf]00@00000
0:f][@2][Jd0[Jf]1@0000000`2][Jd0oj<@0?nS400E0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?ooo`00O02`h>H3
0:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA0100ojHA1@0000000`3oYQ40[Jf]0:f][@030:f][@8000001@2][Jd50?nV4@8000002P3oYQ42
000000<0ojHA00@0[Jf]0?nV403oYQ0000002`3oYQ000`000000ojH@000000060?nV40040000003o
YQ000000000000<0ojH@00<0[Jf]0?nU403oYA00103oYA02000000L0ojD@00<000000?nU403oYA00
1`3oYA001P000000ojD@0?nU40000000ojD@0:f][@<0oj<@00<000000:f][@2][Jd01`2][Jd00`00
0000oj<@0?nS400;0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00H0ojHA100000020?nV4@03
0:f][@000000000000<00000102][Jd40?nV4@030:f][@000000000000X0ojHA0P0000090?nV4@80
0000103oYQ401@2][Jd0ojH@0?nV403oYQ00000000X0ojH@0P0000080?nV40<000000`3oYQ000`2]
[Jd0ojD@0?nU40030?nU40800000203oYA000`000000ojD@0?nU40070?nU40030000003oYA000000
0080ojD@00D0[Jf]0?nS403oXa00oj<@000000080?nS408000002@2][Jd40?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H1
0?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV
4@030:f][@3oYQ40ojHA0080ojHA1@0000050:f][@@0ojHA0P0000080?nV4@030:f][@0000000000
00X0ojHA0P0000080?nV4@030000003oYQ40000000@0ojHA00D0[Jf]0?nV403oYQ00ojH@00000009
0?nV40030000003oYQ00000000P0ojH@0`0000030?nV40030:f][@3oYA00ojD@00<0ojD@0P000009
0?nU40030000003oYA00ojD@00H0ojD@0P0000030?nU40030:f][@3oXa00oj<@0080oj<@00<00000
0?nS403oXa001@3oXa000`000000oj<@000000080?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01@0ojHA1@0000030:f][@<0ojHA0P0000090?nV
4@800000203oYQ400`2][Jd000000000000:0?nV4@800000203oYQ42000000D0ojHA00<0[Jf]0?nV
403oYQ000P3oYQ000`000000ojH@0?nV40060?nV408000002P3oYQ02000000<0ojH@00<0[Jf]0?nU
403oYA000P3oYA02000000X0ojD@00<000000?nU403oYA001P3oYA02000000<0ojD@00<0[Jf]0?nS
403oXa000P3oXa000`000000oj<@0?nS40060?nS40800000303oXa000`2][Jd0o:0@0?bP40060:f]
[A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]G`2`h>H10?oo
o`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0;0?nV4@<0
00000P3oYQ400`2][Jd0000000000003000000030?nV4@2][Jd0@FWQ00H0ojHA0P0000090?nV4@80
0000203oYQ400`2][Jd000000000000:0?nV4@8000001`3oYQ400`000000ojHA000000050?nV4@03
0:f][@3oYQ00ojH@00<0ojH@00<000000?nV403oYQ001@3oYQ02000000X0ojH@0P0000030?nV4003
0:f][@3oYA00ojD@0080ojD@0P00000;0?nU40030000003oYA00ojD@00D0ojD@0P0000030?nU4003
0:f][@3oXa00oj<@00<0oj<@00<000000?nS403oXa001@3oXa02000000`0oj<@00<0[Jf]0?bP403l
X1001P3lX1050:f][@d0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P03
0:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00L0ojHA100000050:f][@@0ojHA
0P0000000`3oYQ40[Jf]0?nV4@060?nV4@8000002@3oYQ42000000P0ojHA00<0[Jf]000000000000
2P3oYQ42000000L0ojHA00<000000?nV4@0000001@3oYQ400`2][Jd0ojH@0?nV400;0?nV40800000
2P3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA000P3oYA02000001<0ojD@00<000000?nU403oYA00
0P3oYA000`2][Jd0oj<@0?nS40030?nS40030000003oXa00oj<@00H0oj<@00<000000?nS403oXa00
2P3oXa000`2][Jd0o:0@0?bP400;0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2]
[Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV
4@050?nV4@@0[Jf]0P0000090?nV4@80000000<0ojHA0:f][@3oYQ401P3oYQ42000000T0ojHA0P00
00080?nV4@030:f][@000000000000X0ojHA0P0000070?nV4@8000001P3oYQ400`2][Jd0ojH@0?nV
400;0?nV408000002P3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA000P3oYA02000001<0ojD@00<0
00000?nU403oYA000P3oYA000`2][Jd0oj<@0?nS40030?nS40030000003oXa00oj<@01<0oj<@00<0
[Jf]0?bP403lX100403lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100
kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030000003oYQ40
ojHA00D0[Jf]103oYQ42000000T0ojHA0P0000000`3oYQ40[Jf]0?nV4@060?nV4@8000002@3oYQ42
000000P0ojHA00<0[Jf]0000000000002P3oYQ42000000H0ojHA00<000000?nV4@0000001P3oYQ40
0`2][Jd0ojH@0?nV400:0?nV408000002`3oYQ02000000<0ojH@00@0[Jf]0?nU403oYA00ojD@0P00
000D0?nU40030000003oYA00ojD@0080ojD@00<0[Jf]0?nS403oXa000`3oXa000`000000oj<@0?nS
400C0?nS40030:f][@3lX100o:0@01H0o:0@102][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404P3oY142000000030:f][@000000000000T0ojHA0P000009
0?nV4@80000000<0ojHA0:f][@3oYQ401P3oYQ42000000T0ojHA0P0000080?nV4@030:f][@000000
000000X0ojHA0P0000060?nV4@030000003oYQ40000000H0ojHA00<0[Jf]0?nV403oYQ002P3oYQ02
000000/0ojH@0P0000030?nV40040:f][@3oYA00ojD@0?nU408000006@3oYA000`2][Jd0oj<@0?nS
40030?nS40030000003oXa00oj<@01<0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0:f]
[@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`
h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0?
0?nT4@80[Jf]00@000000:f][@3oY140[Jf]0P3oYQ400`000000ojHA0?nV4@060?nV4@8000002@3o
YQ42000000030?nV4@2][Jd0ojHA00H0ojHA0P0000090?nV4@8000001`3oYQ40102][Jd0ojHA0000
0000000:0?nV4@8000001P3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ002P3oYQ02000000/0ojH@
0P0000030?nV40040:f][@3oYA00ojD@0?nU408000006@3oYA000`2][Jd0oj<@0?nS40020?nS4080
00005@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0/>3V
0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@030?nT
4@00000000000080oj@A00@0[Jf]0?nV4@3oYQ400000203oYQ42000000T0ojHA0P0000000`3oYQ40
[Jf]0?nV4@060?nV4@8000002@3oYQ42000000L0ojHA00@0[Jf]0?nV4@00000000002P3oYQ420000
00H0ojHA0P0000070?nV4@030:f][@3oYQ00ojH@00X0ojH@0P00000;0?nV408000000`3oYQ00102]
[Jd0ojD@0?nU403oYA02000001T0ojD@00<0[Jf]0?nS403oXa000P3oXa02000001D0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0?
0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY1420000
0080oj@A102][Jd50?nT4@8000000P3oY140102][Jd0ojHA0?nV4@0000080?nV4@8000002@3oYQ42
000000030?nV4@2][Jd0ojHA00H0ojHA0P0000090?nV4@8000001`3oYQ40102][Jd0ojHA00000000
000:0?nV4@8000001P3oYQ42000000L0ojHA00<0[Jf]0?nV403oYQ002P3oYQ02000000/0ojH@0P00
00030?nV40040:f][@3oYA00ojD@0?nU408000006@3oYA00102][Jd0oj<@0?nS403oXa02000001H0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0[Jf]1@3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]
3@3_V1000`2][Jd0o:0@0?bP400?0?bP40040:f][@3oY140oj@A0?nT4@800000102][Jd80?nT4@80
00000`3oY1401@2][Jd0ojHA0?nV4@3oYQ40000000L0ojHA0P0000090?nV4@80000000<0ojHA0:f]
[@3oYQ401P3oYQ42000000T0ojHA0P0000070?nV4@040:f][@3oYQ400000000000X0ojHA0P000006
0?nV4@8000001`3oYQ400`2][Jd0ojH@0?nV400:0?nV408000002`3oYQ02000000<0ojH@00@0[Jf]
0?nU403oYA00ojD@0P00000I0?nU40060:f][@3oXa00oj<@0000003oXa0000005`3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>
0:f][@0=0>nH40030:f][@3lX100o:0@00l0o:0@1P00000<0?nT4@8000000`3oY1401@2][Jd0ojHA
0?nV4@3oYQ40000000L0ojHA0P0000090?nV4@80000000<0ojHA0:f][@3oYQ401P3oYQ42000000T0
ojHA0P0000070?nV4@040:f][@3oYQ400000000000X0ojHA0P0000060?nV4@8000001`3oYQ400`2]
[Jd0ojH@0?nV400:0?nV408000002`3oYQ02000000<0ojH@00@0[Jf]0?nU403oYA00ojD@0P00000I
0?nU40050:f][@00000000000?nS40000000603oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]
C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00d0o:0@
0P0000020:f][@80oj@A0P00000;0?nT4@800000103oY1400`2][Jd0ojHA0?nV4@090?nV4@800000
2@3oYQ4010000000ojHA0?nV4@2][Jd70?nV4@8000002@3oYQ42000000L0ojHA00@0[Jf]0?nV4@00
000000002P3oYQ42000000H0ojHA400000060?nV408000002`3oYQ02000000<0ojH@00@0[Jf]0?nU
403oYA00ojD@2000000B0?nU408000000P3oXa000`000000oj<@0?nS400G0?nS40030:f][@3lX100
o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]
0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00/0o:0@10000000102][Jd0oj@A0?nT
4@3oY142000000/0oj@A0P0000040?nT4@030:f][@3oYQ40ojHA00T0ojHA0P0000080?nV4@800000
0P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000203oYQ42000000P0ojHA00@0[Jf]0?nV4@000000
00002P3oYQ42000000H0ojHA0P0000070?nV4@070:f][@3oYQ00ojH@0?nV40000000ojH@00000006
0?nV408000002`3oYQ02000000<0ojH@00@0[Jf]0?nU403oYA00ojD@0P0000060?nU40L000002P3o
YA000`000000ojD@0:f][@02000000`0oj<@00<000000?nS403oXa002`3oXa000`2][Jd0o:0@0?bP
400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]C02`h>H10?ooo`00HP2`h>H0
0`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX100
0`000000o:0@0:f][@020:f][@040?bP4000000000000:f][@<0oj@A0P00000;0?nT4@800000103o
Y1400`2][Jd0ojHA0?nV4@090?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103o
YQ42000000T0ojHA0P0000080?nV4@040:f][@3oYQ400000000000X0ojHA0P0000060?nV4@800000
2`2][Jd2000000L0[Jf]0P00000;0:f][@8000001`2][Jd200000080[Jf]2@3oYA02000000T0ojD@
00@000000?nU4000000000003P3oXa000`000000oj<@0?nS400;0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00
H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
103lX10300000080[Jf]103lX102000000040:f][@3oY140oj@A0?nT4@8000002`3oY142000000<0
oj@A00<0[Jf]0?nV4@3oYQ402P3oYQ42000000P0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00@0
ojHA0P0000090?nV4@800000203oYQ40102][Jd0ojHA0000000000040?nV4@H0[Jf]0P0000060:f]
[@8000001`3oYQ40102][Jd0ojH@0?nV403oYQ02000000L0ojH@0P00000;0?nV408000000`3oYQ00
102][Jd0ojD@0?nU403oYA0200000080ojD@2@2][Jd2000000D0[Jf]0`3oYA001@000000ojD@0000
003oYA00[Jf]00h0oj<@00<000000?nS403oXa002`3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f]
[@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0
[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00<0o:0@0P00
00020:f][@D0o:0@0P0000000`3lX100[Jf]0?nT4@020?nT4@8000002P3oY142000000@0oj@A00<0
[Jf]0?nV4@3oYQ402P3oYQ42000000P0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00
00090?nV4@800000103oYQ460:f][@800000102][Jd60?nV4@8000001`3oYQ42000000H0ojHA00@0
[Jf]0?nV403oYQ00ojH@0P0000080?nV408000002P3oYQ02000000<0ojH@00<0[Jf]0?nU403oYA00
0P3oYA02000000X0ojD@0P0000050?nU4080[Jf]00<000000:f][@0000001`2][Jd:0?nS40030000
003oXa00oj<@00/0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0dhL>00<0
[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX1030:f][@030000003lX100o:0@00D0o:0@
0P0000000`3lX100[Jf]0?nT4@020?nT4@8000002P3oY142000000@0oj@A00<0[Jf]0?nV4@3oYQ40
2P3oYQ42000000P0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00@0ojHA0P0000060?nV4@<0[Jf]
0P0000040:f][@@0ojHA00@0[Jf]0?nV4@00000000002P3oYQ42000000L0ojHA0P0000060?nV4@04
0:f][@3oYQ00ojH@0?nV40800000203oYQ02000000X0ojH@0P0000030?nV40030:f][@3oYA00ojD@
0080ojD@0P00000:0?nU408000001`3oYA02000000<0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f]
[@030000003oXa00oj<@00/0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL
3`030:f][@3/UPh0k9H>00`0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;
00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>73P060=>73P03
0:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP402][Jd0[Jf]0`3lX1000`000000o:0@0?bP40050?bP
4080000000<0o:0@0:f][@3oY1400P3oY142000000X0oj@A0P0000040?nT4@030:f][@3oYQ40ojHA
00X0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@80[Jf]0P0000060:f]
[@<0ojHA0P0000080?nV4@040:f][@3oYQ400000000000X0ojHA0P0000070?nV4@8000001P3oYQ40
1@2][Jd0ojH@0?nV403oYQ00000000T0ojH@0P00000:0?nV40030000003oYQ0000000080ojH@00<0
[Jf]0?nU403oYA000P3oYA02000000X0ojD@0P0000070?nU40030000003oYA00ojD@0080ojD@00<0
[Jf]0?nS403oXa000`3oXa000`000000oj<@0?nS40060?nS40030000002][Jd0[Jf]00L0[Jf]103o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd8
0=>73P030:f][@3_V100kiP@00/0kiP@0P2][Jd50?bP40030000003lX100o:0@00D0o:0@0P000000
0`3lX100[Jf]0?nT4@020?nT4@8000002P3oY142000000@0oj@A00<0[Jf]0?nV4@3oYQ402P3oYQ42
000000P0ojHA0P0000070:f][@80ojHA0P0000090?nV4@800000203oYQ40102][Jd0ojHA00000000
000:0?nV4@800000203oYQ42000000D0ojHA00D0[Jf]0?nV403oYQ00ojH@000000090?nV40030000
003oYQ00000000P0ojH@0P0000001@3oYQ0000000?nV403oYQ00[Jf]00@0ojD@00<000000?nU4000
00002@3oYA000`000000ojD@0?nU40060?nU40030000003oYA00ojD@0080ojD@00<0[Jf]0?nS403o
Xa000`3oXa000`000000oj<@0?nS40060?nS40030000003oXa00oj<@00L0oj<@202][JdF0?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][@/0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@
0`2][Jd60?bP40030000003lX100o:0@00D0o:0@0P0000000`3lX100[Jf]0?nT4@020?nT4@800000
2P3oY142000000@0oj@A00<0[Jf]0?nV4@3oYQ402P3oYQ42000000@0ojHA102][Jd200000080ojHA
00<0[Jf]045Yh@3oYQ40103oYQ42000000T0ojHA0P0000080?nV4@040:f][@3oYQ400000000000X0
ojHA0P0000080?nV4@8000001@3oYQ400`2][Jd0ojH@0?nV4002000000X0ojH@0P0000080?nV4080
000000D0ojH@0000003oYQ00ojH@0:f][@050?nU408000002@3oYA000`000000ojD@0?nU40060?nU
40030000003oYA00ojD@0080ojD@00<0[Jf]0?nS403oXa000P3oXa02000000P0oj<@00<000000?nS
403oXa002`3oXa00102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2]
[Jd0kiP@0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP40050?bP40030000003lX100o:0@
00@0o:0@0P0000000`3lX100[Jf]0?nT4@020?nT4@8000002P3oY142000000@0oj@A00<0[Jf]0?nV
4@3oYQ402P3oYQ42000000@0[Jf]103oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103oYQ420000
00T0ojHA0P0000080?nV4@040:f][@3oYQ400000000000T0ojHA0P00000:0?nV4@800000103oYQ40
102][Jd0ojH@0?nV4000000;0?nV40030000003oYQ00000000H0ojH@00D000000?nV40000000ojH@
000000020?nV40030:f][@3oYA00ojD@00<0ojD@00<000000?nU400000001`3oYA02000000P0ojD@
00<000000?nU403oYA000P3oYA000`2][Jd0oj<@0?nS40020?nS40800000203oXa000`000000oj<@
0?nS400;0?nS40030:f][@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]1`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]
203CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP40050?bP40030000
003lX100o:0@00@0o:0@0P0000000`3lX100[Jf]0?nT4@020?nT4@8000002P3oY142000000@0oj@A
00<0[Jf]0?nV4@3oYQ401P3oYQ440:f][@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40
103oYQ42000000T0ojHA0P0000080?nV4@050:f][@00000000000?nV4@000000203oYQ42000000/0
ojHA0P0000030?nV4@040:f][@3oYQ00ojH@000000`0ojH@00<000000?nV400000001@3oYQ001@00
0000ojH@0000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA00103oYA000`000000ojD@00000006
0?nU40030000003oYA00ojD@00L0ojD@00<000000?nU403oYA000P3oYA000`2][Jd0oj<@0?nS4002
0?nS40800000203oXa000`000000oj<@0?nS400;0?nS40030:f][@3lX100o:0@00h0o:0@1P2][Jd3
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@04
0=^:3@030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2]
[Je50;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_
V1000`2][Jd0kiP@0>nH40040>nH40030:f][@3lX100o:0@00D0o:0@00<000000?bP403lX100103l
X10010000000o:0@0?bP402][Jd30?nT4@8000002P3oY142000000@0oj@A00D0[Jf]0?nV4@3oYQ40
[Jf]000000040:f][@@0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@80
00002@3oYQ43000000L0ojHA00D0[Jf]000000000000ojHA000000080?nV4@800000303oYQ420000
0080ojHA00<0[Jf]0?nV400000003P3oYQ03000000<0ojH@00H000000?nV403oYQ0000000?nV4000
00020?nV40030:f][@3oYA00ojD@00D0ojD@00<000000?nU400000001@3oYA000`000000ojD@0?nU
40080?nU40050000003oYA00ojD@0?nU402][Jd00`3oXa02000000030?nS40000000oj<@00H0oj<@
00<000000?nS403oXa002`3oXa000`2][Jd0o:0@0?bP400D0?bP40D0[Jf]5@3fW0l00`2][Jd0k9H>
0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd40=^:3@030:f][@2iM@/0^GD;00L0^GD;
00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP40050?bP4003
0000003lX100o:0@00<0o:0@0P0000020?bP40030:f][@3oY140oj@A008000002`3oY142000000<0
oj@A102][Jd2000000P0ojHA0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@80
00002@3oYQ43000000L0ojHA00<0[Jf]0000000000000P3oYQ42000000@0ojHA0`00000?0?nV4@@0
00004@3oYQ04000000<0ojH@00<000000?nV400000000P3oYQ000`2][Jd0ojD@0?nU40060?nU4080
0000103oYA000`000000ojD@0?nU400:0?nU40040000003oYA00ojD@0:f][@<0oj<@00@000000?nS
4000000000001`3oXa000`000000oj<@0?nS400;0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd2
0:f][@80fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3o
ool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080[Jf]2@3_
V1000`2][Jd0o:0@0?bP40050?bP40040000003lX100o:0@0?bP40@000000P3lX1000`2][Jd0oj@A
0?nT4@02000000/0oj@A0P0000030:f][@070?nT4@2][Jd0ojHA0?nV4@000000ojHA000000070?nV
4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P0000000`3o
YQ400000000000050?nV4@8000001@3oYQ45000001<0ojHA00<0[Jf]0?nV403oYQ005`3oYQ000`00
0000ojH@000000020?nV40030:f][@3oYA00ojD@00P0ojD@1000000=0?nU40040000003oYA00ojD@
0:f][@80oj<@00<000000?nS403oXa000P0000060?nS408000003@3oXa000`2][Jd0o:0@0?bP400G
0?bP40030:f][@3fW0l0mY`?00<0mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]
0=^:3@3KRPd02@3KRPd30:f][@T0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP11
0;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f]
[@/0kiP@00<0[Jf]0?bP403lX1001@3lX10010000000o:0@0000000000020?bP408000000P3lX100
0`2][Jd0oj@A0?nT4@03000000L0oj@A0`2][Jd2000000@0oj@A00H0[Jf]0?nV4@3oYQ4000000?nV
4@0000070?nV4@8000001`3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA
0P0000030?nV4@D0000000<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400G0?nV40030000
003oYQ0000000080ojH@00<0[Jf]0?nU403oYA006P3oYA05000000@0oj<@00<000000?nS403oXa00
103oXa03000000`0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]
2@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100
1@3lX102000000@0o:0@0P0000020?bP40030:f][@3oY140oj@A00<00000103oY1430:f][@<0oj@A
0P0000040?nT4@040:f][@3oYQ40ojHA0?nV4@8000001`3oYQ400`000000ojHA000000060?nV4@80
00000`3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000001P3oYQ45000000P0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400G0?nV40030000003oYQ0000000080ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400;0?nS40<00000303oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?00/0mY`?102][Jd50?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd20:f][@80^GD;00<000000;Ue2`2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`03
0:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80
[Jf]303_V1000`2][Jd0o:0@0?bP40060?bP40030000003lX100o:0@00<0o:0@0P0000020?bP4003
0:f][@3oY140oj@A00<00000102][Jd60?nT4@800000103oY1401@2][Jd0ojHA0?nV4@3oYQ400000
00P0ojHA00<000000?nV4@0000001P3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ420000
01<0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400G0?nV40030000003oYQ000000
0080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS40<00000303oXa000`2]
[Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00H0[Jf]0;Ue2`2][Jd0[Jf]0;Ue2`0000040;Ue2`030:f][@28
EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00H0dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400;0>nH40030:f][@3lX100o:0@00H0o:0@00<0
00000?bP403lX1000`3lX10200000080o:0@00<0[Jf]0?nT4@2][Jd00`00000:0?nT4@800000103o
Y1401@2][Jd0ojHA0?nV4@3oYQ40000000P0ojHA00@000000?nV4@3oYQ400000103oYQ42000000<0
ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ43000001D0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400G0?nV40030000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400;0?nS40<00000303oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01<0
mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@020000
00<0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP05
0:f][@2GH0/0Uf0;09MP2`2][Jd01@3CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00`0kiP@00<0[Jf]
0?bP403lX1001P3lX1000`000000o:0@0?bP40030?bP40030000003lX100o:0@00<0[Jf]00@0oj@A
00000000000000001@3oY1400`000000oj@A0?nT4@020?nT4@030000003oY140000000<0oj@A00@0
[Jf]0?nV4@3oYQ4000002@3oYQ4010000000ojHA0?nV4@3oYQ44000000D0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01L0ojH@00<000000?nV4000
00000P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@0`00000<0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@h0
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030000002iM@/000000080
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0
Uf0;0:f][@040=>73P030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0
o:0@0?bP40070?bP40040000003lX100o:0@0?bP408000000P2][Jd0103lX100[Jf]0?nT4@3oY143
000000D0oj@A00<000000?nT4@3oY1400`3oY142000000<0oj@A00@0[Jf]0?nV4@3oYQ4000002@3o
YQ400`000000ojHA0?nV4@0:0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400G0?nV40030000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400;0?nS40<00000303oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`020;Ue2`030000002][Jd0^GD;0080000000<0[Jf]08QF1`28EPL00P28
EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P030:f][@3C
Q`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP40070?bP40040000003l
X100o:0@0:f][@8000000`3lX1000`2][Jd0oj@A0?nT4@03000000@0oj@A0P0000050?nT4@030000
003oY14000000080oj@A00<0[Jf]0?nV4@0000002P3oYQ400`000000ojHA0?nV4@0:0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400G0?nV40030000
003oYQ0000000080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS40<00000
303oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
103/UPh30:f][@T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`060000
002iM@/0[Jf]0:f][@000000[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP2`2G
H0/0Uf0;0:f][@3CQ`h20:f][@H0dhL>00<0[Jf]0>nH403_V1002P3_V1000`2][Jd0o:0@0?bP4007
0?bP40040000002][Jd0[Jf]0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@02000000030?nT4@00
0000oj@A0080oj@A0P0000060?nT4@<0000000@0oj@A0:f][@3oYQ4000002P3oYQ400`000000ojHA
0?nV4@0:0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4Q0:f][@030000
002][Jd0000000X0[Jf]5`3oYA000`2][Jd0oj<@0?nS400;0?nS40<00000303oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f][@H0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`060000002iM@/0^GD;0;Ue2`00
0000[Jf]1028EPL20:f][D80/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>7
3P030:f][@3_V100kiP@00X0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@040000003lX100o:0@
0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@02000000030?nT4@000000oj@A00<0oj@A00<00000
0?nT4@3oY1401P3oY144000000/0ojHA00<000000?nV4@3oYQ402P3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@3oYQ00ojH@01L0ojH@00<00000
0?nV400000000P3oYQ000`2][Jd0ojD@0?nU40050?nU4100[Jf]1`3oYA000`2][Jd0oj<@0?nS400;
0?nS40<00000303oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]
0>bF3P3/UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`02
0;Ue2`060000002iM@/0^GD;0;Ue2`000000[Jf]1@28EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo
001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH400:0>nH40030:f]
[@3lX100o:0@0080o:0@0P2][Jd30?bP40040000003lX100o:0@0?bP408000000`3lX1000`2][Jd0
oj@A0?nT4@0200000080oj@A00D000000?nT4@3oY140oj@A0000000:0?nT4@030:f][@3oYQ40ojHA
00X0ojHA00<000000?nV4@3oYQ402P3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5`3oYQ400`2]
[Jd0ojH@0?nV400G0?nV40030000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA005@3oYA0<0:f]
[@T0oj<@0`00000<0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0
000000<0^GD;00<000000:f][@2][Jd01028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3P
iP030:f][@2GH0/0Uf0;0080[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]
0080[Jf]1@3lX10010000000o:0@0?bP403lX102000000<0o:0@00<0[Jf]0?nT4@3oY1400P000002
0?nT4@030000003oY140oj@A008000002P3oY1400`2][Jd0ojHA0?nV4@0:0?nV4@030000003oYQ40
ojHA00X0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400G0?nV40030000003oYQ0000000080ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS40020?nS40T0[Jf]0`00000<0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P<0[Jf]3@3KRPd01@2][Jd0^GD;0;Ue2`2i
M@/0000000<0^GD;00D000000:f][@2][Jd0R5H70000000208QF1`030:f][@2`h>H0/>3V0400/>3V
0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@0P2]
[Jd80?bP40040000003lX100o:0@0?bP408000000`3lX1000`2][Jd0oj@A0?nT4@02000000<0oj@A
0P00000<0?nT4@030:f][@3oYQ40ojHA00X0ojHA00<000000?nV4@3oYQ402P3oYQ400`2][Jd0ojHA
0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01L0ojH@
00<000000?nV400000000P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@
0`0000080:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0[Jf]2`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/00000
00<0^GD;00<000000:f][@28EPL00P00000208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0
/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_V100kiP@00T0kiP@0`2][Jd90?bP
40030000003lX100o:0@00800000103lX1000`2][Jd0oj@A0?nT4@0200000140oj@A00<0[Jf]0?nV
4@3oYQ402P3oYQ400`000000ojHA0?nV4@070?nV4@P0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01L0ojH@00<000000?nV400000000P3oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@00/0oj<@00<000000?nS40000000203oXa080:f][AL0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=0=^:3@80[Jf]2@3KRPd0
1@2][Jd0^GD;0;Ue2`2iM@/0000000@0^GD;00@0000008QF1`000000[Jf]0P0000000`2][Jd0/>3V
0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@
0>nH40070>nH4080[Jf]0P3_V1000`2][Jd0o:0@0?bP40070?bP40030000003lX100o:0@00800000
0`3lX100102][Jd0oj@A00000000000C0?nT4@030:f][@3oYQ40ojHA00X0ojHA00@000000?nV4@3o
YQ40ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA00D0ojHA00<000000?nV4@3oYQ404P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01@0ojH@1P0000020?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa002`3oXa000`000000oj<@0000000<0?nS40040:f][@3lX100o:0@
0?bP40L0[Jf]403lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0P0000030;Ue2`0400000028
EPL0000008QF1`80000000<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H20:f][@80Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]103_V1000`2][Jd0o:0@0?bP
40070?bP40030000003lX100o:0@008000000`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA00L0ojHA0`2][Jd010000000[Jf]0:f][@2][Jd90?nV4@030:f][@3oYQ40ojHA00@0ojHA
00<000000?nV4@0000004`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40030000003oXa00oj<@00/0oj<@
00<0[Jf]0?bP403lX100203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=0P2][Jd50=^:3@040:f][@2iM@/0^GD;0;Ue2`80
00000`2iM@/010000000R5H700000028EPL2000000030:f][@2`h>H0/>3V0400/>3V0@3oool005T0
/>3V0P2][Jd209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1000`3_V1020:f][@H0
kiP@00<0[Jf]0?bP403lX100203lX10010000000o:0@0000000000030?bP40030:f][@3oY140oj@A
01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd30?nV4@030000003oYQ40ojHA00X0ojHA00<0[Jf]
0?nV4@3oYQ40103oYQ400`000000ojHA0000000C0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@00<00000
0?nS403oXa002`3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00@0[Jf]
0;Ue2`2iM@/0^GD;0P0000030;Ue2`0400000028EPL0000008QF1`80000000<0[Jf]0;3PiP2`h>H0
@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@0[Jf]0>nH403_V100
kiP@0P2][Jd80>nH40030:f][@3lX100o:0@00P0o:0@00@000000?bP4000000000000`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@D0[Jf]2@3oYQ400`000000ojHA0?nV4@0:0?nV4@030:f][@3oYQ40ojHA
00@0ojHA0P00000D0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@00<000000?nS403oXa002`3oXa000`2]
[Jd0o:0@0?bP400E0?bP40H0[Jf]503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@11JN40fhX=
00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`020;Ue2`8000000`2iM@/010000000@FWQ00000028EPL2
000000030:f][@000000/>3V0400/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>
00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2P3_V1000`2][Jd0o:0@0?bP40080?bP40040000003lX100
0000000000<0o:0@00<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA00/0ojHA00<0
00000?nV4@3oYQ402P3oYQ400`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40ojHA0180ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0[Jf]403f
W0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd30;Ue2`80000000L0
^GD;0000002iM@/000000:f][@000000R5H700@00000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;
00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f][@`0kiP@00<0[Jf]0?bP403lX100203lX10010000000o:0@
0000000000030?bP40030:f][@3oY140oj@A00/0oj@A102][Jd50?nT4@030:f][@3oYQ40ojHA00X0
ojHA00<000000?nV4@3oYQ402P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2][Jd20;Ue2`80000000L0^GD;0000002i
M@/0^GD;0:f][@000000R5H700@00000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>7
3P3CQ`h01@3CQ`h20:f][@d0kiP@00<0[Jf]0?bP403lX100203lX1000`000000o:0@000000040?bP
40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA00X0ojHA00<000000?nV
4@3oYQ402P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP
403lX100603lX1000`2][Jd0mY`?0?JL3`090?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`2][Jd0[Jf]0P0000001P2iM@/000000;Ue2`2i
M@/0[Jf]00000080R5H70`0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>7
3P040=>73P030:f][@3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX100203lX103000000@0o:0@00<0
[Jf]0?nT4@3oY1400`3oY1440:f][@d0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ44000000`0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l03P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@040:f][@2iM@/0^GD;0;Ue2`80000000H0^GD;0000002iM@/0^GD;0:f][@00000208QF
1`@00000@02`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h0102][Jd0
dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00P0o:0@0`0000040?bP40030:f][@3oY140[Jf]
00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?102][JdA0>bF
3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0P0000001P2iM@/000000;Ue2`2i
M@/0[Jf]00000080R5H7100000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>7
3P3CQ`h20:f][@<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40080?bP40<00000
0`3lX1030:f][AD0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0;Ue2`80
000000H0[Jf]0000002iM@/0^GD;0:f][@00000208QF1`80000000<0[Jf]0000002`h>H0?`2`h>H1
0?ooo`00F02`h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00P0o:0@0`0000001@3lX100[Jf]0:f][@3lX100[Jf]01H0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2]
[Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/01`000000^GD;0000
002][Jd0^GD;0:f][@0000000P28EPL2000000030:f][@000000/>3V03l0/>3V0@3oool005L0/>3V
00<000000:f][@2][Jd00`2GH0/00`2][Jd0dhL>0:f][@060=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX100203lX10010000000[Jf]0000002][Jd30?bP40030:f][@3oY140oj@A01@0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0
k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/300000004
0;Ue2`2][Jd0[Jf]00000080R5H70P0000000`2][Jd000000;3PiP0o0;3PiP40oooo001G0;3PiP03
0000002][Jd0[Jf]00<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1001`3lX1020:f][@800000103lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;00<000000;Ue2`0000000P2iM@/0102][Jd0
R5H700000028EPL2000000030:f][@000000/>3V03l0/>3V0@3oool005L0/>3V00<000000:f][@2G
H0/00`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X100103lX1030:f][@80o:0@00<000000?bP403lX1000`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0
[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;0080^GD;00D000000;Ue2`2iM@/000000;Ue2`020:f][@0600000028EPL00000
0000002][Jd00000@02`h>H10?ooo`00E`2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]1`3CQ`h0
0`2][Jd0kiP@0>nH400<0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]1@3lX1000`000000o:0@0?bP
40030?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0<0>bF3P<0[Jf]00<0k9H>0:f][@3KRPd03@3KRPd01@2][Jd0^GD;0;Ue2`2iM@/000000080^GD;
00H000000;Ue2`2][Jd0[Jf]00000028EPL2000000030:f][@000000/>3V03l0/>3V0@3oool005L0
/>3V00<000000:f][@2GH0/00P2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V100303_V100102][Jd0
o:0@0:f][@2][Jd80?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f]
[@d0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;000000020;Ue2`060000002iM@/0[Jf]08QF1`000000R5H7
100000100;3PiP40oooo001G0;3PiP070000002][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@070=>73P03
0:f][@3_V100kiP@00/0kiP@0`2][Jd:0?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?nT4@3o
Y1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0
[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh0403/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@050:f][@2iM@/0^GD;0;Ue2`0000000P2iM@/0
1P000000^GD;0:f][@28EPL0000008QF1`@00000@02`h>H10?ooo`00E`2`h>H010000000[Jf]09MP
2`2][Jd209MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1002@3_V1020:f][@030>nH
402][Jd0o:0@0100o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f]
[@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@050:f][@2iM@/0^GD;0;Ue
2`0000000P2iM@/01P000000^GD;0:f][@28EPL000000:f][@@00000@02`h>H10?ooo`00E`2`h>H0
10000000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1001`3_
V1020:f][@<0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/
UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;
000000020;Ue2`060000002iM@/0[Jf]08QF1`000000R5H7100000100;3PiP40oooo001G0;3PiP03
0000002][Jd0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080
[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3KRPd01@2][Jd0^GD;0;Ue2`2iM@/00000
0080^GD;00L000000;Ue2`2][Jd0R5H700000028EPL0[Jf]00<00000@02`h>H10?ooo`00E`2`h>H0
0`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V1000`3_V102
0:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0P00
00001P2iM@/000000;Ue2`2][Jd0R5H700000080R5H70`0000100;3PiP40oooo001G0;3PiP030000
002][Jd0Uf0;00<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@T0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV
4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=00T0fhX=0P2][Jd00`3KRPd0[Jf]0;Ue2`020;Ue2`8000000`2iM@/30000
0080R5H70`0000100;3PiP40oooo001G0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h0102][Jd0kiP@0:f][@2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd20:f][@<0^GD;0P0000030;Ue2`030000002][Jd000000080R5H70`0000100;3P
iP40oooo001F0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P80[Jf]3@3_V1000`2]
[Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd00`2iM@/00000000000030;Ue
2`030000002][Jd0R5H70080R5H70`0000100;3PiP40oooo001F0;3PiP80000000D0[Jf]09MP2`2G
H0/0Uf0;0:f][@070=>73P80[Jf]3P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A
00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
00`0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]0P0000030;Ue2`040000002][Jd0R5H708QF1`D00000?`2`
h>H10?ooo`00EP2`h>H00`000000[Jf]0:f][@0309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd0
0`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY145
0:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
102][Jd0^GD;0;Ue2`2iM@/2000000<0^GD;00<000000:f][@28EPL00P28EPL4000003l0/>3V0@3o
ool005H0/>3V00<000000:f][@2][Jd00`2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0
dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`
h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2i
M@/0^GD;0;Ue2`80000000D0[Jf]0;Ue2`2iM@/000000:f][@0308QF1`040:f][@00000000000000
03l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]
00@0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f]
[A40k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0102][Jd0^GD;0;Ue2`2iM@/2000000050;Ue2`2][Jd0
^GD;0000002][Jd00`28EPL0102][Jd0000000000000000o0;3PiP40oooo001F0;3PiP030000002]
[Jd0[Jf]00<0Uf0;00@0[Jf]0=>73P2][Jd0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f]
[@2iM@/0^GD;0;Ue2`8000000P2iM@/00`2][Jd000000:f][@0308QF1`040:f][@11JN4000000000
03l0/>3V0@3oool005H0/>3V00<000000:f][@2][Jd00`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0
[Jf]0:f][@2][Jd;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`0000030;Ue
2`030000002][Jd0R5H700<0R5H700<0[Jf]000000000000?`2`h>H10?ooo`00EP2`h>H00`000000
[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0
o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0;Ue2`8000000`2iM@/00`000000[Jf]0:f][@0308QF
1`030:f][@000000000003l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@P0
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i
/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@03
0:f][@2iM@/0^GD;00<0^GD;00@000000;Ue2`2iM@/000000P2][Jd308QF1`030:f][@0000000000
03l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0
[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0
[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;00@0^GD;0`0000000`2][Jd0R5H70:f][@0208QF1`03
0:f][@000000000003l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]
00P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;Vb
YP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/01000
0000[Jf]08QF1`2][Jd208QF1`030:f][@000000000003l0/>3V0@3oool005D0/>3V0P0000000`2]
[Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f]
[@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f]
[@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL0R5H70:f][@28EPL0[Jf]0P00000o0;3PiP40oooo001E
0;3PiP80000000<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100
kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`4
0:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP2
0:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`
h>H10?ooo`00E@2`h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100
kiP@00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`4
0:f][LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP4
0:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@800000?`2`
h>H10?ooo`00E@2`h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100
kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3P
iP0m0;3PiP40oooo001E0;3PiP80000000<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P06
0=>73P040:f][@3_V100kiP@0>nH4080[Jf]00D0@FWQ0:BNS`2TWXl0Y9j?0:f][@040;6[W@80[Jf]
1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
1@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40
oooo001E0;3PiP80000000D0[Jf]09MP2`2GH0/0Uf0;0:f][@090=>73P050:f][@3_V100[Jf]0:f]
[@11JN400P2TWXl01011JN40Y9j?0:BNS`2][Jd60;6[W@80[Jf]1@2aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@31^[060:f][JT0/>3V1@2][Jd=
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n
^KP20:f][@L0_[Vh0`11JN420;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102][Jd0R5H708QF
1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00T0dhL>0P2][Jd00`2TWXl0@FWQ0:BNS`020:BNS`05045Yh@2TWXl0Y9j?0:f][@11
JN401`2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]1`2n^KP2045Yh@030;ji^02][Jd0@FWQ
00<0];2a00<0@FWQ0:f][@2][Jd02P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0
/>3V03d0/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P060=>7
3P050:f][@11JN40Y9j?0:BNS`11JN400`2TWXl2045Yh@030:BNS`2][Jd0/J^M0080@FWQ1`2aZid2
0:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@
0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd70;ji^0<0@FWQ0P2n^KP00`2][Jd0@FWQ045Yh@02
0;B`/@80@FWQ00<0];2a0:f][@2][Jd0202iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`
h>H0/>3V03d0/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/00`2][Jd0dhL>0=>73P04
0=>73P80[Jf]00D0Y9j?045Yh@2TWXl0Y9j?045Yh@030:BNS`80@FWQ00<0Y9j?0:f][@2aZid00`11
JN480;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0
[Jf]0<>m/`33_K<0`kfc1`2][Jf70;3PiPH0[Jf]1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/30:f][@030<>m^`2][Jd0_[Vh00T0_[Vh
00H0@FWQ0;ji^02n^KP0[Jf]0;B`/@11JN420;B`/@80@FWQ0`2d/;400`2][Jd0^GD;0;Ue2`050;Ue
2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E@2`h>H00`00
0000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd3045Yh@80Y9j?00@0@FWQ0:BN
S`2TWXl0Y9j?0P11JN400`2][Jd0/J^M0;6[W@02045Yh@80/J^M0`11JN450;6[W@030:f][@2i/ZH0
[Jf]00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<02033_K<80:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^008
0;ji^006045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ0P2d/;42045Yh@@0];2a0P2][Jd50;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E@2`h>H00`000000/>3V
0:f][@0309MP2`030:f][@3CQ`h0dhL>0080dhL>00@0[Jf]045Yh@2:QGD0[Jf]0P11JN420:BNS`04
045Yh@2TWXl0Y9j?0:BNS`80@FWQ00<0[Jf]0;6[W@2aZid00P11JN440;6[W@<0@FWQ0`2aZid00`2]
[Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2]
[Jd0_[Vh0;ji^0080;ji^006045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ0P2d/;42045Yh@<0];2a0P2]
[Jd00`11JN40[Jf]0:f][@030;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0
?@2`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`060:f][@3CQ`h0dhL>0=>73P2][Jd0
RXEe0P11JN400`2][Jd0@FWQ045Yh@020:BNS`03045Yh@2TWXl0Y9j?0080Y9j?00@0@FWQ0:f][@2a
Zid0/J^M0P11JN440;6[W@04045Yh@2aZid0/J^M0;6[W@80@FWQ00<0[Jf]0;VbYP2i/ZH01P2i/ZH3
0:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0
b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^0080;ji^006045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ
0`2d/;401011JN40];2a0;B`/@2][Jd20;B`/@04045Yh@2OVj00Wi^P0:f][@80^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]
00<0Uf0;00H0[Jf]0=>73P2][Jd0[Jf]045Yh@2:QGD2045Yh@060:f][@11JN40@FWQ0:f][@2TWXl0
@FWQ102TWXl01011JN40[Jf]0;6[W@2aZid2045Yh@@0/J^M00<0@FWQ0;6[W@2aZid00P2aZid3045Y
h@X0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1
^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd>0<>m
^`030:f][@2n^KP0_[Vh00P0_[Vh00L0@FWQ0;ji^02n^KP0_[Vh0:f][@2d/;40@FWQ0080];2a00<0
@FWQ0:f][@2][Jd00`2d/;401011JN40Wi^P045Yh@2OVj030:f][@@0R5H700<0[Jf]0000002`h>H0
?P2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`80[Jf]1@2:QGD00`11JN40[Jf]045Y
h@020:BNS`030:f][@11JN40Y9j?00<0Y9j?00@0@FWQ0:f][@2aZid0/J^M0P11JN440;6[W@03045Y
h@2aZid0/J^M0080/J^M0P11JN4?0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]
2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0080;ji^00:045Yh@2n^KP0_[Vh0;ji^02][Jd0];2a045Yh@2d/;40[Jf]045Yh@80];2a00H0
@FWQ0;B`/@2d/;40@FWQ09nKX011JN4309nKX0030:f][@28EPL0R5H70080R5H700<0[Jf]0000002`
h>H0?P2`h>H10?ooo`00E@2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@2:QGD0RXEe00@0RXEe
00<0@FWQ0:f][@11JN400`2TWXl00`11JN40[Jf]0:f][@020:BNS`04045Yh@2][Jd0/J^M0;6[W@80
@FWQ102aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ1P2i/ZH00`11JN40^K:V0;VbYP070;VbYP03
0:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh00T0@FWQ0;ji^02n^KP0_[Vh0:f][@2d/;40
@FWQ0:f][@2d/;400P11JN401P2d/;40@FWQ0;B`/@2d/;40[Jf]045Yh@D0Wi^P00H0[Jf]08QF1`28
EPL0R5H70:f][@00000o0;3PiP40oooo001E0;3PiP030000002][Jd0Uf0;0080Uf0;0P2][Jd608Z5
M@03045Yh@2][Jd0@FWQ00<0Y9j?00L0@FWQ0:BNS`2TWXl0[Jf]0:BNS`11JN40[Jf]0080/J^M0P11
JN440;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN440;VbYP80@FWQ00<0^K:V045Yh@2i/ZH01`2i
/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33
_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36
`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh
0P2][Jd00`11JN40];2a0;B`/@02045Yh@050;B`/@11JN40];2a0;B`/@2][Jd01P2OVj001P2][Jd0
R5H708QF1`28EPL0[Jf]000003l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd7
08Z5M@03045Yh@2TWXl0Y9j?0080Y9j?00@0@FWQ0:BNS`2TWXl0Y9j?0P11JN400`2][Jd0/J^M0;6[
W@02045Yh@<0/J^M0P11JN440;6[W@80@FWQ0`2i/ZH2045Yh@<0^K:V0P11JN460;VbYP030:f][@2n
]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh00<0@FWQ0;ji^02n^KP00P2][Jd0102d/;40@FWQ0;B`
/@2d/;42045Yh@050;B`/@11JN40];2a0;B`/@2][Jd01`2OVj00102][Jd0R5H708QF1`2][Je00;3P
iP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`020:BNS`80
@FWQ0P2TWXl2045Yh@80[Jf]00<0/J^M045Yh@11JN400`2aZid2045Yh@@0/J^M0P11JN430;VbYP80
@FWQ102i/ZH00`11JN40^K:V0;VbYP020;VbYP03045Yh@2i/ZH0[Jf]00d0_[N/102][Jd00`2n]j`0
[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^007045Yh@2][Jd0[Jf]0;ji
^02][Jd0];2a045Yh@020;B`/@04045Yh@2d/;40@FWQ045Yh@80];2a00<0[Jf]09nKX02OVj001@2O
Vj020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2]
[Jd608Z5M@060:f][@2TWXl0Y9j?0:BNS`11JN40Y9j?0P11JN420:BNS`80@FWQ00<0[Jf]0;6[W@2]
[Jd00P11JN430;6[W@80@FWQ102aZid2045Yh@<0^K:V0P11JN450;VbYP07045Yh@2i/ZH0^K:V0;Vb
YP11JN40^K:V0:f][@03045Yh@h0_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`02`36`;`00`11JN40a/2l0<K0_002
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP00`2][Jd0@FWQ0;ji^002
0;ji^0030:f][@2d/;40@FWQ0080];2a00<0@FWQ0;B`/@2d/;400`2d/;400`2][Jd0Wi^P09nKX005
09nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`030:f][@2:QGD0
RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl3045Yh@050:BNS`11JN40@FWQ0:BNS`2][Jd00P2a
Zid2045Yh@80[Jf]00<0/J^M045Yh@11JN40102aZid2045Yh@80^K:V0P11JN460;VbYP04045Yh@2i
/ZH0^K:V0;VbYP<0@FWQ0`2n]j`00`11JN40_[N/0;jg[00<0;jg[0030:f][@31^[00`KZ`00D0[Jf]
3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f]
[@36`;`0a/2l00X0a/2l0P11JN440<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
0`2n^KP30:f][@030;ji^011JN40_[Vh0080_[Vh00@0[Jf]0;B`/@11JN40];2a0P11JN450;B`/@03
0:f][@2OVj00Wi^P00@0Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F0;3PiP80[Jf]
0`1SH5<20:f][@D0RXEe00<0[Jf]0:BNS`2TWXl0102TWXl4045Yh@030:BNS`2][Jd0/J^M0080@FWQ
0`2aZid00`2][Jd0@FWQ045Yh@040;6[W@04045Yh@2][Jd0^K:V0;VbYP80@FWQ2P2i/ZH2045Yh@03
0:f][@2n]j`0_[N/0080_[N/00<0@FWQ0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[0050;jg[003
0:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00<0a/2l0P11JN450<K0_080@FWQ1036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]1@2n^KP01P11JN40_[Vh0;ji^02][Jd0
];2a045Yh@P0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]?`2`
h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0[Jf]00@0RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl0102][Jd0/J^M045Yh@11JN440;6[W@80@FWQ0P2][Jd20;6[W@04045Yh@2]
[Jd0^K:V0;VbYP80@FWQ2P2i/ZH00`11JN40[Jf]0;jg[0040;jg[003045Yh@2n]j`0_[N/0080_[N/
0P11JN470;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0:0<S1^`@0@FWQ1P38`K/00`2][Jd0b<6k
0<S1^`0@0<S1^`H0[Jf]4@37`K`0102][Jd0@FWQ0<K0_036`;`2045Yh@80a/2l00<0@FWQ0<K0_036
`;`00`36`;`00`11JN40a/2l0<K0_0020<K0_0030:f][@33_K/0`kfk00h0`kfk00@0[Jf]0;ji^02]
[Jd0[Jf]1`2n^KP01P11JN40_[Vh0;ji^02][Jd0];2a045Yh@P0];2a00<0[Jf]09nKX02OVj000P2O
Vj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`040:f][@2:QGD0RXEe0:f][@<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
045Yh@02045Yh@<0/J^M0P11JN420;6[W@80[Jf]00@0@FWQ0:f][@2i/ZH0^K:V0P11JN4:0;VbYP03
045Yh@2][Jd0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@L0_[N/00<0[Jf]0<6j/031
^[003`31^[080:f][A00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`070<S1^`@0
@FWQ2@38`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00A0<O1_004
0:f][@11JN40a/2l045Yh@D0a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`<0[Jf]2@2n^KP01P11JN40_[Vh0;ji^02][Jd0];2a045Yh@P0];2a00<0[Jf]09nKX02OVj000P2]
[Jd309nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`02
06=PD`050:f][@2:QGD0RXEe08Z5M@2][Jd00P2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2a
Zid0@FWQ0080@FWQ0`2aZid2045Yh@@0/J^M00@0@FWQ0:f][@2][Jd0^K:V0P11JN4;0;VbYP030:f]
[@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`00`11JN40_[N/0;jg[0050;jg[0030:f]
[@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX0
5@37`KX00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ2@38`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0
b<6k00<0[Jf]0<O1_037`K`02037`K`3045Yh@H0al6l00<0[Jf]045Yh@11JN401P36`;`00`11JN40
a/2l0<K0_0070<K0_0030:f][@33_K/0`kfk00X0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0090;ji^006
045Yh@2n^KP0_[Vh0:f][@2d/;40@FWQ202d/;400`2][Jd0Wi^P0:f][@0509nKX0030:f][@1`KWT0
L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe
0080RXEe00<0[Jf]08Z5M@2][Jd02`2TWXl01P2][Jd0/J^M045Yh@11JN40/J^M045Yh@80/J^M00<0
@FWQ0;6[W@2aZid00`2aZid01011JN40[Jf]0;VbYP2][Jd2045Yh@/0^K:V00<0[Jf]0;jg[02n]j`0
0`2n]j`00`11JN40_[N/0;jg[00;0;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<0
3P33_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@@0b<6k2@2][JdB0<S1^`030:f]
[@37`K`0al6l00L0al6l00@0@FWQ0<O1_037`K`0al6l0P11JN440<O1_0030:f][@11JN40@FWQ00H0
a/2l00<0@FWQ0<K0_036`;`01`36`;`00`2][Jd0`kfk0<>m^`070<>m^`<0[Jf]1033_K/00`2][Jd0
_[Vh0;ji^0080;ji^006045Yh@2n^KP0_[Vh0:f][@2d/;40@FWQ202d/;420:f][@H0Wi^P00<0[Jf]
071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5
M@2:QGD00`2:QGD20:f][@/0Y9j?00@0[Jf]0;6[W@11JN40@FWQ0P2aZid3045Yh@D0/J^M00<0@FWQ
0:f][@2i/ZH00P2i/ZH01011JN40[Jf]0:f][@2][Jd80;VbYP040:f][@2n]j`0_[N/0;jg[0<0@FWQ
3@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
0`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/60:f][@80@FWQ102][Jd50<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]045Yh@11JN400P11JN440<O1_080@FWQ1037`K`00`11JN40al6l
0<O1_0020<O1_0030:f][@11JN40a/2l00D0a/2l0P11JN490<K0_0030:f][@33_K/0`kfk00D0`kfk
0P2][Jd70<>m^`030:f][@2n^KP0_[Vh00P0_[Vh00@0@FWQ0;ji^02n^KP0[Jf]0P11JN480;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`04
0:f][@2aZid0@FWQ045Yh@X0/J^M00<0@FWQ0:f][@2i/ZH00P2i/ZH01011JN40^K:V0;VbYP2i/ZH2
0:f][@03045Yh@2][Jd0^K:V00<0^K:V00@0[Jf]0;jg[011JN40@FWQ0P2n]j`00`11JN40_[N/0;jg
[00:0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00X0al6j4@2]
[Jd60<S1^`80@FWQ2@38`K/00`2][Jd0b<6k0<S1^`0<0<S1^`@0@FWQ0P38`K/4045Yh@D0al6l0P11
JN460<O1_006045Yh@37`K`0al6l0<O1_02][Jd0@FWQ1P36`;`00`11JN40a/2l0<K0_0030<K0_003
045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/00P33_K/30:f][@T0`kfk00<0[Jf]0;ji^02n
^KP0202n^KP01011JN40_[Vh0;ji^02][Jd2045Yh@H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii
071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd9
0:BNS`040:f][@2aZid0@FWQ045Yh@X0/J^M00<0@FWQ0:f][@2i/ZH00P2i/ZH00`11JN40^K:V0;Vb
YP030;VbYP80@FWQ0`2][Jd0102i/ZH0[Jf]045Yh@2n]j`3045Yh@d0_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`080<>m/`@0@FWQ1`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng00T0a[ng<02][Jd;0<O1^P030:f][@38`K/0b<6k00T0b<6k0P11JN490<S1^`030:f]
[@38`K/0b<6k00D0b<6k0`11JN420<S1^`@0@FWQ1@38`K/00`2][Jd0@FWQ045Yh@050<O1_080@FWQ
2P37`K`00`2][Jd0a/2l0<K0_0040<K0_080@FWQ1@36`;`00`11JN40a/2l0<K0_0020<K0_0030:f]
[@33_K/0[Jf]0080[Jf]3033_K/00`2][Jd0_[Vh0;ji^0080;ji^005045Yh@2n^KP0_[Vh0:f][@11
JN401P2d/;40102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H1
0?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd7
0:BNS`040:f][@2aZid0@FWQ045Yh@P0/J^M0`11JN40102][Jd0^K:V0;VbYP2i/ZH2045Yh@@0^K:V
0P11JN430;VbYP040:f][@11JN40@FWQ045Yh@P0_[N/00<0@FWQ0;jg[02n]j`01@2n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00/0`kfc1P11JN420<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/02@38`K/2045Yh@T0b<6k00@0[Jf]0<S1^`38`K/0b<6k1@11JN460<S1
^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@050<O1_080@FWQ2P37`K`00`2][Jd0a/2l0<K0_0030<K0
_080@FWQ1P36`;`00`11JN40a/2l0<K0_0040:f][@l0`kfk00<0[Jf]0;ji^02n^KP0202n^KP00`11
JN40_[Vh0;ji^002045Yh@@0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^
N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]
0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BNS`040:f][@2aZid0@FWQ045Yh@/0/J^M00<0
[Jf]0;VbYP2i/ZH00P2i/ZH00`11JN40^K:V0;VbYP030;VbYP04045Yh@2i/ZH0^K:V0;VbYP80@FWQ
00<0_[N/0:f][@2][Jd00P2][Jd50;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0[Jf]0<6j/031^[00
4P31^[000`2][Jd0`kfc0<>m/`0;0<>m/`03045Yh@33_K<0`kfc0080`kfc0P11JN400`33_K<0[Jf]
0<Fn]@040<Fn]@<0@FWQ3P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`090<S1^`80@FWQ0P38`K/3045Yh@@0b<6k
00<0[Jf]0<S1^`38`K/01038`K/2045Yh@H0b<6k0P11JN450<S1^`030:f][@11JN40@FWQ00@0al6l
0P11JN4;0<O1_0040:f][@36`;`0a/2l0<K0_0<0@FWQ1@36`;`20:f][@03045Yh@2][Jd0[Jf]0080
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0080;ji^004045Yh@2n^KP0_[Vh045Y
h@<0];2a0P2][Jd50;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H1
0?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd4
0:BNS`040:f][@2aZid0@FWQ045Yh@/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH01@11JN40^K:V0;Vb
YP2i/ZH0@FWQ00@0^K:V00<0@FWQ0:f][@2n]j`0102n]j`40:f][@030;jg[011JN40_[N/00H0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0;0<>m/`03045Yh@33_K<0`kfc00<0`kfc
0P11JN400`2][Jd0aKje0<Fn]@050<Fn]@@0@FWQ2`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX3045Yh@D0b<6k0P11JN420<S1^`80@FWQ
00<0b<6k045Yh@38`K/00P38`K/2045Yh@80b<6k00<0[Jf]0<S1^`38`K/01038`K/2045Yh@H0b<6k
0P11JN450<S1^`030:f][@11JN40@FWQ00@0al6l0P11JN4;0<O1_0030:f][@36`;`0a/2l00<0@FWQ
0P36`;`40:f][@80a/2l00<0@FWQ0<K0_036`;`00P36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00P0_[Vh00@0@FWQ0;ji^02n^KP0@FWQ0P2d/;400`2][Jd0];2a0;B`/@050;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0
Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`040:f][@11JN40@FWQ045Y
h@X0/J^M00<0[Jf]0;VbYP2i/ZH01@2i/ZH4045Yh@@0^K:V00<0@FWQ0:f][@2n]j`0102n]j`01P11
JN40_[N/0;jg[02n]j`0[Jf]045Yh@80[Jf]1@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc00/0`kfc00<0@FWQ0<>m/`33_K<01033_K<2045Yh@L0aKje0P11JN4=0<Fn]@030:f][@11
JN40@FWQ0080@FWQ1@36_kL2045Yh@H0a[ng00<0@FWQ0<Jo]`36_kL00`36_kL00`2][Jd0al6h0<O1
^00C0<O1^003045Yh@2][Jd0al6j0080al6j1`11JN4;0<O1^P80@FWQ00<0[Jf]0<S1^`38`K/00P11
JN400`38`K/0@FWQ045Yh@040<S1^`<0@FWQ1@38`K/2045Yh@030<S1^`2][Jd0b<6k00D0b<6k0P11
JN460<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@040<O1_080@FWQ2`37`K`0102][Jd0a/2l045Y
h@11JN440:f][@030<K0_011JN40a/2l00<0a/2l00<0@FWQ0<K0_036`;`00P36`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0`11JN430:f][@P0];2a00<0[Jf]09nKX02OVj00
1@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0
[Jf]0:BNS`2TWXl01`2TWXl30:f][@030;6[W@11JN40@FWQ00X0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`11JN40_[N/0;jg[0020;jg[080@FWQ102n]j`00`11JN40_[N/0;jg[0040:f][@030;jg[02]
[Jd0`KZ`01<0`KZ`00<0[Jf]0<>m/`33_K<02`33_K<00`11JN40`kfc0<>m/`050<>m/`80@FWQ1P35
_[D2045Yh@`0aKje0`11JN430<Jo]`80@FWQ00<0a[ng045Yh@11JN402036_kL00`11JN40a[ng0<Jo
]`030<Jo]`030:f][@11JN40al6h00`0al6h1011JN420<O1^080@FWQ00<0[Jf]0<O1^P37`KX01037
`KX00`11JN40al6j0<O1^P0;0<O1^P80@FWQ00<0al6j0:f][@38`K/00P38`K/3045Yh@D0b<6k0`11
JN460<S1^`80@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@H0b<6k0P11JN450<S1^`030:f][@11
JN40@FWQ00@0al6l0P11JN490<O1_0@0[Jf]00<0@FWQ0<K0_036`;`01036`;`00`11JN40a/2l0<K0
_0020<K0_003045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0070;ji^080@FWQ00<0_[Vh0:f][@2][Jd02P2d/;400`2][Jd0Wi^P09nKX00509nKX0030:f][@1`
KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?0P2][Jd<
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@@0_[N/00<0@FWQ
0;jg[02n]j`0102n]j`50:f][A40`KZ`00<0[Jf]0<>m/`33_K<02`33_K<00`11JN40`kfc0<>m/`05
0<>m/`80@FWQ1P35_[D2045Yh@`0aKje00<0@FWQ0:f][@36_kL01@36_kL2045Yh@T0a[ng00<0@FWQ
0<Jo]`36_kL00`36_kL00`2][Jd0@FWQ0<O1^00:0<O1^0<0@FWQ0`37`KP4045Yh@030:f][@37`KX0
al6j00@0al6j00<0@FWQ0<O1^P37`KX02P37`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/00P38`K/2
045Yh@D0b<6k0P11JN470<S1^`80@FWQ00<0[Jf]0<S1^`38`K/01038`K/2045Yh@H0b<6k0P11JN45
0<S1^`030:f][@11JN40@FWQ00@0al6l0P11JN440<O1_0<0[Jf]00D0@FWQ0:f][@37`K`0al6l0:f]
[@02045Yh@D0a/2l0P11JN440<K0_003045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^0060;ji^006045Yh@2n^KP0[Jf]0:f][@2n^KP0[Jf]2P2d/;400`2][Jd0
Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M00<0@FWQ0;VbYP2i/ZH03P2i/ZH00`2][Jd0@FWQ
0;jg[0020;jg[080@FWQ102n]j`00`11JN40_[N/0;jg[0050;jg[0040:f][@31^[00`KZ`0<6j/0L0
[Jf]2P31^[000`2][Jd0`kfc0<>m/`0;0<>m/`03045Yh@33_K<0`kfc00D0`kfc00<0[Jf]045Yh@11
JN401@35_[D2045Yh@`0aKje00<0@FWQ0:f][@36_kL01P36_kL00`11JN40a[ng0<Jo]`060<Jo]`03
045Yh@36_kL0@FWQ00@0a[ng0P11JN4:0<O1^080@FWQ1P37`KP3045Yh@030:f][@37`KX0al6j00@0
al6j00<0@FWQ0<O1^P37`KX02P37`KX2045Yh@80al6j00<0[Jf]0<S1^`38`K/00P38`K/2045Yh@H0
b<6k0P11JN470<S1^`80@FWQ1P38`K/2045Yh@H0b<6k0P11JN450<S1^`030:f][@37`K`0@FWQ00@0
al6l0P11JN440:f][@80al6l00<0@FWQ0<O1_011JN400P37`K`00`2][Jd0@FWQ0<K0_0050<K0_080
@FWQ1036`;`2045Yh@<0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0060;ji^080
[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40
oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@020;6[W@80[Jf]1P2aZid2045YhA00^K:V00<0[Jf]0;jg[011JN400P11JN400`2n]j`0@FWQ
0;jg[0020;jg[080@FWQ1`2n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[000`2][Jd0`kfc
0<>m/`0;0<>m/`03045Yh@33_K<0`kfc00D0`kfc00<0[Jf]045Yh@11JN401@35_[D2045Yh@`0aKje
00<0@FWQ0:f][@36_kL01P36_kL00`11JN40a[ng0<Jo]`060<Jo]`<0@FWQ1036_kL3045Yh@P0al6h
0P11JN480<O1^080@FWQ00<0al6h0:f][@37`KX01037`KX00`11JN40al6j0<O1^P0:0<O1^P80@FWQ
0P37`KX00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ00<0b<6k00000038`K/00`38`K/2045Yh@L0b<6k
0P11JN460<S1^`80@FWQ1P38`K/2045Yh@D0b<6k00<0[Jf]00000011JN40102][Jd2045Yh@L0al6l
0P11JN420<O1_0030:f][@36`;`0@FWQ00D0a/2l0P11JN440<K0_080@FWQ0`36`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a
00<0[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:
QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]0`2a
Zid2045YhA00^K:V00<0[Jf]0;jg[02n]j`01`2n]j`3045Yh@H0_[N/00<0[Jf]0<6j/031^[003`31
^[070:f][@X0`kfc00<0@FWQ0<>m/`33_K<01@33_K<00`2][Jd0@FWQ045Yh@050<Fn]@80@FWQ3035
_[D00`11JN40[Jf]0<Jo]`060<Jo]`03045Yh@36_kL0a[ng00H0a[ng0`11JN440<Jo]`<0@FWQ2037
`KP00`11JN40al6h0<O1^0070<O1^080@FWQ00<0al6h0:f][@37`KX01037`KX00`11JN40al6j0<O1
^P0:0<O1^P80@FWQ0P37`KX00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ1P38`K/2045Yh@L0b<6k0P11
JN460<S1^`80@FWQ1P38`K/2045Yh@80b<6k1@2][Jd00`11JN40al6l0<O1_0030<O1_080@FWQ1P37
`K`01`11JN40al6l0<O1_037`K`0[Jf]0<K0_011JN400`36`;`2045Yh@030<K0_011JN40a/2l00<0
a/2l0P11JN440<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji
^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3P
iP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0
/J^M0;6[W@070;6[W@<0[Jf]00<0@FWQ0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0<0
@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]0`33_K<00`11
JN40`kfc0<>m/`050<>m/`030:f][@35_[D0@FWQ00D0aKje0P11JN4<0<Fn]@03045Yh@2][Jd0a[ng
00H0a[ng00<0@FWQ0<Jo]`36_kL01P36_kL3045Yh@@0a[ng00<0@FWQ0<O1^011JN402037`KP00`11
JN40al6h0<O1^0070<O1^080@FWQ00<0al6h0:f][@37`KX01037`KX00`11JN40al6j0<O1^P0:0<O1
^P80@FWQ0P37`KX00`2][Jd0b<6k0<S1^`020<S1^`80@FWQ1P38`K/2045Yh@L0b<6k0P11JN460<S1
^`80@FWQ0`38`K/30:f][@80@FWQ0P2][Jd30<S1^`030:f][@37`K`0@FWQ00D0al6l0P11JN460<O1
_005045Yh@37`K`0al6l0<O1_02][Jd00P36`;`3045Yh@P0a/2l0P11JN440<K0_0030:f][@33_K/0
`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2O
Vj00Wi^P0080Wi^P00<0[Jf]0;3PiP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@02
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`3045Yh@H0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`08
0<>m/`<0[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd30<>m/`030:f][@35_[D0@FWQ00D0aKje0P11JN4<
0<Fn]@80@FWQ1`36_kL00`11JN40a[ng0<Jo]`060<Jo]`03045Yh@36_kL0@FWQ00<0a[ng0P11JN40
0`37`KP0@FWQ0<O1^0070<O1^003045Yh@37`KP0al6h00L0al6h0P11JN400`37`KP0[Jf]0<O1^P04
0<O1^P03045Yh@37`KX0al6j00/0al6j0P11JN400`37`KX0[Jf]0<S1^`030<S1^`80@FWQ1P38`K/2
045Yh@L0b<6k0P11JN400`000000b<6k0<S1^`030:f][@80@FWQ0`2][Jd30<S1^`80@FWQ1@38`K/0
0`2][Jd0al6l045Yh@060<O1_003045Yh@37`K`0al6l00<0al6l00<0@FWQ0<O1_037`K`00P37`K`0
0`2][Jd0a/2l0<K0_00;0<K0_080@FWQ1036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP0
0`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f]
[@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]
00<0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0<0@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc00/0`kfc00<0@FWQ0<>m/`33_K<00P33_K<50:f][@04045Yh@2][Jd0[Jf]
0:f][@80aKje0P11JN4=0<Fn]@80@FWQ1@36_kL2045Yh@L0a[ng0P11JN400`36_kL0@FWQ0<Jo]`02
0<Jo]`80@FWQ00<0al6h045Yh@37`KP01P37`KP2045Yh@T0al6h0P11JN400`37`KP0[Jf]0<O1^P04
0<O1^P03045Yh@37`KX0al6j00d0al6j1011JN420<S1^`80@FWQ1P38`K/2045Yh@<0b<6k102][Jd0
0`11JN40[Jf]0:f][@020:f][@<0b<6k0P11JN460<S1^`80@FWQ1@38`K/00`2][Jd0al6l045Yh@07
0<O1_0D0@FWQ1@37`K`00`2][Jd0a/2l0<K0_00;0<K0_080@FWQ1036`;`00`2][Jd0`kfk0<>m^`09
0<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00
[Jf]04P0/>3V0@3oool00600/>3V00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0/J^M0;6[W@0;0;6[
W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/00L0_[N/0`11JN460;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02P33_K<2045Yh@L0`kfc00<0[Jf]0<Fn
]@11JN400`35_[D20:f][@80@FWQ202][Jd50<Fn]@030:f][@36_kL0@FWQ0080@FWQ0P36_kL2045Y
h@L0a[ng0P11JN420<Jo]`03045Yh@36_kL0a[ng0080@FWQ0P37`KP00`11JN40al6h0<O1^0040<O1
^080@FWQ2@37`KP5045Yh@@0al6j00<0@FWQ0<O1^P37`KX03P37`KX00`2][Jd0b<6k0<S1^`04045Y
h@H0[Jf]0P11JN430:f][@<0b<6k0P11JN400`2][Jd0b<6k0<S1^`040<S1^`80@FWQ1P38`K/00`11
JN40b<6k0<S1^`040<S1^`030:f][@37`K`0@FWQ0180al6l00<0[Jf]0<K0_036`;`02P36`;`2045Y
h@@0a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2]
[Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0<0
@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00X0`kfc0P11JN470<>m/`03
0:f][@11JN40@FWQ00D0aKje0P11JN480<Fn]@X0[Jf]1011JN430:f][@@0a[ng0P11JN420<Jo]`05
045Yh@36_kL0a[ng045Yh@2][Jd00P37`KP00`11JN40al6h0<O1^0040<O1^080@FWQ1`37`KP4045Y
h@030<O1^02][Jd0al6j00@0al6j00<0@FWQ0<O1^P37`KX00`37`KX@0:f][@80@FWQ1P38`K/2045Y
h@H0b<6k0P11JN400`2][Jd0b<6k0<S1^`040<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`040<S1
^`030:f][@11JN40@FWQ0180al6l00<0[Jf]0<K0_036`;`02P36`;`2045Yh@@0a/2l00<0[Jf]0<>m
^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`
/@030:f][@2`h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[0080;jg[0<0
@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00X0`kfc0P11JN470<>m/`03
0:f][@11JN40@FWQ00D0aKje0P11JN450<Fn]@03045Yh@35_[D0aKje00D0aKje00<0[Jf]0<Jo]`36
_kL01036_kL2045Yh@<0a[ng102][Jd2045Yh@80[Jf]00@0@FWQ0:f][@11JN40@FWQ0`2][Jd00`11
JN40[Jf]0:f][@040:f][@80@FWQ4P2][Jd00`11JN40[Jf]0:f][@030:f][@T0al6j00<000000<O1
^P2][Jd01038`K/2045Yh@H0b<6k0P11JN450<S1^`80@FWQ00<0b<6k0:f][@38`K/01@38`K/4045Y
h@<0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045YhA@0al6l00<0[Jf]0<K0_036`;`02P36`;`00`11
JN40a/2l0<K0_0030<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji
^0030:f][@2d/;40];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00d0^K:V0`2][Jd80;jg[003045Yh@2n]j`0@FWQ00H0
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0:0<>m/`80@FWQ1`33_K<00`2][Jd0
@FWQ045Yh@050<Fn]@<0@FWQ0`35_[D2045Yh@H0aKje0P11JN460<Jo]`03045Yh@36_kL0a[ng00H0
a[ng0P11JN420<Jo]`05045Yh@36_kL0@FWQ045Yh@2][Jd00P37`KP00`11JN40al6h0<O1^0040<O1
^080@FWQ3037`KP00`2][Jd0al6j0<O1^P030<O1^P80@FWQ1@37`KX00`11JN40al6j0<O1^P040<O1
^P80@FWQ00<0al6j0:f][@38`K/00`38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ1@38`K/2045Y
h@030<S1^`2][Jd0b<6k00D0b<6k0P11JN420<S1^`<0@FWQ2038`K/00`2][Jd0al6l0<O1_00B0<O1
_0030:f][@36`;`0a/2l00X0a/2l00@0@FWQ0<K0_036`;`0a/2l102][Jd>0<>m^`030:f][@2n^KP0
_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3P
iP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02][Jd00`2][Jd50;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0:0<>m/`80@FWQ1`33_K<00`2][Jd0@FWQ045Yh@050<Fn]@80@FWQ00L0aKje045Y
h@35_[D0aKje045Yh@35_[D0@FWQ00D0aKje0P11JN460<Jo]`03045Yh@36_kL0a[ng00H0a[ng00H0
@FWQ0<Jo]`36_kL0a[ng045Yh@36_kL2045Yh@040:f][@37`KP0al6h045Yh@H0al6h0P11JN4<0<O1
^0030:f][@37`KX0al6j00<0al6j0P11JN440<O1^P03045Yh@37`KX0@FWQ00D0al6j0P11JN400`37
`KX0[Jf]0<S1^`030<S1^`03045Yh@38`K/0b<6k00D0b<6k0`11JN430<S1^`80@FWQ0P38`K/00`2]
[Jd0b<6k0<S1^`040<S1^`80@FWQ3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00T0a/2l1@2][Jd20<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2]
[Jd0];2a0;B`/@030;B`/@80[Jf]CP2`h>H10?ooo`00I`2`h>H20:f][@@0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd00`2n]j`0
@FWQ0;jg[0060;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02P33_K<2045Yh@L0
`kfc00<0[Jf]045Yh@11JN400P35_[D5045Yh@80aKje00<0@FWQ0<Fn]@35_[D00P11JN460<Fn]@03
045Yh@36_kL0a[ng00@0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL2045Yh@@0a[ng0P11JN400`36_kL0
[Jf]0<O1^0020<O1^003045Yh@37`KP0al6h00<0al6h0P11JN4<0<O1^0030:f][@37`KX0al6j00<0
al6j00<0@FWQ0<O1^P11JN400`37`KX00`11JN40al6j045Yh@060<O1^P03045Yh@37`KX0[Jf]00@0
b<6k00<0@FWQ0<S1^`38`K/00P38`K/5045Yh@040<S1^`11JN40@FWQ045Yh@@0b<6k00<0[Jf]0<S1
^`38`K/01038`K/2045Yh@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050<K0
_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`
/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0:0<>m/`80@FWQ1`33_K<00`2][Jd0@FWQ0<Fn]@0:0<Fn
]@<0@FWQ1`35_[D0102][Jd0@FWQ045Yh@11JN430<Jo]`03045Yh@36_kL0a[ng00D0a[ng0P11JN44
0<Jo]`80@FWQ00<0a[ng0:f][@37`KP00P37`KP00`11JN40al6h0<O1^0030<O1^080@FWQ3037`KP0
0`2][Jd0al6j0<O1^P030<O1^P04045Yh@37`KX0al6j045Yh@<0al6j0P11JN470<O1^PH0@FWQ4P38
`K/00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0
[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m
/`0:0<>m/`80@FWQ1`33_K<00`2][Jd0@FWQ0<Fn]@0D0<Fn]@040:f][@36_kL0a[ng0<Jo]`<0@FWQ
1@36_kL7045Yh@80a[ng0P11JN400`36_kL0[Jf]0<O1^006045Yh@80al6h0P11JN4<0<O1^0030:f]
[@37`KX0al6j00@0@FWQ0`37`KX4045Yh@T0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`040<S1^`80@FWQ3@38`K/00`2][Jd0al6l045Yh@0@0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk
0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][JdA0<6j/0030:f][@33
_K<0`kfc00X0`kfc0P11JN470<>m/`80@FWQ5@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00L0al6h0P11JN4:0<O1^003045Yh@37`KP0[Jf]00/0al6j00<000000<O1^P37`KX02037
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00@0b<6k0P11JN4=0<S1^`040:f][@11
JN40al6l045Yh@X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]
2P31^[000`2][Jd0`kfc0<>m/`0:0<>m/`80@FWQ1`33_K<2045YhAD0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^0080<O1^003045Yh@37`KP0al6h00P0al6h00<0@FWQ0<O1^02][Jd0
5P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00@0b<6k0P11JN4=0<S1^`030:f]
[@37`K`0@FWQ00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2]
[Jd30<6j/0030:f][@33_K<0`kfc00X0`kfc0P11JN460<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00P0al6h00<0@FWQ0<O1^037`KP01`37`KP2045Yh@030<O1^02]
[Jd0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ3@38
`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[07
0:f][@L0`kfc1011JN450<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h00P0al6h00<0@FWQ0<O1^037`KP01`37`KP2045Yh@030<O1^02][Jd0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ2P38`K/6
0:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh0080_[Vh0`2][JeL0;3PiP40oooo001f0;3PiP<0[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<7
0:f][@80`kfc2011JN400`33_K<0[Jf]0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP02037`KP2045Yh@P0al6h0P11JN400`37`KP0[Jf]0<O1^P0E0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/00P38`K/3045Yh@@0b<6k1`2][Jd30<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0090<O1
^080@FWQ1P37`KP3045Yh@030<O1^02][Jd0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102]
[Jd000000<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033_K<90:f]
[A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00:0<O1^080@FWQ1037`KP2045Y
h@040<O1^011JN40al6h0:f][AH0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU
0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00`0al6h1011JN430<O1^003045Yh@37`KP0[Jf]
01H0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f]
[FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`03
0:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40
oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng
6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;
0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f]
[GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38
`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40
oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2]
[JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3o
ool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`7
0:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1
_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0
/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00
b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302]
[Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52567 .3309 m
.524 .33732 L
s
.51898 .3309 m
.52233 .33411 L
s
.5123 .33086 m
.51898 .3309 L
s
.50895 .33403 m
.5123 .33086 L
s
.54071 .33076 m
.53403 .33085 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52233 .33411 m
.524 .33732 L
s
.54905 .3306 m
.54406 .33391 L
s
.55239 .33052 m
.54905 .3306 L
s
.50727 .33722 m
.50895 .33403 L
s
.49559 .33379 m
.49393 .33054 L
s
.55573 .33364 m
.55239 .33052 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51157 .33856 m
.51322 .33858 L
s
.50825 .34078 m
.51157 .33856 L
s
.50991 .3408 m
.51157 .33856 L
s
0 0 0 r
.51976 .35917 m
.52065 .35986 L
s
.255 .412 .882 r
.49999 .33839 m
.50329 .34071 L
s
.49503 .33828 m
.49999 .33839 L
s
0 0 0 r
.59493 .32859 m
.60035 .32824 L
s
.255 .412 .882 r
.50825 .34529 m
.50991 .3408 L
s
.50659 .34527 m
.50825 .34078 L
s
.49172 .34045 m
.49503 .33828 L
s
.49007 .34041 m
.49503 .33828 L
s
.50329 .34071 m
.50659 .34527 L
s
0 0 0 r
.52328 .35916 m
.524 .35986 L
s
.255 .412 .882 r
.49005 .34492 m
.49172 .34045 L
s
.4884 .34487 m
.49007 .34041 L
s
0 0 0 r
.52568 .36309 m
.524 .35986 L
s
.524 .36309 m
.52065 .35986 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52568 .36632 m
.524 .36309 L
s
.255 .412 .882 r
.56613 .34005 m
.57105 .3376 L
s
.49004 .34944 m
.49005 .34492 L
s
.56777 .33999 m
.57105 .3376 L
s
.48838 .34939 m
.4884 .34487 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56451 .34462 m
.56777 .33999 L
s
.57105 .3376 m
.57433 .33745 L
s
.56286 .34468 m
.56613 .34005 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57433 .33745 m
.57926 .33947 L
s
.56123 .34926 m
.56286 .34468 L
s
.56288 .3492 m
.56451 .34462 L
s
.45563 .33664 m
.46706 .33726 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49526 .38847 m
.4954 .39198 L
s
.49204 .39191 m
.4922 .38836 L
s
.5 Mabswid
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49004 .34944 m
.49167 .354 L
s
.48838 .34939 m
.49002 .35396 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52813 .33861 m
.5348 .37021 L
s
.5215 .37027 m
.52813 .33861 L
s
.54137 .33847 m
.54808 .37 L
s
.5348 .37021 m
.54137 .33847 L
s
.52316 .37027 m
.52813 .34537 L
s
.50822 .36111 m
.50825 .34529 L
s
.50655 .36562 m
.50659 .34527 L
s
.53646 .37019 m
.54138 .34523 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.57592 .37084 m
.57595 .37488 L
s
.57758 .36973 m
.57761 .37481 L
s
.59405 .35872 m
.5941 .3642 L
s
.59569 .35762 m
.59575 .3641 L
s
.255 .412 .882 r
.55961 .3561 m
.56123 .34926 L
s
.58252 .33705 m
.58265 .35514 L
s
.57926 .33947 m
.58257 .34383 L
s
.46192 .36873 m
.46215 .33701 L
s
.56126 .35604 m
.56288 .3492 L
s
.58415 .33696 m
.58429 .35506 L
s
.46028 .36865 m
.46052 .33692 L
s
.49167 .354 m
.49497 .35635 L
s
.49002 .35396 m
.49497 .35635 L
s
.49497 .35635 m
.50491 .3588 L
s
.50491 .3588 m
.50656 .36109 L
s
.50655 .36562 m
.50822 .36111 L
s
.55961 .3561 m
.55966 .36743 L
s
0 0 0 r
.49372 .39194 m
.49373 .38842 L
s
.255 .412 .882 r
.56126 .35604 m
.56132 .36738 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59393 .33639 m
.60527 .33561 L
s
.50489 .36787 m
.50655 .36562 L
s
.48998 .36302 m
.49164 .36306 L
s
.49163 .36533 m
.49164 .36306 L
s
.48997 .36528 m
.48998 .36302 L
s
.50156 .37008 m
.50489 .36787 L
s
.51651 .37025 m
.52815 .37025 L
s
.48997 .36528 m
.49162 .3676 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5431 .37009 m
.55305 .36989 L
s
.49492 .36995 m
.50156 .37008 L
s
.57773 .35539 m
.58919 .35479 L
s
.49162 .3676 m
.49492 .36995 L
s
.43779 .33543 m
.44262 .33805 L
s
.44262 .33805 m
.44581 .34281 L
s
.47346 .36472 m
.47512 .36252 L
s
.47512 .36252 m
.47675 .36485 L
s
.46202 .35511 m
.46361 .362 L
s
.43779 .33543 m
.441 .33794 L
s
.441 .33794 m
.44419 .34269 L
s
.47674 .36712 m
.47675 .36485 L
s
.44581 .34281 m
.44739 .34744 L
s
.42176 .33409 m
.43779 .33543 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44419 .34269 m
.44577 .34734 L
s
.47346 .36472 m
.47509 .36706 L
s
.47508 .36933 m
.47674 .36712 L
s
.44739 .34744 m
.44896 .35435 L
s
.44577 .34734 m
.44733 .35425 L
s
.46361 .362 m
.46686 .3667 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56132 .36738 m
.563 .37414 L
s
.55966 .36743 m
.56135 .37419 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5988 .33607 m
.5991 .36783 L
s
.60042 .33596 m
.60072 .36772 L
s
.47014 .36912 m
.47508 .36933 L
s
.56135 .37419 m
.56303 .37869 L
s
.563 .37414 m
.56468 .37864 L
s
.46686 .3667 m
.47014 .36912 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49529 .39239 m
.4954 .39198 L
s
.5 Mabswid
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44886 .36571 m
.44896 .35435 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42759 .38248 m
.42815 .33466 L
s
.44723 .36561 m
.44733 .35425 L
s
.56303 .37869 m
.56636 .38313 L
s
.56468 .37864 m
.56801 .38308 L
s
.42598 .38235 m
.42655 .33452 L
s
.60059 .35408 m
.60228 .36079 L
s
.45537 .36838 m
.46192 .36873 L
s
0 0 0 r
.64213 .32754 m
.64232 .32771 L
s
.64212 .32652 m
.64391 .32754 L
s
.255 .412 .882 r
.58441 .37096 m
.58451 .38464 L
s
.58282 .37788 m
.58441 .37096 L
s
.56636 .38313 m
.57133 .38523 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56801 .38308 m
.57133 .38523 L
s
.44716 .37244 m
.44886 .36571 L
s
.60228 .36079 m
.60557 .36511 L
s
.59421 .36813 m
.60072 .36772 L
s
.44553 .37234 m
.44723 .36561 L
s
.57956 .38259 m
.58282 .37788 L
s
.58282 .37788 m
.58451 .38464 L
s
.57133 .38523 m
.57463 .3851 L
s
.57463 .3851 m
.57956 .38259 L
s
.62774 .33597 m
.63247 .33324 L
s
.6262 .34066 m
.62774 .33597 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62933 .33582 m
.63247 .33324 L
s
.6278 .34051 m
.62933 .33582 L
s
.6262 .34066 m
.62626 .34521 L
s
.63247 .33324 m
.6372 .33275 L
s
.60557 .36511 m
.60883 .36716 L
s
.44549 .3769 m
.44716 .37244 L
s
.6278 .34051 m
.62785 .34506 L
s
.44386 .3768 m
.44553 .37234 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61202 .36236 m
.6136 .35995 L
s
.62626 .34521 m
.62791 .34961 L
s
.62785 .34506 m
.6295 .34946 L
s
.6372 .33275 m
.64038 .33468 L
s
.44219 .38126 m
.44549 .3769 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60883 .36716 m
.61368 .36679 L
s
.61202 .36236 m
.61366 .36451 L
s
.6136 .35995 m
.61524 .3621 L
s
.61524 .3621 m
.61527 .36438 L
s
.44057 .38115 m
.44386 .3768 L
s
.61368 .36679 m
.61527 .36438 L
s
.62791 .34961 m
.63271 .35143 L
s
.65259 .31507 m
.66336 .31366 L
s
.6295 .34946 m
.63271 .35143 L
s
.64038 .33468 m
.64359 .33889 L
s
.43729 .38321 m
.44219 .38126 L
s
.43729 .38321 m
.44057 .38115 L
s
0 0 0 r
.64741 .34921 m
.64742 .34991 L
s
.255 .412 .882 r
.63271 .35143 m
.64222 .35274 L
s
.64509 .33416 m
.64818 .33153 L
s
.64359 .33889 m
.64509 .33416 L
s
.62803 .35872 m
.62806 .361 L
s
.62803 .35872 m
.62962 .35857 L
s
0 0 0 r
.64897 .34793 m
.649 .34973 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64818 .33153 m
.64973 .33134 L
s
.64665 .33398 m
.64818 .33153 L
s
.64516 .33871 m
.64665 .33398 L
s
.42116 .38195 m
.43729 .38321 L
s
.62962 .35857 m
.62965 .36086 L
s
.62806 .361 m
.62968 .36314 L
s
.62968 .36314 m
.6329 .36512 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64703 .35262 m
.64742 .34991 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64359 .33889 m
.64389 .35942 L
s
.64516 .33871 m
.6454 .35468 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6329 .36512 m
.63923 .3645 L
s
.64222 .35274 m
.64383 .35485 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64389 .35942 m
.6454 .35468 L
s
.63923 .3645 m
.64236 .36188 L
s
.64236 .36188 m
.64389 .35942 L
s
.65914 .33703 m
.66214 .33207 L
s
.66214 .33207 m
.66516 .32938 L
s
.66516 .32938 m
.66822 .32896 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66822 .32896 m
.6713 .33081 L
s
.66822 .32896 m
.67281 .33059 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65876 .31428 m
.65956 .36221 L
s
.65722 .31448 m
.65801 .3624 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6713 .33081 m
.67441 .33495 L
s
.65335 .36295 m
.65956 .36221 L
s
.67281 .33059 m
.67592 .33473 L
s
.65945 .35533 m
.66261 .35953 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67441 .33495 m
.67605 .3416 L
s
.66261 .35953 m
.66573 .36143 L
s
.67592 .33473 m
.67756 .34138 L
s
.67605 .3416 m
.67614 .34619 L
s
.66573 .36143 m
.66879 .36103 L
s
.67756 .34138 m
.67765 .34597 L
s
.67475 .3533 m
.67614 .34619 L
s
.66879 .36103 m
.6718 .35832 L
s
.66879 .36103 m
.67332 .35811 L
s
.67627 .35308 m
.67765 .34597 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6718 .35832 m
.67475 .3533 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67332 .35811 m
.67627 .35308 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68627 .32624 m
.69658 .32451 L
s
.70239 .32347 m
.71242 .32156 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33794 .32715 m
.33943 .32512 L
s
.33805 .32254 m
.33943 .32512 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69071 .32551 m
.69171 .37395 L
s
.69218 .32526 m
.69319 .37371 L
s
.70671 .32266 m
.70729 .34806 L
s
.69271 .35057 m
.69575 .35471 L
s
.33657 .32457 m
.33805 .32254 L
s
.70814 .32239 m
.70872 .34779 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69575 .35471 m
.7002 .35628 L
s
.68724 .37463 m
.69319 .37371 L
s
.33657 .32457 m
.33794 .32715 L
s
.7002 .35628 m
.70311 .35578 L
s
.33768 .33869 m
.33849 .36677 L
s
.33561 .36626 m
.33768 .33869 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70311 .35578 m
.70595 .35295 L
s
.70311 .35578 m
.70739 .35269 L
s
.70595 .35295 m
.70729 .34806 L
s
.70739 .35269 m
.70872 .34779 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72727 .31535 m
.72778 .31395 L
s
.255 .412 .882 r
.33705 .36652 m
.33736 .35258 L
s
.32526 .32231 m
.3266 .32491 L
s
.32644 .33185 m
.3266 .32491 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71806 .32042 m
.72777 .31834 L
s
.5 Mabswid
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32253 .31941 m
.32526 .32231 L
s
.72224 .31954 m
.72304 .35203 L
s
.32504 .33157 m
.32649 .32954 L
s
.31702 .31821 m
.32253 .31941 L
s
.32498 .33388 m
.32644 .33185 L
s
.72363 .31925 m
.72444 .35175 L
s
.33694 .37117 m
.33849 .36677 L
s
.32219 .33331 m
.32504 .33157 L
s
.32213 .33563 m
.32498 .33388 L
s
.33561 .36626 m
.33694 .37117 L
s
.32464 .34781 m
.32616 .34345 L
s
.32593 .35275 m
.32616 .34345 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31518 .33648 m
.32219 .33331 L
s
.31423 .31991 m
.31702 .31821 L
s
.31512 .3388 m
.32213 .33563 L
s
.71884 .35287 m
.72444 .35175 L
s
.32319 .34986 m
.32464 .34781 L
s
.32464 .34781 m
.32593 .35275 L
s
.31281 .32192 m
.31423 .31991 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32034 .35162 m
.32319 .34986 L
s
.31158 .31697 m
.31281 .32192 L
s
.31133 .32626 m
.31158 .31697 L
s
.31133 .32626 m
.31281 .32192 L
s
.31482 .35046 m
.32034 .35162 L
s
.31239 .3382 m
.31518 .33648 L
s
.73475 .32376 m
.73732 .31848 L
s
.73358 .33104 m
.73475 .32376 L
s
.31233 .34053 m
.31512 .3388 L
s
.73732 .31848 m
.74126 .31519 L
s
.73358 .33104 m
.7337 .3357 L
s
.72199 .36631 m
.72333 .36369 L
s
.72199 .36631 m
.72345 .36837 L
s
.7361 .32345 m
.73866 .31816 L
s
.73494 .33074 m
.7361 .32345 L
s
.72333 .36369 m
.72478 .36575 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73866 .31816 m
.74126 .31519 L
s
.73494 .33074 m
.73506 .33539 L
s
.31097 .34023 m
.31239 .3382 L
s
.72345 .36837 m
.72478 .36575 L
s
.31091 .34256 m
.31233 .34053 L
s
.74126 .31519 m
.7439 .31454 L
s
.31215 .34753 m
.31482 .35046 L
s
.31085 .3449 m
.31097 .34023 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73506 .33539 m
.73659 .34209 L
s
.7337 .3357 m
.73524 .34239 L
s
.31085 .3449 m
.31215 .34753 L
s
.73524 .34239 m
.73806 .34645 L
s
.7439 .31454 m
.7479 .31587 L
s
.73659 .34209 m
.73941 .34615 L
s
.29953 .31639 m
.30203 .3217 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29569 .31305 m
.29953 .31639 L
s
.73806 .34645 m
.74214 .34787 L
s
.7479 .31587 m
.75062 .31986 L
s
.73941 .34615 m
.74214 .34787 L
s
.29311 .31237 m
.29569 .31305 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30153 .34039 m
.30159 .33805 L
s
.30033 .33539 m
.30159 .33805 L
s
.29895 .33741 m
.30033 .33539 L
s
.29876 .34444 m
.30153 .34039 L
s
.74214 .34787 m
.74612 .34692 L
s
.29049 .31401 m
.29311 .31237 L
s
.28921 .31366 m
.29311 .31237 L
s
.29895 .33741 m
.30021 .34007 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74848 .3369 m
.74972 .33423 L
s
.74848 .3369 m
.74985 .33892 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29607 .34614 m
.29876 .34444 L
s
.28781 .31799 m
.29049 .31401 L
s
.74612 .34692 m
.74867 .34394 L
s
.74972 .33423 m
.75108 .33624 L
s
.28655 .31764 m
.28921 .31366 L
s
.74867 .34394 m
.75115 .33859 L
s
.75108 .33624 m
.75115 .33859 L
s
.29218 .34517 m
.29607 .34614 L
s
.75934 .31042 m
.76073 .31475 L
s
.75934 .31042 m
.75961 .31979 L
s
.28634 .32468 m
.28781 .31799 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28508 .32433 m
.28655 .31764 L
s
.75961 .31979 m
.76073 .31475 L
s
.76073 .31475 m
.76191 .31205 L
s
.28968 .34215 m
.29218 .34517 L
s
.2884 .34182 m
.29218 .34517 L
s
.76191 .31205 m
.76432 .30898 L
s
.28621 .32938 m
.28634 .32468 L
s
.28727 .33677 m
.28968 .34215 L
s
.28495 .32903 m
.28508 .32433 L
s
.28621 .32938 m
.28727 .33677 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27204 .30622 m
.28053 .30882 L
s
.286 .33643 m
.2884 .34182 L
s
.28495 .32903 m
.286 .33643 L
s
.76003 .33388 m
.76121 .33119 L
s
.76003 .33388 m
.76016 .33859 L
s
.76121 .33119 m
.76364 .32813 L
s
.7601 .33624 m
.76128 .33354 L
s
.76128 .33354 m
.76371 .33049 L
s
.76016 .33859 m
.76149 .34061 L
s
.27585 .34073 m
.27686 .30772 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76364 .32813 m
.76964 .32163 L
s
.76432 .30898 m
.76921 .30751 L
s
.76371 .33049 m
.76972 .32399 L
s
.76921 .30751 m
.7717 .30912 L
s
.76149 .34061 m
.76406 .34228 L
s
.27464 .34037 m
.27564 .30735 L
s
.7717 .30912 m
.77297 .3111 L
s
.76964 .32163 m
.77199 .31854 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76972 .32399 m
.77206 .3209 L
s
.77297 .3111 m
.77319 .31817 L
s
.77199 .31854 m
.77312 .31581 L
s
.77206 .3209 m
.77319 .31817 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76406 .34228 m
.769 .34088 L
s
.769 .34088 m
.77136 .3378 L
s
.27102 .33929 m
.27585 .34073 L
s
.25927 .30194 m
.26731 .30469 L
s
.77136 .3378 m
.7725 .33507 L
s
.7725 .33507 m
.77355 .32998 L
s
.77355 .32998 m
.77385 .33945 L
s
.7725 .33507 m
.77385 .33945 L
s
.27413 .35698 m
.27542 .35495 L
s
.27427 .35223 m
.27542 .35495 L
s
.263 .32958 m
.26383 .30352 L
s
.27299 .35425 m
.27427 .35223 L
s
.78113 .30606 m
.7822 .3033 L
s
.78113 .30606 m
.78235 .30803 L
s
.7822 .3033 m
.78342 .30527 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26184 .3292 m
.26268 .30313 L
s
.27299 .35425 m
.27413 .35698 L
s
.78235 .30803 m
.78342 .30527 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78273 .31987 m
.7848 .34805 L
s
.78249 .34879 m
.78273 .31987 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26169 .33395 m
.263 .32958 L
s
0 0 0 r
.25032 .29452 m
.25091 .29674 L
s
.255 .412 .882 r
.26054 .33357 m
.26184 .3292 L
s
.78319 .33412 m
.78365 .34842 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25819 .33519 m
.26169 .33395 L
s
.24725 .29742 m
.25481 .30032 L
s
.25819 .33519 m
.26054 .33357 L
s
.78249 .34879 m
.7838 .3532 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25594 .33442 m
.25819 .33519 L
s
.7838 .3532 m
.7848 .34805 L
s
.25268 .33087 m
.25594 .33442 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24985 .34926 m
.25153 .29909 L
s
.25065 .32529 m
.25268 .33087 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24876 .34887 m
.25045 .29867 L
s
.24553 .3477 m
.24985 .34926 L
s
.23791 .29594 m
.23975 .3016 L
s
.23975 .3016 m
.24052 .30921 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24035 .314 m
.24052 .30921 L
s
.23691 .29551 m
.23874 .30117 L
s
.23874 .30117 m
.2395 .30878 L
s
.23503 .29223 m
.23791 .29594 L
s
.23908 .32079 m
.24035 .314 L
s
.23933 .31358 m
.2395 .30878 L
s
.23503 .29223 m
.23691 .29551 L
s
.23807 .32037 m
.23933 .31358 L
s
.22623 .27088 m
.23273 .27413 L
s
.23309 .29134 m
.23503 .29223 L
s
.23689 .32476 m
.23908 .32079 L
s
.23589 .32434 m
.23807 .32037 L
s
.23109 .29284 m
.23309 .29134 L
s
.22807 .32333 m
.2299 .27275 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23383 .32591 m
.23689 .32476 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22713 .3229 m
.22897 .27228 L
s
.23383 .32591 m
.23589 .32434 L
s
.22903 .29676 m
.23109 .29284 L
s
0 0 0 r
.22197 .28207 m
.22247 .28144 L
s
.22106 .2816 m
.2225 .28059 L
s
.255 .412 .882 r
.23188 .32506 m
.23383 .32591 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23005 .32178 m
.23188 .32506 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22833 .31607 m
.23005 .32178 L
s
.22293 .28632 m
.22382 .28679 L
s
.22437 .32158 m
.22807 .32333 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22109 .2878 m
.22293 .28632 L
s
.22196 .28827 m
.22293 .28632 L
s
.22091 .29264 m
.22196 .28827 L
s
.22004 .29218 m
.22109 .2878 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22027 .30962 m
.22091 .29264 L
s
.21852 .28639 m
.22004 .29218 L
s
.21923 .31404 m
.22004 .29218 L
s
.21693 .28302 m
.21852 .28639 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21923 .31404 m
.22027 .30962 L
s
.21448 .28158 m
.21693 .28302 L
s
.21864 .30628 m
.21941 .30917 L
s
.21374 .30105 m
.21864 .30628 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21827 .31602 m
.21923 .31404 L
s
.21648 .31755 m
.21827 .31602 L
s
.21279 .28305 m
.21448 .28158 L
s
.212 .28256 m
.21448 .28158 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21318 .31572 m
.21648 .31755 L
s
.21181 .28743 m
.21279 .28305 L
s
.21103 .28695 m
.212 .28256 L
s
.21223 .29767 m
.21374 .30105 L
s
.21144 .29719 m
.21374 .30105 L
s
.21163 .29231 m
.21181 .28743 L
s
.21163 .29231 m
.21223 .29767 L
s
.21085 .29183 m
.21103 .28695 L
s
.83527 .27888 m
.84249 .27389 L
s
.21085 .29183 m
.21144 .29719 L
s
.21166 .31234 m
.21318 .31572 L
s
.21106 .30698 m
.21185 .30745 L
s
.21176 .30989 m
.21185 .30745 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21097 .30943 m
.21166 .31234 L
s
.21097 .30943 m
.21106 .30698 L
s
.83752 .2774 m
.83953 .32899 L
s
.83826 .2769 m
.84027 .32852 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83727 .33037 m
.84454 .32571 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84249 .27389 m
.84393 .27534 L
s
.84249 .27389 m
.84459 .27483 L
s
.20431 .30269 m
.20494 .30563 L
s
.20484 .30809 m
.20494 .30563 L
s
.20402 .31008 m
.20484 .30809 L
s
.20351 .30467 m
.20431 .30269 L
s
.19747 .26958 m
.20193 .27317 L
s
.20351 .30467 m
.20412 .30761 L
s
.84393 .27534 m
.84543 .27924 L
s
.20192 .30864 m
.20402 .31008 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84459 .27483 m
.84608 .27873 L
s
.84543 .27924 m
.84627 .28367 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19858 .30621 m
.19997 .27164 L
s
.19794 .30572 m
.19933 .27112 L
s
.20066 .3052 m
.20192 .30864 L
s
.84608 .27873 m
.84691 .28316 L
s
.19953 .29927 m
.20066 .3052 L
s
.84627 .28367 m
.84721 .29057 L
s
.19918 .29135 m
.19953 .29927 L
s
.84691 .28316 m
.84783 .29007 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84454 .32571 m
.8458 .32228 L
s
.84454 .32571 m
.84646 .3218 L
s
.84721 .29057 m
.8477 .30296 L
s
.84783 .29007 m
.84833 .30247 L
s
.19607 .30424 m
.19858 .30621 L
s
.8458 .32228 m
.84692 .31635 L
s
.84945 .26825 m
.85333 .26457 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84737 .3109 m
.8477 .30296 L
s
.84646 .3218 m
.84756 .31587 L
s
.84692 .31635 m
.84737 .3109 L
s
.848 .31041 m
.84833 .30247 L
s
.84756 .31587 m
.848 .31041 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85117 .26668 m
.85258 .30147 L
s
.19317 .2863 m
.19398 .26645 L
s
.19101 .28424 m
.19488 .28783 L
s
.85172 .26616 m
.85314 .30096 L
s
.19262 .28579 m
.19343 .26593 L
s
.19225 .26735 m
.19312 .27336 L
s
.85086 .30297 m
.85314 .30096 L
s
.19081 .26328 m
.19225 .26735 L
s
.85253 .28601 m
.85338 .29297 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18983 .26221 m
.19081 .26328 L
s
.85338 .29297 m
.85466 .29695 L
s
.19184 .31876 m
.19246 .30374 L
s
.1916 .31075 m
.19246 .30374 L
s
.18878 .26363 m
.18983 .26221 L
s
.18832 .2631 m
.18983 .26221 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19031 .31477 m
.1916 .31075 L
s
.1916 .31075 m
.19184 .31876 L
s
.85466 .29695 m
.85579 .29844 L
s
0 0 0 r
.18373 .24976 m
.18444 .25422 L
s
.255 .412 .882 r
.18766 .26756 m
.18878 .26363 L
s
.18722 .26702 m
.18832 .2631 L
s
.85579 .29844 m
.85728 .2969 L
s
.18865 .31579 m
.19031 .31477 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85659 .2924 m
.85717 .29439 L
s
.85659 .2924 m
.85697 .28938 L
s
.85697 .28938 m
.85754 .29137 L
s
.18701 .27202 m
.18766 .26756 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18321 .2803 m
.18332 .28096 L
s
.5 Mabswid
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18658 .27149 m
.18722 .26702 L
s
.85728 .2969 m
.85765 .29388 L
s
.85754 .29137 m
.85765 .29388 L
s
0 0 0 r
.18282 .28244 m
.18317 .28454 L
s
.255 .412 .882 r
.18765 .31479 m
.18865 .31579 L
s
.18627 .27901 m
.18701 .27202 L
s
0 0 0 r
.18196 .27781 m
.18282 .28244 L
s
.255 .412 .882 r
.18584 .27849 m
.18658 .27149 L
s
0 0 0 r
.18206 .3004 m
.18255 .29924 L
s
.255 .412 .882 r
.1868 .31127 m
.18765 .31479 L
s
.18634 .31077 m
.18765 .31479 L
s
.18574 .29158 m
.18627 .27901 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85966 .26511 m
.85985 .25955 L
s
.85966 .26511 m
.85987 .27012 L
s
.85985 .25955 m
.86088 .25541 L
s
.18532 .29106 m
.18584 .27849 L
s
.18609 .30521 m
.1868 .31127 L
s
.85987 .27012 m
.86048 .27461 L
s
.86006 .26457 m
.86024 .25901 L
s
.86006 .26457 m
.86027 .26959 L
s
.86024 .25901 m
.86088 .25541 L
s
.18565 .3047 m
.18634 .31077 L
s
.18574 .29158 m
.18586 .29966 L
s
.18586 .29966 m
.18609 .30521 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86027 .26959 m
.86087 .27408 L
s
.18532 .29106 m
.18543 .29914 L
s
.86048 .27461 m
.86173 .27553 L
s
.86088 .25541 m
.86193 .25376 L
s
.18543 .29914 m
.18565 .3047 L
s
.86087 .27408 m
.86173 .27553 L
s
.8609 .28468 m
.86101 .2872 L
s
.8609 .28468 m
.86129 .28416 L
s
.86101 .2872 m
.86151 .2892 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86129 .28416 m
.8614 .28668 L
s
.86193 .25376 m
.86269 .25518 L
s
.86173 .27553 m
.86386 .27483 L
s
.86151 .2892 m
.86237 .29068 L
s
.18149 .28834 m
.18361 .2915 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86269 .25518 m
.86352 .25912 L
s
.1825 .28993 m
.18267 .25242 L
s
.17999 .28569 m
.18267 .25242 L
s
.86237 .29068 m
.86376 .28858 L
s
.18027 .28622 m
.18235 .25998 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86352 .25912 m
.86359 .25352 L
s
.86352 .25912 m
.86448 .28191 L
s
.86359 .25352 m
.86404 .24988 L
s
.86381 .25857 m
.86387 .25296 L
s
.86381 .25857 m
.86456 .27629 L
s
.86387 .25296 m
.86404 .24988 L
s
.86386 .27483 m
.86427 .27683 L
s
.86376 .28858 m
.86428 .28498 L
s
.86404 .24988 m
.8643 .24932 L
s
.86428 .28498 m
.86448 .28191 L
s
.86448 .28191 m
.86456 .27629 L
s
.17999 .28569 m
.18049 .24796 L
s
.17812 .2814 m
.18049 .24796 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17832 .28194 m
.18017 .25556 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86631 .28379 m
.86773 .28002 L
s
.17758 .27978 m
.17898 .28355 L
s
0 0 0 r
.8702 .23775 m
.87051 .24081 L
s
.8702 .23775 m
.8702 .23355 L
s
.8702 .23355 m
.87051 .2366 L
s
.255 .412 .882 r
.8662 .24427 m
.86698 .28218 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87051 .24081 m
.87051 .2366 L
s
.255 .412 .882 r
.86653 .2519 m
.86718 .28164 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17867 .24232 m
.17881 .24289 L
s
.17832 .24374 m
.17867 .24232 L
s
.17844 .2443 m
.17867 .24232 L
s
0 0 0 r
.8713 .25902 m
.87305 .30359 L
s
.255 .412 .882 r
.1781 .24885 m
.17844 .2443 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8662 .24427 m
.86832 .27785 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.178 .24828 m
.17832 .24374 L
s
.17734 .26678 m
.1781 .24885 L
s
0 0 0 r
.87127 .22713 m
.87103 .22947 L
s
.255 .412 .882 r
.178 .24828 m
.17804 .24203 L
s
.17701 .27137 m
.178 .24828 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87225 .28097 m
.87321 .30305 L
s
.255 .412 .882 r
.8672 .23973 m
.86832 .27785 L
s
.17801 .23834 m
.17804 .24203 L
s
.86753 .2474 m
.86844 .27731 L
s
.17701 .27137 m
.17734 .26678 L
s
.17789 .23662 m
.17801 .23834 L
s
0 0 0 r
.87305 .30359 m
.87353 .31044 L
s
.255 .412 .882 r
.17723 .26623 m
.17724 .26311 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8713 .25902 m
.87336 .30252 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17724 .26311 m
.177 .2572 L
s
.1768 .2734 m
.17701 .27137 L
s
0 0 0 r
.87353 .31044 m
.87336 .30252 L
s
.87149 .22962 m
.87175 .23811 L
s
.255 .412 .882 r
.17653 .27489 m
.1768 .2734 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17775 .23804 m
.17789 .23662 L
s
.17775 .23747 m
.17789 .23662 L
s
0 0 0 r
.87134 .22478 m
.87149 .22962 L
s
.87131 .2236 m
.87134 .22478 L
s
.255 .412 .882 r
.17634 .2727 m
.17653 .27489 L
s
.17752 .24262 m
.17775 .23804 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86882 .27513 m
.86908 .27184 L
s
.8672 .23973 m
.869 .27349 L
s
.177 .2572 m
.17708 .2535 L
s
.177 .2572 m
.17708 .25293 L
s
.17754 .24205 m
.17775 .23747 L
s
0 0 0 r
.8714 .2261 m
.87131 .2236 L
s
.87135 .22551 m
.87131 .2236 L
s
.255 .412 .882 r
.1773 .24777 m
.17752 .24262 L
s
0 0 0 r
.87303 .26753 m
.87341 .27381 L
s
.255 .412 .882 r
.17708 .2535 m
.1773 .24777 L
s
.17731 .24721 m
.17754 .24205 L
s
.17642 .26901 m
.17634 .2727 L
s
.17708 .25293 m
.17731 .24721 L
s
0 0 0 r
.87161 .2323 m
.8714 .2261 L
s
.255 .412 .882 r
.17664 .26328 m
.17664 .26383 L
s
.17653 .26642 m
.17664 .26383 L
s
0 0 0 r
.87154 .23171 m
.87135 .22551 L
s
.255 .412 .882 r
.17653 .26587 m
.17642 .26901 L
s
0 0 0 r
.87341 .27381 m
.87359 .27641 L
s
.255 .412 .882 r
.17653 .26587 m
.17664 .26328 L
s
.86773 .24002 m
.868 .24576 L
s
.868 .24576 m
.86837 .25408 L
s
.86738 .2337 m
.86773 .24002 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87123 .22772 m
.87459 .30514 L
s
.87127 .22713 m
.87464 .30461 L
s
.255 .412 .882 r
.86837 .25408 m
.86893 .26704 L
s
0 0 0 r
.87472 .30301 m
.87459 .30514 L
s
.87202 .24281 m
.87161 .2323 L
s
.255 .412 .882 r
.86767 .23945 m
.86795 .24519 L
s
.86795 .24519 m
.86833 .25352 L
s
.86729 .23313 m
.86767 .23945 L
s
.86699 .22939 m
.86738 .2337 L
s
.86833 .25352 m
.86889 .26649 L
s
0 0 0 r
.87359 .27641 m
.87356 .27531 L
s
.87193 .24223 m
.87154 .23171 L
s
.255 .412 .882 r
.86699 .22939 m
.86729 .23313 L
s
.86893 .26704 m
.86922 .27429 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86889 .26649 m
.86918 .27375 L
s
0 0 0 r
.87356 .27531 m
.87333 .27048 L
s
.87356 .27531 m
.87328 .26992 L
s
.87234 .25022 m
.87202 .24281 L
s
.255 .412 .882 r
.86675 .22824 m
.86699 .22939 L
s
.86922 .27429 m
.8694 .27896 L
s
0 0 0 r
.87226 .24965 m
.87193 .24223 L
s
.8729 .26192 m
.87234 .25022 L
s
.87333 .27048 m
.8729 .26192 L
s
.255 .412 .882 r
.86918 .27375 m
.86934 .27842 L
s
.86642 .2291 m
.86675 .22824 L
s
0 0 0 r
.87282 .26136 m
.87226 .24965 L
s
.87328 .26992 m
.87282 .26136 L
s
.86909 .21295 m
.87038 .2171 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8694 .27896 m
.8695 .2831 L
s
.17691 .26143 m
.17711 .25827 L
s
.17679 .26403 m
.17691 .26143 L
s
.86934 .27842 m
.86942 .28256 L
s
.17678 .26609 m
.17679 .26403 L
s
.17711 .25827 m
.17711 .26032 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17689 .26348 m
.17711 .26032 L
s
.8663 .23315 m
.86642 .2291 L
s
.17678 .26609 m
.17713 .26443 L
s
.86934 .2841 m
.8695 .2831 L
s
.86934 .2841 m
.86942 .28256 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86633 .23786 m
.86667 .24563 L
s
.86653 .2387 m
.86686 .24619 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17753 .2607 m
.17713 .26443 L
s
.8691 .28302 m
.86934 .2841 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86855 .27876 m
.8691 .28302 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86804 .27309 m
.86855 .27876 L
s
0 0 0 r
.86971 .21473 m
.87198 .26697 L
s
.8699 .21532 m
.87216 .26753 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86596 .20643 m
.86811 .21058 L
s
.87136 .2653 m
.87216 .26753 L
s
.255 .412 .882 r
.8678 .2721 m
.86813 .27977 L
s
.86799 .27288 m
.86813 .27977 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87312 .29334 m
.87314 .29011 L
s
.87279 .28579 m
.87314 .29011 L
s
.87276 .28902 m
.87279 .28579 L
s
.87276 .28902 m
.87312 .29334 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18674 .21201 m
.18772 .21063 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86695 .2082 m
.87036 .28741 L
s
.86726 .2088 m
.87067 .28795 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86298 .20545 m
.86416 .21416 L
s
.86146 .19992 m
.86298 .20545 L
s
.86937 .28579 m
.87067 .28795 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86049 .19874 m
.86146 .19992 L
s
.86529 .24062 m
.86545 .24442 L
s
.8647 .23626 m
.86529 .24062 L
s
.86443 .23949 m
.8647 .23626 L
s
.85963 .20134 m
.86049 .19874 L
s
.85911 .20076 m
.86049 .19874 L
s
.86492 .2509 m
.86545 .24442 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86443 .23949 m
.86503 .24385 L
s
.255 .412 .882 r
.85654 .21181 m
.85724 .2176 L
s
0 0 0 r
.85889 .20776 m
.85963 .20134 L
s
.255 .412 .882 r
.85603 .21124 m
.85676 .21711 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86418 .2536 m
.86492 .2509 L
s
.85834 .20718 m
.85911 .20076 L
s
.255 .412 .882 r
.85576 .22873 m
.85662 .22814 L
s
.85576 .22873 m
.85641 .22765 L
s
0 0 0 r
.85882 .21859 m
.85889 .20776 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1844 .26783 m
.18494 .26713 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86274 .25194 m
.86418 .2536 L
s
.255 .412 .882 r
.85764 .2384 m
.85776 .24107 L
s
.85714 .23785 m
.85764 .2384 L
s
.85736 .24319 m
.85776 .24107 L
s
.85714 .23785 m
.85725 .24052 L
s
0 0 0 r
.86156 .247 m
.86274 .25194 L
s
.86103 .24645 m
.86274 .25194 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85882 .21859 m
.85914 .22621 L
s
.85826 .21802 m
.85834 .20718 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85826 .21802 m
.85858 .22565 L
s
.85242 .19054 m
.85496 .19287 L
s
.85914 .22621 m
.86017 .23824 L
s
.86017 .23824 m
.86156 .247 L
s
.85858 .22565 m
.85962 .23768 L
s
.85962 .23768 m
.86103 .24645 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85242 .19054 m
.85464 .24423 L
s
.85307 .19113 m
.8553 .24478 L
s
.85124 .1932 m
.8529 .20199 L
s
.84899 .18765 m
.85124 .1932 L
s
.84754 .1865 m
.84899 .18765 L
s
.8462 .18918 m
.84754 .1865 L
s
.84543 .18861 m
.84754 .1865 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85261 .2426 m
.8553 .24478 L
s
.84574 .19629 m
.8462 .18918 L
s
.84496 .19573 m
.84543 .18861 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84574 .19629 m
.84746 .23881 L
s
.84496 .19573 m
.84668 .23827 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84427 .23667 m
.84746 .23881 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83634 .21296 m
.83635 .21334 L
s
.83752 .22203 m
.83803 .2238 L
s
.83635 .21334 m
.83752 .22203 L
s
.83544 .21148 m
.8355 .2128 L
s
.83667 .22149 m
.83814 .22651 L
s
.8355 .2128 m
.83667 .22149 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83698 .17911 m
.83789 .20232 L
s
.83608 .17855 m
.83789 .20232 L
s
.82132 .17029 m
.83698 .17911 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83928 .23739 m
.83931 .26044 L
s
.83928 .23739 m
.84021 .26095 L
s
.8325 .20295 m
.83371 .23426 L
s
.22074 .17201 m
.22715 .16877 L
s
.82714 .21543 m
.83311 .21858 L
s
.22283 .17092 m
.22745 .25009 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82442 .25293 m
.83307 .25732 L
s
.83307 .25732 m
.84021 .26095 L
s
.82448 .17192 m
.8276 .2544 L
s
.82551 .17246 m
.82864 .2549 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23395 .16559 m
.24116 .16248 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23463 .20541 m
.23454 .20818 L
s
.23588 .20215 m
.23463 .20541 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22789 .23814 m
.23751 .16403 L
s
.22409 .19329 m
.23427 .18864 L
s
.24365 .16146 m
.2527 .15794 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24554 .21545 m
.24746 .15994 L
s
.24684 .21498 m
.24875 .15944 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22745 .25009 m
.23871 .16351 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24766 .19108 m
.24856 .20254 L
s
.2417 .21688 m
.24684 .21498 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24856 .20254 m
.25094 .20958 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25094 .20958 m
.25351 .21265 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25351 .21265 m
.25763 .21128 L
s
.25651 .20372 m
.25777 .20727 L
s
.25651 .20372 m
.25803 .19926 L
s
.26903 .1641 m
.27222 .15521 L
s
.2672 .17652 m
.26903 .1641 L
s
.25803 .19926 m
.25929 .2028 L
s
.27222 .15521 m
.27681 .14986 L
s
.27049 .16364 m
.2737 .15476 L
s
.26865 .17606 m
.27049 .16364 L
s
.2737 .15476 m
.27681 .14986 L
s
.26694 .18451 m
.2672 .17652 L
s
.25916 .20681 m
.25929 .2028 L
s
.27681 .14986 m
.27984 .14896 L
s
.2684 .18406 m
.26865 .17606 L
s
.25763 .21128 m
.25916 .20681 L
s
.26694 .18451 m
.26801 .19608 L
s
.27984 .14896 m
.28434 .15161 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2684 .18406 m
.26948 .19564 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26801 .19608 m
.2707 .20324 L
s
.28434 .15161 m
.28723 .15874 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26948 .19564 m
.27219 .20281 L
s
.2707 .20324 m
.27508 .20598 L
s
.27219 .20281 m
.27508 .20598 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2972 .14417 m
.30883 .1413 L
s
.27508 .20598 m
.27966 .2047 L
s
.28326 .18771 m
.28494 .18326 L
s
.28326 .18771 m
.2847 .19133 L
s
.28494 .18326 m
.2864 .18687 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29976 .22801 m
.30213 .14293 L
s
.30144 .22764 m
.30379 .14252 L
s
.27966 .2047 m
.28289 .19982 L
s
.28628 .19091 m
.2864 .18687 L
s
.28289 .19982 m
.28628 .19091 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31567 .13973 m
.32798 .13709 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30257 .18688 m
.30571 .19423 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31976 .18312 m
.3209 .13858 L
s
.32153 .18277 m
.32266 .1382 L
s
.30571 .19423 m
.31073 .19718 L
s
.33519 .13566 m
.34812 .13327 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29478 .22915 m
.30144 .22764 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33938 .19163 m
.34069 .13461 L
s
.31073 .19718 m
.31419 .19644 L
s
.34124 .19131 m
.34253 .13427 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3178 .19164 m
.31976 .18312 L
s
.31419 .19644 m
.3178 .19164 L
s
.31419 .19644 m
.31956 .19128 L
s
.31956 .19128 m
.32153 .18277 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36025 .18827 m
.36141 .13105 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35567 .13198 m
.36916 .12986 L
s
.5 Mabswid
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36219 .18799 m
.36334 .13074 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33385 .19261 m
.34124 .19131 L
s
.37701 .12872 m
.391 .12688 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38218 .17295 m
.38297 .12791 L
s
.38419 .1727 m
.38497 .12765 L
s
.33891 .21219 m
.34068 .216 L
s
.33695 .21663 m
.33891 .21219 L
s
.33695 .21663 m
.33872 .22044 L
s
.39912 .12591 m
.41353 .12436 L
s
.36243 .17565 m
.36617 .18331 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35447 .18915 m
.36219 .18799 L
s
.33872 .22044 m
.34068 .216 L
s
.40459 .17038 m
.40526 .12522 L
s
.40666 .17017 m
.40732 .125 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36617 .18331 m
.37199 .18661 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37199 .18661 m
.37596 .18608 L
s
.38003 .18144 m
.38218 .17295 L
s
.38419 .1727 m
.38808 .18046 L
s
.38203 .18119 m
.38419 .1727 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42813 .12709 m
.43452 .12248 L
s
.42382 .13566 m
.42813 .12709 L
s
.43024 .12692 m
.43452 .12248 L
s
.43452 .12248 m
.43876 .12215 L
s
.37596 .18608 m
.38003 .18144 L
s
.37596 .18608 m
.38203 .18119 L
s
.42592 .13547 m
.43024 .12692 L
s
.43876 .12215 m
.44512 .12578 L
s
.42156 .14817 m
.42382 .13566 L
s
.42366 .14798 m
.42592 .13547 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38808 .18046 m
.39412 .18389 L
s
.59344 .12124 m
.59563 .12547 L
s
.59133 .1252 m
.59344 .12124 L
s
.44512 .12578 m
.44933 .13371 L
s
.59352 .12944 m
.59563 .12547 L
s
.42145 .15641 m
.42156 .14817 L
s
.59133 .1252 m
.59352 .12944 L
s
.42356 .15622 m
.42366 .14798 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4024 .17886 m
.40459 .17038 L
s
.39412 .18389 m
.39822 .18344 L
s
.56092 .11967 m
.56964 .12 L
s
.56964 .12 m
.57402 .12429 L
s
.40447 .17865 m
.40666 .17017 L
s
.47319 .12421 m
.47757 .11992 L
s
.47757 .11992 m
.48193 .11976 L
s
.47101 .12431 m
.47757 .11992 L
s
.42145 .15641 m
.4234 .16861 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48193 .11976 m
.48628 .12372 L
s
.46661 .13273 m
.47101 .12431 L
s
.57402 .12429 m
.57622 .1285 L
s
.42356 .15622 m
.42552 .16844 L
s
.42356 .15622 m
.44914 .15432 L
s
.55656 .12364 m
.56092 .11967 L
s
.46878 .13263 m
.47319 .12421 L
s
.39822 .18344 m
.4024 .17886 L
s
.39822 .18344 m
.40447 .17865 L
s
.49067 .11948 m
.49944 .11927 L
s
.55217 .11941 m
.55439 .12769 L
s
.55217 .11941 m
.55223 .13587 L
s
.57622 .1285 m
.5763 .14085 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48628 .12372 m
.49062 .13182 L
s
.55439 .12769 m
.55656 .12364 L
s
.52581 .11904 m
.53241 .12318 L
s
.52141 .11903 m
.52581 .11904 L
s
.46435 .1452 m
.46661 .13273 L
s
.51701 .12316 m
.52141 .11903 L
s
.51481 .12317 m
.52141 .11903 L
s
.46652 .1451 m
.46878 .13263 L
s
.53241 .12318 m
.53683 .13146 L
s
.5104 .13144 m
.51481 .12317 L
s
.5126 .13142 m
.51701 .12316 L
s
.55223 .13587 m
.55439 .12769 L
s
.57413 .14075 m
.57628 .13673 L
s
.4234 .16861 m
.42754 .17655 L
s
.42552 .16844 m
.42966 .17638 L
s
.57415 .14488 m
.5763 .14085 L
s
.56979 .1447 m
.57413 .14075 L
s
.44687 .16687 m
.44699 .15446 L
s
.46429 .15347 m
.46435 .1452 L
s
.44906 .16259 m
.44914 .15432 L
s
.50818 .14385 m
.5104 .13144 L
s
.51038 .14382 m
.5126 .13142 L
s
.46646 .15336 m
.46652 .1451 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56981 .14883 m
.57415 .14488 L
s
.55888 .15258 m
.56979 .1447 L
s
.42754 .17655 m
.43387 .18021 L
s
.255 .412 .882 r
.52251 .15777 m
.52436 .15738 L
s
0 0 0 r
.42966 .17638 m
.43387 .18021 L
s
.46429 .15347 m
.46638 .16579 L
s
.44683 .17102 m
.44906 .16259 L
s
.5589 .15672 m
.56981 .14883 L
s
.46646 .15336 m
.46856 .16569 L
s
.255 .412 .882 r
.56243 .16523 m
.56386 .16718 L
s
.55953 .16704 m
.56141 .16456 L
s
0 0 0 r
.44464 .17531 m
.44687 .16687 L
s
.50816 .15212 m
.50818 .14385 L
s
.51037 .1521 m
.51038 .14382 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49548 .15746 m
.49654 .16274 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43387 .18021 m
.4403 .17975 L
s
.44464 .17531 m
.44683 .17102 L
s
.55451 .1566 m
.55888 .15258 L
s
.4403 .17975 m
.44464 .17531 L
s
.57431 .16973 m
.57644 .16153 L
s
.57644 .16153 m
.57656 .17814 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.55452 .16074 m
.5589 .15672 L
s
.50816 .15212 m
.51035 .16454 L
s
.53686 .15212 m
.53688 .16041 L
s
.51037 .1521 m
.53686 .15212 L
s
.51037 .1521 m
.51256 .16452 L
s
.53466 .15209 m
.53468 .16454 L
s
.46638 .16579 m
.47069 .1739 L
s
.55232 .16069 m
.55451 .1566 L
s
.46856 .16569 m
.47288 .17381 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59392 .17488 m
.59415 .19989 L
s
.5937 .15003 m
.59632 .20001 L
s
.59198 .19976 m
.5937 .15003 L
s
.55234 .16484 m
.55452 .16074 L
s
.55232 .16069 m
.55235 .169 L
s
.57215 .1738 m
.57431 .16973 L
s
.57431 .16973 m
.57656 .17814 L
s
.53468 .16869 m
.53688 .16041 L
s
.48605 .17335 m
.49049 .16491 L
s
.47069 .1739 m
.47724 .1778 L
s
.47288 .17381 m
.47724 .1778 L
s
.56779 .17779 m
.57215 .1738 L
s
.51035 .16454 m
.51476 .17282 L
s
.53248 .17284 m
.53468 .16454 L
s
.51256 .16452 m
.51698 .17281 L
s
.55235 .169 m
.55457 .17321 L
s
.48163 .17765 m
.48605 .17335 L
s
.53248 .17284 m
.53468 .16869 L
s
.55457 .17321 m
.559 .1775 L
s
.47724 .1778 m
.48163 .17765 L
s
.559 .1775 m
.56779 .17779 L
s
.52805 .17698 m
.53248 .17284 L
s
.51476 .17282 m
.5214 .17696 L
s
.51698 .17281 m
.5214 .17696 L
s
.5214 .17696 m
.52805 .17698 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49032 .20666 m
.49067 .11948 L
s
.49253 .2066 m
.49286 .11942 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59198 .19976 m
.59422 .20826 L
s
.59422 .20826 m
.59632 .20001 L
s
.48369 .20684 m
.49253 .2066 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00@0[Jf]0?nV403oYQ00ojH@
0`00000:0?nV40<000002`3oYQ000`2][Jd000000?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>
0P2][Je^0;3PiP40oooo00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4@80[Jf]0`00
00030:f][@<000002`2][Jd2000000<0[Jf]0P00000:0:f][@040000002][Jd0[Jf]0:f][@H00000
1@2][Jd60?nU40030000003oYA00ojD@00H0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][F/0/>3V
0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00@0000000<0ojHA0:f][@2][Jd03@2]
[Jd2000000<0ojHA00<000000?nV4@2][Jd00P00000:0?nV408000001`3oYQ000`000000ojH@0?nV
40060?nV40050:f][@000000ojD@0?nU400000001P3oYA000`000000ojD@0?nU40020?nU40D0[Jf]
0P00000=0:f][AL0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00L0k9H>0`2][JeX0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ403`3oYQ4500000080ojHA1@2]
[Jd2000000@0[Jf]0P00000=0?nV4@8000001@3oYQ4010000000[Jf]0000000000090?nV40800000
203oYQ000`000000ojH@0?nV40060?nV40040:f][@0000000000000000P0ojD@00<000000?nU403o
YA001@3oYA0010000000ojD@0?nU400000070?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF
3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00D0ojHA100000030?nV4@D000001@2][Jd40?nV4@80
00001`3oYQ400`000000ojHA0?nV4@090?nV4@8000001P3oYQ4010000000[Jf]0000000000090?nV
408000002@3oYQ000`000000ojH@0?nV40050?nV40030:f][@000000000000T0ojD@00<000000?nU
403oYA001P3oYA000`000000ojD@000000070?nU40030:f][@3oXa00oj<@00/0oj<@2P2][Jd40?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF
3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@040:f][@3oYQ40ojHA0?nV4@D000001P2][Jd30?nV4@8000002@3oYQ400`00
0000ojHA0?nV4@060?nV4@030000003oYQ40ojHA00P0ojHA0P0000080?nV4@<00000203oYQ020000
00X0ojH@00<000000?nV403oYQ001@3oYQ000`2][Jd000000000000:0?nU40030000003oYA00ojD@
00H0ojD@00<000000?nU403oYA001P3oYA000`2][Jd0oj<@0?nS400E0?nS40L0[Jf]603lX1000`2]
[Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80
[Jf]4@3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01<0ojHA100000050:f][@80
ojHA0P0000090?nV4@800000203oYQ42000000T0ojHA00<000000?nV4@3oYQ401`3oYQ42000000P0
ojHA0`0000080?nV408000002`3oYQ000`000000ojH@0?nV40040?nV40030:f][@000000000000X0
ojD@00<000000?nU403oYA003`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0
[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40
oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00/0ojHA
0P0000030?nV4@D000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000002@3oYQ42000000P0ojHA
00<000000:f][@3oYQ40203oYQ400`000000ojHA0?nV4@060?nV4@8000002@3oYQ400`2][Jd00000
000000080?nV408000004P3oYQ000`2][Jd000000?nU400:0?nU40030000003oYA00ojD@00l0ojD@
00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP40060?bP40D0[Jf]3@3lX1000`2][Jd0mY`?
0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo
001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<0
[Jf]0?nV4@3oYQ40203oYQ43000000D0[Jf]0`3oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103o
YQ42000000T0ojHA0P0000070?nV4@80000000<0[Jf]0?nV4@3oYQ40203oYQ400`000000ojHA0?nV
4@050?nV4@8000002@3oYQ400`2][Jd00000000000080?nV408000004P3oYQ000`2][Jd000000?nU
400:0?nU40030000003oYA00ojD@00l0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
400;0?bP40D0[Jf]203lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0
[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ4200000080ojHA00@0
[Jf]000000000000[Jf]0P0000080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@800000
2@3oYQ42000000L0ojHA0P0000000`2][Jd0ojHA0?nV4@0@0?nV4@8000002@3oYQ400`2][Jd00000
000000080?nV408000004P3oYQ000`2][Jd000000?nU400:0?nU40030000003oYA00ojD@00l0ojD@
00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400@0?bP40H0[Jf]0P3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V
0@3oool006h0/>3V00<0[Jf]0>nH403_V100103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A01@0oj@A00@0[Jf]0000000000000000102][Jd40?nV4@800000203oYQ4200000080ojHA
00<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P0000070?nV4@80000000<0[Jf]0?nV4@3oYQ40
3`3oYQ42000000X0ojHA00<0[Jf]0000000000001`3oYQ02000001<0ojH@00<0[Jf]0?nU403oYA00
2@3oYA0200000140ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400F0?bP40@0[Jf]
5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo
001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00l0oj@A0P00
00020?nT4@80000000<0[Jf]000000000000203oYQ42000000P0ojHA0P0000020?nV4@030:f][@3o
YQ40ojHA00@0ojHA0P0000090?nV4@8000001`3oYQ42000000030:f][@3oYQ40ojHA00l0ojHA0P00
000:0?nV4@030:f][@000000000000L0ojH@0P00000C0?nV40030:f][@3oYA00ojD@00T0ojD@0P00
000A0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0:f]
[@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`
h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0<
0?nT4@<00000102][Jd00`3oY140[Jf]0?nV4@02000000P0ojHA0P0000080?nV4@8000000P3oYQ40
0`2][Jd0ojHA0?nV4@040?nV4@8000002@3oYQ42000000H0ojHA0P0000000`2][Jd0ojHA0?nV4@0@
0?nV4@8000002P3oYQ400`2][Jd00000000000070?nV408000004`3oYQ000`2][Jd0ojD@0?nU4008
0?nU408000004P3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l00`3fW0l40:f][@d0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0:
0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0:0?nT4@80000000<0[Jf]0000002][Jd01@3oY140102][Jd0ojHA000000000008
0?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P000006
0?nV4@80000000<0[Jf]0?nV4@3oYQ40403oYQ42000000X0ojHA00<0[Jf]0000000000001`3oYQ02
000001<0ojH@00<0[Jf]0?nU403oYA001`3oYA000`000000ojD@0000000B0?nU40030:f][@3oXa00
oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H1
0?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT
4@3oY1401`3oY1440:f][@80oj@A00<000000?nT4@3oY140103oY140102][Jd0ojHA000000000008
0?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P000006
0?nV4@80000000<0[Jf]0?nV4@3oYQ40403oYQ42000000X0ojHA00<0[Jf]0000000000001`3oYQ02
000001<0ojH@00<0[Jf]0?nU403oYA001@3oYA02000000030?nU40000000ojD@0180ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?102][Jd5
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool0
06H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00H0[Jf]0?nT4@3oY140oj@A0000003o
Y1440:f][@H0oj@A00<000000?nT4@3oY140103oY140102][Jd0ojHA0000000000080?nV4@800000
203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P0000060?nV4@800000
00<0[Jf]0?nV4@3oYQ40403oYQ42000000X0ojHA00<0[Jf]0000000000001`3oYQ02000001<0ojH@
00<0[Jf]0?nU403oYA00103oYA0010000000ojD@0?nU4000000D0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/
UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V
00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40050:f][@3oY140[Jf]0000002]
[Jd00P0000090?nT4@030000003oY140oj@A00@0oj@A00@0[Jf]0?nV4@0000000000203oYQ420000
00P0ojHA0P0000020?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00000:0?nV4@8000001P3oYQ420000
00030:f][@3oYQ40ojHA0100ojHA0P00000:0?nV4@030:f][@000000000000L0ojH@0P00000C0?nV
40030:f][@3oYA00ojD@0080ojD@0P0000000`3oYA0000000000000<0?nU40030000003oYA00ojD@
00H0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?
01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H1
0?ooo`00I02`h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00h0o:0@0`2][Jd0
0`000000oj@A0?nT4@020?nT4@030000003oY140oj@A00H0oj@A00<000000?nT4@3oY140103oY140
102][Jd0ojHA0000000000080?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ400`3o
YQ42000000X0ojHA0P0000060?nV4@80000000<0[Jf]0?nV4@3oYQ40403oYQ42000000X0ojHA00<0
[Jf]0000000000001`3oYQ0?000000H0ojH@00D0[Jf]0?nU403oYA00ojD@000000020?nU40030000
003oYA00ojD@00`0ojD@00<000000?nU403oYA001P3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V
00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX100
[Jf]000000050?nT4@030000003oY140oj@A00H0oj@A00<000000?nT4@3oY140103oY140102][Jd0
ojHA0000000000080?nV4@800000203oYQ4200000080ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ420000
00X0ojHA0P0000060?nV4@80000000<0[Jf]0?nV4@3oYQ400`3oYQ47000000H0ojHA0P00000:0?nV
4@030:f][@000000000000L0ojH@0P00000;0?nV408000001P3oYQ001@2][Jd0ojD@0?nU40000000
ojD@008000003`3oYA000`000000ojD@0?nU40060?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][D`0/>3V0@3oool0
0680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00T0o:0@0`2][Jd30?bP40030:f][@000000oj@A00D0oj@A00<000000?nT4@3oY1401@3oY1400`00
0000oj@A0?nT4@040?nT4@040:f][@3oYQ400000000000P0ojHA0P0000080?nV4@8000000P3oYQ40
0`2][Jd0ojHA0?nV4@030?nV4@8000002P3oYQ42000000H0ojHA200000050?nV4@8000001P3oYQ42
000000<0ojHA202][Jd2000000L0[Jf]0P00000;0:f][@800000202][Jd00`000000[Jf]00000003
0:f][@h0ojD@00<000000?nU403oYA001P3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H1
0?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX100103lX10300000080[Jf]1P3lX102000000H0oj@A00<000000?nT4@3oY1401@3oY1400`00
0000oj@A0?nT4@030?nT4@030:f][@3oYQ40ojHA00800000203oYQ42000000P0ojHA0P0000020?nV
4@030:f][@3oYQ40ojHA00<0ojHA0P00000:0?nV4@8000001P3oYQ42000000030:f][@3oYQ40ojHA
00D0ojHA0`2][Jd2000000H0[Jf]0P0000030:f][@L0ojHA00<0[Jf]0000000000001`3oYQ020000
00/0ojH@0P0000060?nV40040:f][@000000ojD@000000@0ojD@3P2][Jd00`000000[Jf]0?nU4006
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3PiP40oooo001P0;3PiP030:f][@3CQ`h0dhL>
00@0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP403lX10400000080[Jf]203lX100
0`000000oj@A0?nT4@0=0?nT4@030000003oY140oj@A00<0oj@A00@0[Jf]0?nV4@00000000002@3o
YQ42000000L0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00000:0?nV4@800000103o
YQ420:f][@800000202][Jd30?nV4@8000001`3oYQ42000000T0ojHA00<0[Jf]000000000000203o
YQ02000000X0ojH@0P0000060?nV40030:f][@000000000000X0ojD@00<000000?nU403oYA001P3o
YA000`000000ojD@0:f][@0;0:f][AP0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0
[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0
dhL>00D0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0000000000020:f][@8000002@3l
X102000000l0oj@A00<000000?nT4@3oY1400`3oY140102][Jd0ojHA0000000000080?nV4@800000
203oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ400`3oYQ42000000L0ojHA0`2][Jd2000000@0[Jf]
0P3oYQ42000000030:f][@3oYQ40ojHA00P0ojHA0P0000070?nV4@8000002@3oYQ401@2][Jd00000
0000003oYQ00@FWQ00H0ojH@0P00000:0?nV408000001P3oYQ000`2][Jd000000?nU400:0?nU4003
0000003oYA00ojD@00H0ojD@00<000000?nU403oYA001P3oYA000`2][Jd0oj<@0?nS40020?nS40X0
[Jf]3P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V100
2`3_V103000000030:f][@3lX100o:0@008000002@3lX102000000h0oj@A0P0000050?nT4@040:f]
[@3oYQ400000000000P0ojHA0P0000080?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@03
0:f][@000000000000L0[Jf]0`3oYQ42000000L0ojHA0P00000:0?nV4@8000001`3oYQ42000000T0
ojHA00<0[Jf]000000000000203oYQ02000000X0ojH@00<000000?nV403oYQ001@3oYQ000`2][Jd0
00000?nU40030?nU4003045Yh@3oYA00ojD@00@0ojD@00<000000?nU403oYA001P3oYA000`000000
ojD@0?nU40060?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]3@3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd00000000000030?bP408000002@3lX102000000h0oj@A0P0000050?nT4@040:f]
[@3oYQ400000000000P0ojHA0P0000080?nV4@80000000<0ojHA0:f][@2][Jd01@2][Jd00`3oYQ40
00000000000:0?nV4@8000001`3oYQ42000000X0ojHA00<000000?nV4@3oYQ401P3oYQ42000000T0
ojHA0`0000080?nV408000002P3oYQ000`000000ojH@0?nV40050?nV40030:f][@000000ojD@00T0
ojD@0P0000080?nU40030000003oYA00ojD@00H0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AH0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P<0[Jf]2`3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V100
1`3_V1000`000000kiP@0:f][@020:f][@8000000`3lX102000000T0o:0@0P00000>0?nT4@800000
1@3oY140102][Jd0ojHA0000000000080?nV4@8000001@3oYQ430:f][@80000000@0[Jf]0?nV4@3o
YQ40[Jf]1@3oYQ42000000X0ojHA0P0000070?nV4@8000002@3oYQ42000000P0ojHA00<000000?nV
4@000000203oYQ43000000T0ojH@0P0000080?nV408000001`3oYQ000`2][Jd000000?nU40090?nU
40800000203oYA000`000000ojD@0?nU40060?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP
403lX100o:0@1P2][Jd@0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0
0`2][Jd0fhX=0=^:3@020:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@16
0;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001@3_V1020000
0080[Jf]0P3_V1000`2][Jd000000?bP40030?bP40800000203lX102000000030:f][@3oY140oj@A
00`0oj@A0P0000050?nT4@040:f][@3oYQ400000000000P0ojHA0P0000050:f][@<0ojHA0P000003
0?nV4@030:f][@3oYQ40ojHA00<0ojHA0P00000:0?nV4@8000001`3oYQ42000000T0ojHA0P000009
0?nV4@8000001`3oYQ4010000000[Jf]0000000000090?nV40800000203oYQ000`000000ojH@0?nV
40060?nV40030:f][@000000ojD@00T0ojD@0P0000080?nU40030000003oYA00ojD@00H0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40070?bP40L0[Jf]2@3lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][@030000003K
RPd0fhX=00@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K
0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V102000000030:f][@3_
V100kiP@0080kiP@00<0[Jf]0000003lX1000`3lX102000000P0o:0@0P0000000`2][Jd0oj@A0?nT
4@0<0?nT4@8000001@3oY140102][Jd0ojHA0000000000050?nV4@<0[Jf]0P0000080?nV4@800000
0`3oYQ400`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000T0ojHA0P0000070?nV4@800000
2P3oYQ400`000000ojHA000000060?nV4@040000002][Jd00000000000X0ojH@0P0000070?nV4003
0000003oYQ00ojH@00H0ojH@00<0[Jf]0?nU40000000203oYA03000000P0ojD@00<000000?nU403o
YA001P3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1P2][Jd30?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@040=^:3@03
0:f][@000000000000@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`2][Je50;3P
iP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V100103_V1000`2]
[Jd000000>nH40040>nH40800000103lX102000000P0o:0@0P0000000`2][Jd0oj@A0?nT4@0<0?nT
4@8000001@3oY140102][Jd0ojHA0000000000050:f][@<0ojHA0P0000080?nV4@<000000P3oYQ40
0`2][Jd0ojHA0?nV4@030?nV4@8000002@3oYQ42000000T0ojHA0P0000070?nV4@030000003oYQ40
ojHA00X0ojHA00<000000?nV4@000000103oYQ400`000000ojHA0:f][@02000000/0ojH@0`000004
0?nV40030000003oYQ00ojH@00L0ojH@00@0[Jf]0?nU403oYA0000001`3oYA03000000L0ojD@0P00
00080?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100503lX1050:f][AD0mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@050=^:3@040:f][@000000000000000080fhX=
00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080kiP@0P2][Jd00`3_V100
00000>nH40040>nH40800000103lX102000000P0o:0@0P0000000`2][Jd0oj@A0?nT4@0<0?nT4@80
0000103oY1430:f][@800000203oYQ42000000P0ojHA0`0000020?nV4@030:f][@3oYQ40ojHA0080
ojHA0P0000000`3oYQ4000000?nV4@060?nV4@8000002P3oYQ400`2][Jd00000000000050?nV4@03
0000003oYQ40ojHA00`0ojHA0`0000020?nV4@040000003oYQ40ojHA0:f][@8000003@3oYQ050000
00X0ojH@00@0[Jf]0?nU403oYA00ojD@0`0000030?nU40040000003oYA00ojD@000000L0ojD@0`00
00070?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0:f]
[@030:f][A40mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@060=^:3@030000002]
[Jd0[Jf]0080000000<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V
0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@3_V100kiP@0080[Jf]
0`3_V1000`000000kiP@0>nH40030>nH40800000103lX102000000P0o:0@0P0000000`2][Jd0oj@A
0?nT4@0<0?nT4@800000102][Jd00`3oY140[Jf]0?nV4@02000000P0ojHA0P0000080?nV4@<00000
0P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@80000000<0ojHA0000003oYQ401P3oYQ42000000X0ojHA
00@0[Jf]0?nV4@0000000000103oYQ400`000000ojHA0?nV4@0>0?nV4@<000000`3oYQ400`2][Jd0
00000000000L0?nV40030:f][@3oYA00ojD@00@0ojD@0`0000030?nU40030000003oYA00ojD@00D0
ojD@0`0000070?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0
mY`?0?JL3`030?JL3`@0[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00H0
fhX=00<000000=^:3@3KRPd00P2][Jd2000000P0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0
/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h30:f][@D0kiP@00<000000>nH403_V1000`3_V102000000@0o:0@0P0000080?bP40800000
00<0[Jf]0?nT4@3oY1402P3oY1420:f][@8000001@3oY140102][Jd0ojHA0000000000080?nV4@80
0000203oYQ42000000040?nV4@000000ojHA0:f][@@0ojHA0P0000020?nV4@030000003oYQ40ojHA
00<0ojHA0P00000;0?nV4@040:f][@3oYQ40ojHA0?nV4@@000005`3oYQ400`2][Jd000000000000L
0?nV40030:f][@3oYA00ojD@0180ojD@0`0000070?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0@
0>bF3P030:f][@3KRPd0fhX=00H0fhX=00<000000=^:3@3KRPd00P3KRPd2000000P0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH40050>nH40030000003_V100kiP@00<0kiP@0P000004
0?bP40800000203lX102000000030:f][@3oY140oj@A00@0oj@A00<000000?nT4@3oY1400`2][Jd2
0?nT4@8000001@3oY140102][Jd0ojHA0000000000080?nV4@800000203oYQ42000000040?nV4@00
0000ojHA0:f][@<0ojHA0P0000040?nV4@8000000P3oYQ400`000000ojHA0?nV4@0;0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]000000000000703oYQ000`2][Jd0ojD@0?nU400B0?nU40<00000
1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
2`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@060=^:3@030000
003KRPd0fhX=0080fhX=0P0000080;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0
@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>0P2][Jd70>nH40030000
003_V100kiP@0080kiP@00<0[Jf]0000003lX100103lX102000000P0o:0@0P0000000`2][Jd0oj@A
0?nT4@030?nT4@8000000P2][Jd50?nT4@030000003oY140oj@A00@0oj@A00@0[Jf]0?nV4@000000
0000203oYQ42000000P0ojHA0P0000020?nV4@8000000`3oYQ400`000000ojHA0?nV4@050?nV4@80
00003P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@000000000001`0ojH@00<0[Jf]0?nU403o
YA004P3oYA03000000L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?00l0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00H0
fhX=00<000000=^:3@3KRPd00P3KRPd200000080[Jf]1P2iM@/00`2][Jd0R5H708QF1`0208QF1`03
0:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P80
[Jf]00<0dhL>0:f][@3_V1001P3_V1000`000000kiP@0>nH40020>nH40030:f][@000000o:0@00@0
o:0@00<000000?bP403lX1001`3lX102000000030:f][@3oY140[Jf]00<0[Jf]00<000000?nT4@00
00001P3oY142000000D0oj@A00<0[Jf]0000000000002@3oYQ42000000P0ojHA0P0000020?nV4@03
0:f][@3oYQ40000000800000603oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@000000000001`0
ojH@00<0[Jf]0?nU403oYA004P3oYA03000000L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01<0mY`?0`2][JdA0>bF3P030:f][@3KRPd0fhX=00H0
fhX=00<000000=^:3@3KRPd00P3KRPd200000080^GD;00@0[Jf]0;Ue2`00000000000P2iM@/00`2]
[Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2G
H0/0Uf0;0:f][@050=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd01`3_V1000`000000kiP@0>nH4002
0>nH40800000103lX102000000T0o:0@0P0000020:f][@@0oj@A00<000000?nT4@0000001P3oY142
000000D0oj@A00<0[Jf]0000000000002@3oYQ42000000H0ojHA100000020?nV4@030:f][@3oYQ40
ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd000000000000L0?nV40030:f][@3oYA00
ojD@0180ojD@0`0000070?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@06
0=^:3@030000003KRPd0fhX=0080fhX=0P0000030;Ue2`030000002iM@/000000080^GD;00<0[Jf]
08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@04
0=>73P030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1001@3_V1000`000000kiP@0>nH4002
000000030:f][@000000o:0@00<0o:0@0P0000070?bP4080[Jf]0P0000000`2][Jd0oj@A0?nT4@04
0?nT4@8000001P3oY142000000D0oj@A00<0[Jf]0000000000002@3oYQ42000000`0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@000000000001`0ojH@00<0[Jf]
0?nU403oYA004P3oYA03000000L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]
0=^:3@3KRPd01P3KRPd00`000000fhX=0=^:3@020=^:3@8000000`2iM@/00`000000[Jf]0;Ue2`02
000000030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd00`3CQ`h00`2][Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00H0kiP@0P000002
0>nH40800000103lX102000000D0o:0@0P2][Jd30?bP40030000002][Jd0oj@A00H0oj@A00<00000
0?nT4@3oY140103oY1400`000000oj@A000000040?nT4@030:f][@000000ojHA00H0ojHA0`00000>
0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd000000000000L
0?nV40030:f][@3oYA00ojD@0180ojD@0`0000070?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd9
0>bF3P030:f][@3KRPd0fhX=00H0fhX=00<000000=^:3@3KRPd00P3KRPd00`2][Jd000000;Ue2`02
0;Ue2`030000002iM@/0[Jf]00<000001028EPL20:f][D80/>3V0@3oool005T0/>3V00H0[Jf]09MP
2`2GH0/0Uf0;0:f][@3CQ`h20:f][@H0dhL>00<0[Jf]0>nH403_V1001P3_V10010000000kiP@0>nH
403_V102000000@0o:0@0P0000020?bP40<0[Jf]1@3lX1000`000000[Jf]0?nT4@050?nT4@030000
003oY140oj@A00D0oj@A00@000000?nT4@00000000000`3oY142000001P0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4@P0[Jf]0P00000T0:f][@d0ojD@0`0000070?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`03
0:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0fhX=00H0fhX=0P0000030=^:3@03
0:f][@000000^GD;0080^GD;00<000000;Ue2`2iM@/00P0000000`2][Jd0R5H708QF1`0208QF1`80
[Jf]@P2`h>H10?ooo`00F@2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_
V1001P3_V10010000000kiP@0>nH403_V102000000@0o:0@0P0000020:f][@P0o:0@00<000000:f]
[@3oY1401@3oY1400`000000oj@A0?nT4@050?nT4@040000003oY140oj@A0?nT4@@000006@3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA402][Jd70?nV4@030:f][@000000
000001`0ojH@00<0[Jf]0?nU403oYA001@3oYA0=0:f][@<000001`3oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:
0>bF3P80[Jf]103/UPh00`2][Jd0fhX=0=^:3@060=^:3@8000000`3KRPd00`2][Jd000000;Ue2`02
0;Ue2`030000002iM@/0^GD;0080000000<0[Jf]08QF1`28EPL00`28EPL00`2][Jd0/>3V0;3PiP10
0;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h00`2][Jd0kiP@0>nH4006
0>nH40040000003_V100kiP@0>nH408000000`3lX100102][Jd000000000000000040?bP40030000
003lX100o:0@0080o:0@0P0000050?nT4@030000003oY140oj@A00H0oj@A00<000000?nT4@3oY140
103oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][JdG0?nV4@030:f]
[@000000000001`0ojH@00<0[Jf]0?nU403oYA004P3oYA03000000`0[Jf]603oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][@030>bF
3P2][Jd0fhX=00L0fhX=0P0000040=^:3@050000002iM@/0^GD;0;Ue2`0000000P2iM@/200000080
[Jf]00D0000008QF1`28EPL0R5H70:f][@120;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080
[Jf]203CQ`h00`2][Jd0kiP@0>nH40070>nH40060000003_V100kiP@0>nH40000000o:0@0`2][Jd0
103lX10000000000000000030?bP408000001@3lX1000`000000oj@A0?nT4@030?nT4@030000003o
Y140oj@A00H0oj@A00<000000?nT4@3oY140103oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA00`0ojHA2P2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]000000000000703o
YQ000`2][Jd0ojD@0?nU400B0?nU40<000001`3oYA000`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3o
Xa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh30:f][@L0fhX=0P0000040=^:3@050000002iM@/0^GD;0;Ue2`0000000P2iM@/200000080[Jf]
0P00000208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2]
[Jd80=>73P030:f][@3_V100kiP@00L0kiP@00H000000>nH403_V100kiP@0000002][Jd40?bP40<0
00000`3lX102000000D0o:0@0P0000030?nT4@030000003oY140oj@A00L0oj@A00<000000?nT4@3o
Y140103oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd>0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]000000000000703oYQ000`2][Jd0ojD@0?nU400B0?nU4003
0000003oYA00000000L0ojD@00<0[Jf]0?nS403oXa00303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2]
[Jd0[Jf]1@3KRPd200000080fhX=00<000000=^:3@0000000`2iM@/00`000000^GD;0;Ue2`020000
00040:f][@28EPL0000000000080R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01@2]
[Jd0Uf0;0:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1001@000000kiP@0:f][@2]
[Jd0000000D0o:0@0`0000030?bP408000001@3lX1001@2][Jd000000?nT4@3oY140000000X0oj@A
00<000000?nT4@3oY140103oY1400`2][Jd0ojHA0?nV4@0D0?nV4@P0[Jf]603oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@000000000001`0ojH@00<0[Jf]0?nU403oYA004`3oYA000`000000ojD@
0?nU40060?nU40030:f][@3oXa00oj<@01H0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0=^:3@3KRPd20:f][@<0fhX=0P0000020=^:3@03
0000003KRPd0[Jf]00<0^GD;00H000000;Ue2`2iM@/0^GD;0000002][Jd2000000040:f][@000000
R5H70:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_
V100kiP@00L0kiP@00D000000:f][@3_V100kiP@000000050?bP4080000000@0o:0@0000003lX100
o:0@0P0000040?bP40030:f][@3oY140oj@A008000002`3oY1400`000000oj@A0?nT4@040?nT4@03
0:f][@3oYQ40ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ45000001`0ojH@00<0[Jf]0?nU403oYA004`3oYA000`000000ojD@0?nU40060?nU4003
0:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?
01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80[Jf]00<0fhX=0000
000000000P3KRPd00`000000fhX=0:f][@030;Ue2`060000002iM@/0^GD;0;Ue2`000000[Jf]0P00
00001028EPL000000000002][Je20;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00D0kiP@0P2][Jd01@000000kiP@0>nH403_V100000000D0o:0@
0P0000001@3lX10000000?bP403lX100000000D0o:0@00<0[Jf]0?nT4@3oY140303oY142000000H0
oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA004`3oYA000`000000
ojD@0?nU40060?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100203lX1060:f][@X0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0
fhX=00<0[Jf]0000000000000P3KRPd00`000000fhX=0:f][@030;Ue2`060000002iM@/0^GD;0;Ue
2`000000[Jf]0P0000001028EPL000000000000000120;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/0
0`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0kiP@0P2][Jd20>nH40050000003_V100
kiP@0>nH400000001@3lX102000000050?bP40000000o:0@0?bP400000001@3lX1000`2][Jd0oj@A
0?nT4@0<0?nT4@8000001P3oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1`2][Jd30?bP4003
0:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@060=^:3@80
000000D0[Jf]0=^:3@000000@FWQ0:f][@030;Ue2`060000002iM@/0^GD;0;Ue2`000000[Jf]0P00
00001028EPL000000:f][@0000120;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0
203CQ`h0102][Jd0kiP@0>nH403_V1020:f][@@0kiP@00<000000>nH403_V1000P0000050?bP4080
00000P3lX102000000H0o:0@00<0[Jf]0?nT4@3oY140303oY142000000D0oj@A1@2][Jd80?nV4@03
0000003oYQ40ojHA00/0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01D0o:0@1P2][JdD0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd01P3KRPd2000000050=^:3@2][Jd000000=^:3@2][Jd00`2iM@/01P000000^GD;0;Ue2`2iM@/0
00000:f][@80000000<0R5H700000028EPL00P0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0
0`2][Jd0dhL>0=>73P060=>73P040:f][@3_V100[Jf]0:f][@H0kiP@00D000000>nH403_V1000000
0:f][@050?bP408000002P3lX1000`2][Jd0oj@A0?nT4@0<0?nT4@80000000<0oj@A0:f][@2][Jd0
0P2][Jd00`3oY140[Jf]0?nV4@090?nV4@8000003@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][A00mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@070=^:3@040000003KRPd0fhX=00000080
[Jf]0`2iM@/01P000000^GD;0;Ue2`2iM@/000000;Ue2`80000000<0R5H700000028EPL00P000011
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P80[Jf]203_V1001@00
0000kiP@0>nH40000000[Jf]00<0o:0@0P00000<0?bP40030:f][@3oY140oj@A00/0oj@A00@0[Jf]
000000000000[Jf]1@3oY1400`2][Jd0ojHA0?nV4@080?nV4@030000003oYQ40000000`0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0103fW0l50:f][@/0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@070=^:3@@0000000<0fhX=0:f][@2][Jd00P2iM@/01P000000^GD;0;Ue2`2iM@/000000;Ue2`80
00000`28EPL200000440/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>
0P2][Jd90>nH40050000003_V100kiP@0000002][Jd04@3lX1000`2][Jd0oj@A0?nT4@070?nT4@@0
[Jf]00<0oj@A0000000000001P3oY1400`2][Jd0ojHA0?nV4@080?nV4@8000003@3oYQ400`2][Jd0
ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`090?JL3`D0[Jf]1P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00L0
fhX=00L000000=^:3@3KRPd000000=^:3@2][Jd0^GD;0080[Jf]00@0^GD;0000002iM@/0^GD;1000
000308QF1`800000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0103CQ`h0
0`2][Jd0dhL>0:f][@090>nH40050000003_V100kiP@0000002][Jd04@3lX1000`2][Jd0oj@A0?nT
4@030?nT4@@0[Jf]1@3oY142000000H0oj@A00<0[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV
4@0;0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?00h0mY`?102][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>00<0
[Jf]0=^:3@3KRPd01P3KRPd01P000000fhX=0=^:3@000000fhX=0:f][@<0^GD;00@0[Jf]0000002i
M@/0^GD;1000000308QF1`800000@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3C
Q`h00`3CQ`h0102][Jd0dhL>0=>73P2][Jd90>nH40050000003_V100kiP@0000002][Jd04@3lX100
0`2][Jd0oj@A0:f][@030:f][@T0oj@A0P0000060?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l04P3fW0l40:f][A40k9H>00<0[Jf]0=^:3@3KRPd01P3KRPd01P000000fhX=0=^:3@00
0000fhX=0:f][@@0^GD;00<000000;Ue2`2iM@/01000000308QF1`<00000@02`h>H10?ooo`00F02`
h>H20:f][@<0Uf0;00@0[Jf]0=>73P3CQ`h0dhL>0P2][Jd30=>73P030:f][@3_V100kiP@00L0kiP@
00D000000>nH403_V10000000:f][@0@0?bP40<0[Jf]3@3oY142000000H0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]3P3/UPh00`2][Jd0
fhX=0=^:3@060=^:3@060000003KRPd0fhX=0000003KRPd0[Jf]102iM@/00`000000[Jf]0;Ue2`04
000000<0R5H70`0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>73P2][Jd5
0=>73P030:f][@3_V100kiP@00L0kiP@00D000000>nH403_V10000000:f][@0>0?bP4080[Jf]00<0
o:0@0:f][@3oY1403@3oY142000000H0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL
3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00H0fhX=00H0
00000=^:3@3KRPd000000=^:3@2][Jd40;Ue2`030000002iM@/0[Jf]00@000000`28EPL300000400
/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0[Jf]00H0dhL>00<0[Jf]0>nH403_V100
1`3_V1001@000000kiP@000000000000[Jf]00/0o:0@0`2][Jd30?bP40030:f][@3oY140oj@A00X0
oj@A0`0000070?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P040>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@060=^:3@060000003KRPd0fhX=0000
003KRPd0[Jf]102iM@/00`000000^GD;0;Ue2`04000000<0R5H70`0000100;3PiP40oooo001H0;3P
iP80[Jf]0`2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1001`3_V1001@000000kiP@0000003_V100
[Jf]00T0o:0@0P2][Jd60?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX100
0`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>0`2][Jd60>bF3P030:f][@3KRPd0
fhX=00H0fhX=00H000000=^:3@3KRPd000000=^:3@2][Jd40;Ue2`030000002iM@/0^GD;00@00000
0`28EPL300000400/>3V0@3oool005P0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>7
3P060=>73P030:f][@3_V100kiP@00P0kiP@0P0000000`3_V100[Jf]0?bP40050?bP40<0[Jf]203l
X1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]103/
UPh00`2][Jd0fhX=0=^:3@060=^:3@060000003KRPd0fhX=0000003KRPd0[Jf]102iM@/01`000000
^GD;0;Ue2`2iM@/000000:f][@0000000`28EPL300000400/>3V0@3oool005P0/>3V00@0[Jf]09MP
2`2GH0/0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00T0kiP@0P0000000`3_V100[Jf]0?bP4002
0?bP40<0[Jf]2`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh0303/UPh30:f][@030>bF3P2][Jd0fhX=00L0fhX=0P0000001@3KRPd000000=^:3@3K
RPd0[Jf]00<0^GD;00L000000;Ue2`2iM@/0^GD;0000002][Jd0000000<0R5H70`0000100;3PiP40
oooo001H0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH40090>nH4080
000000<0kiP@0:f][@3lX1000P2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0k9H>0`2][Jd70=^:3@80
0000103KRPd01@000000^GD;0000002iM@/0000000<0^GD;00D000000:f][@000000[Jf]08QF1`04
00000400/>3V0@3oool005P0/>3V00H0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd70=>73P030:f][@3_
V100kiP@00T0kiP@0P0000030:f][A00o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA00`0ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=0:f]
[@2][Jd50=^:3@800000103KRPd00`000000^GD;0;Ue2`02000000<0^GD;00@000000:f][@000000
[Jf]1@0000100;3PiP40oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h0
1@3CQ`h00`2][Jd0kiP@0>nH40090>nH4080000000<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V
2P2][JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh0102][Jd0fhX=
0=^:3@3KRPd20:f][@<0fhX=0P0000040=^:3@030000002iM@/0^GD;00D0^GD;00@000000:f][@00
0000R5H71@0000100;3PiP40oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3C
Q`h01@3CQ`h00`2][Jd0kiP@0>nH40070>nH4080[Jf]0P0000000`3_V100[Jf]0?bP400@0?bP4003
0:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405@3oYQ480:f][ID0/>3V1P2][JdB0?bP4003
0:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@80
[Jf]00<0fhX=000000000000103KRPd00`000000^GD;0;Ue2`040;Ue2`80000000@0[Jf]00000000
0000R5H7100000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P03
0:f][@3_V100kiP@00D0kiP@0P2][Jd20>nH40040000003_V100kiP@0:f][A40o:0@00<0[Jf]0?nT
4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0[Jf]0?JL
3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00D0fhX=00<0[Jf]0000
00000000103KRPd00`000000^GD;0;Ue2`050;Ue2`050000002][Jd0R5H700000028EPL010000010
0;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@
00<0kiP@0P2][Jd40>nH40040000003_V100kiP@0:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=0P0000001@2][Jd0fhX=0=^:3@3K
RPd0000000P0^GD;00@0[Jf]08QF1`000000R5H7100000100;3PiP40oooo001G0;3PiP80[Jf]102G
H0/00`2][Jd0dhL>0=>73P050=>73P040:f][@3_V100kiP@0>nH4080[Jf]1P3_V10010000000kiP@
0>nH402][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1`2][Jfj0;3P
iPH0[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:
3@3KRPd01P3KRPd2000000050=^:3@2][Jd0[Jf]0=^:3@0000002@2iM@/01@2][Jd0000008QF1`00
0000[Jf]00800000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0
102][Jd0kiP@0:f][@2][Jd80>nH40040000003_V100kiP@0:f][A40o:0@00<0[Jf]0?nT4@3oY140
4@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0
1P3KRPd2000000<0fhX=00<0[Jf]0000002iM@/0202iM@/01@2][Jd0R5H7000000000000[Jf]0080
0000@02`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h20:f][@d0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f][A00mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@@00000103KRPd00`000000[Jf]
0:f][@070;Ue2`050:f][@28EPL0000008QF1`2][Jd00P0000100;3PiP40oooo001G0;3PiP80[Jf]
0`2GH0/00`2][Jd0dhL>0=>73P050=>73P80[Jf]3P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00H0fhX=0P0000040=^:3@040000002iM@/0^GD;0:f][@H0^GD;00D0[Jf]08QF1`28
EPL0R5H70:f][@0200000400/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00<0
dhL>0P2][Jd00`3CQ`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3o
Y140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3K
RPd01`3KRPd200000080fhX=00D000000;Ue2`2iM@/0^GD;0:f][@050;Ue2`050:f][@28EPL0R5H7
08QF1`2][Jd00`00000o0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P020=>7
3P050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140
oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@09
0=^:3@<00000102iM@/20:f][@<0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@03000003l0/>3V0@3o
ool005L0/>3V0P2][Jd309MP2`050:f][@3CQ`h0dhL>0=>73P2][Jd0103CQ`h00`2][Jd0kiP@0>nH
400;0>nH40030:f][@3lX100o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030000002iM@/0^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL0102][Jd00000
00000000000o0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0:f][@2][Jd50=>73P03
0:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0/>3V0`2][Jd>0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0R5H700@0[Jf]00000000
00000000?`2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;0P2][Jd70=>73P030:f][@3_V100kiP@00/0
kiP@00<0[Jf]0?bP403lX1002P3lX1020:f][@<0^K:V0`2][Jgj0;3PiP<0[Jf]00@0`kfk0:f][@2]
[Jd0[Jf]2`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF
1`28EPL00P28EPL3000003l0/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0
dhL>0=>73P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0
^K:V0P2][Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL3000003l0/>3V0@3oool005L0/>3V00@0[Jf]09MP2`2GH0/0
Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100103lX1030:f][@03
0;6[W@2][Jd0^K:V00X0^K:V0`2][Jg^0;3PiP<0[Jf]3`33_K/30:f][@@0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]0`28EPL3000003l0/>3V0@3oool005L0/>3V
00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36`;`0
[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H70`00000o0;3PiP40oooo001G0;3PiP060:f]
[@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100[Jf]
0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`h>H30:f]
[@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H70`00000o0;3PiP40oooo001G0;3PiP03
0:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0
[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0
[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@03
0:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0[Jf]08QF1`03000003l0/>3V0@3oool005L0
/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0
kiP@0P2][Jd2045Yh@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0
[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^080
[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00`00000o0;3P
iP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00H0
kiP@102][Jd2045Yh@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0
[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0@0
[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd00`00000o0;3P
iP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00<0
kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid2045Yh@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036`;`03`36`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080[Jf]1@3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70`00000o0;3PiP40oooo001G0;3PiP03
0:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f]
[@050:BNS`11JN40Y9j?0:BNS`2][Jd00P2aZid2045Yh@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`0
0`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP2
0:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28
EPL0R5H70080R5H70`00000o0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3C
Q`h0102][Jd0kiP@0:f][@2][Jd2045Yh@050:BNS`11JN40Y9j?0:BNS`2][Jd00P2aZid2045Yh@80
/J^M0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a0;B`/@2d/;42
0:f][@030=^:3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70`00000o0;3PiP40oooo001G
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@80Y9j?0P11JN420:BNS`@0@FWQ00<0
/J^M045Yh@11JN40102aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a
0;B`/@030;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL3000003l0/>3V0@3oool005L0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@2TWXl0Y9j?0080Y9j?0P11JN420:BNS`<0
@FWQ0P2aZid2045Yh@H0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0
];2a0;B`/@030;B`/@04045Yh@2d/;40[Jf]0:f][@P0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd0
0`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@D0Y9j?00<0@FWQ0:BNS`2TWXl00P2TWXl01011JN40[Jf]0;6[W@2aZid3045Yh@L0/J^M0`2]
[Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m
/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a
0;B`/@030;B`/@05045Yh@2d/;40];2a0;B`/@2][Jd01`2iM@/0102][Jd0R5H708QF1`28EPL20:f]
[@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>7
3P80[Jf]00<0@FWQ0:BNS`2TWXl00`2TWXl00`11JN40Y9j?0:BNS`020:BNS`04045Yh@2aZid0/J^M
0;6[W@80@FWQ00<0/J^M045Yh@2aZid01P2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jej
0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@02
0;B`/@03045Yh@2d/;40];2a0080];2a0P2][Jd50;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0
00000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00@0
[Jf]08Z5M@2:QGD0@FWQ1@2TWXl00`11JN40Y9j?0:BNS`020:BNS`04045Yh@2aZid0/J^M0;6[W@80
@FWQ0P2aZid2045Yh@D0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0
[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@020;B`/@06
045Yh@2d/;40];2a0;B`/@2][Jd0@FWQ0`2][Jd30;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<0
00000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00D0
[Jf]08Z5M@2:QGD0RXEe045Yh@020:f][@<0Y9j?0P11JN430:BNS`04045Yh@2aZid0/J^M0;6[W@80
@FWQ0P2aZid2045Yh@<0/J^M00<0@FWQ0;6[W@2][Jd0202i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a0080];2a00X0@FWQ0;B`/@2d/;40[Jf]0;B`/@11JN40
[Jf]09nKX011JN40[Jf]0P2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0
/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@@0RXEe00@0@FWQ0:BN
S`2TWXl0[Jf]0`2TWXl01@11JN40Y9j?0:BNS`2TWXl0@FWQ0080/J^M0P11JN440;6[W@03045Yh@2a
Zid0/J^M0080/J^M0P11JN4;0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2]
[JdA0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00?0<K0_0<0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a0080];2a00<0
@FWQ0:f][@2][Jd00P2d/;400`11JN40[Jf]09nKX002045Yh@<0[Jf]1028EPL00`2][Jd000000;3P
iP0n0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd00`11JN40RXEe08Z5M@03
08Z5M@04045Yh@2TWXl0Y9j?0:BNS`80[Jf]0P2TWXl01011JN40Y9j?0:BNS`11JN420;6[W@80@FWQ
102aZid00`11JN40/J^M0;6[W@030;6[W@<0@FWQ00<0^K:V045Yh@2i/ZH02P2i/ZH30:f][A40_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL02@36_kL_0:f][@/0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][@030<K0
_02][Jd0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP01P2][Jd0];2a0;B`/@2d/;40[Jf]045Y
h@@0];2a00@0@FWQ0:f][@2OVj00@FWQ0`2OVj000`2][Jd0R5H708QF1`0208QF1`030:f][@000000
/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe045Yh@0208Z5
M@03045Yh@2:QGD0@FWQ0080@FWQ00@0Y9j?045Yh@2TWXl0Y9j?0P2][Jd0102TWXl0@FWQ045Yh@11
JN420;6[W@80@FWQ102aZid00`11JN40/J^M0;6[W@030;6[W@03045Yh@2i/ZH0^K:V0080^K:V0P11
JN4:0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36
`;`00`2][Jd0`kfk0<>m^`050<>m^`03045Yh@33_K/0`kfk00D0`kfk00<0[Jf]0;ji^02n^KP0302n
^KP01P2][Jd0];2a0;B`/@2][Jd0];2a045Yh@@0];2a00<0@FWQ0:f][@11JN401@2OVj001@2][Jd0
R5H708QF1`28EPL0[Jf]00800000?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@0508Z5M@11JN40RXEe08Z5M@11JN400P2:QGD4045Yh@@0Y9j?00@0[Jf]045Yh@11JN40@FWQ0P2a
Zid2045Yh@@0/J^M00<0@FWQ0;6[W@2aZid00`2aZid00`11JN40^K:V0;VbYP030;VbYP<0@FWQ0P2i
/ZH00`11JN40^K:V0;VbYP030;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f][@31
^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36
`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk00D0`kfk0P11JN470<>m^`030:f][@2n
^KP0_[Vh00/0_[Vh0`2][Jd30;B`/@06045Yh@2d/;40];2a0;B`/@11JN40[Jf]1P2OVj001P2][Jd0
R5H708QF1`28EPL0[Jf]000003l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd0
0`2:QGD0@FWQ08Z5M@02045Yh@80RXEe00@0[Jf]045Yh@2TWXl0@FWQ0P2TWXl2045Yh@040:BNS`2]
[Jd0@FWQ045Yh@80/J^M0P11JN440;6[W@80@FWQ102aZid00`11JN40^K:V0;VbYP030;VbYP03045Y
h@2i/ZH0^K:V00<0^K:V0P11JN430;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f]
[@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f]
[@36`;`0[Jf]00<0[Jf]3@36`;`00`2][Jd0`kfk045Yh@060<>m^`03045Yh@33_K/0`kfk00D0`kfk
00<0[Jf]0;ji^02n^KP02P2n^KP20:f][@D0];2a00H0@FWQ0;B`/@2d/;40];2a045Yh@2][Jd709nK
X0050:f][@28EPL0R5H70:f][@000000?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`030:f]
[@0308Z5M@11JN40RXEe0080@FWQ0P2:QGD0102][Jd0Y9j?045Yh@11JN420:BNS`80@FWQ0P2TWXl2
045Yh@040:f][@2aZid0@FWQ045Yh@@0/J^M0P11JN440;6[W@03045Yh@2i/ZH0^K:V00<0^K:V00<0
@FWQ0;VbYP2i/ZH00`2i/ZH4045Yh@030;VbYP2][Jd0_[N/00`0_[N/102][Jd00`2n]j`0[Jf]0<6j
/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo
]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f][A40a/2l0P11
JN400`33_K/0@FWQ0<>m^`0<0<>m^`030:f][@2n^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`
/@040;B`/@06045Yh@2d/;40];2a0;B`/@11JN40[Jf]1`2OVj020:f][@0308QF1`2][Jd0000003l0
/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd00`2:QGD0@FWQ08Z5M@02045Yh@03
08Z5M@2][Jd0Y9j?00D0Y9j?00P0@FWQ0:BNS`2TWXl0Y9j?045Yh@2][Jd0/J^M0:f][@80@FWQ102a
Zid2045Yh@@0/J^M00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP030;VbYP80@FWQ0`2i
/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l00X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l00d0a/2l0`11JN401@2][Jd0`kfk0<>m
^`33_K/0@FWQ00`0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;40
0`2d/;401P11JN40];2a0;B`/@2d/;40@FWQ0:f][@L0Wi^P00D0[Jf]071^N@2][Jd0[Jf]0000000o
0;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<0102][Jd0RXEe045Yh@2:QGD2045Yh@0308Z5M@2][Jd0
Y9j?00D0Y9j?00H0@FWQ0:BNS`2TWXl0Y9j?045Yh@2][Jd20;6[W@80@FWQ0P2][Jd20;6[W@80@FWQ
102aZid00`11JN40^K:V0;VbYP030;VbYP03045Yh@2i/ZH0^K:V00<0^K:V0P11JN430;VbYP030:f]
[@2n]j`0@FWQ00<0@FWQ3@2n]j`00`2][Jd0`KZ`0<6j/0050:f][@`0`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
1@38`K/3045Yh@/0b<6k00<0[Jf]0<O1_037`K`01@37`K`50:f][@L0al6l00<0[Jf]0<K0_036`;`0
3@36`;`2045Yh@030<K0_02][Jd0`kfk0080`kfk00<0@FWQ0<>m^`33_K/02P33_K/00`2][Jd0_[Vh
0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@030;B`/@06045Yh@2d/;40];2a0;B`/@11
JN40[Jf]1P2OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80
[Jf]00H0RXEe045Yh@11JN40@FWQ08Z5M@2][Jd70:BNS`05045Yh@2TWXl0Y9j?045Yh@2][Jd00P2a
Zid2045Yh@80/J^M0P2][Jd2045Yh@@0/J^M00<0@FWQ0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;Vb
YP030;VbYP80@FWQ0`2i/ZH00`2][Jd0@FWQ045Yh@030;jg[003045Yh@2n]j`0_[N/00X0_[N/00<0
[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/00P38`K/4045Yh@d0b<6k00<0
[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00@0a/2l1011JN450<K0_080@FWQ00<0
a/2l0:f][@33_K/00P33_K/00`11JN40`kfk0<>m^`0:0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]
202n^KP00`2][Jd0];2a0;B`/@030;B`/@06045Yh@2d/;40];2a0;B`/@11JN40[Jf]1@2OVj000`2]
[Jd0Wi^P0:f][@02071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`03
0:f][@2:QGD0[Jf]0080RXEe00<0@FWQ08Z5M@2][Jd0202TWXl2045Yh@040:BNS`2][Jd0/J^M0;6[
W@80@FWQ102aZid00`11JN40[Jf]0:f][@030;6[W@03045Yh@2i/ZH0^K:V0080^K:V0P11JN450;Vb
YP80@FWQ0P2i/ZH00`2][Jd0_[N/045Yh@050;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg
[02n]j`00P11JN400`2n]j`0[Jf]0<6j/00;0<6j/0D0[Jf]0P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1
^`80@FWQ2P38`K/60:f][A40al6l00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0020<K0
_003045Yh@36`;`0a/2l0080a/2l00@0@FWQ0<K0_036`;`0[Jf]0P33_K/2045Yh@`0`kfk00@0[Jf]
0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@030;B`/@06045Yh@2d/;40];2a0;B`/@11JN40
[Jf]102OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`080:f][@2:QGD0RXEe0:f][@2:QGD0@FWQ08Z5M@2][Jd;0:BNS`030:f][@2a
Zid0/J^M00<0@FWQ0`2aZid00`11JN40/J^M0;6[W@020:f][@030;6[W@11JN40^K:V00<0^K:V0P11
JN450;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/045Yh@050;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0
@FWQ0;jg[011JN400P2n]j`2045YhA40`KZ`202][Jd@0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`040<S1^`80@FWQ0`38`K/70:f][@<0b<6k00<0
[Jf]0<O1_037`K`03`37`K`3045Yh@@0a/2l0P11JN450<K0_005045Yh@36`;`0a/2l0<K0_011JN40
0P36`;`0102][Jd0`kfk0<>m^`11JN450<>m^`03045Yh@33_K/0`kfk00@0`kfk0`2][Jd<0;ji^003
0:f][@2d/;40];2a00<0];2a00H0@FWQ0;B`/@2d/;40@FWQ0;B`/@2][Jd209nKX080[Jf]0`2OVj00
0`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2]
[Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M045Yh@03
045Yh@<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`2][Jd0@FWQ0:f][@030;VbYP80@FWQ1@2i/ZH2
045Yh@80^K:V00<0[Jf]045Yh@11JN401P2n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ102n]j`0
0`2][Jd0@FWQ0<6j/00A0<6j/0030:f][@33_K<0`kfc00<0`kfc2`2][Jd50<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/30:f][@80@FWQ0`2]
[Jd:0<S1^`030:f][@37`K`0al6l00P0al6l0`11JN420<O1_0<0@FWQ00<0al6l0:f][@36`;`00P36
`;`2045Yh@d0a/2l00@0[Jf]0<>m^`11JN40@FWQ1@33_K/01011JN40`kfk0<>m^`33_K/30:f][@03
0<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;402011JN40];2a0;B`/@11JN40];2a
0:f][@2OVj00[Jf]1@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]
0;6[W@2aZid00`11JN420;6[W@03045Yh@2aZid0/J^M00@0/J^M00<0@FWQ0;VbYP2][Jd00P2][Jd2
045Yh@D0^K:V0P11JN420;VbYP030:f][@11JN40@FWQ00/0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`0
0`2][Jd0@FWQ0<6j/0040<6j/003045Yh@31^[00`KZ`00X0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;
0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][@<0b<6k0P11JN4=0<S1^`030:f][@37`K`0
al6l00D0al6l1011JN460<O1_003045Yh@37`K`0[Jf]00<0a/2l0P11JN4=0<K0_0030:f][@11JN40
@FWQ00H0`kfk00@0@FWQ0:f][@2][Jd0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@2d
/;40];2a00<0];2a00<0@FWQ0;B`/@11JN400P2d/;420:f][@H0Wi^P00<0[Jf]071^N@1`KWT00P2]
[Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:QGD00`2:QGD2
0:f][@/0Y9j?00<0[Jf]0;6[W@2aZid00`2aZid3045Yh@D0/J^M0P11JN440;VbYP80@FWQ00<0[Jf]
0;VbYP2i/ZH00P2i/ZH01@11JN40^K:V0;VbYP2i/ZH0[Jf]0080@FWQ2`2n]j`00`11JN40_[N/0;jg
[0030;jg[0030:f][@31^[00@FWQ00@0`KZ`0P11JN4;0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0
[Jf]0<S1^`38`K/01038`K/2045Yh@d0b<6k1P11JN440<O1_080@FWQ1P37`K`00`11JN40al6l0:f]
[@030<K0_080@FWQ3@36`;`2045Yh@H0`kfk00<0[Jf]045Yh@33_K/01P33_K/00`2][Jd0_[Vh0;ji
^00;0;ji^0030:f][@2d/;40];2a00<0];2a00<0@FWQ0;B`/@11JN400P2d/;400`2][Jd0Wi^P09nK
X00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=P
D`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@0;0;6[W@80@FWQ102i/ZH2045Yh@030;VbYP2][Jd0[Jf]0080[Jf]00D0@FWQ0;VbYP2i/ZH0^K:V
0:f][@02045YhA00_[N/00@0[Jf]0<6j/031^[00@FWQ1031^[000`11JN40`KZ`0<6j/00:0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037
`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`040<S1^`80
@FWQ3@38`K/0102][Jd0al6l045Yh@11JN460<O1_080@FWQ1P37`K`00`11JN40al6l0:f][@020<K0
_080@FWQ3@36`;`2045Yh@@0`kfk0`2][Jd00`33_K/0@FWQ0<>m^`060<>m^`030:f][@2n^KP0_[Vh
00/0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;42045Yh@040;B`/@2][Jd0[Jf]0:f][@L0Wi^P00D0[Jf]
071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:
QGD30:f][@T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`11JN40[Jf]045Yh@030;VbYP80@FWQ1@2i
/ZH01@11JN40[Jf]0:f][@2i/ZH0[Jf]0080@FWQ402n]j`0102][Jd0`KZ`0<6j/011JN4A0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00
[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00@0b<6k0P11JN420<S1^`<0
@FWQ2038`K/0102][Jd0al6l045Yh@11JN460<O1_080@FWQ1P37`K`00`11JN40al6l0:f][@020<K0
_080@FWQ3036`;`01011JN40a/2l045Yh@33_K/20:f][@03045Yh@33_K/0`kfk0080`kfk00<0@FWQ
0<>m^`33_K/01@33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0030:f][@2d/;40];2a00<0];2a00<0@FWQ
0;B`/@2][Jd00P2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`
h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2]
[Jd70:BNS`030:f][@2aZid0/J^M00/0/J^M00<0@FWQ0:f][@11JN400`2i/ZH00`11JN40^K:V0;Vb
YP040;VbYP03045Yh@2i/ZH0^K:V0080[Jf]0P11JN4@0;jg[0040:f][@31^[00@FWQ045YhA40`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/00P11JN420<S1^`80@FWQ00<0b<6k045Yh@38`K/00P38`K/2045Yh@H0b<6k
00@0[Jf]0<O1_011JN40@FWQ1P37`K`2045Yh@H0al6l00<0@FWQ0<O1_02][Jd00P36`;`2045Yh@`0
a/2l0P11JN420:f][@80`kfk00<0@FWQ0<>m^`33_K/00P33_K/00`11JN40`kfk0<>m^`050<>m^`03
0:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;400P2d/;400`11JN40[Jf]0:f][@030;B`/@03
0:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP04
0:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`040:BN
S`030:f][@2aZid0/J^M00/0/J^M00@0@FWQ0:f][@2i/ZH0@FWQ0P2i/ZH00`11JN40^K:V0;VbYP04
0;VbYP05045Yh@2i/ZH0^K:V0;VbYP2][Jd00P11JN430:f][@d0_[N/0`11JN4B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01035_[D4045Yh@`0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38
`K/3045Yh@80b<6k00<0[Jf]045Yh@11JN401038`K/3045Yh@D0b<6k0P11JN450<S1^`040:f][@37
`K`0@FWQ045Yh@H0al6l0P11JN460<O1_003045Yh@37`K`0[Jf]0080a/2l0P11JN460<K0_003045Y
h@2][Jd0[Jf]0080[Jf]0P11JN400`36`;`0[Jf]0<>m^`020<>m^`03045Yh@33_K/0`kfk0080`kfk
00<0@FWQ0<>m^`33_K/01@33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0040:f][@2d/;40];2a0;B`/@80
[Jf]1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0
/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2]
[Jd0/J^M0;6[W@0;0;6[W@04045Yh@2][Jd0^K:V0;VbYP80@FWQ1`2i/ZH01@11JN40^K:V0;VbYP2i
/ZH0[Jf]0080@FWQ0`2n]j`30:f][@03045Yh@2n]j`0_[N/00D0_[N/1011JN4C0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01P35_[D7045Yh@L0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]045Yh@11JN400P11
JN4;0<S1^`80@FWQ0`38`K/2045Yh@030:f][@11JN40@FWQ00@0b<6k0`11JN460<S1^`80@FWQ1038
`K/0102][Jd0al6l045Yh@11JN460<O1_080@FWQ1P37`K`00`11JN40al6l0:f][@020<K0_080@FWQ
0`36`;`30:f][@80@FWQ0`36`;`01011JN40a/2l0<K0_02][Jd30<>m^`03045Yh@33_K/0`kfk0080
`kfk0P11JN460<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;400`2]
[Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=P
D`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0;0;6[
W@03045Yh@2i/ZH0^K:V00X0^K:V00D0@FWQ0;VbYP2i/ZH0^K:V0:f][@02045Yh@D0_[N/0P11JN44
0:f][@030;jg[011JN40@FWQ0080@FWQ00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00H0aKje0P11JN450<Fn]@80@FWQ1@35_[D00`2][Jd0@FWQ045Yh@05
045Yh@d0a[ng0`11JN400`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j00P0al6j0`11JN43
0<O1^P80@FWQ1037`KX4045Yh@d0b<6k00<0@FWQ0<S1^`38`K/00`38`K/3045Yh@D0b<6k0P11JN47
0<S1^`80@FWQ1038`K/0102][Jd0al6l045Yh@11JN460<O1_080@FWQ1P37`K`2045Yh@030:f][@36
`;`0a/2l0080@FWQ0`2][Jd30<K0_080@FWQ0`36`;`01011JN40a/2l0<K0_02][Jd20<>m^`80@FWQ
1033_K/2045Yh@H0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj00
1@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0
[Jf]0:BNS`2TWXl01`2TWXl30:f][@d0/J^M00<0@FWQ0;VbYP2i/ZH0202i/ZH00`11JN40^K:V045Y
h@030;VbYP030:f][@2n]j`0@FWQ00H0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`01P11JN40[Jf]045Y
h@2][Jd0_[N/0:f][@L0`KZ`00<0@FWQ0<6j/031^[002P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00H0aKje0P11JN460<Fn]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo]`02045Yh@h0
a[ng0P11JN430<Jo]`03045Yh@37`KP0al6h0080al6h0P11JN460<O1^003045Yh@37`KP0al6h00@0
al6h00@0@FWQ0<O1^037`KP0[Jf]2037`KX2045Yh@<0al6j0P11JN400`37`KX0@FWQ045Yh@050<O1
^P030:f][@11JN40@FWQ00`0b<6k0P11JN460<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`060<S1
^`03045Yh@38`K/0b<6k0080b<6k00@0[Jf]0<O1_011JN40@FWQ1P37`K`2045Yh@H0al6l0P11JN43
0:f][@030<K0_011JN40@FWQ00D0a/2l0P11JN430<K0_008045Yh@36`;`0a/2l0:f][@33_K/0@FWQ
0<>m^`11JN440<>m^`80@FWQ1P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0
Wi^P09nKX00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f]
[@2TWXl0Y9j?00T0Y9j?0P2][Jd<0;6[W@03045Yh@2i/ZH0^K:V00T0^K:V0P11JN430;VbYP040:f]
[@2n]j`0_[N/045Yh@D0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@80_[N/1@2][Jd40<6j/003
045Yh@31^[00`KZ`00X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80
@FWQ1`35_[D00`11JN40aKje0<Fn]@020<Fn]@030:f][@36_kL0a[ng0080@FWQ3@36_kL2045Yh@@0
a[ng00<0[Jf]045Yh@37`KP00P11JN480<O1^003045Yh@37`KP0al6h00@0al6h00@0@FWQ0<O1^037
`KP0[Jf]1`37`KX2045Yh@H0al6j0`11JN450<O1^P030:f][@11JN40@FWQ00`0b<6k0P11JN460<S1
^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k0080b<6k00@0[Jf]0<O1
_011JN40@FWQ1P37`K`2045Yh@030<O1_02][Jd0[Jf]00<0[Jf]0P11JN40102][Jd0a/2l0<K0_036
`;`2045Yh@D0a/2l00<0@FWQ0<K0_036`;`00`36`;`5045Yh@H0`kfk0P11JN460<>m^`030:f][@2n
^KP0_[Vh00P0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2]
[Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0
[Jf]0080[Jf]2@2aZid00`11JN40^K:V0;VbYP0>0;VbYP050:f][@2n]j`0_[N/0;jg[011JN400`2n
]j`00`11JN40_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/0080_[N/00@0[Jf]0<6j/011JN40`KZ`
102][Jd00`11JN40[Jf]0:f][@0:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
1P35_[D2045Yh@L0aKje0P11JN430<Fn]@030:f][@36_kL0a[ng0080@FWQ3036_kL2045Yh@D0a[ng
00@0[Jf]045Yh@11JN40@FWQ2@37`KP00`11JN40al6h0<O1^0030<O1^080@FWQ0P37`KP00`2][Jd0
al6j0<O1^P050<O1^P80@FWQ1`37`KX2045Yh@D0al6j00<0[Jf]045Yh@11JN403038`K/2045Yh@H0
b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00H0b<6k00<0@FWQ0<S1^`38`K/00P38`K/0102][Jd0
al6l045Yh@11JN440<O1_080[Jf]0P11JN400`2][Jd0al6l0<O1_0030<O1_080@FWQ00@0[Jf]0<K0
_036`;`0a/2l0P11JN450<K0_003045Yh@36`;`0a/2l00D0a/2l00<0[Jf]0<>m^`33_K/01P33_K/2
045Yh@H0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;40
0`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@0508Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0@FWQ0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0020;jg[0@0@FWQ1@2n]j`00`11JN40_[N/0;jg[0020;jg
[0030:f][@31^[00@FWQ00D0`KZ`00<0@FWQ0<6j/031^[001`2][Jd30<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D01P35_[D2045Yh@L0aKje0P11JN430<Fn]@030:f][@36_kL0a[ng
0080@FWQ3036_kL2045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ2037`KP3045Yh@@0al6h0`11JN42
0<O1^0030:f][@37`KX0al6j00<0al6j0P11JN480<O1^P80@FWQ1@37`KX00`2][Jd0@FWQ045Yh@0<
0<S1^`80@FWQ1P38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`02
0<S1^`040:f][@37`K`0@FWQ045Yh@@0[Jf]0P37`K`2045Yh@H0al6l0P11JN400`2][Jd0a/2l0<K0
_0020<K0_080@FWQ0`36`;`00`11JN40a/2l0<K0_0060<K0_0030:f][@33_K/0`kfk00H0`kfk0P11
JN460<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0
[Jf]09nKX02OVj00102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0
RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]0P2aZid0
0`11JN40/J^M045Yh@0@0;VbYP030:f][@2n]j`0_[N/00/0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`0
0`2][Jd0`KZ`045Yh@050<6j/003045Yh@31^[00`KZ`00L0`KZ`1`2][JdB0<>m/`030:f][@35_[D0
aKje00H0aKje0P11JN480<Fn]@80@FWQ0P35_[D00`2][Jd0a[ng0<Jo]`02045Yh@`0a[ng0P11JN45
0<Jo]`040:f][@37`KP0@FWQ045Yh@P0al6h0`11JN440<O1^0<0@FWQ0P37`KP00`2][Jd0al6j0<O1
^P020<O1^P80@FWQ2@37`KX2045Yh@D0al6j00<0[Jf]045Yh@11JN403038`K/2045Yh@H0b<6k0P11
JN400`38`K/000000<S1^`030<S1^`03045Yh@38`K/0b<6k00H0b<6k00<0@FWQ0<S1^`2][Jd0102]
[Jd2045Yh@H0al6l0P11JN460<O1_080@FWQ00<0[Jf]0<K0_036`;`00P36`;`6045Yh@T0a/2l00<0
[Jf]0<>m^`33_K/01@33_K/2045Yh@H0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo
001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@070;6[W@<0[Jf]0P11JN4@0;VbYP030:f][@2n]j`0_[N/00`0_[N/00D0@FWQ0;jg[02n]j`0_[N/
0:f][@02045Yh@D0`KZ`00<0@FWQ0<6j/031^[002P31^[00102][Jd0`kfc0<>m/`33_K<70:f][@/0
`kfc00<0[Jf]0<Fn]@35_[D01P35_[D2045Yh@P0aKje0P11JN420<Fn]@030:f][@36_kL0a[ng0080
@FWQ3036_kL2045Yh@D0a[ng00@0[Jf]0<O1^011JN40@FWQ2037`KP3045Yh@@0al6h00<0@FWQ0<O1
^011JN400P37`KP00`2][Jd0al6j0<O1^P020<O1^P80@FWQ2@37`KX2045Yh@D0al6j00<0[Jf]045Y
h@11JN403@38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ00<000000<S1^`38`K/00`38`K/01011
JN40b<6k0<S1^`38`K/40:f][@80@FWQ00H0[Jf]0<S1^`38`K/0b<6k0:f][@37`K`2045Yh@H0al6l
0P11JN460<O1_080@FWQ00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ
1P33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02O
Vj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080RXEe
00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]2`2i/ZH01@11JN40^K:V
0;VbYP2i/ZH0[Jf]00l0_[N/1011JN400`31^[00@FWQ0<6j/0040<6j/003045Yh@31^[00`KZ`00X0
`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D01P35_[D2045Yh@T0
aKje0P11JN401035_[D0[Jf]0<Jo]`36_kL2045Yh@`0a[ng0P11JN450<Jo]`040:f][@37`KP0@FWQ
045Yh@P0al6h00<0@FWQ0<O1^011JN400`37`KP2045Yh@050<O1^011JN40al6h0<O1^02][Jd01037
`KX2045Yh@T0al6j0P11JN450<O1^P030:f][@11JN40@FWQ00h0b<6k1011JN420<S1^`040:f][@11
JN40b<6k0<S1^`@0[Jf]00@0@FWQ0:f][@2][Jd0[Jf]1038`K/2045Yh@@0b<6k00@0[Jf]0<O1_011
JN40@FWQ1P37`K`00`11JN40al6l0<O1_0050<O1_080@FWQ00<0[Jf]0<K0_036`;`04@36`;`00`2]
[Jd0`kfk0<>m^`050<>m^`03045Yh@33_K/0`kfk00@0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a
00T0];2a00<0[Jf]09nKX02OVj000P2][Je60;3PiP40oooo001N0;3PiP80[Jf]0P2:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd60;VbYP80
@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00@FWQ00@0`KZ`0P11JN4<0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][Jd30<Fn]@80@FWQ2@35_[D2045Yh@040<Fn]@2][Jd0a[ng0<Jo
]`80@FWQ3@36_kL2045Yh@@0a[ng00@0[Jf]0<O1^011JN40@FWQ2037`KP00`11JN40al6h045Yh@03
0<O1^080@FWQ00D0al6h045Yh@37`KP0al6h0:f][@040<O1^P03045Yh@37`KX0al6j00P0al6j0P11
JN450<O1^P030:f][@11JN40@FWQ00l0b<6k0`2][Jd4045Yh@80[Jf]1038`K/00`11JN40b<6k0<S1
^`050<S1^`80@FWQ1038`K/0102][Jd0al6l045Yh@11JN460<O1_003045Yh@37`K`0al6l00<0al6l
0P11JN420<O1_0030:f][@36`;`0a/2l0140a/2l00<0[Jf]0<>m^`33_K/01@33_K/01011JN40`kfk
0<>m^`33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0
Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid0
2`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]0`2i/ZH2045Yh@<0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/0040<6j/0<0@FWQ2`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje00<0aKje0`2][Jd2045Yh@L0[Jf]0P35_[D2045Yh@040<Fn]@2][Jd0a[ng0<Jo]`80
@FWQ3P36_kL3045Yh@80a[ng00@0[Jf]0<O1^011JN40@FWQ1`37`KP2045Yh@80al6h00<0@FWQ0<O1
^037`KP00P11JN420<O1^003045Yh@37`KP0[Jf]00@0al6j00<0@FWQ0<O1^P37`KX01P37`KX6045Y
h@<0al6j00<0[Jf]045Yh@11JN400`38`K/<0:f][@D0b<6k00<0[Jf]045Yh@38`K/01@38`K/00`11
JN40b<6k0<S1^`040<S1^`80@FWQ1@38`K/00`2][Jd0al6l045Yh@07045Yh@/0al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^00;0;ji
^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2TWXl00`2][Jd0
/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd00`2i/ZH0@FWQ0;VbYP020;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001031^[03045Yh@/0`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ1`35_[D20:f][@80@FWQ102][Jd2045Yh@L0
[Jf]2P36_kL2045Yh@040:f][@37`KP0@FWQ045Yh@L0al6h0P11JN420<O1^004045Yh@37`KP0al6h
045Yh@<0al6h00<0@FWQ0<O1^02][Jd01037`KX00`11JN40al6j0<O1^P040<O1^P`0[Jf]0P11JN43
0:f][A40b<6k00<0[Jf]045Yh@38`K/01@38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/01038`K/0
102][Jd0al6l045Yh@11JN4A0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33
_K/40:f][@L0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2`
h>H0/>3V04P0/>3V0@3oool00680/>3V00<0[Jf]0:BNS`2TWXl0202TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00T0^K:V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00
`KZ`00@0`KZ`0`11JN4;0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01P35_[D2
045Yh@T0aKje0P11JN401035_[D0[Jf]0<Jo]`36_kL3045Yh@H0a[ng302][Jd4045Yh@L0[Jf]0P11
JN420:f][@04045Yh@2][Jd0@FWQ045Yh@<0[Jf]00<0@FWQ0:f][@2][Jd0102][Jd00`11JN40[Jf]
0:f][@040:f][@/0al6j00@0[Jf]045Yh@11JN40@FWQ1@38`K/00`11JN40b<6k0<S1^`040<S1^`80
@FWQ1@38`K/00`2][Jd0@FWQ0<S1^`050<S1^`03045Yh@38`K/0@FWQ00<0b<6k00<0@FWQ0<S1^`38
`K/01@38`K/0102][Jd0al6l045Yh@11JN4A0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401P2d/;420:f]
[D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i
/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[001031^[03045Yh@/0`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ2@35_[D2045Yh@040<Fn]@2][Jd0a[ng0<Jo
]`<0@FWQ4P36_kL0102][Jd0al6h045Yh@11JN470<O1^080@FWQ0P37`KP01011JN40al6h045Yh@11
JN430<O1^003045Yh@37`KP0[Jf]00@0al6j00<0@FWQ0<O1^P37`KX03`37`KX0102][Jd0@FWQ045Y
h@11JN440<S1^`80@FWQ1P38`K/2045Yh@D0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@80b<6k
0`11JN480<S1^`040:f][@37`K`0@FWQ045YhA40al6l00<0[Jf]0<K0_036`;`03P36`;`40:f][@h0
`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0
/>3V0@3oool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0_[N/00<0[Jf]0<6j/031^[001031^[03045Yh@/0`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ2@35_[D2045Yh@040<Fn
]@2][Jd0a[ng0<Jo]`80@FWQ00<0a[ng045Yh@36_kL00`36_kL00`11JN40a[ng0<Jo]`040<Jo]`80
@FWQ1036_kL00`2][Jd0al6h045Yh@080<O1^006045Yh@37`KP0al6h0<O1^011JN40al6h0P11JN43
0<O1^003045Yh@37`KP0[Jf]00@0al6j0P11JN4@0<O1^P050:f][@11JN40@FWQ0<S1^`11JN401038
`K/00`11JN40b<6k0<S1^`050<S1^`03045Yh@38`K/0b<6k00<0@FWQ00<0[Jf]0<S1^`38`K/00P38
`K/2045Yh@l0b<6k00@0[Jf]0<O1_011JN40@FWQ3P37`K`01011JN40al6l0<O1_02][Jd;0<K0_0D0
[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d
/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0`KZ`
0<6j/0040<6j/0<0@FWQ2`31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00H0aKje
0P11JN490<Fn]@80@FWQ00@0aKje0:f][@36_kL0a[ng0P11JN400`36_kL0@FWQ0<Jo]`020<Jo]`80
@FWQ1P36_kL2045Yh@@0a[ng00<0[Jf]0<O1^011JN401`37`KP2045Yh@@0al6h0P11JN450<O1^003
045Yh@2][Jd0al6j00<0al6j0P11JN4@0<O1^P030:f][@11JN40@FWQ0080b<6k00D0@FWQ0<S1^`38
`K/0b<6k045Yh@080<S1^`80@FWQ0`38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0@FWQ
045Yh@d0al6l00D0@FWQ0<O1_011JN40al6l0:f][@070<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m
^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo
001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[001031^[000`11JN40`KZ`045Y
h@0;0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D01P35_[D2045Yh@T0aKje0P11
JN400`35_[D0[Jf]045Yh@03045Yh@80a[ng00D0@FWQ0<Jo]`36_kL0a[ng045Yh@070<Jo]`03045Y
h@36_kL0a[ng0080a[ng00<0[Jf]045Yh@37`KP01`37`KP2045Yh@@0al6h0P11JN450<O1^003045Y
h@2][Jd0al6j00<0al6j0P11JN4?0<O1^P@0@FWQ0`38`K/4045Yh@d0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/0102][Jd0al6l045Yh@11JN4>0<O1_004045Yh@37`K`0al6l0:f][@80a/2l1@2][Jd;0<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB
0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/
00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/0060<6j/003045Yh@31^[00`KZ`00X0`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ2035_[D2045Yh@80aKje00<0[Jf]0<Jo
]`36_kL00P11JN430<Jo]`@0@FWQ2036_kL5045Yh@H0al6h1`11JN420<O1^080@FWQ0P37`KP6045Y
h@<0al6j0P11JN4@0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102]
[Jd0al6l045Yh@11JN4?0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0
_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00l0_[N/1@2][Jd40<6j/003045Yh@31^[00`KZ`00X0`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ2035_[D2045Yh@80aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00<0al6j00<0@FWQ0<O1
^P37`KX02037`KX00`11JN40al6j0<O1^P030<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/0102][Jd0al6l045Yh@11JN4:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][ED0/>3V0@3oool0
06l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0102]
[Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@06
0<Fn]@80@FWQ2035_[D2045Yh@80aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j00<0al6j00<0@FWQ0<O1^P37`KX02037`KX00`11JN40al6j0<O1^P03
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0al6l045Yh@11
JN440<O1_0H0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP01`2n^KP30:f][EL0/>3V0@3oool00740/>3V0`2][Jd80;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0080<6j/0L0[Jf]0`31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00H0aKje0P11JN470<Fn]@80@FWQ0`35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX00`37`KX0
0`11JN40al6j0<O1^P070<O1^P80@FWQ1@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k0P11JN400`37`K`0[Jf]0:f][@030:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3P
iP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[003`31^[070:f][A80`kfc00<0[Jf]0<Fn]@35_[D01P35_[D2045Yh@L0aKje0P11JN430<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P030<O1
^P80@FWQ2037`KX2045Yh@D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1
^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m
/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@060<Fn]@80@FWQ1P35_[D2045Yh@@0aKje00<0[Jf]0<Jo
]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00<0al6j0P11JN470<O1
^P<0@FWQ1@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m
^`030:f][@2n^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0
`kfc202][Jd30<>m/`030:f][@35_[D0aKje00@0aKje1011JN450<Fn]@80@FWQ1@35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01037`KX2045Yh@H0
al6j0`11JN450<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=0<>m
^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][Jd50<Fn]@H0@FWQ1P35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX01@37`KX2045Yh@<0
al6j0P11JN420<O1^P03045Yh@37`KX0al6j00<0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0
`kfk102][JeU0;3PiP40oooo001n0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]
1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
1`37`KX3045Yh@@0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]
1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`060<>m^`<0[Jf]J@2`h>H10?ooo`00PP2`h>H30:f][@P0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D03`35_[DA0:f][@L0a[ng0`0000020<Jo]`030:f][@37`KP0al6h00X0al6h:02]
[JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool0
08P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3P
iP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00
T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102]
[Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1
^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`0
0`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h
01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V
1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40
oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`
h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?oo
o`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5321 .33086 m
.53043 .33408 L
s
.53378 .33406 m
.5321 .33086 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53043 .33408 m
.53211 .33728 L
s
.53211 .33728 m
.53378 .33406 L
s
.55047 .33057 m
.55713 .33039 L
s
.54714 .33385 m
.55047 .33057 L
s
.5 Mabswid
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54548 .3371 m
.54714 .33385 L
s
.5 Mabswid
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52953 .34085 m
.53284 .33857 L
s
.53284 .33857 m
.53781 .33852 L
s
.52788 .34086 m
.53284 .33857 L
s
.53781 .33852 m
.54112 .34072 L
s
.49313 .33824 m
.5047 .33848 L
s
.52622 .34537 m
.52788 .34086 L
s
.52788 .34537 m
.52953 .34085 L
s
0 0 0 r
.55649 .35428 m
.55891 .35608 L
s
.255 .412 .882 r
.54938 .33831 m
.55103 .33827 L
s
.54608 .34063 m
.54938 .33831 L
s
.54773 .3406 m
.54938 .33831 L
s
0 0 0 r
.59204 .33052 m
.59357 .33191 L
s
.5925 .33021 m
.59521 .33181 L
s
.255 .412 .882 r
.54112 .34072 m
.54444 .34518 L
s
.54444 .34518 m
.54608 .34063 L
s
.54609 .34514 m
.54773 .3406 L
s
.52622 .34537 m
.52622 .34989 L
s
.52788 .34537 m
.52788 .34988 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52622 .34989 m
.52788 .3544 L
s
.52788 .34988 m
.52954 .35439 L
s
.47501 .33762 m
.47993 .34008 L
s
.47993 .34008 m
.4832 .34471 L
s
.47501 .33762 m
.47829 .34001 L
s
.45864 .33682 m
.47501 .33762 L
s
.47829 .34001 m
.48156 .34465 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.56159 .35858 m
.56226 .35921 L
s
.55814 .35873 m
.55893 .35931 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4832 .34471 m
.48483 .34928 L
s
.48156 .34465 m
.48318 .34922 L
s
.52788 .3544 m
.53286 .35663 L
s
.52954 .35439 m
.53286 .35663 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49965 .37005 m
.49974 .33839 L
s
.49799 .37001 m
.49809 .33835 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46484 .38483 m
.46518 .33717 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.53049 .39225 m
.53064 .38863 L
s
.5337 .38863 m
.53386 .39223 L
s
.255 .412 .882 r
.54444 .34518 m
.54449 .36553 L
s
.54609 .34514 m
.54614 .36097 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56108 .36966 m
.5659 .34457 L
s
0 0 0 r
.57732 .3699 m
.57736 .37482 L
s
.57898 .3688 m
.57902 .37474 L
s
.255 .412 .882 r
.55942 .36971 m
.56587 .3378 L
s
.54282 .35877 m
.53286 .35663 L
s
.46319 .38475 m
.46354 .33709 L
s
.48483 .34928 m
.48645 .35612 L
s
.48318 .34922 m
.4848 .35607 L
s
.49969 .35645 m
.50133 .36327 L
s
0 0 0 r
.53217 .38863 m
.53217 .39224 L
s
.255 .412 .882 r
.54282 .35877 m
.54448 .361 L
s
.52789 .36345 m
.52789 .36572 L
s
.52789 .36345 m
.52955 .36344 L
s
.4864 .36745 m
.48645 .35612 L
s
.52955 .36344 m
.52955 .36571 L
s
.51128 .36568 m
.51294 .36342 L
s
.51294 .36342 m
.5146 .3657 L
s
.54449 .36553 m
.54614 .36097 L
s
.48475 .3674 m
.4848 .35607 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52789 .36572 m
.52956 .36798 L
s
.50133 .36327 m
.50463 .36786 L
s
.5146 .36797 m
.5146 .3657 L
s
.51128 .36568 m
.51294 .36796 L
s
.52956 .36798 m
.53288 .37022 L
s
.54284 .36783 m
.54449 .36553 L
s
.51293 .37023 m
.5146 .36797 L
s
.50463 .36786 m
.50795 .37018 L
s
.53953 .37015 m
.54284 .36783 L
s
.50795 .37018 m
.51293 .37023 L
s
.53288 .37022 m
.53953 .37015 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49302 .3699 m
.49965 .37005 L
s
.48472 .37422 m
.4864 .36745 L
s
.55446 .36985 m
.56603 .36949 L
s
.48306 .37416 m
.48475 .3674 L
s
.60343 .33801 m
.60825 .33538 L
s
.60024 .34276 m
.60343 .33801 L
s
.60505 .33789 m
.60825 .33538 L
s
.60186 .34265 m
.60505 .33789 L
s
.59866 .3474 m
.60024 .34276 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60825 .33538 m
.61147 .33513 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57428 .36916 m
.57904 .344 L
s
.56587 .3378 m
.57263 .36923 L
s
.579 .33723 m
.58578 .36861 L
s
.57263 .36923 m
.579 .33723 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.59708 .35666 m
.59708 .35705 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5971 .35431 m
.59866 .3474 L
s
.61147 .33513 m
.61632 .337 L
s
.60028 .34729 m
.60186 .34265 L
s
.59872 .3542 m
.60028 .34729 L
s
.48304 .37871 m
.48472 .37422 L
s
.48138 .37866 m
.48306 .37416 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5971 .35431 m
.5972 .36567 L
s
.47971 .38316 m
.48304 .37871 L
s
.59872 .3542 m
.59883 .36557 L
s
.58086 .36886 m
.59069 .36834 L
s
.61632 .337 m
.61958 .34126 L
s
.47805 .3831 m
.48138 .37866 L
s
.61949 .33446 m
.61971 .35262 L
s
.62109 .33432 m
.62131 .35248 L
s
.47473 .38526 m
.47971 .38316 L
s
.47473 .38526 m
.47805 .3831 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5972 .36567 m
.59889 .3724 L
s
.45826 .3845 m
.47473 .38526 L
s
.59883 .36557 m
.60052 .3723 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63064 .33342 m
.64168 .33227 L
s
.61489 .35302 m
.62611 .35205 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63696 .33277 m
.63741 .36468 L
s
.63539 .33294 m
.63583 .36484 L
s
.60052 .3723 m
.60219 .37675 L
s
.59889 .3724 m
.60056 .37686 L
s
.60056 .37686 m
.60386 .38121 L
s
.60219 .37675 m
.60549 .3811 L
s
.60386 .38121 m
.60876 .38316 L
s
.60549 .3811 m
.60876 .38316 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62151 .36844 m
.62167 .38217 L
s
.61998 .37543 m
.62151 .36844 L
s
.60876 .38316 m
.612 .38293 L
s
.63722 .35098 m
.6389 .35766 L
s
.612 .38293 m
.61682 .38027 L
s
.61682 .38027 m
.61998 .37543 L
s
.61998 .37543 m
.62167 .38217 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63106 .3653 m
.63741 .36468 L
s
.6389 .35766 m
.64212 .36191 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64212 .36191 m
.6453 .36386 L
s
.66344 .3319 m
.66798 .32899 L
s
.66198 .33666 m
.66344 .3319 L
s
.64836 .35893 m
.64989 .35647 L
s
.64989 .35647 m
.65148 .35858 L
s
.64836 .35893 m
.64996 .36105 L
s
.6453 .36386 m
.65 .36334 L
s
.66198 .33666 m
.66206 .34123 L
s
.66497 .33169 m
.66798 .32899 L
s
.66352 .33646 m
.66497 .33169 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66352 .33646 m
.6636 .34103 L
s
.66798 .32899 m
.67254 .32834 L
s
.65148 .35858 m
.65152 .36087 L
s
.66206 .34123 m
.66368 .34561 L
s
.65 .36334 m
.65152 .36087 L
s
.6636 .34103 m
.66521 .34541 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67254 .32834 m
.67561 .33019 L
s
.66368 .34561 m
.66831 .34729 L
s
.37164 .33275 m
.37319 .33068 L
s
.37172 .32818 m
.37319 .33068 L
s
.37017 .33024 m
.37172 .32818 L
s
.66521 .34541 m
.66831 .34729 L
s
.37017 .33024 m
.37164 .33275 L
s
.67561 .33019 m
.67871 .33431 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66384 .35477 m
.66388 .35707 L
s
.66384 .35477 m
.66537 .35457 L
s
.66831 .34729 m
.67746 .3483 L
s
.6872 .31003 m
.69747 .30825 L
s
.66388 .35707 m
.66545 .35917 L
s
.66537 .35457 m
.66541 .35687 L
s
.68012 .32951 m
.68307 .32675 L
s
.67871 .33431 m
.68012 .32951 L
s
.66545 .35917 m
.66856 .36106 L
s
.67871 .33431 m
.6791 .35498 L
s
.37143 .3442 m
.37243 .37202 L
s
.36939 .37161 m
.37143 .3442 L
s
.68162 .32928 m
.68307 .32675 L
s
.68021 .33409 m
.68162 .32928 L
s
.68307 .32675 m
.68456 .32652 L
s
.68021 .33409 m
.68052 .35016 L
s
.66856 .36106 m
.67465 .36023 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67746 .3483 m
.67901 .35038 L
s
.3582 .32839 m
.35964 .33092 L
s
.3595 .33781 m
.35964 .33092 L
s
.35528 .32561 m
.3582 .32839 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37091 .37182 m
.37117 .35799 L
s
.34941 .32461 m
.35528 .32561 L
s
.35801 .33757 m
.35954 .33551 L
s
.67465 .36023 m
.67764 .3575 L
s
.35796 .33987 m
.3595 .33781 L
s
.6791 .35498 m
.68052 .35016 L
s
.67764 .3575 m
.6791 .35498 L
s
.355 .33939 m
.35801 .33757 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69162 .30928 m
.69263 .35754 L
s
.35495 .34169 m
.35796 .33987 L
s
.37083 .37644 m
.37243 .37202 L
s
.34644 .3264 m
.34941 .32461 L
s
.69357 .33194 m
.69641 .32684 L
s
.34755 .34277 m
.355 .33939 L
s
.35768 .35368 m
.35927 .34931 L
s
.35908 .35853 m
.35927 .34931 L
s
.69641 .32684 m
.69927 .32403 L
s
.36939 .37161 m
.37083 .37644 L
s
.3475 .34507 m
.35495 .34169 L
s
.69927 .32403 m
.70217 .32351 L
s
.34494 .32844 m
.34644 .3264 L
s
.35615 .35576 m
.35768 .35368 L
s
.35768 .35368 m
.35908 .35853 L
s
.34359 .32357 m
.34494 .32844 L
s
.34339 .33278 m
.34359 .32357 L
s
.70217 .32351 m
.70511 .32527 L
s
.70217 .32351 m
.70654 .32501 L
s
.34339 .33278 m
.34494 .32844 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35314 .3576 m
.35615 .35576 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34458 .34457 m
.34755 .34277 L
s
.70511 .32527 m
.70808 .32934 L
s
.34725 .35663 m
.35314 .3576 L
s
.34453 .34688 m
.3475 .34507 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69396 .35037 m
.697 .3545 L
s
.68818 .35824 m
.69411 .3573 L
s
.69309 .30903 m
.69411 .3573 L
s
.70654 .32501 m
.70951 .32907 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34308 .34663 m
.34458 .34457 L
s
.697 .3545 m
.69997 .35632 L
s
.34303 .34894 m
.34453 .34688 L
s
.70808 .32934 m
.70967 .336 L
s
.34438 .35382 m
.34725 .35663 L
s
.34298 .35125 m
.34308 .34663 L
s
.70951 .32907 m
.7111 .33573 L
s
.69997 .35632 m
.70289 .35582 L
s
.34298 .35125 m
.34438 .35382 L
s
.33067 .32342 m
.33339 .32859 L
s
.70967 .336 m
.70978 .34062 L
s
.3265 .32025 m
.33067 .32342 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32101 .31185 m
.32106 .31139 L
s
.5 Mabswid
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70289 .35582 m
.70573 .35299 L
s
.70289 .35582 m
.70717 .35273 L
s
.7111 .33573 m
.71121 .34035 L
s
.70851 .34783 m
.70978 .34062 L
s
.70573 .35299 m
.70851 .34783 L
s
.70994 .34757 m
.71121 .34035 L
s
.32371 .31966 m
.3265 .32025 L
s
.70717 .35273 m
.70994 .34757 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71924 .32017 m
.72893 .31808 L
s
.5 Mabswid
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33296 .3471 m
.33301 .34478 L
s
.33165 .3422 m
.33301 .34478 L
s
.32088 .32138 m
.32371 .31966 L
s
.3195 .32108 m
.32371 .31966 L
s
.33017 .34424 m
.33165 .3422 L
s
.33001 .3512 m
.33296 .3471 L
s
.72342 .31929 m
.72463 .36814 L
s
.33017 .34424 m
.33154 .34683 L
s
.7248 .31899 m
.72602 .36786 L
s
.31801 .32542 m
.32088 .32138 L
s
.32713 .35298 m
.33001 .3512 L
s
.31663 .32512 m
.3195 .32108 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31646 .33208 m
.31801 .32542 L
s
.32292 .35214 m
.32713 .35298 L
s
.31509 .33178 m
.31663 .32512 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31634 .33673 m
.31646 .33208 L
s
.32019 .34925 m
.32292 .35214 L
s
.3188 .34896 m
.32292 .35214 L
s
.72544 .34451 m
.72832 .34859 L
s
.73437 .31684 m
.7437 .31459 L
s
.31497 .33643 m
.31509 .33178 L
s
.30071 .31434 m
.31002 .31661 L
s
.31634 .33673 m
.31754 .34401 L
s
.31754 .34401 m
.32019 .34925 L
s
.31497 .33643 m
.31616 .34371 L
s
.31616 .34371 m
.3188 .34896 L
s
.72043 .36896 m
.72602 .36786 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31885 .37058 m
.31894 .37253 L
s
.5 Mabswid
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30513 .34831 m
.306 .31565 L
s
.30379 .348 m
.30467 .31532 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73973 .31557 m
.74042 .3412 L
s
.72832 .34859 m
.7325 .35004 L
s
.7384 .31589 m
.73908 .34152 L
s
.7325 .35004 m
.73522 .34945 L
s
.73522 .34945 m
.73786 .3465 L
s
.73522 .34945 m
.7392 .34619 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73786 .3465 m
.73908 .34152 L
s
.7392 .34619 m
.74042 .3412 L
s
.74893 .31325 m
.75789 .31083 L
s
.28656 .31057 m
.29549 .313 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29981 .34705 m
.30513 .34831 L
s
.7528 .31223 m
.75373 .34503 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2909 .33773 m
.29163 .31197 L
s
.75408 .31188 m
.75502 .3447 L
s
.30335 .36443 m
.30475 .36238 L
s
.30348 .35973 m
.30475 .36238 L
s
.28962 .3374 m
.29036 .31162 L
s
.30208 .36177 m
.30348 .35973 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76479 .30299 m
.76602 .30421 L
s
.255 .412 .882 r
.30208 .36177 m
.30335 .36443 L
s
.74985 .34601 m
.75502 .3447 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28948 .3421 m
.2909 .33773 L
s
.28821 .34176 m
.28962 .3374 L
s
.27305 .30654 m
.28157 .30913 L
s
.2856 .34345 m
.28948 .3421 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2856 .34345 m
.28821 .34176 L
s
.75284 .35949 m
.75407 .35681 L
s
.75284 .35949 m
.7542 .36153 L
s
.76434 .31608 m
.76666 .31066 L
s
.76331 .32348 m
.76434 .31608 L
s
.75407 .35681 m
.75542 .35885 L
s
.76331 .32348 m
.76345 .32819 L
s
.76558 .31572 m
.76788 .31029 L
s
.76455 .32313 m
.76558 .31572 L
s
.7542 .36153 m
.75542 .35885 L
s
.76455 .32313 m
.76469 .32783 L
s
.76345 .32819 m
.7649 .3349 L
s
.28309 .34276 m
.2856 .34345 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76788 .31029 m
.77024 .3072 L
s
.76666 .31066 m
.77024 .3072 L
s
.76469 .32783 m
.76614 .33455 L
s
.77024 .3072 m
.77264 .30645 L
s
.27942 .33936 m
.28309 .34276 L
s
.7649 .3349 m
.76751 .33892 L
s
.76614 .33455 m
.76874 .33857 L
s
.77264 .30645 m
.77628 .30766 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27516 .35727 m
.27667 .30767 L
s
.27639 .35762 m
.27789 .30804 L
s
.2771 .33393 m
.27942 .33936 L
s
.77628 .30766 m
.77878 .31161 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76874 .33857 m
.77125 .34022 L
s
.76751 .33892 m
.77125 .34022 L
s
.77125 .34022 m
.77486 .33914 L
s
.27152 .35623 m
.27639 .35762 L
s
.77695 .32893 m
.77805 .32619 L
s
.77695 .32893 m
.7782 .33093 L
s
.26243 .30543 m
.26458 .31094 L
s
.26458 .31094 m
.26552 .31842 L
s
.77486 .33914 m
.77717 .33604 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77805 .32619 m
.7793 .32818 L
s
.26537 .32316 m
.26552 .31842 L
s
.2591 .30188 m
.26243 .30543 L
s
.26129 .30504 m
.26343 .31055 L
s
.26343 .31055 m
.26436 .31804 L
s
.77717 .33604 m
.77937 .33055 L
s
.26421 .32278 m
.26436 .31804 L
s
.26398 .3299 m
.26537 .32316 L
s
.7793 .32818 m
.77937 .33055 L
s
.2591 .30188 m
.26129 .30504 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26282 .32952 m
.26421 .32278 L
s
.25686 .30107 m
.2591 .30188 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78658 .30177 m
.78785 .30611 L
s
.78658 .30177 m
.78689 .31125 L
s
.26152 .3339 m
.26398 .3299 L
s
0 0 0 r
.24917 .29066 m
.25102 .29333 L
s
.255 .412 .882 r
.26037 .33352 m
.26282 .32952 L
s
0 0 0 r
.24917 .29066 m
.25099 .29432 L
s
.255 .412 .882 r
.25456 .30263 m
.25686 .30107 L
s
.78689 .31125 m
.78785 .30611 L
s
.78785 .30611 m
.78889 .30334 L
s
.25134 .3328 m
.25301 .28286 L
s
.78889 .30334 m
.79103 .30015 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24871 .28116 m
.25629 .28411 L
s
.25025 .33241 m
.25192 .28244 L
s
.25802 .33514 m
.26152 .3339 L
s
.79103 .30015 m
.79538 .2985 L
s
.25221 .30657 m
.25456 .30263 L
s
.25802 .33514 m
.26037 .33352 L
s
.78735 .32551 m
.7884 .32274 L
s
.78735 .32551 m
.78751 .33027 L
s
.7884 .32274 m
.79055 .31957 L
s
.78743 .32789 m
.78848 .32512 L
s
.78848 .32512 m
.79063 .32195 L
s
.78751 .33027 m
.78871 .33227 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25577 .33437 m
.25802 .33514 L
s
.79055 .31957 m
.79586 .31279 L
s
.79063 .32195 m
.79594 .31517 L
s
.78871 .33227 m
.79103 .33388 L
s
.79538 .2985 m
.7976 .30005 L
s
.25362 .3312 m
.25577 .33437 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79103 .33388 m
.79542 .33231 L
s
.25158 .32563 m
.25362 .3312 L
s
.7976 .30005 m
.79874 .30201 L
s
.79586 .31279 m
.79792 .30958 L
s
.79594 .31517 m
.798 .31197 L
s
.24498 .29651 m
.24603 .29693 L
s
.79792 .30958 m
.7989 .30678 L
s
.24701 .33121 m
.25134 .3328 L
s
.24283 .29804 m
.24498 .29651 L
s
.24386 .29847 m
.24498 .29651 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79874 .30201 m
.79898 .30916 L
s
.798 .31197 m
.79898 .30916 L
s
.79542 .33231 m
.7975 .32911 L
s
.24266 .30281 m
.24386 .29847 L
s
.24163 .30239 m
.24283 .29804 L
s
.7975 .32911 m
.79849 .32631 L
s
.79849 .32631 m
.79939 .32112 L
s
.79849 .32631 m
.79972 .33071 L
s
.79939 .32112 m
.79972 .33071 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24208 .31957 m
.24266 .30281 L
s
.23976 .29675 m
.24163 .30239 L
s
.24088 .32396 m
.24163 .30239 L
s
.23784 .29349 m
.23976 .29675 L
s
.80588 .29664 m
.80681 .29381 L
s
.80588 .29664 m
.80697 .29859 L
s
.80681 .29381 m
.80789 .29577 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24088 .32396 m
.24208 .31957 L
s
.23488 .29216 m
.23784 .29349 L
s
.80697 .29859 m
.80789 .29577 L
s
.24011 .31634 m
.24105 .31916 L
s
.2342 .31137 m
.24011 .31634 L
s
.23977 .32595 m
.24088 .32396 L
s
.23286 .29367 m
.23488 .29216 L
s
.2319 .29323 m
.23488 .29216 L
s
.23766 .32753 m
.23977 .32595 L
s
.23172 .29803 m
.23286 .29367 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8079 .32501 m
.80841 .33949 L
s
.8074 .31058 m
.8074 .3399 L
s
.8074 .31058 m
.80942 .33908 L
s
.23368 .32584 m
.23766 .32753 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23077 .29758 m
.2319 .29323 L
s
.23234 .3081 m
.2342 .31137 L
s
.23138 .30766 m
.2342 .31137 L
s
.8074 .3399 m
.80858 .34433 L
s
.23155 .30284 m
.23172 .29803 L
s
.23155 .30284 m
.23234 .3081 L
s
.2306 .3024 m
.23077 .29758 L
s
0 0 0 r
.22196 .27857 m
.22247 .28163 L
s
.255 .412 .882 r
.80858 .34433 m
.80942 .33908 L
s
.2306 .3024 m
.23138 .30766 L
s
.23182 .32257 m
.23368 .32584 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23103 .31731 m
.23199 .31774 L
s
.23191 .32016 m
.23199 .31774 L
s
.23094 .31973 m
.23182 .32257 L
s
.23094 .31973 m
.23103 .31731 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2227 .31334 m
.2235 .31622 L
s
.22341 .31864 m
.2235 .31622 L
s
.22243 .32063 m
.22341 .31864 L
s
.21356 .28102 m
.21933 .28437 L
s
.22172 .31532 m
.2227 .31334 L
s
.22172 .31532 m
.22252 .3182 L
s
.21978 .31929 m
.22243 .32063 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21552 .31703 m
.21681 .28295 L
s
.21469 .31657 m
.21598 .28247 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21814 .31595 m
.21978 .31929 L
s
.21663 .31016 m
.21814 .31595 L
s
.21607 .30239 m
.21663 .31016 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21225 .31519 m
.21552 .31703 L
s
.20815 .29765 m
.20891 .27809 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20521 .29572 m
.21045 .29909 L
s
.20741 .29717 m
.20817 .2776 L
s
.20661 .27905 m
.20788 .28493 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20456 .27511 m
.20661 .27905 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20318 .2741 m
.20456 .27511 L
s
.20691 .32964 m
.20749 .31484 L
s
.20645 .32177 m
.20749 .31484 L
s
.20173 .27554 m
.20318 .2741 L
s
.20107 .27504 m
.20318 .2741 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19878 .26478 m
.1988 .26417 L
s
.1987 .26486 m
.1988 .26417 L
s
.5 Mabswid
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20478 .32578 m
.20645 .32177 L
s
.20645 .32177 m
.20691 .32964 L
s
.20022 .27945 m
.20173 .27554 L
s
.19957 .27894 m
.20107 .27504 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20252 .32685 m
.20478 .32578 L
s
.19938 .28387 m
.20022 .27945 L
s
0 0 0 r
.19739 .29928 m
.19685 .29526 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19874 .28337 m
.19957 .27894 L
s
.20113 .32591 m
.20252 .32685 L
s
.19844 .29078 m
.19938 .28387 L
s
.19781 .29028 m
.19874 .28337 L
s
.19987 .32248 m
.20113 .32591 L
s
.1992 .322 m
.20113 .32591 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19794 .30316 m
.19844 .29078 L
s
.19731 .30267 m
.19781 .29028 L
s
.19874 .31655 m
.19987 .32248 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19794 .30316 m
.19829 .3111 L
s
.19809 .31607 m
.1992 .322 L
s
.19829 .3111 m
.19874 .31655 L
s
.19731 .30267 m
.19765 .31061 L
s
.19765 .31061 m
.19809 .31607 L
s
.85052 .26729 m
.85576 .26199 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19138 .30016 m
.19477 .30317 L
s
.19227 .26479 m
.19303 .30167 L
s
.1888 .29762 m
.19227 .26479 L
s
.18929 .29813 m
.19197 .27224 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85272 .26518 m
.85487 .31757 L
s
.85218 .26571 m
.85432 .31806 L
s
.85264 .31954 m
.85793 .31459 L
s
.85576 .26199 m
.8568 .26341 L
s
.85576 .26199 m
.85725 .26288 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8568 .26341 m
.85791 .26734 L
s
.18835 .26052 m
.1888 .29762 L
s
.18515 .2935 m
.18835 .26052 L
s
.85725 .26288 m
.85835 .2668 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18557 .29402 m
.18804 .26801 L
s
.85791 .26734 m
.85855 .27181 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85835 .2668 m
.85898 .27127 L
s
.85855 .27181 m
.8593 .2788 L
s
.85898 .27127 m
.85972 .27827 L
s
.18393 .29194 m
.1869 .29557 L
s
.85793 .31459 m
.85878 .31106 L
s
.85793 .31459 m
.85924 .31056 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8593 .2788 m
.85982 .29137 L
s
.85972 .27827 m
.86024 .29085 L
s
.85878 .31106 m
.85948 .305 L
s
.86046 .25604 m
.86285 .25219 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85924 .31056 m
.85992 .30449 L
s
.85971 .29945 m
.85982 .29137 L
s
.85948 .305 m
.85971 .29945 L
s
.18429 .25509 m
.18465 .25564 L
s
.86014 .29893 m
.86024 .29085 L
s
.85992 .30449 m
.86014 .29893 L
s
.18349 .2565 m
.18429 .25509 L
s
.18383 .25705 m
.18429 .25509 L
s
.86154 .2544 m
.86303 .28971 L
s
.18328 .26153 m
.18383 .25705 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86188 .25385 m
.86337 .28918 L
s
.18294 .26099 m
.18349 .2565 L
s
.18253 .27919 m
.18328 .26153 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86194 .29129 m
.86337 .28918 L
s
.18251 .25485 m
.18294 .26099 L
s
.18198 .28372 m
.18294 .26099 L
s
.18202 .25122 m
.18251 .25485 L
s
.86273 .274 m
.86338 .28105 L
s
.18198 .28372 m
.18253 .27919 L
s
.18119 .24955 m
.18202 .25122 L
s
.18198 .27559 m
.18219 .27866 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18033 .26981 m
.18198 .27559 L
s
.86338 .28105 m
.86424 .28506 L
s
.18155 .28573 m
.18198 .28372 L
s
.18082 .2872 m
.18155 .28573 L
s
.18058 .25097 m
.18119 .24955 L
s
.18035 .25041 m
.18119 .24955 L
s
.86424 .28506 m
.86495 .28654 L
s
.17968 .28508 m
.18082 .2872 L
s
.18013 .25548 m
.18058 .25097 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86495 .28654 m
.86577 .28494 L
s
.17994 .26618 m
.18033 .26981 L
s
.1797 .26563 m
.18033 .26981 L
s
.17991 .25492 m
.18035 .25041 L
s
.17992 .26055 m
.18013 .25548 L
s
.86529 .28038 m
.86566 .28239 L
s
.86529 .28038 m
.86545 .2773 L
s
.86545 .2773 m
.86581 .27931 L
s
.17992 .26055 m
.17994 .26618 L
s
.17969 .26 m
.17991 .25492 L
s
.17929 .28146 m
.17968 .28508 L
s
.17969 .26 m
.1797 .26563 L
s
.86577 .28494 m
.86592 .28185 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86581 .27931 m
.86592 .28185 L
s
.17927 .27582 m
.1795 .27636 L
s
.17939 .27891 m
.1795 .27636 L
s
.17916 .27837 m
.17929 .28146 L
s
.17916 .27837 m
.17927 .27582 L
s
.86629 .2469 m
.86633 .25255 L
s
.86633 .25255 m
.86655 .25764 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86629 .2469 m
.86663 .24266 L
s
.86655 .25764 m
.86694 .26219 L
s
.86645 .24633 m
.8665 .25199 L
s
.8665 .25199 m
.86672 .25708 L
s
.86645 .24633 m
.86663 .24266 L
s
.86672 .25708 m
.8671 .26163 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86663 .24266 m
.867 .24095 L
s
.86738 .27241 m
.86749 .27498 L
s
.86738 .27241 m
.86754 .27187 L
s
.86749 .27498 m
.86776 .27699 L
s
.86754 .27187 m
.86765 .27443 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8671 .26163 m
.86751 .26309 L
s
.86694 .26219 m
.86751 .26309 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.867 .24095 m
.8673 .24237 L
s
.86776 .27699 m
.86817 .27848 L
s
.17758 .27091 m
.17762 .27403 L
s
.17751 .27659 m
.17762 .27403 L
s
.17726 .27862 m
.17751 .27659 L
s
.17734 .27293 m
.17758 .27091 L
s
.17786 .23596 m
.17822 .23996 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17734 .27293 m
.17737 .27605 L
s
.8673 .24237 m
.86767 .24636 L
s
.17688 .27699 m
.17726 .27862 L
s
.17646 .27426 m
.17801 .23825 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86817 .27848 m
.86864 .2763 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86767 .24636 m
.86866 .2695 L
s
.86751 .24066 m
.86767 .24636 L
s
.86751 .26309 m
.86826 .26233 L
s
.86748 .23696 m
.86751 .24066 L
s
.17679 .27332 m
.17688 .27699 L
s
.17641 .27371 m
.17795 .23768 L
s
.86756 .24009 m
.86773 .24579 L
s
.86773 .24579 m
.8685 .26379 L
s
.86748 .23696 m
.86756 .24009 L
s
.86826 .26233 m
.86844 .26435 L
s
.86864 .2763 m
.8687 .27263 L
s
.86748 .23696 m
.86751 .23638 L
s
.17679 .27332 m
.17685 .26707 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17685 .26707 m
.17712 .25879 L
s
.86866 .2695 m
.8687 .27263 L
s
.8685 .26379 m
.86866 .2695 L
s
.17631 .27207 m
.17646 .27426 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17737 .24599 m
.17764 .24025 L
s
.17701 .25431 m
.17737 .24599 L
s
.86884 .26752 m
.86909 .27137 L
s
.17764 .24025 m
.17798 .23394 L
s
.17645 .26727 m
.17701 .25431 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87123 .22443 m
.8713 .22753 L
s
.87098 .22015 m
.87123 .22443 L
s
.255 .412 .882 r
.17742 .24542 m
.17769 .23968 L
s
.17704 .25375 m
.17742 .24542 L
s
.86728 .23121 m
.86846 .26531 L
s
.86728 .23121 m
.86904 .26972 L
s
.17769 .23968 m
.17806 .23337 L
s
.17798 .23394 m
.17836 .22963 L
s
.17648 .26672 m
.17704 .25375 L
s
0 0 0 r
.87105 .22325 m
.87098 .22015 L
s
.255 .412 .882 r
.17806 .23337 m
.17836 .22963 L
s
.86761 .23896 m
.86901 .26917 L
s
.17615 .27452 m
.17645 .26727 L
s
0 0 0 r
.8713 .22753 m
.87105 .22325 L
s
.255 .412 .882 r
.17619 .27397 m
.17648 .26672 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17597 .27918 m
.17615 .27452 L
s
0 0 0 r
.87211 .24602 m
.87413 .29131 L
s
.87211 .24602 m
.87396 .29022 L
s
.255 .412 .882 r
.17602 .27864 m
.17619 .27397 L
s
.17586 .28332 m
.17597 .27918 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17594 .28278 m
.17602 .27864 L
s
0 0 0 r
.86934 .21364 m
.87009 .21601 L
s
.255 .412 .882 r
.86634 .22659 m
.86846 .26531 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87308 .26833 m
.87405 .29076 L
s
.255 .412 .882 r
.17601 .28432 m
.17586 .28332 L
s
.86667 .23438 m
.86833 .26476 L
s
.17594 .28278 m
.17601 .28432 L
s
0 0 0 r
.87413 .29131 m
.87438 .29827 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87438 .29827 m
.87396 .29022 L
s
.86906 .21617 m
.86983 .22479 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.177 .28053 m
.17705 .27931 L
s
.17682 .28107 m
.17689 .27957 L
s
.17802 .2531 m
.17835 .24533 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86841 .21126 m
.86906 .21617 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86664 .23913 m
.86677 .24439 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86788 .21008 m
.86841 .21126 L
s
.86746 .21262 m
.86788 .21008 L
s
.86716 .21203 m
.86788 .21008 L
s
.871 .26106 m
.87112 .25467 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86716 .21893 m
.86746 .21262 L
s
.86684 .21834 m
.86716 .21203 L
s
.87068 .26371 m
.871 .26106 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86934 .21364 m
.87275 .29235 L
s
.86955 .21423 m
.87296 .29289 L
s
.86716 .21893 m
.86732 .22961 L
s
.87207 .29073 m
.87296 .29289 L
s
.87068 .26371 m
.87015 .26259 L
s
.86684 .21834 m
.86698 .22903 L
s
.86941 .2577 m
.87015 .26259 L
s
.8691 .25714 m
.87015 .26259 L
s
.86732 .22961 m
.86764 .23714 L
s
.86698 .22903 m
.8673 .23656 L
s
.86764 .23714 m
.86846 .24902 L
s
.86846 .24902 m
.86941 .2577 L
s
.86105 .19942 m
.86415 .20355 L
s
.8673 .23656 m
.86813 .24845 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86813 .24845 m
.8691 .25714 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86289 .20178 m
.86515 .2548 L
s
.86245 .20119 m
.8647 .25424 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8633 .25258 m
.86515 .2548 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86584 .28103 m
.86612 .27773 L
s
.86551 .27336 m
.86612 .27773 L
s
.86522 .27665 m
.86551 .27336 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85505 .19296 m
.85903 .19706 L
s
.86522 .27665 m
.86584 .28103 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85739 .1953 m
.86076 .27568 L
s
.85683 .19472 m
.86019 .27515 L
s
.84997 .19214 m
.85166 .20093 L
s
.84765 .18659 m
.84997 .19214 L
s
.84616 .18544 m
.84765 .18659 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85841 .27355 m
.86076 .27568 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85277 .22779 m
.85293 .23165 L
s
.85192 .22339 m
.85277 .22779 L
s
.84477 .18813 m
.84616 .18544 L
s
.84399 .18756 m
.84616 .18544 L
s
.85138 .22669 m
.85192 .22339 L
s
.85186 .23827 m
.85293 .23165 L
s
.85138 .22669 m
.85224 .23109 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84349 .19469 m
.84477 .18813 L
s
.84268 .19413 m
.84399 .18756 L
s
.85059 .24105 m
.85186 .23827 L
s
.255 .412 .882 r
.20556 .19971 m
.20656 .19389 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2001 .18478 m
.20494 .18137 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84315 .20571 m
.84349 .19469 L
s
.84835 .23943 m
.85059 .24105 L
s
.84232 .20515 m
.84268 .19413 L
s
.255 .412 .882 r
.83573 .2156 m
.83772 .21581 L
s
.20481 .2188 m
.20549 .22092 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2047 .22151 m
.20538 .22364 L
s
0 0 0 r
.84315 .20571 m
.84346 .21344 L
s
.84664 .23447 m
.84835 .23943 L
s
.84585 .23393 m
.84835 .23943 L
s
.8344 .17751 m
.83799 .17975 L
s
.255 .412 .882 r
.20527 .22635 m
.20549 .22092 L
s
0 0 0 r
.84232 .20515 m
.84263 .2129 L
s
.84346 .21344 m
.84474 .22562 L
s
.255 .412 .882 r
.20438 .22954 m
.20527 .22635 L
s
.83797 .23027 m
.8383 .23048 L
s
0 0 0 r
.84474 .22562 m
.84664 .23447 L
s
.84263 .2129 m
.84392 .22508 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20236 .20563 m
.2102 .20069 L
s
.84392 .22508 m
.84585 .23393 L
s
.2102 .17799 m
.21586 .17466 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83468 .21021 m
.83481 .21374 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83269 .18027 m
.83486 .18912 L
s
.82966 .17474 m
.83269 .18027 L
s
.21284 .18548 m
.21393 .17577 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20167 .18364 m
.20428 .26146 L
s
.20428 .26146 m
.21284 .18548 L
s
.20475 .24968 m
.21298 .17632 L
s
.82768 .17364 m
.82966 .17474 L
s
.82581 .17643 m
.82768 .17364 L
s
.82478 .17589 m
.82768 .17364 L
s
.21784 .17356 m
.22513 .16976 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8344 .17751 m
.83654 .23198 L
s
.83532 .17807 m
.83745 .23251 L
s
.83371 .23041 m
.83745 .23251 L
s
.82508 .18368 m
.82581 .17643 L
s
.21882 .22673 m
.2209 .17192 L
s
.82404 .18314 m
.82478 .17589 L
s
.21987 .22622 m
.22194 .17138 L
s
.82508 .18368 m
.82671 .2268 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82404 .18314 m
.82567 .22629 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22076 .20262 m
.22137 .21389 L
s
.21575 .22827 m
.21987 .22622 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81373 .16664 m
.81459 .19017 L
s
.22137 .21389 m
.22322 .22074 L
s
.82246 .22476 m
.82671 .2268 L
s
.81258 .16611 m
.81459 .19017 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22322 .22074 m
.22527 .22368 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22527 .22368 m
.22865 .22218 L
s
.2278 .21477 m
.2288 .21822 L
s
.2278 .21477 m
.22909 .21031 L
s
.22909 .21031 m
.23009 .21376 L
s
.23848 .17522 m
.24121 .16633 L
s
.23684 .18755 m
.23848 .17522 L
s
.24121 .16633 m
.2451 .16087 L
s
.2397 .17471 m
.24245 .16582 L
s
.23805 .18704 m
.2397 .17471 L
s
.22994 .21772 m
.23009 .21376 L
s
.24245 .16582 m
.2451 .16087 L
s
.23656 .19544 m
.23684 .18755 L
s
.22865 .22218 m
.22994 .21772 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.794 .15843 m
.79691 .15964 L
s
.79691 .15964 m
.81373 .16664 L
s
.23777 .19494 m
.23805 .18704 L
s
.2451 .16087 m
.24766 .15986 L
s
.23656 .19544 m
.23735 .20682 L
s
.81561 .24912 m
.8159 .22572 L
s
.8159 .22572 m
.81677 .2496 L
s
.23777 .19494 m
.23857 .20633 L
s
.24766 .15986 m
.25144 .16231 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23735 .20682 m
.23953 .21379 L
s
.23857 .20633 m
.24077 .21331 L
s
.25144 .16231 m
.25384 .16924 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80071 .20397 m
.80821 .20689 L
s
.80764 .19106 m
.80878 .22279 L
s
.23953 .21379 m
.24316 .21633 L
s
.24077 .21331 m
.24316 .21633 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24316 .21633 m
.24704 .21491 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25022 .198 m
.25169 .19355 L
s
.25022 .198 m
.25142 .20152 L
s
.25169 .19355 m
.2529 .19706 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79791 .15993 m
.8008 .2435 L
s
.79919 .16044 m
.8021 .24396 L
s
.7998 .24324 m
.81677 .2496 L
s
.79686 .24213 m
.7998 .24324 L
s
.24704 .21491 m
.24981 .20997 L
s
.25276 .20105 m
.2529 .19706 L
s
.26403 .23722 m
.26674 .15304 L
s
.24981 .20997 m
.25276 .20105 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26248 .15446 m
.27257 .15117 L
s
.26548 .23679 m
.26818 .15257 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27855 .14934 m
.28941 .14624 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27294 .18783 m
.27326 .18998 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28182 .1921 m
.28315 .148 L
s
.26678 .19646 m
.26945 .20361 L
s
.28337 .19168 m
.2847 .14755 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26945 .20361 m
.27379 .20634 L
s
.25973 .23852 m
.26548 .23679 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29582 .14453 m
.3074 .14164 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27379 .20634 m
.27683 .20548 L
s
.27683 .20548 m
.28002 .2006 L
s
.27683 .20548 m
.28157 .20018 L
s
.29915 .19978 m
.30073 .14327 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28002 .2006 m
.28182 .1921 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30081 .19939 m
.30238 .14286 L
s
.28157 .20018 m
.28337 .19168 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31421 .14006 m
.32647 .1374 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29421 .20096 m
.30081 .19939 L
s
.255 .412 .882 r
.72353 .17647 m
.72358 .17653 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31796 .19566 m
.31941 .1389 L
s
.31972 .19531 m
.32116 .13852 L
s
.33365 .13596 m
.34653 .13355 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29858 .22015 m
.30013 .22386 L
s
.2968 .22462 m
.29858 .22015 L
s
.2968 .22462 m
.29835 .22833 L
s
.33809 .17962 m
.33913 .1349 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33994 .17929 m
.34097 .13456 L
s
.29835 .22833 m
.30013 .22386 L
s
.31272 .19675 m
.31972 .19531 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32003 .18307 m
.32337 .19051 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35406 .13225 m
.36751 .1301 L
s
.32337 .19051 m
.32866 .19357 L
s
.35886 .17619 m
.35978 .13131 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36079 .1759 m
.3617 .131 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32866 .19357 m
.3323 .19289 L
s
.33606 .18813 m
.33809 .17962 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3323 .19289 m
.33606 .18813 L
s
.3323 .19289 m
.3379 .1878 L
s
.33994 .17929 m
.34348 .18684 L
s
.3379 .1878 m
.33994 .17929 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34348 .18684 m
.34904 .19001 L
s
.38121 .13221 m
.38728 .12735 L
s
.37709 .1409 m
.38121 .13221 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3832 .13194 m
.38728 .12735 L
s
.37907 .14063 m
.3832 .13194 L
s
.38728 .12735 m
.39131 .12684 L
s
.37489 .15343 m
.37709 .1409 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37687 .15316 m
.37907 .14063 L
s
.39131 .12684 m
.39732 .13019 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34904 .19001 m
.35285 .1894 L
s
.35676 .1847 m
.35886 .17619 L
s
.37473 .16163 m
.37489 .15343 L
s
.35869 .1844 m
.36079 .1759 L
s
.37671 .16136 m
.37687 .15316 L
s
.35285 .1894 m
.35676 .1847 L
s
.35285 .1894 m
.35869 .1844 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39732 .13019 m
.40128 .1379 L
s
.37473 .16163 m
.37649 .17368 L
s
.37671 .16136 m
.37848 .17342 L
s
.37671 .16136 m
.40097 .15842 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37649 .17368 m
.38033 .18141 L
s
.37848 .17342 m
.38234 .18115 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42214 .12762 m
.4285 .12297 L
s
.41785 .1362 m
.42214 .12762 L
s
.42424 .12743 m
.4285 .12297 L
s
.4285 .12297 m
.43272 .12262 L
s
.41994 .13601 m
.42424 .12743 L
s
.43272 .12262 m
.43692 .12638 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41559 .14872 m
.41785 .1362 L
s
.41768 .14852 m
.41994 .13601 L
s
.38033 .18141 m
.3863 .18479 L
s
.39872 .17101 m
.39892 .15865 L
s
.40084 .16666 m
.40097 .15842 L
s
.38234 .18115 m
.3863 .18479 L
s
.44122 .12197 m
.44977 .12138 L
s
.43692 .12638 m
.44109 .13427 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41548 .15695 m
.41559 .14872 L
s
.41757 .15676 m
.41768 .14852 L
s
.39866 .17513 m
.40084 .16666 L
s
.3863 .18479 m
.39239 .18408 L
s
.39654 .17949 m
.39872 .17101 L
s
.41548 .15695 m
.41741 .16914 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39654 .17949 m
.39866 .17513 L
s
.41757 .15676 m
.41951 .16895 L
s
.39239 .18408 m
.39654 .17949 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.467 .1245 m
.47137 .12019 L
s
.47137 .12019 m
.47572 .12 L
s
.46483 .1246 m
.47137 .12019 L
s
.46044 .13305 m
.46483 .1246 L
s
.47572 .12 m
.48224 .12385 L
s
.4626 .13294 m
.467 .1245 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42951 .16075 m
.4299 .16286 L
s
.43146 .16064 m
.43216 .16412 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.45818 .14553 m
.46044 .13305 L
s
.48224 .12385 m
.48657 .13194 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46034 .14541 m
.4626 .13294 L
s
.54373 .11922 m
.54594 .12338 L
s
.54154 .1233 m
.54373 .11922 L
s
.50197 .11922 m
.50414 .1274 L
s
.50192 .13568 m
.50197 .11922 L
s
.50635 .12326 m
.51075 .11909 L
s
.51955 .11904 m
.51075 .11909 L
s
.51955 .11904 m
.52395 .12314 L
s
.41741 .16914 m
.42151 .17705 L
s
.54375 .12745 m
.54594 .12338 L
s
.54154 .1233 m
.54375 .12745 L
s
.41951 .16895 m
.42362 .17687 L
s
.50414 .1274 m
.50635 .12326 L
s
.52395 .12314 m
.52615 .12726 L
s
.50192 .13568 m
.50414 .1274 L
s
.52615 .12726 m
.52616 .13963 L
s
.45811 .15379 m
.45818 .14553 L
s
.46028 .15367 m
.46034 .14541 L
s
.42151 .17705 m
.42781 .18067 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.42362 .17687 m
.42781 .18067 L
s
.52395 .13963 m
.52615 .1355 L
s
.45811 .15379 m
.46018 .1661 L
s
.46028 .15367 m
.46235 .16599 L
s
.46028 .15367 m
.48648 .15258 L
s
.43638 .17587 m
.44075 .16728 L
s
.52395 .14376 m
.52616 .13963 L
s
.51954 .14376 m
.52395 .13963 L
s
.42781 .18067 m
.43206 .18034 L
s
.255 .412 .882 r
.49019 .16402 m
.49236 .16396 L
s
0 0 0 r
.43206 .18034 m
.43638 .17587 L
s
.5085 .15212 m
.51954 .14376 L
s
.51954 .1479 m
.52395 .14376 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.48422 .16509 m
.48428 .15265 L
s
.48644 .16087 m
.48648 .15258 L
s
.50849 .15626 m
.51954 .1479 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44032 .20892 m
.44122 .12197 L
s
.44248 .20878 m
.44335 .12181 L
s
.46018 .1661 m
.46447 .17419 L
s
.46235 .16599 m
.46665 .17408 L
s
.50407 .15632 m
.5085 .15212 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.50186 .16051 m
.50407 .15632 L
s
.4842 .16924 m
.48644 .16087 L
s
.50406 .16047 m
.50849 .15626 L
s
.50184 .16881 m
.50186 .16051 L
s
.48198 .17347 m
.48422 .16509 L
s
.50185 .16466 m
.50406 .16047 L
s
.46447 .17419 m
.47099 .17805 L
s
.52396 .16864 m
.52617 .16033 L
s
.52617 .16033 m
.52617 .17697 L
s
.46665 .17408 m
.47099 .17805 L
s
.48198 .17347 m
.4842 .16924 L
s
.47757 .17779 m
.48198 .17347 L
s
.47099 .17805 m
.47757 .17779 L
s
.50184 .16881 m
.50404 .17294 L
s
.52174 .1728 m
.52396 .16864 L
s
.52396 .16864 m
.52617 .17697 L
s
.50404 .17294 m
.50845 .17705 L
s
.51731 .17698 m
.52174 .1728 L
s
.43387 .20936 m
.44248 .20878 L
s
.50845 .17705 m
.51731 .17698 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54381 .14808 m
.54615 .19808 L
s
.54172 .198 m
.54381 .14808 L
s
.54387 .17298 m
.54394 .19804 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.54396 .20643 m
.54615 .19808 L
s
.54172 .198 m
.54396 .20643 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00103o
YQ0010000000ojH@0?nV403oYQ06000000/0ojH@00@000000?nV403oYQ00[Jf]7P3oYA000`2][Jd0
oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P020>bF3P80[Jf]KP2`h>H10?ooo`00PP2`h>H20:f][@@0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
1`3oYQ42000000X0ojHA0`00000<0:f][@040000002][Jd0[Jf]000000H0[Jf]00<000000:f][@2]
[Jd01`2][Jd200000180[Jf]3`3oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P040>bF3P<0[Jf]J`2`h>H10?ooo`00
O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA100000030?nV4@<000002P2][Jd2000000030:f][@3oYQ40ojHA00800000
0`3oYQ400`2][Jd0ojH@0?nV40040?nV40030000003oYQ00000000P0ojH@00<000000?nV403oYQ00
1P3oYQ001@000000ojH@0000003oYQ00[Jf]00l0ojD@502][JdG0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?ooo`00
O02`h>H30:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01H0ojHA0`2][Jd00`000000[Jf]0:f][@020:f][@030000002][Jd0[Jf]00800000
2@3oYQ43000000H0ojHA00@000000?nV4@3oYQ40[Jf]1P3oYQ02000000T0ojH@00<000000?nV403o
YQ001P3oYQ001@000000ojH@0000003oYQ00[Jf]01h0ojD@00<0[Jf]0?nS403oXa000P3oXa090:f]
[@h0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>
00X0k9H>0P2][JeV0;3PiP40oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@03
0:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ43000000<0ojHA2P2][Jd20?nV4@03
0000003oYQ40[Jf]00@0ojHA00@000000?nV4@0000000000203oYQ400`000000ojHA000000070?nV
4@040000003oYQ40ojHA0:f][@H0ojH@0P00000:0?nV40030000003oYQ00ojH@00H0ojH@00@00000
0?nV403oYQ00[Jf]7P3oYA000`2][Jd0oj<@0?nS400;0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3o
ool007L0/>3V0`2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ40
0`2][Jd0ojHA0?nV4@020?nV4@<0[Jf]00@000000:f][@2][Jd0[Jf]0P0000000`2][Jd0ojHA0?nV
4@090?nV4@80000000<0ojHA0:f][@3oYQ400`3oYQ4010000000ojHA0000000000080?nV4@800000
2@3oYQ400`000000ojHA0:f][@060?nV408000002P3oYQ000`000000ojH@0?nV40060?nV40040000
003oYQ00ojH@0:f][Ah0ojD@00<0[Jf]0?nS403oXa005@3oXa070:f][AP0o:0@00<0[Jf]0?JL3`3f
W0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`h>H10?ooo`00M@2`h>H20:f][A40o:0@
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0B0?nV4@D000001@2][Jd20?nV4@800000
1@3oYQ400`000000ojHA0?nV4@080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@<00000
1`3oYQ400`000000ojHA000000090?nV4@030000003oYQ40[Jf]00H0ojH@0P00000:0?nV40030000
003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f]
[@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>
0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA00l0ojHA1@000000102][Jd0ojHA0?nV4@2][Jd50?nV4@8000001P3oYQ400`000000ojHA
0?nV4@080?nV4@8000000P3oYQ400`2][Jd0ojHA0?nV4@030?nV4@<000001`3oYQ42000000/0ojHA
00<000000:f][@3oYQ001@3oYQ000`000000ojH@0?nV40090?nV40030000003oYQ00ojH@00T0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0o:0@
1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=
0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@080?nV4@D000000`2][Jd20?nV4@8000000`3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@800000203oYQ400`000000ojHA0?nV4@060?nV4@8000000`3o
YQ400`2][Jd0ojHA0?nV4@040?nV4@8000001`3oYQ42000000`0ojHA00<0[Jf]0?nV403oYQ00103o
YQ000`000000ojH@0?nV40090?nV40030000003oYQ00ojH@00T0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00/0o:0@1@2][Jd80?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`
h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D
0?nT4@040:f][@3oYQ40ojHA0?nV4@8000000P3oYQ45000000030:f][@3oYQ40ojHA00D0ojHA0P00
00030?nV4@030:f][@3oYQ40ojHA0080ojHA0P0000080?nV4@030000003oYQ40ojHA00H0ojHA0P00
00030?nV4@030:f][@3oYQ40ojHA00@0ojHA0P0000070?nV4@800000303oYQ400`2][Jd0ojH@0?nV
40040?nV40030000003oYQ00ojH@00T0ojH@00<000000?nV403oYQ002@3oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100403lX1060:f][@80o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2]
[JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX100
0`2][Jd0oj@A0?nT4@0D0?nT4@040:f][@0000000000000000@0[Jf]0`3oYQ42000000P0ojHA0P00
00030?nV4@040:f][@3oYQ40ojHA0?nV4@8000002P3oYQ400`000000ojHA0?nV4@050?nV4@800000
0`3oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000001`3oYQ400`000000ojHA0?nV4@0;0?nV4@030:f]
[@3oYQ00ojH@00l0ojH@0P00000;0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6@3oXa000`2][Jd0o:0@0?bP400F0?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01<0oj@A100000080?nV4@800000203oYQ42000000<0ojHA00@0
[Jf]0?nV4@3oYQ40ojHA0P00000B0?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@040?nV4@800000
1P3oYQ42000000d0ojHA00<0[Jf]0?nV403oYQ003`3oYQ02000000/0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`2][Jd0
0`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V
0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140303o
Y144000000<0[Jf]00@0oj@A0:f][@0000000000203oYQ42000000P0ojHA0P0000030?nV4@040:f]
[@3oYQ40ojHA0?nV4@8000004@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000H0
ojHA0P00000=0?nV4@030:f][@3oYQ00ojH@00h0ojH@0P00000<0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00<0
mY`?102][Jd=0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0
/>3V0@3oool006P0/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
2@3oY145000000030:f][@3oY140oj@A00<0oj@A00<0[Jf]000000000000203oYQ42000000P0ojHA
0P0000030?nV4@040:f][@3oYQ40ojHA0?nV4@8000004@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3o
YQ401@3oYQ42000000H0ojHA0P00000=0?nV4@030:f][@3oYQ00ojH@00d0ojH@00<000000?nV4000
0000303oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@
0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140103oY143000000@0[Jf]
00<0oj@A0000000000001P3oY1400`2][Jd00000000000080?nV4@800000203oYQ42000000<0ojHA
00<0[Jf]0?nV4@3oYQ400P00000B0?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@800000
1P3oYQ42000000d0ojHA00<0[Jf]0?nV403oYQ002`3oYQ02000000030?nV40000000ojH@00`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3l
X100102][Jd0oj@A0?nT4@3oY14400000080[Jf]1@3oY142000000H0oj@A00<0[Jf]000000000000
203oYQ42000000P0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA008000004P3oYQ42000000<0ojHA
00<0[Jf]0?nV4@3oYQ401@3oYQ42000000H0ojHA0P00000=0?nV4@030:f][@3oYQ00ojH@00X0ojH@
00@000000?nV403oYQ0000002`3oYQ0010000000ojH@0?nV402][JdN0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f]
[@3/UPh04@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3oool006D0
/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40800000102][Jd2000000L0
oj@A0P0000060?nT4@030:f][@000000000000P0ojHA0P0000080?nV4@8000000`3oYQ400`2][Jd0
ojHA0?nV4@0200000180ojHA0P0000030?nV4@030:f][@3oYQ40ojHA00D0ojHA0P0000060?nV4@80
00003@3oYQ400`2][Jd0ojH@0?nV40080?nV4080000000<0ojH@000000000000303oYQ0010000000
ojH@0?nV402][JdN0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0C0?JL3`<0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;
0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400=
0?bP408000000P2][Jd40?nT4@8000001`3oY142000000H0oj@A00<0[Jf]000000000000203oYQ42
000000P0ojHA0P0000030?nV4@030:f][@3oYQ40ojHA008000004P3oYQ42000000<0ojHA00<0[Jf]
0?nV4@3oYQ401@3oYQ42000000H0ojHA0P0000060?nV4@L0000000<0[Jf]0?nV403oYQ001`3oYQ00
10000000ojH@0?nV4000000>0?nV40040000003oYQ00ojH@0:f][Ah0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd0
0P2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40
oooo001S0;3PiP050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400;0?bP40@0
000000<0[Jf]0?nT4@3oY1400`3oY142000000L0oj@A0P0000060?nT4@030:f][@000000000000P0
ojHA0P0000080?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@0200000180ojHA0P0000030?nV4@03
0:f][@3oYQ40ojHA00D0ojHA0P0000060?nV4@P000001@3oYQ42000000030:f][@3oYQ00ojH@00H0
ojH@00@000000?nV4000000000003`3oYQ0010000000ojH@0?nV402][JdN0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>0080k9H>0P2][Jd<0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/2
0:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00T0o:0@0`2][Jd0103lX10000000000002][Jd50?nT4@8000001`3oY142
000000H0oj@A00<0[Jf]0000000000001`3oYQ42000000T0ojHA0P0000030?nV4@030:f][@3oYQ40
ojHA008000004P3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000H0ojHA0P000006
0?nV4@D0[Jf]0P0000080:f][@030000002][Jd000000140[Jf]00<000000:f][@2][Jd0202][JdG
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd90>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]
0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3CQ`h0dhL>
00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]103lX1020000
00030:f][@3oY140oj@A00<0oj@A0P0000070?nT4@8000001@3oY140102][Jd0ojHA000000000007
0?nV4@8000002@3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ400P0000060?nV4@H000001P3oYQ42
000000<0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ42000000H0[Jf]0P0000060:f][@D0ojHA0P000000
0`2][Jd0ojH@0?nV40040?nV40030000003oYQ0000000180ojH@00@000000?nV403oYQ00[Jf]1`3o
YA0@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh20:f][@030000003/UPh0k9H>00@0k9H>00<0
[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3o
ool00600/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100
o:0@0080o:0@0P0000030:f][@H0o:0@0P0000000`2][Jd0oj@A0?nT4@030?nT4@8000001`3oY142
000000D0oj@A00@0[Jf]0?nV4@00000000001`3oYQ42000000T0ojHA0P0000030?nV4@030:f][@3o
YQ40ojHA00P00000103oYQ42000000H0ojHA0P00000;0:f][@8000001P3oYQ42000000/0ojHA0P00
00000`2][Jd0ojH@0?nV40040?nV408000002P3oYQ000`000000ojH@0?nV40060?nV40040000003o
YQ00ojH@0:f][AL0ojD@302][JdH0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P<000000`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H10?ooo`00G`2`h>H00`2][Jd0dhL>0=>7
3P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP403lX100o:0@0P0000000`2][Jd00000
000000070?bP4080000000<0[Jf]0?nT4@3oY1400`3oY142000000L0oj@A0P0000050?nT4@040:f]
[@3oYQ400000000000L0ojHA0P0000090?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@02000000X0
ojHA0P0000060:f][@8000000`3oYQ400`2][Jd0ojHA0?nV4@050?nV4@8000001`3oYQ42000000X0
ojHA0P0000000`2][Jd0ojH@0?nV40040?nV40030000003oYQ00ojH@00T0ojH@00<000000?nV403o
YQ001P3oYQ0010000000ojH@0?nV402][JdN0?nU40030:f][@3oXa00oj<@0080oj<@2P2][Jd>0?nS
40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0;0>bF
3P@0000000<0k9H>0:f][@3KRPd0303KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V
04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH4005
0:f][@3lX100[Jf]0:f][@0000000`3lX1000`000000o:0@0?bP40050?bP4080000000<0[Jf]0?nT
4@3oY1400`3oY142000000L0oj@A0P0000050?nT4@040:f][@3oYQ400000000000L0ojHA0P000009
0?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@02000000X0[Jf]0P0000070?nV4@8000000P3oYQ40
102][Jd0ojHA0?nV4@11JN440?nV4@8000001`3oYQ42000000X0ojHA00<000000?nV4@2][Jd01P3o
YQ000`000000ojH@0?nV40080?nV40800000203oYQ0010000000ojH@0?nV402][JdN0?nU40030:f]
[@3oXa00oj<@00`0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
503fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P8000000P3/UPh3000000`0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@0P2]
[Jd00`3lX1000000000000040?bP40030000003lX100o:0@00@0o:0@0P0000000`2][Jd0oj@A0?nT
4@030?nT4@8000001`3oY142000000D0oj@A00<0[Jf]000000000000203oYQ42000000T0ojHA0P00
00000`3oYQ40[Jf]0:f][@030:f][@8000002P3oYQ42000000L0ojHA0P0000020?nV4@030:f][@3o
YQ40ojHA00@0ojHA0P0000080?nV4@8000002P3oYQ400`000000ojHA0:f][@060?nV40030000003o
YQ00ojH@00P0ojH@0P0000080?nV40040000003oYQ00ojH@0:f][Ah0ojD@00<0[Jf]0?nS403oXa00
5P3oXa080:f][AH0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P800000
0`3/UPh20:f][@8000002P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`
h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002@3_V1030:f][@80o:0@00<000000?bP403lX1000`3l
X1000`000000o:0@0?bP40040?bP4080000000<0[Jf]0?nT4@3oY1400`3oY142000000L0oj@A0P00
00050?nT4@030:f][@000000000000P0ojHA0P0000060?nV4@<0[Jf]0P000000102][Jd0ojHA0?nV
4@2][Jd20?nV4@030000003oYQ40000000T0ojHA0P0000070?nV4@8000000P3oYQ400`2][Jd0ojHA
0?nV4@040?nV4@800000203oYQ42000000T0ojHA0P0000000`3oYQ40[Jf]0?nV40050?nV40030000
003oYQ00ojH@00P0ojH@0P0000080?nV40040000003oYQ00ojH@0:f][Ah0ojD@00<0[Jf]0?nS403o
Xa006P3oXa00102][Jd0o:0@0?bP403lX1060:f][A00o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0;0>bF3P8000000`3/UPh01@2][Jd0fhX=0=^:3@000000[Jf]00T0fhX=00<0[Jf]
0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]
00P0dhL>00<0[Jf]0>nH403_V1001@3_V10200000080[Jf]0P3_V100102][Jd0o:0@00000000000<
0?bP4080000000<0[Jf]0?nT4@3oY1400P3oY142000000P0oj@A00<000000?nT4@3oY140103oY140
0`2][Jd00000000000080?nV4@80000000<0ojHA0:f][@2][Jd00`2][Jd30?nV4@8000000`3oYQ40
102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA00<000000?nV4@3oYQ401P3oYQ4200000080ojHA00<0
[Jf]0?nV4@3oYQ40103oYQ42000000T0ojHA0P0000080?nV4@040000003oYQ40ojHA0:f][@H0ojH@
00<000000?nV403oYQ001`3oYQ03000000P0ojH@00@000000?nV403oYQ00[Jf]7P3oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh2000000<0k9H>00D0[Jf]0=^:3@3KRPd000000=^:3@020:f]
[@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP04
0:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V103000000030:f][@3_V100kiP@
0080kiP@00<0[Jf]0?bP400000003@3lX102000000030:f][@3oY140oj@A0080oj@A0P0000070?nT
4@8000001P3oY1400`2][Jd00000000000060?nV4@80[Jf]0P0000000`2][Jd0ojHA0?nV4@060?nV
4@8000000`3oYQ40102][Jd0ojHA0?nV4@3oYQ42000000T0ojHA00<000000?nV4@3oYQ401`3oYQ42
000000030?nV4@2][Jd0ojHA00@0ojHA0`0000090?nV4@800000203oYQ4010000000ojHA0?nV4@2]
[Jd70?nV40030000003oYQ00ojH@00H0ojH@0`0000080?nV40040000003oYQ00ojH@0:f][Ah0ojD@
00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40H0[Jf]0`3lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00/0k9H>0P0000030>bF3P040:f][@3KRPd0fhX=000000<0
fhX=00@0[Jf]0=^:3@3KRPd000000`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H7
0:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH4002
0>nH40040000003_V1000000000000D0kiP@00<0[Jf]0?bP400000003@3lX1000`000000o:0@0:f]
[@040?nT4@8000001`3oY142000000H0oj@A00<0[Jf]0000000000001P2][Jd20?nV4@8000002@3o
YQ42000000<0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000080?nV4@8000002@3oYQ42000000030?nV
4@2][Jd0ojHA00@0ojHA0`00000:0?nV4@8000001P3oYQ401@000000ojHA0?nV4@3oYQ40[Jf]00P0
ojH@00<000000?nV403oYQ00103oYQ0010000000ojH@0?nV400000070?nV40<0000000<0ojH@0:f]
[@3oYA007@3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01@0o:0@1@2][JdE0?JL
3`030:f][@3/UPh0k9H>00/0k9H>0P0000030>bF3P040:f][@3KRPd0fhX=000000@0fhX=00@0[Jf]
0000003KRPd000000P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2][Jd0
A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V100
0P0000020:f][@8000001@3_V1000`2][Jd0o:0@0000000=0?bP40030000003lX100[Jf]00@0oj@A
0P0000070?nT4@8000001@3oY1420:f][@800000203oYQ42000000T0ojHA0P0000030?nV4@040:f]
[@3oYQ40ojHA0?nV4@800000203oYQ400`000000ojHA0?nV4@090?nV4@80000000<0[Jf]0?nV4@3o
YQ400P3oYQ4010000000ojHA00000000000;0?nV4@<00000103oYQ401@000000ojHA0?nV4@3oYQ40
[Jf]00T0ojH@1P0000030?nV40030000003oYQ00ojH@00D0ojH@0`0000000`3oYQ00[Jf]0?nU400M
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0:f][@03
0:f][A40mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh2000000<0k9H>00@0[Jf]0=^:3@3KRPd000001@3K
RPd00`000000[Jf]0:f][@02000000030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H7
0:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@
0000000200000080kiP@0P0000050>nH40030:f][@3lX100000000d0o:0@00<000000?bP402][Jd0
103oY142000000L0oj@A0P0000000`3oY140[Jf]0:f][@020:f][@040?nT4@2][Jd00000000000P0
ojHA0P0000090?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000001`3oYQ400`000000
ojHA0?nV4@0:0?nV4@8000000`3oYQ400`000000ojHA0?nV4@02000000d0ojHA1@0000040?nV4@03
0:f][@3oYQ00ojH@01P0ojH@0`0000000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0
oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]3@3fW0l00`2][Jd0
k9H>0>bF3P0;0>bF3P8000000`3/UPh0102][Jd0fhX=0=^:3@0000050=^:3@030000003KRPd0fhX=
00<000002@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0
/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P050=>73P050000002][Jd0[Jf]0:f]
[@0000000`3_V102000000D0kiP@00<0[Jf]0000000000003@3lX1000`000000o:0@0:f][@040?nT
4@8000001P3oY140102][Jd000000000002][Jd50?nT4@030:f][@000000000000P0ojHA0P000008
0?nV4@800000103oYQ400`2][Jd0ojHA0?nV4@020?nV4@8000001P3oYQ400`000000ojHA0?nV4@0<
0?nV4@040:f][@0000000000000000<0ojHA0P00000F0?nV4@030:f][@3oYQ00ojH@01P0ojH@0`00
00000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]2@3fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P8000000`3/
UPh01@2][Jd0fhX=0=^:3@3KRPd0000000<0fhX=0P0000030=^:3@<00000202iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@070=>73P030000003CQ`h0[Jf]0080kiP@00@000000>nH403_V100kiP@0P0000050>nH4003
0:f][@000000000000d0o:0@00<000000?bP402][Jd0103oY142000000<0oj@A0`2][Jd00`3oY140
0000000000060?nT4@030:f][@000000000000P0ojHA0`0000070?nV4@800000103oYQ400`2][Jd0
ojHA0?nV4@030?nV4@800000103oYQ400`000000ojHA0?nV4@0=0?nV4@030:f][@3oYQ40ojHA00@0
ojHA0P00000F0?nV4@030:f][@3oYQ00ojH@01P0ojH@0`0000000`3oYQ00[Jf]0?nU400M0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;0?JL3`@0
[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P050000003/UPh0k9H>0>bF3P2][Jd00`3KRPd01000
0000fhX=0=^:3@3KRPd2000000<0fhX=0P0000000`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@28EPL0
R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00H0dhL>0P0000020:f][@80kiP@00@000000>nH403_V100kiP@0P0000040>nH40040:f][@3l
X1000000000000d0o:0@00<000000?bP402][Jd0103oY142000000<0[Jf]103oY142000000H0oj@A
00<0[Jf]0000000000001`3oYQ42000000030?nV4@000000ojHA00H0ojHA0P0000040?nV4@030:f]
[@3oYQ40ojHA00D0ojHA1000000@0?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00000F0?nV4@030:f]
[@3oYQ00ojH@01P0ojH@0`0000000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`@0[Jf]00<0mY`?0:f][@3/UPh0
3@3/UPh01@000000k9H>0>bF3P3/UPh0[Jf]00<0fhX=00@000000=^:3@3KRPd0fhX=0P0000030=^:
3@80000000D0^GD;0:f][@2][Jd0^GD;000000040;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]
0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>00D0[Jf]
0000003CQ`h0[Jf]0>nH4002000000<0kiP@0P0000040>nH40040:f][@3lX1000000000000d0o:0@
00@000000?bP402][Jd0oj@A0`2][Jd2000000L0oj@A0P0000060?nT4@040:f][@00000000000000
00H0ojHA0P0000020?nV4@030000003oYQ40ojHA00<0ojHA0P0000040?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000001H0ojHA00<0[Jf]0?nV403oYQ00603oYQ030000
00030?nV402][Jd0ojD@01d0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP
40030:f][@3fW0l0mY`?01<0mY`?0`2][Jd=0>bF3P050000003/UPh0k9H>0>bF3P2][Jd00`3KRPd0
10000000fhX=0=^:3@3KRPd2000000<0fhX=0P0000030;Ue2`<000000`2iM@/00`2][Jd0R5H708QF
1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f]
[@050=>73P060:f][@3CQ`h000000=>73P2][Jd0kiP@0P0000030>nH40800000103_V100102][Jd0
o:0@00000000000=0?bP40040000002][Jd0[Jf]0:f][@<0oj@A0P0000070?nT4@8000001P3oY140
102][Jd000000000000000060?nV4@8000000`3oYQ4200000080ojHA00<000000?nV4@3oYQ40103o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00@0ojHA0P00000F0?nV4@030:f][@3o
YQ00ojH@01P0ojH@0`0000000`3oYQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]2P3/
UPh01@000000k9H>0>bF3P3/UPh0[Jf]00<0fhX=00@000000=^:3@3KRPd0fhX=0P0000030=^:3@80
00000`2iM@/3000000<0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P070:f][@3CQ`h0dhL>0000003CQ`h0[Jf]0>nH4002
000000<0kiP@0P0000040>nH40030:f][@3lX100000000`0o:0@0P2][Jd010000000o:0@0:f][@11
JN430?nT4@8000001`3oY142000000H0oj@A00@0[Jf]000000000000ojHA0P0000030?nV4@800000
1P3oYQ42000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@040?nV4@800000
5P3oYQ400`2][Jd0ojH@0?nV400H0?nV40<0000000<0ojH@0:f][@3oYA007@3oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P020>bF3P80[Jf]203/UPh01@000000k9H>0>bF3P3/UPh0000000<0fhX=00@000000=^:3@3K
RPd0fhX=0P0000030=^:3@8000000`2iM@/2000000050:f][@000000^GD;0;Ue2`2][Jd01028EPL2
0:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P080:f][@3CQ`h0
dhL>0=>73P000000dhL>0:f][@3_V102000000<0kiP@0P0000040>nH40030:f][@3lX100000000H0
o:0@00@000000?bP403lX100o:0@0P2][Jd20?bP40030000003lX100[Jf]00@0oj@A0P0000070?nT
4@8000001P3oY1400`2][Jd00000000000030?nV4@@00000403oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00@0ojHA0P00000F0?nV4@030:f][@3oYQ00ojH@01P0ojH@0`0000000`3o
YQ00[Jf]0?nU400M0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd50>bF3P050000003/UPh0k9H>
0>bF3P0000001`3KRPd2000000@0fhX=00D000000;Ue2`2iM@/0^GD;000000020;Ue2`040000002]
[Jd0^GD;000000@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0
dhL>0P2][Jd40=>73P050000003CQ`h0[Jf]0>nH40000000103_V102000000@0kiP@00<0[Jf]0?bP
400000001P3lX10010000000[Jf]0:f][@2][Jd30?bP4080000000<0o:0@0:f][@3oY1400`3oY142
000000L0oj@A0P0000060?nT4@030:f][@000000000001L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@040?nV4@8000003`3oYQ4R0:f][@<000002@2][JdG0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>00L0k9H>0`2][Jd20>bF3P050000003/UPh0k9H>0>bF3P0000001`3KRPd2000000@0fhX=00D0
00000;Ue2`2iM@/0^GD;000000020;Ue2`050000002iM@/0[Jf]0:f][@0000000`28EPL20:f][D80
/>3V0@3oool005T0/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd60=>73P0500000011JN40[Jf]0>nH
40000000103_V102000000@0kiP@00<0[Jf]0?bP40000000103lX1020:f][@8000001@3lX1020000
00030?bP402][Jd0oj@A00<0oj@A00<000000?nT4@3oY1401P3oY142000000D0oj@A0P00000I0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000000l0[Jf]1`3oYQ400`2]
[Jd0ojH@0?nV400H0?nV40<0000000<0ojH@0:f][@3oYA001P3oYA0@0:f][@L0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF
3P3/UPh02P3/UPh20:f][@050000003/UPh0k9H>0>bF3P0000001`3KRPd2000000@0fhX=00D00000
0;Ue2`2iM@/0^GD;000000020;Ue2`040000002iM@/0^GD;0:f][@8000000`28EPL00`2][Jd0/>3V
0;3PiP100;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01`3CQ`h01@000000@FWQ
0:f][@3_V100000000@0kiP@00<000000>nH403_V1000`3_V1000`2][Jd0o:0@000000020?bP4080
[Jf]0P3lX102000000D0o:0@0P0000000`3lX100[Jf]0?nT4@030?nT4@030000003oY140oj@A00H0
oj@A0P0000060?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4;0:f][@80
00005P3oYQ400`2][Jd0ojH@0?nV400H0?nV40<0000000<0ojH@0:f][@3oYA005P3oYA0<0:f][AP0
oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0
k9H>00D000000:f][@2][Jd0k9H>000000070=^:3@800000103KRPd01@000000[Jf]0;Ue2`2iM@/0
000000<0^GD;00H000000;Ue2`2][Jd0000008QF1`00000208QF1`030:f][@2`h>H0/>3V0400/>3V
0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P2][Jd70=>73P050000002][Jd0kiP@0>nH40000000
0`3_V102000000D0kiP@00<0[Jf]0?bP400000000P2][Jd40?bP408000001@3lX103000000030:f]
[@3oY140oj@A0080oj@A00<000000?nT4@3oY140103oY143000000L0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@040?nV4@800000
5P3oYQ400`2][Jd0ojH@0?nV400H0?nV40050000003oYQ0000000?nV402][Jd07P3oYA000`2][Jd0
oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh0303/UPh01P000000k9H>0>bF3P2][Jd000000:f][@H0fhX=0P000004
0=^:3@030000002][Jd0^GD;008000000`2iM@/01@000000^GD;0:f][@000000R5H70080000000<0
R5H70:f][@2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`020:f][@L0dhL>00<00000
0:f][@0000000P0000030>nH408000001@3_V1020:f][@8000001P3lX1000`000000o:0@0?bP4003
0?bP40<0000000D0[Jf]0?nT4@3oY140oj@A0000000A0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40103oYQ42000001H0ojHA00<0
[Jf]0?nV403oYQ00603oYQ0200000080ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0
[Jf]0>bF3P3/UPh0303/UPh200000080k9H>00@000000=^:3@2][Jd0[Jf]103KRPd2000000@0fhX=
00<000000:f][@2iM@/00P0000050;Ue2`030:f][@000000[Jf]0080000000<0R5H70:f][@2`h>H0
@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0:f][@2GH0/0[Jf]00L0dhL>0P0000000`3_V1000000
000000030>nH408000000`3_V1030:f][@030?bP40000000000000D0o:0@00<000000?bP403lX100
103lX102000000050?bP40000000oj@A0?nT4@0000004P3oY1400`2][Jd0ojHA0?nV4@0D0?nV4@P0
[Jf]603oYQ400`2][Jd0ojHA0?nV4@040?nV4@8000005P3oYQ400`2][Jd0ojH@0?nV400I0?nV4004
0000003oYQ00ojH@0:f][Ah0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AL0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0000000<0k9H>0000003KRPd00P3KRPd20:f]
[@80fhX=0P0000040=^:3@030000002][Jd0^GD;008000001@2iM@/00`2][Jd0000008QF1`020000
000308QF1`2][Jd0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2][Jd0Uf0;0:f][@070=>7
3P030000002][Jd0kiP@008000000`3_V102000000030>nH402][Jd0[Jf]0080kiP@00@0[Jf]0?bP
4000000000001@3lX1000`000000o:0@0?bP40040?bP4080000000@0[Jf]0?nT4@00000000004`3o
Y1400`2][Jd0ojHA0?nV4@0>0?nV4@H0[Jf]0`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA00@0ojHA0P00000F0?nV4@030:f][@3oYQ00ojH@01T0ojH@00@000000?nV403oYQ00[Jf]
7P3oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP40L0[Jf]403lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00/0k9H>0P0000000`3/UPh00000000000050=^:3@80
[Jf]00<0fhX=0000000000000`3KRPd2000000030;Ue2`000000000000D0^GD;00<0[Jf]00000028
EPL00P0000000`28EPL0[Jf]0;3PiP110;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2][Jd0dhL>
0=>73P050=>73P030000002][Jd0kiP@008000000`3_V102000000030:f][@3_V100kiP@0080kiP@
00@0[Jf]0?bP400000000000103lX1000`000000o:0@0?bP40050?bP4080000000<0[Jf]0?nT4@3o
Y140503oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]2@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@04
0:f][@3oYQ40ojHA0?nV4@D000005P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40080?bP40H0[Jf]2P3lX1000`2]
[Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00/0k9H>0P0000020>bF3P030:f][@000000fhX=
00D0fhX=00<0[Jf]0000000000000`3KRPd2000000030;Ue2`000000000000D0^GD;00<0[Jf]0000
0028EPL00P0000000`28EPL0[Jf]0;3PiP110;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/00`2][Jd0
dhL>0=>73P050=>73P030000002][Jd0kiP@008000000P3_V1000`2][Jd00000000000030>nH4003
0000003_V100[Jf]0080o:0@0P0000030?bP40030000003lX100o:0@00D0o:0@0P0000000`2][Jd0
oj@A0?nT4@0D0?nT4@040:f][@3oYQ40ojHA0?nV4@H0[Jf]403oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL
3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P8000000P3/UPh00`2][Jd000000=^:3@060=^:
3@80000000<0[Jf]0=^:3@3KRPd00P0000020;Ue2`030000002iM@/0^GD;00<0^GD;00<0[Jf]0000
0028EPL00P0000000`2][Jd000000;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd01`3CQ`h00`000000[Jf]0>nH400200000080[Jf]00<0kiP@0000000000000`3_V1020000
00030:f][@3lX100o:0@008000000P3lX1000`000000o:0@0?bP40060?bP4080000000<0[Jf]0?nT
4@3oY1404`3oY1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01D0o:0@1P2][JdD0?JL3`030:f][@3/UPh0k9H>00/0k9H>0P0000020>bF
3P030:f][@000000fhX=00H0fhX=0P0000000`3KRPd0[Jf]0:f][@0200000080^GD;00<000000;Ue
2`2iM@/00`2iM@/00`2][Jd0000008QF1`020000000308QF1`00000000000440/>3V0@3oool005P0
/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00D000000:f][@3_V10000000:f][@030>nH
408000000`3_V102000000050:f][@3lX100o:0@0?bP400000000P3lX1000`000000o:0@0?bP4006
0?bP4080000000<0[Jf]0?nT4@3oY1403`3oY1440:f][@030?nT4@2][Jd0ojHA01P0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]
0?JL3`3fW0l0102][Jd@0?JL3`030:f][@3/UPh0k9H>00/0k9H>0P0000020>bF3P030:f][@000000
fhX=00H0fhX=0P0000030=^:3@8000000P2iM@/00`000000^GD;0;Ue2`040;Ue2`0500000028EPL0
R5H700000028EPL00P0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P05
0=>73P040000002][Jd0[Jf]000000@0kiP@0P0000030>nH4080000000<0[Jf]0?bP403lX1000P3l
X102000000T0o:0@00<000000?bP402][Jd03@3oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P8000000P3/
UPh00`2][Jd000000=^:3@060=^:3@8000000`3KRPd2000000030:f][@2iM@/0000000H0^GD;0P00
00000`28EPL0000008QF1`0200000440/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0
dhL>00D0dhL>00@000000:f][@3_V1000000103_V10300000080kiP@0P0000000`2][Jd0o:0@0?bP
400=0?bP40030000003lX100[Jf]00T0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]0>bF3P3/UPh02`3/UPh200000080k9H>00<0
[Jf]0000003KRPd01P3KRPd2000000<0fhX=0P0000000`2iM@/0[Jf]000000060;Ue2`80000000<0
R5H700000028EPL00P0000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P04
0=>73P050:f][@000000[Jf]0>nH40000000103_V10300000080kiP@00<000000>nH402][Jd03`3l
X1000`000000o:0@0:f][@050?nT4@@0[Jf]1@3oY1400`000000oj@A0?nT4@050?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l40:f][@80mY`?00<0[Jf]0>bF3P3/UPh02`3/
UPh2000000<0k9H>00<000000=^:3@3KRPd01@3KRPd2000000@0fhX=00<000000;Ue2`2iM@/00P00
00050;Ue2`80000000<0R5H700000028EPL00`0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0
0`2][Jd0dhL>0=>73P030=>73P030:f][@3CQ`h0dhL>00<00000103_V102000000060>nH40000000
00000000003_V100[Jf]3`3lX10010000000o:0@0:f][@3oY1440:f][@P0oj@A00<000000?nT4@00
00001P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?102][Jd=0>bF3P05
0000003/UPh0k9H>0>bF3P0000001`3KRPd2000000@0fhX=00<000000;Ue2`2iM@/00P0000000`2]
[Jd0^GD;000000020;Ue2`80000000<0R5H700000028EPL00`0000100;3PiP40oooo001H0;3PiP80
[Jf]0`2GH0/0102][Jd0dhL>0=>73P3CQ`h20:f][@<0dhL>0`0000040>nH408000001@3_V1000`2]
[Jd0o:0@0?bP400=0?bP40040000002][Jd0[Jf]0:f][@`0oj@A00<000000?nT4@0000001P3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P2][Jd00P2][Jd:
0>bF3P050000003/UPh0k9H>0>bF3P2][Jd00P3KRPd010000000fhX=0=^:3@3KRPd3000000@0fhX=
00<000000;Ue2`2iM@/00P0000000`2iM@/0[Jf]000000020;Ue2`80000000<0R5H700000028EPL0
0`0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/0102][Jd0dhL>0=>73P2][Jd50=>73P<00000
103_V102000000D0kiP@00<0[Jf]0?bP403lX100303lX100102][Jd000000?bP402][Jd=0?nT4@80
00001`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh00P3/UPh20:f][@P0k9H>00D000000>bF3P3/UPh0k9H>0:f][@020=^:3@030000003KRPd0fhX=
0080fhX=0P0000040=^:3@030000002iM@/0^GD;008000000P2iM@/2000000060;Ue2`0000000000
08QF1`000000R5H70`0000100;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0:f][@06
0=>73P<000000`3_V102000000H0kiP@00<0[Jf]0?bP403lX1002@3lX1030:f][@040?bP40000000
o:0@0:f][@h0oj@A00<000000?nT4@3oY1401@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@D0k9H>00D000000>bF3P3/UPh0k9H>
0:f][@020=^:3@030000003KRPd0fhX=00P0fhX=00<000000;Ue2`2iM@/00P0000020;Ue2`800000
00@0[Jf]000000000000R5H7100000110;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/20:f][@L0dhL>
0`00000;0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd40?bP40030000003lX100[Jf]01H0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00L0k9H>
0`2][Jd20>bF3P050000003/UPh0k9H>0>bF3P2][Jd00P3KRPd00`000000fhX=0=^:3@060=^:3@03
0000003KRPd0000000<0^GD;0P000000102iM@/000000000002iM@/20000000308QF1`0000000000
00800000@@2`h>H10?ooo`00F02`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0
dhL>0P00000<0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd60?bP40030000003lX100[Jf]01D0
oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01D0
ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0
mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][Jd01@000000k9H>0>bF3P3/UPh0[Jf]
0080fhX=00<000000=^:3@3KRPd01`3KRPd2000000<0^GD;0P0000020;Ue2`050000002iM@/00000
00000028EPL0100000110;3PiP40oooo001H0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h0
0`2][Jd000000000000<0>nH40040:f][@3lX100o:0@0?bP40<0[Jf]2@3lX1000`000000o:0@0:f]
[@0E0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh01@000000[Jf]0:f]
[@3/UPh0[Jf]0080fhX=00<000000=^:3@3KRPd02@3KRPd00`2][Jd0^GD;0;Ue2`02000000040;Ue
2`000000^GD;0;Ue2`80000000H0R5H700000000000000000:f][@0000100;3PiP40oooo001H0;3P
iP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`3CQ`h00`2][Jd000000000000<0>nH40040:f][@3lX100
[Jf]0:f][@/0o:0@0P0000000`3lX100[Jf]0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0
[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P030000003/UPh0k9H>00<0[Jf]00<0
fhX=0000003KRPd02P3KRPd00`2][Jd0^GD;0;Ue2`02000000070;Ue2`000000^GD;0;Ue2`2][Jd0
00000:f][@03000000030:f][@000000/>3V03l0/>3V0@3oool005P0/>3V00H0[Jf]09MP2`2GH0/0
[Jf]09MP2`2][Jd70=>73P030:f][@000000000000/0kiP@0`2][Jd;0?bP408000000`3lX1000`2]
[Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f]
[FT0/>3V3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2]
[Jd0k9H>0>bF3P0<0>bF3P070000003/UPh0k9H>0>bF3P2][Jd0fhX=0:f][@02000000X0fhX=00L0
[Jf]0;Ue2`2iM@/0^GD;0000002iM@/000000080^GD;00<0[Jf]0000002][Jd00`0000000`2][Jd0
00000;3PiP0o0;3PiP40oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h0
1@3CQ`h00`2][Jd00000000000090>nH4080[Jf]00<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V
2P2][JdH0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0303/UPh01@000000k9H>
0>bF3P3/UPh0[Jf]0080fhX=0P0000000`2][Jd0fhX=0=^:3@070=^:3@030:f][@2iM@/0^GD;0080
^GD;0P0000020;Ue2`030:f][@000000R5H700<0000000<0[Jf]0000002`h>H0?`2`h>H10?ooo`00
F02`h>H00`2][Jd0Uf0;0:f][@0209MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]000000000000
1`3_V1020:f][@<0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f]
[@3/UPh0k9H>00T0k9H>0`0000030>bF3P030:f][@3KRPd0fhX=0080000000<0fhX=0:f][@2][Jd0
1`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@000000R5H708QF1`80000000<0[Jf]0000002`
h>H0?`2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd00000
000000050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?
00<0[Jf]0>bF3P3/UPh0303/UPh3000000030:f][@3KRPd0fhX=008000000`3KRPd20:f][@D0fhX=
00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0000008QF1`28EPL2000000030:f][@000000/>3V03l0
/>3V0@3oool005P0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]000000000000
0`3_V1020:f][@L0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f]
[@3oYQ40ojHA00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>1@0000050=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f]
[@000000R5H708QF1`80000000<0[Jf]0000002`h>H0?`2`h>H10?ooo`00E`2`h>H20:f][@@0Uf0;
00<0[Jf]0=>73P3CQ`h01@3CQ`h0102][Jd000000000003_V1020:f][@T0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40ojHA0?nV4@L0[Jf]^P2`h>H60:f]
[@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=
008000001`3KRPd20:f][@030=^:3@2][Jd0^GD;00P0^GD;00<0000008QF1`28EPL00P0000000`2]
[Jd000000;3PiP0o0;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd0dhL>0=>73P060=>73P04
0:f][@00000000000:f][@/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT
4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@80[Jf]2@2iM@/00`000000R5H708QF1`0200000003045Yh@000000/>3V03l0/>3V0@3oool005L0
/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0[Jf]0000003_V100303_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd70;Ue2`0300000028EPL000000080
000000<0@FWQ0000002`h>H0?`2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0
1@3CQ`h20:f][@030000003_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A
0?nT4@090?nT4@@0[Jf]f`2`h>H40:f][@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@0<0=^:3@040:f][@2iM@/0^GD;0:f][@H0^GD;00D0000008QF1`28EPL000000:f][@020000
0400/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00<0dhL>0P2][Jd00`3CQ`h0
[Jf]0000000<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f][N<0
/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0
^GD;0;Ue2`2iM@/0[Jf]00D0^GD;0P00000208QF1`030:f][@00000000000400/>3V0@3oool005L0
/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>0080dhL>00H0[Jf]0=>73P3CQ`h0dhL>0:f][@00000<
0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140102][Jg]0;3PiPD0[Jf]0P3fW0l0
0`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2iM@/2
0:f][@<0^GD;0P00000208QF1`030:f][@00000000000400/>3V0@3oool005L0/>3V0P2][Jd309MP
2`050:f][@3CQ`h0dhL>0=>73P2][Jd0103CQ`h00`2][Jd000000>nH400;0>nH40030:f][@3lX100
o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00@0^GD;00<0[Jf]0;Ue2`2iM@/00P00000208QF1`030:f][@00000000000400/>3V0@3oool0
05L0/>3V0P2][Jd309MP2`040:f][@3CQ`h0[Jf]0:f][@D0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`h>H30:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`050;Ue2`80[Jf]0P00000208QF1`030:f][@00000000000400/>3V0@3oool0
05L0/>3V0P2][Jd309MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@
00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]
0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`8000000`28EPL00`2][Jd000000;3PiP0o
0;3PiP40oooo001G0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2]
[Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0o:0@0`2][Jd80;VbYP80[Jf]m02`h>H40:f]
[@L0`kfk102][Jd70>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20000
00<0R5H700<0[Jf]0000002`h>H0?`2`h>H10?ooo`00E`2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f]
[@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:
3@030:f][@2iM@/0^GD;00L0^GD;0P00000308QF1`030:f][@000000000003l0/>3V0@3oool005L0
/>3V00@0[Jf]09MP2`2GH0/0Uf0;0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP
403lX1000P3lX1020:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0302i/ZH30:f][NL0/>3V102][Jd00`36
`;`0[Jf]0<>m^`0?0<>m^`030:f][@2n^KP0_[Vh00<0[Jf]00<0k9H>0:f][@3KRPd0303KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`80000000@0[Jf]08QF1`28EPL0[Jf]0P00000o0;3PiP40oooo001G0;3P
iP060:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`
h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3K
RPd00`2][Jd0^GD;0;Ue2`060;Ue2`<0000000@0[Jf]00000028EPL0[Jf]0P00000o0;3PiP40oooo
001G0;3PiP030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH
400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102]
[JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2]
[Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P0000001P28EPL0000008QF1`2][Jd0/>3V000003l0
/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f]
[@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
1`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
1`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`0000020:f][@03
0;3PiP000000/>3V03h0/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H700000080
[Jf]00<0/>3V0000002`h>H0?P2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h0
1P3CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2aZid0/J^M0P2][Jd80;6[W@80
@FWQ402i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0[Jf]0<K0_036
`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd40;ji^080
[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H700000028EPL00P2][Jd00`00
0000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]0=>73P3C
Q`h01P3CQ`h0102][Jd0kiP@0>nH403_V1020:f][@80@FWQ0P2TWXl00`2][Jd0/J^M0;6[W@020;6[
W@80[Jf]1`2aZid0102][Jd0@FWQ045Yh@11JN4=0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]
0<6j/031^[001@2][Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0
`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3K
RPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Jd00`000000/>3V0;3P
iP0m0;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0:f]
[@2][Jd30:BNS`80@FWQ00<0Y9j?0:f][@2aZid01@2aZid20:f][@D0/J^M00<0[Jf]045Yh@2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]
3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0
_[Vh0P2][Jd80;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00D0[Jf]09MP
2`2GH0/0Uf0;0:f][@090=>73P80[Jf]0P11JN430:BNS`04045Yh@2TWXl0Y9j?0:f][@P0/J^M0P2]
[Jd30;6[W@030:f][@11JN40^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j
/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`0=0<>m^`040:f][@2n^KP0[Jf]0:f][@X0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][@X0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0m0;3PiP40oooo001G0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0Y9j?0:BNS`02045Yh@<0Y9j?00@0@FWQ0:BNS`2T
WXl0[Jf]2P2aZid20:f][@030;6[W@2][Jd0@FWQ00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2][Jd<0;ji^0030:f][@2d/;40];2a
00D0];2a0P2][Jd80;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H1
0?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd30:BNS`80@FWQ0`2TWXl0
1011JN40Y9j?0:BNS`2][Jd50;6[W@03045Yh@2aZid0/J^M00@0/J^M0P2][Jd00`11JN40^K:V0;Vb
YP0=0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m
/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`0
4036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP0302n^KP00`2][Jd0];2a
0;B`/@070;B`/@030:f][@2iM@/0^GD;00D0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@02000003l0
/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P80[Jf]00@0@FWQ0:BNS`2T
WXl0Y9j?0P11JN430:BNS`03045Yh@2TWXl0[Jf]00D0/J^M00@0@FWQ0;6[W@11JN40@FWQ1@2aZid0
0`2][Jd0@FWQ0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]
0;ji^02n^KP00P2n^KP00`11JN40_[Vh0;ji^0070;ji^0030:f][@2d/;40];2a00L0];2a0P2][Jd5
0;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H0
1@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>00@0[Jf]08Z5M@2:QGD0@FWQ0P2TWXl3045Yh@<0Y9j?
00<0@FWQ0:BNS`2][Jd0102aZid01@11JN40/J^M0;6[W@2aZid0@FWQ00D0/J^M00<0[Jf]045Yh@2i
/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00@0[Jf]0;ji^02n
^KP0_[Vh0P11JN490;ji^0030:f][@2d/;40];2a00H0];2a1@2][Jd30;Ue2`040:f][@28EPL0R5H7
08QF1`80[Jf]00<000000;3PiP2`h>H0?@2`h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00<0dhL>00<0[Jf]045Yh@2:QGD00P11JN420:f][@030:BNS`11JN40@FWQ00<0Y9j?00<0@FWQ
0:BNS`2][Jd0102aZid01P11JN40/J^M0;6[W@2aZid0@FWQ0;6[W@<0@FWQ00<0/J^M0:f][@11JN40
1`2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f]
[@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0[Jf]0080[Jf]2`33_K/0102][Jd0_[Vh0;ji^02n^KP2045Yh@T0_[Vh00<0[Jf]0;B`/@2d
/;401@2d/;401`2][Jd0];2a0;B`/@2][Jd0Wi^P045Yh@2][Jd00P2iM@/0102][Jd0R5H708QF1`28
EPL20:f][@030000002`h>H0/>3V03d0/>3V0@3oool005L0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f]
[@3CQ`h20:f][@80@FWQ00<0RXEe045Yh@11JN400P2TWXl0102][Jd0Y9j?0:BNS`11JN420:BNS`03
045Yh@2TWXl0[Jf]00@0/J^M00H0@FWQ0;6[W@2aZid0/J^M045Yh@2aZid2045Yh@80/J^M00<0[Jf]
045Yh@2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`03`36`;`3
0:f][@/0`kfk1011JN440;ji^003045Yh@2n^KP0_[Vh00L0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;42
0:f][@<0];2a00@0[Jf]09nKX011JN40@FWQ0`2][Jd408QF1`030:f][@000000/>3V03h0/>3V0@3o
ool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/20:f][@<0RXEe00@0@FWQ08Z5M@11JN40@FWQ0`2T
WXl20:f][@80Y9j?00@0@FWQ0:BNS`2TWXl0[Jf]102aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ
0`2aZid00`2][Jd0@FWQ0;VbYP02045Yh@/0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng
;`2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`090<>m^`80@FWQ
0`33_K/00`2][Jd0@FWQ0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;401`2][Jd0
Wi^P045Yh@11JN40Wi^P045Yh@2][Jd01028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3P
iP030:f][@2GH0/0Uf0;0080Uf0;00<0[Jf]08Z5M@2:QGD00`2:QGD3045Yh@D0Y9j?0P2][Jd2045Y
h@030:BNS`2][Jd0/J^M00<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@<0/J^M00@0[Jf]045Y
h@11JN40^K:V0P11JN4;0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D
0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_007
0<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`080<>m^`80@FWQ0`33_K/00`2][Jd0@FWQ0;ji^00<
0;ji^0040:f][@2d/;40];2a0:f][@L0];2a00P0[Jf]09nKX011JN40@FWQ09nKX011JN40Wi^P0:f]
[@<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f]
[@H0RXEe0P11JN470:BNS`80@FWQ00<0Y9j?0:f][@2aZid00`2aZid00`11JN40/J^M0;6[W@020;6[
W@80@FWQ0`2aZid00`2][Jd0@FWQ0;VbYP020;VbYP80@FWQ2P2i/ZH00`2][Jd0_[N/0;jg[0030;jg
[0@0[Jf]2@2n]j`00`2][Jd0`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`04@37`K`00`2][Jd0a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`080<>m
^`03045Yh@33_K/0`kfk00<0`kfk00<0@FWQ0;ji^02n^KP02`2n^KP30:f][@P0];2a00P0[Jf]09nK
X011JN40@FWQ09nKX011JN40Wi^P0:f][@<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`
h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@H0RXEe0P11JN470:BNS`80@FWQ0P2][Jd40;6[W@80@FWQ
0`2aZid2045Yh@<0/J^M00<0[Jf]045Yh@2i/ZH00P2i/ZH2045Yh@@0^K:V0`11JN430;VbYP030:f]
[@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<0
5033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4`38`K/00`2][Jd0al6l0<O1_003045Yh@h0al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0030:f]
[@33_K/0`kfk00@0@FWQ1033_K/00`11JN40`kfk0<>m^`030<>m^`03045Yh@2n^KP0_[Vh00X0_[Vh
0P2][Jd:0;B`/@060:f][@2OVj00@FWQ045Yh@2OVj00@FWQ0P2OVj00102][Jd0R5H708QF1`2][Je0
0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;00<0[Jf]1`2:QGD00`11JN40Y9j?0:BNS`050:BN
S`80@FWQ00<0Y9j?0:f][@2][Jd0102aZid01011JN40/J^M0;6[W@2aZid2045Yh@<0/J^M00<0@FWQ
0;VbYP2i/ZH00`2i/ZH2045Yh@D0^K:V0`11JN400`2i/ZH0[Jf]0;jg[00<0;jg[0@0[Jf]00<0_[N/
0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]
0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`@0@FWQ3P37`K`40:f][A40a/2l00<0[Jf]
0<>m^`11JN400`33_K/00`11JN40`kfk0<>m^`020<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN4:
0;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;401P2][Jd0Wi^P045Yh@11JN40Wi^P045Yh@80Wi^P
0P2][Jd00`28EPL0[Jf]0;3PiP0o0;3PiP40oooo001F0;3PiP040:f][@2GH0/0[Jf]06=PD`80[Jf]
1P2:QGD00`2][Jd0@FWQ0:BNS`060:BNS`80@FWQ00<0Y9j?0:f][@2aZid00P2][Jd30;6[W@03045Y
h@2aZid0/J^M0080@FWQ0`2aZid00`11JN40^K:V0;VbYP030;VbYP80@FWQ1@2i/ZH01@11JN40^K:V
0;VbYP2i/ZH0[Jf]00<0@FWQ3P2n]j`40:f][A40`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0
aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0
al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0102][Jd0
al6l045Yh@11JN490<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00:0<K0_0<0@FWQ0`36`;`00`2]
[Jd0@FWQ0<>m^`040<>m^`05045Yh@33_K/0`kfk0<>m^`11JN400`33_K/2045Yh@050:f][@2n^KP0
_[Vh0;ji^011JN40102n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;40202d/;401P2][Jd0Wi^P045Y
h@11JN40Wi^P045Yh@80Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`h>H20:f][@<0
Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0@FWQ0:BNS`060:BNS`05045Yh@2TWXl0@FWQ0:f]
[@11JN400P2aZid30:f][@030;6[W@11JN40/J^M0080@FWQ0`2aZid00`11JN40^K:V0;VbYP030;Vb
YP80@FWQ1@2i/ZH01@11JN40^K:V0;VbYP2i/ZH0[Jf]0080_[N/0`11JN4=0;jg[0030:f][@31^[00
`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0@FWQ045Yh@@0al6l1@2]
[Jd70<O1_0030:f][@36`;`0a/2l00P0a/2l0`11JN450<K0_003045Yh@33_K/0`kfk00`0`kfk00<0
@FWQ0<>m^`2][Jd00`2n^KP00`11JN40_[Vh0:f][@020:f][@D0_[Vh00<0[Jf]0;B`/@2d/;40202d
/;400`2][Jd0Wi^P045Yh@02045Yh@80Wi^P0P2][Jd00`1`KWT0[Jf]0:f][@100;3PiP40oooo001F
0;3PiP80[Jf]0`1SH5<20:f][@D0RXEe00<0[Jf]045Yh@2TWXl00P2TWXl00`11JN40Y9j?0:BNS`02
045Yh@040:BNS`11JN40@FWQ045Yh@D0/J^M0P2][Jd3045Yh@<0/J^M00<0@FWQ0;VbYP2i/ZH0102i
/ZH00`11JN40^K:V0;VbYP030;VbYP05045Yh@2i/ZH0^K:V0;VbYP2][Jd00P2n]j`00`11JN40_[N/
0;jg[0020;jg[0<0@FWQ202n]j`00`2][Jd0`KZ`0<6j/0050<6j/0D0[Jf]1`31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`040:f][@37`K`0@FWQ045Yh@@0[Jf]3037`K`00`2][Jd0a/2l0<K0_0030<K0_0<0
@FWQ1036`;`00`11JN40a/2l0<K0_0030<K0_003045Yh@33_K/0`kfk00/0`kfk0P11JN400`33_K/0
[Jf]0;ji^0020;ji^003045Yh@2][Jd0_[Vh00L0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0
Wi^P045Yh@02045Yh@0409nKX02][Jd0Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP03
0:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2][Jd0102:QGD00`2][Jd0@FWQ0:BNS`020:BNS`09
045Yh@2TWXl0Y9j?0:BNS`11JN40Y9j?045Yh@2][Jd0@FWQ00<0/J^M0P11JN420;6[W@030:f][@11
JN40@FWQ00<0/J^M00<0@FWQ0;VbYP2i/ZH0102i/ZH00`11JN40^K:V0;VbYP030;VbYP04045Yh@2i
/ZH0^K:V0:f][@<0_[N/00<0@FWQ0;jg[02n]j`0102n]j`3045Yh@H0_[N/00<0[Jf]0<6j/031^[00
2P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/50:f][@80@FWQ3`37`K`3045Yh@80a/2l
0`11JN460<K0_003045Yh@36`;`0a/2l00<0a/2l00<0@FWQ0<>m^`33_K/02`33_K/01@11JN40`kfk
0<>m^`2][Jd0_[Vh0080[Jf]00<0@FWQ0;ji^02n^KP01`2n^KP00`2][Jd0];2a0;B`/@080;B`/@06
0:f][@2OVj00@FWQ045Yh@2OVj00[Jf]0P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@030:f][@11JN40
Y9j?0080Y9j?00<0@FWQ0:BNS`2TWXl0102TWXl2045Yh@<0/J^M0P11JN430;6[W@80@FWQ0P2][Jd0
0`2aZid0@FWQ0;VbYP050;VbYP03045Yh@2i/ZH0^K:V00<0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]0`2n
]j`00`11JN40_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00H0_[N/0`11JN4?0<6j/0P0[Jf]4033
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38
`K/70:f][@<0b<6k00@0[Jf]0<O1_011JN40@FWQ3037`K`4045Yh@030:f][@36`;`0a/2l00<0a/2l
00<0@FWQ0<K0_036`;`01036`;`00`11JN40a/2l0<K0_0020<K0_080@FWQ3033_K/2045Yh@040<>m
^`2][Jd0[Jf]0:f][@80_[Vh00<0@FWQ0;ji^02n^KP01`2n^KP00`2][Jd0];2a0;B`/@080;B`/@03
0:f][@2OVj00@FWQ0080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]045Yh@11
JN400P2TWXl00`11JN40Y9j?0:BNS`040:BNS`030:f][@11JN40/J^M0080/J^M00<0@FWQ0;6[W@2a
Zid00P2aZid01011JN40/J^M0;6[W@2aZid30:f][@D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH01011
JN40^K:V0;VbYP2][Jd30;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0;jg[02n]j`0102n]j`2
045Yh@040:f][@31^[00`KZ`045YhA00`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]
2P38`K/0102][Jd0al6l045Yh@11JN4>0<O1_080@FWQ00<0[Jf]0<K0_036`;`00`36`;`00`11JN40
a/2l0<K0_0040<K0_003045Yh@36`;`0a/2l0080a/2l0P11JN4;0<>m^`80@FWQ0P2][Jd00`33_K/0
@FWQ0;ji^0020;ji^003045Yh@2n^KP0_[Vh00L0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0
Wi^P0:f][@0509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C
06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd00P11JN400`2TWXl0@FWQ
045Yh@060:BNS`030:f][@2aZid0/J^M00<0/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@040;6[W@03
0:f][@2i/ZH0[Jf]0080[Jf]0P2i/ZH00`11JN40^K:V0;VbYP030;VbYP04045Yh@2i/ZH0^K:V0:f]
[@<0_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40_[N/0;jg[0030;jg[080@FWQ00<0_[N/0:f]
[@31^[000P31^[000`11JN40`KZ`0<6j/0030<6j/003045Yh@31^[00`KZ`00L0`KZ`00<0[Jf]0<>m
/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00@0[Jf]0<O1
_011JN40@FWQ0P37`K`3045Yh@T0al6l0P11JN400`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0
a/2l00@0a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@T0`kfk0P2][Jd00`11JN40`kfk0<>m^`02
0<>m^`05045Yh@2n^KP0_[Vh0;ji^011JN402@2n^KP00`2][Jd0];2a0;B`/@080;B`/@80[Jf]1P2O
Vj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0
0`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]00<0Y9j?045Yh@2TWXl00P11JN460:BNS`030:f][@2aZid0
/J^M00<0/J^M00@0@FWQ0;6[W@2aZid0@FWQ1@2aZid00`11JN40^K:V0;VbYP020;VbYP80[Jf]00<0
@FWQ0;VbYP2i/ZH00`2i/ZH01011JN40^K:V0;VbYP2][Jd20;jg[080@FWQ1P2n]j`00`11JN40_[N/
0;jg[0030;jg[004045Yh@2n]j`0_[N/0:f][@<0`KZ`00<0@FWQ0<6j/031^[000`31^[000`11JN40
`KZ`0<6j/004045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0
[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37
`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`06
0:f][@37`K`0@FWQ045Yh@37`K`0@FWQ0`37`K`2045Yh@L0al6l0P11JN400`2][Jd0a/2l0<K0_003
0<K0_003045Yh@36`;`0a/2l00@0a/2l00<0@FWQ0<K0_036`;`00P36`;`2045Yh@D0`kfk00D0@FWQ
0<>m^`2][Jd0[Jf]0<>m^`02045Yh@@0`kfk00D0@FWQ0;ji^02n^KP0_[Vh045Yh@090;ji^0030:f]
[@2d/;40];2a00P0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0
/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@060:f]
[@2TWXl0Y9j?045Yh@2TWXl0@FWQ1P2TWXl00`2][Jd0/J^M0;6[W@040;6[W@80@FWQ1P2aZid00`11
JN40^K:V0;VbYP030;VbYP80@FWQ102][Jd01@2i/ZH0@FWQ0;VbYP2i/ZH0[Jf]0080_[N/0P11JN46
0;jg[003045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02][Jd01@31^[000`11JN40`KZ`0<6j/002
0<6j/0<0@FWQ0`31^[001@11JN40`KZ`0<6j/031^[00[Jf]00<0`kfc00<0@FWQ0<>m/`33_K<03`33
_K<00`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00`0b<6k00<0@FWQ0<S1^`38`K/00P38
`K/2045Yh@060:f][@37`K`0@FWQ045Yh@37`K`0@FWQ1037`K`00`11JN40al6l0<O1_0050<O1_080
@FWQ00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0040<K0_003045Yh@36`;`0a/2l0080
a/2l0P11JN440<>m^`030:f][@11JN40@FWQ00<0`kfk00<0@FWQ0<>m^`33_K/00P33_K/2045Yh@<0
_[Vh0P11JN480;ji^0030:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^
N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd20:BN
S`03045Yh@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0@FWQ0;VbYP030;Vb
YP80@FWQ102i/ZH01@2][Jd0@FWQ0:f][@2i/ZH0[Jf]0080_[N/0P11JN460;jg[003045Yh@2n]j`0
_[N/0080_[N/0P11JN400`2n]j`0[Jf]0<6j/0040<6j/003045Yh@31^[00`KZ`0080`KZ`0P11JN45
0<6j/004045Yh@31^[00`KZ`0:f][@80`kfc0P11JN4A0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL02@36_kL`0:f][@T0al6j00<000000<O1^P2][Jd05P38`K/00`2][Jd0b<6k0<S1
^`090<S1^`<0@FWQ00D0b<6k045Yh@38`K/0b<6k045Yh@020<S1^`030:f][@37`K`0@FWQ0080@FWQ
1P37`K`00`11JN40al6l0<O1_0040<O1_080@FWQ00<0[Jf]0<K0_036`;`00`36`;`2045Yh@D0a/2l
0P11JN430<K0_080@FWQ00D0`kfk0:f][@2][Jd0[Jf]0<>m^`02045Yh@<0`kfk00<0@FWQ0<>m^`33
_K/00P33_K/2045Yh@<0_[Vh0P11JN480;ji^0030:f][@2d/;40];2a00D0];2a00@0[Jf]0;B`/@2d
/;40[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00D0[Jf]06=P
D`1SH5<0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?0080[Jf]1`2TWXl00`2][Jd0/J^M0;6[W@0:
0;6[W@04045Yh@2aZid0[Jf]045Yh@<0^K:V0P11JN460;VbYP03045Yh@2i/ZH0[Jf]0080[Jf]00<0
_[N/045Yh@11JN401@2n]j`2045Yh@@0_[N/0P11JN400`2n]j`0[Jf]0<6j/0090<6j/003045Yh@31
^[00`KZ`00D0`KZ`00<0@FWQ0<6j/02][Jd00P33_K<00`11JN40`kfc045Yh@0@0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/04P38`K/3045Yh@T0b<6k0`11JN440<S1^`<0@FWQ0P38
`K/0102][Jd0al6l045Yh@11JN470<O1_003045Yh@37`K`0al6l00@0al6l0P11JN400`2][Jd0a/2l
0<K0_0030<K0_080@FWQ1@36`;`2045Yh@80a/2l00@0[Jf]045Yh@11JN40[Jf]1033_K/2045Yh@@0
`kfk00H0@FWQ0<>m^`33_K/0@FWQ0<>m^`11JN430;ji^080@FWQ202n^KP00`2][Jd0];2a0;B`/@03
0;B`/@80[Jf]0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`
h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0
[Jf]0:BNS`2TWXl0102TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@80@FWQ00D0^K:V045Yh@2i/ZH0^K:V
045Yh@060;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/0:f][@02045Yh@030:f][@2n]j`0_[N/0080_[N/
0P11JN440;jg[080@FWQ00<0_[N/0:f][@31^[002@31^[000`11JN40`KZ`0<6j/0050<6j/003045Y
h@31^[00[Jf]00<0`kfc00<0@FWQ0<>m/`33_K<03`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k00T0b<6k00<0@FWQ0<S1^`38`K/00P38`K/4045Yh@80b<6k00<0[Jf]0<S1^`38`K/0
1`38`K/2045Yh@H0b<6k0P11JN420<S1^`040:f][@37`K`0@FWQ045Yh@L0al6l0P11JN450<O1_080
@FWQ00<0[Jf]0<K0_036`;`00`36`;`2045Yh@@0a/2l00<0[Jf]045Yh@11JN400P2][Jd20<K0_003
045Yh@33_K/0`kfk00<0`kfk00<0@FWQ0<>m^`33_K/01033_K/2045Yh@80`kfk00@0[Jf]0;ji^02n
^KP0_[Vh0P11JN480;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX005
09nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:
QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i
/ZH0^K:V0080@FWQ1`2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`00P11JN400`2n]j`0[Jf]0:f]
[@020:f][@80@FWQ102n]j`2045Yh@030;jg[02][Jd0`KZ`0140`KZ`00<0@FWQ0<6j/02][Jd05@33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037
`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k0080b<6k1011JN420<S1^`80@FWQ1P38
`K/2045Yh@80b<6k00<0[Jf]0<S1^`38`K/01`38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ0P38
`K/00`2][Jd0al6l0<O1_002045Yh@H0al6l0P11JN450<O1_080@FWQ00<0[Jf]0<K0_036`;`00`36
`;`2045Yh@@0[Jf]00<0a/2l045Yh@11JN401036`;`00`11JN40`kfk0<>m^`030<>m^`03045Yh@33
_K/0`kfk00P0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P11JN480;ji^0040:f][@2d/;40];2a0:f][@L0
];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo001H0;3PiP03
0:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f][@80Y9j?00<0[Jf]0;6[W@2a
Zid02`2aZid00`2][Jd0^K:V0;VbYP0:0;VbYP<0@FWQ00@0^K:V0:f][@2n]j`0_[N/0P11JN450;jg
[080@FWQ0P2][Jd20;jg[080@FWQ00<0_[N/0:f][@31^[004031^[02045Yh@030<6j/02][Jd0`kfc
01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng045Yh@09045Yh@P0a[ng1011JN400`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@11JN40al6j00H0al6j00<0@FWQ0<O1^P37`KX00`37`KX00`11
JN40al6j0<O1^P060<O1^P030:f][@38`K/0b<6k00<0@FWQ0`38`K/4045Yh@H0b<6k0P11JN420<S1
^`030:f][@38`K/0b<6k00L0b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@80b<6k00<0[Jf]0<O1
_037`K`00P11JN460<O1_080@FWQ1@37`K`2045Yh@030:f][@36`;`0a/2l00<0[Jf]0P11JN450<K0
_080@FWQ1036`;`2045Yh@<0`kfk00<0@FWQ0<>m^`33_K/02@33_K/0102][Jd0_[Vh0;ji^02n^KP2
045Yh@P0_[Vh0`2][Jd80;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H1
0?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd=0;6[
W@030:f][@2i/ZH0^K:V00X0^K:V0`11JN401@2i/ZH0[Jf]0;jg[02n]j`0@FWQ00H0_[N/0P11JN42
0;jg[080[Jf]0P11JN400`2n]j`0[Jf]0<6j/00?0<6j/080@FWQ0P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045Yh@D0a[ng0P11JN48
0<Jo]`@0@FWQ3@37`KP4045Yh@@0al6h00<0@FWQ0<O1^P37`KX01P37`KX00`11JN40al6j0<O1^P03
0<O1^P03045Yh@37`KX0al6j00H0al6j00<0[Jf]0<S1^`38`K/00P11JN460<S1^`80@FWQ1P38`K/2
045Yh@80b<6k00<0[Jf]0<S1^`38`K/01`38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ0P38`K/0
0`2][Jd0al6l0<O1_002045Yh@H0al6l0P11JN450<O1_080@FWQ0`2][Jd30<K0_080@FWQ1@36`;`2
045Yh@@0a/2l00<0[Jf]045Yh@11JN400`11JN4;0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ1`2n
^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I
0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP0:
0;VbYP80@FWQ00<0^K:V045Yh@2][Jd00P2n]j`00`11JN40_[N/0;jg[0040;jg[080@FWQ102n]j`2
045Yh@D0[Jf]00<0`KZ`045Yh@31^[002031^[03045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN460<Jo]`80@FWQ1`36_kL2
045Yh@030:f][@37`KP0al6h00X0al6h0P11JN440<O1^003045Yh@37`KP0al6h0080@FWQ2037`KX0
0`11JN40al6j0<O1^P030<O1^P03045Yh@37`KX0al6j00H0al6j00@0[Jf]0<S1^`11JN40@FWQ1`38
`K/2045Yh@H0b<6k0P11JN420<S1^`030:f][@38`K/0b<6k00L0b<6k00<0@FWQ0<S1^`38`K/01@38
`K/2045Yh@80b<6k00<0[Jf]0<O1_037`K`00P11JN460<O1_080@FWQ1@2][Jd2045Yh@030:f][@36
`;`0a/2l00<0a/2l0P11JN450<K0_080@FWQ1036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`040:f][@2n
^KP0_[Vh0;ji^080@FWQ1@2n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj00
1@2OVj020:f][D80/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]0;6[W@2][Jd00P2][Jd90;6[W@030:f][@2i/ZH0^K:V00X0^K:V0P11JN420;VbYP<0@FWQ1`2n
]j`2045Yh@@0_[N/0P11JN400`2n]j`0[Jf]0<6j/0020<6j/080@FWQ1@2][Jd20<6j/0@0@FWQ1031
^[001@2][Jd0`kfc0<>m/`33_K<0@FWQ0140`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`020<Jo]`80@FWQ1P36_kL2045Yh@L0a[ng0P11JN400`2][Jd0al6h0<O1^0090<O1^080@FWQ
1P37`KP3045Yh@030:f][@37`KX0al6j00D0al6j00<0@FWQ0<O1^P11JN400`37`KX3045Yh@L0al6j
00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@H0b<6k0P11JN420<S1^`030:f][@38`K/0b<6k00L0
b<6k00<0@FWQ0<S1^`38`K/01@38`K/2045Yh@80b<6k00<0[Jf]0<O1_037`K`00P11JN430<O1_0<0
[Jf]0P11JN450<O1_080@FWQ00<0[Jf]0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0040<K0_080
@FWQ1036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n
^KP0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00102OVj020:f]
[D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD01@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`03
0:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00X0^K:V0P11JN420;VbYP03
0:f][@2n]j`0_[N/00L0_[N/0P11JN450;jg[080@FWQ00L0[Jf]0<6j/031^[00`KZ`045Yh@31^[00
@FWQ00@0`KZ`00@0[Jf]045Yh@11JN40@FWQ0`2][Jd30<6j/0050:f][@33_K<0`kfc0<>m/`11JN40
4@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN470<Jo]`80@FWQ
1P36_kL2045Yh@030:f][@37`KP0al6h00T0al6h0P11JN470<O1^080@FWQ00<0al6h0:f][@37`KX0
1@37`KX3045Yh@<0al6j0`11JN470<O1^P030:f][@11JN40@FWQ00T0b<6k00<0@FWQ0<S1^`38`K/0
1038`K/2045Yh@80b<6k00<0[Jf]0<S1^`38`K/01`38`K/2045Yh@H0b<6k0P11JN420<S1^`030:f]
[@37`K`0al6l0080@FWQ0`2][Jd30<O1_080@FWQ1P37`K`00`11JN40[Jf]0<K0_0030<K0_080@FWQ
1036`;`4045Yh@@0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]
1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0
@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0
[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH02P2i/ZH2045Yh@80^K:V00<0
[Jf]0;jg[02n]j`01@2n]j`4045Yh@D0_[N/0P11JN400`2][Jd0`KZ`0<6j/0020<6j/080@FWQ1031
^[02045Yh@D0`KZ`1`2][Jd00`11JN40`kfc0<>m/`0?0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL00P36_kL2045Yh@L0a[ng0P11JN460<Jo]`80@FWQ00<0[Jf]0<O1^037`KP02@37
`KP2045Yh@L0al6h0P11JN400`37`KP0[Jf]0<O1^P050<O1^P<0@FWQ0`37`KX3045Yh@L0al6j00<0
[Jf]045Yh@11JN402@38`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ0P38`K/00`2][Jd0b<6k0<S1
^`090<S1^`P0@FWQ1@2][Jd2045Yh@H0al6l0P11JN460<O1_080@FWQ1036`;`00`11JN40a/2l0<K0
_00<0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f]
[@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo
001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[
W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH02`2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`03`2n
]j`2045Yh@@0`KZ`00<0@FWQ0<6j/031^[000`31^[000`11JN40`KZ`0<6j/0050<6j/003045Yh@31
^[00[Jf]00<0`kfc00<0@FWQ0:f][@2][Jd0102][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL00P36_kL2045Yh@P0a[ng00<0@FWQ0<Jo]`36_kL01036_kL2045Yh@030:f][@37
`KP0al6h00T0al6h0P11JN470<O1^080@FWQ00<0al6h0:f][@37`KX01@37`KX00`11JN40al6j045Y
h@030<O1^P<0@FWQ1`37`KX00`2][Jd0@FWQ045Yh@090<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11
JN420<S1^`030:f][@38`K/0b<6k00T0b<6k1P2][Jd2045Yh@80b<6k00<0[Jf]0<O1_037`K`00P11
JN450<O1_080@FWQ1`37`K`00`11JN40[Jf]045Yh@03045Yh@l0a/2l00<0[Jf]0<>m^`33_K/03@33
_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00
0P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]2`2i/ZH2045Yh@80^K:V00<0
[Jf]0;jg[02n]j`0402n]j`2045Yh@80`KZ`00<0@FWQ0<6j/031^[001031^[000`11JN40`KZ`0<6j
/0040<6j/080@FWQ00<0`KZ`0:f][@33_K<00P33_K<00`11JN40`kfc0<>m/`040<>m/`P0[Jf]0`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN480<Jo]`03045Yh@36
_kL0a[ng00@0a[ng0P11JN400`2][Jd0al6h0<O1^0090<O1^080@FWQ1`37`KP2045Yh@030<O1^02]
[Jd0al6j00D0al6j00<0@FWQ0<O1^P11JN400`37`KX01011JN40al6j0<O1^P11JN460<O1^P80@FWQ
2P38`K/4045Yh@@0b<6k00@0@FWQ0<S1^`38`K/0[Jf]0`38`K/80:f][@H0b<6k0P11JN420<S1^`03
0:f][@37`K`0al6l0080@FWQ1@37`K`2045Yh@L0al6l00<0@FWQ0:f][@36`;`04P36`;`00`2][Jd0
`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080
[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M
0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]1`2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`0
402n]j`0102][Jd0`KZ`045Yh@11JN480<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11JN400`31^[00
[Jf]0<>m/`020<>m/`03045Yh@33_K<0`kfc00`0`kfc2@2][JdA0<Fn]@030:f][@36_kL0a[ng0080
a[ng0P11JN480<Jo]`80@FWQ1@36_kL2045Yh@030:f][@37`KP0al6h00X0al6h0P11JN460<O1^080
@FWQ00D0al6h0:f][@37`KX0al6j000000020<O1^P80@FWQ00@0al6j045Yh@37`KX0al6j0P11JN42
0<O1^P03045Yh@37`KX0al6j00@0al6j0P11JN470<S1^`@0@FWQ1@38`K/20:f][@03045Yh@2][Jd0
[Jf]00@0[Jf]3P38`K/01@11JN40b<6k0<S1^`38`K/0[Jf]0080al6l0`11JN430<O1_080@FWQ2037
`K`00`11JN40[Jf]0<K0_00B0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji
^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H0
0`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH3
0:f][@80^K:V1011JN420;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002@31^[00
0`11JN40`KZ`0<6j/0020<6j/0<0@FWQ00<0`KZ`0:f][@33_K<00P33_K<00`11JN40`kfc0<>m/`0?
0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN48
0<Jo]`80@FWQ1@36_kL2045Yh@030:f][@37`KP0al6h00/0al6h00<0@FWQ0<O1^037`KP01037`KP2
045Yh@030<O1^02][Jd0al6j00@0al6j0P11JN420<O1^P04045Yh@37`KX0@FWQ045Yh@80al6j00<0
@FWQ0<O1^P37`KX01037`KX2045Yh@@0b<6k302][Jd20<S1^`80@FWQ00<0b<6k0:f][@38`K/00P38
`K/00`11JN40b<6k0<S1^`040<S1^`03045Yh@38`K/0b<6k00@0b<6k00D0@FWQ0<S1^`38`K/0b<6k
0:f][@020<O1_0L0@FWQ2@37`K`2045Yh@030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
1P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]
B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;Vb
YP060;VbYP<0[Jf]00<0^K:V045Yh@11JN400P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31
^[00`KZ`00X0`KZ`1011JN420<6j/003045Yh@31^[00[Jf]0080`kfc0P11JN4A0<>m/`030:f][@35
_[D0aKje00l0aKje2P2][Jd2045Yh@D0[Jf]0`36_kL2045Yh@D0a[ng0P11JN400`2][Jd0al6h0<O1
^00<0<O1^0<0@FWQ0`37`KP2045Yh@030<O1^02][Jd0al6j00@0al6j00H0@FWQ0<O1^P37`KX0al6j
045Yh@37`KX2045Yh@80[Jf]00<0@FWQ0:f][@2][Jd0102][Jd2045Yh@@0[Jf]3P38`K/2045Yh@04
0<S1^`2][Jd0b<6k0<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`030<S1^`03045Yh@38`K/0b<6k
0080b<6k00<0[Jf]045Yh@11JN400P11JN4>0<O1_080@FWQ00<0[Jf]0<K0_036`;`02@36`;`00`11
JN40a/2l0<K0_0040<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh
00`0_[Vh00<0[Jf]0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP03
0:f][@2TWXl0Y9j?00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0
[Jf]00<0^K:V0:f][@2n]j`0202n]j`00`11JN40_[N/0;jg[0060;jg[0030:f][@31^[00`KZ`0100
`KZ`00<0@FWQ0<6j/02][Jd00P33_K<3045YhA00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`020<Jo]`80@FWQ1@36_kL30:f][@80@FWQ1@2][Jd2045YhA80[Jf]1@11JN470:f][@06
045Yh@2][Jd0[Jf]0:f][@11JN40[Jf]0P11JN430<O1^P03045Yh@37`KX0al6j00<0al6j0P11JN4B
0<S1^`04045Yh@38`K/0@FWQ0:f][@80b<6k0P11JN460<S1^`04045Yh@38`K/0b<6k0<S1^`80@FWQ
1@38`K/00`2][Jd0al6l0<O1_00@0<O1_080@FWQ00<0[Jf]0<K0_036`;`02@36`;`2045Yh@D0a/2l
00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40
1P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M00`0/J^M00<0
[Jf]0;VbYP2i/ZH03@2i/ZH30:f][@L0_[N/00<0@FWQ0;jg[011JN401`2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc00<0@FWQ4033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng0080a[ng0P11JN480<Jo]`80@FWQ1@36_kL3045YhA@0al6h0P11JN400`37`KP0[Jf]0<O1
^P040<O1^P06045Yh@37`KX0al6j0<O1^P11JN40al6j0P11JN430<O1^P03045Yh@37`KX0al6j00<0
al6j0P11JN4B0<S1^`04045Yh@38`K/0b<6k045Yh@<0b<6k00<0@FWQ0<S1^`38`K/01@38`K/3045Y
h@L0b<6k00<0[Jf]0<O1_037`K`04037`K`2045Yh@030:f][@36`;`0a/2l00X0a/2l00@0@FWQ0<K0
_036`;`0a/2l102][Jd>0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40
0`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02][Jd00`2][Jd40;jg[003045Yh@2n]j`0_[N/
00H0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`03045YhA00`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`020<Jo]`80@FWQ2036_kL2045Yh@D0a[ng0`11JN440<O1
^003045Yh@37`KP0al6h00D0al6h0P11JN460<O1^004045Yh@37`KP0al6h0:f][@D0al6j00L0@FWQ
0<O1^P37`KX0al6j045Yh@37`KX0@FWQ00@0al6j00<0@FWQ0<O1^P37`KX00`37`KX2045YhA80b<6k
00@0@FWQ0<S1^`38`K/0[Jf]1011JN4A0<S1^`030:f][@37`K`0al6l0100al6l0P11JN400`2][Jd0
a/2l0<K0_0090<K0_0D0[Jf]0P36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0
_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]
2@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00<0@FWQ4033_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN480<Jo]`80@FWQ1@36_kL3045Yh@@0al6h
0P11JN460<O1^080@FWQ1P37`KP01011JN40al6h0<O1^02][Jd40<O1^P03045Yh@37`KX0al6j00<0
al6j0P11JN440<O1^P03045Yh@37`KX0al6j00<0al6j0P11JN4?0<S1^`@0@FWQ0P38`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0100al6l0P11JN400`2][Jd0a/2l0<K0_0050<K0_0@0
[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d
/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`03045YhA00`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`020<Jo]`80@FWQ2036_kL2045Yh@D0a[ng0P11JN400`2][Jd0@FWQ0<O1^0020<O1^080
@FWQ1`37`KP00`11JN40al6h0<O1^0030<O1^005045Yh@37`KP0al6h0<O1^02][Jd01037`KX00`11
JN40al6j0<O1^P030<O1^P80@FWQ1@37`KX3045Yh@80al6j0P11JN4:0<S1^`03045Yh@38`K/0b<6k
00P0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00@0<O1_080@FWQ00<0[Jf]0<K0
_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102]
[Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3PiP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;Vb
YP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n]j`0[Jf]0<6j/00C0<6j/0030:f][@33_K<0`kfc
00<0@FWQ4033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng0080a[ng0P11JN480<Jo
]`80@FWQ0`36_kL4045Yh@030:f][@37`KP0@FWQ00<0@FWQ2@37`KP5045Yh@@0al6h00<0[Jf]0<O1
^P11JN401P11JN420<O1^P80@FWQ00<000000<O1^P11JN400`11JN440<O1^P030:f][@11JN40@FWQ
00T0b<6k00<0@FWQ0<S1^`38`K/02038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00h0al6l0P11JN450:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji
^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0
_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`03045YhA00`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`020<Jo]`80@FWQ2036_kL00`11JN40a[ng0<Jo]`060<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0@FWQ045Yh@090<S1^`03
045Yh@38`K/0b<6k00P0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00;0<O1_0D0
[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP02P2n^KP20:f][ED0/>3V0@3oool006l0/>3V0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V
00<0[Jf]0;jg[02n]j`0402n]j`0102][Jd0`KZ`0<6j/031^[070:f][@X0`KZ`00<0[Jf]0<>m/`33
_K<00P11JN4A0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045Yh@P0
a[ng00<0@FWQ0<Jo]`36_kL01P36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]045Yh@11JN402@38`K/00`11JN40b<6k0<S1^`080<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`01@37`K`60:f][@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40oooo001a0;3PiP<0[Jf]
202aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
2031^[070:f][@<0`KZ`00D0[Jf]0<>m/`33_K<0`kfc045Yh@0A0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045Yh@P0a[ng00<0@FWQ0<Jo]`36_kL01P36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00@0[Jf]0<S1^`11JN40@FWQ2038`K/2045Y
h@T0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3P
iP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100
_[N/00<0[Jf]0<6j/031^[003`31^[070:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`020<Jo]`80@FWQ1`36_kL2045Yh@P0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0D0<O1^P040:f][@38`K/0@FWQ045Yh@L0b<6k0`11JN490<S1^`030:f][@38`K/0b<6k
0100b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33
_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL00P36_kL2045Y
h@L0a[ng0P11JN480<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`02045Yh@D0b<6k00@0@FWQ0<S1^`38`K/0@FWQ2@38`K/00`2][Jd0b<6k0<S1^`09
0<S1^`L0[Jf]0`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]
0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0:f][@020:f][El0/>3V0@3oool007T0/>3V0P2][Jd00`2a
Zid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`080<>m/`P0[Jf]0`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
0080a[ng0P11JN460<Jo]`80@FWQ2@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00@0[Jf]0<S1^`38`K/0b<6k0P11JN430<S1^`05045Yh@38`K/0b<6k0<S1^`11JN402@38
`K/0102][Jd0b<6k0<S1^`38`K/80:f][@X0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0<K0_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk0`2][JeR0;3PiP40oooo001k0;3PiP<0[Jf]3`2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04033
_K<90:f][A40aKje00<0[Jf]0<Jo]`11JN401011JN450<Jo]`80@FWQ2P36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00P38`K/4045Yh@T0b<6k2@2]
[JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<
0:f][@D0aKje00<0[Jf]0<Jo]`36_kL00P36_kL7045Yh@`0a[ng00<0[Jf]0<O1^037`KP05@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0
`kfk00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0?0<Fn
]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`030<>m
^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]00<0^K:V0:f][@2n]j`0
4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`h>H40:f][A00_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;0;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0
a/2l00L0a/2l102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2][Jd0`KZ`0<6j/00B0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0030<K0
_0@0[Jf]OP2`h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0
`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0
b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02][Jd00`2][Jf20;3PiP40
oooo002N0;3PiPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l
1@2][Jf60;3PiP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l00P0al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`040:f][@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H70:f][A80`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0100b<6k1`2][JfI
0;3PiP40oooo002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00/>3V202][Jd30<>m/`03
0:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f]
[JL0/>3V0@3oool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0b<6k3`2][Jf_0;3PiP40
oooo003A0;3PiP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2][JgE0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53093 .33859 m
.54252 .33845 L
s
.51272 .33857 m
.51603 .34085 L
s
.49618 .33831 m
.51272 .33857 L
s
.51272 .33857 m
.51769 .34086 L
s
.51769 .34086 m
.521 .34538 L
s
.51603 .34085 m
.51934 .34537 L
s
0 0 0 r
.59491 .32861 m
.59493 .3286 L
s
.255 .412 .882 r
.521 .34538 m
.52266 .34989 L
s
.51934 .34537 m
.521 .34989 L
s
0 0 0 r
.59493 .3286 m
.59824 .33161 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52266 .34989 m
.52431 .35667 L
s
.521 .34989 m
.52266 .35667 L
s
.56563 .34007 m
.57055 .33762 L
s
.56727 .34001 m
.57055 .33762 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.56565 .34458 m
.56727 .34001 L
s
.57055 .33762 m
.57547 .3374 L
s
.564 .34464 m
.56563 .34007 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57547 .3374 m
.57876 .3395 L
s
.564 .34464 m
.56403 .34916 L
s
.56565 .34458 m
.56568 .3491 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50101 .386 m
.50114 .33842 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52431 .35667 m
.52432 .368 L
s
.52266 .368 m
.52266 .35667 L
s
.5359 .33854 m
.53595 .37019 L
s
.53755 .33852 m
.53761 .37018 L
s
.50268 .38602 m
.50279 .33845 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57876 .3395 m
.58207 .34385 L
s
.53759 .35658 m
.53926 .36335 L
s
.56403 .34916 m
.5657 .35363 L
s
.56568 .3491 m
.56735 .35356 L
s
.58692 .33681 m
.58855 .33671 L
s
.58367 .33925 m
.58692 .33681 L
s
.5853 .33916 m
.58692 .33681 L
s
.58207 .34385 m
.58367 .33925 L
s
.5837 .34377 m
.5853 .33916 L
s
0 0 0 r
.59634 .35719 m
.59684 .35755 L
s
.255 .412 .882 r
.5657 .35363 m
.57065 .3557 L
s
.53926 .36335 m
.54259 .36783 L
s
.56735 .35356 m
.57065 .3557 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5837 .34377 m
.58382 .35962 L
s
.54922 .36544 m
.55087 .36313 L
s
.55087 .36313 m
.55253 .36536 L
s
.52099 .37481 m
.52266 .368 L
s
.52266 .37481 m
.52432 .368 L
s
.57065 .3557 m
.58053 .35752 L
s
.54922 .36544 m
.55088 .36767 L
s
.54259 .36783 m
.54591 .37004 L
s
0 0 0 r
.58459 .36505 m
.58536 .36794 L
s
.255 .412 .882 r
.55253 .36536 m
.55254 .36763 L
s
.53097 .37024 m
.53761 .37018 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55089 .36994 m
.55254 .36763 L
s
.54591 .37004 m
.55089 .36994 L
s
0 0 0 r
.59835 .35572 m
.60013 .35734 L
s
.255 .412 .882 r
.56575 .36269 m
.56576 .36496 L
s
.56575 .36269 m
.5674 .36263 L
s
.5674 .36263 m
.56741 .3649 L
s
.52099 .37935 m
.52266 .37481 L
s
.51933 .37935 m
.52099 .37481 L
s
.56576 .36496 m
.56742 .36717 L
s
.58053 .35752 m
.58218 .35971 L
s
0 0 0 r
.58536 .36794 m
.58704 .3711 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51766 .3839 m
.52099 .37935 L
s
.51599 .38389 m
.51933 .37935 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.58222 .36425 m
.58382 .35962 L
s
.56742 .36717 m
.57073 .36931 L
s
.58207 .34385 m
.58222 .36425 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.61665 .37212 m
.61666 .3724 L
s
.5 Mabswid
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60316 .33576 m
.60996 .36707 L
s
.59697 .36796 m
.60316 .33576 L
s
.5986 .36786 m
.60323 .34255 L
s
.57073 .36931 m
.57732 .36903 L
s
.51266 .38614 m
.51766 .3839 L
s
.51266 .38614 m
.51599 .38389 L
s
.58059 .3666 m
.58222 .36425 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60996 .36707 m
.61605 .33476 L
s
.57732 .36903 m
.58059 .3666 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49603 .3859 m
.51266 .38614 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59208 .36826 m
.60348 .36754 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61158 .36695 m
.61613 .34155 L
s
.61605 .33476 m
.62284 .36604 L
s
.40702 .33263 m
.40856 .33506 L
s
.40541 .33473 m
.40702 .33263 L
s
.40695 .33717 m
.40856 .33506 L
s
.6399 .33474 m
.64458 .33194 L
s
.63682 .33962 m
.6399 .33474 L
s
.40541 .33473 m
.40695 .33717 L
s
.6353 .34433 m
.63682 .33962 L
s
.64148 .33456 m
.64458 .33194 L
s
.6384 .33945 m
.64148 .33456 L
s
.63688 .34417 m
.6384 .33945 L
s
.63381 .35132 m
.6353 .34433 L
s
.61802 .36644 m
.62763 .36561 L
s
.64458 .33194 m
.6477 .33158 L
s
.6354 .35116 m
.63688 .34417 L
s
.63381 .35132 m
.63397 .36273 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6354 .35116 m
.63556 .36258 L
s
.40679 .34855 m
.40798 .37615 L
s
.40482 .37584 m
.40679 .34855 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6477 .33158 m
.65241 .3333 L
s
.65241 .3333 m
.65558 .33748 L
s
.38985 .33064 m
.39291 .33329 L
s
.39291 .33329 m
.39443 .33576 L
s
.39432 .3426 m
.39443 .33576 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63397 .36273 m
.63565 .36944 L
s
.65547 .33064 m
.65577 .3489 L
s
.38368 .32984 m
.38985 .33064 L
s
.63556 .36258 m
.63724 .36928 L
s
.39276 .34241 m
.39436 .34032 L
s
.65701 .33045 m
.65731 .34871 L
s
.39273 .34469 m
.39432 .3426 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4064 .376 m
.40659 .36225 L
s
.38962 .34432 m
.39276 .34241 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63565 .36944 m
.6373 .37387 L
s
.38959 .3466 m
.39273 .34469 L
s
.38058 .33171 m
.38368 .32984 L
s
.63724 .36928 m
.63888 .37371 L
s
.38183 .34792 m
.38962 .34432 L
s
.6373 .37387 m
.64053 .37814 L
s
.39251 .35842 m
.39414 .35402 L
s
.39399 .36318 m
.39414 .35402 L
s
.38179 .35021 m
.38959 .3466 L
s
.63888 .37371 m
.64211 .37798 L
s
.37901 .33379 m
.38058 .33171 L
s
.66623 .32923 m
.67684 .32771 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40633 .38059 m
.40798 .37615 L
s
.37756 .32901 m
.37901 .33379 L
s
.3774 .33815 m
.37756 .32901 L
s
.40482 .37584 m
.40633 .38059 L
s
.3774 .33815 m
.37901 .33379 L
s
.39092 .36053 m
.39251 .35842 L
s
.39251 .35842 m
.39399 .36318 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64053 .37814 m
.6453 .37995 L
s
.67079 .32859 m
.67138 .36068 L
s
.6511 .34946 m
.66194 .34813 L
s
.64211 .37798 m
.6453 .37995 L
s
.67231 .32838 m
.6729 .36048 L
s
.38777 .36245 m
.39092 .36053 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37873 .34981 m
.38183 .34792 L
s
.6453 .37995 m
.64844 .37962 L
s
.37869 .3521 m
.38179 .35021 L
s
.3816 .36168 m
.38777 .36245 L
s
.64844 .37962 m
.6531 .37679 L
s
.65758 .36475 m
.65781 .37856 L
s
.65614 .37183 m
.65758 .36475 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37716 .3519 m
.37873 .34981 L
s
.37711 .35419 m
.37869 .3521 L
s
.6531 .37679 m
.65614 .37183 L
s
.65614 .37183 m
.65781 .37856 L
s
.37707 .35649 m
.37716 .3519 L
s
.37856 .35899 m
.3816 .36168 L
s
.36393 .3293 m
.36684 .33434 L
s
.67265 .34669 m
.67429 .35336 L
s
.3595 .3263 m
.36393 .3293 L
s
.37707 .35649 m
.37856 .35899 L
s
.66679 .36129 m
.6729 .36048 L
s
.35654 .32582 m
.3595 .3263 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67429 .35336 m
.67741 .35753 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36107 .34971 m
.3611 .34775 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35354 .32762 m
.35654 .32582 L
s
.35207 .32737 m
.35654 .32582 L
s
.36649 .3527 m
.36653 .3504 L
s
.36507 .34788 m
.36653 .3504 L
s
.36353 .34996 m
.36507 .34788 L
s
.36339 .35687 m
.36649 .3527 L
s
.67741 .35753 m
.68047 .3594 L
s
.36353 .34996 m
.36498 .35248 L
s
.3505 .33172 m
.35354 .32762 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34904 .33147 m
.35207 .32737 L
s
.68047 .3594 m
.68497 .35873 L
s
.36035 .35872 m
.36339 .35687 L
s
.68338 .35435 m
.68492 .35643 L
s
.68338 .35435 m
.68483 .35182 L
s
.68483 .35182 m
.68637 .35389 L
s
.34889 .33837 m
.3505 .33172 L
s
.69764 .32663 m
.70195 .32355 L
s
.69628 .33148 m
.69764 .32663 L
s
.68637 .35389 m
.68642 .3562 L
s
.69628 .33148 m
.69638 .33608 L
s
.34743 .33812 m
.34904 .33147 L
s
.6991 .32637 m
.70195 .32355 L
s
.69774 .33122 m
.6991 .32637 L
s
.68497 .35873 m
.68642 .3562 L
s
.35588 .35803 m
.36035 .35872 L
s
.69774 .33122 m
.69784 .33583 L
s
.69638 .33608 m
.69794 .34043 L
s
.70195 .32355 m
.70627 .32274 L
s
.34879 .34298 m
.34889 .33837 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69784 .33583 m
.6994 .34018 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33192 .32135 m
.34192 .32327 L
s
.34733 .34273 m
.34743 .33812 L
s
.35296 .35525 m
.35588 .35803 L
s
.35149 .35501 m
.35588 .35803 L
s
.34879 .34298 m
.35011 .35015 L
s
.35011 .35015 m
.35296 .35525 L
s
.34733 .34273 m
.34864 .3499 L
s
.70627 .32274 m
.70919 .3245 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6994 .34018 m
.70236 .34198 L
s
.69794 .34043 m
.70236 .34198 L
s
.34864 .3499 m
.35149 .35501 L
s
.33687 .35482 m
.33761 .32246 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69814 .34967 m
.69819 .35198 L
s
.69814 .34967 m
.6996 .34942 L
s
.33544 .35456 m
.33618 .32219 L
s
.69819 .35198 m
.6997 .35404 L
s
.70919 .3245 m
.71215 .32856 L
s
.70236 .34198 m
.71104 .34271 L
s
.6996 .34942 m
.69965 .35173 L
s
.6997 .35404 m
.70267 .35586 L
s
.71346 .32367 m
.71623 .3208 L
s
.71215 .32856 m
.71346 .32367 L
s
.71215 .32856 m
.71263 .34939 L
s
.71487 .32339 m
.71623 .3208 L
s
.71356 .32829 m
.71487 .32339 L
s
.70267 .35586 m
.70845 .35483 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71623 .3208 m
.71763 .32051 L
s
.71356 .32829 m
.71395 .34448 L
s
.72419 .30288 m
.7254 .35155 L
s
.3166 .31812 m
.32629 .3202 L
s
.71104 .34271 m
.71252 .34476 L
s
.72557 .30257 m
.72679 .35126 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72004 .30379 m
.72967 .30164 L
s
.70845 .35483 m
.71126 .35198 L
s
.33116 .35376 m
.33687 .35482 L
s
.71263 .34939 m
.71395 .34448 L
s
.71126 .35198 m
.71263 .34939 L
s
.33507 .37084 m
.33656 .36877 L
s
.33517 .36618 m
.33656 .36877 L
s
.33368 .36825 m
.33517 .36618 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32152 .34123 m
.32153 .34075 L
s
.5 Mabswid
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32148 .34483 m
.32211 .31932 L
s
.32009 .34455 m
.32073 .31902 L
s
.72615 .32569 m
.72878 .32045 L
s
.33368 .36825 m
.33507 .37084 L
s
.72878 .32045 m
.73145 .31751 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73074 .33685 m
.7308 .33921 L
s
.72938 .33832 m
.72941 .33955 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73145 .31751 m
.73416 .31689 L
s
.72122 .3524 m
.72679 .35126 L
s
.31998 .3492 m
.32148 .34483 L
s
.73416 .31689 m
.73691 .31858 L
s
.73416 .31689 m
.73825 .31826 L
s
.30182 .31462 m
.31116 .31688 L
s
.31859 .34891 m
.32009 .34455 L
s
.72661 .34427 m
.72949 .34835 L
s
.31578 .35066 m
.31998 .3492 L
s
.31578 .35066 m
.31859 .34891 L
s
.73691 .31858 m
.73971 .32259 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30583 .36499 m
.30713 .31592 L
s
.73825 .31826 m
.74104 .32227 L
s
.30449 .36469 m
.3058 .3156 L
s
.72949 .34835 m
.73229 .35009 L
s
.31304 .35008 m
.31578 .35066 L
s
.73971 .32259 m
.74123 .32926 L
s
.30902 .34684 m
.31304 .35008 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73015 .36863 m
.73018 .36987 L
s
.73152 .36717 m
.73158 .36954 L
s
.5 Mabswid
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73229 .35009 m
.73501 .34949 L
s
.74104 .32227 m
.74256 .32894 L
s
.73501 .34949 m
.73765 .34655 L
s
.73501 .34949 m
.739 .34624 L
s
.74123 .32926 m
.74136 .33393 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30645 .34155 m
.30902 .34684 L
s
.74256 .32894 m
.74269 .33361 L
s
.74021 .34125 m
.74136 .33393 L
s
.73765 .34655 m
.74021 .34125 L
s
.74155 .34094 m
.74269 .33361 L
s
.739 .34624 m
.74155 .34094 L
s
.75003 .31296 m
.75896 .31053 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75389 .31193 m
.7553 .36126 L
s
.30048 .36377 m
.30583 .36499 L
s
.2901 .3139 m
.29252 .31927 L
s
.29252 .31927 m
.29361 .32662 L
s
.75516 .31158 m
.75658 .36094 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76474 .30121 m
.76573 .30092 L
s
.255 .412 .882 r
.29348 .33131 m
.29361 .32662 L
s
.28637 .31051 m
.2901 .3139 L
s
.28883 .31356 m
.29124 .31893 L
s
.29124 .31893 m
.29232 .32629 L
s
.29219 .33097 m
.29232 .32629 L
s
.28637 .31051 m
.28883 .31356 L
s
.29199 .33801 m
.29348 .33131 L
s
.27457 .29044 m
.28311 .29308 L
s
.2907 .33768 m
.29219 .33097 L
s
.28387 .3098 m
.28637 .31051 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28929 .34205 m
.29199 .33801 L
s
.28131 .31142 m
.28387 .3098 L
s
.28801 .34171 m
.2907 .33768 L
s
.7559 .33736 m
.75858 .34139 L
s
.28541 .34339 m
.28929 .34205 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28191 .333 m
.28219 .33126 L
s
.5 Mabswid
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27793 .34132 m
.27942 .29196 L
s
.2767 .34097 m
.2782 .29158 L
s
.27871 .31539 m
.28131 .31142 L
s
.75141 .36222 m
.75658 .36094 L
s
.28541 .34339 m
.28801 .34171 L
s
.75858 .34139 m
.76243 .34273 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76763 .308 m
.76841 .3339 L
s
.76395 .30909 m
.77246 .3065 L
s
.2829 .34271 m
.28541 .34339 L
s
.76885 .30763 m
.76963 .33354 L
s
.76243 .34273 m
.76493 .34204 L
s
.28047 .33966 m
.2829 .34271 L
s
.27815 .33423 m
.28047 .33966 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76493 .34204 m
.76733 .33898 L
s
.76493 .34204 m
.76855 .33862 L
s
.27049 .30573 m
.27168 .30611 L
s
.76733 .33898 m
.76841 .3339 L
s
.26805 .30732 m
.27049 .30573 L
s
.26923 .3077 m
.27049 .30573 L
s
.27306 .3399 m
.27793 .34132 L
s
.76855 .33862 m
.76963 .33354 L
s
.26791 .31204 m
.26923 .3077 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7772 .30498 m
.78528 .30224 L
s
.26673 .31165 m
.26805 .30732 L
s
.26739 .32859 m
.26791 .31204 L
s
.26456 .30616 m
.26673 .31165 L
s
.26606 .33297 m
.26673 .31165 L
s
.7807 .30382 m
.78176 .33699 L
s
.26233 .30301 m
.26456 .30616 L
s
.78185 .30342 m
.78292 .33661 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25893 .30182 m
.26233 .30301 L
s
.26606 .33297 m
.26739 .32859 L
s
.26512 .32547 m
.26621 .32822 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25831 .32079 m
.26512 .32547 L
s
.26482 .33497 m
.26606 .33297 L
s
.77825 .3381 m
.78292 .33661 L
s
.25661 .30338 m
.25893 .30182 L
s
.2555 .30298 m
.25893 .30182 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26242 .3366 m
.26482 .33497 L
s
.25534 .30772 m
.25661 .30338 L
s
.25784 .33508 m
.26242 .3366 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25424 .30732 m
.2555 .30298 L
s
.25614 .31762 m
.25831 .32079 L
s
.25503 .31723 m
.25831 .32079 L
s
.78105 .35166 m
.78214 .3489 L
s
.78105 .35166 m
.78229 .35368 L
s
.25519 .31247 m
.25534 .30772 L
s
.78214 .3489 m
.78337 .35092 L
s
.7911 .30734 m
.79313 .30177 L
s
.79023 .31487 m
.7911 .30734 L
s
.25408 .31207 m
.25424 .30732 L
s
.25519 .31247 m
.25614 .31762 L
s
.78229 .35368 m
.78337 .35092 L
s
.79023 .31487 m
.79038 .31963 L
s
.79313 .30177 m
.79629 .29815 L
s
.7922 .30693 m
.79422 .30136 L
s
.79133 .31447 m
.7922 .30693 L
s
.25408 .31207 m
.25503 .31723 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79133 .31447 m
.79149 .31923 L
s
.79038 .31963 m
.79173 .32638 L
s
.25567 .33192 m
.25784 .33508 L
s
.79422 .30136 m
.79629 .29815 L
s
.25472 .32676 m
.25583 .32715 L
s
.25575 .32953 m
.25583 .32715 L
s
.79149 .31923 m
.79283 .32599 L
s
.25464 .32914 m
.25472 .32676 L
s
.25464 .32914 m
.25567 .33192 L
s
.79629 .29815 m
.79841 .29731 L
s
.79173 .32638 m
.79409 .33037 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79283 .32599 m
.79518 .32997 L
s
.79409 .33037 m
.79742 .33157 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79841 .29731 m
.80164 .29842 L
s
.79518 .32997 m
.79742 .33157 L
s
.80164 .29842 m
.80386 .30234 L
s
.79742 .33157 m
.80061 .33036 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24497 .32315 m
.24595 .32595 L
s
.24586 .32835 m
.24595 .32595 L
s
.23376 .29165 m
.24071 .29473 L
s
.24473 .33034 m
.24586 .32835 L
s
.24384 .32514 m
.24497 .32315 L
s
.24384 .32514 m
.24481 .32794 L
s
.80238 .31995 m
.80333 .31713 L
s
.24159 .32912 m
.24473 .33034 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80333 .31713 m
.80445 .31911 L
s
.80238 .31995 m
.8035 .32193 L
s
.80061 .33036 m
.80263 .32715 L
s
.2365 .32704 m
.23769 .29342 L
s
.80263 .32715 m
.80453 .32152 L
s
.80445 .31911 m
.80453 .32152 L
s
.23551 .32662 m
.2367 .29298 L
s
.23962 .32589 m
.24159 .32912 L
s
.81061 .29212 m
.81175 .29647 L
s
.81061 .29212 m
.81095 .30171 L
s
.23776 .32024 m
.23962 .32589 L
s
.23701 .3126 m
.23776 .32024 L
s
.81095 .30171 m
.81175 .29647 L
s
.81175 .29647 m
.81263 .29362 L
s
.81263 .29362 m
.81445 .29033 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23256 .32535 m
.2365 .32704 L
s
.81445 .29033 m
.81819 .28851 L
s
.81147 .31615 m
.81236 .31331 L
s
.81147 .31615 m
.81164 .32097 L
s
0 0 0 r
.22092 .27802 m
.22257 .27887 L
s
.255 .412 .882 r
.81155 .31856 m
.81244 .31572 L
s
.81236 .31331 m
.8142 .31002 L
s
.81164 .32097 m
.8127 .32296 L
s
.81244 .31572 m
.81428 .31244 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8142 .31002 m
.81871 .30298 L
s
.22738 .30824 m
.22808 .28895 L
s
.8127 .32296 m
.81472 .32452 L
s
.81428 .31244 m
.8188 .30539 L
s
.22373 .30644 m
.23019 .30956 L
s
.81819 .28851 m
.8201 .29 L
s
.22645 .30779 m
.22716 .28849 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22525 .28998 m
.2269 .29572 L
s
.81472 .32452 m
.8185 .32279 L
s
.8201 .29 m
.82108 .29195 L
s
.22266 .28618 m
.22525 .28998 L
s
.81871 .30298 m
.82045 .29966 L
s
.8188 .30539 m
.82054 .30208 L
s
.82108 .29195 m
.82135 .2992 L
s
.82045 .29966 m
.82126 .29679 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82054 .30208 m
.82135 .2992 L
s
.22092 .28524 m
.22266 .28618 L
s
.8185 .32279 m
.82025 .31948 L
s
.22623 .33978 m
.22676 .32519 L
s
.22557 .33205 m
.22676 .32519 L
s
.82025 .31948 m
.82107 .31661 L
s
.21911 .28672 m
.22092 .28524 L
s
.21826 .28625 m
.22092 .28524 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82107 .31661 m
.8218 .31131 L
s
.82107 .31661 m
.82216 .32103 L
s
.8218 .31131 m
.82216 .32103 L
s
.22355 .33606 m
.22557 .33205 L
s
.22557 .33205 m
.22623 .33978 L
s
.21724 .29063 m
.21911 .28672 L
s
.21641 .29015 m
.21826 .28625 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82709 .28627 m
.82802 .28822 L
s
.82709 .28627 m
.82783 .28337 L
s
.82783 .28337 m
.82876 .28532 L
s
.22077 .3372 m
.22355 .33606 L
s
.82802 .28822 m
.82876 .28532 L
s
.21622 .29501 m
.21724 .29063 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2154 .29454 m
.21641 .29015 L
s
.21512 .30185 m
.21622 .29501 L
s
.21901 .33632 m
.22077 .3372 L
s
.2143 .30138 m
.2154 .29454 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82848 .30037 m
.83042 .32922 L
s
.82848 .30037 m
.82874 .33012 L
s
.21737 .33299 m
.21901 .33632 L
s
.21652 .33255 m
.21901 .33632 L
s
.21466 .31406 m
.21512 .30185 L
s
.82903 .31499 m
.82958 .32967 L
s
.21384 .31359 m
.2143 .30138 L
s
.21586 .3272 m
.21737 .33299 L
s
.82874 .33012 m
.82977 .33458 L
s
.21466 .31406 m
.21521 .32185 L
s
.21502 .32675 m
.21652 .33255 L
s
.21521 .32185 m
.21586 .3272 L
s
.21384 .31359 m
.21438 .3214 L
s
.21438 .3214 m
.21502 .32675 L
s
.82977 .33458 m
.83042 .32922 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20598 .31137 m
.21054 .31419 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20659 .27653 m
.20822 .31278 L
s
.2024 .30897 m
.20659 .27653 L
s
.2031 .30945 m
.2063 .28387 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20107 .2725 m
.2024 .30897 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19712 .30508 m
.20107 .2725 L
s
.19775 .30557 m
.20077 .27988 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19528 .30359 m
.19969 .30704 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19493 .26734 m
.19551 .26786 L
s
.19371 .26877 m
.19493 .26734 L
s
.19427 .26929 m
.19493 .26734 L
s
.19351 .27372 m
.19427 .26929 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19296 .2732 m
.19371 .26877 L
s
.1928 .29112 m
.19351 .27372 L
s
.19209 .26719 m
.19296 .2732 L
s
.19204 .2956 m
.19296 .2732 L
s
.19116 .26365 m
.19209 .26719 L
s
.19204 .2956 m
.1928 .29112 L
s
.18968 .26205 m
.19116 .26365 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19181 .28761 m
.19225 .29061 L
s
.18886 .28201 m
.19181 .28761 L
s
.1914 .29759 m
.19204 .2956 L
s
.19024 .29907 m
.1914 .29759 L
s
.18864 .26347 m
.18968 .26205 L
s
.18818 .26293 m
.18968 .26205 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18823 .29704 m
.19024 .29907 L
s
.18797 .26793 m
.18864 .26347 L
s
.18802 .27846 m
.18886 .28201 L
s
.18756 .27793 m
.18886 .28201 L
s
.18753 .26739 m
.18818 .26293 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18777 .27293 m
.18797 .26793 L
s
.18777 .27293 m
.18802 .27846 L
s
.18732 .27239 m
.18753 .26739 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18739 .2935 m
.18823 .29704 L
s
.18732 .27239 m
.18756 .27793 L
s
.18714 .28796 m
.1876 .28848 L
s
.1875 .29099 m
.1876 .28848 L
s
.18704 .29047 m
.18739 .2935 L
s
.18704 .29047 m
.18714 .28796 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86113 .25503 m
.86422 .24949 L
s
.86216 .25338 m
.86441 .30653 L
s
.18344 .28323 m
.1837 .28629 L
s
.1836 .28881 m
.1837 .28629 L
s
.18312 .29082 m
.1836 .28881 L
s
.18297 .28523 m
.18344 .28323 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86249 .25283 m
.86473 .30602 L
s
.1809 .24891 m
.18289 .2528 L
s
.18297 .28523 m
.18322 .28829 L
s
.18205 .28924 m
.18312 .29082 L
s
.18047 .28659 m
.18198 .25114 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1815 .28565 m
.18205 .28924 L
s
.18019 .28606 m
.18169 .25058 L
s
.18109 .27951 m
.1815 .28565 L
s
.86422 .24949 m
.86483 .25091 L
s
.86422 .24949 m
.86506 .25035 L
s
.18109 .27951 m
.18112 .27136 L
s
.86483 .25091 m
.86551 .25486 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86337 .30808 m
.86649 .3029 L
s
.17939 .28446 m
.18047 .28659 L
s
.86506 .25035 m
.86572 .25431 L
s
.86551 .25486 m
.86594 .25939 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86572 .25431 m
.86614 .25884 L
s
.86594 .25939 m
.86647 .26648 L
s
.86614 .25884 m
.86666 .26593 L
s
.17924 .25881 m
.17926 .25316 L
s
.17912 .267 m
.17924 .25881 L
s
.17912 .24696 m
.17926 .25316 L
s
.17857 .27976 m
.17912 .267 L
s
.86649 .3029 m
.86689 .29929 L
s
.86649 .3029 m
.86713 .29877 L
s
.17904 .25825 m
.17907 .25261 L
s
.17891 .26645 m
.17904 .25825 L
s
.17895 .24639 m
.17907 .25261 L
s
.86647 .26648 m
.86701 .27924 L
s
.17837 .27922 m
.17891 .26645 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17877 .24272 m
.17912 .24696 L
s
.86666 .26593 m
.86721 .2787 L
s
.17877 .24272 m
.17895 .24639 L
s
.86689 .29929 m
.86714 .29311 L
s
.17804 .2869 m
.17857 .27976 L
s
.86713 .29877 m
.86735 .29258 L
s
.86701 .27924 m
.86713 .28746 L
s
.17784 .28636 m
.17837 .27922 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86713 .28746 m
.86714 .29311 L
s
.17791 .23702 m
.17877 .24272 L
s
.86721 .2787 m
.86734 .28692 L
s
.86734 .28692 m
.86735 .29258 L
s
.17762 .29149 m
.17804 .2869 L
s
.17744 .29096 m
.17784 .28636 L
s
.17704 .29557 m
.17762 .29149 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86687 .24161 m
.86841 .27747 L
s
.86647 .24331 m
.86726 .23933 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17687 .29504 m
.17744 .29096 L
s
.868 .2791 m
.86852 .27693 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17646 .29656 m
.17704 .29557 L
s
.17581 .29337 m
.17813 .2393 L
s
.17646 .29656 m
.17687 .29504 L
s
.17573 .29284 m
.17806 .23873 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86786 .26151 m
.86829 .26866 L
s
.86698 .24104 m
.86852 .27693 L
s
.86829 .26866 m
.86869 .27271 L
s
.17558 .29123 m
.17646 .29656 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86869 .27271 m
.86893 .2742 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86893 .2742 m
.86906 .27256 L
s
.8688 .26793 m
.86895 .26997 L
s
.86872 .2648 m
.8688 .26793 L
s
.86872 .2648 m
.86885 .26683 L
s
.86896 .26942 m
.86906 .27256 L
s
.86885 .26683 m
.86896 .26942 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8674 .23388 m
.86769 .23962 L
s
.86769 .23962 m
.86791 .24479 L
s
.86702 .22957 m
.8674 .23388 L
s
.86791 .24479 m
.86807 .24941 L
s
.86732 .2333 m
.86762 .23905 L
s
.86762 .23905 m
.86784 .24423 L
s
.86702 .22957 m
.86732 .2333 L
s
.86784 .24423 m
.86799 .24884 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86666 .22783 m
.86702 .22957 L
s
.86791 .25031 m
.86807 .24941 L
s
.86791 .25031 m
.86799 .24884 L
s
.86851 .2598 m
.86862 .2624 L
s
.86843 .25924 m
.86851 .2598 L
s
.86862 .2624 m
.86866 .26445 L
s
.86843 .25924 m
.86855 .26184 L
s
.86647 .22927 m
.86666 .22783 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8672 .24954 m
.86791 .25031 L
s
.86858 .26595 m
.86866 .26445 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86635 .23332 m
.86647 .22927 L
s
.86808 .26373 m
.86858 .26595 L
s
.86594 .22754 m
.86635 .23332 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86659 .23894 m
.86736 .25683 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8664 .23812 m
.86695 .25103 L
s
.86714 .25159 m
.8672 .24954 L
s
.86765 .26001 m
.86808 .26373 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86736 .25683 m
.86765 .26001 L
s
.86695 .25103 m
.86736 .25683 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86639 .2141 m
.86656 .21094 L
s
.86607 .20661 m
.86656 .21094 L
s
.86588 .20976 m
.86607 .20661 L
s
.86588 .20976 m
.86639 .2141 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86719 .23288 m
.8688 .27779 L
s
.86719 .23288 m
.86948 .27888 L
s
.8616 .2001 m
.86338 .20246 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86817 .25554 m
.86915 .27833 L
s
.255 .412 .882 r
.1867 .213 m
.18712 .21138 L
s
0 0 0 r
.86206 .20069 m
.86546 .28058 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8616 .2001 m
.86499 .28004 L
s
.86947 .28596 m
.86948 .27888 L
s
.8608 .20269 m
.86208 .21142 L
s
.8688 .27779 m
.86947 .28596 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85963 .19774 m
.8608 .20269 L
s
.18547 .19807 m
.18873 .19455 L
s
.255 .412 .882 r
.85813 .24658 m
.85847 .24698 L
s
0 0 0 r
.85858 .19657 m
.85963 .19774 L
s
.255 .412 .882 r
.18529 .24655 m
.18603 .24799 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85764 .19918 m
.85858 .19657 L
s
.85707 .1986 m
.85858 .19657 L
s
.86273 .24828 m
.86337 .24177 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86188 .251 m
.86273 .24828 L
s
.255 .412 .882 r
.85497 .22422 m
.85539 .22834 L
s
0 0 0 r
.18664 .21851 m
.19211 .21339 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85539 .22834 m
.85542 .22906 L
s
.5 Mabswid
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85622 .20504 m
.85707 .1986 L
s
.85681 .20562 m
.85764 .19918 L
s
.8567 .21648 m
.85681 .20562 L
s
.86352 .27843 m
.86546 .28058 L
s
.8561 .21591 m
.85622 .20504 L
s
.86082 .24989 m
.86188 .251 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18651 .19689 m
.18716 .27339 L
s
.8567 .21648 m
.85702 .22412 L
s
.85956 .24495 m
.86082 .24989 L
s
.85899 .2444 m
.86082 .24989 L
s
.1924 .19104 m
.19649 .18757 L
s
.8561 .21591 m
.85641 .22356 L
s
.85702 .22412 m
.85809 .23617 L
s
.85809 .23617 m
.85956 .24495 L
s
.84703 .1861 m
.85196 .19014 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8575 .23561 m
.85899 .2444 L
s
.85641 .22356 m
.8575 .23561 L
s
.18764 .26178 m
.1944 .1893 L
s
.18716 .27339 m
.19508 .18872 L
s
.84992 .1884 m
.85212 .24222 L
s
.84921 .18783 m
.85142 .24168 L
s
.19795 .18642 m
.20341 .18242 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19803 .23874 m
.20022 .1847 L
s
.19882 .2382 m
.201 .18413 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83813 .17984 m
.84395 .18381 L
s
.84922 .24005 m
.85212 .24222 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84152 .1821 m
.84479 .26367 L
s
.84069 .18153 m
.84395 .26315 L
s
.19976 .21493 m
.20008 .22601 L
s
.19575 .24035 m
.19882 .2382 L
s
.85253 .26888 m
.85308 .26551 L
s
.85221 .26109 m
.85308 .26551 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85165 .26445 m
.85221 .26109 L
s
.85165 .26445 m
.85253 .26888 L
s
.255 .412 .882 r
.83778 .22219 m
.8379 .22039 L
s
0 0 0 r
.20008 .22601 m
.20139 .2327 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20139 .2327 m
.20291 .23553 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20291 .23553 m
.2055 .23393 L
s
.20494 .22666 m
.20566 .23003 L
s
.20494 .22666 m
.20597 .22223 L
s
.83093 .17925 m
.83314 .18811 L
s
.20597 .22223 m
.2067 .22559 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82784 .17372 m
.83093 .17925 L
s
.21362 .18731 m
.21586 .17846 L
s
.21222 .19952 m
.21362 .18731 L
s
.20654 .2295 m
.2067 .22559 L
s
.21586 .17846 m
.219 .17293 L
s
.2055 .23393 m
.20654 .2295 L
s
.21459 .18677 m
.21685 .17791 L
s
.21317 .19898 m
.21459 .18677 L
s
.21191 .20731 m
.21222 .19952 L
s
.82582 .17263 m
.82784 .17372 L
s
.84136 .26161 m
.84479 .26367 L
s
.21685 .17791 m
.219 .17293 L
s
.21287 .20678 m
.21317 .19898 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21191 .20731 m
.21242 .2185 L
s
.219 .17293 m
.22106 .17184 L
s
.8239 .17543 m
.82582 .17263 L
s
.82285 .17489 m
.82582 .17263 L
s
.21287 .20678 m
.21338 .21797 L
s
.8342 .21536 m
.83435 .21927 L
s
.83309 .21092 m
.8342 .21536 L
s
.83228 .2143 m
.83309 .21092 L
s
.83274 .22605 m
.83435 .21927 L
s
.22106 .17184 m
.22407 .17411 L
s
.83228 .2143 m
.8334 .21874 L
s
.21242 .2185 m
.21406 .22529 L
s
.82208 .18216 m
.8239 .17543 L
s
.21338 .21797 m
.21505 .22477 L
s
.82101 .18162 m
.82285 .17489 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.83093 .22893 m
.83274 .22605 L
s
.22407 .17411 m
.22595 .18086 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21406 .22529 m
.21692 .22767 L
s
.82145 .19336 m
.82208 .18216 L
s
.21505 .22477 m
.21692 .22767 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82036 .19284 m
.82101 .18162 L
s
.8279 .22739 m
.83093 .22893 L
s
.82145 .19336 m
.82174 .20121 L
s
.81043 .16514 m
.81505 .16725 L
s
.21692 .22767 m
.22003 .22614 L
s
.82036 .19284 m
.82066 .20069 L
s
.82568 .22242 m
.8279 .22739 L
s
.82462 .22191 m
.8279 .22739 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82174 .20121 m
.82326 .21352 L
s
.82326 .21352 m
.82568 .22242 L
s
.22275 .20936 m
.22398 .20491 L
s
.22275 .20936 m
.22368 .21278 L
s
.82066 .20069 m
.82218 .21301 L
s
.22398 .20491 m
.22492 .20833 L
s
.23314 .16596 m
.24153 .16232 L
s
.82218 .21301 m
.82462 .22191 L
s
.8116 .16567 m
.8136 .22084 L
s
.22003 .22614 m
.22231 .22117 L
s
.81043 .16514 m
.81242 .22035 L
s
.22478 .21227 m
.22492 .20833 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22231 .22117 m
.22478 .21227 L
s
.80819 .16802 m
.81085 .17691 L
s
.8044 .16255 m
.80819 .16802 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80192 .16153 m
.8044 .16255 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79824 .16395 m
.80192 .16153 L
s
.79952 .16445 m
.80192 .16153 L
s
.24657 .16029 m
.25579 .15681 L
s
.79852 .17184 m
.79952 .16445 L
s
.80882 .21888 m
.8136 .22084 L
s
.79722 .17134 m
.79824 .16395 L
s
.23632 .20724 m
.23848 .2142 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23368 .24755 m
.23667 .16439 L
s
.23489 .24708 m
.23787 .16387 L
s
.24896 .20239 m
.25046 .15879 L
s
.25029 .20192 m
.25177 .15829 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79722 .17134 m
.79873 .21505 L
s
.79852 .17184 m
.80003 .21552 L
s
.23848 .2142 m
.24209 .21674 L
s
.23012 .24898 m
.23489 .24708 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24209 .21674 m
.24464 .21578 L
s
.78471 .15508 m
.7855 .1789 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78332 .1546 m
.7855 .1789 L
s
.24464 .21578 m
.24738 .21084 L
s
.24464 .21578 m
.24869 .21037 L
s
.24738 .21084 m
.24896 .20239 L
s
.79477 .21364 m
.80003 .21552 L
s
.24869 .21037 m
.25029 .20192 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26372 .20934 m
.26553 .15344 L
s
.26516 .20889 m
.26696 .15296 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26129 .15487 m
.27132 .15156 L
s
.5 Mabswid
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76114 .14768 m
.78471 .15508 L
s
.27727 .14972 m
.28807 .14661 L
s
.255 .412 .882 r
.27128 .19206 m
.27281 .18882 L
s
0 0 0 r
.77707 .18012 m
.77809 .21223 L
s
.25946 .21068 m
.26516 .20889 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.27138 .18891 m
.2714 .18822 L
s
.5 Mabswid
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78607 .23864 m
.78669 .2149 L
s
.78669 .2149 m
.78748 .23908 L
s
.28013 .20457 m
.28184 .14837 L
s
.28169 .20416 m
.28338 .14793 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76863 .19351 m
.77758 .19615 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2615 .23397 m
.26307 .22949 L
s
.2615 .23397 m
.2628 .23758 L
s
.26307 .22949 m
.26438 .2331 L
s
.29445 .14489 m
.30597 .14198 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2628 .23758 m
.26438 .2331 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27554 .20585 m
.28169 .20416 L
s
.29808 .18794 m
.29933 .14363 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76728 .14947 m
.76988 .23397 L
s
.76576 .14902 m
.76835 .23356 L
s
.29974 .18754 m
.30098 .14321 L
s
.28205 .19204 m
.28494 .19928 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28494 .19928 m
.28959 .2021 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31276 .14039 m
.32496 .13772 L
s
.28959 .2021 m
.29282 .2013 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76369 .23234 m
.78748 .23908 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29621 .19644 m
.29808 .18794 L
s
.29282 .2013 m
.29621 .19644 L
s
.29282 .2013 m
.29786 .19605 L
s
.29974 .18754 m
.30285 .19488 L
s
.29786 .19605 m
.29974 .18754 L
s
.30285 .19488 m
.30782 .19781 L
s
.255 .412 .882 r
.7222 .18185 m
.7234 .17541 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31679 .18374 m
.31794 .13923 L
s
.31854 .18338 m
.31968 .13884 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72163 .17522 m
.72184 .17408 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30782 .19781 m
.31126 .19706 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33748 .13924 m
.3431 .13417 L
s
.33364 .14803 m
.33748 .13924 L
s
.33154 .16055 m
.33364 .14803 L
s
.33931 .1389 m
.3431 .13417 L
s
.33546 .14769 m
.33931 .1389 L
s
.31483 .19225 m
.31679 .18374 L
s
.31126 .19706 m
.31483 .19225 L
s
.31126 .19706 m
.31658 .19189 L
s
.33335 .1602 m
.33546 .14769 L
s
.3431 .13417 m
.34682 .1335 L
s
.31658 .19189 m
.31854 .18338 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33134 .16868 m
.33154 .16055 L
s
.34682 .1335 m
.35237 .13657 L
s
.33316 .16834 m
.33335 .1602 L
s
.33134 .16868 m
.33287 .18057 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33316 .16834 m
.33469 .18023 L
s
.33316 .16834 m
.35557 .16445 L
s
.35237 .13657 m
.356 .14407 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33287 .18057 m
.33634 .18808 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33469 .18023 m
.33818 .18775 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33634 .18808 m
.3418 .19121 L
s
.33818 .18775 m
.3418 .19121 L
s
.3534 .17704 m
.35366 .16476 L
s
.37556 .13299 m
.38158 .1281 L
s
.37148 .14169 m
.37556 .13299 L
s
.35539 .17264 m
.35557 .16445 L
s
.37754 .13271 m
.38158 .1281 L
s
.37344 .14141 m
.37754 .13271 L
s
.36928 .15422 m
.37148 .14169 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38158 .1281 m
.38558 .12757 L
s
.3418 .19121 m
.34744 .19027 L
s
.37124 .15394 m
.37344 .14141 L
s
.38558 .12757 m
.38953 .13113 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35331 .18114 m
.35539 .17264 L
s
.35132 .18555 m
.3534 .17704 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34744 .19027 m
.35132 .18555 L
s
.35132 .18555 m
.35331 .18114 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37109 .16213 m
.37124 .15394 L
s
.36912 .16241 m
.36928 .15422 L
s
.38953 .13113 m
.39344 .13881 L
s
.39364 .12656 m
.40178 .12561 L
s
.36912 .16241 m
.37085 .17445 L
s
.37109 .16213 m
.37283 .17417 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37085 .17445 m
.37465 .18214 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37283 .17417 m
.37664 .18188 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.41619 .12818 m
.42251 .1235 L
s
.41191 .13678 m
.41619 .12818 L
s
.41827 .12798 m
.42251 .1235 L
s
.42251 .1235 m
.42671 .12313 L
s
.41399 .13657 m
.41827 .12798 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40967 .1493 m
.41191 .13678 L
s
.42671 .12313 m
.433 .12669 L
s
.37465 .18214 m
.38056 .18549 L
s
.41174 .14909 m
.41399 .13657 L
s
.37664 .18188 m
.38056 .18549 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39222 .21311 m
.39364 .12656 L
s
.39428 .21288 m
.39566 .12631 L
s
.433 .12669 m
.43715 .13456 L
s
.40955 .15753 m
.40967 .1493 L
s
.41163 .15732 m
.41174 .14909 L
s
.38056 .18549 m
.38458 .185 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3887 .18038 m
.3929 .17166 L
s
.38458 .185 m
.3887 .18038 L
s
.45224 .12122 m
.45432 .12929 L
s
.4521 .13765 m
.45224 .12122 L
s
.40955 .15753 m
.41145 .1697 L
s
.255 .412 .882 r
.42646 .1613 m
.42794 .16084 L
s
0 0 0 r
.41163 .15732 m
.41354 .1695 L
s
.41163 .15732 m
.43693 .15515 L
s
.45651 .12506 m
.46086 .12071 L
s
.46086 .12071 m
.46953 .12027 L
s
.45432 .12929 m
.45651 .12506 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.46953 .12027 m
.47385 .12418 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4521 .13765 m
.45432 .12929 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47385 .12418 m
.476 .1282 L
s
.41145 .1697 m
.41552 .17758 L
s
.49353 .1194 m
.4957 .12346 L
s
.49132 .12357 m
.49353 .1194 L
s
.41354 .1695 m
.41762 .17739 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47593 .14056 m
.476 .1282 L
s
.49132 .12357 m
.4935 .12762 L
s
.4935 .12762 m
.4957 .12346 L
s
.43466 .16772 m
.4348 .15531 L
s
.43684 .16342 m
.43693 .15515 L
s
.41552 .17758 m
.42178 .18117 L
s
.47375 .14065 m
.47595 .13643 L
s
.41762 .17739 m
.42178 .18117 L
s
.46936 .14496 m
.47375 .14065 L
s
.38611 .21379 m
.39428 .21288 L
s
.47372 .14477 m
.47593 .14056 L
s
.43461 .17186 m
.43684 .16342 L
s
.45844 .15377 m
.46936 .14496 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.43244 .17617 m
.43466 .16772 L
s
.46933 .1491 m
.47372 .14477 L
s
.45408 .15815 m
.45844 .15377 L
s
.42178 .18117 m
.42813 .18065 L
s
.4584 .15791 m
.46933 .1491 L
s
.45188 .16242 m
.45408 .15815 L
s
.43244 .17617 m
.43461 .17186 L
s
.45404 .16229 m
.4584 .15791 L
s
.42813 .18065 m
.43244 .17617 L
s
.4518 .17071 m
.45188 .16242 L
s
.45184 .16656 m
.45404 .16229 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49704 .16304 m
.49705 .15746 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4518 .17071 m
.45393 .17474 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47357 .16963 m
.47581 .16124 L
s
.47571 .17786 m
.47581 .16124 L
s
.45393 .17474 m
.45824 .17866 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.47135 .17387 m
.47357 .16963 L
s
.47357 .16963 m
.47571 .17786 L
s
.45824 .17866 m
.46695 .17823 L
s
.46695 .17823 m
.47135 .17387 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49342 .14825 m
.49545 .19815 L
s
.49102 .19825 m
.49342 .14825 L
s
.49324 .1982 m
.49333 .17315 L
s
.5 Mabswid
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49102 .19825 m
.49321 .20659 L
s
.49321 .20659 m
.49545 .19815 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00@0[Jf]0?nV403oYQ000000
6`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
5`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo
00220;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40ojHA0080ojHA1@00
00000`3oYQ40[Jf]0:f][@080:f][@030000002][Jd0[Jf]02T0[Jf]3`3oYA000`2][Jd0oj<@0?nS
400I0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P040>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY140
0`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA0P0000070?nV4@@0[Jf]00<00000
0:f][@2][Jd00P0000050:f][@030000003oYQ40ojHA00D0ojHA00D0[Jf]0?nV40000000ojH@0000
000J0?nV40030:f][@3oYA00ojD@00d0ojD@502][JdG0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P070>bF3P<0[Jf]J02`h>H10?ooo`00O02`h>H3
0:f][@T0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40
ojHA01H0ojHA00<0[Jf]0000000000000P2][Jd2000000D0[Jf]103oYQ400`000000ojHA00000008
0?nV4@030000003oYQ40ojHA00@0ojHA00D0[Jf]0?nV40000000ojH@0000000J0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa090:f][@h0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40oooo001j
0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ402@3oYQ45000000L0[Jf]0P0000030?nV4@040:f][@3oYQ40ojHA000000P0ojHA0P00
00090?nV4@030000003oYQ40ojHA00@0ojHA00@0[Jf]0?nV4000000000006`3oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`
h>H30:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA0080ojHA00@0[Jf]00000000000000000`2][Jd2000000030:f][@3oYQ40ojHA00H0ojHA
0P0000040?nV4@040:f][@3oYQ40ojHA000000P0ojHA0P00000:0?nV4@030000003oYQ40ojHA00<0
ojHA00@0[Jf]0?nV403oYQ0000006`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01D0oj<@1`2][JdH0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f]
[F40/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405@3oYQ460:f][@8000000`3oYQ42000000030?nV4@000000000000P0ojHA0P0000050?nV4@05
0:f][@3oYQ40ojHA0?nV4@0000001`3oYQ42000000X0ojHA00<000000?nV4@3oYQ400`3oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2]
[Jd0o:0@0?bP40060:f][A80o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P<0[Jf]G`2`h>H10?ooo`00L`2`h>H30:f][A80o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0
ojHA0?nV4@0@0?nV4@D0[Jf]0P3oYQ400`2][Jd0ojHA0?nV4@02000000D0ojHA00@000000?nV4@00
00000000203oYQ42000000D0ojHA00D0[Jf]0?nV4@3oYQ40ojHA000000070?nV4@8000002P3oYQ40
0`000000ojHA0?nV4@030?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0o:0@1@2][Jd=0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool0
0740/>3V0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2]
[Jd0ojHA0?nV4@0:0?nV4@@000000P2][Jd70?nV4@040:f][@3oYQ40ojHA000000L0ojHA0`000007
0?nV4@8000001P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40ojHA00@0ojHA00<00000
0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV4@030?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00/0o:0@1@2][Jd8
0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@02
0=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2]
[Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0ojHA0`2][Jd2000000040:f][@3oYQ40ojHA
0?nV4@8000001`3oYQ40102][Jd0ojHA0000000000070?nV4@<000001`3oYQ42000000H0ojHA00<0
[Jf]0?nV4@3oYQ402@3oYQ400`000000ojHA0?nV4@090?nV4@030000003oYQ40ojHA00<0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0
[Jf]0?bP403lX100403lX1060:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100
kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@D000000`2][Jd2
0?nV4@8000001P3oYQ400`000000ojHA0?nV4@050?nV4@030:f][@3oYQ40000000T0ojHA0P000007
0?nV4@8000001P3oYQ400`2][Jd0ojHA0?nV4@090?nV4@030000003oYQ40ojHA00P0ojHA0P000005
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01H0o:0@102][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]
0=^:3@3KRPd01P3KRPd20:f][EL0/>3V0@3oool006`0/>3V0P2][Jd70>nH40030:f][@3lX100o:0@
00l0o:0@00<0[Jf]0?nT4@3oY1404P3oY144000000030:f][@3oYQ40ojHA00D0ojHA0P0000060?nV
4@030000003oYQ40ojHA00D0ojHA00<0[Jf]0000000000002@3oYQ42000000L0ojHA0P0000060?nV
4@030:f][@3oYQ40ojHA01@0ojHA0P0000050?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`2][Jd00`2][JdA0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f]
[ED0/>3V0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y140303oY143000000@0[Jf]00<0oj@A0000000000001`3oYQ42000000P0ojHA00<000000?nV4@3o
YQ40103oYQ400`2][Jd00000000000090?nV4@8000001P3oYQ42000000H0ojHA00<0[Jf]0?nV4@3o
YQ40503oYQ42000000H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`030?JL3`@0
[Jf]3@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40
oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A
100000020:f][@D0oj@A0P0000070?nV4@800000203oYQ400`000000ojHA0?nV4@040?nV4@030:f]
[@000000000000T0ojHA0P0000060?nV4@8000001P3oYQ400`2][Jd0ojHA0?nV4@0C0?nV4@030000
003oYQ40000000H0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]
2@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0
D02`h>H10?ooo`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1401@3oY142000000@0[Jf]0P0000070?nT4@8000001P3oYQ4200000100ojHA00<0
[Jf]0000000000002@3oYQ42000000H0ojHA0P0000060?nV4@030:f][@3oYQ40ojHA0180ojHA00<0
00000?nV4@0000001`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00/0mY`?102]
[Jd50?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3o
ool006H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400P3oY143
00000080[Jf]103oY142000000L0oj@A0P0000060?nV4@800000403oYQ42000000X0ojHA0P000006
0?nV4@8000001P3oYQ400`2][Jd0ojHA0?nV4@0A0?nV4@030000003oYQ40000000P0ojHA00@0[Jf]
0?nV403oYQ0000006`3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0?0?JL3`030:f][@00000000000080000000<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0[Jf]0500/>3V0@3o
ool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
[Jf]00@000001`3oY142000000L0oj@A0P0000060?nV4@800000403oYQ42000000X0ojHA0P000006
0?nV4@8000001P3oYQ400`2][Jd0ojHA0?nV4@0?0?nV4@80000000<0ojHA0000003oYQ40203oYQ40
102][Jd0ojH@0?nV4000000K0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?0180mY`?1000000A0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>7
3P2][Jd=0>nH40030:f][@3lX100o:0@00`0o:0@0`0000020:f][@<0oj@A0P0000070?nT4@800000
1`3oY142000000H0ojHA0P00000@0?nV4@8000002P3oYQ42000000H0ojHA0P0000060?nV4@030:f]
[@3oYQ40ojHA00h0ojHA00@000000?nV4@3oYQ4000002P3oYQ40102][Jd0ojH@0?nV4000000K0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP
40030:f][@3fW0l0mY`?0180mY`?0P0000000`2][Jd0k9H>00000003000000d0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>7
3P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@00X0o:0@100000000`3lX100[Jf]0?nT4@03
0?nT4@8000001`3oY142000000L0oj@A0P0000050?nV4@8000004@3oYQ42000000X0ojHA0P000006
0?nV4@8000001P3oYQ47000000T0ojHA00@000000?nV4@00000000002`3oYQ40102][Jd0ojH@0?nV
4000000K0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?0180mY`?0P0000000`2][Jd0k9H>0>bF3P020>bF3P040:f]
[@0000000000000000X0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80
[Jf]C02`h>H10?ooo`00HP2`h>H00`2][Jd0dhL>0=>73P020=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1001`3lX1000`000000o:0@0:f][@020:f][@80000000<0o:0@0:f][@3oY140
0`3oY142000000L0oj@A0P0000070?nT4@8000001@3oYQ4200000140ojHA0P00000:0?nV4@800000
1P3oYQ48000000030:f][@3oYQ40ojHA0080ojHA0P0000080?nV4@030000003oYQ40000000H0ojHA
2P2][Jd00`000000[Jf]0:f][@0Q0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400G0?bP40030:f][@3fW0l0mY`?0180mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P800000
00<0[Jf]0>bF3P3/UPh01`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00@0^GD;
00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2][Jd0dhL>0=>73P030=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001@3lX10200000080[Jf]0`3lX102000000030?bP402]
[Jd0oj@A00<0oj@A0P0000070?nT4@8000001P3oY1400`2][Jd00000000000050?nV4@8000004@3o
YQ42000000X0ojHA0P0000060?nV4@8000001P3oYQ400`2][Jd0ojHA0?nV4@020?nV4@80000000<0
ojHA0:f][@2][Jd0102][Jd00`000000[Jf]000000070:f][@L0ojHA00@0[Jf]0?nV403oYQ000000
6`3oYQ000`2][Jd0ojD@0?nU40050?nU4100[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000030:f][@3/UPh0k9H>00@0k9H>
0P000000103/UPh0[Jf]0:f][@2][Jd60>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2i
M@/01@2iM@/00`2][Jd0/>3V0;3PiP180;3PiP40oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40030?bP40<0000000<0[Jf]0?bP403lX100
0`3lX102000000030?bP402][Jd0oj@A00<0oj@A0P0000070?nT4@8000001P3oY1400`2][Jd00000
000000050?nV4@8000004@3oYQ42000000X0ojHA0P0000060?nV4@8000000P3oYQ490:f][@800000
00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA000000090?nV4@030000003oYQ40ojHA00<0ojHA
00@0[Jf]0?nV403oYQ0000006`3oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?0180mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P80
0000103/UPh20:f][@050>bF3P000000k9H>0>bF3P2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0
kiP@0>nH400;0>nH40040:f][@3lX100o:0@000000<0[Jf]00<0o:0@0000003lX1001@3lX1020000
00030?bP402][Jd0oj@A00<0oj@A0P0000070?nT4@8000001P3oY1400`2][Jd00000000000050?nV
4@8000004@3oYQ42000000X0ojHA0P0000000`3oYQ40[Jf]0:f][@030:f][@8000000P2][Jd40?nV
4@070:f][@3oYQ40ojHA0?nV4@000000ojHA000000060?nV4@8000002P3oYQ400`000000ojHA0?nV
4@030?nV4@040:f][@3oYQ00ojH@000001/0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?0180mY`?
0P0000000`2][Jd0k9H>0>bF3P040>bF3P8000001P3/UPh01@000000[Jf]000000000000[Jf]00d0
fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0/>3V0;3PiP160;3PiP40oooo001N0;3PiP030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd000000000002][Jd40?bP4003
0000003lX100o:0@00@0o:0@0P0000000`3lX100[Jf]0?nT4@030?nT4@8000001`3oY1400`000000
oj@A0?nT4@050?nT4@030:f][@000000000000D0ojHA0P0000080?nV4@<000001P3oYQ42000000<0
ojHA1`2][Jd2000000030:f][@3oYQ40ojHA00@0ojHA0P0000050?nV4@070:f][@3oYQ40ojHA0?nV
4@000000ojHA000000060?nV4@030000003oYQ40ojHA00P0ojHA0P0000050?nV4@040:f][@3oYQ00
ojH@000001/0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103o
Xa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?0180mY`?0P0000000`2][Jd0k9H>0>bF
3P040>bF3P8000001@3/UPh200000080k9H>00@000000:f][@3KRPd000002`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_
V104000000D0o:0@00<000000?bP403lX100103lX102000000030?bP402][Jd0oj@A00<0oj@A0P00
00060?nT4@8000001`3oY1400`2][Jd00000000000050?nV4@8000000P3oYQ46000000030?nV4@00
0000000000@0ojHA0P2][Jd2000000<0[Jf]1`3oYQ42000000L0ojHA0P0000050?nV4@040:f][@3o
YQ40ojHA0?nV4@8000001`3oYQ400`000000ojHA0?nV4@080?nV4@8000001@3oYQ40102][Jd0ojH@
0?nV4000000K0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][AH0
o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000030:f][@3/UPh0k9H>00@0k9H>0P0000050>bF3P80
00000`3/UPh00`000000[Jf]00000002000000T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0
/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@0`2][Jd2000000D0o:0@
00<000000?bP403lX100103lX102000000030?bP402][Jd0oj@A00<0oj@A0P0000060?nT4@800000
1`3oY1400`2][Jd00000000000050?nV4@@000001`3oYQ42000000@0[Jf]0P3oYQ42000000X0ojHA
0P0000070?nV4@8000001@3oYQ40102][Jd0ojHA0?nV4@3oYQ42000000L0ojHA00<000000?nV4@3o
YQ40203oYQ42000000D0ojHA00@0[Jf]0?nV403oYQ0000006`3oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1P2][Jd@0?bP40030:f][@3fW0l0
mY`?0180mY`?0P0000000`2][Jd0k9H>0>bF3P050>bF3P030000003/UPh0k9H>00<0k9H>0P000003
0>bF3P030000003KRPd000000080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0
[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40070>nH
4080[Jf]0P3_V1000`2][Jd00000000000050?bP40030000003lX100o:0@00@0o:0@0P0000000`3l
X100[Jf]0?nT4@030?nT4@8000001P3oY142000000L0oj@A00<0[Jf]0000000000001@3oYQ420000
00@0ojHA1@2][Jd2000000H0ojHA00<0[Jf]000000000000203oYQ42000000P0ojHA0P0000050?nV
4@050:f][@3oYQ40ojHA0?nV4@000000203oYQ400`000000ojHA0?nV4@080?nV4@8000001@3oYQ40
102][Jd0ojH@0?nV4000000K0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa000`2][Jd0o:0@0?bP40070?bP40L0[Jf]2@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030000002]
[Jd0k9H>00H0k9H>00<000000>bF3P3/UPh00`3/UPh2000000<0k9H>00<000000=^:3@0000000P3K
RPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K
0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V10200000080[Jf]103_
V1000`2][Jd00000000000050?bP40030000003lX100o:0@00@0o:0@0P0000000`3lX100[Jf]0?nT
4@030?nT4@8000001P3oY142000000L0oj@A00<0[Jf]0000000000001@3oYQ42000000@0[Jf]1@3o
YQ42000000H0ojHA00<0[Jf]000000000000203oYQ42000000T0ojHA0P0000040?nV4@030:f][@3o
YQ40ojHA00800000203oYQ400`000000ojHA0?nV4@070?nV4@<000001@3oYQ40102][Jd0ojH@0?nV
4000000K0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400>0?bP40H0[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030000002][Jd0k9H>00H0k9H>
00<000000>bF3P3/UPh00`3/UPh2000000<0k9H>00<0[Jf]000000000000103KRPd00`2][Jd0fhX=
000000040=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00
F`2`h>H0102][Jd0Uf0;09MP2`2][Jd80=>73P030:f][@3_V100kiP@00<0kiP@00@000000:f][@00
00000000103_V1000`2][Jd00000000000050?bP40030000003lX100o:0@00@0o:0@0P0000000`3l
X100[Jf]0?nT4@030?nT4@8000001P3oY142000000L0oj@A00<0[Jf]0000000000001@2][Jd20000
00T0ojHA0P0000060?nV4@030:f][@000000000000P0ojHA0P0000090?nV4@800000103oYQ40102]
[Jd0ojHA0?nV4@00000:0?nV4@030000003oYQ40ojHA00H0ojHA00<000000?nV4@0000001@3oYQ40
0`2][Jd0ojH@00000002000001X0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01@0o:0@1@2][JdD0?JL3`030000002][Jd0k9H>00H0k9H>00<00000
0>bF3P3/UPh00`3/UPh2000000<0k9H>00<0[Jf]0000000000001@3KRPd00`000000[Jf]00000003
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020>nH40050000002]
[Jd0kiP@0>nH40000000103_V1000`2][Jd00000000000050?bP40030000003lX100o:0@00@0o:0@
0P0000000`3lX100[Jf]0?nT4@030?nT4@030000003oY140oj@A00D0oj@A0P0000060?nT4@80[Jf]
0P0000060?nV4@800000203oYQ400`000000ojHA0?nV4@050?nV4@030:f][@000000000000P0ojHA
0P00000:0?nV4@8000000`3oYQ40102][Jd0ojHA0?nV4@00000;0?nV4@030000003oYQ40ojHA00@0
ojHA00@000000?nV4@3oYQ4000001@3oYQ400`2][Jd0ojH@00000002000001X0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL
3`2][Jd00`2][Jd@0?JL3`030000002][Jd0k9H>00H0k9H>00<000000>bF3P3/UPh00`3/UPh20000
00<0k9H>00<0[Jf]0=^:3@0000001@3KRPd010000000fhX=0:f][@0000020=^:3@030:f][@2iM@/0
^GD;00L0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH40020:f][@030000003_V100kiP@0080kiP@00D0
00000>nH403_V100kiP@0:f][@02000000D0o:0@00<000000?bP403lX100103lX102000000030?bP
402][Jd0oj@A00<0oj@A00<000000?nT4@3oY1401@3oY14200000080oj@A102][Jd0103oY140[Jf]
0000000000060?nV4@800000203oYQ400`000000ojHA0?nV4@050?nV4@040:f][@3oYQ4000000000
00H0ojHA0`00000;0?nV4@8000000P3oYQ400`2][Jd0ojHA0000000=0?nV4@H000000`3oYQ400`00
0000ojHA0?nV4@030?nV4@030:f][@3oYQ000000008000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL
3`@0[Jf]303fW0l00`000000[Jf]0>bF3P060>bF3P030000003/UPh0k9H>00<0k9H>0P0000030>bF
3P030:f][@3KRPd0000000@0fhX=00<000000=^:3@3KRPd00P3KRPd00`000000[Jf]0:f][@090;Ue
2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0
Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>0`2][Jd00`3_V1000000000000040>nH4005
0000003_V100kiP@0>nH402][Jd00P0000040?bP408000001@3lX10200000080o:0@00<0[Jf]0?nT
4@3oY1400P3oY1400`000000oj@A0?nT4@050?nT4@8000000P2][Jd50?nT4@030:f][@0000000000
00H0ojHA0P0000070?nV4@8000001`3oYQ40102][Jd0ojHA0000000000060?nV4@<000003@3oYQ44
000001d0ojHA00<0[Jf]0?nV400000000P00000J0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00L0mY`?102][Jd8
0?JL3`030000002][Jd0k9H>0080k9H>00<000000>bF3P3/UPh01`3/UPh2000000<0k9H>00<0[Jf]
0=^:3@000000103KRPd00`000000fhX=0=^:3@020=^:3@060000003KRPd0[Jf]0000002iM@/00000
1P2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@070=>73P030000003CQ`h0[Jf]00<0kiP@00<000000>nH403_V100
1`3_V1000`2][Jd00000000000040?bP408000001@3lX10200000080o:0@00<0[Jf]0?nT4@3oY140
0P3oY1400`000000oj@A0?nT4@020?nT4@<0[Jf]0P0000070?nT4@030:f][@000000000000H0ojHA
0P0000070?nV4@030000003oYQ40ojHA00H0ojHA00<0[Jf]0?nV4@3oYQ400P0000040?nV4@040000
003oYQ400000000000l0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@00000002000001X0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l02`3fW0l40:f][@@0mY`?00<000000:f][@3/UPh00P3/UPh00`000000
k9H>0>bF3P070>bF3P8000000`3/UPh00`2][Jd0fhX=000000040=^:3@030000003KRPd0fhX=0080
fhX=00@000000=^:3@2][Jd0[Jf]0P0000060;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3P
iP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>00@000000=>7
3P2][Jd0[Jf]0P3_V102000000P0kiP@00@0[Jf]0?bP400000000000103lX102000000D0o:0@0P00
00020?bP40030:f][@3oY140oj@A0080oj@A00<000000:f][@2][Jd00P2][Jd30?nT4@8000001`3o
Y1400`2][Jd00000000000070?nV4@030000003oYQ40ojHA00D0ojHA00<000000?nV4@3oYQ401P3o
YQ400`2][Jd0ojHA0?nV4@020?nV4@@000000P3oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@00000002000001X0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l03`3fW0l40:f][@030000002]
[Jd0k9H>0080k9H>00<000000>bF3P3/UPh01`3/UPh2000000<0k9H>00<0[Jf]0=^:3@000000103K
RPd00`000000fhX=0=^:3@030=^:3@040000002][Jd0^GD;0:f][@8000001@2iM@/00`2][Jd0R5H7
08QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@040=>73P<0000000<0[Jf]0=>73P2][Jd00P3_V102000000P0kiP@00<0[Jf]000000000000
1@3lX102000000D0o:0@0P0000020?bP40030:f][@3oY140[Jf]0080[Jf]00<000000?nT4@3oY140
1@3oY142000000L0oj@A00<0[Jf]0000000000001`3oYQ42000000D0ojHA00<000000?nV4@3oYQ40
1P3oYQ400`2][Jd0ojHA0?nV4@090?nV4@8000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ000000008000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030000002][Jd0[Jf]0080k9H>
00<000000>bF3P3/UPh01`3/UPh2000000<0k9H>00<0[Jf]0=^:3@0000000`3KRPd2000000D0fhX=
00P000000:f][@2iM@/0^GD;0000002][Jd0^GD;000000<0^GD;00<0[Jf]08QF1`28EPL00P28EPL0
0`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h0
10000000dhL>0:f][@0000020=>73P030:f][@3_V100kiP@00800000203_V1000`2][Jd000000000
00050?bP408000001@3lX102000000040?bP402][Jd0[Jf]0:f][@<0oj@A00<000000?nT4@3oY140
1@3oY142000000L0oj@A0P0000090?nV4@030000003oYQ40ojHA00<0ojHA00<000000?nV4@3oYQ40
1P3oYQ400`2][Jd0ojHA0?nV4@090?nV4@8000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ000000008000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030000002][Jd0k9H>0080[Jf]
00<000000>bF3P3/UPh01`3/UPh2000000<0k9H>00<0[Jf]0=^:3@0000000`3KRPd2000000D0fhX=
00T000000:f][@2iM@/0^GD;0000002iM@/0[Jf]0;Ue2`0000000P2iM@/00`2][Jd0R5H708QF1`02
08QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]0080dhL>0P000000
0`2][Jd0dhL>000000020=>73P030:f][@3_V100kiP@00800000203_V1000`2][Jd0000000000005
0?bP408000001@3lX102000000030:f][@3lX100[Jf]00@0oj@A00<000000?nT4@3oY1401@3oY143
000000H0oj@A0P00000:0?nV4@D000002@3oYQ400`2][Jd0ojHA0?nV4@090?nV4@8000003`3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ000000008000006P3oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0C
0?JL3`030000002][Jd0k9H>0080k9H>00<000000:f][@2][Jd01`3/UPh2000000<0k9H>00<0[Jf]
0=^:3@0000000`3KRPd2000000H0fhX=00@0[Jf]0;Ue2`2iM@/000000P2iM@/01@2][Jd000000000
002iM@/0[Jf]00@0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0
0`3CQ`h010000000dhL>0=>73P0000020=>73P040:f][@3_V100kiP@000000T0kiP@00<0[Jf]0000
000000001@3lX102000000<0o:0@0P2][Jd200000080o:0@00<0[Jf]0?nT4@3oY1400P3oY1420000
00H0oj@A00<000000?nT4@0000001P3oY142000001P0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ420000
00l0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@00000002000001X0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l2000000<0k9H>00<000000>bF3P3/UPh00`2][Jd40>bF3P8000000`3/UPh00`2]
[Jd0fhX=000000030=^:3@8000001P3KRPd0102][Jd0^GD;0;Ue2`0000030;Ue2`040000002][Jd0
^GD;0:f][@@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd00000
0P2][Jd010000000dhL>0=>73P0000020=>73P040:f][@3_V100kiP@000000T0kiP@00<0[Jf]0000
000000001@3lX102000000<0[Jf]0P3lX10200000080o:0@00<0[Jf]0?nT4@3oY1400P3oY1420000
00H0oj@A00@000000?nT4@3oY1400000103oY142000001T0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ42
000000l0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ490:f][@<000008P2][JdG0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`@0000000<0k9H>
0000003/UPh0103/UPh30:f][@80k9H>00D000000>bF3P3/UPh0k9H>0:f][@020=^:3@030000003K
RPd0fhX=008000001P3KRPd0102][Jd0^GD;0;Ue2`0000030;Ue2`040000002iM@/0[Jf]0:f][@@0
R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`000000[Jf]0P3CQ`h01000
0000dhL>0=>73P0000020=>73P040:f][@3_V100kiP@000000T0kiP@00<0[Jf]000000000000103l
X1000`2][Jd00000000000050?bP408000000P3lX1000`2][Jd0oj@A0?nT4@020?nT4@030000003o
Y140000000D0oj@A00D000000?nT4@3oY140oj@A000000020?nT4@030000003oY140[Jf]01T0ojHA
00<0[Jf]0?nV4@3oYQ402@3oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][@L0ojHA
00<0[Jf]0?nV400000000P00000J0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL3`800000
0P3/UPh2000000P0k9H>0P2][Jd01@000000k9H>0>bF3P3/UPh0[Jf]0080fhX=00<000000=^:3@3K
RPd00P0000060=^:3@040:f][@2iM@/0^GD;000000<0^GD;00@000000;Ue2`2iM@/0[Jf]0P000003
08QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]09MP2`2GH0/00P0000030=>7
3P040000003CQ`h0dhL>00000080dhL>00@0[Jf]0>nH403_V10000002@3_V1000`2][Jd000000000
00020?bP4080[Jf]00<0o:0@0000000000001@3lX10200000080o:0@00<0[Jf]0?nT4@3oY1400P3o
Y1400`000000oj@A000000040?nT4@030000003oY140oj@A00<0oj@A0P0000020?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ42000000/0ojHA302][JdG0?nV4@030:f][@3o
YQ000000008000006P3oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?0180mY`?0P0000030>bF3P030000003/UPh0k9H>00P0k9H>00D0
00000:f][@2][Jd0k9H>0:f][@020=^:3@050000003KRPd0fhX=0=^:3@0000001`3KRPd00`2][Jd0
^GD;000000030;Ue2`040000002iM@/0^GD;0:f][@8000000`28EPL00`2][Jd0/>3V0;3PiP100;3P
iP40oooo001I0;3PiP050:f][@2GH0/0Uf0;0:f][@0000000P3CQ`h01`000000dhL>0=>73P3CQ`h0
00000=>73P2][Jd00`3_V1000`000000kiP@0>nH40070>nH40030:f][@00000000000080[Jf]0`3l
X102000000D0o:0@0P0000020?bP40030:f][@3oY140oj@A0080oj@A00@000000?nT4@3oY1400000
0P3oY1400`000000oj@A0?nT4@080?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ40
2@3oYQ42000000030?nV4@2][Jd0[Jf]00P0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@050:f]
[@3oYQ0000000?nV400000006P3oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080
oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000<0
k9H>00<000000>bF3P3/UPh0203/UPh00`000000k9H>0>bF3P030:f][@030=^:3@000000fhX=0080
fhX=00<000000=^:3@3KRPd01@3KRPd00`2][Jd0^GD;000000030;Ue2`070000002iM@/0^GD;0:f]
[@000000R5H70000000208QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]09MP
2`2GH0/0[Jf]000000020=>73P070000003CQ`h0dhL>0=>73P000000dhL>0:f][@030>nH40030000
003_V100kiP@00L0kiP@00<0[Jf]0000000000001@3lX102000000D0o:0@0P0000020?bP40030:f]
[@3oY140oj@A0080oj@A00@000000?nT4@3oY140oj@A0P00000;0?nT4@030:f][@3oYQ40ojHA01L0
ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ470:f][@80000000<0[Jf]0?nV4@3oYQ40303oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@040:f][@3oYQ000000000001/0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
0180mY`?0P0000030>bF3P030000003/UPh0k9H>00P0k9H>00P000000>bF3P3/UPh0k9H>0:f][@3K
RPd0[Jf]000000<0fhX=00<000000=^:3@3KRPd01@3KRPd00`2][Jd0^GD;000000030;Ue2`030000
002iM@/0^GD;0080000000D0[Jf]000000000000R5H70:f][@120;3PiP40oooo001I0;3PiP050:f]
[@2GH0/0[Jf]09MP2`0000000P3CQ`h01`000000dhL>0=>73P3CQ`h000000=>73P2][Jd00`3_V100
0`000000kiP@0>nH40030>nH40030000003_V100[Jf]0080[Jf]0P0000050?bP408000001@3lX102
00000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P00000@0?nT4@030:f][@3oYQ40ojHA01@0ojHA202]
[Jd70?nV4@8000003`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@040:f][@3oYQ00ojH@000001/0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]5`3lX1000`2][Jd0mY`?
0?JL3`0B0?JL3`8000000`3/UPh00`000000k9H>0>bF3P080>bF3P050000003/UPh0k9H>0>bF3P2]
[Jd00P3KRPd01@000000[Jf]0:f][@3KRPd0000000L0fhX=00@0[Jf]0;Ue2`00000000000P2iM@/0
0`000000^GD;0;Ue2`020000000508QF1`000000R5H708QF1`2][Jd0@P2`h>H10?ooo`00F@2`h>H0
1@2][Jd0Uf0;0:f][@2GH0/000000080dhL>00L000000=>73P3CQ`h0dhL>0000003CQ`h0[Jf]00<0
kiP@00<000000>nH403_V1000P3_V102000000040:f][@3_V100kiP@0:f][@800000103lX1020000
00H0o:0@0P000000103lX100[Jf]0?nT4@3oY14200000180oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ46
0:f][@<0ojHA00<0[Jf]0?nV4@3oYQ402@3oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
102][Jd0ojH@0?nV4000000K0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3o
Xa00102][Jd0o:0@0?bP403lX1070:f][A00o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000040:f]
[@3/UPh0k9H>000000X0k9H>00D000000>bF3P3/UPh0k9H>0:f][@020=^:3@050000003KRPd0fhX=
0:f][@0000001`3KRPd0102][Jd0^GD;0000000000020;Ue2`030000002iM@/0^GD;0080000000D0
R5H70000002][Jd000000:f][@120;3PiP40oooo001I0;3PiP80[Jf]0P2GH0/010000000dhL>0=>7
3P0000030=>73P030000003CQ`h0[Jf]00<0kiP@00D000000>nH403_V100kiP@0:f][@02000000<0
kiP@00<0[Jf]000000000000103lX102000000H0o:0@0P0000000`3lX100[Jf]0?nT4@0E0?nT4@03
0:f][@3oYQ40ojHA00L0ojHA1`2][Jd90?nV4@030:f][@3oYQ40ojHA00T0ojHA0P00000?0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3f
W0l04P3fW0l2000000040:f][@3/UPh0k9H>000000X0k9H>00D000000>bF3P3/UPh0k9H>0:f][@02
0=^:3@040000003KRPd0fhX=0=^:3@80000000<0[Jf]0=^:3@3KRPd00`3KRPd0102][Jd0^GD;0000
000000020;Ue2`030000002iM@/0^GD;0080000000D0R5H70000002][Jd000000:f][@120;3PiP40
oooo001I0;3PiP80[Jf]0P2GH0/010000000dhL>0=>73P0000030=>73P030000003CQ`h0[Jf]00<0
kiP@00D000000>nH402][Jd0[Jf]0>nH4002000000<0kiP@00<0[Jf]000000000000103lX1020000
00@0o:0@0P0000030?bP40030:f][@3oY140oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd@
0?nV4@030:f][@3oYQ40ojHA00T0ojHA0P00000?0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX1003P3lX1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l2000000040:f][@3/UPh0
k9H>000000X0k9H>00D000000>bF3P3/UPh0k9H>0:f][@020=^:3@040000003KRPd0fhX=0=^:3@80
000000P0fhX=0:f][@2][Jd0fhX=0000003KRPd0[Jf]0;Ue2`8000000P2iM@/00`000000^GD;0;Ue
2`020000000508QF1`000000R5H70000002][Jd0@P2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP
2`2GH0/000000080dhL>00@000000=>73P3CQ`h000000P3CQ`h01P2][Jd0kiP@0>nH403_V1000000
0:f][@<0kiP@0P0000030>nH40040:f][@000000000000000080o:0@0P00000:0?bP40030:f][@3o
Y140oj@A01<0oj@A1@2][JdF0?nV4@030:f][@3oYQ40ojHA00H0ojHA1@00000?0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1060:f][A<0mY`?00D000000:f][@3/UPh0k9H>
000000080>bF3P030000003/UPh0000000<0k9H>00@0[Jf]0=^:3@3KRPd000000`3KRPd2000000<0
fhX=0P0000000`3KRPd0[Jf]0;Ue2`0200000080^GD;00<000000;Ue2`2iM@/00P0000001@28EPL0
000008QF1`000000[Jf]0480/>3V0@3oool005P0/>3V0P2][Jd309MP2`040000003CQ`h000000000
0080dhL>0P0000000`3CQ`h0[Jf]0>nH40020:f][@030000003_V100kiP@00<0kiP@00D000000>nH
403_V100kiP@0:f][@0300000080o:0@00<000000?bP403lX1002@3lX1000`2][Jd0oj@A0?nT4@0?
0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`040:f][@l0mY`?00<00000
0:f][@3/UPh01P3/UPh00`000000k9H>0>bF3P020>bF3P8000000`3/UPh0102][Jd0fhX=0=^:3@00
00030=^:3@8000000`3KRPd200000080[Jf]00<0^GD;0000000000000P2iM@/00`000000^GD;0;Ue
2`020000000408QF1`000000R5H700000080[Jf]@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;0P00
0000103CQ`h000000=>73P3CQ`h2000000030=>73P2][Jd0[Jf]0080kiP@00<000000>nH403_V100
0P3_V1000`000000kiP@0>nH40020>nH40040:f][@00000000000?bP40800000303lX1000`2][Jd0
oj@A0?nT4@0;0?nT4@@0[Jf]1@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0
mY`?1@2][Jd:0?JL3`030000002][Jd0k9H>00H0k9H>00<000000>bF3P3/UPh01`3/UPh0102][Jd0
fhX=0=^:3@0000040=^:3@040000003KRPd0fhX=0=^:3@80000000<0fhX=0:f][@2][Jd00P000003
0;Ue2`060000002iM@/0000000000028EPL000000P28EPL20:f][D40/>3V0@3oool005P0/>3V0P2]
[Jd309MP2`040000003CQ`h0dhL>00000080dhL>0P0000020:f][@<0kiP@00<000000>nH403_V100
0P3_V1000`000000kiP@0>nH40020>nH40030:f][@000000000000l0o:0@00<0[Jf]0?nT4@3oY140
1`3oY1440:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`090?JL3`D0[Jf]
1@3fW0l00`000000[Jf]0>bF3P060>bF3P030000003/UPh0k9H>00L0k9H>00@0[Jf]0000003KRPd0
0000103KRPd2000000<0fhX=00@000000=^:3@2][Jd0^GD;0P0000030;Ue2`060000002iM@/00000
00000028EPL000000P28EPL20:f][D40/>3V0@3oool005P0/>3V0P2][Jd309MP2`040000003CQ`h0
000000000080dhL>0P0000000`3CQ`h0[Jf]0>nH40020>nH40030000003_V100kiP@0080kiP@00<0
00000>nH403_V1000P3_V1000`2][Jd000000000000?0?bP40030:f][@3oY140oj@A00<0oj@A102]
[Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l40:f][@030?JL3`00
0000[Jf]00L0k9H>00<000000>bF3P3/UPh0203/UPh00`2][Jd00000000000050=^:3@080000003K
RPd0fhX=0=^:3@000000fhX=0:f][@2iM@/2000000050:f][@2iM@/0^GD;0000002iM@/00P000000
1028EPL0000000000028EPL20:f][D40/>3V0@3oool005P0/>3V0P2][Jd309MP2`040000003CQ`h0
000000000080dhL>0P0000000`3CQ`h0[Jf]000000030>nH40050000003_V100kiP@0>nH40000000
103_V1000`2][Jd000000000000?0?bP40030:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA
0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?0180mY`?00@0[Jf]0000002][Jd0[Jf]1P3/UPh00`000000
k9H>0>bF3P080>bF3P030:f][@3KRPd0fhX=00D0fhX=00L000000=^:3@3KRPd0fhX=0000003KRPd0
[Jf]0080^GD;00H000000;Ue2`2][Jd0^GD;0000002iM@/200000080R5H700@0000008QF1`2][Jd0
[Jf]@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00@000000=>73P000000dhL>0P2][Jd200000003
0=>73P000000000000<0kiP@00@000000>nH403_V10000001@3_V1000`2][Jd000000000000>0?bP
40<0[Jf]5@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<000000:f]
[@3/UPh00`2][Jd30>bF3P030000003/UPh0k9H>00P0k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd01`00
0000fhX=0=^:3@3KRPd000000=^:3@2][Jd00P2iM@/01P000000^GD;0;Ue2`2][Jd000000;Ue2`80
00000P28EPL010000000R5H70:f][@2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/010000000
dhL>0000002][Jd20=>73P80000000<0dhL>000000000000103_V103000000D0kiP@0P00000=0?bP
4080[Jf]00<0o:0@0:f][@3oY1405@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
01<0mY`?00<000000:f][@3/UPh00`3/UPh20:f][@8000002P3/UPh00`2][Jd0fhX=0=^:3@060=^:
3@060000003KRPd0fhX=0000003KRPd0[Jf]0P2iM@/01P000000^GD;0;Ue2`2iM@/000000:f][@80
00000P28EPL010000000R5H70:f][@2][Je10;3PiP40oooo001H0;3PiP80[Jf]0`2GH0/00`000000
dhL>000000030=>73P80000000<0dhL>000000000000303_V102000000X0o:0@0`2][Jd010000000
o:0@0?bP402][JdF0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`00
0000[Jf]0>bF3P050>bF3P80000000<0[Jf]0>bF3P3/UPh01`3/UPh00`2][Jd0fhX=0=^:3@070=^:
3@8000000P3KRPd0102][Jd0^GD;0;Ue2`0000030;Ue2`040000002iM@/0000000000080R5H700@0
000008QF1`2][Jd0[Jf]@@2`h>H10?ooo`00F02`h>H20:f][@<0Uf0;00<000000:f][@0000000`3C
Q`h2000000030=>73P000000000000`0kiP@0P0000080?bP4080[Jf]0`3lX10010000000o:0@0?bP
402][JdF0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`000000[Jf]
0>bF3P050>bF3P80000000@0k9H>0:f][@2][Jd0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@04
0:f][@2iM@/0^GD;000000<0^GD;00@000000;Ue2`2iM@/000000P28EPL010000000R5H70:f][@2]
[Je10;3PiP40oooo001H0;3PiP030:f][@2GH0/0Uf0;0080Uf0;00<000000=>73P0000000`3CQ`h2
000000030=>73P000000kiP@00`0kiP@0P0000050?bP40<0[Jf]103lX1001@000000o:0@0000003l
X100[Jf]01D0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0@0?JL3`80000000<0mY`?0000002][Jd01P3/UPh2000000@0k9H>0P2]
[Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/000000`2iM@/02P000000^GD;
0;Ue2`000000[Jf]08QF1`000000R5H70000002][Je10;3PiP40oooo001H0;3PiP080:f][@2GH0/0
Uf0;09MP2`2][Jd000000=>73P0000030=>73P040000003CQ`h00000000000d0kiP@0P0000020?bP
40<0[Jf]1`3lX10200000080o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU
40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0B0?JL
3`@000001@3/UPh2000000H0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0=0=^:3@030:f][@2iM@/00000
00<0^GD;00X000000;Ue2`2iM@/000000:f][@28EPL0000008QF1`000000[Jf]@@2`h>H10?ooo`00
F02`h>H0202][Jd0Uf0;09MP2`2GH0/0[Jf]0000003CQ`h000000`3CQ`h00`000000dhL>0:f][@0>
0>nH408000000P2][Jd;0?bP40040000003lX100o:0@0:f][AD0oj@A00<0[Jf]0?nV4@3oYQ40603o
YQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@00<0[Jf]0?bP403lX100603l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0000000<0000000<0k9H>0000000000002@3/
UPh30:f][@d0fhX=00<0[Jf]0;Ue2`0000000`2iM@/02P000000^GD;0;Ue2`000000R5H70:f][@00
0000R5H70000002][Je10;3PiP40oooo001H0;3PiP080:f][@2GH0/0Uf0;0:f][@2GH0/000000=>7
3P0000030=>73P030000003CQ`h0[Jf]00d0kiP@00<0[Jf]000000000000403lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][FT0/>3V
3P2][Jd70?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P030>bF3P<000002P3/UPh0102][Jd0fhX=0:f][@2][Jd;0=^:3@030:f][@2iM@/0000000<0
^GD;00X000000;Ue2`2iM@/0000008QF1`2][Jd0000008QF1`000000[Jf]@@2`h>H10?ooo`00F02`
h>H00`2][Jd0Uf0;0:f][@0209MP2`030000003CQ`h000000080dhL>00@000000=>73P3CQ`h0[Jf]
2`3_V1020:f][@030>nH4000000000000100o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603lX1000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=0P2][Jd90=^:3@03
0:f][@2iM@/000000080^GD;0P0000020;Ue2`80000000D0R5H700000028EPL000000:f][@110;3P
iP40oooo001H0;3PiP030:f][@2GH0/0[Jf]0080Uf0;0`0000050=>73P030:f][@3_V100kiP@00L0
kiP@0P2][Jd30>nH40800000403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0
ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`0000000`2iM@/02P000000
^GD;0;Ue2`2][Jd0000008QF1`000000[Jf]0000002][Je10;3PiP40oooo001H0;3PiP80[Jf]0`2G
H0/3000000D0dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@0P00000@0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2][Jd=0?bP40030:f][@3f
W0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@050=^:3@80[Jf]1@3K
RPd0102][Jd0^GD;0000000000050;Ue2`070:f][@000000R5H70000002][Jd000000:f][@110;3P
iP40oooo001H0;3PiP80[Jf]0P2GH0/01011JN4000000000000000050=>73P030:f][@3_V100kiP@
00<0kiP@0P2][Jd70>nH40800000403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA
00P0ojHA1P2][Jf_0;3PiPD0[Jf]203lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd01`3KRPd20:f][@<0fhX=00@0[Jf]0;Ue2`00000000001@2iM@/0
1`2][Jd0000008QF1`000000R5H70000002][Jd0@@2`h>H10?ooo`00E`2`h>H20:f][@@0Uf0;0P00
00060=>73P040:f][@3_V100kiP@0>nH4080[Jf]203_V10200000140o:0@00<0[Jf]0?nT4@3oY140
4`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2i
M@/00P0000060;Ue2`060:f][@000000000008QF1`000000[Jf]@@2`h>H10?ooo`00E`2`h>H20:f]
[@<0Uf0;00<0[Jf]0000000000001P3CQ`h0102][Jd0kiP@0:f][@2][Jd;0>nH40030:f][@3lX100
o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0
k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@030;Ue2`000000000000H0^GD;00H0[Jf]
000000000000R5H70000002][Je10;3PiP40oooo001G0;3PiP80[Jf]0`2GH0/00`2][Jd000000000
00060=>73P80[Jf]3@3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102]
[JgB0;3PiPD0[Jf]403fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0P2]
[Jd2000000H0^GD;00H0[Jf]08QF1`000000R5H70000002][Je10;3PiP40oooo001G0;3PiP80[Jf]
0`2GH0/00`2][Jd00000000000050=>73P80[Jf]3P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f]
[@3oY140oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue2`00000000001P2iM@/01P2][Jd0R5H700000028EPL00000
0:f][D40/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@000000000000<0dhL>0P2][Jd00`3C
Q`h0[Jf]0>nH400<0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140103oY1450:f]
[N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2]
[Jd0^GD;000000000000[Jf]00D0^GD;00@0[Jf]08QF1`000000R5H70P0000110;3PiP40oooo001G
0;3PiP80[Jf]0`2GH0/00`2][Jd00000000000020=>73P050:f][@3CQ`h0dhL>0=>73P2][Jd03@3_
V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0
[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/000000000002iM@/0
0P2][Jd30;Ue2`040:f][@28EPL0000008QF1`800000@@2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;
00D0[Jf]000000000000dhL>0:f][@040=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403l
X1003`3lX1040:f][OH0/>3V102][JdA0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]00000000
000000000P2iM@/01P000000[Jf]0;Ue2`2iM@/0[Jf]08QF1`@00000@@2`h>H10?ooo`00E`2`h>H2
0:f][@<0Uf0;00@0[Jf]0000002][Jd0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2i
M@/0000000000080^GD;00<000000;Ue2`2][Jd00P2][Jd208QF1`<00000@@2`h>H10?ooo`00E`2`
h>H20:f][@<0Uf0;00<0[Jf]0000003CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`8000000P2iM@/00`2][Jd0R5H7
08QF1`0300000440/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd000000=>7
3P060=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1030:f][@P0^K:V0P2]
[Jgd0;3PiP@0[Jf]1`33_K/40:f][@L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue
2`030;Ue2`040000002iM@/0^GD;0;Ue2`80[Jf]00@0R5H70000000000000000@@2`h>H10?ooo`00
E`2`h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@030000003CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0
/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0
^GD;00@000000;Ue2`2iM@/0^GD;0P2][Jd01028EPL0000008QF1`0000110;3PiP40oooo001G0;3P
iP040:f][@2GH0/0Uf0;09MP2`80[Jf]00<000000=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW
0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0
fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H70:f][@000000R5H700000440/>3V
0@3oool005L0/>3V00L0[Jf]09MP2`2GH0/0[Jf]09MP2`2][Jd0000000L0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0:f][@020:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0
_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H70:f][@000000R5H7
00000440/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P060=>7
3P030:f][@3_V100kiP@00X0kiP@0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`00`2n]j`40:f][MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji
^02n^KP01@2n^KP20:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H708QF1`000000
R5H700000440/>3V0@3oool005L0/>3V00<0[Jf]09MP2`2][Jd00P2GH0/00`2][Jd0dhL>0=>73P06
0=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]
0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01P2][Jd0R5H708QF1`00
0000[Jf]00000440/>3V0@3oool005L0/>3V0P2][Jd309MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL000000000002][Jd0
0000@@2`h>H10?ooo`00E`2`h>H20:f][@<0Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@
0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2aZid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f][Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080[Jf]102n^KP20:f][@D0
fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01`2][Jd0R5H708QF1`000000R5H70000002][Jd0@02`h>H1
0?ooo`00E`2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH
403_V100kiP@0P2][Jd40:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0
^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd7
0<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^003
0;ji^080[Jf]1P2n^KP0102][Jd0@FWQ0:f][@2][Jd30=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0
[Jf]08QF1`28EPL00P28EPL00`000000[Jf]0;3PiP0o0;3PiP40oooo001G0;3PiP050:f][@2GH0/0
Uf0;09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0:f][@2][Jd50:BNS`03045Yh@2][Jd0/J^M00D0/J^M
0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0@FWQ045Yh@2d/;420:f]
[@030=^:3@2][Jd0^GD;00T0^GD;00H0[Jf]08QF1`28EPL0R5H70000002][Je00;3PiP40oooo001G
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@03045Yh@2TWXl0Y9j?00<0Y9j?00<0
@FWQ0:BNS`11JN40202aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0
_00@0<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02][Jd0[Jf]2P2n^KP00`2][Jd0@FWQ
0;B`/@030;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P040:f][@2TWXl0@FWQ045Yh@@0Y9j?00@0@FWQ0:BN
S`2TWXl0[Jf]0`11JN470;6[W@80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0100`KZ`1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@P0_[Vh0P11JN42
0;ji^0030:f][@11JN40];2a00D0];2a0P2][Jd80;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`
h>H10?ooo`00E`2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00H0dhL>0P2][Jd01011JN40Y9j?045Y
h@11JN440:BNS`04045Yh@2TWXl0Y9j?0:f][@<0@FWQ00<0/J^M045Yh@2aZid01P2aZid30:f][@X0
^K:V0`11JN420;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0
`kfc0<>m/`33_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01@2n^KP00`11
JN40_[Vh045Yh@020;ji^003045Yh@2n^KP0[Jf]00T0];2a00<0[Jf]0;Ue2`2iM@/01@2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@05
0=>73P80[Jf]00<0@FWQ0:BNS`11JN400P11JN430:BNS`80@FWQ00@0Y9j?0:f][@2aZid0/J^M0P11
JN420;6[W@80@FWQ1P2aZid00`2][Jd0^K:V0:f][@030:f][@P0^K:V0`11JN400`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][GX0/>3V1@2]
[Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m
^`060<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh0;ji^0040;ji^080@FWQ0`2n^KP01011JN40_[Vh0;ji
^02][Jd90;B`/@80[Jf]1@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@040=>73P050:f][@2:QGD0RXEe045Yh@2TWXl00`11JN430:BN
S`80@FWQ00@0Y9j?0:f][@2aZid0/J^M0P11JN430;6[W@<0@FWQ102aZid00`2][Jd0^K:V0;VbYP03
0;VbYP<0[Jf]1@2i/ZH01011JN40^K:V0;VbYP2][JdB0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0
[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji
^0040;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0@FWQ0;ji^02n^KP0[Jf]202d/;450:f][@<0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd00`3CQ`h00`2][Jd0RXEe08Z5M@02045Yh@050:f][@11JN40@FWQ0:BNS`11JN400P2TWXl2045Y
h@040:BNS`2][Jd0/J^M0;6[W@80@FWQ0`2aZid00`11JN40/J^M0;6[W@040;6[W@030:f][@2i/ZH0
^K:V00H0^K:V0`2][Jd20;VbYP04045Yh@2i/ZH0^K:V0:f][A80_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][JeA0;3PiP`0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0:f][@020:f][@X0`kfk0`11JN450;ji^003045Yh@2n^KP0_[Vh0080_[Vh00@0
@FWQ0;ji^02n^KP0[Jf]1`2d/;40102][Jd0];2a0;B`/@2][Jd209nKX0040:f][@2iM@/0^GD;0:f]
[@<0R5H70P2][Je00;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2][Jd0
0`11JN40RXEe08Z5M@02045Yh@050:BNS`11JN40@FWQ0:BNS`11JN400P2TWXl01011JN40Y9j?0:BN
S`2][Jd20;6[W@03045Yh@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid0102aZid00`2][Jd0^K:V
0;VbYP090;VbYP80[Jf]00@0@FWQ0:f][@2i/ZH0[Jf]4P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`03
0:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0
[Jf]3033_K/01@11JN40`kfk0:f][@2n^KP0@FWQ00@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP01011
JN40_[Vh0;ji^02][Jd50;B`/@80[Jf]0`2d/;40102][Jd0Wi^P09nKX02OVj030:f][@@0R5H700<0
[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]1@2:QGD2
045Yh@050:BNS`11JN40@FWQ0:f][@11JN400P2TWXl01011JN40Y9j?0:BNS`2][Jd20;6[W@03045Y
h@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid0102aZid01@2][Jd0^K:V0;VbYP2i/ZH0@FWQ00T0
^K:V00<0@FWQ0;VbYP2][Jd00P2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_080
@FWQ3036`;`40:f][@030<K0_02][Jd0`kfk00`0`kfk00D0@FWQ0<>m^`2][Jd0_[Vh045Yh@040;ji
^004045Yh@2n^KP0_[Vh0;ji^080@FWQ0P2n^KP0102][Jd0@FWQ0;B`/@2d/;420:f][@D0];2a00<0
[Jf]09nKX02OVj000`2OVj000`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V03h0/>3V0@3o
ool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe08Z5M@0308Z5M@<0@FWQ00D0Y9j?
045Yh@2TWXl0Y9j?045Yh@020:f][@04045Yh@2TWXl0Y9j?0:f][@80/J^M00<0@FWQ0;6[W@2aZid0
0P2aZid00`11JN40/J^M0;6[W@040;6[W@050:f][@2i/ZH0@FWQ045Yh@2i/ZH00P11JN470;VbYP05
045Yh@2i/ZH0^K:V0:f][@2n]j`0102][Jd=0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00>0<O1_0<0@FWQ00<0[Jf]0<K0_036`;`01`36`;`40:f]
[@D0a/2l00<0[Jf]0<>m^`33_K/01@33_K/3045Yh@<0`kfk00<0@FWQ0<>m^`2][Jd00P2n^KP00`11
JN40_[Vh0;ji^0050;ji^008045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ0;B`/@2][Jd70;B`/@030:f]
[@2OVj00Wi^P00@0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f]
[@2GH0/0Uf0;09MP2`80[Jf]1P2:QGD2045Yh@050:BNS`11JN40Y9j?0:BNS`11JN400P2TWXl01011
JN40Y9j?0:BNS`2][Jd20;6[W@03045Yh@2aZid0/J^M0080/J^M00<0@FWQ0;6[W@2aZid0102aZid0
0`2][Jd0^K:V045Yh@040;VbYP04045Yh@2i/ZH0^K:V045Yh@<0^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]
1@2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l0100al6l00<0@FWQ0:f][@36`;`01036`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/0
0`33_K/3045Yh@@0`kfk00D0@FWQ0<>m^`33_K/0`kfk0:f][@080;ji^080@FWQ0`2n^KP00`2][Jd0
@FWQ0:f][@080;B`/@030:f][@2OVj00Wi^P00@0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3P
iP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1`2:QGD00`2][Jd0@FWQ045Yh@020:BN
S`04045Yh@2TWXl0Y9j?045Yh@<0[Jf]0`11JN440;6[W@03045Yh@2aZid0/J^M00@0/J^M00<0[Jf]
0;VbYP11JN40102i/ZH00`11JN40^K:V045Yh@040;VbYP04045Yh@2i/ZH0^K:V0:f][@T0_[N/102]
[Jd50;jg[0030:f][@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1
_00@0<O1_003045Yh@2][Jd0a/2l00@0[Jf]3@36`;`00`2][Jd0@FWQ045Yh@02045Yh@<0`kfk00<0
@FWQ0<>m^`33_K/00P33_K/01@11JN40`kfk0<>m^`33_K/0[Jf]00L0_[Vh0P11JN430;ji^080[Jf]
00<0@FWQ0;B`/@2d/;401`2d/;400`2][Jd0Wi^P09nKX00409nKX005045Yh@2][Jd0R5H708QF1`2]
[Jd0@02`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`030:f][@L0RXEe00<0[Jf]0:BNS`11JN40
0P2TWXl01011JN40Y9j?0:BNS`11JN420:BNS`80[Jf]00@0/J^M045Yh@11JN40@FWQ0P2aZid00`11
JN40/J^M0;6[W@040;6[W@030:f][@2i/ZH0@FWQ00D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH01011
JN40^K:V045Yh@2][Jd=0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l00l0al6l00@0[Jf]045Yh@2][Jd0[Jf]4036`;`4045Yh@D0`kfk00<0
@FWQ0<>m^`33_K/00P33_K/01@11JN40`kfk0<>m^`33_K/0[Jf]00H0_[Vh0P11JN420;ji^080[Jf]
00<0_[Vh0:f][@11JN402@2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]00<0R5H70:f][@2`h>H0
?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]0:BNS`2TWXl0
0P2TWXl2045Yh@80Y9j?00D0@FWQ0:BNS`2TWXl0[Jf]0;6[W@020:f][@<0/J^M0P11JN460;6[W@03
0:f][@2i/ZH0@FWQ00D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@030;VbYP11JN40@FWQ0100
_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@03
0<O1_011JN40[Jf]00`0a/2l1011JN420<K0_0030:f][@11JN40@FWQ00D0`kfk00@0@FWQ0<>m^`33
_K/0`kfk0P11JN430<>m^`030:f][@2n^KP0_[Vh00<0_[Vh00<0@FWQ0;ji^011JN400P2][Jd01@11
JN40_[Vh0;ji^02][Jd0@FWQ00T0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii0:f][@2]
[Je00;3PiP40oooo001F0;3PiP80[Jf]0`1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0
Y9j?00<0Y9j?0P11JN401@2TWXl0@FWQ0:BNS`2TWXl0[Jf]00<0/J^M0`2][Jd2045Yh@H0/J^M00<0
[Jf]0;VbYP11JN401@2i/ZH00`11JN40^K:V0;VbYP030;VbYP05045Yh@2i/ZH0^K:V0:f][@2n]j`0
0P11JN4?0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00D0al6l1@2][Jd60<O1_003045Yh@2][Jd0a/2l00T0a/2l1011JN440<K0_0030:f]
[@11JN40@FWQ00D0`kfk00@0@FWQ0<>m^`33_K/0`kfk0P11JN430<>m^`030:f][@2n^KP0_[Vh00<0
_[Vh0P11JN40102][Jd0_[Vh0;ji^011JN420;ji^0030:f][@11JN40];2a00P0];2a00<0[Jf]09nK
X02OVj00102OVj020:f][@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80
[Jf]1@2:QGD00`2][Jd0Y9j?0:BNS`060:BNS`04045Yh@2TWXl0Y9j?0:f][@H0/J^M0P11JN460;6[
W@030:f][@2i/ZH0@FWQ00D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH01@11JN40^K:V0;VbYP2][Jd0
_[N/0080@FWQ102n]j`4045Yh@L0_[N/00<0[Jf]0<6j/031^[001@31^[050:f][@L0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@/0al6l00<0@FWQ0:f][@36`;`02`36`;`2
045Yh@@0a/2l00<0[Jf]045Yh@11JN401@33_K/01011JN40`kfk0<>m^`33_K/2045Yh@<0`kfk00@0
[Jf]0;ji^02n^KP0_[Vh0P2][Jd2045Yh@<0_[Vh00D0@FWQ0;ji^02n^KP0[Jf]045Yh@090;B`/@03
0:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?00H0Y9j?
00@0@FWQ0:BNS`2TWXl0[Jf]1P2aZid2045Yh@<0[Jf]0`2aZid0102][Jd0^K:V045Yh@11JN440;Vb
YP03045Yh@2i/ZH0^K:V0080^K:V00@0@FWQ0;VbYP2i/ZH0[Jf]0`2n]j`2045Yh@D0_[N/1011JN42
0;jg[0<0@FWQ00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP0
0`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/6
0:f][A00al6l00<0@FWQ0:f][@36`;`01@11JN460<K0_080@FWQ1036`;`00`2][Jd0@FWQ045Yh@05
0<>m^`04045Yh@33_K/0`kfk0<>m^`80@FWQ0`33_K/0102][Jd0_[Vh045Yh@2][Jd20;ji^003045Y
h@2n^KP0_[Vh0080_[Vh00D0@FWQ0;ji^02n^KP0[Jf]045Yh@090;B`/@030:f][@2OVj00Wi^P0080
Wi^P00@0[Jf]09nKX02OVj00[Jf]0P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1S
H5<00P1SH5<0102][Jd0RXEe08Z5M@2][Jd308Z5M@030:f][@2TWXl0Y9j?00H0Y9j?00@0@FWQ0:BN
S`2TWXl0[Jf]1P2aZid2045Yh@<0/J^M0P2][Jd01@2aZid0[Jf]0;VbYP2i/ZH0@FWQ00@0^K:V00<0
@FWQ0;VbYP2i/ZH00P2i/ZH01011JN40^K:V0;VbYP2][Jd30;jg[080@FWQ1@2n]j`2045Yh@H0_[N/
1011JN4?0<6j/0P0[Jf]4033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04037`K`00`11JN40[Jf]
045Yh@030<K0_080@FWQ1P36`;`2045Yh@@0a/2l00<0[Jf]045Yh@11JN401@33_K/00`11JN40`kfk
0<>m^`020<>m^`03045Yh@33_K/0`kfk00<0[Jf]0P11JN420;ji^004045Yh@2n^KP0_[Vh0;ji^080
@FWQ0P2n^KP00`2][Jd0@FWQ0;B`/@080;B`/@030:f][@2OVj00Wi^P0080[Jf]0`2OVj000`2][Jd0
L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe
08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl01P2TWXl01011JN40Y9j?0:BNS`2][Jd60;6[
W@80@FWQ1@2aZid30:f][@80^K:V00D0@FWQ0;VbYP2i/ZH0^K:V045Yh@040;VbYP04045Yh@2i/ZH0
^K:V0:f][@<0_[N/0P11JN450;jg[080@FWQ1P2n]j`00`11JN40[Jf]0<6j/0020<6j/0<0@FWQ3@31
^[000`2][Jd0`kfc0<>m/`030<>m/`/0[Jf]1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38
`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00`0al6l
00L0@FWQ0<O1_037`K`0al6l045Yh@2][Jd0@FWQ00<0a/2l00<0@FWQ0<K0_011JN401@36`;`2045Y
h@@0a/2l00<0[Jf]0<>m^`11JN401@33_K/2045Yh@<0`kfk00H0@FWQ0:f][@2][Jd0`kfk0:f][@2n
^KP2045Yh@80_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN420;ji^0030:f][@11JN40];2a00P0];2a
00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00P0Y9j?00@0
@FWQ0:BNS`2TWXl0[Jf]1P2aZid3045Yh@80/J^M00D0@FWQ0;6[W@2aZid0[Jf]0;VbYP030:f][@80
@FWQ00<0^K:V045Yh@2i/ZH00`2i/ZH01011JN40^K:V0;VbYP2][Jd40;jg[003045Yh@2n]j`0_[N/
00<0_[N/0P11JN460;jg[003045Yh@2][Jd0`KZ`00@0`KZ`1011JN4:0<6j/0030:f][@33_K<0`kfc
00h0`kfc2`2][JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2]
[Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l
00D0al6l0`11JN420<O1_080@FWQ1037`K`2045Yh@D0a/2l0P11JN450<K0_080@FWQ1036`;`00`2]
[Jd0`kfk045Yh@050<>m^`80@FWQ0`2][Jd2045Yh@80`kfk00@0[Jf]0;ji^02n^KP0@FWQ0`2n^KP0
1011JN40_[Vh0;ji^011JN430;ji^0030:f][@11JN40];2a00P0];2a0P2][Jd609nKX0030:f][@1`
KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0
RXEe00<0RXEe0P2][Jd80:BNS`80@FWQ00D0Y9j?0:f][@2aZid0/J^M045Yh@020;6[W@@0@FWQ00H0
/J^M045Yh@2aZid0@FWQ0;6[W@2][Jd40;VbYP80[Jf]0P11JN440;VbYP04045Yh@2i/ZH0^K:V0:f]
[@@0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@H0_[N/00<0@FWQ0:f][@31^[001031^[02045Y
h@P0`KZ`0`11JN400`31^[00[Jf]0<>m/`0D0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`00`37`K`2045Yh@<0al6l00<0@FWQ0<O1_011JN401@37`K`2045Yh@D0a/2l0P11JN450<K0
_080@FWQ1036`;`00`2][Jd0`kfk045Yh@050<>m^`80@FWQ0`33_K/2045Yh@80`kfk00<0[Jf]0;ji
^011JN401@2n^KP2045Yh@@0_[Vh00<0[Jf]045Yh@2d/;40202d/;400`2][Jd0Wi^P09nKX00509nK
X0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=P
D`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl01P2TWXl2045Yh@050:BNS`2][Jd0/J^M
0;6[W@11JN400`2aZid3045Yh@80/J^M0P11JN40102aZid0[Jf]0;VbYP11JN450;VbYP06045Yh@2]
[Jd0[Jf]0:f][@2i/ZH0@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[0020;jg[003045Yh@2n]j`0_[N/00<0
_[N/0P11JN460;jg[003045Yh@31^[00`KZ`00@0`KZ`0P11JN460<6j/0<0@FWQ0P31^[000`11JN40
[Jf]0<>m/`0D0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1^`38`K/03038`K/3045Yh@@0
b<6k00<0[Jf]0<O1_037`K`00P37`K`2045Yh@D0al6l0P11JN450<O1_003045Yh@2][Jd0a/2l00D0
a/2l0P11JN440<K0_080@FWQ1036`;`00`2][Jd0`kfk045Yh@020<>m^`<0[Jf]0P11JN430<>m^`80
@FWQ0P33_K/00`2][Jd0_[Vh045Yh@0;0;ji^0030:f][@11JN40];2a00H0];2a0`2][Jd709nKX005
0:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]
00L0RXEe0`2][Jd60:BNS`80@FWQ00<0Y9j?0:f][@2aZid00P11JN460;6[W@<0@FWQ0P2aZid00`2]
[Jd0^K:V045Yh@050;VbYP09045Yh@2i/ZH0^K:V0;VbYP2][Jd0@FWQ0:f][@2i/ZH0[Jf]00@0_[N/
00<0@FWQ0;jg[02n]j`00`2n]j`2045Yh@H0_[N/00<0@FWQ0<6j/031^[001031^[02045Yh@D0`KZ`
0P11JN450<6j/003045Yh@33_K<0`kfc00@0`kfc00<0@FWQ0<>m/`33_K<00P11JN4:0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL`0:f][@/0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`090<S1^`@0@FWQ1P38`K/00`2][Jd0al6l0<O1_0020<O1_003045Y
h@37`K`0al6l00D0al6l00<0@FWQ0<O1_037`K`00`37`K`00`11JN40[Jf]0<K0_0050<K0_080@FWQ
1036`;`2045Yh@@0a/2l00<0[Jf]0<>m^`11JN400P2][Jd30<>m^`80@FWQ0`33_K/01P11JN40`kfk
045Yh@33_K/0[Jf]045Yh@`0_[Vh00<0[Jf]045Yh@2d/;401@2d/;40102][Jd0];2a0;B`/@2][Jd7
09nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1S
H5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd50:BNS`04045Yh@2TWXl0[Jf]0;6[W@80@FWQ
2`2aZid00`2][Jd0^K:V045Yh@050;VbYP03045Yh@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2][Jd0
0P2][Jd30;jg[003045Yh@2n]j`0_[N/00<0_[N/0P11JN460;jg[003045Yh@31^[00`KZ`00@0`KZ`
0P11JN450<6j/080@FWQ1@31^[000`2][Jd0@FWQ0<>m/`040<>m/`03045Yh@33_K<0@FWQ0080`kfc
0P11JN480<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0@FWQ
045Yh@11JN420<S1^`80@FWQ1P38`K/2045Yh@H0b<6k00<0[Jf]0<O1_037`K`00P37`K`00`11JN40
al6l0<O1_0050<O1_003045Yh@37`K`0al6l00<0al6l00<0@FWQ0:f][@36`;`01@36`;`2045Yh@@0
a/2l0P11JN420<K0_0@0[Jf]00<0@FWQ0<>m^`33_K/00`33_K/2045Yh@@0`kfk1@11JN4<0;ji^003
0:f][@11JN40];2a00<0];2a0P2][Jd30;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`
KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BN
S`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`020:BNS`03045Yh@2TWXl0[Jf]00<0@FWQ2`2aZid00`2]
[Jd0^K:V045Yh@050;VbYP03045Yh@2i/ZH0^K:V0080^K:V0P11JN400`000000[Jf]0;jg[0030:f]
[@03045Yh@2n]j`0_[N/00<0_[N/0P11JN450;jg[080@FWQ1P31^[02045Yh@D0`KZ`0P11JN450<6j
/0030:f][@33_K<0@FWQ00@0`kfc0P11JN450<>m/`80@FWQ1P33_K<00`11JN40aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1
^P030:f][@38`K/0b<6k01@0b<6k00@0@FWQ0<S1^`38`K/0b<6k1011JN460<S1^`80@FWQ1P38`K/0
0`2][Jd0al6l0<O1_0020<O1_003045Yh@37`K`0al6l00D0al6l00<0@FWQ0<O1_037`K`00`37`K`0
0`11JN40[Jf]0<K0_0050<K0_080@FWQ0`36`;`00`2][Jd0@FWQ045Yh@020:f][@80a/2l00<0[Jf]
0<>m^`11JN401@33_K/2045Yh@L0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0@FWQ0;B`/@2d
/;420:f][@D0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je00;3PiP40oooo
001G0;3PiP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00`2TWXl20:f][@<0Y9j?
00<0@FWQ0:f][@11JN400P11JN4;0;6[W@030:f][@2i/ZH0^K:V0080@FWQ0P2i/ZH00`11JN40^K:V
0;VbYP030;VbYP80@FWQ00<0^K:V0:f][@2n]j`00P2n]j`00`11JN40_[N/0:f][@030:f][@030;jg
[011JN40@FWQ00D0_[N/0P11JN460<6j/080@FWQ1031^[02045Yh@H0`KZ`00<0[Jf]0<>m/`33_K<0
1033_K<00`11JN40`kfc0<>m/`050<>m/`03045Yh@33_K<0`kfc00<0`kfc0P11JN4F0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P040:f]
[@38`K/0b<6k045Yh@H0b<6k00<0@FWQ0<S1^`38`K/02@38`K/00`11JN40[Jf]0<S1^`030<S1^`<0
@FWQ1P38`K/2045Yh@H0b<6k00<0[Jf]0<O1_037`K`00P37`K`00`11JN40al6l0<O1_0050<O1_003
045Yh@37`K`0al6l00<0al6l00<0@FWQ0:f][@36`;`01@36`;`2045Yh@<0[Jf]00<0a/2l045Yh@11
JN401036`;`00`2][Jd0`kfk045Yh@050<>m^`80@FWQ1`33_K/00`2][Jd0_[Vh0;ji^00;0;ji^004
0:f][@11JN40];2a0:f][@L0];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii071^N@2][Je0
0;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01@2TWXl20:f]
[@80Y9j?00@0@FWQ0;6[W@2aZid0@FWQ2P2aZid00`2][Jd0^K:V0;VbYP030;VbYP80@FWQ1P2i/ZH0
1011JN40^K:V045Yh@2][Jd30;jg[003045Yh@2n]j`0_[N/00<0_[N/00@0[Jf]045Yh@11JN40[Jf]
102n]j`2045Yh@H0`KZ`0P11JN440<6j/080@FWQ1P31^[000`2][Jd0`kfc0<>m/`040<>m/`03045Y
h@33_K<0`kfc00D0`kfc00<0@FWQ0<>m/`33_K<01033_K<00`11JN40aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng0180a[ng1011JN4F0<O1^0030:f][@37`KX0al6j00P0al6j1011JN440<O1^P80@FWQ
0`37`KX0102][Jd0b<6k0<S1^`11JN460<S1^`03045Yh@38`K/0b<6k00P0b<6k00<0@FWQ0<S1^`2]
[Jd01@38`K/2045Yh@H0b<6k0P11JN460<S1^`030:f][@37`K`0al6l0080al6l00<0@FWQ0<O1_037
`K`01@37`K`00`11JN40al6l0<O1_0030<O1_004045Yh@2][Jd0a/2l0<K0_0@0[Jf]00<0@FWQ0<K0
_036`;`01036`;`2045Yh@<0a/2l00<0[Jf]045Yh@11JN401033_K/3045Yh@L0`kfk00<0[Jf]0;ji
^02n^KP02`2n^KP30:f][@P0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3P
iP40oooo001H0;3PiP030:f][@1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@80
/J^M00<0@FWQ0;6[W@2aZid0202aZid00`2][Jd0^K:V0;VbYP090;VbYP06045Yh@2i/ZH0@FWQ0;Vb
YP11JN40[Jf]0P2n]j`00`11JN40_[N/0;jg[0050;jg[080@FWQ00<0_[N/0:f][@2][Jd00P2][Jd2
045Yh@H0`KZ`0P11JN440<6j/080@FWQ1P31^[000`2][Jd0`kfc0<>m/`0<0<>m/`03045Yh@33_K<0
`kfc00@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`L0@FWQ1`37`KP7
045Yh@80al6h00<0[Jf]0<O1^P37`KX01P37`KX2045Yh@@0al6j00@0@FWQ0<O1^P37`KX0@FWQ1@37
`KX0102][Jd0b<6k0<S1^`11JN460<S1^`03045Yh@38`K/0b<6k00L0b<6k0P11JN400`38`K/0[Jf]
0<S1^`040<S1^`80@FWQ1P38`K/2045Yh@H0b<6k00<0[Jf]0<O1_037`K`00`37`K`00`11JN40al6l
0<O1_0040<O1_003045Yh@37`K`0al6l0080al6l00<0[Jf]045Yh@2][Jd00P2][Jd40<K0_003045Y
h@36`;`0a/2l00@0a/2l0P11JN430<K0_0030:f][@11JN40@FWQ00h0`kfk00<0[Jf]0;ji^02n^KP0
2P2n^KP20:f][@X0];2a00<0[Jf]09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo
001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;Vb
YP0:0;VbYP80@FWQ00@0^K:V045Yh@2][Jd0_[N/0P11JN470;jg[080@FWQ1@2n]j`2045Yh@<0[Jf]
0`31^[02045Yh@@0`KZ`0P11JN460<6j/0030:f][@33_K<0`kfc00`0`kfc00<0@FWQ0<>m/`33_K<0
1033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0@FWQ0<O1^037`KP0
0`37`KP3045Yh@P0al6h0P11JN440<O1^0030:f][@37`KX0al6j00H0al6j00<0@FWQ0<O1^P37`KX0
1037`KX3045Yh@D0al6j00D0[Jf]0<S1^`11JN40b<6k045Yh@040<S1^`<0@FWQ1`38`K/2045Yh@80
b<6k00<0[Jf]0<S1^`38`K/01038`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ1P38`K/00`2][Jd0
al6l0<O1_0030<O1_0@0@FWQ0`37`K`00`11JN40[Jf]0:f][@020:f][@030<O1_011JN40[Jf]00H0
a/2l00<0@FWQ0<K0_036`;`01036`;`3045Yh@80a/2l0P11JN4?0<>m^`030:f][@2n^KP0_[Vh00P0
_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00Wi^P00D0Wi^P0P2][Je20;3PiP40
oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0[Jf]0080[Jf]
2@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP<0@FWQ202n]j`2045Yh@D0_[N/0P11JN430<6j/0<0[Jf]
0P11JN420:f][@80`KZ`0P11JN460<6j/0030:f][@33_K<0`kfc00X0`kfc0`11JN460<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`11JN40al6h0<O1^0050<O1^003045Y
h@37`KP0al6h00H0al6h0P11JN440<O1^0030:f][@37`KX0al6j00D0al6j0P11JN470<O1^P80@FWQ
1@37`KX00`2][Jd0b<6k045Yh@02045Yh@@0b<6k0`11JN470<S1^`80@FWQ0P38`K/00`2][Jd0b<6k
0<S1^`040<S1^`03045Yh@38`K/0b<6k00@0b<6k0P11JN460<S1^`030:f][@37`K`0al6l00D0al6l
0P2][Jd4045Yh@D0al6l0P11JN450<K0_003045Yh@36`;`0a/2l00D0a/2l0P11JN401036`;`0@FWQ
045Yh@2][Jd@0<>m^`030:f][@2n^KP0_[Vh00H0_[Vh0P2][Jd30;ji^0030:f][@2d/;40];2a00T0
];2a00<0[Jf]09nKX02OVj00102OVj020:f][D80/>3V0@3oool005X0/>3V00<0[Jf]08Z5M@2:QGD0
1@2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0202n]j`00`11JN40_[N/045Yh@040;jg[080@FWQ
1P31^[02045Yh@80`KZ`0P2][Jd2045Yh@<0[Jf]0`31^[000`2][Jd0`kfc0<>m/`080<>m/`80@FWQ
0P33_K<00`11JN40`kfc0<>m/`040<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`11JN40al6h0<O1^0060<O1^003045Yh@37`KP0al6h00D0al6h0P11JN450<O1^0030:f]
[@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1@37`KX00`2][Jd0b<6k045Yh@02045Yh@@0b<6k
0`11JN470<S1^`80@FWQ0P38`K/00`2][Jd0b<6k0<S1^`040<S1^`03045Yh@38`K/0b<6k00@0b<6k
0P11JN460<S1^`030:f][@37`K`0al6l00D0[Jf]1@37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ
1@36`;`00`11JN40a/2l0<K0_0050<K0_080@FWQ0`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00<0_[Vh0`2][Jd50;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj00
102OVj000`2][Jd0/>3V0;3PiP110;3PiP40oooo001K0;3PiP030:f][@2:QGD0RXEe00@0RXEe00<0
[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@040;6[W@<0[Jf]102aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00P0_[N/00<0@FWQ0;jg[011JN40102n]j`00`11JN40[Jf]0<6j
/0050<6j/080@FWQ1@31^[001011JN40`KZ`0<6j/031^[040:f][@03045Yh@2][Jd0[Jf]00D0`kfc
0P11JN401033_K<0@FWQ045Yh@11JN470<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`11JN40al6h0<O1^0060<O1^003045Yh@37`KP0al6h00D0al6h0P11JN450<O1^003
0:f][@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1@37`KX00`2][Jd0b<6k045Yh@02045Yh@@0
b<6k0`11JN470<S1^`05045Yh@38`K/0b<6k0<S1^`2][Jd01P38`K/4045Yh@<0b<6k0P11JN430<S1
^`H0[Jf]2P37`K`00`11JN40al6l0<O1_0030<O1_003045Yh@2][Jd0@FWQ00<0a/2l00<0@FWQ0<K0
_036`;`01P36`;`2045Yh@@0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0;ji^02n^KP2
0:f][@P0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0
/>3V0480/>3V0@3oool005`0/>3V00<0[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0/J^M00L0/J^M0`2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/
00P0_[N/00<0@FWQ0;jg[02n]j`00P11JN420;jg[003045Yh@2][Jd0`KZ`00D0`KZ`0P11JN450<6j
/003045Yh@31^[00`KZ`00<0`KZ`00D00000045Yh@33_K<0@FWQ0<>m/`040:f][@@0@FWQ2P33_K<0
0`11JN40aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0@FWQ0<O1^037`KP01P37`KP2
045Yh@H0al6h0P11JN450<O1^0030:f][@37`KX0al6j00@0al6j0P11JN470<O1^P80@FWQ1@37`KX0
0`2][Jd0b<6k045Yh@020<S1^`07045Yh@38`K/0b<6k0<S1^`11JN40b<6k045Yh@070<S1^`05045Y
h@38`K/0b<6k0<S1^`2][Jd00`38`K/4045Yh@@0b<6k0P2][Jd2045Yh@<0[Jf]0`38`K/00`2][Jd0
al6l0<O1_0030<O1_003045Yh@37`K`0al6l00@0al6l00<0@FWQ0<O1_037`K`00`37`K`00`11JN40
[Jf]0<K0_003045Yh@T0a/2l0P11JN440<K0_0030:f][@33_K/0`kfk00@0`kfk00<0@FWQ0<>m^`33
_K/01P33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nK
X02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080
RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0
_[N/0;jg[0080;jg[003045Yh@2n]j`0_[N/0080_[N/0P11JN400`2n]j`0[Jf]0<6j/0050<6j/080
@FWQ1@31^[02045Yh@D0`KZ`00<0@FWQ0<>m/`11JN401033_K<2045Yh@80`kfc202][Jd30<>m/`03
045Yh@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`11JN40al6h0<O1^0060<O1^080
@FWQ1P37`KP2045Yh@D0al6h00<0[Jf]0<O1^P37`KX01037`KX2045Yh@L0al6j0P11JN450<O1^P03
0:f][@11JN40@FWQ0080b<6k00<0@FWQ0<S1^`38`K/00P11JN420<S1^`03045Yh@38`K/0b<6k00@0
b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@030<S1^`P0[Jf]0P38`K/3045Yh@@0b<6k00<0@FWQ0:f]
[@37`K`01037`K`00`11JN40al6l0<O1_0030<O1_003045Yh@37`K`0al6l0080al6l1011JN4=0<K0
_080@FWQ1036`;`00`2][Jd0`kfk0<>m^`040<>m^`80@FWQ1P33_K/30:f][@`0_[Vh00<0[Jf]0;B`
/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@03
0:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0
^K:V00<0[Jf]0;jg[02n]j`0202n]j`00`11JN40_[N/0;jg[0050;jg[0030:f][@31^[00`KZ`0080
`KZ`1011JN460<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0[Jf]045Yh@11JN401033_K<00`11JN40
`kfc0<>m/`050<>m/`04045Yh@33_K<0`kfc0<>m/`<0[Jf]00<0@FWQ0:f][@2][Jd00`2][JdA0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0@FWQ0<O1^037`KP01P37`KP2045Yh@H0al6h0P11JN450<O1
^0030:f][@37`KX0al6j00D0al6j0P11JN460<O1^P80@FWQ1@37`KX00`2][Jd0@FWQ045Yh@020<S1
^`03045Yh@38`K/0b<6k0080@FWQ0P38`K/00`11JN40b<6k0<S1^`030<S1^`030:f][@11JN40[Jf]
00H0[Jf]2P38`K/3045Yh@<0b<6k00<0@FWQ0<S1^`11JN401@37`K`00`11JN40al6l0<O1_0020<O1
_003045Yh@37`K`0al6l00H0al6l00<0[Jf]0<K0_036`;`02`36`;`2045Yh@@0a/2l00<0[Jf]0<>m
^`33_K/01@33_K/01011JN40`kfk0<>m^`33_K/30:f][@030<>m^`2][Jd0_[Vh00`0_[Vh00<0[Jf]
0;B`/@2d/;402@2d/;400`2][Jd0Wi^P0:f][@180;3PiP40oooo001P0;3PiP030:f][@2:QGD0[Jf]
00/0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0;VbYP030;VbYP<0[Jf]202i/ZH00`2]
[Jd0_[N/0;jg[0080;jg[003045Yh@2n]j`0_[N/00D0_[N/00<0[Jf]0<6j/031^[001031^[02045Y
h@H0`KZ`0P11JN440<6j/0030:f][@11JN40`kfc00@0`kfc00<0@FWQ0<>m/`33_K<01033_K<2045Y
h@H0`kfc00<0@FWQ0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`11
JN40al6h0<O1^0070<O1^080@FWQ1@37`KP2045Yh@D0al6h00<0[Jf]0<O1^P37`KX01P37`KX4045Y
h@<0al6j0P11JN450<O1^P030:f][@11JN40@FWQ0080b<6k00<0@FWQ0:f][@2][Jd00P11JN420:f]
[@03045Yh@2][Jd0[Jf]00<0[Jf]00<0b<6k045Yh@38`K/00P38`K/00`2][Jd0b<6k0<S1^`0;0<S1
^`<0@FWQ1038`K/2045Yh@H0al6l1@11JN490<O1_0030:f][@36`;`0a/2l00X0a/2l0P11JN440<K0
_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`
/@2d/;402@2d/;420:f][DT0/>3V0@3oool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0202n]j`00`11JN40
_[N/0;jg[0050;jg[0030:f][@31^[00`KZ`00d0`KZ`0P11JN430<6j/003045Yh@33_K<0`kfc00@0
`kfc00<0@FWQ0<>m/`33_K<01033_K<2045Yh@H0`kfc00<0@FWQ0<Fn]@35_[D03`35_[DA0:f][@`0
a[ng00<0@FWQ0<O1^037`KP01`37`KP2045Yh@D0al6h0P11JN450<O1^0030:f][@37`KX0al6j00T0
al6j00<0[Jf]045Yh@11JN400`11JN460:f][@80@FWQ0`2][Jd01011JN40b<6k045Yh@11JN420<S1
^`03045Yh@38`K/0b<6k00@0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@0=0<S1^`80@FWQ00<0b<6k
045Yh@38`K/00P38`K/00`11JN40[Jf]0<O1_00C0<O1_0030:f][@36`;`0a/2l00X0a/2l0P11JN44
0<K0_0030:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]
0;B`/@2d/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP030:f][@2TWXl0Y9j?
00P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f]
[@2n]j`02@2n]j`00`11JN40_[N/0;jg[0050;jg[0030:f][@31^[00`KZ`00l0`KZ`0`11JN400`2]
[Jd0`kfc0<>m/`050<>m/`03045Yh@33_K<0`kfc00<0`kfc0P11JN460<>m/`03045Yh@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL02@36_kL<0:f][@03045Yh@2][Jd0[Jf]00L0[Jf]0P11JN450:f]
[@80@FWQ4@2][Jd40<O1^P80@FWQ1@37`KX00`2][Jd0@FWQ045Yh@030<S1^`04045Yh@38`K/0@FWQ
045Yh@80b<6k00<0@FWQ0<S1^`38`K/01038`K/01@11JN40b<6k0<S1^`38`K/0[Jf]00d0b<6k0P11
JN420<S1^`@0@FWQ00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00:0<K0_080@FWQ1036
`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`
/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]2@2n]j`00`11JN40_[N/0;jg[0050;jg[0030:f][@31^[00
`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<01P33_K<7045Yh@H0`kfc00<0@FWQ0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`03045Yh@37`KP0al6h00L0al6h0P11JN450<O1^0<0@FWQ1037`KP0
0`2][Jd0al6j0<O1^P0=0<O1^P03045Yh@37`KX0al6j00@0al6j00<0[Jf]045Yh@38`K/00`38`K/0
0`11JN40b<6k045Yh@040<S1^`03045Yh@38`K/0b<6k00<0b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f]
[@0;0<S1^`<0@FWQ1`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00P0a/2l1011
JN420<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00D0];2a00<0
[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]0`2n]j`00`11JN40_[N/045Yh@07
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<03033_K<00`11JN40`kfc0<>m/`03
0<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03045Yh@37`KP0al6h00L0al6h0P11JN45
0<O1^0<0@FWQ1037`KP00`11JN40al6j0<O1^P050<O1^P80@FWQ1P37`KX00`11JN40al6j0<O1^P04
0<O1^P80@FWQ1038`K/3045Yh@@0b<6k00<0@FWQ0<S1^`38`K/00`38`K/01@11JN40b<6k0<S1^`38
`K/0[Jf]01D0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0090<K0_0D0[Jf]0P36
`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d
/;420:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]0P11JN470;jg[0030:f][@31^[00
`KZ`00@0`KZ`00<0@FWQ0<6j/031^[002`31^[000`2][Jd0`kfc0<>m/`0B0<>m/`80@FWQ5P35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`03045Yh@37`KP0al6h00L0al6h0P11JN450<O1^0<0@FWQ1037`KP2
045Yh@H0al6j0P11JN450<O1^P03045Yh@37`KX0al6j00D0al6j0P11JN450<S1^`80@FWQ0P38`K/6
045Yh@80b<6k00D0@FWQ0<S1^`38`K/0b<6k0:f][@060<S1^`03045Yh@38`K/0b<6k00`0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m
^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo
001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[000`31^[02045Yh@d0`KZ`00<0
[Jf]0<>m/`33_K<04P33_K<2045YhAH0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`11JN40al6h0<O1
^0070<O1^080@FWQ1@37`KP2045Yh@030<O1^011JN40al6h0080al6h0P11JN470<O1^P03045Yh@37
`KX0al6j00<0al6j00<0@FWQ0<O1^P37`KX00`37`KX7045Yh@80b<6k0P11JN4;0<S1^`04045Yh@38
`K/0b<6k0:f][@H0b<6k00<0@FWQ0<S1^`38`K/03038`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[001031^[000`11JN40`KZ`
045Yh@0<0<6j/0030:f][@33_K<0`kfc0180`kfc0P11JN4F0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0@FWQ0<O1^037`KP01`37`KP2045Yh@80al6h1@11JN420<O1^0@0@FWQ2@37`KX5045Yh@P0al6j
00<0[Jf]0<S1^`38`K/04@38`K/01011JN40b<6k0<S1^`2][Jd60<S1^`03045Yh@38`K/0b<6k00`0
b<6k00<0[Jf]0<O1_037`K`04037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^00;0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0D0[Jf]0`31^[000`11JN40`KZ`0<6j/00;0<6j/0030:f]
[@33_K<0`kfc0180`kfc0P11JN4F0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0@FWQ0<O1^037`KP0
1P37`KP2045Yh@d0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`070<S1^`030000
0038`K/0b<6k00L0b<6k00@0@FWQ0<S1^`38`K/0[Jf]1P38`K/00`11JN40b<6k0<S1^`0<0<S1^`03
0:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0
[Jf]2P31^[000`2][Jd0`kfc0<>m/`0B0<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
045Yh@37`KP0al6h00H0al6h0P11JN4=0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/04@38`K/2045Yh@030<S1^`2][Jd0b<6k00@0b<6k0`11JN4=0<S1^`030:f][@37`K`0al6l00D0
al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f]
[@33_K<0`kfc0180`kfc0P11JN4F0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0@FWQ0<O1^037`KP0
1P37`KP2045Yh@d0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0B0<S1^`80@FWQ
00<0[Jf]0<S1^`38`K/00`38`K/00`11JN40b<6k045Yh@0=0<S1^`030:f][@37`K`0al6l00D0[Jf]
3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
1@2n^KP20:f][EX0/>3V0@3oool007@0/>3V0P2][Jd60;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00?0<6j/0L0[Jf]4@33_K<2045YhAH0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`11JN40al6h0<O1^0060<O1^003045Yh@37`KP0al6h00`0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0C0<S1^`80@FWQ1038`K/01011JN40b<6k0<S1
^`11JN4:0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk
00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i
/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33
_K<0`kfc0<>m/`L0[Jf]2P33_K<00`11JN40[Jf]0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0@FWQ0<O1^037`KP01P37`KP00`11JN40al6h0<O1^00<0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/5045Yh@L0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]
G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd20<>m/`03045Yh@2]
[Jd0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`11JN40al6h0<O1^0050<O1^003045Yh@37
`KP0al6h00d0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38
`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35
_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03045Yh@37`KP0al6h00@0al6h0P11JN4?0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0`kfk102][JeU0;3PiP40oooo001n
0;3PiP@0[Jf]2`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0B
0<Jo]`X0@FWQ4@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd5
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@
0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][JeY0;3PiP40oooo00220;3PiP<0[Jf]202i/ZH00`2]
[Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0?0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00:0<O1^2P0[Jf]4@38`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`030<>m^`<0[Jf]K02`h>H10?ooo`00Q@2`h>H30:f][@D0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]aT0[Jf]2`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00`2][Je_0;3PiP40oooo00280;3PiP@0[Jf]
00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]L`2`h>H10?ooo`00S02`
h>H40:f][A00_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37
`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37
`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`40:f][GH0/>3V0@3oool00900/>3V1@2][Jd;
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l00L0a/2l102][Jej0;3PiP40oooo002E0;3PiP@0[Jf]1`2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_0030<K0_0@0[Jf]OP2`h>H10?ooo`00V@2`h>H50:f][@80_[N/00<0[Jf]0<6j/031
^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_02]
[Jd00`2][Jf20;3PiP40oooo002N0;3PiPH0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f]
[@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f]
[@37`K`0al6l00l0al6l1@2][Jf60;3PiP40oooo002T0;3PiPL0[Jf]2P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00P0al6l1`2][Jf;0;3PiP40oooo002[0;3PiPL0[Jf]0`31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`040:f][@37`K`0al6l0<O1_0L0[Jf]TP2`h>H10?ooo`00/P2`h>H7
0:f][A80`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k0100b<6k1`2][JfI0;3PiP40oooo002i0;3PiPL0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1
^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][J00/>3V0@3oool00<00
/>3V202][Jd30<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0
al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0
b<6k0<S1^`38`K/80:f][JL0/>3V0@3oool00<P0/>3V2@2][JdA0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00T0
b<6k3`2][Jf_0;3PiP40oooo003A0;3PiP`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37`KXG0:f][Kh0/>3V0@3oool00=d0/>3V@@2]
[JgE0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53399 .33856 m
.55053 .33828 L
s
.55053 .33828 m
.55384 .34045 L
s
.55053 .33828 m
.55549 .3404 L
s
.55384 .34045 m
.55716 .34487 L
s
.55549 .3404 m
.55881 .34482 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55881 .34482 m
.56048 .34928 L
s
.55716 .34487 m
.55883 .34933 L
s
.56865 .3377 m
.58013 .33717 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.53896 .3385 m
.53905 .38608 L
s
.54061 .33848 m
.54072 .38605 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55883 .34933 m
.56051 .35607 L
s
.56048 .34928 m
.56216 .35601 L
s
.56051 .35607 m
.56056 .3674 L
s
.56216 .35601 m
.56222 .36735 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57534 .3555 m
.57703 .36222 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44352 .33586 m
.44512 .33823 L
s
.44188 .338 m
.44352 .33586 L
s
.44348 .34038 m
.44512 .33823 L
s
.60294 .33804 m
.60776 .33542 L
s
.60137 .34268 m
.60294 .33804 L
s
.55894 .37427 m
.56056 .3674 L
s
.44188 .338 m
.44348 .34038 L
s
.60456 .33792 m
.60776 .33542 L
s
.60299 .34257 m
.60456 .33792 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5573 .37887 m
.55894 .37427 L
s
.56883 .36938 m
.57543 .36911 L
s
.57703 .36222 m
.58034 .36661 L
s
.56059 .37422 m
.56222 .36735 L
s
.57358 .33749 m
.57378 .36918 L
s
.57522 .33741 m
.57543 .36911 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60299 .34257 m
.60303 .3471 L
s
.60137 .34268 m
.60141 .34721 L
s
.60776 .33542 m
.61259 .33504 L
s
.61259 .33504 m
.61583 .33704 L
s
.55896 .37882 m
.56059 .37422 L
s
.60141 .34721 m
.60308 .35164 L
s
.60303 .3471 m
.6047 .35152 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.554 .38351 m
.5573 .37887 L
s
.58034 .36661 m
.58364 .36872 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.55566 .38347 m
.55896 .37882 L
s
.58688 .364 m
.5885 .36164 L
s
.5885 .36164 m
.59016 .36382 L
s
.53406 .38613 m
.55069 .38587 L
s
.58688 .364 m
.58854 .36619 L
s
.61583 .33704 m
.61909 .3413 L
s
.44336 .35171 m
.44473 .37914 L
s
.44147 .37892 m
.44336 .35171 L
s
.42582 .33445 m
.42899 .33699 L
s
.42899 .33699 m
.43057 .33939 L
s
.55069 .38587 m
.554 .38351 L
s
.4305 .3462 m
.43057 .33939 L
s
.60308 .35164 m
.60795 .35356 L
s
.41944 .33387 m
.42582 .33445 L
s
.55069 .38587 m
.55566 .38347 L
s
.59016 .36382 m
.59018 .36609 L
s
.58364 .36872 m
.58856 .36846 L
s
.6047 .35152 m
.60795 .35356 L
s
.58856 .36846 m
.59018 .36609 L
s
.62063 .33663 m
.6238 .33407 L
s
.61909 .3413 m
.62063 .33663 L
s
.42889 .34606 m
.43052 .34393 L
s
.6238 .33407 m
.62539 .33393 L
s
.62223 .33648 m
.6238 .33407 L
s
.62069 .34116 m
.62223 .33648 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40645 .32538 m
.40645 .32484 L
s
.5 Mabswid
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60795 .35356 m
.61765 .35507 L
s
.42886 .34834 m
.4305 .3462 L
s
.41623 .33584 m
.41944 .33387 L
s
.42566 .34807 m
.42889 .34606 L
s
.60316 .36072 m
.60319 .363 L
s
.60316 .36072 m
.60479 .36061 L
s
.60479 .36061 m
.60481 .36289 L
s
.42563 .35034 m
.42886 .34834 L
s
.60319 .363 m
.60483 .36516 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4431 .37903 m
.44323 .36535 L
s
.41461 .33795 m
.41623 .33584 L
s
.41761 .3519 m
.42566 .34807 L
s
.41309 .33326 m
.41461 .33795 L
s
.41297 .34234 m
.41309 .33326 L
s
.60483 .36516 m
.6081 .36721 L
s
.41758 .35418 m
.42563 .35034 L
s
.41297 .34234 m
.41461 .33795 L
s
.42871 .36199 m
.43037 .35756 L
s
.43026 .36668 m
.43037 .35756 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61765 .35507 m
.61928 .35721 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6081 .36721 m
.61456 .36672 L
s
.62069 .34116 m
.62088 .35708 L
s
.61909 .3413 m
.61933 .36177 L
s
.61933 .36177 m
.62088 .35708 L
s
.42707 .36414 m
.42871 .36199 L
s
.42871 .36199 m
.43026 .36668 L
s
.63376 .36504 m
.63963 .33249 L
s
.44305 .3836 m
.44473 .37914 L
s
.61456 .36672 m
.61775 .36418 L
s
.61775 .36418 m
.61933 .36177 L
s
.4144 .35388 m
.41761 .3519 L
s
.44147 .37892 m
.44305 .3836 L
s
.42383 .36615 m
.42707 .36414 L
s
.41437 .35616 m
.41758 .35418 L
s
.63535 .36489 m
.63973 .33931 L
s
.41278 .356 m
.4144 .35388 L
s
.41744 .36559 m
.42383 .36615 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40764 .35403 m
.40764 .35369 L
s
.40602 .3549 m
.40604 .35349 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41275 .35829 m
.41437 .35616 L
s
.3989 .334 m
.40196 .33891 L
s
.39426 .33118 m
.3989 .334 L
s
.41272 .36057 m
.41278 .356 L
s
.39116 .3308 m
.39426 .33118 L
s
.41428 .36301 m
.41744 .36559 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63963 .33249 m
.64639 .36374 L
s
.64639 .36374 m
.65213 .33106 L
s
.41272 .36057 m
.41428 .36301 L
s
.62899 .36549 m
.64009 .36441 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38803 .33269 m
.39116 .3308 L
s
.38649 .33249 m
.39116 .3308 L
s
.64796 .36357 m
.65224 .33789 L
s
.38487 .33686 m
.38803 .33269 L
s
.40019 .35241 m
.40173 .35487 L
s
.39859 .35453 m
.40019 .35241 L
s
.40169 .35716 m
.40173 .35487 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38333 .33666 m
.38649 .33249 L
s
.39848 .36139 m
.40169 .35716 L
s
.39859 .35453 m
.40012 .35699 L
s
.38322 .34351 m
.38487 .33686 L
s
.39532 .36333 m
.39848 .36139 L
s
.38168 .34331 m
.38333 .33666 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4056 .38464 m
.40562 .38322 L
s
.40722 .38375 m
.40722 .38341 L
s
.5 Mabswid
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36524 .32721 m
.37581 .32877 L
s
.39064 .36279 m
.39532 .36333 L
s
.38314 .34809 m
.38322 .34351 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65213 .33106 m
.65886 .3623 L
s
.3816 .34789 m
.38168 .34331 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38314 .34809 m
.38456 .35516 L
s
.6542 .36286 m
.66349 .36172 L
s
.38758 .36013 m
.39064 .36279 L
s
.38603 .35994 m
.39064 .36279 L
s
.37066 .36022 m
.37126 .32811 L
s
.3816 .34789 m
.38302 .35496 L
s
.38456 .35516 m
.38758 .36013 L
s
.36915 .36001 m
.36975 .32789 L
s
.67221 .33527 m
.67515 .33025 L
s
.67077 .34006 m
.67221 .33527 L
s
.67515 .33025 m
.67962 .32729 L
s
.38302 .35496 m
.38603 .35994 L
s
.66937 .34714 m
.67077 .34006 L
s
.67372 .33505 m
.67666 .33003 L
s
.67229 .33984 m
.67372 .33505 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67666 .33003 m
.67962 .32729 L
s
.6709 .34693 m
.67229 .33984 L
s
.66937 .34714 m
.66958 .35862 L
s
.67962 .32729 m
.68261 .32683 L
s
.6709 .34693 m
.67111 .35841 L
s
.68261 .32683 m
.68712 .3284 L
s
.66958 .35862 m
.67123 .36532 L
s
.34896 .32453 m
.35928 .32627 L
s
.67111 .35841 m
.67276 .36511 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67123 .36532 m
.67284 .36972 L
s
.35431 .35084 m
.35483 .32554 L
s
.36462 .35936 m
.37066 .36022 L
s
.67276 .36511 m
.67436 .36952 L
s
.35283 .3506 m
.35336 .32529 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.687 .34708 m
.68701 .34739 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69004 .32562 m
.69041 .344 L
s
.69151 .32538 m
.69189 .34376 L
s
.68712 .3284 m
.69018 .33251 L
s
.67284 .36972 m
.67597 .37393 L
s
.68596 .34471 m
.69631 .34303 L
s
.67436 .36952 m
.67748 .37372 L
s
.36884 .37617 m
.37041 .37406 L
s
.36893 .37154 m
.37041 .37406 L
s
.36737 .37364 m
.36893 .37154 L
s
.67597 .37393 m
.68055 .3756 L
s
.67748 .37372 m
.68055 .3756 L
s
.36737 .37364 m
.36884 .37617 L
s
.70028 .32385 m
.71035 .32196 L
s
.33312 .32159 m
.34315 .32349 L
s
.35274 .35521 m
.35431 .35084 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68055 .3756 m
.68356 .37517 L
s
.35126 .35497 m
.35283 .3506 L
s
0 0 0 r
.68727 .38192 m
.68768 .38092 L
s
.255 .412 .882 r
.34827 .3568 m
.35274 .35521 L
s
.33773 .37131 m
.33883 .32269 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68356 .37517 m
.68801 .37219 L
s
.70606 .32279 m
.70679 .35513 L
s
.70462 .32306 m
.70534 .35539 L
s
.34827 .3568 m
.35126 .35497 L
s
.69223 .35992 m
.69252 .37382 L
s
.69089 .3671 m
.69223 .35992 L
s
.33628 .37106 m
.3374 .32242 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68801 .37219 m
.69089 .3671 L
s
.69089 .3671 m
.69252 .37382 L
s
0 0 0 r
.32063 .3113 m
.32284 .31177 L
s
.255 .412 .882 r
.34535 .35631 m
.34827 .3568 L
s
.34104 .35324 m
.34535 .35631 L
s
.70647 .34124 m
.70807 .34792 L
s
.70099 .35615 m
.70679 .35513 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33825 .34809 m
.34104 .35324 L
s
.70807 .34792 m
.71104 .35202 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71104 .35202 m
.71395 .35381 L
s
.32046 .32129 m
.32312 .32651 L
s
.32312 .32651 m
.32434 .33375 L
s
.3164 .31807 m
.32046 .32129 L
s
.32423 .33839 m
.32434 .33375 L
s
.31908 .32099 m
.32173 .32622 L
s
.32173 .32622 m
.32295 .33346 L
s
.71395 .35381 m
.7182 .35299 L
s
.33198 .37028 m
.33773 .37131 L
s
.30338 .29865 m
.31273 .30094 L
s
.71667 .34862 m
.71814 .35067 L
s
.71667 .34862 m
.71803 .34602 L
s
.3164 .31807 m
.31908 .32099 L
s
.71803 .34602 m
.71949 .34806 L
s
.32283 .33811 m
.32295 .33346 L
s
.32266 .34508 m
.32423 .33839 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31367 .31745 m
.3164 .31807 L
s
.32127 .34479 m
.32283 .33811 L
s
.71949 .34806 m
.71955 .35039 L
s
.7182 .35299 m
.71955 .35039 L
s
.72869 .32513 m
.72994 .32019 L
s
.3074 .34883 m
.3087 .29997 L
s
.3109 .31915 m
.31367 .31745 L
s
.31977 .34916 m
.32266 .34508 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73059 .33702 m
.73095 .33917 L
s
.5 Mabswid
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73006 .32483 m
.7313 .31988 L
s
.7313 .31988 m
.73396 .31694 L
s
.72869 .32513 m
.72881 .32977 L
s
.72994 .32019 m
.73396 .31694 L
s
.73006 .32483 m
.73018 .32947 L
s
.30606 .34852 m
.30736 .29965 L
s
.72881 .32977 m
.7303 .33412 L
s
.31838 .34887 m
.32127 .34479 L
s
.73396 .31694 m
.73799 .31599 L
s
.73018 .32947 m
.73166 .33382 L
s
.30808 .32316 m
.3109 .31915 L
s
.7303 .33412 m
.73444 .33553 L
s
.31557 .35062 m
.31977 .34916 L
s
.73166 .33382 m
.73444 .33553 L
s
.31557 .35062 m
.31838 .34887 L
s
.73799 .31599 m
.74072 .31766 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73053 .34343 m
.73059 .34576 L
s
.73053 .34343 m
.7319 .34313 L
s
.73059 .34576 m
.73202 .3478 L
s
.7319 .34313 m
.73196 .34547 L
s
.31283 .35003 m
.31557 .35062 L
s
.74072 .31766 m
.74349 .32167 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73202 .3478 m
.7348 .34954 L
s
.73444 .33553 m
.74255 .33599 L
s
.31017 .34709 m
.31283 .35003 L
s
.30759 .34181 m
.31017 .34709 L
s
.299 .31391 m
.30031 .31424 L
s
.7348 .34954 m
.7402 .34832 L
s
.74468 .31668 m
.74724 .31369 L
s
.74349 .32167 m
.74468 .31668 L
s
.74349 .32167 m
.74406 .3427 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75067 .29638 m
.75954 .29388 L
s
.29633 .31556 m
.299 .31391 L
s
.29763 .3159 m
.299 .31391 L
s
.74599 .31635 m
.74724 .31369 L
s
.74481 .32134 m
.74599 .31635 L
s
.74481 .32134 m
.74526 .3377 L
s
.74724 .31369 m
.74854 .31335 L
s
.30206 .34759 m
.3074 .34883 L
s
.2962 .32023 m
.29763 .3159 L
s
.74255 .33599 m
.74394 .33802 L
s
.2949 .3199 m
.29633 .31556 L
s
.7545 .29532 m
.75591 .34447 L
s
.7402 .34832 m
.7428 .34535 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75577 .29496 m
.75719 .34414 L
s
.29574 .33661 m
.2962 .32023 L
s
.7428 .34535 m
.74406 .3427 L
s
.74406 .3427 m
.74526 .3377 L
s
.29246 .31454 m
.2949 .3199 L
s
.29431 .34097 m
.2949 .3199 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28997 .31152 m
.29246 .31454 L
s
.28618 .31046 m
.28997 .31152 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29431 .34097 m
.29574 .33661 L
s
.29322 .3336 m
.29444 .33628 L
s
.28563 .32922 m
.29322 .3336 L
s
.75644 .3183 m
.75884 .31292 L
s
.29295 .34299 m
.29431 .34097 L
s
.28361 .31209 m
.28618 .31046 L
s
.28236 .31173 m
.28618 .31046 L
s
.75884 .31292 m
.76127 .30987 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29031 .34469 m
.29295 .34299 L
s
.75205 .34546 m
.75719 .34414 L
s
.76127 .30987 m
.76376 .30915 L
s
.28223 .31642 m
.28361 .31209 L
s
.28099 .31606 m
.28236 .31173 L
s
.76376 .30915 m
.76629 .31077 L
s
.76376 .30915 m
.76751 .3104 L
s
.75698 .33707 m
.75966 .3411 L
s
.28522 .34334 m
.29031 .34469 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28319 .32617 m
.28563 .32922 L
s
.28195 .32582 m
.28563 .32922 L
s
.28209 .32112 m
.28223 .31642 L
s
.28085 .32076 m
.28099 .31606 L
s
.28209 .32112 m
.28319 .32617 L
s
.28085 .32076 m
.28195 .32582 L
s
.75966 .3411 m
.76224 .34278 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76751 .3104 m
.77009 .31436 L
s
.76629 .31077 m
.76887 .31473 L
s
.28278 .3403 m
.28522 .34334 L
s
.28167 .33524 m
.28291 .33558 L
s
.28285 .33794 m
.28291 .33558 L
s
.2816 .33759 m
.28167 .33524 L
s
.2816 .33759 m
.28278 .3403 L
s
.76887 .31473 m
.7703 .32143 L
s
.76224 .34278 m
.76474 .34209 L
s
.77009 .31436 m
.77151 .32106 L
s
.76474 .34209 m
.76714 .33903 L
s
.76474 .34209 m
.76837 .33868 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7703 .32143 m
.77045 .32615 L
s
.76714 .33903 m
.76945 .33359 L
s
.77151 .32106 m
.77166 .32578 L
s
.76945 .33359 m
.77045 .32615 L
s
.76837 .33868 m
.77066 .33323 L
s
.77066 .33323 m
.77166 .32578 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7782 .30465 m
.78623 .3019 L
s
.25764 .30135 m
.26562 .30413 L
s
.27069 .33202 m
.27181 .33475 L
s
.27174 .33712 m
.27181 .33475 L
s
.26942 .33402 m
.27069 .33202 L
s
.27047 .33913 m
.27174 .33712 L
s
.26942 .33402 m
.27054 .33676 L
s
.26691 .33803 m
.27047 .33913 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26109 .33616 m
.26216 .30295 L
s
.25995 .33578 m
.26102 .30255 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78283 .30309 m
.78443 .353 L
s
.78168 .30348 m
.78327 .35337 L
s
0 0 0 r
.24982 .29433 m
.25101 .2936 L
s
.255 .412 .882 r
.26464 .33491 m
.26691 .33803 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26247 .3294 m
.26464 .33491 L
s
.26155 .3219 m
.26247 .3294 L
s
.78366 .32916 m
.78611 .33315 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77977 .35446 m
.78443 .353 L
s
.25655 .33463 m
.26109 .33616 L
s
.78611 .33315 m
.78957 .33438 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79069 .30028 m
.79825 .29737 L
s
.5 Mabswid
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79397 .29905 m
.79485 .32525 L
s
.2504 .31795 m
.25104 .2989 L
s
.79505 .29863 m
.79594 .32485 L
s
.78957 .33438 m
.7918 .33361 L
s
.24774 .30003 m
.24972 .30562 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24932 .31754 m
.24996 .29848 L
s
.24611 .31631 m
.25368 .31915 L
s
.24467 .29638 m
.24774 .30003 L
s
0 0 0 r
.79897 .32149 m
.79911 .3194 L
s
.255 .412 .882 r
.7918 .33361 m
.79392 .33043 L
s
.7918 .33361 m
.79501 .33003 L
s
0 0 0 r
.79963 .32723 m
.80031 .31745 L
s
.79922 .32884 m
.79963 .32723 L
s
.255 .412 .882 r
.79392 .33043 m
.79485 .32525 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2426 .29552 m
.24467 .29638 L
s
.79501 .33003 m
.79594 .32485 L
s
.24935 .34909 m
.24983 .33468 L
s
.80243 .29567 m
.80948 .29263 L
s
.24047 .29705 m
.2426 .29552 L
s
.23946 .29662 m
.2426 .29552 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24851 .34149 m
.24983 .33468 L
s
.2462 .34551 m
.24851 .34149 L
s
.24851 .34149 m
.24935 .34909 L
s
.23828 .30097 m
.24047 .29705 L
s
.23728 .30053 m
.23946 .29662 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8065 .29394 m
.80768 .32755 L
s
.80549 .29438 m
.80667 .32796 L
s
.24294 .34673 m
.2462 .34551 L
s
.23711 .30533 m
.23828 .30097 L
s
.80359 .3292 m
.80768 .32755 L
s
.23612 .3049 m
.23728 .30053 L
s
.23587 .31211 m
.23711 .30533 L
s
.24085 .34593 m
.24294 .34673 L
s
.23488 .31168 m
.23612 .3049 L
s
.23544 .32415 m
.23587 .31211 L
s
.23887 .34271 m
.24085 .34593 L
s
.23786 .3423 m
.24085 .34593 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23445 .32372 m
.23488 .31168 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80615 .34285 m
.80709 .34002 L
s
.80615 .34285 m
.80726 .34486 L
s
.23701 .33705 m
.23887 .34271 L
s
.80709 .34002 m
.80819 .34203 L
s
.23544 .32415 m
.23618 .33181 L
s
.23601 .33664 m
.23786 .3423 L
s
.23618 .33181 m
.23701 .33705 L
s
.80726 .34486 m
.80819 .34203 L
s
.81457 .29761 m
.81628 .2919 L
s
.81388 .30527 m
.81457 .29761 L
s
.23445 .32372 m
.23518 .33139 L
s
.81388 .30527 m
.81405 .31009 L
s
.23518 .33139 m
.23601 .33664 L
s
.81552 .29716 m
.81721 .29144 L
s
.81483 .30483 m
.81552 .29716 L
s
.81628 .2919 m
.81896 .28812 L
s
.81405 .31009 m
.81527 .3169 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81483 .30483 m
.81501 .30965 L
s
.81721 .29144 m
.81896 .28812 L
s
.81501 .30965 m
.81622 .31646 L
s
.81896 .28812 m
.82077 .2872 L
s
.81527 .3169 m
.81733 .32086 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22486 .32182 m
.23048 .32443 L
s
.81622 .31646 m
.81827 .32043 L
s
.2252 .2875 m
.22764 .32314 L
s
.82077 .2872 m
.82352 .28822 L
s
.81733 .32086 m
.8202 .32198 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81827 .32043 m
.8202 .32198 L
s
.82352 .28822 m
.82543 .29213 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22039 .3196 m
.2252 .2875 L
s
.22127 .32005 m
.22494 .29474 L
s
.8202 .32198 m
.82292 .32065 L
s
.21823 .28375 m
.22039 .3196 L
s
.21362 .31597 m
.21823 .28375 L
s
.82292 .32065 m
.8246 .31733 L
s
.82433 .31003 m
.82511 .30715 L
s
.82433 .31003 m
.8253 .31201 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82511 .30715 m
.82607 .30912 L
s
.21444 .31643 m
.21795 .29103 L
s
.8246 .31733 m
.82616 .31155 L
s
.82607 .30912 m
.82616 .31155 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21834 .34202 m
.21839 .33937 L
s
.5 Mabswid
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83099 .28153 m
.83198 .28591 L
s
.83099 .28153 m
.83136 .29126 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21121 .31458 m
.21694 .3178 L
s
.83136 .29126 m
.83198 .28591 L
s
.83198 .28591 m
.83268 .28299 L
s
.83268 .28299 m
.83415 .27959 L
s
.83415 .27959 m
.83718 .27762 L
s
.2102 .27893 m
.21096 .27942 L
s
.83192 .30589 m
.83263 .30298 L
s
.83192 .30589 m
.83211 .31078 L
s
.83202 .30833 m
.83273 .30542 L
s
.83263 .30298 m
.83413 .29959 L
s
.20859 .28038 m
.2102 .27893 L
s
.20934 .28087 m
.2102 .27893 L
s
.83211 .31078 m
.83301 .31276 L
s
.83273 .30542 m
.83422 .30203 L
s
.83413 .29959 m
.83776 .29229 L
s
.2084 .28527 m
.20934 .28087 L
s
.83301 .31276 m
.83469 .31428 L
s
.83422 .30203 m
.83785 .29474 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20766 .28478 m
.20859 .28038 L
s
.83718 .27762 m
.83875 .27907 L
s
.20773 .30241 m
.2084 .28527 L
s
.83469 .31428 m
.83777 .31241 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20639 .2789 m
.20766 .28478 L
s
.2068 .30685 m
.20766 .28478 L
s
.83875 .27907 m
.83956 .28102 L
s
.83776 .29229 m
.83913 .28887 L
s
.20505 .27546 m
.20639 .2789 L
s
.83785 .29474 m
.83923 .29132 L
s
.2068 .30685 m
.20773 .30241 L
s
.83956 .28102 m
.83985 .28838 L
s
.83913 .28887 m
.83976 .28592 L
s
.20297 .27395 m
.20505 .27546 L
s
.83923 .29132 m
.83985 .28838 L
s
.20635 .299 m
.20699 .30193 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83777 .31241 m
.83917 .309 L
s
.20219 .29361 m
.20635 .299 L
s
.20596 .30883 m
.2068 .30685 L
s
.83917 .309 m
.8398 .30606 L
s
.20441 .31034 m
.20596 .30883 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8398 .30606 m
.84034 .30066 L
s
.8398 .30606 m
.84072 .31051 L
s
.20153 .27539 m
.20297 .27395 L
s
.20087 .27488 m
.20297 .27395 L
s
.84034 .30066 m
.84072 .31051 L
s
.20161 .30842 m
.20441 .31034 L
s
.20067 .2798 m
.20153 .27539 L
s
.84429 .27506 m
.84484 .27209 L
s
.84429 .27506 m
.84504 .27701 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20002 .27929 m
.20087 .27488 L
s
.20094 .29015 m
.20219 .29361 L
s
.20028 .28966 m
.20219 .29361 L
s
.84484 .27209 m
.84559 .27404 L
s
.20048 .28473 m
.20067 .2798 L
s
.84504 .27701 m
.84559 .27404 L
s
.20048 .28473 m
.20094 .29015 L
s
.19983 .28422 m
.20002 .27929 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19983 .28422 m
.20028 .28966 L
s
.20035 .30497 m
.20161 .30842 L
s
.84553 .28933 m
.84737 .31857 L
s
.84553 .28933 m
.84606 .31954 L
s
.19989 .29954 m
.20055 .30003 L
s
.20045 .3025 m
.20055 .30003 L
s
.19979 .30201 m
.20035 .30497 L
s
.19979 .30201 m
.19989 .29954 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84612 .30417 m
.84672 .31906 L
s
.84606 .31954 m
.84692 .32403 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84692 .32403 m
.84737 .31857 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19431 .29505 m
.19479 .29804 L
s
.19469 .30053 m
.19479 .29804 L
s
.19401 .30252 m
.19469 .30053 L
s
.19363 .29704 m
.19431 .29505 L
s
.18913 .26143 m
.19264 .26516 L
s
.19363 .29704 m
.19411 .30003 L
s
.1923 .30102 m
.19401 .30252 L
s
.18965 .29849 m
.19108 .26357 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18914 .29798 m
.19058 .26304 L
s
.19132 .29751 m
.1923 .30102 L
s
.19047 .29149 m
.19132 .29751 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.19026 .28349 m
.19047 .29149 L
s
.18768 .29645 m
.18965 .29849 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18618 .2657 m
.18638 .27125 L
s
.18638 .27125 m
.1865 .2793 L
s
.18558 .25961 m
.18618 .2657 L
s
.18598 .29187 m
.1865 .2793 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18577 .26516 m
.18597 .27071 L
s
.18597 .27071 m
.18607 .27877 L
s
.18519 .25907 m
.18577 .26516 L
s
.18555 .29135 m
.18607 .27877 L
s
.18454 .25547 m
.18558 .25961 L
s
.18454 .25547 m
.18519 .25907 L
s
.18523 .29891 m
.18598 .29187 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18481 .29839 m
.18555 .29135 L
s
.18138 .24994 m
.18454 .25547 L
s
.1846 .30345 m
.18523 .29891 L
s
.18419 .30293 m
.18481 .29839 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18357 .30749 m
.1846 .30345 L
s
.18318 .30697 m
.18419 .30293 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18231 .30849 m
.18357 .30749 L
s
.18027 .3054 m
.18253 .25216 L
s
.18231 .30849 m
.18318 .30697 L
s
.17997 .30488 m
.18222 .25161 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17911 .30332 m
.18231 .30849 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86707 .24056 m
.86938 .29454 L
s
.86716 .23999 m
.86948 .29401 L
s
.86673 .24226 m
.8675 .23656 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8675 .23656 m
.86764 .23798 L
s
.8675 .23656 m
.86764 .23741 L
s
.86764 .23798 m
.86785 .24199 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86904 .29614 m
.86983 .2908 L
s
.86764 .23741 m
.86783 .24142 L
s
.86785 .24199 m
.86805 .24658 L
s
.86783 .24142 m
.86802 .24601 L
s
.86805 .24658 m
.86835 .25377 L
s
.86802 .24601 m
.86831 .25321 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86975 .28713 m
.86983 .2908 L
s
.86975 .28659 m
.86983 .2908 L
s
.17796 .23411 m
.17792 .23612 L
s
.17796 .23411 m
.17815 .23095 L
s
.86835 .25377 m
.86891 .26674 L
s
.17812 .23296 m
.17815 .23095 L
s
.86831 .25321 m
.86886 .26619 L
s
.86952 .28084 m
.86975 .28713 L
s
.17792 .23612 m
.17812 .23296 L
s
.86622 .22619 m
.86713 .23023 L
s
.8695 .2803 m
.86975 .28659 L
s
.86891 .26674 m
.86928 .27509 L
s
.86928 .27509 m
.86952 .28084 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86886 .26619 m
.86924 .27454 L
s
.86924 .27454 m
.8695 .2803 L
s
.17595 .28087 m
.17737 .24907 L
s
.17611 .27978 m
.17737 .24907 L
s
.86681 .2285 m
.86837 .26492 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17602 .28033 m
.1767 .26467 L
s
.1758 .28556 m
.17595 .28087 L
s
.86824 .26437 m
.8687 .26658 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86757 .24871 m
.86776 .25597 L
s
.1758 .28556 m
.17611 .27978 L
s
.86767 .26009 m
.86776 .25597 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86727 .24175 m
.86824 .26437 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17798 .25301 m
.17801 .25238 L
s
.178 .25305 m
.17801 .25238 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86743 .2616 m
.86767 .26009 L
s
0 0 0 r
.17683 .21159 m
.17853 .20803 L
s
.17706 .22843 m
.17735 .21041 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17612 .28563 m
.17706 .22843 L
s
.17695 .23166 m
.18005 .22646 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18063 .20447 m
.18314 .20093 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17661 .2742 m
.18183 .2027 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17612 .28563 m
.18226 .20211 L
s
.255 .412 .882 r
.18675 .21188 m
.18754 .21336 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18407 .19975 m
.18768 .19563 L
s
.255 .412 .882 r
.18519 .24899 m
.18621 .24524 L
s
.18519 .249 m
.18668 .24468 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18621 .24524 m
.18739 .23879 L
s
.18739 .23879 m
.18816 .23088 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1833 .25122 m
.18555 .19798 L
s
.5 Mabswid
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18382 .25067 m
.18607 .19739 L
s
.18182 .25288 m
.18382 .25067 L
s
.18479 .22775 m
.18483 .23863 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85524 .19314 m
.85599 .19752 L
s
.85555 .20074 m
.85599 .19752 L
s
.85478 .19636 m
.85524 .19314 L
s
.18483 .23863 m
.1856 .24518 L
s
.85478 .19636 m
.85555 .20074 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1856 .24518 m
.18658 .24791 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85635 .21982 m
.85887 .2665 L
s
.84788 .18676 m
.85072 .18907 L
s
.18658 .24791 m
.18838 .24626 L
s
.18809 .23912 m
.18854 .24241 L
s
.18809 .23912 m
.18886 .23473 L
s
.18886 .23473 m
.18932 .23801 L
s
.19472 .20011 m
.19645 .19131 L
s
.19356 .21217 m
.19472 .20011 L
s
.18916 .24186 m
.18932 .23801 L
s
.18838 .24626 m
.18916 .24186 L
s
.19645 .19131 m
.19881 .18576 L
s
.19542 .19953 m
.19717 .19073 L
s
.19425 .21161 m
.19542 .19953 L
s
.19324 .21985 m
.19356 .21217 L
s
.19717 .19073 m
.19881 .18576 L
s
.19393 .21929 m
.19425 .21161 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85859 .27371 m
.85887 .2665 L
s
.84788 .18676 m
.85119 .26791 L
s
.8486 .18734 m
.85192 .26843 L
s
.85731 .24283 m
.85827 .26597 L
s
.85635 .21982 m
.85765 .26543 L
s
.19324 .21985 m
.19346 .23085 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19881 .18576 m
.20034 .18461 L
s
.84655 .18944 m
.84835 .19825 L
s
.19393 .21929 m
.19416 .2303 L
s
.84486 .18447 m
.84655 .18944 L
s
.85765 .26543 m
.85859 .27371 L
s
.20034 .18461 m
.20256 .18674 L
s
.84328 .18332 m
.84486 .18447 L
s
.19346 .23085 m
.19456 .23748 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19416 .2303 m
.19529 .23694 L
s
.8418 .18603 m
.84328 .18332 L
s
.84097 .18547 m
.84328 .18332 L
s
.20256 .18674 m
.2039 .19332 L
s
.84842 .23572 m
.8496 .22906 L
s
.19456 .23748 m
.19662 .23973 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19529 .23694 m
.19662 .23973 L
s
.84044 .19262 m
.8418 .18603 L
s
.83958 .19206 m
.84097 .18547 L
s
.84704 .23852 m
.84842 .23572 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19662 .23973 m
.19894 .23812 L
s
.84004 .20367 m
.84044 .19262 L
s
.83918 .20312 m
.83958 .19206 L
s
.84892 .26634 m
.85192 .26843 L
s
.20117 .2215 m
.20214 .21708 L
s
.20117 .2215 m
.20183 .22484 L
s
.84545 .23745 m
.84704 .23852 L
s
.20214 .21708 m
.20282 .22041 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19894 .23812 m
.2007 .23315 L
s
.20957 .17838 m
.21616 .17449 L
s
.84004 .20367 m
.84035 .21142 L
s
.20266 .2243 m
.20282 .22041 L
s
.84366 .23248 m
.84545 .23745 L
s
.84283 .23195 m
.84545 .23745 L
s
.2007 .23315 m
.20266 .2243 L
s
.83918 .20312 m
.83948 .21088 L
s
.84035 .21142 m
.84167 .22362 L
s
.84167 .22362 m
.84366 .23248 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82699 .17326 m
.83376 .17712 L
s
.83948 .21088 m
.84081 .22308 L
s
.84081 .22308 m
.84283 .23195 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20913 .25876 m
.21232 .17671 L
s
.21008 .25826 m
.21327 .17615 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82996 .17491 m
.83206 .22953 L
s
.83093 .17546 m
.83304 .23005 L
s
.22018 .1723 m
.22765 .16853 L
s
.2116 .21895 m
.21323 .22574 L
s
.81522 .16733 m
.82286 .17108 L
s
.2217 .21373 m
.22331 .17067 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22277 .21321 m
.22438 .17014 L
s
.20635 .26029 m
.21008 .25826 L
s
.82908 .22798 m
.83304 .23005 L
s
.21323 .22574 m
.21606 .22811 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81965 .16946 m
.82274 .25217 L
s
.81856 .16893 m
.82164 .25168 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21606 .22811 m
.2181 .22708 L
s
.83313 .25712 m
.83395 .25368 L
s
.83282 .24922 m
.83395 .25368 L
s
.83199 .25267 m
.83282 .24922 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2181 .22708 m
.22034 .22212 L
s
.2181 .22708 m
.2214 .22161 L
s
.23216 .1664 m
.24049 .16276 L
s
.83199 .25267 m
.83313 .25712 L
s
.22034 .22212 m
.2217 .21373 L
s
.2214 .22161 m
.22277 .21321 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23367 .22006 m
.23567 .16483 L
s
.23487 .21957 m
.23685 .16431 L
s
.80595 .16707 m
.80865 .17596 L
s
.80211 .16161 m
.80595 .16707 L
s
.255 .412 .882 r
.80772 .20684 m
.80859 .20909 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79958 .16059 m
.80211 .16161 L
s
.81827 .25023 m
.82274 .25217 L
s
.24549 .16072 m
.25465 .15723 L
s
.23015 .22154 m
.23487 .21957 L
s
.79715 .16352 m
.79958 .16059 L
s
.79585 .16303 m
.79958 .16059 L
s
.80965 .20358 m
.80979 .20754 L
s
.8083 .19912 m
.80965 .20358 L
s
.80722 .20258 m
.8083 .19912 L
s
.80764 .21449 m
.80979 .20754 L
s
.24744 .21477 m
.24935 .15921 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79481 .17043 m
.79715 .16352 L
s
.80722 .20258 m
.80858 .20704 L
s
.24875 .2143 m
.25066 .15871 L
s
.79348 .16994 m
.79585 .16303 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80531 .2175 m
.80764 .21449 L
s
.79389 .18183 m
.79481 .17043 L
s
.23162 .24444 m
.23295 .23996 L
s
.23162 .24444 m
.23267 .24796 L
s
.23295 .23996 m
.23401 .24348 L
s
.79255 .18135 m
.79348 .16994 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80151 .21607 m
.80531 .2175 L
s
.23267 .24796 m
.23401 .24348 L
s
.78071 .15372 m
.78631 .15564 L
s
.79389 .18183 m
.79416 .18978 L
s
.26011 .15528 m
.27008 .15196 L
s
.79255 .18135 m
.79282 .1893 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24355 .21619 m
.24875 .2143 L
s
.79416 .18978 m
.79589 .2022 L
s
.79879 .21113 m
.80151 .21607 L
s
.79748 .21065 m
.80151 .21607 L
s
.79282 .1893 m
.79456 .20173 L
s
.78212 .1542 m
.78395 .21005 L
s
.79589 .2022 m
.79879 .21113 L
s
.24916 .20232 m
.25155 .20936 L
s
.2629 .19768 m
.26432 .15384 L
s
.78071 .15372 m
.78252 .2096 L
s
.79456 .20173 m
.79748 .21065 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26433 .19722 m
.26575 .15336 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77797 .15674 m
.7811 .16563 L
s
.77347 .15137 m
.77797 .15674 L
s
.25155 .20936 m
.2555 .21198 L
s
.77051 .15045 m
.77347 .15137 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76788 .1497 m
.76791 .15044 L
s
.5 Mabswid
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76763 .15352 m
.77051 .15045 L
s
.76611 .15307 m
.77051 .15045 L
s
.2555 .21198 m
.25827 .21107 L
s
.276 .15011 m
.28673 .14698 L
s
.25827 .21107 m
.26121 .20615 L
s
.25827 .21107 m
.26263 .2057 L
s
.26121 .20615 m
.2629 .19768 L
s
.76636 .16106 m
.76763 .15352 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27919 .19283 m
.28054 .14875 L
s
.26433 .19722 m
.26696 .20436 L
s
.26263 .2057 m
.26433 .19722 L
s
.76483 .16061 m
.76611 .15307 L
s
.28074 .1924 m
.28207 .14831 L
s
.77819 .20827 m
.78395 .21005 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.769 .18601 m
.76903 .18675 L
s
.5 Mabswid
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26696 .20436 m
.27125 .20707 L
s
.27125 .20707 m
.27425 .20621 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75029 .14472 m
.75098 .1688 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74867 .14429 m
.75098 .1688 L
s
.27425 .20621 m
.27742 .20132 L
s
.27425 .20621 m
.27895 .20089 L
s
.27742 .20132 m
.27919 .19283 L
s
.27895 .20089 m
.28074 .1924 L
s
.29783 .14799 m
.30289 .14274 L
s
.29435 .15684 m
.29783 .14799 L
s
.29239 .16932 m
.29435 .15684 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76483 .16061 m
.76617 .20483 L
s
.76636 .16106 m
.76771 .20525 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29947 .14757 m
.30289 .14274 L
s
.29597 .15643 m
.29947 .14757 L
s
.294 .1689 m
.29597 .15643 L
s
.76151 .20357 m
.76771 .20525 L
s
.30289 .14274 m
.30623 .14192 L
s
.29215 .17737 m
.29239 .16932 L
s
.29377 .17696 m
.294 .1689 L
s
.30623 .14192 m
.3112 .14474 L
s
.29215 .17737 m
.29342 .18908 L
s
.29377 .17696 m
.29505 .18868 L
s
.29377 .17696 m
.31389 .17224 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3112 .14474 m
.31442 .15202 L
s
.29342 .18908 m
.29646 .19638 L
s
.29505 .18868 m
.29811 .19599 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72849 .13946 m
.7307 .22485 L
s
.73022 .13984 m
.73245 .22521 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72325 .13831 m
.73901 .14205 L
s
.73901 .14205 m
.75029 .14472 L
s
.5 Mabswid
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.74119 .17041 m
.74208 .20286 L
s
.29646 .19638 m
.30132 .19927 L
s
.75109 .22926 m
.75202 .20519 L
s
.75202 .20519 m
.75272 .22964 L
s
.29811 .19599 m
.30132 .19927 L
s
.73138 .18433 m
.74163 .1866 L
s
.31184 .18479 m
.31216 .17262 L
s
.30132 .19927 m
.30638 .19813 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31745 .1775 m
.31747 .1765 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31368 .18036 m
.31389 .17224 L
s
.3323 .14024 m
.33785 .13515 L
s
.3285 .14905 m
.3323 .14024 L
s
.32641 .16156 m
.3285 .14905 L
s
.31173 .18886 m
.31368 .18036 L
s
.3099 .1933 m
.31184 .18479 L
s
.33411 .13989 m
.33785 .13515 L
s
.3303 .14869 m
.33411 .13989 L
s
.30638 .19813 m
.3099 .1933 L
s
.3282 .1612 m
.3303 .14869 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33785 .13515 m
.34153 .13446 L
s
.3099 .1933 m
.31173 .18886 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32621 .16968 m
.32641 .16156 L
s
.34153 .13446 m
.34515 .13783 L
s
.328 .16933 m
.3282 .1612 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32621 .16968 m
.3277 .18155 L
s
.328 .16933 m
.32951 .1812 L
s
.34515 .13783 m
.34871 .14529 L
s
.34898 .13312 m
.35654 .13184 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34709 .21908 m
.34898 .13312 L
s
.34899 .21879 m
.35086 .13279 L
s
.3277 .18155 m
.33113 .18903 L
s
.32951 .1812 m
.33295 .18869 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72541 .22381 m
.74133 .22721 L
s
.74133 .22721 m
.75272 .22964 L
s
.5 Mabswid
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33113 .18903 m
.33652 .19213 L
s
.33295 .18869 m
.33652 .19213 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36997 .13379 m
.37594 .12887 L
s
.36592 .14251 m
.36997 .13379 L
s
.37193 .1335 m
.37594 .12887 L
s
.36786 .14222 m
.37193 .1335 L
s
.36373 .15504 m
.36592 .14251 L
s
.33652 .19213 m
.34023 .19148 L
s
.37594 .12887 m
.3799 .12832 L
s
.36567 .15475 m
.36786 .14222 L
s
.3799 .12832 m
.38581 .1316 L
s
.34023 .19148 m
.34405 .18674 L
s
.34405 .18674 m
.34799 .17792 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36357 .16322 m
.36373 .15504 L
s
.36551 .16293 m
.36567 .15475 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38581 .1316 m
.3897 .13926 L
s
.36357 .16322 m
.36527 .17524 L
s
.36551 .16293 m
.36722 .17496 L
s
.38739 .16001 m
.38935 .15975 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36551 .16293 m
.38739 .16001 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36527 .17524 m
.36903 .18291 L
s
.40415 .12534 m
.40608 .13329 L
s
.4039 .1417 m
.40415 .12534 L
s
.36722 .17496 m
.37099 .18264 L
s
.34144 .21999 m
.34899 .21879 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4082 .12899 m
.4124 .12447 L
s
.4124 .12447 m
.42073 .12366 L
s
.40608 .13329 m
.4082 .12899 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4039 .1417 m
.40608 .13329 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36903 .18291 m
.37488 .18623 L
s
.42073 .12366 m
.42488 .12737 L
s
.38712 .17234 m
.38733 .16 L
s
.37099 .18264 m
.37488 .18623 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.38921 .16798 m
.38935 .15975 L
s
.42488 .12737 m
.42693 .13129 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37488 .18623 m
.38087 .18546 L
s
.38705 .17646 m
.38921 .16798 L
s
.38496 .18083 m
.38712 .17234 L
s
.42678 .14361 m
.42693 .13129 L
s
.38496 .18083 m
.38705 .17646 L
s
.444 .12177 m
.4461 .12572 L
s
.44182 .12602 m
.444 .12177 L
s
.38087 .18546 m
.38496 .18083 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44182 .12602 m
.44392 .12997 L
s
.42467 .14379 m
.42683 .1395 L
s
.44392 .12997 m
.4461 .12572 L
s
.40986 .1575 m
.42042 .14827 L
s
.40566 .16204 m
.40986 .1575 L
s
.40353 .16637 m
.40566 .16204 L
s
.42042 .14827 m
.42467 .14379 L
s
.42462 .1479 m
.42678 .14361 L
s
.40341 .17463 m
.40353 .16637 L
s
.255 .412 .882 r
.42888 .16732 m
.43052 .1607 L
s
0 0 0 r
.40981 .16162 m
.42036 .15239 L
s
.4056 .16616 m
.40981 .16162 L
s
.40347 .1705 m
.4056 .16616 L
s
.42036 .15239 m
.42462 .1479 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40341 .17463 m
.40542 .17855 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.43101 .16348 m
.43104 .16067 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40542 .17855 m
.40951 .18228 L
s
.42432 .17267 m
.42653 .16422 L
s
.42633 .18079 m
.42653 .16422 L
s
.40951 .18228 m
.41789 .18151 L
s
.42215 .17699 m
.42432 .17267 L
s
.42432 .17267 m
.42633 .18079 L
s
.41789 .18151 m
.42215 .17699 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44371 .15055 m
.44538 .20024 L
s
.44106 .20051 m
.44371 .15055 L
s
.44322 .20037 m
.44347 .17538 L
s
.5 Mabswid
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.44106 .20051 m
.44314 .20874 L
s
.44314 .20874 m
.44538 .20024 L
s
.5 Mabswid
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ400`00
0000[Jf]0:f][@0<0:f][@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU
41@0[Jf]5`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF
3P3/UPh01`3/UPh30:f][FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0>0?nV4@040000003oYQ40ojHA0?nV
4@H000002@2][Jd2000001D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@0080oj<@2@2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0:0>bF3P80[Jf]IP2`h>H10?ooo`00NP2`h>H20:f][@`0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00`0
ojHA0P2][Jd010000000[Jf]0:f][@0000040:f][@80ojHA0P0000000`2][Jd0ojHA0?nV4@040?nV
4@030000003oYQ40000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU
40030:f][@3oXa00oj<@00/0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL
3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0[Jf]H`2`h>H10?ooo`00M`2`h>H30:f][@h0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA00<0
00002@2][Jd20?nV4@030000003oYQ40000000P0ojHA00<000000:f][@3oYQ401@3oYQ42000001D0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01D0
oj<@1`2][JdH0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh20:f][F40
/>3V0@3oool007D0/>3V0P2][JdA0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
5@3oYQ440:f][@040000002][Jd0[Jf]0?nV4@8000002@3oYQ42000000X0ojHA00<000000?nV4@3o
YQ401@3oYQ400`000000ojHA0?nV4@0C0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0[Jf]4P3lX1000`2][Jd0
mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]
4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00d0ojHA1@0000030:f][@80ojHA
00<0[Jf]0000000000001@3oYQ400`000000ojHA0?nV4@060?nV4@8000002P3oYQ400`000000ojHA
0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@
0?nS400I0?nS40030:f][@3lX100o:0@00H0o:0@1@2][Jd=0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V0P2]
[Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV
4@070?nV4@<0000000<0ojHA0:f][@2][Jd00P0000000`2][Jd0ojHA0?nV4@050?nV4@8000001`3o
YQ400`000000ojHA0?nV4@050?nV4@8000002P3oYQ400`000000ojHA0?nV4@0K0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@00/0o:0@1@2][Jd80?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0ojHA00<0[Jf]
0000002][Jd00P2][Jd00`000000ojHA0?nV4@02000000L0ojHA0P0000080?nV4@030000003oYQ40
ojHA00D0ojHA0P00000:0?nV4@030000003oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100403lX106
0:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_V100kiP@00@0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0[Jf]00<0ojHA0000
003oYQ400`3oYQ4010000000ojHA0000000000070?nV4@8000002@3oYQ400`000000ojHA0?nV4@04
0?nV4@030000003oYQ40ojHA00T0ojHA00<000000?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400F
0?bP40<0[Jf]00<000000?JL3`0000004`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00H0fhX=0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A01<0oj@A102][Jd50?nV4@030000003oYQ40ojHA00@0ojHA0`0000060?nV
4@80000000<0[Jf]0?nV4@3oYQ403P3oYQ400`000000ojHA0?nV4@090?nV4@030000003oYQ40ojHA
01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01T0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0000000300000140mY`?00<0[Jf]0>bF
3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f][@T0
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@<000000`2][Jd00`3oY140
[Jf]0?nV4@050?nV4@8000001P3oYQ43000000H0ojHA0P0000000`2][Jd0ojHA0?nV4@0>0?nV4@03
0000003oYQ40ojHA00P0ojHA0P00000M0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l00P0000000`3fW0l0000000000003000000`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0:0=^:3@80[Jf]D`2`h>H10?ooo`00J02`h>H20:f][@/0kiP@00<0[Jf]0?bP403lX100
3`3lX1000`2][Jd0oj@A0?nT4@0;0?nT4@050:f][@000000[Jf]0:f][@3oY1400P0000020?nT4@03
0:f][@3oYQ40ojHA00@0ojHA00<000000?nV4@3oYQ401P3oYQ42000000H0ojHA0P0000000`2][Jd0
ojHA0?nV4@0I0?nV4@8000007@3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?0080
00001@3fW0l00`2][Jd0000000000002000000P0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0
fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_V100
2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00@0oj@A0P0000000`3oY140[Jf]
0:f][@020:f][@800000103oY14010000000oj@A0?nT4@2][Jd50?nV4@800000203oYQ42000000H0
ojHA0P0000000`2][Jd0ojHA0?nV4@0G0?nV4@<000007P3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400H0?bP4003
0:f][@3fW0l0mY`?00800000203fW0l2000000<0[Jf]1@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P03
0:f][@3KRPd0fhX=00`0fhX=0P2][JeA0;3PiP40oooo001V0;3PiP80[Jf]3@3_V1000`2][Jd0o:0@
0?bP400?0?bP40030:f][@3oY140oj@A0080oj@A0P0000030:f][@<0oj@A0P0000060?nT4@030000
003oY140[Jf]00D0ojHA0P0000080?nV4@8000001@3oYQ42000000030?nV4@2][Jd0ojHA01L0ojHA
00@000000?nV4@000000[Jf]7P3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?0080
0000203fW0l2000000<0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=0>nH40030:f]
[@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd0100000060?nT4@030000003oY140oj@A00D0oj@A
00<000000?nT4@2][Jd01@3oYQ42000000P0ojHA0P0000050?nV4@80000000<0ojHA0:f][@3oYQ40
5P3oYQ401@000000ojHA0000003oYQ40[Jf]00P0ojHA00<000000?nV4@3oYQ404`3oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0
o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?00800000203fW0l2000000L0mY`?00@0[Jf]00000000
00000000403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0^GD;0:f][Dl0/>3V0@3oool0
06@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP400<0?bP40<000000P2][Jd3
0?nT4@8000001@3oY142000000P0oj@A00<000000:f][@3oYQ40103oYQ400`000000ojHA0?nV4@07
0?nV4@8000001@3oYQ42000000030?nV4@2][Jd0ojHA01@0ojHA0P0000001@3oYQ4000000?nV4@3o
YQ40[Jf]00P0ojHA00<000000?nV4@3oYQ404`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3f
W0l0mY`?00800000203fW0l2000000H0mY`?0`000000103/UPh0[Jf]0000002][Jd>0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@1>0;3PiP40oooo001S0;3PiP050:f]
[@3CQ`h0dhL>0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP400:0?bP40<0000000<0[Jf]0?bP402]
[Jd0103oY142000000D0oj@A00<000000?nT4@3oY140203oY1400`2][Jd0ojHA0?nV4@020?nV4@80
00002@3oYQ42000000D0ojHA0P0000000`3oYQ40[Jf]0?nV4@0C0?nV4@040000003oYQ40ojHA0000
00<0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ400`000000ojHA0?nV4@0C0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@
01L0o:0@00<0[Jf]0?JL3`3fW0l00P0000080?JL3`8000001P3fW0l2000000060:f][@3/UPh0k9H>
0000003/UPh0[Jf]0P00000;0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00P2i
M@/20:f][D`0/>3V0@3oool00680/>3V00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40030:f][@3lX100o:0@00H0o:0@0P0000001@3lX100[Jf]0:f][@2][Jd000000080o:0@00<0
[Jf]0?nT4@3oY1400P3oY142000000D0oj@A00<000000?nT4@3oY140203oY1400`2][Jd0ojHA0?nV
4@020?nV4@8000002@3oYQ42000000D0ojHA0P0000000`3oYQ40[Jf]0?nV4@0B0?nV4@040000003o
YQ40ojHA000000@0ojHA00<0[Jf]0?nV4@3oYQ401P3oYQ400`000000ojHA0?nV4@0<0?nV4Bh0[Jf]
5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0
0P0000080?JL3`8000001P3fW0l2000000080:f][@3/UPh0k9H>0>bF3P000000k9H>0000002][Jd2
000000T0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`h>H0
/>3V04T0/>3V0@3oool00640/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@00@0o:0@0P0000000`3lX100[Jf]0:f][@030?bP40040000003lX100o:0@
0:f][@@0oj@A0P0000050?nT4@030000003oY140oj@A00L0oj@A00<0[Jf]0?nV4@3oYQ400`3oYQ40
0`000000ojHA0?nV4@080?nV4@8000001@3oYQ42000000030?nV4@2][Jd0ojHA0140ojHA00@00000
0?nV4@3oYQ4000001@3oYQ400`2][Jd0ojHA0?nV4@050?nV4@030:f][@000000[Jf]00d0[Jf]1`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`02000000T0mY`?00<0
00000?JL3`3fW0l0103fW0l2000000070:f][@3/UPh0k9H>0>bF3P000000k9H>000000030>bF3P<0
[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00D0^GD;00<0[Jf]0;3PiP2`
h>H0B02`h>H10?ooo`00H02`h>H00`2][Jd0dhL>0=>73P040=>73P030:f][@3_V100kiP@00/0kiP@
00<0[Jf]0?bP403lX1000P3lX104000000030:f][@3lX100o:0@00<0o:0@00@000000?bP403lX100
[Jf]103oY142000000D0oj@A00<000000?nT4@3oY1401`3oY1400`2][Jd0ojHA0?nV4@030?nV4@03
0000003oYQ40ojHA00P0ojHA0P0000050?nV4@80000000<0ojHA0:f][@3oYQ400P3oYQ47000000P0
ojHA00<000000?nV4@0000000P3oYQ4<0:f][@030?nV4@000000ojHA01@0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]603oXa000`2][Jd0o:0@0?bP400G0?bP4003
0:f][@3fW0l0mY`?008000002@3fW0l00`000000mY`?0?JL3`040?JL3`80000000<0[Jf]0>bF3P3/
UPh00P3/UPh2000000H0k9H>0P2][Jd01@000000k9H>0>bF3P3/UPh0[Jf]00d0fhX=00<0[Jf]0;Ue
2`2iM@/01P2iM@/00`2][Jd0/>3V0;3PiP170;3PiP40oooo001O0;3PiP030:f][@3CQ`h0dhL>00D0
dhL>00<0[Jf]0>nH403_V1002`3_V100102][Jd0o:0@0?bP400000030:f][@8000001P3lX1001000
0000o:0@0?bP402][Jd40?nT4@800000103oY1400`000000oj@A0?nT4@080?nT4@030:f][@3oYQ40
ojHA00<0ojHA00<000000?nV4@3oYQ40203oYQ42000000D0ojHA1`0000050?nV4@800000103oYQ43
0:f][@030000002][Jd0000000<0[Jf]103oYQ400`2][Jd0ojHA0?nV4@060?nV4@030000003oYQ40
ojHA01<0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l00P000009
0?JL3`030000003fW0l0mY`?00@0mY`?0P0000000`2][Jd0k9H>0>bF3P020>bF3P8000001P3/UPh2
000000050:f][@000000[Jf]0>bF3P2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`
h>H0/>3V04H0/>3V0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;
0>nH40<0000000@0[Jf]0?bP403lX100o:0@0P0000060?bP40040000003lX100o:0@0:f][@@0oj@A
0P0000040?nT4@030000003oY140oj@A00P0oj@A00<0[Jf]0?nV4@3oYQ400`3oYQ400`000000ojHA
0?nV4@080?nV4@8000001@3oYQ42000000030?nV4@2][Jd0ojHA00<0ojHA102][Jd2000000@0[Jf]
0P3oYQ400`000000ojHA000000080?nV4@030000003oYQ40ojHA00H0ojHA00<000000?nV4@3oYQ40
4`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
303oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`02000000T0mY`?
00<000000?JL3`3fW0l0103fW0l2000000030:f][@3/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh0
103/UPh200000080k9H>00<000000:f][@2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]
A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>00<0[Jf]0>nH403_V1002P3_V103000000D0o:0@0P00
00060?bP40040000003lX100o:0@0:f][@@0oj@A0P0000040?nT4@030000003oY140oj@A00P0oj@A
00<0[Jf]0?nV4@3oYQ400P3oYQ42000000X0ojHA0P0000050?nV4@8000001P2][Jd40?nV4@800000
1P3oYQ42000000T0ojHA00<000000?nV4@3oYQ401P3oYQ400`000000ojHA0?nV4@0C0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400F0?nS40P0[Jf]
5P3lX1000`2][Jd0mY`?0?JL3`02000000T0mY`?00<000000?JL3`3fW0l0103fW0l2000000030:f]
[@3/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh2000000@0k9H>00H000000:f][@2][Jd0
[Jf]0=^:3@0000090=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80
[Jf]203CQ`h00`2][Jd0kiP@0>nH40070>nH40040000003_V100[Jf]0:f][@8000001@3lX1020000
00H0o:0@00@000000?bP403lX100[Jf]103oY142000000@0oj@A00<000000?nT4@3oY140203oY140
0`2][Jd0ojHA0?nV4@020?nV4@8000002P3oYQ42000000D0[Jf]0P0000000`3oYQ40[Jf]0?nV4@07
0?nV4@8000001P3oYQ400`000000ojHA0?nV4@070?nV4@800000203oYQ400`000000ojHA0?nV4@0C
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40040:f][@3lX100o:0@0?bP40H0[Jf]403lX1000`2][Jd0mY`?0?JL3`02000000T0mY`?00<0
00000?JL3`3fW0l0103fW0l2000000030:f][@3/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh00`3/
UPh2000000@0k9H>00@000000:f][@3KRPd0fhX=0P2][Jd2000000L0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0
[Jf]0>nH403_V1001@3_V10200000080[Jf]0P3_V102000000D0o:0@0P0000060?bP40040000003l
X100o:0@0:f][@<0oj@A0P0000050?nT4@030000003oY140oj@A00P0oj@A00<0[Jf]0?nV4@3oYQ40
0P3oYQ42000000L0ojHA0`2][Jd2000000H0ojHA0P0000000`2][Jd0ojHA0?nV4@060?nV4@800000
1P3oYQ400`000000ojHA0?nV4@070?nV4@800000203oYQ400`000000ojHA0?nV4@0C0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00L0o:0@1`2][Jd90?bP40030:f][@3fW0l0mY`?00800000103fW0l00`000000mY`?
0?JL3`090?JL3`80000000<0[Jf]0>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P030>bF3P800000
1@3/UPh00`000000fhX=0=^:3@020=^:3@040:f][@0000000000000000D0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0
dhL>00<0[Jf]0>nH403_V100103_V103000000@0kiP@0P0000050?bP408000001P3lX10010000000
o:0@0?bP402][Jd30?nT4@8000001@3oY1400`000000oj@A0?nT4@050?nT4@<0000000<0[Jf]0?nV
4@3oYQ400P3oYQ4200000080ojHA1@2][Jd30?nV4@8000001P3oYQ42000000030:f][@3oYQ40ojHA
00H0ojHA00<000000?nV4@3oYQ401@3oYQ400`000000ojHA0?nV4@070?nV4@800000203oYQ400`00
0000ojHA0?nV4@0C0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00h0o:0@1P2][Jd30?bP40030:f][@3fW0l0mY`?
00800000103fW0l00`000000mY`?0?JL3`090?JL3`80000000<0[Jf]0>bF3P3/UPh00`3/UPh00`00
0000k9H>0>bF3P030>bF3P8000001@3/UPh00`000000fhX=0=^:3@030=^:3@050000002][Jd0fhX=
0=^:3@0000000`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3o
ool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH40020>nH40030000003_
V100[Jf]00800000103_V102000000D0o:0@0P0000060?bP40040000003lX100o:0@0:f][@<0oj@A
0P0000050?nT4@030000003oY140oj@A00D000000P3oY14010000000[Jf]0?nV4@3oYQ420:f][@80
00000P2][Jd80?nV4@8000001P3oYQ42000000030:f][@3oYQ40ojHA00H0ojHA00<000000?nV4@3o
YQ401@3oYQ400`000000ojHA0?nV4@060?nV4@<00000203oYQ400`000000ojHA0?nV4@0C0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01@0o:0@1@2][Jd00`3fW0l00000000000040?JL3`030000003fW0l0mY`?00T0
mY`?0P0000000`2][Jd0k9H>0>bF3P030>bF3P030000003/UPh0k9H>00<0k9H>0P0000050>bF3P03
0:f][@000000fhX=00<0fhX=00D000000=^:3@2][Jd0[Jf]0=^:3@02000000030=^:3@2][Jd0^GD;
00P0^GD;00D0[Jf]08QF1`28EPL0R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd0203CQ`h00`2][Jd0kiP@0>nH400200000080[Jf]00<0kiP@000000000000103_V102
000000D0o:0@0P0000050?bP408000000P3lX100102][Jd0oj@A0?nT4@3oY142000000D0oj@A0`00
00070?nT4@040000002][Jd0[Jf]0:f][@<0ojHA0P0000080?nV4@8000001`3oYQ42000000030:f]
[@3oYQ40ojHA00D0ojHA0P0000070?nV4@030000003oYQ40ojHA00H0ojHA0`0000070?nV4@<00000
503oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0[Jf]0080000000D0[Jf]0?JL3`3fW0l0
mY`?0000000;0?JL3`80000000<0[Jf]0>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P030>bF3P03
0000003/UPh0k9H>00@0k9H>00<0[Jf]0000003KRPd00`3KRPd01@000000fhX=0=^:3@3KRPd0[Jf]
00<0000000<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool0
05X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P050:f][@00000000000000002][Jd00`3_
V102000000@0kiP@0P0000050?bP408000001@3lX10200000080o:0@00@0[Jf]0?nT4@3oY140oj@A
0P0000050?nT4@030000003oY140oj@A00<0oj@A0`2][Jd2000000030:f][@3oYQ40ojHA00<0ojHA
0P0000080?nV4@800000203oYQ42000000L0ojHA00<000000?nV4@3oYQ401`3oYQ400`000000ojHA
0?nV4@040?nV4@040000003oYQ40ojHA000000L0ojHA0`00000D0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0
o:0@00<0[Jf]0?JL3`3fW0l00P0000001@3fW0l0[Jf]0:f][@2][Jd0000000/0mY`?0P0000000`2]
[Jd0k9H>0>bF3P030>bF3P030000003/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh0103/UPh00`2]
[Jd0fhX=0=^:3@030=^:3@030000003KRPd0fhX=0080fhX=0P0000020:f][@T0^GD;00<0[Jf]08QF
1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2GH0/0Uf0;0080
Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h30:f][@030000003_V100kiP@0080kiP@0P0000040>nH4080
00001@3lX102000000D0o:0@0P0000020?bP40040:f][@3oY140oj@A0?nT4@8000001@3oY1400`00
0000oj@A0:f][@030:f][@<0oj@A0P0000000`2][Jd0ojHA0?nV4@030?nV4@8000001`3oYQ430000
00P0ojHA0P0000070?nV4@030000003oYQ40ojHA00P0ojHA00@000000?nV4@3oYQ40ojHA0P000003
0?nV4@030000003oYQ40ojHA00D0ojHA0`00000D0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]
0?JL3`3fW0l00P0000040?JL3`030000002][Jd0[Jf]0080[Jf]1`3fW0l2000000030:f][@3/UPh0
k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh00`000000k9H>0>bF3P040>bF3P030:f][@3KRPd0
fhX=00<0fhX=00<000000=^:3@3KRPd00P3KRPd2000000030=^:3@2][Jd0^GD;00P0^GD;00<0[Jf]
08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;
09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0>nH400000040>nH40800000103_V102000000D0o:0@0P00
00050?bP408000000P3lX100102][Jd0oj@A0?nT4@3oY142000000@0oj@A00<0[Jf]0000002][Jd0
1`3oY142000000030:f][@3oYQ40ojHA00<0ojHA0P0000070?nV4@<000002@3oYQ42000000D0ojHA
00<000000?nV4@3oYQ402P3oYQ43000000D0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ43000001@0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1005`3lX1001@2][Jd0mY`?0?JL3`3fW0l0000000@0mY`?00<000000?JL3`3f
W0l00P3fW0l40:f][@<0mY`?0P0000000`2][Jd0k9H>0>bF3P030>bF3P800000103/UPh00`000000
k9H>0>bF3P040>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P3KRPd200000003
0=^:3@2][Jd0[Jf]0080^GD;00<000000;Ue2`2iM@/00`2iM@/00`2][Jd0R5H708QF1`0208QF1`03
0:f][@2`h>H0/>3V0440/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@060=>73P04
0000003CQ`h0[Jf]0:f][@80kiP@00<000000>nH403_V1000P3_V102000000<0kiP@00<0[Jf]0000
000000001@3lX102000000D0o:0@0P0000020?bP40040:f][@3oY140oj@A0?nT4@800000102][Jd0
0`3oY1400000000000070?nT4@030000003oY140[Jf]00H0ojHA0P0000050?nV4@040000003oYQ40
0000000000T0ojHA00<0[Jf]0000000000000P3oYQ42000001D0ojHA00<0[Jf]0?nV4@3oYQ401@3o
YQ43000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100102][Jd0mY`?0?JL3`3fW0l300000080mY`?
00<000000?JL3`3fW0l01P3fW0l30:f][@80000000<0[Jf]0>bF3P3/UPh0103/UPh00`000000k9H>
0>bF3P020>bF3P030000003/UPh0k9H>00@0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=
0=^:3@020=^:3@80000000L0fhX=0:f][@2iM@/0[Jf]0000002iM@/0000000@0^GD;00<0[Jf]08QF
1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP
2`2][Jd01@3CQ`h01@000000[Jf]0000003CQ`h0[Jf]0080kiP@00<000000>nH403_V1000P3_V102
000000<0kiP@00<0[Jf]000000000000103lX102000000H0o:0@0P0000020?bP40040:f][@3oY140
[Jf]0:f][@8000001@3oY142000000L0oj@A00<000000?nT4@2][Jd01P3oYQ42000000D0ojHA00@0
00000?nV4@0000000000203oYQ40102][Jd0ojHA0?nV4@3oYQ42000001L0ojHA00<0[Jf]0?nV4@3o
YQ401@3oYQ43000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100102][Jd0mY`?0?JL3`3fW0l20000
00040?JL3`0000000000000000/0mY`?0P0000020:f][@D0k9H>00<000000>bF3P3/UPh00P3/UPh0
0`000000k9H>0>bF3P040>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P3KRPd2
000000060=^:3@2][Jd0^GD;0;Ue2`000000[Jf]0`0000020;Ue2`030:f][@28EPL0R5H70080R5H7
00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00@0dhL>
00H000000:f][@3CQ`h000000=>73P2][Jd20>nH40030000003_V100kiP@0080kiP@0P0000030>nH
40030:f][@000000000000@0o:0@0P0000060?bP4080000000@0o:0@0:f][@2][Jd0[Jf]0P3oY142
000000D0oj@A0P0000060?nT4@80000000<0oj@A0:f][@3oYQ401P3oYQ42000000<0ojHA00<00000
0?nV4@3oYQ400P0000080?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ43
000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100102][Jd0mY`?0?JL3`3fW0l2000000<0mY`?00<0
00000?JL3`3fW0l02@3fW0l2000000030:f][@3/UPh0[Jf]0080[Jf]0P3/UPh00`000000k9H>0>bF
3P020>bF3P030000003/UPh0k9H>00@0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:
3@020=^:3@80000000<0fhX=0:f][@2iM@/00P0000000`2iM@/0000000000002000000030;Ue2`2]
[Jd0R5H700<0R5H70P2][Je20;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103C
Q`h01P000000dhL>0=>73P3CQ`h000000:f][@80kiP@00<000000>nH403_V1000P3_V102000000<0
kiP@00<0[Jf]000000000000103lX102000000H0o:0@0P0000000`2][Jd0o:0@0:f][@030?nT4@80
00001@3oY142000000H0oj@A00@000000?nT4@3oY140[Jf]203oYQ42000000030?nV4@000000ojHA
0080ojHA0P0000080?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ430000
01@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1005`3lX100102][Jd0mY`?0?JL3`3fW0l2000000<0mY`?00<00000
0?JL3`3fW0l02@3fW0l2000000030:f][@3/UPh0k9H>0080k9H>0P2][Jd00`000000k9H>0>bF3P02
0>bF3P030000003/UPh0k9H>00@0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2000000<0fhX=0P000000
103KRPd0[Jf]0;Ue2`0000020;Ue2`<000000P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@P2`
h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00<0dhL>00<0[Jf]0000003CQ`h00P3C
Q`h01@000000[Jf]0>nH403_V100000000<0kiP@0P0000040>nH408000001@3lX102000000@0o:0@
0P2][Jd200000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P0000060?nT4@8000001@3oY14010000000
oj@A0?nT4@2][Jd:0?nV4@030000003oYQ40ojHA0080ojHA0P0000080?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ43000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005`3lX100102]
[Jd0mY`?0?JL3`3fW0l2000000<0mY`?00<000000?JL3`3fW0l02@3fW0l2000000030:f][@3/UPh0
k9H>00@0k9H>00<000000:f][@2][Jd00P3/UPh00`000000k9H>0>bF3P040>bF3P030:f][@3KRPd0
fhX=00<0fhX=0P0000030=^:3@80000000@0fhX=0:f][@2iM@/000000P2iM@/3000000030:f][@2i
M@/0000000@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd00000
0P2][Jd2000000@0dhL>00@0[Jf]0>nH403_V10000000`3_V102000000@0kiP@0P0000050?bP4080
000000@0o:0@0:f][@2][Jd0[Jf]0P3lX10200000080o:0@00@0[Jf]0?nT4@3oY140oj@A0P000006
0?nT4@8000001@3oY14010000000oj@A0?nT4@2][Jd?0?nV4@800000203oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA0`00000=0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P0000030?JL3`030000003f
W0l0mY`?00T0mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P030000003/UPh0k9H>0080[Jf]00<0
00000>bF3P3/UPh0103/UPh00`2][Jd0fhX=0=^:3@030=^:3@8000000`3KRPd2000000040=^:3@2]
[Jd0^GD;000000<0^GD;0P0000000`2iM@/0[Jf]0000000408QF1`80[Jf]@P2`h>H10?ooo`00F@2`
h>H01P2][Jd0Uf0;09MP2`2GH0/000000:f][@80dhL>00<000000=>73P3CQ`h00`3CQ`h0102][Jd0
kiP@0>nH400000030>nH40800000103_V102000000D0o:0@0P0000000`2][Jd0o:0@0?bP40030?bP
408000000P3lX1000`2][Jd0oj@A0?nT4@02000000P0oj@A0P0000030?nT4@050000003oY140oj@A
0?nT4@2][Jd03`3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@05
0?nV4@<000003@2][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0@
0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0
mY`?008000000`3fW0l00`000000mY`?0?JL3`090?JL3`80000000<0[Jf]0>bF3P3/UPh0103/UPh0
0`000000k9H>0>bF3P020>bF3P80000000<0[Jf]0>bF3P3/UPh00P3/UPh00`2][Jd0fhX=0=^:3@03
0=^:3@8000000`3KRPd2000000040=^:3@2][Jd0^GD;000000<0^GD;0P0000020;Ue2`0300000028
EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`02
000000<0dhL>00<000000=>73P3CQ`h00`3CQ`h0102][Jd0kiP@0000000000030>nH40800000103_
V102000000<0o:0@0P2][Jd2000000H0o:0@0P0000020?bP40030:f][@3oY140oj@A008000002@3o
Y145000000<0oj@A00<0[Jf]0?nV4@3oYQ403@3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ405P3o
YQ4<0:f][@<00000503oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01D0ojD@302]
[JdH0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P0000030?JL3`030000003f
W0l0mY`?00T0mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P030000003/UPh0k9H>00<0k9H>00<0
00000>bF3P2][Jd00P2][Jd00`3/UPh000000=^:3@040=^:3@8000000`3KRPd200000080fhX=00<0
[Jf]0000002iM@/00P2iM@/200000080^GD;00<000000:f][@28EPL00`28EPL00`2][Jd0/>3V0;3P
iP100;3PiP40oooo001I0;3PiP030:f][@2GH0/00000008000000`3CQ`h00`000000dhL>0=>73P02
0=>73P030:f][@3_V100kiP@008000000`3_V102000000@0kiP@0P0000030:f][@80o:0@0P000006
0?bP408000000P3lX1000`2][Jd0oj@A0?nT4@0200000140oj@A00<0[Jf]0?nV4@3oYQ403@3oYQ42
000000P0ojHA00<0[Jf]0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ43
000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@0080oj<@2P2][Jd>0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P000003
0?JL3`030000003fW0l0mY`?00T0mY`?0P0000000`2][Jd0k9H>0>bF3P040>bF3P030000003/UPh0
k9H>00<0k9H>00<000000>bF3P3/UPh00P3/UPh00`2][Jd000000:f][@040=^:3@8000000`3KRPd2
00000080fhX=00<0[Jf]0000002iM@/00P2iM@/200000080^GD;00<000000:f][@28EPL00`28EPL0
0`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP030:f][@0000000000008000000`3CQ`h00`00
0000dhL>0=>73P020=>73P030:f][@3_V100kiP@008000000`3_V102000000@0kiP@0P0000050?bP
408000001@3lX102000000040?bP40000000o:0@0:f][@80oj@A00<000000?nT4@3oY140403oY140
0`2][Jd0ojHA0?nV4@0=0?nV4@800000203oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3oYQ40
0`2][Jd0ojHA0?nV4@050?nV4@030000003oYQ40000001@0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][Jd40?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P0000030?JL3`030000003fW0l0mY`?00L0mY`?10000000
0`2][Jd0k9H>0>bF3P040>bF3P030000003/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh00`3/UPh2
00000080[Jf]0P3KRPd2000000@0fhX=00D000000=^:3@3KRPd0[Jf]000000030;Ue2`8000000P2i
M@/00`2][Jd0R5H70:f][@0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0[Jf]
0000000000000P0000030=>73P030000003CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1000P000003
0>nH408000000P3_V1020:f][@8000001@3lX102000000D0o:0@0P0000001@3lX10000000?bP402]
[Jd0oj@A008000004P3oY1400`2][Jd0ojHA0?nV4@0=0?nV4@8000001@3oYQ480:f][AP0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ42000001D0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01H0oj<@202][JdG0?bP40030:f][@3fW0l0mY`?00800000203f
W0l00`000000mY`?0?JL3`040?JL3`80000000<0[Jf]0>bF3P3/UPh0103/UPh00`000000k9H>0>bF
3P030>bF3P030000003/UPh0k9H>00<0k9H>0P0000020=^:3@80[Jf]0P0000040=^:3@80000000<0
fhX=0:f][@0000000`2iM@/200000080^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2][Jd0/>3V
0;3PiP100;3PiP40oooo001I0;3PiP030:f][@2GH0/00000008000000P3CQ`h2000000@0dhL>00<0
[Jf]0>nH403_V1000P0000030>nH408000000P2][Jd20>nH408000001@3lX103000000@0o:0@00@0
00000?bP403lX100o:0@1000000C0?nT4@030:f][@3oYQ40ojHA00d0ojHA0P0000050:f][@<0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@060?nV4@030000003oYQ40ojHA01<0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@
00@0[Jf]0?bP403lX100o:0@1`2][Jd@0?bP40030:f][@3fW0l0mY`?00800000203fW0l00`000000
mY`?0?JL3`070?JL3`030:f][@3/UPh0k9H>00<0k9H>00<000000>bF3P3/UPh0103/UPh00`000000
k9H>0>bF3P020>bF3P030:f][@000000fhX=00<0fhX=0P0000040=^:3@80000000<0fhX=0:f][@00
00000`2iM@/200000080^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool0
05T0/>3V00<000000:f][@0000000P0000020=>73P800000103CQ`h00`2][Jd0kiP@0>nH40020000
00<0kiP@0P0000040>nH408000001@3lX103000000<0o:0@0P0000030?bP40030:f][@3oY140oj@A
01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ460:f][@800000203oYQ400`2][Jd0ojHA0?nV4@0J0?nV
4@030:f][@3oYQ40ojHA00H0ojHA00<000000?nV4@3oYQ404`3oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40080?bP
40H0[Jf]2P3lX1000`2][Jd0mY`?0?JL3`02000000P0mY`?00<000000?JL3`3fW0l01`3fW0l00`2]
[Jd0k9H>0>bF3P02000000030>bF3P000000k9H>00D0k9H>00<000000>bF3P3/UPh00P3/UPh00`2]
[Jd000000=^:3@030=^:3@8000000P2][Jd20=^:3@80000000<0fhX=0:f][@000000102iM@/01000
0000^GD;0;Ue2`2][Jd308QF1`030:f][@28EPL0[Jf]0480/>3V0@3oool005P0/>3V00<000000:f]
[@2][Jd00`0000020=>73P800000103CQ`h00`2][Jd0kiP@0>nH4002000000030>nH402][Jd0[Jf]
00800000103_V102000000D0o:0@0P0000001@3lX10000000?bP403lX100000000@0o:0@00<0[Jf]
0?nT4@3oY140503oY140102][Jd0ojHA0?nV4@3oYQ460:f][@H0ojHA0P0000080?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400>0?bP40L0[Jf]0`3l
X1000`2][Jd0mY`?0?JL3`02000000P0mY`?00<000000?JL3`3fW0l01`3fW0l00`2][Jd0k9H>0>bF
3P020>bF3P8000001P3/UPh2000000<0k9H>00<000000=^:3@3KRPd0103KRPd00`000000fhX=0=^:
3@020:f][@80000000<0fhX=0:f][@000000102iM@/010000000^GD;0;Ue2`2][Jd408QF1`80[Jf]
@P2`h>H10?ooo`00F02`h>H00`000000[Jf]09MP2`0300000080dhL>0P0000040=>73P030:f][@3_
V100kiP@0080000000<0[Jf]0>nH403_V1000P0000040>nH408000001@3lX10200000080o:0@0P00
00050?bP40030:f][@3oY140oj@A01<0oj@A1@2][Jd<0?nV4@800000203oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1005@3lX1060:f][@800000203f
W0l00`000000mY`?0?JL3`070?JL3`030:f][@3/UPh0k9H>00/0k9H>00D000000>bF3P3/UPh0k9H>
000000060=^:3@030000003KRPd0fhX=0080fhX=0P0000000`3KRPd0[Jf]000000040;Ue2`040000
002iM@/0^GD;0:f][@D0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F02`h>H00`000000[Jf]
0000000300000080dhL>0P0000040=>73P030:f][@3_V100[Jf]008000000`3_V102000000@0kiP@
0P0000050?bP408000002@3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@@0[Jf]00<0oj@A0:f][@3oYQ40
3P3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P0000020:f][@H0mY`?00<000000?JL3`3fW0l0
1`3fW0l00`2][Jd0k9H>0>bF3P0;0>bF3P8000000P3/UPh00`000000fhX=0=^:3@040=^:3@030000
003KRPd0fhX=0080fhX=0P0000020:f][@030000002iM@/0^GD;0080^GD;00D000000;Ue2`2iM@/0
^GD;0:f][@0408QF1`80[Jf]@@2`h>H10?ooo`00F02`h>H010000000[Jf]0000002GH0/200000080
dhL>0P0000030=>73P040000002][Jd0[Jf]0>nH408000000`3_V1000`000000kiP@0>nH40030>nH
408000000`3lX102000000/0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f][@D0oj@A00<0[Jf]0?nV
4@3oYQ403@3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS
40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l00P0000020?JL3`D0[Jf]00<0mY`?0000
003fW0l0203fW0l00`2][Jd0k9H>0>bF3P0<0>bF3P<0000000<0[Jf]0=^:3@3KRPd0103KRPd00`00
0000fhX=0=^:3@020=^:3@80000000<0fhX=0:f][@000000102iM@/01@000000^GD;0;Ue2`2iM@/0
[Jf]00@0R5H70P2][Je10;3PiP40oooo001H0;3PiP040000002][Jd0000009MP2`8000000P3CQ`h2
00000080dhL>0P000000102][Jd0kiP@0>nH400000040>nH40030000003_V100kiP@00<0kiP@0P00
000@0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd90?nT4@030:f][@3oYQ40ojHA00d0ojHA0P00
00080?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?008000001`3fW0l00`2][Jd00000000000020:f][@H0mY`?00<0
[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@040=^:3@030000003KRPd0fhX=0080fhX=0P00
00001@3KRPd0[Jf]0;Ue2`000000[Jf]0080^GD;00D000000;Ue2`2iM@/000000:f][@0408QF1`80
[Jf]@@2`h>H10?ooo`00F02`h>H010000000[Jf]0000002GH0/200000080dhL>0P0000020=>73P80
000000@0[Jf]0>nH403_V1000000103_V1000`000000kiP@0>nH40020>nH408000004@3lX1000`2]
[Jd0oj@A0?nT4@030?nT4@@0[Jf]3@3oY1400`2][Jd0ojHA0?nV4@0:0?nV4@<000002P3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2]
[Jd0mY`?0?JL3`02000000P0mY`?0P0000020?JL3`@0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF
3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00P3KRPd2000000080=^:3@2][Jd0^GD;
0000002iM@/0[Jf]0;Ue2`0000020;Ue2`030000002][Jd0R5H700<0R5H70P2][Je10;3PiP40oooo
001H0;3PiP040000002][Jd0000009MP2`8000000P3CQ`h2000000050=>73P2][Jd000000000002]
[Jd00P3_V102000000<0kiP@00<000000>nH403_V1000`3_V1000`2][Jd0o:0@0?bP400?0?bP4003
0:f][@3oY140[Jf]00<0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP4080000000<0mY`?00000000
0000203fW0l2000000H0mY`?102][JdA0>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3K
RPd00P3KRPd2000000040=^:3@2][Jd0^GD;00000080^GD;00H0[Jf]0000002iM@/0^GD;0000002]
[Jd408QF1`80[Jf]@@2`h>H10?ooo`00F02`h>H00`000000[Jf]00000002000000030:f][@3CQ`h0
dhL>0080000000D0[Jf]0=>73P3CQ`h000000:f][@020>nH408000000P3_V1000`000000kiP@0>nH
40040>nH40030:f][@3lX100o:0@00h0o:0@0`2][JdE0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0
[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0
[Jf]0?JL3`0000000`0000070?JL3`800000203fW0l00`2][Jd0k9H>0:f][@020:f][@h0k9H>00<0
[Jf]0=^:3@3KRPd00`3KRPd00`000000fhX=0=^:3@020=^:3@80000000@0fhX=0:f][@2iM@/00000
0`2iM@/01@000000^GD;0;Ue2`000000[Jf]00@0R5H70P2][Je10;3PiP40oooo001H0;3PiP030000
002][Jd000000080000000<0[Jf]0=>73P3CQ`h00P0000030=>73P090000002][Jd0kiP@0>nH4000
0000kiP@0000003_V100000000H0kiP@00<0[Jf]0?bP403lX100303lX1020:f][@030?bP402][Jd0
oj@A01D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`030?JL3`D000000P3fW0l2
000000P0mY`?00<0[Jf]0>bF3P3/UPh00P3/UPh20:f][@`0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd0
0`000000fhX=0=^:3@020=^:3@80000000@0fhX=0:f][@2iM@/000000`2iM@/01@000000[Jf]0:f]
[@000000[Jf]00@0R5H70P2][Je10;3PiP40oooo001H0;3PiPD0000000<0[Jf]0=>73P2][Jd00P00
00020=>73P030000003CQ`h0[Jf]0080kiP@00@000000>nH403_V10000001`3_V1000`2][Jd0o:0@
0?bP40090?bP40<0[Jf]0`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0203fW0l4000000P0mY`?00<0[Jf]0>bF3P3/UPh0103/UPh30:f][@T0k9H>
00<0[Jf]0=^:3@3KRPd00`3KRPd010000000fhX=0=^:3@3KRPd3000000050=^:3@2][Jd0^GD;0;Ue
2`0000000P2iM@/2000000030;Ue2`000000[Jf]00@0R5H70P2][Je10;3PiP40oooo001H0;3PiP03
0000002][Jd00000008000000P2][Jd00`3CQ`h00000000000020=>73P030000003CQ`h0[Jf]0080
kiP@00<000000>nH403_V100203_V1000`2][Jd0o:0@0?bP40070?bP4080[Jf]1P3lX1000`2][Jd0
oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0
k9H>0>bF3P070>bF3P<0[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@030=^:3@030000003KRPd0fhX=0080
fhX=0P0000001@3KRPd0[Jf]0;Ue2`2iM@/000000080^GD;0P0000000`2iM@/000000:f][@0408QF
1`80[Jf]@@2`h>H10?ooo`00F02`h>H00`000000Uf0;00000002000000030:f][@3CQ`h0dhL>0080
00000P3CQ`h00`000000dhL>0:f][@020>nH40030000003_V100kiP@00P0kiP@00<0[Jf]0?bP403l
X100103lX1030:f][@P0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@03
0:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/
UPh02P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2000000H0fhX=00D0[Jf]0;Ue2`2i
M@/000000;Ue2`03000000040;Ue2`00000000000:f][@<0R5H70P2][Je10;3PiP40oooo001H0;3P
iP030000002GH0/000000080000000D0[Jf]0000003CQ`h0dhL>000000020=>73P030000002][Jd0
kiP@0080kiP@00<000000>nH403_V100203_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00`0k9H>0`2]
[Jd00`3/UPh0[Jf]0=^:3@040=^:3@8000001`3KRPd0102][Jd0^GD;0000002iM@/3000000040;Ue
2`00000000000:f][@<0R5H70P2][Je10;3PiP40oooo001H0;3PiP030000002GH0/0000000800000
00T0[Jf]0000003CQ`h0dhL>0000003CQ`h000000=>73P2][Jd00`3_V1000`000000kiP@0>nH4008
0>nH40040:f][@3lX100[Jf]0:f][@h0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP
400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh30:f][@@0fhX=0P00
00070=^:3@030:f][@2iM@/0^GD;00@0000000D0^GD;000000000000R5H70:f][@0208QF1`80[Jf]
@@2`h>H10?ooo`00F02`h>H5000000030:f][@000000dhL>0080dhL>0P000000103CQ`h0[Jf]0>nH
403_V102000000T0kiP@0`2][Jd@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@2][Jd0
[Jf]0P3KRPd2000000L0fhX=00@0[Jf]0;Ue2`2iM@/0^GD;0`0000001@2iM@/0000000000028EPL0
[Jf]0080R5H70P2][Je10;3PiP40oooo001H0;3PiPD0000000<0[Jf]0000003CQ`h01@3CQ`h00`2]
[Jd0kiP@0>nH4002000000L0kiP@0P2][Jd00`3_V10000000?bP400@0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f]
[AP0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P040:f][@3KRPd0fhX=
0=^:3@80[Jf]0P0000070=^:3@030:f][@2iM@/0^GD;0080^GD;0P0000000`2iM@/0000000000002
08QF1`040:f][@28EPL0@FWQ0:f][D40/>3V0@3oool005P0/>3V1`0000060=>73P030:f][@3_V100
kiP@008000001@3_V1020:f][@80kiP@00<000000:f][@000000403lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2000000L0fhX=00<0[Jf]
0;Ue2`2iM@/00P2iM@/200000080^GD;00L0000008QF1`28EPL0R5H70:f][@11JN40[Jf]0440/>3V
0@3oool005P0/>3V0P0000000`2GH0/0000000000002000000H0dhL>00<0[Jf]0>nH403_V1000P00
00030>nH4080[Jf]103_V10200000140o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@0>0?nV4@L0[Jf]X`2`h>H50:f][@d0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P0000020:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/00P2i
M@/200000080^GD;00L0000008QF1`28EPL0R5H70:f][@11JN40[Jf]0440/>3V0@3oool005P0/>3V
0P0000000`2GH0/0000000000002000000H0dhL>00<0[Jf]0>nH403_V1000P0000000`3_V100[Jf]
0:f][@070>nH40030000003lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA
0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00<0fhX=0P0000020=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;
0;Ue2`020;Ue2`8000000P2iM@/00`000000R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H0102][Jd000000000002GH0/2000000030:f][@3CQ`h0dhL>00D0dhL>00<0[Jf]0>nH403_V100
0P0000000`2][Jd0kiP@0>nH40070>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
4`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0
mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@030=^:3@800000103KRPd010000000
[Jf]0=^:3@2][Jd50;Ue2`050000002iM@/0^GD;0000002][Jd00`28EPL20:f][D40/>3V0@3oool0
05L0/>3V00@0[Jf]000000000000Uf0;0P0000080=>73P030:f][@3_V100[Jf]008000002P3_V100
0`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l0
0`2][Jd0k9H>0>bF3P0?0>bF3P040:f][@3KRPd0fhX=0=^:3@@000000`3KRPd2000000030=^:3@2]
[Jd0[Jf]00D0^GD;00D000000;Ue2`2iM@/000000:f][@0308QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H01P2][Jd000000000002GH0/000000:f][@P0dhL>0P2][Jd00`3_V10000000000000:0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd2000000<0fhX=0P0000020=^:3@<0
[Jf]0`2iM@/01@000000^GD;0;Ue2`000000[Jf]00<0R5H70P2][Je10;3PiP40oooo001G0;3PiP03
0:f][@00000000000080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h20:f][@80kiP@0P00000:0>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1402@3oY1440:f][M/0/>3V102][Jd<0?JL3`03
0:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd200000080fhX=00@0[Jf]0;Ue2`2i
M@/0[Jf]0P2iM@/01@000000^GD;0;Ue2`000000[Jf]00<0R5H70P2][Je10;3PiP40oooo001G0;3P
iP030:f][@00000000000080Uf0;00<0[Jf]0=>73P3CQ`h00`3CQ`h20:f][@040=>73P2][Jd0kiP@
0>nH408000002@3_V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS
0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00P0fhX=00@00000
0=^:3@3KRPd0[Jf]0`2iM@/00`2][Jd0^GD;000000020;Ue2`8000000`28EPL20:f][D40/>3V0@3o
ool005L0/>3V00<0[Jf]0000000000000P2GH0/00`2][Jd0dhL>0=>73P020=>73P050:f][@3CQ`h0
dhL>0=>73P2][Jd00P3_V102000000T0kiP@00<0[Jf]0?bP403lX100403lX1000`2][Jd0oj@A0?nT
4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/UPh0k9H>0100k9H>00<0[Jf]0=^:3@3KRPd02`3K
RPd00`2][Jd0^GD;0;Ue2`020;Ue2`040:f][@000000^GD;0;Ue2`8000000`28EPL20:f][D40/>3V
0@3oool005L0/>3V00<0[Jf]0000000000000P2GH0/01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00@0dhL>
00@0[Jf]0>nH4000000000002P3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`030000002][Jd0^GD;0080
00000`28EPL00`2][Jd0@FWQ0;3PiP100;3PiP40oooo001G0;3PiP030:f][@00000000000080Uf0;
00@0[Jf]0=>73P2][Jd0[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00`0
o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00<0
^GD;00<000000;Ue2`2][Jd00P00000308QF1`030:f][@11JN40/>3V0400/>3V0@3oool005L0/>3V
00<0[Jf]0000000000000P2GH0/20:f][@L0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@
0?bP400:0?bP4080[Jf]0`2i/ZH30:f][OX0/>3V0`2][Jd01033_K/0[Jf]0:f][@2][Jd;0>bF3P03
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/00`000000^GD;0;Ue2`02000000@0
R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00E`2`h>H00`2][Jd000000000000209MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]
202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;0080^GD;0P0000020;Ue2`80000000D0[Jf]08QF1`28EPL0R5H70:f][@110;3PiP40
oooo001G0;3PiP040:f][@000000000009MP2`80[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`h>H30:f][@l0
`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/00`000000
^GD;0;Ue2`02000000050:f][@28EPL0R5H708QF1`2][Jd0@@2`h>H10?ooo`00E`2`h>H0102][Jd0
00000000002GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP
4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H40:f][@030<K0_02][Jd0`kfk
00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2iM@/0^GD;
00H0^GD;00@000000:f][@28EPL0[Jf]0P28EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001G0;3P
iP060:f][@000000Uf0;0:f][@2GH0/0[Jf]203CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3l
X100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]h02`
h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji^080[Jf]3@3K
RPd00`2][Jd0^GD;0;Ue2`060;Ue2`040000002][Jd0R5H70:f][@80R5H700<0[Jf]0;3PiP2`h>H0
?`2`h>H10?ooo`00E`2`h>H00`2][Jd000000:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>00<0
[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL0R5H70:f][@28EPL0
[Jf]@@2`h>H10?ooo`00E`2`h>H00`2][Jd000000:f][@0209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V100203_V1020:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[0070;jg[0@0[Jf]d02`h>H40:f][@`0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80
[Jf]@@2`h>H10?ooo`00E`2`h>H00`2][Jd0000009MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H708QF1`80
[Jf]@@2`h>H10?ooo`00E`2`h>H00`2][Jd0000009MP2`0209MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1000`3_V1030:f][@040:BNS`2][Jd0/J^M0;6[W@80[Jf]2@2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/102][Jfo0;3PiPD0[Jf]0P37`K`00`2][Jd0
a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01@2n^KP20:f][@@0
_[Vh0P2][Jd50=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D00
/>3V0@3oool005L0/>3V00<0[Jf]0000002GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f]
[@3_V100kiP@0>nH4080[Jf]0P2TWXl00`11JN40Y9j?0:f][@040;6[W@80[Jf]1`2aZid00`2][Jd0
^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2][Jfd0;3PiPH0
[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n
^KP00`2n^KP20:f][@H0_[Vh00@0[Jf]0;B`/@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@000000Uf0;09MP
2`2][Jd02@3CQ`h0102][Jd0kiP@0:f][@2][Jd40:BNS`03045Yh@2TWXl0[Jf]00H0/J^M0P2][Jd5
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/005
0<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0=
0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0102][Jd0];2a0;B`/@11JN420:f][@030=^:
3@2][Jd0^GD;00T0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f]
[@2GH0/0Uf0;09MP2`2][Jd02@3CQ`h20:f][@80@FWQ102TWXl01011JN40Y9j?0:f][@11JN470;6[
W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd70;ji^080@FWQ00D0_[Vh0:f][@2d/;40];2a045Y
h@020;B`/@80[Jf]2P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0
[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P030:f][@2TWXl0Y9j?0080@FWQ0`2TWXl2045Yh@030:BN
S`2][Jd0@FWQ00T0/J^M0P2][Jd00`2aZid0[Jf]0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]202n^KP01@11JN40_[Vh
0;ji^011JN40[Jf]0080];2a00D0@FWQ0;B`/@2d/;40];2a045Yh@020:f][@P0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2
0:f][@03045Yh@2TWXl0Y9j?0080@FWQ0`2TWXl2045Yh@030:BNS`2][Jd0@FWQ00/0/J^M0`2][Jd?
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33
_K<70:f][HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`090<>m^`<0[Jf]00<0`kfk0:f][@2n^KP01`2n^KP2045Yh@<0_[Vh00@0
@FWQ0;B`/@2d/;40@FWQ0P2d/;42045Yh@80];2a00<0[Jf]0;Ue2`2iM@/01@2iM@/0102][Jd0R5H7
08QF1`28EPL20:f][D00/>3V0@3oool005L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@050=>73P<0
[Jf]00<0Y9j?045Yh@2TWXl00P11JN430:BNS`80@FWQ00<0[Jf]0;6[W@11JN40302aZid00`2][Jd0
^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc00P0`kfc202][Jej0;3PiPD0[Jf]3@38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l00d0a/2l00@0@FWQ0<K0_036`;`0[Jf]2033_K/30:f][@@0`kfk00<0[Jf]0;ji
^02n^KP00P2n^KP2045Yh@80_[Vh0P11JN440;ji^0030:f][@2d/;40];2a0080];2a00D0@FWQ0;B`
/@2d/;40];2a045Yh@020:f][@D0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001G
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h0102][Jd0@FWQ08Z5M@2][Jd20:BNS`<0@FWQ
0`2TWXl2045Yh@030:f][@11JN40@FWQ00P0/J^M00D0@FWQ0;6[W@2aZid0/J^M0:f][@050;VbYP<0
[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036
`;`02`36`;`2045Yh@<0a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^02n
^KP00`11JN430;ji^003045Yh@2n^KP0_[Vh00<0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P11JN430;B`
/@03045Yh@2][Jd0[Jf]0080[Jf]0`2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool0
05L0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P040:f][@2:QGD0@FWQ08Z5M@<0[Jf]0`11
JN430:BNS`80@FWQ00<0[Jf]045Yh@11JN401P2aZid2045Yh@050;6[W@11JN40/J^M0;6[W@2][Jd0
202i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f]
[@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0090<K0_0<0@FWQ
1036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00@0@FWQ0;ji^02n^KP0_[Vh0P11JN430;ji^003
045Yh@2n^KP0_[Vh00<0_[Vh00D0[Jf]0;B`/@2d/;40];2a045Yh@030;B`/@040:f][@11JN40];2a
0:f][@80Wi^P00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL20:f][D00/>3V0@3oool005L0/>3V00H0[Jf]
09MP2`2GH0/0Uf0;0:f][@3CQ`h20:f][@08045Yh@2:QGD0@FWQ08Z5M@2][Jd0@FWQ0:BNS`2][Jd2
045Yh@80Y9j?0`11JN400`2][Jd0@FWQ045Yh@050;6[W@80@FWQ0`2aZid00`11JN40/J^M045Yh@0;
0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`01`2n]j`4045Yh@H0_[N/00<0[Jf]0<6j/031^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd_0;3PiQ40[Jf]4@38`K/0
0`2][Jd0b<6k0<S1^`0B0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02`36`;`0
1011JN40a/2l0<K0_036`;`30:f][@`0`kfk0P11JN40102][Jd0_[Vh0;ji^02n^KP2045Yh@<0_[Vh
00<0@FWQ0;ji^02n^KP00`2n^KP00`2][Jd0];2a0;B`/@02045Yh@070;B`/@2][Jd0[Jf]0;B`/@11
JN40];2a0:f][@0309nKX0<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP03
0:f][@2GH0/0Uf0;0080Uf0;0P2][Jd308Z5M@80@FWQ00<0RXEe0:f][@11JN400P2TWXl2045Yh@80
Y9j?0`11JN400`2][Jd0@FWQ045Yh@050;6[W@80@FWQ0`2aZid00`11JN40/J^M045Yh@020;VbYP80
@FWQ2`2i/ZH30:f][@T0_[N/1011JN440;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2][Jd;0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l00/0a/2l00H0@FWQ0:f][@2][Jd0[Jf]0<K0_02][Jd90<>m^`03045Yh@33_K/0
`kfk00<0@FWQ00@0[Jf]0;ji^02n^KP0_[Vh0P11JN420;ji^080@FWQ1@2n^KP0102][Jd0];2a0;B`
/@11JN420:f][@06045Yh@2d/;40];2a045Yh@2d/;40[Jf]1@2OVj000`2][Jd0R5H708QF1`0208QF
1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0
@FWQ08Z5M@0308Z5M@04045Yh@2:QGD0[Jf]045Yh@80Y9j?0P11JN420:f][@80@FWQ00@0Y9j?045Y
h@11JN40@FWQ1@2aZid00`11JN40/J^M0;6[W@030;6[W@80@FWQ102i/ZH3045Yh@T0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd50;jg[080@FWQ1P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]00<0@FWQ
0<K0_036`;`00P36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ1033_K/2045Yh@040:f][@2n^KP0
_[Vh0;ji^080@FWQ0P2n^KP2045Yh@D0_[Vh00@0[Jf]0;B`/@2d/;40@FWQ0P2d/;401P11JN40];2a
0;B`/@11JN40];2a0:f][@H0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3P
iP060:f][@2GH0/0Uf0;09MP2`2][Jd0@FWQ1`2:QGD01@2][Jd0@FWQ0:BNS`2TWXl0@FWQ00<0Y9j?
0P11JN40102TWXl0@FWQ045Yh@11JN450;6[W@03045Yh@2aZid0/J^M00<0/J^M0P11JN440;VbYP80
@FWQ2P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]00<0_[N/045Yh@11JN401P2n]j`00`2][Jd0
`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0
a/2l0<K0_0030<K0_0@0[Jf]1036`;`00`11JN40a/2l0<K0_0020<K0_0030:f][@33_K/0`kfk00<0
`kfk1011JN440<>m^`80@FWQ00@0`kfk0:f][@2n^KP0_[Vh0P11JN420;ji^080@FWQ1@2n^KP20:f]
[@80@FWQ0P2d/;400`11JN40];2a0;B`/@02045Yh@030:f][@2OVj00Wi^P00@0Wi^P00D0[Jf]08QF
1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0@FWQ1`2:
QGD01@2][Jd0@FWQ0:BNS`2TWXl0@FWQ00<0Y9j?0P11JN401@2][Jd0@FWQ045Yh@2aZid0@FWQ00@0
/J^M00<0@FWQ0;6[W@2aZid0102aZid00`11JN40^K:V0;VbYP020;VbYP80@FWQ2P2i/ZH00`2][Jd0
_[N/0;jg[0070;jg[0040:f][@11JN40@FWQ0:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2]
[Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd80<K0
_003045Yh@36`;`0a/2l0080a/2l00<0[Jf]0<>m^`33_K/01@33_K/2045Yh@@0`kfk0P11JN401033
_K/0[Jf]0;ji^02n^KP2045Yh@80_[Vh0P11JN440;ji^004045Yh@2][Jd0];2a045Yh@<0];2a0P11
JN40102d/;40@FWQ045Yh@2][Jd709nKX0040:f][@28EPL0R5H70:f][D00/>3V0@3oool005H0/>3V
00<0[Jf]09MP2`2GH0/00P2][Jd00`11JN40RXEe08Z5M@0508Z5M@050:f][@11JN40Y9j?0:BNS`11
JN400`2TWXl2045Yh@050:BNS`11JN40@FWQ0;6[W@11JN400`2aZid2045Yh@D0/J^M0P11JN440;Vb
YP80@FWQ2P2i/ZH00`2][Jd0_[N/0;jg[0080;jg[080@FWQ00<0_[N/0:f][@2][Jd00P2][Jd00`2n
]j`0[Jf]0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2]
[Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`40:f]
[@`0a/2l00<0@FWQ0<K0_036`;`00P11JN400`2][Jd0`kfk0<>m^`050<>m^`80@FWQ1033_K/2045Y
h@040<>m^`2][Jd0_[Vh0;ji^080@FWQ0P2n^KP2045Yh@80_[Vh00H0[Jf]045Yh@11JN40[Jf]0;B`
/@11JN430;B`/@80@FWQ00@0];2a045Yh@11JN40[Jf]1`2OVj020:f][@0308QF1`2][Jd0/>3V03l0
/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd608Z5M@030:f][@2TWXl0Y9j?0080
@FWQ0`2TWXl2045Yh@80Y9j?0P11JN400`2][Jd0@FWQ0;6[W@020;6[W@80@FWQ1@2aZid2045Yh@@0
^K:V0P11JN490;VbYP@0@FWQ202n]j`2045Yh@D0_[N/102][JdA0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036`;`02`36`;`00`11JN40
a/2l045Yh@020<K0_080@FWQ1P33_K/2045Yh@@0`kfk0P11JN401033_K/0[Jf]0;ji^02n^KP2045Y
h@80_[Vh0P11JN420:f][@80_[Vh00@0@FWQ0:f][@2d/;40@FWQ0P2d/;401011JN40];2a045Yh@2d
/;42045Yh@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@2][Jd0[Jf]@02`h>H10?ooo`00EP2`
h>H20:f][@<0Hf1C00<0[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80@FWQ0P2T
WXl01011JN40/J^M0;6[W@11JN430:f][@80@FWQ1@2aZid2045Yh@@0^K:V0P11JN480;VbYP80@FWQ
00@0[Jf]0;jg[02n]j`0@FWQ0`2n]j`2045Yh@80_[N/0P11JN460;jg[0030:f][@31^[00`KZ`00D0
[Jf]3031^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_003
0:f][@36`;`0a/2l00L0a/2l0P11JN420<K0_003045Yh@36`;`0@FWQ0080a/2l00<0[Jf]045Yh@33
_K/01@33_K/2045Yh@D0`kfk00<0@FWQ0<>m^`2][Jd00`2n^KP00`11JN40_[Vh0:f][@02045Yh@@0
_[Vh00@0@FWQ0:f][@2d/;40];2a0`11JN430;B`/@80@FWQ00<0[Jf]09nKX02OVj00102OVj020:f]
[@03071^N@2][Jd0[Jf]0400/>3V0@3oool005H0/>3V0P2][Jd306=PD`80[Jf]1@2:QGD00`2][Jd0
Y9j?0:BNS`040:BNS`<0@FWQ0P2TWXl01011JN40/J^M0;6[W@11JN430;6[W@80@FWQ1@2aZid2045Y
h@@0^K:V0P11JN480;VbYP80@FWQ00L0[Jf]0;jg[02n]j`0_[N/045Yh@2n]j`0@FWQ00@0_[N/0P11
JN460;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0
[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l0080a/2l00D0@FWQ0<K0_036`;`0a/2l
045Yh@040<K0_080@FWQ0`36`;`00`2][Jd0`kfk045Yh@050<>m^`80@FWQ1@33_K/00`11JN40`kfk
0:f][@030;ji^005045Yh@2][Jd0_[Vh0;ji^011JN40102n^KP00`11JN40[Jf]0;B`/@070;B`/@80
@FWQ00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0Wi^P0:f][@02071^N@80[Jf]?`2`h>H10?ooo`00
EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0[Jf]00@0RXEe00<0[Jf]0:BNS`2TWXl0
1P2TWXl2045Yh@050:BNS`11JN40/J^M0;6[W@11JN400`2aZid00`11JN40/J^M0:f][@020:f][@04
0;6[W@11JN40@FWQ045Yh@@0^K:V0P11JN480;VbYP80@FWQ102n]j`3045Yh@@0_[N/0P11JN40102n
]j`0@FWQ045Yh@11JN420;jg[0030:f][@31^[00`KZ`00X0`KZ`1@2][Jd20<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k0100b<6k1P2][JdA0<O1_0030:f][@36`;`0a/2l0080@FWQ00D0a/2l045Yh@11JN40a/2l045Y
h@040<K0_080@FWQ0`36`;`00`2][Jd0`kfk045Yh@050<>m^`80@FWQ1@33_K/01011JN40`kfk0000
002n^KP20:f][@05045Yh@2n^KP0_[Vh0;ji^011JN40102n^KP00`11JN40[Jf]0;B`/@070;B`/@80
@FWQ00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`040:f][@2:QGD0RXEe0:f][@<0RXEe00<0[Jf]0:BN
S`2TWXl02@2TWXl01011JN40/J^M0;6[W@11JN430;6[W@03045Yh@2aZid0/J^M0080/J^M0P2][Jd0
0`2aZid0@FWQ045Yh@030;VbYP03045Yh@2i/ZH0^K:V00L0^K:V0P11JN450;jg[080@FWQ102n]j`3
045Yh@80_[N/0P11JN400`2n]j`0[Jf]0<6j/00@0<6j/0P0[Jf]4033_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]
0<O1_037`K`04@37`K`00`2][Jd0@FWQ045Yh@040<K0_0<0@FWQ1036`;`00`11JN40a/2l0<K0_002
0<K0_0040:f][@33_K/0`kfk045Yh@@0`kfk0P11JN450<>m^`04045Yh@2][Jd0[Jf]0:f][@80_[Vh
00D0@FWQ0;ji^02n^KP0_[Vh045Yh@030;ji^003045Yh@2n^KP0[Jf]00P0];2a0P11JN400`2][Jd0
Wi^P09nKX0020:f][@<0Wi^P00<0[Jf]071^N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f]
[@1SH5<0Hf1C0080Hf1C00D0[Jf]08Z5M@2:QGD0RXEe0:f][@0208Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00@0[Jf]0;6[W@11JN40@FWQ0`2aZid00`11JN40/J^M0;6[W@040;6[W@<0[Jf]0`2i/ZH00`11
JN40^K:V0;VbYP070;VbYP80@FWQ1@2n]j`2045Yh@@0_[N/0P11JN440;jg[080@FWQ00<0[Jf]0<6j
/031^[000P31^[03045Yh@`0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;0:f][@D0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/0
0`2][Jd0al6l0<O1_0070<O1_0<0@FWQ1`37`K`00`2][Jd0@FWQ045Yh@050<K0_080@FWQ1036`;`2
045Yh@<0a/2l00@0[Jf]0<>m^`33_K/0@FWQ1033_K/2045Yh@<0`kfk0P2][Jd00`11JN40`kfk0:f]
[@030;ji^003045Yh@2n^KP0_[Vh0080_[Vh1011JN400`2n^KP0[Jf]0;B`/@070;B`/@80@FWQ00<0
[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]
06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]
0;6[W@2aZid00P11JN420;6[W@03045Yh@2aZid0/J^M00D0/J^M00<0[Jf]0;VbYP2][Jd00P2][Jd0
0`11JN40^K:V0;VbYP070;VbYP80@FWQ1@2n]j`2045Yh@@0_[N/0P11JN440;jg[080@FWQ00<0[Jf]
0<6j/031^[001031^[04045Yh@T0`KZ`00<0[Jf]0<>m/`33_K<03P33_K<;0:f][A40aKje00<0[Jf]
0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]
0<S1^`38`K/03`38`K/90:f][A80b<6k00<0[Jf]0<O1_037`K`01037`K`4045Yh@T0al6l00<0[Jf]
045Yh@11JN401@36`;`2045Yh@@0a/2l0P11JN430<K0_0040:f][@33_K/0`kfk045Yh@@0`kfk0P11
JN430:f][@80`kfk00<0@FWQ0<>m^`2][Jd00`2n^KP00`11JN40_[Vh0;ji^0070;ji^0030:f][@2d
/;40];2a00L0];2a00<0@FWQ0:f][@2][Jd01P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3o
ool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]2`2TWXl0
0`2][Jd0/J^M0;6[W@020;6[W@03045Yh@2aZid0@FWQ00L0/J^M00<0[Jf]0;VbYP2i/ZH00P2i/ZH0
0`11JN40[Jf]0:f][@070;VbYP80@FWQ1@2n]j`2045Yh@<0_[N/0P11JN460;jg[080@FWQ1P31^[02
045Yh@@0`KZ`1P11JN400`31^[00[Jf]0<>m/`0C0<>m/`030000002][Jd0aKje00@0aKje302][Jd5
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k00<0b<6k302][Jd50<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_011JN401P37`K`2045Yh@T0al6l00<0[Jf]045Yh@11JN401@36`;`2045Yh@@0a/2l0P11JN43
0<K0_0040:f][@33_K/0`kfk045Yh@@0`kfk0P11JN450<>m^`03045Yh@33_K/0[Jf]00<0_[Vh00<0
@FWQ0;ji^02n^KP01`2n^KP00`2][Jd0];2a0;B`/@080;B`/@030:f][@2OVj00Wi^P00D0Wi^P00D0
[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0
[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M00<0
@FWQ0;6[W@2aZid01@2aZid00`2][Jd0^K:V0;VbYP020;VbYP80@FWQ00<0^K:V0:f][@2][Jd00P2]
[Jd40;VbYP03045Yh@2n]j`0_[N/00<0_[N/0P11JN430;jg[080@FWQ1P2n]j`2045Yh@H0`KZ`0P11
JN460<6j/080@FWQ0`31^[000`2][Jd0@FWQ045Yh@02045YhA40`kfc00<0[Jf]0<Fn]@35_[D03`35
_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1^Q40[Jf]4@38
`K/00`2][Jd0b<6k0<S1^`0?0<S1^`<0@FWQ00@0b<6k0:f][@37`K`0@FWQ1P37`K`2045Yh@T0al6l
00<0[Jf]045Yh@11JN401@36`;`2045Yh@@0a/2l0P11JN430<K0_0050:f][@33_K/0`kfk045Yh@33
_K/00`2][Jd2045Yh@D0`kfk00<0@FWQ0<>m^`2][Jd00`2n^KP00`11JN40_[Vh0;ji^0070;ji^003
0:f][@2d/;40];2a00H0];2a0`2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0/J^M
00@0/J^M0P11JN460;6[W@030:f][@2i/ZH0^K:V0080^K:V0P11JN450;VbYP<0[Jf]00<0^K:V0:f]
[@11JN40102n]j`00`11JN40_[N/0;jg[0020;jg[080@FWQ1P2n]j`2045Yh@H0`KZ`0P11JN460<6j
/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`04045Yh@l0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
00d0b<6k0P11JN430<S1^`80@FWQ00<0al6l045Yh@37`K`01@37`K`2045Yh@T0al6l00<0[Jf]045Y
h@11JN401@36`;`2045Yh@@0a/2l0P11JN430<K0_0050:f][@33_K/0@FWQ045Yh@2][Jd01033_K/2
045Yh@<0`kfk0P11JN400`33_K/0[Jf]0;ji^002045Yh@X0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;40
102][Jd0];2a0;B`/@2][Jd709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`
h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]00L0RXEe00<0[Jf]0:BNS`2TWXl00P2][Jd70:BNS`030:f]
[@2aZid0/J^M00@0/J^M0P11JN460;6[W@030:f][@2i/ZH0^K:V0080^K:V0P11JN430;VbYP03045Y
h@2i/ZH0^K:V0080^K:V0`2][Jd2045Yh@80_[N/00<0@FWQ0;jg[02n]j`00P2n]j`2045Yh@H0_[N/
00<0[Jf]045Yh@11JN401@31^[02045Yh@H0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc0080@FWQ
2@33_K<3045Yh@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k0080b<6k00<0@FWQ0<S1^`38`K/02038`K/00`11JN40b<6k0<S1^`030<S1^`030:f]
[@11JN40@FWQ00H0al6l0P11JN490<O1_0030:f][@11JN40@FWQ00D0a/2l0P11JN440<K0_080@FWQ
00<0a/2l0:f][@2][Jd00P2][Jd2045Yh@D0`kfk0P11JN430<>m^`04045Yh@33_K/0`kfk0:f][@d0
_[Vh00<0[Jf]0;B`/@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2][Jd0
L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2]
[Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0102aZid2045Y
h@H0/J^M00<0[Jf]0;VbYP2i/ZH00P2i/ZH01011JN40^K:V045Yh@2i/ZH2045Yh@D0^K:V00@0[Jf]
0;jg[02][Jd0[Jf]0`11JN440;jg[080@FWQ1P2n]j`00`2][Jd0@FWQ045Yh@050<6j/080@FWQ1P31
^[02045Yh@<0`KZ`00<0[Jf]0<>m/`33_K<00P11JN470<>m/`80@FWQ0`33_K<2045Yh@<0`kfc00@0
[Jf]0<Fn]@35_[D0@FWQ0P35_[D2045Yh@l0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/02`38`K/00`11JN40b<6k
0<S1^`050<S1^`03045Yh@2][Jd0b<6k00<0b<6k00<0@FWQ0<S1^`38`K/01`38`K/2045Yh@D0b<6k
00<0[Jf]0<O1_011JN401P37`K`2045Yh@T0al6l00<0[Jf]0<K0_011JN401@36`;`2045Yh@80a/2l
0P2][Jd2045Yh@050:f][@36`;`0a/2l0:f][@33_K/00P11JN450<>m^`80@FWQ0P33_K/01@11JN40
`kfk0<>m^`33_K/0[Jf]00d0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Jd50;B`/@030:f][@2OVj00
Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=PD`2]
[Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M00D0/J^M00<0
@FWQ0;6[W@2aZid00`2aZid01011JN40[Jf]0;VbYP2i/ZH3045Yh@030;VbYP11JN40^K:V0080@FWQ
102i/ZH2045Yh@D0_[N/00D0@FWQ0:f][@2][Jd0[Jf]0;jg[002045Yh@H0_[N/00<0[Jf]045Yh@11
JN401@31^[02045Yh@H0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc0080@FWQ1P33_K<00`11JN40
`kfc0<>m/`040<>m/`05045Yh@33_K<0`kfc0<>m/`2][Jd00P35_[D3045Yh@80aKje0P11JN480<Fn
]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00P38`K/4045Yh@@0b<6k00<0@FWQ0<S1
^`38`K/01P38`K/00`11JN40[Jf]0<S1^`030<S1^`03045Yh@38`K/0b<6k00L0b<6k00<0@FWQ0<S1
^`38`K/01038`K/0102][Jd0al6l045Yh@11JN450<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_007
045Yh@80[Jf]0P36`;`2045Yh@<0a/2l00@0[Jf]0<>m^`11JN40@FWQ1@33_K/4045Yh@@0`kfk00<0
[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][Jd70;B`/@030:f][@2OVj00Wi^P00D0Wi^P
00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f]
[@2TWXl0Y9j?00D0Y9j?0P2][Jd20:BNS`030:f][@2aZid0/J^M00D0/J^M00<0@FWQ0;6[W@2aZid0
0`2aZid00`11JN40^K:V0;VbYP060;VbYP03045Yh@2i/ZH0@FWQ00@0^K:V0P11JN450;jg[005045Y
h@2n]j`0_[N/0;jg[02][Jd00P11JN400`2][Jd0_[N/0;jg[0030;jg[0030:f][@11JN40@FWQ00D0
`KZ`0P11JN460<6j/080@FWQ0`31^[000`2][Jd0`kfc0<>m/`02045Yh@D0`kfc0P11JN470<>m/`04
045Yh@33_K<0`kfc0:f][@80aKje00<0@FWQ0<Fn]@35_[D01035_[D2045Yh@D0aKje00<0@FWQ0<Fn
]@11JN400`35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h0180al6h1@11JN470<O1
^PL0@FWQ1`37`KX00`2][Jd0b<6k0<S1^`03045Yh@<0b<6k0P11JN400`38`K/0@FWQ045Yh@080<S1
^`03045Yh@2][Jd0b<6k0080b<6k0`11JN470<S1^`80@FWQ1P38`K/0102][Jd0al6l045Yh@11JN45
0<O1_080@FWQ2@37`K`00`2][Jd0a/2l0<K0_0050:f][@80@FWQ1036`;`2045Yh@<0a/2l00<0[Jf]
045Yh@11JN401P33_K/2045Yh@H0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP30:f][@P0];2a00<0[Jf]
09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001H0;3PiP030:f][@1SH5<0[Jf]
00L0RXEe00<0[Jf]0:BNS`2TWXl01`2TWXl30:f][@L0/J^M00<0@FWQ0;6[W@2aZid00`2aZid00`11
JN40^K:V0;VbYP070;VbYP80@FWQ1@2i/ZH00`11JN40_[N/0;jg[0030;jg[003045Yh@2n]j`0_[N/
0080_[N/0P11JN400`2n]j`0[Jf]0:f][@020:f][@040;jg[02][Jd0@FWQ045Yh@D0`KZ`0P11JN46
0<6j/003045Yh@31^[00`KZ`0080`KZ`00<0[Jf]0<>m/`33_K<00P11JN450<>m/`80@FWQ1`33_K<0
1011JN40`kfc0<>m/`2][Jd20<Fn]@03045Yh@35_[D0aKje00D0aKje00<0@FWQ0<Fn]@35_[D01035
_[D00`11JN40aKje0<Fn]@020<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03@37
`KP5045Yh@80al6h00<0[Jf]0<O1^P11JN400P11JN480<O1^P03045Yh@37`KX0al6j00P0al6j00<0
[Jf]0<S1^`38`K/00P11JN450<S1^`<0@FWQ2038`K/3045Yh@<0b<6k0`11JN470<S1^`80@FWQ1P38
`K/0102][Jd0al6l045Yh@11JN450<O1_080@FWQ1`37`K`50:f][@D0a/2l0P11JN440<K0_080@FWQ
0`36`;`00`2][Jd0@FWQ045Yh@060<>m^`80@FWQ1P33_K/01@2][Jd0_[Vh0;ji^02n^KP0@FWQ00P0
_[Vh0P2][Jd:0;B`/@030:f][@2OVj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00
F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl20:f][@L0/J^M00<0@FWQ0;6[W@2aZid0
0P2aZid00`11JN40^K:V0;VbYP0>0;VbYP03045Yh@2n]j`0_[N/00<0_[N/00<0@FWQ0;jg[02n]j`0
0P2n]j`2045Yh@D0_[N/00<0[Jf]045Yh@11JN400P2][Jd40<6j/080@FWQ1P31^[000`11JN40`KZ`
0<6j/0020<6j/0030:f][@33_K<0`kfc0080@FWQ1033_K<2045Yh@/0`kfc00@0[Jf]0<Fn]@35_[D0
@FWQ1`35_[D00`11JN40aKje0<Fn]@090<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037
`KP03`37`KP2045Yh@<0al6h00<0[Jf]0<O1^P37`KX00P11JN480<O1^P03045Yh@37`KX0al6j00P0
al6j00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Yh@P0b<6k0`11JN430<S1^`<0@FWQ1`38`K/2045Y
h@H0b<6k00@0[Jf]0<O1_011JN40@FWQ1@37`K`2045Yh@80al6l1@2][Jd20<O1_0030:f][@36`;`0
a/2l00D0a/2l00<0@FWQ0<K0_036`;`00`36`;`3045Yh@80a/2l0P11JN470<>m^`80@FWQ1P33_K/0
0`2][Jd0_[Vh0;ji^002045Yh@H0_[Vh0P2][Jd00`2n^KP0[Jf]0;B`/@090;B`/@030:f][@2OVj00
Wi^P00D0Wi^P0P2][Je20;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`090:BN
S`030:f][@2aZid0[Jf]0080[Jf]102aZid01011JN40/J^M0;6[W@2aZid2045YhA00^K:V00<0[Jf]
045Yh@11JN400P2n]j`00`11JN40_[N/0;jg[0030;jg[0<0@FWQ1@2n]j`2045Yh@80`KZ`102][Jd2
045Yh@030:f][@31^[00`KZ`00<0`KZ`00<0@FWQ0<6j/031^[000P31^[000`2][Jd0`kfc0<>m/`02
045Yh@@0`kfc0P11JN4;0<>m/`030:f][@35_[D0aKje00P0aKje00<0@FWQ0<Fn]@35_[D02@35_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN430<O1^0060:f][@37`KX0
al6j045Yh@37`KX0@FWQ1`37`KX00`11JN40al6j0<O1^P080<O1^P040:f][@38`K/0@FWQ045Yh@L0
b<6k0P11JN480<S1^`<0@FWQ0`38`K/3045Yh@H0b<6k0P11JN470<S1^`030:f][@37`K`0@FWQ00<0
@FWQ0P37`K`00`2][Jd0@FWQ045Yh@020:f][@L0al6l00<0[Jf]0<K0_011JN401@36`;`00`11JN40
a/2l0<K0_0030<K0_080@FWQ00@0a/2l045Yh@11JN40[Jf]2033_K/2045Yh@H0`kfk00<0[Jf]0;ji
^02n^KP00P11JN440;ji^080[Jf]0`2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P
00@0Wi^P0P2][Je20;3PiP40oooo001J0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]0`2aZid00`11JN40/J^M0;6[W@02045YhA00
^K:V00<0[Jf]0;jg[02n]j`00P11JN460;jg[0<0@FWQ1@2n]j`2045Yh@H0`KZ`0P11JN400`31^[00
[Jf]0:f][@030:f][@03045Yh@2][Jd0`KZ`0080`KZ`00<0[Jf]0<>m/`33_K<00P11JN440<>m/`80
@FWQ2`33_K<00`2][Jd0aKje0<Fn]@080<Fn]@03045Yh@35_[D0aKje00T0aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00?0<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P02045Yh@L0
al6j00<0@FWQ0<O1^P37`KX02037`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ2038`K/00`11
JN40b<6k045Yh@030<S1^`03045Yh@38`K/0@FWQ00H0b<6k0P11JN470<S1^`<0@FWQ1@2][Jd01037
`K`0@FWQ045Yh@11JN440<O1_007045Yh@37`K`0al6l0<O1_02][Jd0a/2l045Yh@050<K0_004045Y
h@36`;`0a/2l0<K0_0<0@FWQ1036`;`00`2][Jd0`kfk0<>m^`060<>m^`80@FWQ1P33_K/01P2][Jd0
_[Vh0;ji^02n^KP0@FWQ0;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00
Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5
M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@050;6[W@11JN40@FWQ
0;6[W@11JN40402i/ZH00`2][Jd0_[N/0;jg[0060;jg[0@0@FWQ00<0_[N/045Yh@2n]j`00P2n]j`2
045Yh@L0`KZ`00<0@FWQ0<6j/031^[001@31^[000`11JN40`KZ`0:f][@050:f][@80@FWQ1033_K<2
045Yh@/0`kfc00<0[Jf]0<Fn]@35_[D01P35_[D3045Yh@/0aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00?0<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P02045Yh@L0al6j00<0@FWQ
0<O1^P37`KX02037`KX0102][Jd0b<6k045Yh@11JN470<S1^`80@FWQ2038`K/00`11JN40b<6k045Y
h@020<S1^`80@FWQ0P38`K/00`11JN40b<6k0<S1^`030<S1^`80@FWQ1038`K/60:f][@H0al6l0`11
JN430<O1_080@FWQ0`37`K`00`2][Jd0a/2l045Yh@030<K0_080@FWQ3036`;`00`2][Jd0`kfk0<>m
^`050<>m^`80@FWQ1P33_K/0102][Jd0_[Vh0;ji^02n^KP20:f][@P0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX00309nKX0030:f][@2`h>H0/>3V0480/>3V0@3oool005`0/>3V00<0
[Jf]08Z5M@2:QGD00`2:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00L0/J^M0`2]
[Jd00`2aZid0@FWQ0;VbYP0?0;VbYP030:f][@2n]j`0_[N/00P0_[N/0P11JN420;jg[005045Yh@2n
]j`0_[N/045Yh@2][Jd01`31^[02045Yh@H0`KZ`00<0@FWQ0<6j/031^[000P31^[000`2][Jd0`kfc
0<>m/`02045Yh@@0[Jf]0P11JN4;0<>m/`030:f][@35_[D0aKje00@0aKje1011JN4<0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03`37`KP2045Yh@@0al6h00@0[Jf]0<O1^P37`KX0
al6j0P11JN460<O1^P03045Yh@37`KX0al6j00P0al6j00@0[Jf]0<S1^`11JN40@FWQ1`38`K/2045Y
h@L0b<6k0P11JN401038`K/0[Jf]045Yh@38`K/2045Yh@80b<6k00<0@FWQ0<S1^`38`K/00P38`K/0
0`2][Jd0@FWQ045Yh@040:f][@<0b<6k00<0[Jf]0<O1_037`K`01P37`K`3045Yh@<0al6l0P11JN43
0<O1_0030:f][@36`;`0a/2l00<0@FWQ3P36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ1P33_K/0
102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2O
Vj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]
0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00=
0;jg[080@FWQ00<0_[N/0:f][@31^[001P31^[02045Yh@H0`KZ`00<0@FWQ0<6j/031^[000P31^[00
0`2][Jd0`kfc0<>m/`02045Yh@@0`kfc0P11JN470:f][@05045Yh@33_K<0`kfc0<>m/`2][Jd01035
_[D4045Yh@T0aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h00l0al6h0P11JN440<O1^0040:f][@37`KX0al6j0<O1^P80@FWQ1P37`KX00`11JN40al6j
0<O1^P080<O1^P030:f][@38`K/0b<6k0080@FWQ1P38`K/2045Yh@L0b<6k0P11JN401038`K/0[Jf]
045Yh@38`K/2045Yh@80[Jf]00<0@FWQ0:f][@2][Jd00P2][Jd00`38`K/0@FWQ045Yh@070<S1^`03
0:f][@37`K`0al6l00H0al6l0P11JN400`37`K`0@FWQ0<O1_0020<O1_005045Yh@37`K`0al6l0<O1
_02][Jd04`36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ1@33_K/30:f][@`0_[Vh00<0[Jf]0;B`
/@2d/;402@2d/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@03
0:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/003045Yh@31^[00@FWQ00@0
`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc0080@FWQ1@33_K<2045Yh@H0`kfc00<0@FWQ0:f][@2]
[Jd0102][Jd4045Yh@/0aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h00l0al6h0P11JN440<O1^0030:f][@37`KX0al6j0080al6j0P11JN450<O1^P03
045Yh@37`KX0al6j00P0al6j00<0[Jf]0<S1^`38`K/00P38`K/4045Yh@80b<6k0P11JN450<S1^`80
[Jf]00H0@FWQ0:f][@2][Jd0[Jf]045Yh@2][Jd2045Yh@80b<6k00<0@FWQ0<S1^`38`K/00`38`K/2
045Yh@L0b<6k00<0[Jf]0<O1_037`K`01P37`K`2045Yh@80al6l1011JN430<O1_0030:f][@36`;`0
a/2l0140a/2l00<0[Jf]0<>m^`33_K/00`33_K/4045Yh@80`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<
0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2]
[Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f]
[@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050<6j/003045Yh@31^[00`KZ`
0080@FWQ0P31^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<00P11JN450<>m/`80@FWQ1P33_K<2045Y
h@030<>m/`000000[Jf]0080aKje0P11JN400`35_[D0[Jf]0:f][@0:0:f][@03045Yh@35_[D0aKje
0080aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00?0<O1^080@FWQ1037`KP00`2]
[Jd0al6j0<O1^P020<O1^P80@FWQ1@37`KX2045Yh@T0al6j00<0[Jf]0<S1^`38`K/00`38`K/30:f]
[@@0@FWQ1@2][Jd20<S1^`06045Yh@38`K/0b<6k0:f][@11JN40b<6k0P11JN420<S1^`03045Yh@38
`K/0b<6k00<0b<6k0P11JN470<S1^`030:f][@37`K`0al6l00@0al6l1011JN4:0<O1_0030:f][@36
`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][@@0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP00`2][Jd0];2a0;B`/@090;B`/@80[Jf]B@2`h>H10?ooo`00H@2`h>H20:f][@X0Y9j?00<0[Jf]
0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j/031^[000P31^[02045Yh@H0`KZ`00<0[Jf]
0<>m/`33_K<00P11JN450<>m/`80@FWQ1P33_K<2045Yh@80`kfc00@0[Jf]0<Fn]@35_[D0@FWQ1`35
_[D00`11JN40aKje0<Fn]@040<Fn]@03045Yh@2][Jd0[Jf]00h0[Jf]3036_kL00`2][Jd0al6h0<O1
^00?0<O1^080@FWQ1037`KP00`2][Jd0al6j0<O1^P020<O1^P80@FWQ1@37`KX2045Yh@l0[Jf]1@38
`K/2045Yh@L0b<6k00L0@FWQ0<S1^`38`K/0[Jf]045Yh@38`K/0@FWQ00@0b<6k00<0@FWQ0<S1^`38
`K/00P38`K/2045Yh@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d
/;40202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP030:f][@2TWXl0Y9j?00P0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f][@2n]j`0
4@2n]j`00`2][Jd0`KZ`0<6j/0050<6j/003045Yh@31^[00`KZ`00X0`KZ`00<0[Jf]045Yh@11JN40
0P11JN460<>m/`80@FWQ1@33_K<01@11JN40`kfc0<>m/`33_K<0[Jf]0080aKje00<0@FWQ0<Fn]@35
_[D01@35_[D00`11JN40aKje0<Fn]@040<Fn]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36
_kL02@36_kLN0:f][@80@FWQ2@2][Jd2045Yh@D0[Jf]0P11JN490<O1^P030:f][@38`K/0b<6k00P0
b<6k00<0@FWQ0<S1^`38`K/01P38`K/01@11JN40b<6k0<S1^`2][Jd0b<6k0080@FWQ1038`K/00`11
JN40b<6k0<S1^`020<S1^`80@FWQ1`38`K/0102][Jd0al6l0<O1_011JN4A0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]
0;B`/@2d/;401P2d/;420:f][D/0/>3V0@3oool006<0/>3V0P2][Jd80:BNS`030:f][@2aZid0/J^M
00`0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH30:f][A40_[N/00<0[Jf]0<6j/031^[001@31^[000`11
JN40`KZ`0<6j/00:0<6j/0030:f][@33_K<0`kfc00T0`kfc0P11JN430<>m/`03045Yh@33_K<0`kfc
0080`kfc00@0[Jf]0<Fn]@35_[D0@FWQ1`35_[D00`11JN40aKje0<Fn]@040<Fn]@03045Yh@35_[D0
aKje0080aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00?0<O1^080@FWQ1037`KP0
0`2][Jd0al6j0<O1^P020<O1^P80@FWQ1@37`KX2045Yh@D0al6j00D0@FWQ0<O1^P37`KX0al6j0:f]
[@020<S1^`80@FWQ1P38`K/00`11JN40b<6k0<S1^`050<S1^`06045Yh@38`K/0b<6k0<S1^`2][Jd0
b<6k0P11JN440<S1^`<0@FWQ0P38`K/2045Yh@L0b<6k00@0[Jf]0<O1_037`K`0@FWQ4@37`K`00`2]
[Jd0a/2l0<K0_00>0<K0_0@0[Jf]3P33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a
00D0];2a00<0[Jf]0;3PiP2`h>H0B`2`h>H10?ooo`00I@2`h>H20:f][@H0Y9j?00<0[Jf]0;6[W@2a
Zid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0
`KZ`0<6j/0050<6j/003045Yh@31^[00`KZ`00X0`KZ`00<0[Jf]0<>m/`33_K<02`33_K<3045Yh@D0
`kfc00@0[Jf]0<Fn]@35_[D0@FWQ1P35_[D2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2]
[Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN440<O1^0030:f][@37`KX0al6j
0080al6j0P11JN450<O1^P<0@FWQ0`37`KX00`11JN40al6j045Yh@020<O1^P030:f][@38`K/0b<6k
0080@FWQ1P38`K/00`11JN40b<6k0<S1^`050<S1^`@0@FWQ00@0[Jf]0<S1^`11JN40@FWQ0P38`K/3
045Yh@D0b<6k0P11JN460<S1^`040:f][@37`K`0@FWQ045YhA40al6l00<0[Jf]0<K0_036`;`02@36
`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d
/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/00<0[Jf]
0<6j/031^[001@31^[000`11JN40`KZ`0<6j/00:0<6j/0030:f][@33_K<0`kfc01<0`kfc00@0[Jf]
0<Fn]@35_[D0aKje1P11JN400`35_[D0@FWQ0<Fn]@040<Fn]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN440<O1^0030:f][@37`KX0al6j0080al6j0P11
JN450<O1^P<0@FWQ1037`KX2045Yh@80al6j00D0[Jf]0<S1^`38`K/0b<6k045Yh@050<S1^`03045Y
h@38`K/0b<6k00<0b<6k1011JN430<S1^`030:f][@38`K/0b<6k00/0b<6k0P11JN460<S1^`040:f]
[@37`K`0@FWQ045YhA40al6l00<0[Jf]0<K0_036`;`01@36`;`40:f][@L0a/2l00<0[Jf]0<>m^`33
_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]D02`h>H10?oo
o`00J@2`h>H20:f][@80Y9j?00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0>0;VbYP03
0:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00`KZ`00D0`KZ`00<0@FWQ0<6j/031
^[002P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00P0aKje00<0@FWQ0<Fn]@35
_[D00`35_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00?0<O1^080
@FWQ1037`KP00`2][Jd0al6j0<O1^P020<O1^P80@FWQ1@37`KX2045Yh@030<O1^P11JN40al6j0080
al6j00D0@FWQ0<O1^P37`KX0al6j0:f][@040<S1^`D0@FWQ3@38`K/00`2][Jd0b<6k0<S1^`0;0<S1
^`80@FWQ1P38`K/0102][Jd0al6l045Yh@11JN4A0<O1_0030:f][@36`;`0a/2l00D0[Jf]2`36`;`0
0`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]DP2`
h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00;
0;jg[0@0[Jf]00<0_[N/0:f][@31^[000`31^[02045Yh@030<6j/011JN40`KZ`00/0`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0>0<Fn]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN440<O1^0030:f][@37`KX0al6j0080al6j0P11JN42
0<O1^PD0@FWQ0P37`KX3045Yh@@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0<
0<S1^`80@FWQ1@38`K/0102][Jd0@FWQ045Yh@11JN4?0<O1_0D0[Jf]4036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][JeC0;3PiP40oooo001]0;3PiP80[Jf]3@2aZid0
0`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00l0_[N/1@2][Jd30<6j/080@FWQ3031^[00
102][Jd0`kfc0<>m/`11JN4B0<>m/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03`37`KP2045Yh@@0al6h00@0[Jf]0<O1^P37`KX0al6j
0P11JN4A0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03@38`K/00`11JN40b<6k
0<S1^`030<S1^`040:f][@11JN40al6l045Yh@X0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100
a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00
K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f]
[@31^[00`KZ`0<6j/0L0[Jf]2P31^[00102][Jd0`kfc045Yh@11JN4B0<>m/`030:f][@35_[D0aKje
00h0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03`37`KP2045Y
h@@0al6h00@0[Jf]0<O1^P37`KX0al6j0P11JN4A0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]
0<S1^`38`K/03P38`K/01011JN40b<6k0<S1^`38`K/2045Yh@80al6l00<0@FWQ0<O1_037`K`00P37
`K`60:f][@L0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00L0_[Vh0`2][JeG0;3PiP40oooo001a0;3PiP<0[Jf]202aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[002031^[070:f][@<0`KZ`00@0[Jf]
0<>m/`33_K<0@FWQ4P33_K<00`2][Jd0aKje0<Fn]@0>0<Fn]@80@FWQ1035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN440<O1^0040:f][@37`KX0al6j0<O1^P80@FWQ
4@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00l0b<6k0`11JN401038`K/0[Jf]
0<O1_037`K`50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`03
0:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2][Jd0^K:V
0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f][A80`kfc
00<0[Jf]0<Fn]@35_[D03P35_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00?0<O1^080@FWQ1037`KP01@2][Jd0al6j0<O1^P37`KX0@FWQ0180al6j00<0[Jf]0<S1^`38
`K/05038`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00P2n^KP30:f][E`0/>3V0@3oool007H0/>3V
0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]2`33_K<00`2][Jd0aKje0<Fn]@0>0<Fn]@80
@FWQ1035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00l0al6h0P11JN440<O1^005
0:f][@37`KX0al6j0<O1^P11JN404P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k
00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@03
0;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03`37`KP2045Yh@@0al6h00@0[Jf]0<O1^P37
`KX0@FWQ4`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/3
0:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j
/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]3035_[D00`11JN40aKje0<Fn]@020<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP03`37`KP2045Yh@@0al6h00@0[Jf]0<O1
^P11JN40@FWQ4`37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool0
07h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0B0<>m/`030000002][Jd0aKje00@0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP03@37`KP:045YhAD0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f]
[@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`03
0:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_003
0:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje
0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102]
[Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<
0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f]
[@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P03
0:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`
0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l
0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0
[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0
[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0
[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3P
iPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00
`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f]
[@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL0
5@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
2@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I1
0:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48084 .33785 m
.48247 .34017 L
s
.47918 .34005 m
.48084 .33785 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48082 .34236 m
.48247 .34017 L
s
.47918 .34005 m
.48082 .34236 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57169 .33757 m
.58805 .33674 L
s
.5 Mabswid
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45627 .33668 m
.4628 .33705 L
s
.4628 .33705 m
.46605 .33947 L
s
.46605 .33947 m
.46767 .34181 L
s
.46763 .34859 m
.46767 .34181 L
s
.58805 .33674 m
.59133 .33881 L
s
.58805 .33674 m
.59296 .33871 L
s
.45299 .33874 m
.45627 .33668 L
s
.48076 .35366 m
.48227 .38097 L
s
.47896 .38085 m
.48076 .35366 L
s
.46599 .34851 m
.46764 .34633 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46597 .35077 m
.46763 .34859 L
s
.59133 .33881 m
.59463 .34313 L
s
.45134 .3409 m
.45299 .33874 L
s
.4627 .35061 m
.46599 .34851 L
s
.44976 .33628 m
.45134 .3409 L
s
.44968 .34533 m
.44976 .33628 L
s
.59296 .33871 m
.59625 .34303 L
s
.46268 .35287 m
.46597 .35077 L
s
.44968 .34533 m
.45134 .3409 L
s
.45449 .35469 m
.4627 .35061 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59463 .34313 m
.59629 .34755 L
s
.45447 .35696 m
.46268 .35287 L
s
.59625 .34303 m
.59792 .34745 L
s
.48062 .38091 m
.48069 .36726 L
s
.46588 .36438 m
.46755 .35992 L
s
.46749 .369 m
.46755 .35992 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4512 .35676 m
.45449 .35469 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57661 .33735 m
.57693 .385 L
s
.57825 .33727 m
.57857 .38492 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59629 .34755 m
.59798 .35425 L
s
.59792 .34745 m
.59961 .35414 L
s
.6059 .33556 m
.61716 .33466 L
s
.43518 .3375 m
.43836 .34227 L
s
.43038 .33484 m
.43518 .3375 L
s
.46422 .36657 m
.46588 .36438 L
s
.46588 .36438 m
.46749 .369 L
s
.45118 .35903 m
.45447 .35696 L
s
.42718 .33457 m
.43038 .33484 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46092 .36868 m
.46422 .36657 L
s
.44955 .35893 m
.4512 .35676 L
s
.59798 .35425 m
.59809 .36562 L
s
.42395 .33656 m
.42718 .33457 L
s
.42235 .33641 m
.42718 .33457 L
s
.59961 .35414 m
.59971 .36551 L
s
.44953 .36121 m
.45118 .35903 L
s
.44951 .36348 m
.44955 .35893 L
s
.48059 .38547 m
.48227 .38097 L
s
.45437 .36832 m
.46092 .36868 L
s
.47896 .38085 m
.48059 .38547 L
s
.4207 .3408 m
.42395 .33656 L
s
.44951 .36348 m
.45112 .36585 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45112 .36585 m
.45437 .36832 L
s
.41911 .34066 m
.42235 .33641 L
s
.59652 .37255 m
.59809 .36562 L
s
0 0 0 r
.64448 .32423 m
.64295 .32764 L
s
.255 .412 .882 r
.4366 .35577 m
.43819 .35816 L
s
.43496 .35792 m
.4366 .35577 L
s
.57198 .3852 m
.58844 .38443 L
s
.43817 .36044 m
.43819 .35816 L
s
.59815 .37245 m
.59971 .36551 L
s
.61255 .35321 m
.61424 .3599 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41902 .34747 m
.4207 .3408 L
s
.43488 .36475 m
.43817 .36044 L
s
.43496 .35792 m
.43655 .36032 L
s
.41743 .34732 m
.41911 .34066 L
s
.59493 .37721 m
.59652 .37255 L
s
.59656 .37711 m
.59815 .37245 L
s
.40026 .33188 m
.41127 .33307 L
s
.5917 .38197 m
.59493 .37721 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.59333 .38187 m
.59656 .37711 L
s
.58844 .38443 m
.5917 .38197 L
s
.58844 .38443 m
.59333 .38187 L
s
.43163 .36679 m
.43488 .36475 L
s
.41896 .35202 m
.41902 .34747 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61424 .3599 m
.61751 .3642 L
s
.60623 .36735 m
.6127 .36687 L
s
.61235 .33506 m
.6127 .36687 L
s
.61074 .33519 m
.61109 .36699 L
s
.41737 .35188 m
.41743 .34732 L
s
.4268 .3664 m
.43163 .36679 L
s
.41896 .35202 m
.42047 .359 L
s
.63943 .33479 m
.6441 .332 L
s
.63792 .3395 m
.63943 .33479 L
s
.61751 .3642 m
.62075 .36622 L
s
.41737 .35188 m
.41888 .35886 L
s
.641 .33462 m
.6441 .332 L
s
.63949 .33933 m
.641 .33462 L
s
.63792 .3395 m
.63798 .34405 L
s
.6441 .332 m
.64879 .33146 L
s
.42362 .36385 m
.4268 .3664 L
s
.42202 .36371 m
.4268 .3664 L
s
.63949 .33933 m
.63956 .34389 L
s
.42047 .359 m
.42362 .36385 L
s
.6239 .36138 m
.62547 .35896 L
s
.62547 .35896 m
.62709 .36109 L
s
.6239 .36138 m
.62552 .36352 L
s
.41888 .35886 m
.42202 .36371 L
s
.62075 .36622 m
.62555 .3658 L
s
.63798 .34405 m
.63962 .34844 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.40739 .35416 m
.4074 .35366 L
s
.5 Mabswid
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40608 .36449 m
.40654 .33257 L
s
.4045 .36433 m
.40496 .3324 L
s
.63956 .34389 m
.6412 .34828 L
s
.62709 .36109 m
.62712 .36337 L
s
.62555 .3658 m
.62712 .36337 L
s
.38322 .32978 m
.39403 .33115 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64506 .35113 m
.64515 .35286 L
s
.64381 .38633 m
.64392 .38216 L
s
.64467 .35293 m
.64471 .35141 L
s
.5 Mabswid
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63962 .34844 m
.64437 .35022 L
s
.64879 .33146 m
.65193 .33336 L
s
.6412 .34828 m
.64437 .35022 L
s
.65193 .33336 m
.65511 .33754 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38897 .3557 m
.38938 .33058 L
s
.64437 .35022 m
.65378 .35143 L
s
.63975 .35757 m
.63979 .35986 L
s
.63975 .35757 m
.64133 .35741 L
s
.38742 .35551 m
.38783 .33038 L
s
.65658 .33279 m
.65963 .33011 L
s
.65511 .33754 m
.65658 .33279 L
s
.64133 .35741 m
.64136 .35969 L
s
.63979 .35986 m
.6414 .36198 L
s
0 0 0 r
.64533 .38101 m
.64541 .38617 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65812 .33259 m
.65963 .33011 L
s
.65666 .33735 m
.65812 .33259 L
s
.65963 .33011 m
.66117 .32991 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65666 .33735 m
.65692 .35334 L
s
.39978 .36383 m
.40608 .36449 L
s
.6414 .36198 m
.64458 .36394 L
s
.64458 .36394 m
.65085 .36324 L
s
.65378 .35143 m
.65537 .35353 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36266 .32235 m
.36433 .32085 L
s
.255 .412 .882 r
.36652 .3274 m
.3771 .32895 L
s
.40434 .37579 m
.40588 .37824 L
s
.40272 .37792 m
.40434 .37579 L
s
.40427 .38038 m
.40588 .37824 L
s
0 0 0 r
.686 .31856 m
.6877 .31829 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.64666 .37993 m
.64681 .38247 L
s
.5 Mabswid
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.65544 .35811 m
.65692 .35334 L
s
.65085 .36324 m
.65393 .36059 L
s
.65511 .33754 m
.65544 .35811 L
s
.38734 .3601 m
.38897 .3557 L
s
.40272 .37792 m
.40427 .38038 L
s
.65393 .36059 m
.65544 .35811 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38579 .35991 m
.38742 .35551 L
s
.37165 .37655 m
.37255 .3283 L
s
.37013 .37634 m
.37103 .32808 L
s
.67488 .328 m
.68152 .35925 L
s
.66939 .36095 m
.67488 .328 L
s
.38267 .36182 m
.38734 .3601 L
s
.38267 .36182 m
.38579 .35991 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67092 .36075 m
.675 .33486 L
s
.37959 .36142 m
.38267 .36182 L
s
.66479 .36155 m
.67548 .36012 L
s
.37504 .35852 m
.37959 .36142 L
s
.37208 .3535 m
.37504 .35852 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35309 .32755 m
.35595 .33263 L
s
.35595 .33263 m
.35729 .33976 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.68678 .34729 m
.68678 .34743 L
s
.68826 .34591 m
.68828 .34716 L
s
.5 Mabswid
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68152 .35925 m
.68685 .32615 L
s
.68302 .35903 m
.68699 .33303 L
s
.34874 .3245 m
.35309 .32755 L
s
.3347 .30573 m
.34473 .30766 L
s
.35162 .3273 m
.35447 .33238 L
s
.35447 .33238 m
.3558 .33952 L
s
.35719 .34436 m
.35729 .33976 L
s
.34874 .3245 m
.35162 .3273 L
s
.35571 .34412 m
.3558 .33952 L
s
.34583 .32398 m
.34874 .3245 L
s
.35557 .35104 m
.35719 .34436 L
s
.36559 .37571 m
.37165 .37655 L
s
.33932 .35526 m
.34041 .30685 L
s
.35409 .3508 m
.35571 .34412 L
s
.33788 .355 m
.33897 .30657 L
s
.34288 .32575 m
.34583 .32398 L
s
.35251 .35518 m
.35557 .35104 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35104 .35494 m
.35409 .3508 L
s
.5 Mabswid
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33989 .32983 m
.34288 .32575 L
s
.34805 .35676 m
.35251 .35518 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68899 .35811 m
.69784 .35668 L
s
.68685 .32615 m
.69343 .35741 L
s
.34805 .35676 m
.35104 .35494 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70599 .32974 m
.70876 .32459 L
s
.70466 .33461 m
.70599 .32974 L
s
.70337 .3418 m
.70466 .33461 L
s
.70876 .32459 m
.71297 .32145 L
s
.70743 .32947 m
.71018 .32431 L
s
.7061 .33435 m
.70743 .32947 L
s
.70481 .34154 m
.7061 .33435 L
s
.70337 .3418 m
.70362 .35336 L
s
.71018 .32431 m
.71297 .32145 L
s
.34512 .35627 m
.34805 .35676 L
s
.70481 .34154 m
.70507 .35311 L
s
.71297 .32145 m
.7158 .32088 L
s
.34226 .35345 m
.34512 .35627 L
s
.33008 .32098 m
.33149 .32126 L
s
.32721 .32272 m
.33008 .32098 L
s
.32861 .323 m
.33008 .32098 L
s
.33947 .34831 m
.34226 .35345 L
s
.7158 .32088 m
.72006 .32233 L
s
.70362 .35336 m
.70523 .36007 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70507 .35311 m
.70667 .35981 L
s
.3271 .32734 m
.32861 .323 L
s
.33357 .35421 m
.33932 .35526 L
s
.3257 .32705 m
.32721 .32272 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70523 .36007 m
.70678 .36446 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32671 .34356 m
.3271 .32734 L
s
.72006 .32233 m
.72296 .32637 L
s
.70667 .35981 m
.70822 .3642 L
s
.32302 .32184 m
.3257 .32705 L
s
.32519 .34792 m
.3257 .32705 L
s
.72279 .31943 m
.72325 .33796 L
s
.70678 .36446 m
.70977 .3686 L
s
.32031 .31893 m
.32302 .32184 L
s
.72417 .31913 m
.72463 .33767 L
s
.70822 .3642 m
.7112 .36834 L
s
.31619 .31802 m
.32031 .31893 L
s
.32519 .34792 m
.32671 .34356 L
s
.70977 .3686 m
.71411 .37015 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32396 .34067 m
.3253 .34328 L
s
.7112 .36834 m
.71411 .37015 L
s
.31571 .33659 m
.32396 .34067 L
s
.3134 .31972 m
.31619 .31802 L
s
.31204 .31941 m
.31619 .31802 L
s
.32373 .34997 m
.32519 .34792 L
s
.71411 .37015 m
.71696 .36962 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71905 .33882 m
.72877 .33679 L
s
.73239 .3173 m
.74178 .31506 L
s
.32089 .35173 m
.32373 .34997 L
s
.31192 .32406 m
.3134 .31972 L
s
.31057 .32374 m
.31204 .31941 L
s
.71696 .36962 m
.72113 .36647 L
s
.3118 .3287 m
.31192 .32406 L
s
.31536 .35058 m
.32089 .35173 L
s
.31304 .33366 m
.31571 .33659 L
s
.31168 .33336 m
.31571 .33659 L
s
.72504 .35397 m
.72539 .36798 L
s
.72382 .36125 m
.72504 .35397 L
s
.31045 .32839 m
.31057 .32374 L
s
.3118 .3287 m
.31304 .33366 L
s
.72113 .36647 m
.72382 .36125 L
s
.72382 .36125 m
.72539 .36798 L
s
.31045 .32839 m
.31168 .33336 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31268 .34765 m
.31536 .35058 L
s
.31144 .34268 m
.3128 .34298 L
s
.31274 .34532 m
.3128 .34298 L
s
.31138 .34501 m
.31144 .34268 L
s
.31138 .34501 m
.31268 .34765 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73779 .31603 m
.73865 .34867 L
s
.73644 .31635 m
.73731 .34898 L
s
.73324 .34988 m
.73865 .34867 L
s
.73828 .33465 m
.73981 .34135 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73981 .34135 m
.7426 .3454 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7426 .3454 m
.74531 .34712 L
s
0 0 0 r
.283 .3019 m
.28475 .30398 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2994 .33988 m
.30066 .34254 L
s
.30059 .34488 m
.30066 .34254 L
s
0 0 0 r
.283 .3019 m
.28473 .30477 L
s
.255 .412 .882 r
.29803 .3419 m
.2994 .33988 L
s
.29921 .34691 m
.30059 .34488 L
s
.74531 .34712 m
.74925 .34616 L
s
.29803 .3419 m
.29928 .34456 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28474 .31005 m
.29361 .3125 L
s
.28883 .3443 m
.28978 .31146 L
s
.29528 .34595 m
.29921 .34691 L
s
.74781 .34179 m
.74919 .34381 L
s
.74781 .34179 m
.74906 .33912 L
s
.74906 .33912 m
.75042 .34114 L
s
.28756 .34397 m
.28851 .31111 L
s
0 0 0 r
.76489 .30616 m
.76545 .30437 L
s
.255 .412 .882 r
.75042 .34114 m
.75049 .34349 L
s
.74925 .34616 m
.75049 .34349 L
s
.29275 .34294 m
.29528 .34595 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7599 .31262 m
.76357 .30921 L
s
.75878 .31766 m
.7599 .31262 L
s
.75878 .31766 m
.75892 .32235 L
s
.29031 .33758 m
.29275 .34294 L
s
.28924 .3302 m
.29031 .33758 L
s
.76115 .31227 m
.76357 .30921 L
s
.76004 .31731 m
.76115 .31227 L
s
.76004 .31731 m
.76018 .322 L
s
.75892 .32235 m
.76031 .32669 L
s
.76018 .322 m
.76157 .32635 L
s
.76357 .30921 m
.76726 .30811 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76031 .32669 m
.76413 .32799 L
s
.28377 .34295 m
.28883 .3443 L
s
.76157 .32635 m
.76413 .32799 L
s
.76059 .3361 m
.76066 .33846 L
s
.76059 .3361 m
.76184 .33576 L
s
.76066 .33846 m
.76198 .34047 L
s
.27676 .32669 m
.27733 .30787 L
s
.76184 .33576 m
.76191 .33811 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76726 .30811 m
.76976 .30972 L
s
.76413 .32799 m
.77155 .3282 L
s
.27554 .32633 m
.27612 .3075 L
s
.27192 .32523 m
.28045 .32776 L
s
.76198 .34047 m
.76455 .34214 L
s
.76976 .30972 m
.77231 .31368 L
s
.27363 .3091 m
.2759 .31455 L
s
.27013 .30561 m
.27363 .3091 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77337 .30859 m
.77567 .30548 L
s
.77231 .31368 m
.77337 .30859 L
s
.77866 .28785 m
.78665 .28502 L
s
.77456 .30822 m
.77567 .30548 L
s
.77351 .3133 m
.77456 .30822 L
s
.26777 .30484 m
.27013 .30561 L
s
.77567 .30548 m
.77685 .3051 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77155 .3282 m
.77282 .3302 L
s
.77351 .3133 m
.77402 .32983 L
s
.77231 .31368 m
.77297 .33493 L
s
.76455 .34214 m
.76948 .34074 L
s
.76948 .34074 m
.77184 .33766 L
s
.26537 .30643 m
.26777 .30484 L
s
.26421 .30604 m
.26777 .30484 L
s
.27583 .35746 m
.27626 .34323 L
s
.27482 .34999 m
.27626 .34323 L
s
.78212 .28665 m
.78372 .33635 L
s
.77184 .33766 m
.77297 .33493 L
s
.77297 .33493 m
.77402 .32983 L
s
.78326 .28625 m
.78487 .33597 L
s
.2629 .31038 m
.26537 .30643 L
s
.27225 .35404 m
.27482 .34999 L
s
.27482 .34999 m
.27583 .35746 L
s
.26176 .30999 m
.26421 .30604 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26858 .35536 m
.27225 .35404 L
s
.26161 .31472 m
.2629 .31038 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26046 .31433 m
.26176 .30999 L
s
.78402 .30985 m
.78614 .30432 L
s
.26023 .32145 m
.26161 .31472 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78614 .30432 m
.78831 .30115 L
s
.2591 .32106 m
.26046 .31433 L
s
.78024 .33748 m
.78487 .33597 L
s
0 0 0 r
.25064 .29807 m
.25088 .2975 L
s
.255 .412 .882 r
.2662 .35464 m
.26858 .35536 L
s
.78831 .30115 m
.79053 .30034 L
s
.25985 .33334 m
.26023 .32145 L
s
.26393 .35153 m
.2662 .35464 L
s
.26277 .35116 m
.2662 .35464 L
s
.78464 .32883 m
.78707 .33283 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25871 .33296 m
.2591 .32106 L
s
.79053 .30034 m
.7928 .3019 L
s
.79053 .30034 m
.79389 .30148 L
s
.26176 .34602 m
.26393 .35153 L
s
.25985 .33334 m
.26076 .34087 L
s
.26076 .34087 m
.26176 .34602 L
s
.26061 .34564 m
.26277 .35116 L
s
.25871 .33296 m
.25962 .34049 L
s
.7928 .3019 m
.79513 .30583 L
s
.78707 .33283 m
.7894 .33444 L
s
.25962 .34049 m
.26061 .34564 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79389 .30148 m
.7962 .30541 L
s
0 0 0 r
.24973 .32523 m
.2499 .32663 L
s
.255 .412 .882 r
.7894 .33444 m
.79163 .33367 L
s
.79513 .30583 m
.79645 .31256 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7962 .30541 m
.79752 .31215 L
s
.24759 .33143 m
.25414 .3338 L
s
.24766 .29758 m
.25084 .33262 L
s
.24231 .32941 m
.24766 .29758 L
s
.79163 .33367 m
.79375 .33049 L
s
.79163 .33367 m
.79485 .33009 L
s
.79645 .31256 m
.79661 .31734 L
s
.24336 .32981 m
.24742 .30473 L
s
.79375 .33049 m
.79577 .32491 L
s
.79577 .32491 m
.79661 .31734 L
s
.79752 .31215 m
.79768 .31693 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80023 .31757 m
.80029 .31913 L
s
.5 Mabswid
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79485 .33009 m
.79685 .32451 L
s
.79685 .32451 m
.79768 .31693 L
s
.8033 .29531 m
.81031 .29225 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.23939 .29416 m
.24231 .32941 L
s
.23422 .32607 m
.23939 .29416 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8013 .34873 m
.80136 .35031 L
s
.5 Mabswid
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2352 .3265 m
.23914 .30134 L
s
.80828 .31996 m
.81044 .32394 L
s
.23129 .3248 m
.23821 .32775 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80735 .29357 m
.80913 .34411 L
s
.80635 .29401 m
.80812 .34451 L
s
.80505 .34573 m
.80913 .34411 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81417 .29046 m
.82063 .28727 L
s
.22966 .28972 m
.2306 .29017 L
s
.81044 .32394 m
.81346 .32508 L
s
.22771 .29121 m
.22966 .28972 L
s
.22864 .29167 m
.22966 .28972 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81698 .28911 m
.81795 .31565 L
s
.22754 .29603 m
.22864 .29167 L
s
.81791 .28865 m
.81888 .31521 L
s
.22662 .29558 m
.22771 .29121 L
s
.81346 .32508 m
.81538 .32422 L
s
.22692 .31294 m
.22754 .29603 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22498 .28984 m
.22662 .29558 L
s
.22582 .31734 m
.22662 .29558 L
s
.81538 .32422 m
.81719 .32093 L
s
.81538 .32422 m
.81813 .32049 L
s
.22328 .2865 m
.22498 .28984 L
s
.81719 .32093 m
.81795 .31565 L
s
.22582 .31734 m
.22692 .31294 L
s
.22065 .2851 m
.22328 .2865 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81813 .32049 m
.81888 .31521 L
s
.22517 .30963 m
.226 .3125 L
s
.22481 .31933 m
.22582 .31734 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21993 .30449 m
.22517 .30963 L
s
.22291 .32087 m
.22481 .31933 L
s
.21885 .28658 m
.22065 .2851 L
s
.21801 .2861 m
.22065 .2851 L
s
.21938 .31909 m
.22291 .32087 L
s
.21782 .29095 m
.21885 .28658 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82674 .28399 m
.82802 .31803 L
s
.82417 .28541 m
.83006 .28208 L
s
.21699 .29048 m
.21801 .2861 L
s
.2183 .30113 m
.21993 .30449 L
s
.21746 .30067 m
.21993 .30449 L
s
.21764 .29581 m
.21782 .29095 L
s
.21764 .29581 m
.2183 .30113 L
s
.2168 .29534 m
.21699 .29048 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2168 .29534 m
.21746 .30067 L
s
.21775 .31574 m
.21938 .31909 L
s
.21709 .31041 m
.21794 .31087 L
s
.21784 .31331 m
.21794 .31087 L
s
.217 .31285 m
.21775 .31574 L
s
.217 .31285 m
.21709 .31041 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82544 .31938 m
.82887 .31757 L
s
.82758 .28352 m
.82887 .31757 L
s
.82772 .33315 m
.82848 .33025 L
s
.82772 .33315 m
.82867 .33515 L
s
.82848 .33025 m
.82942 .33226 L
s
.82867 .33515 m
.82942 .33226 L
s
.83432 .28697 m
.83566 .28112 L
s
.83382 .29477 m
.83432 .28697 L
s
.83382 .29477 m
.83401 .29966 L
s
.83509 .28649 m
.83642 .28063 L
s
.8346 .29429 m
.83509 .28649 L
s
.83566 .28112 m
.83781 .2772 L
s
.83401 .29966 m
.83507 .30653 L
s
.8346 .29429 m
.83479 .29918 L
s
.83642 .28063 m
.83781 .2772 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83479 .29918 m
.83585 .30606 L
s
.83507 .30653 m
.8368 .31049 L
s
.20981 .30622 m
.21049 .30914 L
s
.2104 .31159 m
.21049 .30914 L
s
.83781 .2772 m
.83926 .27621 L
s
.20952 .31358 m
.2104 .31159 L
s
.20894 .3082 m
.20981 .30622 L
s
.20219 .27336 m
.2071 .27688 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83585 .30606 m
.83756 .31002 L
s
.20894 .3082 m
.20962 .31112 L
s
.20724 .31217 m
.20952 .31358 L
s
.83926 .27621 m
.84148 .27715 L
s
.8368 .31049 m
.83915 .31153 L
s
.20359 .30979 m
.20495 .27538 L
s
.83756 .31002 m
.83915 .31153 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20289 .30931 m
.20425 .27488 L
s
.20585 .30876 m
.20724 .31217 L
s
.84148 .27715 m
.84304 .28106 L
s
.83915 .31153 m
.84133 .3101 L
s
.20459 .30287 m
.20585 .30876 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20417 .29501 m
.20459 .30287 L
s
.84133 .3101 m
.84264 .30667 L
s
.84235 .29927 m
.84295 .29632 L
s
.84235 .29927 m
.84314 .30125 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20082 .30786 m
.20359 .30979 L
s
.84295 .29632 m
.84373 .2983 L
s
.84264 .30667 m
.84383 .30076 L
s
.84373 .2983 m
.84383 .30076 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84728 .27012 m
.84809 .27454 L
s
.84728 .27012 m
.84768 .27998 L
s
.19802 .27769 m
.19845 .28314 L
s
.19845 .28314 m
.19879 .29105 L
s
.197 .27173 m
.19802 .27769 L
s
.19829 .30343 m
.19879 .29105 L
s
.5 Mabswid
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85121 .32144 m
.85169 .32577 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84768 .27998 m
.84809 .27454 L
s
.19741 .27718 m
.19782 .28263 L
s
.19782 .28263 m
.19815 .29055 L
s
.84809 .27454 m
.8486 .27155 L
s
.1964 .27121 m
.19741 .27718 L
s
.19533 .2677 m
.197 .27173 L
s
.19765 .30294 m
.19815 .29055 L
s
.8486 .27155 m
.84968 .26805 L
s
.19533 .2677 m
.1964 .27121 L
s
.19736 .31039 m
.19829 .30343 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84968 .26805 m
.85193 .26595 L
s
.19673 .3099 m
.19765 .30294 L
s
.84828 .29483 m
.84879 .29185 L
s
.84828 .29483 m
.84848 .29979 L
s
.19002 .26242 m
.19533 .2677 L
s
.84838 .29731 m
.84889 .29433 L
s
.84879 .29185 m
.84989 .28836 L
s
.84848 .29979 m
.84919 .30178 L
s
.84889 .29433 m
.84999 .29084 L
s
.19653 .31487 m
.19736 .31039 L
s
.19591 .31439 m
.19673 .3099 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.85068 .32332 m
.85086 .32498 L
s
.5 Mabswid
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84999 .29084 m
.85264 .28332 L
s
.84919 .30178 m
.8505 .30327 L
s
.84989 .28836 m
.85254 .28084 L
s
.19509 .31889 m
.19653 .31487 L
s
.85193 .26595 m
.85311 .26738 L
s
.19449 .3184 m
.19591 .31439 L
s
.8505 .30327 m
.8528 .30127 L
s
.19321 .31993 m
.19509 .31889 L
s
.85311 .26738 m
.85374 .26933 L
s
.85254 .28084 m
.85352 .27731 L
s
.18988 .31698 m
.19203 .26455 L
s
.85264 .28332 m
.85362 .2798 L
s
.19321 .31993 m
.19449 .3184 L
s
.18936 .31648 m
.19152 .26402 L
s
.85374 .26933 m
.85404 .27679 L
s
.85352 .27731 m
.85394 .2743 L
s
.85362 .2798 m
.85404 .27679 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8528 .30127 m
.8538 .29777 L
s
.18785 .31499 m
.19321 .31993 L
s
.8538 .29777 m
.85423 .29476 L
s
.85423 .29476 m
.85456 .28925 L
s
.85423 .29476 m
.85497 .29925 L
s
.85456 .28925 m
.85497 .29925 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85705 .26312 m
.85739 .26009 L
s
.85705 .26312 m
.8576 .26508 L
s
.85739 .26009 m
.85794 .26205 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8576 .26508 m
.85794 .26205 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85812 .27759 m
.85982 .30725 L
s
.85812 .27759 m
.85892 .30827 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85875 .29265 m
.85938 .30776 L
s
.85892 .30827 m
.85959 .31281 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85959 .31281 m
.85982 .30725 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17889 .24911 m
.17917 .24712 L
s
.17911 .24402 m
.17917 .24712 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17885 .246 m
.17911 .24402 L
s
.17885 .246 m
.17889 .24911 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1772 .29316 m
.17835 .26186 L
s
.17687 .2921 m
.17835 .26186 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17703 .29263 m
.17769 .27721 L
s
.17681 .29778 m
.1772 .29316 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17793 .24459 m
.17797 .24146 L
s
.1776 .25228 m
.17793 .24459 L
s
.17681 .29778 m
.17687 .2921 L
s
.17797 .24146 m
.17796 .23776 L
s
.17753 .25172 m
.17771 .24971 L
s
.17742 .25428 m
.1776 .25228 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17796 .23776 m
.17786 .23547 L
s
.1773 .25316 m
.17753 .25172 L
s
.17719 .25573 m
.17742 .25428 L
s
.17675 .26972 m
.17705 .26512 L
s
.17661 .27543 m
.17705 .26512 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17697 .25551 m
.1773 .25316 L
s
.17675 .26972 m
.17661 .27543 L
s
.17686 .2581 m
.17719 .25573 L
s
.17675 .26972 m
.17658 .27175 L
s
0 0 0 r
.17404 .22511 m
.17422 .22157 L
s
.255 .412 .882 r
.17786 .23547 m
.17776 .23689 L
s
.17658 .27175 m
.17637 .27324 L
s
0 0 0 r
.17106 .29795 m
.17406 .22393 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17776 .23689 m
.17767 .2389 L
s
.17637 .27324 m
.1763 .27105 L
s
.17792 .23317 m
.17767 .2389 L
s
.17748 .24349 m
.17767 .2389 L
s
.17748 .24349 m
.17792 .23317 L
s
.17689 .25698 m
.17697 .25551 L
s
.17678 .25957 m
.17686 .2581 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17681 .25901 m
.17689 .25698 L
s
0 0 0 r
.17316 .24485 m
.17396 .23967 L
s
.255 .412 .882 r
.1763 .27105 m
.17645 .26735 L
s
.1767 .26161 m
.17678 .25957 L
s
.17659 .2642 m
.17681 .25901 L
s
.17645 .26735 m
.17659 .2642 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17479 .21802 m
.17576 .21447 L
s
.255 .412 .882 r
.17811 .23691 m
.17859 .23057 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17155 .28669 m
.17523 .21625 L
s
.255 .412 .882 r
.17733 .2551 m
.17722 .25771 L
s
.17756 .25193 m
.17733 .2551 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17722 .25771 m
.17724 .26181 L
s
.17758 .25398 m
.17756 .25193 L
s
.17734 .25715 m
.17758 .25398 L
s
.17724 .26181 m
.17742 .26332 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.867 .24062 m
.86876 .28172 L
s
.86715 .24126 m
.86891 .28226 L
s
.5 Mabswid
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17617 .21328 m
.17796 .20913 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17106 .29795 m
.17539 .21565 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17461 .26393 m
.17687 .2115 L
s
.17486 .26338 m
.17713 .21091 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86763 .27847 m
.86929 .28388 L
s
.5 Mabswid
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17391 .26561 m
.17486 .26338 L
s
.17562 .25151 m
.17584 .24081 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17562 .25151 m
.17586 .25792 L
s
.17586 .25792 m
.17631 .26059 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17631 .26059 m
.17732 .25891 L
s
.1773 .2519 m
.17748 .25512 L
s
.1773 .2519 m
.17781 .24755 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17781 .24755 m
.178 .25077 L
s
.17784 .25456 m
.178 .25077 L
s
.17732 .25891 m
.17784 .25456 L
s
.18184 .21332 m
.18305 .2046 L
s
.18093 .22522 m
.18184 .21332 L
s
.18305 .2046 m
.18463 .19907 L
s
.18061 .23279 m
.18093 .22522 L
s
.18228 .21273 m
.18351 .20402 L
s
.18136 .22465 m
.18228 .21273 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18351 .20402 m
.18463 .19907 L
s
.18104 .23222 m
.18136 .22465 L
s
.18055 .2436 m
.18061 .23279 L
s
.18463 .19907 m
.18563 .19789 L
s
.18099 .24304 m
.18104 .23222 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1865 .23982 m
.18683 .23198 L
s
.18604 .24038 m
.18638 .23236 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18563 .19789 m
.18706 .19991 L
s
.18055 .2436 m
.18112 .25009 L
s
.18099 .24304 m
.18158 .24954 L
s
.255 .412 .882 r
.18628 .24515 m
.18604 .24038 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18676 .2446 m
.1865 .23982 L
s
.85806 .24141 m
.8582 .2406 L
s
0 0 0 r
.18112 .25009 m
.18238 .25225 L
s
.18706 .19991 m
.18785 .20634 L
s
.18158 .24954 m
.18238 .25225 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85817 .24408 m
.8584 .2453 L
s
.85806 .24141 m
.85817 .24408 L
s
0 0 0 r
.18238 .25225 m
.1839 .25059 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18562 .23416 m
.18633 .22978 L
s
.18562 .23416 m
.18601 .23743 L
s
.18633 .22978 m
.18674 .23304 L
s
.1839 .25059 m
.18513 .24565 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19196 .19145 m
.19671 .18739 L
s
.18513 .24565 m
.18658 .23687 L
s
.18658 .23687 m
.18674 .23304 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19059 .27059 m
.19392 .18971 L
s
.19128 .27006 m
.1946 .18913 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19287 .23132 m
.19395 .23794 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20032 .22584 m
.20203 .18338 L
s
.18861 .27217 m
.19128 .27006 L
s
.19395 .23794 m
.19598 .24019 L
s
.20113 .2253 m
.20284 .18281 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19968 .1851 m
.20533 .18111 L
s
.5 Mabswid
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19598 .24019 m
.19749 .23911 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8387 .18773 m
.83941 .18443 L
s
.83839 .18001 m
.83941 .18443 L
s
.83767 .18331 m
.83839 .18001 L
s
.19749 .23911 m
.19921 .23415 L
s
.19749 .23911 m
.20001 .23361 L
s
.83767 .18331 m
.8387 .18773 L
s
.19921 .23415 m
.20032 .22584 L
s
.2088 .17886 m
.21533 .17496 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20001 .23361 m
.20113 .2253 L
s
.20941 .23167 m
.21153 .17718 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83482 .21374 m
.83498 .21072 L
s
.5 Mabswid
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21034 .23114 m
.21247 .17662 L
s
.82814 .17389 m
.83203 .1761 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20666 .23325 m
.21034 .23114 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84039 .23043 m
.84132 .25391 L
s
.83946 .20708 m
.84044 .25339 L
s
.83946 .20708 m
.84219 .25443 L
s
.5 Mabswid
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84163 .26177 m
.84219 .25443 L
s
.21931 .17277 m
.22672 .16898 L
s
.82628 .17668 m
.82859 .18554 L
s
.82407 .1717 m
.82628 .17668 L
s
.84044 .25339 m
.84163 .26177 L
s
.82197 .17062 m
.82407 .1717 L
s
.22035 .22598 m
.22242 .17113 L
s
.81997 .17344 m
.82197 .17062 L
s
.81887 .17291 m
.82197 .17062 L
s
.22141 .22547 m
.22348 .17059 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20756 .25576 m
.20864 .25131 L
s
.20756 .25576 m
.20833 .25919 L
s
.20864 .25131 m
.20942 .25474 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82814 .17389 m
.8313 .2562 L
s
.82913 .17444 m
.83229 .2567 L
s
.82806 .22361 m
.82978 .21679 L
s
.81806 .1802 m
.81997 .17344 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20833 .25919 m
.20942 .25474 L
s
.81695 .17967 m
.81887 .17291 L
s
.82614 .22652 m
.82806 .22361 L
s
.81738 .19144 m
.81806 .1802 L
s
.21723 .22752 m
.22141 .22547 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23119 .16685 m
.23945 .1632 L
s
.81626 .19092 m
.81695 .17967 L
s
.22186 .21365 m
.22372 .22051 L
s
.82403 .2255 m
.82614 .22652 L
s
.82824 .25471 m
.83229 .2567 L
s
.81738 .19144 m
.81767 .1993 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81626 .19092 m
.81654 .19879 L
s
.82172 .22054 m
.82403 .2255 L
s
.82063 .22003 m
.82403 .2255 L
s
.81767 .1993 m
.81923 .21163 L
s
.81923 .21163 m
.82172 .22054 L
s
.22372 .22051 m
.2269 .22295 L
s
.81654 .19879 m
.81811 .21112 L
s
.81811 .21112 m
.82063 .22003 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2331 .20858 m
.23467 .16527 L
s
.23428 .20808 m
.23585 .16475 L
s
.2269 .22295 m
.22917 .22196 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80104 .16118 m
.8096 .16478 L
s
.24441 .16115 m
.25351 .15764 L
s
.22917 .22196 m
.23164 .217 L
s
.22917 .22196 m
.23281 .2165 L
s
.23164 .217 m
.2331 .20858 L
s
.23428 .20808 m
.2364 .21503 L
s
.23281 .2165 m
.23428 .20808 L
s
.24674 .2032 m
.24825 .15963 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78652 .15571 m
.79591 .15916 L
s
.24805 .20272 m
.24955 .15913 L
s
.2364 .21503 m
.23995 .21755 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80478 .16271 m
.80674 .21806 L
s
.806 .16322 m
.80797 .21854 L
s
.80298 .21662 m
.80797 .21854 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23995 .21755 m
.24247 .21659 L
s
.24247 .21659 m
.24517 .21165 L
s
.24247 .21659 m
.24647 .21117 L
s
.24517 .21165 m
.24674 .2032 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80773 .24602 m
.80882 .24249 L
s
.80745 .23801 m
.80882 .24249 L
s
.80634 .24155 m
.80745 .23801 L
s
.24647 .21117 m
.24805 .20272 L
s
.25993 .16709 m
.26299 .15821 L
s
.25815 .17949 m
.25993 .16709 L
s
.80634 .24155 m
.80773 .24602 L
s
.26299 .15821 m
.2674 .15282 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.79061 .15718 m
.79343 .24099 L
s
.79195 .15767 m
.79479 .24144 L
s
.26133 .16662 m
.26441 .15773 L
s
.25954 .17902 m
.26133 .16662 L
s
.26441 .15773 m
.2674 .15282 L
s
.25788 .18746 m
.25815 .17949 L
s
.2674 .15282 m
.2703 .15188 L
s
.25927 .18699 m
.25954 .17902 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25788 .18746 m
.25888 .19898 L
s
.2703 .15188 m
.2746 .15448 L
s
.25927 .18699 m
.26028 .19852 L
s
.77529 .15588 m
.77845 .16477 L
s
.77074 .15052 m
.77529 .15588 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25888 .19898 m
.26143 .20608 L
s
.76774 .14961 m
.77074 .15052 L
s
.2746 .15448 m
.27736 .16155 L
s
.26028 .19852 m
.26285 .20563 L
s
.76482 .15269 m
.76774 .14961 L
s
.76328 .15225 m
.76774 .14961 L
s
.78931 .23966 m
.79479 .24144 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25927 .18699 m
.27674 .18156 L
s
.26143 .20608 m
.2656 .20876 L
s
.77935 .19272 m
.77948 .19673 L
s
.77777 .18826 m
.77935 .19272 L
s
.77643 .19182 m
.77777 .18826 L
s
.26285 .20563 m
.2656 .20876 L
s
.77682 .20387 m
.77948 .19673 L
s
.77643 .19182 m
.77802 .19628 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76042 .15936 m
.76328 .15225 L
s
.76198 .1598 m
.76482 .15269 L
s
.2656 .20876 m
.27 .20744 L
s
.27486 .19405 m
.27523 .182 L
s
.76078 .17139 m
.76198 .1598 L
s
.77398 .20703 m
.77682 .20387 L
s
.2765 .1896 m
.27674 .18156 L
s
.75921 .17096 m
.76042 .15936 L
s
.27 .20744 m
.2731 .20254 L
s
.2731 .20254 m
.27486 .19405 L
s
.27473 .19808 m
.2765 .1896 L
s
.74564 .14352 m
.75215 .14521 L
s
.76947 .20574 m
.77398 .20703 L
s
.2731 .20254 m
.27473 .19808 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76078 .17139 m
.76102 .17943 L
s
.29321 .14919 m
.29819 .14392 L
s
.28978 .15805 m
.29321 .14919 L
s
.28784 .17051 m
.28978 .15805 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75921 .17096 m
.75945 .179 L
s
.29482 .14876 m
.29819 .14392 L
s
.29137 .15762 m
.29482 .14876 L
s
.28943 .17009 m
.29137 .15762 L
s
.29819 .14392 m
.30148 .14309 L
s
.2876 .17856 m
.28784 .17051 L
s
.28919 .17814 m
.28943 .17009 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75945 .179 m
.76138 .19151 L
s
.74564 .14352 m
.74723 .20001 L
s
.76474 .20043 m
.76947 .20574 L
s
.76629 .20085 m
.76947 .20574 L
s
.76102 .17943 m
.76294 .19193 L
s
.74728 .14394 m
.74888 .2004 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76294 .19193 m
.76629 .20085 L
s
.30148 .14309 m
.3047 .14628 L
s
.2876 .17856 m
.28884 .19024 L
s
.76138 .19151 m
.76474 .20043 L
s
.28919 .17814 m
.29044 .18983 L
s
.74245 .14671 m
.74598 .15556 L
s
.73731 .14148 m
.74245 .14671 L
s
.3047 .14628 m
.30784 .15352 L
s
.73391 .14068 m
.73731 .14148 L
s
.30817 .14146 m
.315 .13988 L
s
.30586 .22668 m
.30817 .14146 L
s
.28884 .19024 m
.29181 .19752 L
s
.30757 .22632 m
.30986 .14106 L
s
.29044 .18983 m
.29344 .19712 L
s
.73059 .14392 m
.73391 .14068 L
s
.72886 .14354 m
.73391 .14068 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29181 .19752 m
.29659 .20038 L
s
.72907 .1516 m
.73059 .14392 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.29344 .19712 m
.29659 .20038 L
s
.72733 .15122 m
.72886 .14354 L
s
.72907 .1516 m
.73023 .19624 L
s
.74222 .19885 m
.74888 .2004 L
s
.72733 .15122 m
.72848 .19588 L
s
.29659 .20038 m
.2999 .1996 L
s
.2999 .1996 m
.30336 .19476 L
s
.32718 .14127 m
.33267 .13615 L
s
.32343 .15008 m
.32718 .14127 L
s
.32135 .16259 m
.32343 .15008 L
s
.30336 .19476 m
.30697 .18587 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32897 .14091 m
.33267 .13615 L
s
.3252 .14972 m
.32897 .14091 L
s
.32312 .16223 m
.3252 .14972 L
s
.33267 .13615 m
.3363 .13544 L
s
.32115 .1707 m
.32135 .16259 L
s
.3363 .13544 m
.34172 .13845 L
s
.32292 .17034 m
.32312 .16223 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70918 .13546 m
.71158 .16012 L
s
.68098 .13058 m
.711 .13581 L
s
.711 .13581 m
.71158 .16012 L
s
.32115 .1707 m
.32261 .18255 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32292 .17034 m
.32439 .18219 L
s
.32292 .17034 m
.34479 .16624 L
s
.34172 .13845 m
.34525 .14589 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30078 .22779 m
.30757 .22632 L
s
.72318 .19481 m
.73023 .19624 L
s
.32261 .18255 m
.32598 .19001 L
s
.32439 .18219 m
.32778 .18966 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32598 .19001 m
.3313 .19307 L
s
.35874 .13148 m
.36049 .13929 L
s
.3584 .14773 m
.35874 .13148 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32778 .18966 m
.3313 .19307 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7006 .16218 m
.70133 .19492 L
s
.34265 .17882 m
.34293 .16656 L
s
.36049 .13929 m
.3625 .13492 L
s
.3625 .13492 m
.36645 .13026 L
s
.3584 .14773 m
.36049 .13929 L
s
.36645 .13026 m
.37427 .12911 L
s
.34461 .17441 m
.34479 .16624 L
s
.3313 .19307 m
.3368 .19208 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34256 .18291 m
.34461 .17441 L
s
.3406 .18733 m
.34265 .17882 L
s
.37427 .12911 m
.37814 .13263 L
s
.3368 .19208 m
.3406 .18733 L
s
.6896 .17666 m
.70097 .17852 L
s
.3406 .18733 m
.34256 .18291 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37814 .13263 m
.38005 .13643 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37983 .14868 m
.38005 .13643 L
s
.35991 .16786 m
.36386 .16318 L
s
.3579 .17225 m
.35991 .16786 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71245 .19685 m
.71304 .22154 L
s
.7112 .22121 m
.71245 .19685 L
s
.68675 .13149 m
.68853 .2176 L
s
.68866 .1318 m
.69046 .21788 L
s
.35773 .18045 m
.3579 .17225 L
s
.255 .412 .882 r
.36844 .17445 m
.36872 .17401 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36386 .16318 m
.37381 .15358 L
s
.35982 .17195 m
.36378 .16727 L
s
.35781 .17635 m
.35982 .17195 L
s
.36378 .16727 m
.37373 .15768 L
s
.37785 .14895 m
.37991 .1446 L
s
.6827 .21677 m
.71304 .22154 L
s
.37381 .15358 m
.37785 .14895 L
s
.39628 .12624 m
.39825 .13008 L
s
.39419 .13056 m
.39628 .12624 L
s
.35773 .18045 m
.35957 .18427 L
s
.37777 .15304 m
.37983 .14868 L
s
.39419 .13056 m
.39615 .1344 L
s
.37373 .15768 m
.37777 .15304 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39615 .1344 m
.39825 .13008 L
s
.35957 .18427 m
.36337 .18782 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36337 .18782 m
.37122 .18672 L
s
.5 Mabswid
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37732 .17768 m
.37946 .16919 L
s
.37917 .18567 m
.37946 .16919 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.37526 .18206 m
.37732 .17768 L
s
.37732 .17768 m
.37917 .18567 L
s
.37122 .18672 m
.37526 .18206 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39298 .20471 m
.39582 .15489 L
s
.39582 .15489 m
.39709 .20427 L
s
.5 Mabswid
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.57361 .13579 m
.57408 .13549 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39503 .20449 m
.39543 .17961 L
s
.5 Mabswid
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60998 .16392 m
.61195 .16131 L
s
.5 Mabswid
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42925 .16249 m
.42927 .16077 L
s
.42718 .16133 m
.42719 .16088 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60998 .16392 m
.61001 .16681 L
s
.5 Mabswid
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.39298 .20471 m
.3949 .21282 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3949 .21282 m
.39709 .20427 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa090:f][@h0oj<@00<0[Jf]0?bP403l
X100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00X0k9H>0P2][JeV0;3PiP40
oooo001j0;3PiP80[Jf]303lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ402P3oYQ400`000000ojHA0:f][@090:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40
6`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
2`3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f]
[@3/UPh0k9H>00`0k9H>0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT
4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0000000000000P3oYQ470:f][@80000000<0
[Jf]0?nV4@3oYQ40303oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400E0?nS40L0[Jf]603lX1000`2][Jd0mY`?0?JL
3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA00<0[Jf]0000000000000P2][Jd0
0`000000[Jf]0?nV4@060?nV4@030000003oYQ40000000h0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa00
0`2][Jd0o:0@0?bP40030:f][@<000004P3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0
k9H>0100k9H>0`2][JeO0;3PiP40oooo001c0;3PiP<0[Jf]4P3lX1000`2][Jd0oj@A0?nT4@0C0?nT
4@030:f][@3oYQ40ojHA0100ojHA0P2][Jd01P000000[Jf]0:f][@000000ojHA0:f][@<0ojHA00<0
00000?nV4@3oYQ401@3oYQ42000000l0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP
40060?bP40D000003@3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>0100k9H>00<0
[Jf]0=^:3@3KRPd00P2][JeM0;3PiP40oooo001a0;3PiP80[Jf]0P3_V1000`2][Jd0o:0@0?bP400?
0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ4010000000ojHA0?nV4@3o
YQ450:f][@80ojHA00<000000?nV4@0000000P3oYQ401@2][Jd0ojHA0?nV4@3oYQ40000000P0ojHA
00<000000?nV4@3oYQ403@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0o:0@
0P0000030?bP40D0000000<0o:0@0000003lX1001@3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2]
[Jd40>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV
4@050?nV4@80000000@0[Jf]0000002][Jd0[Jf]1`3oYQ42000000<0ojHA00<0[Jf]0?nV4@3oYQ40
0P3oYQ400`000000ojHA0?nV4@0E0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX100
1P3lX102000000P0o:0@0`0000030:f][@80o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_
V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA00<0[Jf]0P0000040?nV4@030000003oYQ40ojHA00H0ojHA0P0000030?nV4@030:f][@3o
YQ40ojHA0080ojHA00<000000?nV4@3oYQ405@3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400I0?nS40030:f][@3l
X100o:0@00H0o:0@0P0000090?bP408000000`3lX1040:f][AD0mY`?00<0[Jf]0>bF3P3/UPh03`3/
UPh00`2][Jd0fhX=0=^:3@060=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]
0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0@0?nT4@@000000`2][Jd20?nV4@8000001@3oYQ40
0`000000ojHA0?nV4@060?nV4@8000000`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40
ojHA01D0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00
ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP40060?bP408000002@3lX102
000000D0o:0@00<0[Jf]0?JL3`2][Jd00P2][Jd3000000l0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh0
0`2][Jd0fhX=0=^:3@080=^:3@80[Jf]E@2`h>H10?ooo`00JP2`h>H20:f][@T0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0<0?nT4@050000003oY140oj@A0:f][@0000000P2][Jd0
0`3oY140[Jf]0?nV4@030?nV4@8000001P3oYQ400`000000ojHA0?nV4@050?nV4@8000000`3oYQ40
0`2][Jd0ojHA0?nV4@020?nV4@030000003oYQ40ojHA01@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006@3oXa00
0`2][Jd0o:0@0?bP40060?bP408000002@3lX102000000D0o:0@00H0[Jf]0?JL3`3fW0l0mY`?0000
003fW0l20:f][@030000002][Jd0mY`?008000002P3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80[Jf]2`3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00/0oj@A00H000000:f][@000000[Jf]0?nT4@0000030?nT4@04
0:f][@3oYQ40ojHA0?nV4@8000001`3oYQ400`000000ojHA0?nV4@050?nV4@030000003oYQ40ojHA
0080ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0?nV4@0D0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01T0oj<@00<0[Jf]0?bP403lX1001P3lX102000000T0o:0@0P0000050?bP40030:f][@3fW0l0mY`?
00800000103fW0l00`000000[Jf]00000004000000L0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2]
[Jd0fhX=0=^:3@0<0=^:3@030:f][@2`h>H0/>3V0500/>3V0@3oool006L0/>3V00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00L0oj@A0P2][Jd2000000<0
oj@A00<000000?nT4@0000000`3oY140102][Jd0ojHA0?nV4@3oYQ42000000P0ojHA00<000000?nV
4@3oYQ40103oYQ400`000000ojHA0?nV4@020?nV4@040:f][@3oYQ40ojHA0?nV4@8000005P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400I0?nS40030:f][@3lX100o:0@00H0o:0@0P0000090?bP408000001@3lX100
0`2][Jd0mY`?0?JL3`02000000D0mY`?0`0000000`3fW0l0[Jf]0:f][@020:f][@D0mY`?00<0[Jf]
0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`h>H20:f]
[@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@030?nT4@@0[Jf]00<0oj@A0000
00000000103oY1400`000000oj@A000000030?nT4@030:f][@3oYQ40ojHA00800000403oYQ400`00
0000ojHA0?nV4@020?nV4@040:f][@3oYQ40ojHA0?nV4@8000005P3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@00D0o:0@0P00000:0?bP40030000003lX100o:0@00<0o:0@00@0[Jf]
0?JL3`00000000001P3fW0l3000000D0mY`?102][Jd00`3fW0l0[Jf]0>bF3P0A0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f][@0=
0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd50?nT4@8000001@3oY142
000000<0oj@A00<0[Jf]0?nV4@3oYQ400P00000E0?nV4@030:f][@3oYQ40ojHA008000005`3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000:0?bP40030000003lX100
o:0@00<0o:0@00@0[Jf]0?JL3`00000000001P3fW0l3000000T0mY`?0`00000A0>bF3P030:f][@3K
RPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`h>H0102][Jd0dhL>0=>7
3P2][Jd=0>nH40030:f][@3lX100o:0@00d0o:0@0`0000000`2][Jd0oj@A0?nT4@060?nT4@800000
1P3oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ400P00000E0?nV4@030:f][@3oYQ40ojHA00800000
5`3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000:0?bP40030000
003lX100o:0@00<0o:0@00@0[Jf]0?JL3`00000000001`3fW0l2000000L0mY`?0P000000103fW0l0
[Jf]0>bF3P0000020:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd01@2][Jd0^GD;0;Ue2`2iM@/0
[Jf]04h0/>3V0@3oool006<0/>3V00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100
o:0@00`0o:0@0P000000103lX100[Jf]0000000000070?nT4@8000001`3oY1401@000000oj@A0?nT
4@3oY140[Jf]0080ojHA0P00000E0?nV4@040:f][@3oYQ400000000000T0ojHA00<000000?nV4@3o
YQ40303oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P00000:0?bP4003
0000003lX100o:0@00<0o:0@00@0[Jf]0?JL3`00000000001`3fW0l2000000L0mY`?00H000000?JL
3`3fW0l0[Jf]0>bF3P0000020>bF3P80[Jf]303/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]00H000000?bP403lX100[Jf]0?nT
4@0000060?nT4@800000203oY1401P000000oj@A0?nT4@3oY140[Jf]0?nV4@8000005P3oYQ40102]
[Jd000000?nV4@0000090?nV4@030000003oYQ40ojHA00`0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^
0:f][AL0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050?bP408000002P3lX100
0`000000o:0@0?bP40030?bP40040:f][@3fW0l00000000000L0mY`?0P0000060?JL3`8000000P3f
W0l0102][Jd0k9H>0>bF3P0000030>bF3P80[Jf]0`0000070>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/0102iM@/00`2][Jd0/>3V0;3PiP190;3PiP40oooo001Q0;3PiP030:f][@3C
Q`h0dhL>00<0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<000000P2]
[Jd20?bP408000000P3lX100102][Jd0oj@A0?nT4@0000050?nT4@800000203oY14010000000oj@A
0?nT4@2][Jd20?nV4@8000005@3oYQ42000000030?nV4@000000ojHA00T0ojHA00<000000?nV4@3o
YQ40303oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403l
X1001@3lX102000000X0o:0@00<000000?bP403lX1000`3lX100102][Jd0mY`?0000000000070?JL
3`8000001P3fW0l01@000000mY`?0?JL3`3fW0l0[Jf]0080k9H>00<000000>bF3P3/UPh0103/UPh0
102][Jd000000000000000050>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2i
M@/00`2][Jd0/>3V0;3PiP180;3PiP40oooo001P0;3PiP030:f][@3CQ`h0dhL>00@0dhL>00<0[Jf]
0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40020?bP40<000000P2][Jd40?bP40050000003lX100
o:0@0?bP402][Jd00P3oY1400`000000oj@A0?nT4@030?nT4@800000203oY14010000000oj@A0?nT
4@2][Jd20?nV4@800000503oYQ4010000000ojHA0:f][@00000;0?nV4@030000003oYQ40ojHA00P0
ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA005@3oYA0<0:f][AP0
oj<@00<0[Jf]0?bP403lX1001@3lX102000000X0o:0@00<000000?bP403lX1000`3lX100102][Jd0
mY`?0000000000070?JL3`8000001P3fW0l01@000000mY`?0?JL3`3fW0l0[Jf]00<0k9H>00<00000
0>bF3P3/UPh0103/UPh01P000000k9H>0:f][@2][Jd0k9H>00000080k9H>00<0[Jf]0=^:3@3KRPd0
2`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0/>3V04L0/>3V0@3oool005l0/>3V00<0
[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40040:f][@3lX10000000?bP40<0[Jf]
00<000000?bP403lX1000`3lX102000000<0o:0@00<0[Jf]0?nT4@3oY1401P3oY142000000L0oj@A
0P0000020?nT4@030:f][@3oYQ40ojHA008000004`3oYQ4010000000ojHA00000000000<0?nV4@03
0000003oYQ40[Jf]00P0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS40020?nS40X0[Jf]3P3oXa000`2][Jd0
o:0@0?bP40050?bP408000001@3lX1000`000000o:0@0?bP40080?bP40040:f][@3fW0l000000000
00L0mY`?0P0000060?JL3`050000003fW0l0mY`?0?JL3`2][Jd00`3/UPh00`000000k9H>0>bF3P04
0>bF3P040000003/UPh0k9H>0>bF3P80[Jf]0P0000000`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>73P06
0=>73P030:f][@3_V100kiP@00/0kiP@0P0000020:f][@<0o:0@00<000000?bP403lX1000`3lX100
0`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A00D0oj@A0P0000080?nT4@8000000P3oY140
0`2][Jd0ojHA0?nV4@0200000180ojHA00D000000?nV4@000000ojHA0:f][@040?nV4@P0[Jf]00<0
00000:f][@3oYQ40303oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0
[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40X0[Jf]103oXa000`2][Jd0o:0@0?bP
40050?bP408000001@3lX1000`000000o:0@0?bP40080?bP40040:f][@3fW0l00000000000L0mY`?
0P0000050?JL3`8000000`3fW0l00`2][Jd0k9H>0>bF3P020>bF3P030000003/UPh0k9H>00<0k9H>
00<000000>bF3P3/UPh0103/UPh3000000`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][DL0/>3V
0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00T0kiP@100000050?bP40030000003l
X100o:0@00<0o:0@00<000000?bP403lX1000P3lX1000`2][Jd0oj@A0?nT4@050?nT4@800000203o
Y14200000080oj@A00<0[Jf]0?nV4@3oYQ400P0000080?nV4@<000001`3oYQ42000000L0[Jf]203o
YQ400`000000ojHA0?nV4@0<0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01H0oj<@202][Jd40?bP408000001@3l
X1000`000000o:0@0?bP40080?bP40040:f][@3fW0l00000000000L0mY`?0P0000050?JL3`800000
0`3fW0l00`2][Jd0k9H>0>bF3P080>bF3P030000003/UPh0k9H>00@0k9H>00@000000:f][@2][Jd0
[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`80[Jf]A`2`h>H10?ooo`00G@2`h>H20:f][@P0dhL>
00<0[Jf]0>nH403_V1001`3_V10010000000kiP@0:f][@2][Jd2000000D0o:0@00<000000?bP403l
X1000`3lX1000`000000o:0@0?bP40020?bP40030:f][@3oY140oj@A00D0oj@A0P0000080?nT4@80
00000P3oY1400`2][Jd0ojHA0?nV4@0200000080ojHA1P0000000`3oYQ400000000000030?nV4@<0
[Jf]0P000000102][Jd0ojHA0?nV4@2][Jd40?nV4@030000003oYQ40ojHA00D0ojHA00<000000?nV
4@3oYQ40303oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40040:f][@3lX100o:0@0?bP40@0[Jf]0P000005
0?bP40030000003lX100o:0@00P0o:0@00@0[Jf]0?JL3`00000000001`3fW0l2000000D0mY`?0P00
00030?JL3`030:f][@3/UPh0k9H>00P0k9H>00<000000>bF3P3/UPh0103/UPh010000000[Jf]0=^:
3@3KRPd20:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo
001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001@3_V10200000080[Jf]0P3_
V102000000D0o:0@00<000000?bP403lX1000`3lX1000`000000o:0@0?bP40020?bP40030:f][@3o
Y140oj@A00D0oj@A0P0000080?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@04000000L0ojHA0P00
00030:f][@80ojHA00<000000?nV4@0000000`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@030000003o
YQ40ojHA00D0ojHA00<000000?nV4@3oYQ40303oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@00D0o:0@0P0000050:f][@030000002][Jd0o:0@00P0o:0@00@0[Jf]0?JL3`0000000000
1`3fW0l2000000D0mY`?0P0000030?JL3`030:f][@3/UPh0k9H>00P0k9H>00<000000>bF3P3/UPh0
103/UPh00`000000[Jf]0=^:3@030=^:3@80[Jf]00<000000=^:3@3KRPd0103KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]
203CQ`h00`2][Jd0kiP@0>nH40030>nH40<0000000<0[Jf]0>nH403_V1000P3_V102000000D0o:0@
00<000000?bP403lX1000P3lX1000`000000o:0@0?bP40030?bP40030:f][@3oY140oj@A00D0oj@A
0P0000080?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@02000000@0ojHA1@2][Jd2000000D0ojHA
0P0000040?nV4@030:f][@3oYQ40ojHA0080ojHA00<000000?nV4@3oYQ401@3oYQ400`000000ojHA
0?nV4@0<0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001@3lX102000000D0o:0@
00<000000?bP402][Jd01@2][Jd30?bP40040:f][@3fW0l00000000000P0mY`?00<000000?JL3`3f
W0l00`3fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh00`000000k9H>0>bF3P040>bF3P03
0000002][Jd0fhX=00@0fhX=00<000000:f][@0000001@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`04
0:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]09MP2`2GH0/0[Jf]203CQ`h01@2]
[Jd0kiP@0>nH403_V10000000080kiP@00<0[Jf]0000003_V100103_V102000000D0o:0@00<00000
0?bP403lX1000P3lX1000`000000o:0@0?bP40030?bP40030:f][@3oY140oj@A00D0oj@A0P000008
0?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@02000000@0[Jf]1@3oYQ42000000D0ojHA00<00000
0?nV4@3oYQ400`3oYQ40102][Jd0ojHA0?nV4@3oYQ42000000L0ojHA00<000000?nV4@3oYQ40303o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00D0o:0@0P0000050?bP40030000003l
X100o:0@00D0o:0@1@2][Jd00`3fW0l000000?JL3`070?JL3`800000103fW0l2000000<0mY`?00<0
[Jf]0>bF3P3/UPh0203/UPh00`000000k9H>0>bF3P040>bF3P030000002][Jd0fhX=00@0fhX=00@0
00000=^:3@000000[Jf]0P0000020=^:3@030:f][@2iM@/0^GD;00L0^GD;00D0[Jf]08QF1`28EPL0
R5H70:f][@140;3PiP40oooo001J0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0203CQ`h01@2][Jd0
kiP@000000000000kiP@0080[Jf]00<0kiP@0000003_V100103_V102000000D0o:0@00<000000?bP
403lX1000P3lX1000`000000o:0@0?bP40030?bP40030:f][@3oY140oj@A00D0oj@A0P0000080?nT
4@80000000<0oj@A0:f][@2][Jd00P2][Jd2000000T0ojHA0P0000050?nV4@030000003oYQ40ojHA
00<0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000070?nV4@030000003oYQ40ojHA00`0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40060?bP40<000000`3lX1000`000000o:0@0?bP4008
0?bP40030:f][@3fW0l0[Jf]0080000000<0[Jf]0?JL3`3fW0l0103fW0l2000000@0mY`?0P000003
0?JL3`030:f][@3/UPh0k9H>00P0k9H>00<000000>bF3P3/UPh0103/UPh00`000000[Jf]0=^:3@03
0=^:3@040000003KRPd0fhX=0=^:3@@0000000<0fhX=0:f][@2iM@/0202iM@/01@2][Jd0R5H708QF
1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P050:f]
[@00000000000000002][Jd00`3_V1000`000000kiP@0>nH40030>nH408000001@3lX1000`000000
o:0@0?bP40020?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?nT4@3oY1401@3oY142000000L0
oj@A00H0[Jf]000000000000[Jf]0?nT4@2][Jd30?nV4@800000203oYQ400`000000ojHA0?nV4@04
0?nV4@030000003oYQ40ojHA00<0ojHA00@0[Jf]0?nV4@3oYQ40ojHA0P0000070?nV4@030000003o
YQ40ojHA00`0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40060?bP4080000000<0
o:0@0000000000000P00000:0?bP40030:f][@3fW0l0mY`?0080000000<0mY`?0:f][@2][Jd00P2]
[Jd20?JL3`800000103fW0l2000000<0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh00`000000k9H>0>bF
3P040>bF3P030000002][Jd0fhX=00<0fhX=00@000000=^:3@3KRPd0fhX=0`0000030:f][@T0^GD;
00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP030:f][@2G
H0/0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01@3CQ`h00`000000[Jf]0:f][@02000000@0kiP@00<0
00000>nH403_V1000`3_V102000000D0o:0@00<000000?bP403lX1000P3lX1000`000000o:0@0?bP
40030?bP40040:f][@3oY1400000000000@0oj@A0P0000030?nT4@@0[Jf]00<0oj@A000000000000
0P3oY140102][Jd0ojHA0?nV4@3oYQ42000000P0ojHA00<000000?nV4@3oYQ40103oYQ400`000000
ojHA0?nV4@030?nV4@030:f][@3oYQ40ojHA00<000001P3oYQ43000000d0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP40060?bP40800000103lX1000`000000o:0@0?bP40080?bP4003
0:f][@3fW0l0mY`?008000001@3fW0l20:f][@800000103fW0l2000000<0mY`?00<0[Jf]0>bF3P3/
UPh0203/UPh2000000D0k9H>00<000000:f][@3KRPd00`3KRPd00`000000fhX=0=^:3@020=^:3@80
00000P3KRPd00`2][Jd000000;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00L0dhL>00@000000=>73P2]
[Jd0kiP@0P0000040>nH40030000003_V100kiP@00<0kiP@0P0000040?bP408000000`3lX1020000
00@0o:0@1@0000040?nT4@8000000`2][Jd50?nT4@8000000P3oY140102][Jd0ojHA0?nV4@3oYQ42
000000L0ojHA0P0000060?nV4@030000003oYQ40ojHA00<0ojHA00H0[Jf]0?nV4@3oYQ4000000?nV
4@0000060?nV4@<000003@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00H0o:0@
0P0000040?bP40030000003lX100o:0@00P0o:0@00<0[Jf]0?JL3`3fW0l00P0000070?JL3`800000
102][Jd2000000<0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh2000000D0k9H>00<000000:f][@3KRPd0
0`3KRPd00`000000fhX=0=^:3@020=^:3@8000000P3KRPd00`2][Jd000000;Ue2`070;Ue2`030:f]
[@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP
2`2GH0/0[Jf]00H0dhL>0P0000020:f][@030>nH40000000000000@0kiP@00<000000>nH403_V100
0P3_V1000`2][Jd00000000000040?bP408000000`3lX102000000070?bP4000000000000000003l
X100[Jf]0?nT4@0200000080oj@A0P2][Jd2000000P0oj@A00D000000?nT4@3oY140oj@A0:f][@03
0?nV4@8000001`3oYQ400`000000ojHA0?nV4@060?nV4@030000003oYQ40ojHA0080ojHA00<0[Jf]
0?nV4@0000000P3oYQ400`000000ojHA0?nV4@040?nV4@<000003@3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@00H0o:0@0P0000040?bP40030000003lX100o:0@00P0o:0@00<0[Jf]
0?JL3`3fW0l00P0000070?JL3`800000103fW0l200000080[Jf]00<0mY`?0:f][@3/UPh02@3/UPh2
000000D0k9H>00<000000:f][@3KRPd00P3KRPd2000000@0fhX=0P0000020=^:3@040:f][@000000
00000:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I
0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd0103CQ`h01`000000dhL>0:f][@000000dhL>0:f][@3_
V1000P0000040>nH40030000003_V100kiP@0080kiP@0P0000050?bP408000000`3lX103000000@0
o:0@00@0[Jf]0?nT4@00000000000P2][Jd30?nT4@8000001`3oY1401@000000oj@A0?nT4@3oY140
[Jf]00<0ojHA00<000000?nV4@0000001P3oYQ400`000000ojHA0?nV4@070?nV4@040000003oYQ40
ojHA0:f][@8000002P3oYQ43000000d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP
40060?bP40800000103lX1000`000000o:0@0?bP40080?bP40030:f][@3fW0l0mY`?008000001`3f
W0l2000000D0mY`?0P000000103fW0l0[Jf]0:f][@2][Jd90>bF3P8000001@3/UPh00`000000[Jf]
0=^:3@020=^:3@800000103KRPd200000080fhX=00D0[Jf]0;Ue2`000000^GD;0:f][@050;Ue2`03
0:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;
09MP2`2GH0/0[Jf]00<0dhL>00P000000=>73P2][Jd0dhL>0000003CQ`h0[Jf]0>nH40800000103_
V1000`000000kiP@0>nH40020>nH408000001@3lX102000000<0o:0@0P0000040?bP40<0[Jf]0P00
00050?nT4@8000001P3oY142000000<0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ42000000D0ojHA00<0
00000?nV4@3oYQ402@3oYQ43000000`0ojHA0`00000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX1001P3lX102000000@0o:0@00<000000?bP403lX100203lX1000`2][Jd0mY`?0?JL
3`02000000L0mY`?0P0000050?JL3`8000000P3fW0l01@2][Jd0k9H>0:f][@2][Jd0000000H0k9H>
0P0000050>bF3P030000002][Jd0fhX=0080fhX=0P0000040=^:3@8000000P3KRPd00`2][Jd0^GD;
000000020;Ue2`030:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V
0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@020=>73P80000000L0[Jf]0=>73P3CQ`h0
00000=>73P2][Jd0kiP@00800000103_V1000`000000kiP@0>nH40020>nH408000001@3lX1020000
00<0o:0@0P0000001`3lX100[Jf]0:f][@2][Jd0o:0@0:f][@3oY1400P0000050?nT4@8000001P3o
Y142000000<0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ43000000@0ojHA00<000000?nV4@3oYQ402`3o
YQ400`2][Jd0ojHA0?nV4@0:0?nV4@<000003@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3l
X100o:0@00H0o:0@0P0000040?bP40030000003lX100o:0@00P0o:0@00<0[Jf]0?JL3`3fW0l00P00
00070?JL3`8000001@3fW0l200000080mY`?00D0[Jf]0>bF3P3/UPh0k9H>000000020:f][@@0k9H>
0P0000050>bF3P030000002][Jd0fhX=0080fhX=0P0000040=^:3@8000000P3KRPd00`2][Jd0^GD;
0;Ue2`030;Ue2`050:f][@2iM@/0^GD;0;Ue2`2][Jd01028EPL20:f][D80/>3V0@3oool005T0/>3V
00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P080000003CQ`h0dhL>0=>73P000000dhL>0:f][@3_
V102000000@0kiP@00<000000>nH403_V1000P3_V102000000D0o:0@0P0000030?bP4080000000<0
[Jf]0?bP403lX1000P3lX100102][Jd0oj@A0000000000050?nT4@8000001@3oY1400`000000oj@A
000000030?nT4@030:f][@3oYQ40ojHA00@0ojHA1@00000>0?nV4@030:f][@3oYQ40ojHA00X0ojHA
0`00000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001P3lX102000000@0o:0@
00<000000?bP403lX100203lX1000`2][Jd0mY`?0?JL3`02000000L0mY`?0P0000050?JL3`800000
0P3fW0l0102][Jd0k9H>0>bF3P3/UPh2000000050>bF3P2][Jd0[Jf]0:f][@3/UPh00P0000060>bF
3P040000003KRPd0fhX=0=^:3@800000103KRPd200000080fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/2
0:f][@030;Ue2`2][Jd0R5H700<0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;
09MP2`2][Jd0dhL>0P2][Jd020000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@0P0000040>nH
40030000003_V100kiP@0080kiP@0P0000050?bP4080000000@0o:0@0:f][@2][Jd0[Jf]0P000004
0?bP40030:f][@3oY140000000L0oj@A0P0000040?nT4@030000003oY140000000<0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@<000003@3oYQ400`2][Jd0ojHA0?nV4@0E
0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00H0o:0@0P000004
0?bP40030000003lX100o:0@00P0o:0@0P0000000`3fW0l00000000000070?JL3`8000001P3fW0l0
10000000mY`?0?JL3`2][Jd30>bF3P800000103/UPh00`2][Jd00000000000060>bF3P040000003K
RPd0fhX=0=^:3@800000103KRPd200000080fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/20:f][@@0R5H7
0P2][Je20;3PiP40oooo001I0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]0P3CQ`h020000000dhL>
0=>73P3CQ`h000000=>73P2][Jd0kiP@0P0000040>nH40030000003_V100kiP@0080kiP@0P000005
0?bP4080000000@0[Jf]0?bP403lX100o:0@0P0000040?bP40030:f][@3oY140000000L0oj@A0P00
00030?nT4@040000003oY140oj@A000000<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA
0?nV4@0:0?nV4@<000003@3oYQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@
00<0[Jf]0?bP403lX1001P3lX102000000X0o:0@00<000000?bP403lX1000`3lX100102][Jd00000
0000000000070?JL3`8000001P3fW0l2000000030?JL3`2][Jd0k9H>0080k9H>0P0000050>bF3P80
00000P2][Jd40>bF3P030000003KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00`3KRPd010000000
fhX=0=^:3@2][Jd90;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?oo
o`00F@2`h>H00`2][Jd0Uf0;09MP2`02000000<0dhL>00P000000=>73P3CQ`h0dhL>0000003CQ`h0
[Jf]0>nH408000000`3_V1000`000000kiP@0>nH40030>nH408000000`3lX1020:f][@800000103l
X102000000@0o:0@00<0[Jf]000000000000203oY142000000030?nT4@000000oj@A0080oj@A00D0
00000?nT4@3oY140oj@A0:f][@0I0?nV4@030:f][@3oYQ40ojHA00X0ojHA0`0000090?nV4@`0[Jf]
5`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01D0ojD@302][JdH0?nS40030:f]
[@3lX100o:0@00H0o:0@0P00000:0?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?JL3`3fW0l0
1P3fW0l4000000L0mY`?00<000000?JL3`2][Jd0103/UPh00`000000k9H>0>bF3P030>bF3P800000
0P3/UPh30:f][@030>bF3P000000fhX=00<0fhX=00<000000=^:3@3KRPd00`3KRPd01@000000fhX=
0=^:3@3KRPd0[Jf]00P0^GD;0P2][Jd408QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V
00<0[Jf]09MP2`2GH0/00P0000030=>73P060000003CQ`h0dhL>0=>73P000000[Jf]0P3_V1020000
00<0kiP@00<000000>nH403_V1000`3_V102000000<0[Jf]0P3lX102000000@0o:0@0P0000040?bP
40030:f][@000000oj@A00X0oj@A00<000000?nT4@3oY1400P3oY1401@000000oj@A0?nT4@3oY140
[Jf]01T0ojHA00<0[Jf]0?nV4@3oYQ402P3oYQ43000000T0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS4002
0?nS40X0[Jf]3P3oXa000`2][Jd0o:0@0?bP40060?bP408000002P3lX1000`000000o:0@0?bP4003
0?bP40030:f][@3fW0l0mY`?00P0mY`?0P0000070?JL3`80000000D0[Jf]0>bF3P3/UPh0k9H>0000
00070>bF3P030000003/UPh0k9H>00<0k9H>00<0[Jf]0000002][Jd00`3KRPd00`000000fhX=0=^:
3@030=^:3@050000003KRPd0fhX=0=^:3@2][Jd0202iM@/20:f][@@0R5H700<0[Jf]0;3PiP2`h>H0
@02`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;0000002][Jd0000000<0dhL>00H000000=>73P3CQ`h0
dhL>0000002][Jd20>nH408000000`3_V1000`000000kiP@0>nH40030>nH408000001@3lX1020000
00@0o:0@00<000000?bP400000000`3lX1000`2][Jd000000?nT4@0?0?nT4@050000003oY140oj@A
0?nT4@2][Jd06@3oYQ400`2][Jd0ojHA0?nV4@020?nV4@P0[Jf]0`00000=0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@00`0oj<@2P2][Jd40?nS40030:f][@3lX100o:0@00H0o:0@0P00000:0?bP40030000003lX100
o:0@00<0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l00`000000[Jf]0>bF3P020>bF3P030000003/UPh0
k9H>00D0k9H>00<000000>bF3P3/UPh0103/UPh01P000000fhX=0:f][@2][Jd0fhX=000000D0fhX=
00D000000=^:3@3KRPd0fhX=0:f][@080;Ue2`030:f][@28EPL0[Jf]00<0R5H700<0[Jf]0;3PiP2`
h>H0@02`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;0000002GH0/0[Jf]00000080dhL>00L000000=>7
3P3CQ`h000000=>73P2][Jd0kiP@00800000103_V10010000000kiP@0>nH403_V1020:f][@800000
1@3lX102000000D0o:0@0P0000030?bP40030000003oY140oj@A00l0oj@A00D000000?nT4@3oY140
oj@A0:f][@0F0?nV4@P0[Jf]203oYQ43000000d0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa005P3oXa080:f][@D0
o:0@0P00000:0?bP40030000003lX100o:0@00<0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l01@000000
k9H>0>bF3P3/UPh0000000L0k9H>00<000000>bF3P3/UPh0103/UPh01P000000fhX=0=^:3@3KRPd0
[Jf]000000D0fhX=00D000000=^:3@3KRPd0fhX=0:f][@080;Ue2`040:f][@28EPL0R5H70:f][@80
R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00F@2`h>H01P2][Jd0Uf0;0000002GH0/0[Jf]0000
0080dhL>00L000000=>73P3CQ`h000000=>73P2][Jd0kiP@00800000103_V10010000000kiP@0:f]
[@2][Jd20>nH40800000103lX102000000H0o:0@0P0000020?bP40800000403oY142000000<0oj@A
00<0[Jf]0?nV4@3oYQ403P3oYQ460:f][@<0ojHA00<0[Jf]0?nV4@3oYQ402P3oYQ400`000000ojHA
0000000=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00@0[Jf]0?bP403lX100o:0@1@2][Jd2000000X0
o:0@00<000000?bP403lX1000`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`<00000203/UPh00`000000
k9H>0>bF3P040>bF3P030000003KRPd0fhX=0080fhX=0P0000001@2][Jd0fhX=0=^:3@3KRPd00000
00<0fhX=00<0[Jf]0000002iM@/01P2iM@/01`2][Jd0R5H708QF1`28EPL0[Jf]08QF1`2][Jd0@P2`
h>H10?ooo`00F@2`h>H01@000000[Jf]0000002GH0/0[Jf]0080dhL>0P0000020=>73P040000003C
Q`h0[Jf]0>nH40800000103_V1000`000000[Jf]0>nH40030>nH40800000103lX102000000L0o:0@
0`0000000`2][Jd0oj@A0?nT4@0?0?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@070?nV4@L0[Jf]
2@3oYQ400`2][Jd0ojHA0?nV4@0:0?nV4@8000003P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f]
[@3lX100o:0@00H0o:0@0P0000060:f][@<0o:0@0P0000050?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh0203/UPh00`000000k9H>0>bF3P040>bF3P030000003KRPd0fhX=0080fhX=
0P0000001@3KRPd0[Jf]0:f][@3KRPd0000000<0fhX=00<0[Jf]0000002iM@/01P2iM@/01`2][Jd0
R5H708QF1`28EPL0[Jf]08QF1`2][Jd0@P2`h>H10?ooo`00F02`h>H01P000000[Jf]0:f][@000000
Uf0;0:f][@80dhL>00P000000=>73P3CQ`h0dhL>0000003CQ`h0[Jf]0>nH408000000P3_V1020:f]
[@030000003_V100kiP@00<0kiP@0P0000040?bP408000002P3lX1000`2][Jd0oj@A0?nT4@0?0?nT
4@8000000`3oY140102][Jd0ojHA0?nV4@3oYQ460:f][A00ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ40
0`000000ojHA0?nV4@0<0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001P3lX102
000000H0o:0@0`2][Jd200000080[Jf]0`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0
k9H>00P0k9H>00<000000>bF3P3/UPh0103/UPh00`000000fhX=0=^:3@020=^:3@8000000`3KRPd0
1`2][Jd000000=^:3@3KRPd0@FWQ0:f][@0000001`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@P2`h>H10?ooo`00F02`h>H01P000000[Jf]09MP2`000000Uf0;0:f][@80dhL>00P000000=>73P3C
Q`h0dhL>0000003CQ`h0[Jf]0>nH408000000P2][Jd20>nH408000000`3_V102000000030?bP4000
0000o:0@0080o:0@00<000000?bP403lX1002@3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@8000000P3o
Y1450:f][AH0ojHA00<0[Jf]0?nV4@3oYQ402`3oYQ400`000000ojHA0?nV4@0<0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX1001P3lX102000000T0o:0@0P0000020?bP40H0[Jf]503f
W0l00`2][Jd0k9H>0>bF3P080>bF3P030000003/UPh0k9H>00@0k9H>00<000000=^:3@3KRPd00P3K
RPd2000000@0fhX=00H000000:f][@2][Jd0fhX=0:f][@0000070;Ue2`030:f][@28EPL0R5H700<0
R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00E`2`h>H2000000050:f][@2GH0/0000009MP2`2]
[Jd00P3CQ`h020000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@0P0000040>nH408000000`3_
V102000000040?bP40000000o:0@0?bP408000002`3lX1000`2][Jd0oj@A0?nT4@0?0?nT4@800000
0P2][Jd00`3oY140[Jf]0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40
703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00
6P3oXa000`2][Jd0o:0@0?bP40060?bP408000002@3lX102000000D0o:0@00<0[Jf]0?JL3`3fW0l0
102][Jd@0?JL3`030:f][@3/UPh0k9H>00P0k9H>00<000000>bF3P3/UPh0103/UPh00`000000fhX=
0=^:3@030=^:3@030000003KRPd0fhX=0080fhX=00<000000=^:3@3KRPd00P2][Jd00`000000^GD;
0;Ue2`060;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP80000000D0
[Jf]09MP2`000000Uf0;0:f][@020=>73P060000003CQ`h0dhL>0=>73P000000dhL>0P2][Jd20000
00@0kiP@0P0000030>nH408000000P3lX103000000`0o:0@00<0[Jf]0?nT4@3oY1402`3oY1440:f]
[@8000000`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV
4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS
403oXa006P3oXa000`2][Jd0o:0@0?bP40030?bP40D000002@3lX102000000D0o:0@00<0[Jf]0?JL
3`3fW0l0103fW0l50:f][@/0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh00`000000k9H>0>bF3P020>bF
3P030000003/UPh0000000D0fhX=0P0000030=^:3@8000000P3KRPd00`2][Jd000000;Ue2`070;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP80000000D0[Jf]0000002G
H0/0Uf0;0:f][@020=>73P050000003CQ`h0dhL>0=>73P0000000P2][Jd00`3_V100000000000004
0>nH408000000`3_V1000`000000[Jf]0?bP400@0?bP40030:f][@3oY140oj@A00L0oj@A102][Jd4
0?nT4@8000000`3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]
0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40070?bP40P000000P3lX102000000D0o:0@00<0[Jf]
0?JL3`3fW0l02@3fW0l50:f][@H0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh00`000000k9H>0>bF3P03
0>bF3P8000001P3KRPd010000000fhX=0=^:3@3KRPd200000080fhX=00@0[Jf]0000002][Jd0[Jf]
1P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000050:f][@00
0000Uf0;09MP2`2][Jd00P3CQ`h020000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@0P000004
0>nH408000000P3_V102000000030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1400`3oY144
0:f][@P0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ40
0`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA00
0`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00l0o:0@100000050?bP40030:f][@3fW0l0
mY`?00h0mY`?102][Jd20?JL3`030:f][@3/UPh0k9H>00P0k9H>0P0000060>bF3P030:f][@3KRPd0
fhX=00<0fhX=00<000000=^:3@3KRPd00`0000020=^:3@050:f][@000000^GD;0;Ue2`2][Jd01@2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000050:f][@000000
Uf0;09MP2`2][Jd00P3CQ`h020000000dhL>0=>73P2][Jd000000=>73P2][Jd0kiP@0P0000040>nH
40030000003_V10000000080000000<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A0:f][@030:f]
[@`0oj@A0P0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2]
[Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2]
[Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04P3fW0l40:f]
[@T0k9H>0P0000060>bF3P030:f][@3KRPd0fhX=00<0fhX=00<000000=^:3@3KRPd00`0000020=^:
3@030:f][@000000^GD;0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF
1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000050:f][@000000Uf0;09MP2`2][Jd00P3CQ`h02000
0000[Jf]0:f][@3CQ`h000000=>73P2][Jd0kiP@0P0000040>nH40030000003_V100kiP@00<0kiP@
00<0[Jf]0?bP403lX1003P3lX1030:f][A00oj@A0P0000030?nT4@030:f][@3oYQ40ojHA01L0ojHA
00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@
00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0:f][@020:f][@H0k9H>0P0000060>bF3P030:f]
[@3KRPd0fhX=00@0fhX=0P0000000`3KRPd00000000000020=^:3@030:f][@000000^GD;00<0^GD;
00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H2000000050:f]
[@000000Uf0;09MP2`2][Jd00P3CQ`h020000000dhL>0=>73P3CQ`h000000=>73P2][Jd0kiP@0P00
00020>nH40<000001@3_V1000`2][Jd0o:0@0?bP400<0?bP4080[Jf]00<0o:0@0:f][@3oY1403P3o
Y144000000<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/
UPh0k9H>0080k9H>0P2][Jd40>bF3P8000001P3/UPh00`2][Jd0fhX=0=^:3@050=^:3@040000003K
RPd0000000000080fhX=00<0[Jf]0000002iM@/0102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H7
0P2][Je10;3PiP40oooo001G0;3PiP80000000P0[Jf]0000002GH0/0Uf0;0000003CQ`h0[Jf]0000
00<0dhL>00@000000=>73P2][Jd0kiP@0P00000:0>nH40030:f][@3lX100o:0@00T0o:0@0`2][Jd3
0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00@0k9H>0`2][Jd00`3/UPh00000000000060>bF3P030:f][@3KRPd0
fhX=00L0fhX=0P0000020=^:3@030:f][@000000^GD;00H0^GD;0P2][Jd408QF1`80[Jf]@@2`h>H1
0?ooo`00E`2`h>H2000000080:f][@000000Uf0;09MP2`000000[Jf]0=>73P0000020=>73P800000
00<0dhL>0:f][@3_V1000P00000:0>nH40030:f][@3lX100o:0@00L0o:0@0P2][Jd60?bP40030:f]
[@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f]
[@3/UPh0k9H>00L0k9H>00<0[Jf]0000000000001P3/UPh00`2][Jd0fhX=0=^:3@070=^:3@800000
0P3KRPd00`2][Jd000000;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3PiP40oooo
001G0;3PiP80000000D0Uf0;0000002GH0/0Uf0;000000020=>73P030000003CQ`h0dhL>00800000
00@0dhL>0:f][@00000000002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]203lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0
o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P080>bF3P8000000P2][Jd40>bF3P03
0:f][@3KRPd0fhX=00L0fhX=0P0000020=^:3@030:f][@000000000000L0^GD;0P2][Jd308QF1`80
[Jf]@@2`h>H10?ooo`00E`2`h>H20000000509MP2`000000Uf0;0:f][@0000000P3CQ`h200000004
0=>73P000000dhL>0:f][@h0kiP@00@0[Jf]0?bP403lX100o:0@0`2][Jd;0?bP40030:f][@3oY140
oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA00D0ojHA402][Jd^0;3PiQ00[Jf]1`3oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P080>bF3P8000000P3/UPh3
0:f][@030>bF3P2][Jd0fhX=00P0fhX=0P0000030=^:3@8000001`2iM@/20:f][@<0R5H70P2][Je1
0;3PiP40oooo001F0;3PiP80000000H0[Jf]09MP2`000000Uf0;0:f][@0000020=>73P@0000000<0
dhL>0:f][@3_V1003@3_V100102][Jd0o:0@0:f][@2][Jd>0?bP40030:f][@3oY140oj@A01<0oj@A
00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]CP2`h>H?0:f][AD0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00P0k9H>
0P0000050>bF3P<0[Jf]2@3KRPd010000000fhX=0=^:3@3KRPd2000000L0^GD;00<0[Jf]08QF1`2]
[Jd00P28EPL20:f][D40/>3V0@3oool005H0/>3V0P0000001P2][Jd0Uf0;0000002][Jd0Uf0;0000
0080dhL>0`0000020=>73P030:f][@3_V100kiP@00/0kiP@0`2][Jd@0?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]J@2`h>H>0:f]
[@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00H0k9H>100000050>bF3P030000002][Jd0fhX=0080[Jf]1`3KRPd010000000fhX=0=^:3@3KRPd2
000000L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL20:f][D40/>3V0@3oool005H0/>3V0`0000001@2G
H0/0000009MP2`000000[Jf]0080dhL>00<000000=>73P0000000P3CQ`h00`2][Jd0kiP@0>nH4009
0>nH4080[Jf]00<0kiP@0:f][@3lX100403lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][H40/>3V2P2][JdH0?bP40030:f][@3fW0l0
mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0203/UPh2000000@0k9H>0P000000102][Jd0fhX=0=^:3@3K
RPd20:f][@D0fhX=00@000000=^:3@3KRPd0fhX=0P0000070;Ue2`070:f][@28EPL0R5H70:f][@28
EPL0@FWQ0:f][@110;3PiP40oooo001F0;3PiP<0000000D0Uf0;0000002GH0/000000:f][@020=>7
3P030000003CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@<0kiP@00<0[Jf]0?bP
403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3P
iPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00d0k9H>00<000000>bF
3P0000001@3KRPd20:f][@<0fhX=00@000000=^:3@3KRPd0fhX=0P0000070;Ue2`070:f][@28EPL0
R5H708QF1`2][Jd0@FWQ0:f][@110;3PiP40oooo001F0;3PiP<0000000D0[Jf]0000002GH0/00000
0:f][@020=>73P030000003CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1001@3_V1020:f][@D0kiP@
00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA00h0ojHA
1`2][JfS0;3PiPD0[Jf]3@3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0k9H>00h0k9H>
00<000000:f][@3KRPd01P3KRPd20:f][@030=^:3@000000fhX=0080fhX=0P0000070;Ue2`070:f]
[@28EPL0R5H708QF1`2][Jd0@FWQ0:f][@110;3PiP40oooo001F0;3PiPL0000000@0[Jf]0=>73P3C
Q`h00000103CQ`h00`2][Jd0kiP@0>nH40030>nH4080[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40203oYQ460:f][Jl0/>3V1@2][Jd80?bP
40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03P3/UPh00`000000[Jf]0=^:3@080=^:
3@030:f][@000000fhX=0080fhX=0P0000070;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je10;3P
iP40oooo001F0;3PiPL0000000@0[Jf]0=>73P0000000000103CQ`h0102][Jd0kiP@0>nH403_V102
0:f][@T0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@040:f][@3oYQ40
ojHA0?nV4@L0[Jf]^P2`h>H60:f][@80o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00P0fhX=00@000000:f][@2][Jd0fhX=0P0000080;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H700000080dhL>00<000000=>73P3CQ`h0
0`3CQ`h0102][Jd0kiP@0:f][@00000;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1404@3oY1460:f][LL0/>3V1@2][JdE0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0203KRPd00`000000fhX=0=^:3@020:f][@030000002iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28
EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP@0000000<0Uf0;0000002][Jd00P3CQ`h00`000000
dhL>0=>73P030=>73P80[Jf]0P00000;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y1403@3oY1440:f][M80/>3V1@2][Jd@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3K
RPd0203KRPd010000000fhX=0=^:3@3KRPd2000000030:f][@2iM@/0^GD;00D0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP@000000P2GH0/0102][Jd0dhL>0=>73P000004
0=>73P80[Jf]00<0kiP@0000000000002`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140
oj@A00T0oj@A102][JgK0;3PiP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0
fhX=00H0fhX=00<000000=^:3@0000000`3KRPd2000000030;Ue2`2][Jd0^GD;00D0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP<000000`2GH0/0102][Jd0dhL>0=>73P00
00020=>73P80[Jf]00<0dhL>0:f][@3_V1000P00000:0>nH40030:f][@3lX100o:0@0100o:0@00<0
[Jf]0?nT4@3oY140103oY1450:f][N<0/>3V1@2][Jd70?JL3`030:f][@3/UPh0k9H>0100k9H>00<0
[Jf]0=^:3@3KRPd01P3KRPd2000000<0fhX=0P0000020;Ue2`030:f][@2iM@/0^GD;00<0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP<000000`2GH0/01P2][Jd0dhL>0=>7
3P000000dhL>0:f][@<0dhL>00@0[Jf]0>nH403_V10000002P3_V1000`2][Jd0o:0@0?bP400@0?bP
40030:f][@3oY140oj@A00@0[Jf]k@2`h>H50:f][@80mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@000000^GD;0080^GD;0P2][Jd30;Ue2`040:f][@28EPL0R5H7
08QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H3000000<0Uf0;00D0[Jf]0=>73P3CQ`h000000:f][@04
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1003`3lX1040:f][OH0/>3V102][JdA
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0000002iM@/0102iM@/0102][Jd0^GD;0;Ue2`2]
[Jd308QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000080:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>
0:f][@0000050=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX100303lX1030:f][Oh0
/>3V0`2][Jd>0>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01@2iM@/30:f][@<0
R5H700<0[Jf]045Yh@2`h>H0@02`h>H10?ooo`00EP2`h>H2000000040:f][@2GH0/0Uf0;09MP2`80
[Jf]00<0dhL>0000003CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00X0
o:0@0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3P
iP2`h>H0?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0309MP2`040:f][@3CQ`h0dhL>0000
00D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f]
[O@0/>3V102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
00L0^GD;0P2][Jd308QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00<000000:f][@2G
H0/00P2GH0/20:f][@80dhL>00<000000=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH4003
0:f][@3lX100o:0@00@0o:0@0`2][Jd00`2aZid0[Jf]0;VbYP0:0;VbYP<0[Jf]kP2`h>H30:f][@l0
`kfk0`2][Jd40>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f][@<0
R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`80[Jf]
00<0dhL>0000000000001@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@
0P2][Jd40;6[W@030:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/0
3`33_K/00`2][Jd0_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00T0
00000:f][@2GH0/0Uf0;0:f][@2GH0/0[Jf]0=>73P0000001P3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100[Jf]0080[Jf]1P2aZid00`2][Jd0^K:V0;VbYP0=0;VbYP030:f][@2n]j`0[Jf]
00<0[Jf]h02`h>H30:f][@D0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0030;ji
^080[Jf]3@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]0080R5H700<0[Jf]0;3P
iP2`h>H0?`2`h>H10?ooo`00EP2`h>H010000000[Jf]09MP2`2][Jd209MP2`030:f][@3CQ`h0dhL>
00H0dhL>00<0[Jf]0>nH403_V1002P3_V1030:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[0030;jg[0@0[Jf]f02`h>H40:f][@P0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0050;ji^080[Jf]2`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`060:f][@28EPL0R5H7
0:f][@28EPL0[Jf]@@2`h>H10?ooo`00E@2`h>H2000000030:f][@2GH0/0[Jf]0080Uf0;00<0[Jf]
0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>
0;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00L0_[Vh0P2][Jd90=^:3@030:f][@2iM@/0^GD;00L0^GD;00@0[Jf]
08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001E0;3PiP8000000P2][Jd309MP2`030:f][@3CQ`h0
dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/0
0`2][Jd0_[Vh0;ji^0070;ji^0@0[Jf]1`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]@@2`h>H10?ooo`00E@2`h>H200000080[Jf]0`2GH0/00`2][Jd0dhL>0=>73P06
0=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0
[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2]
[Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2]
[Je00;3PiP40oooo001E0;3PiP80000000<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0dhL>0=>73P06
0=>73P040:f][@3_V100kiP@0>nH4080[Jf]102TWXl00`2][Jd0/J^M0;6[W@020;6[W@80[Jf]1`2a
Zid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[001@2]
[Jfd0;3PiPH0[Jf]1`37`K`00`2][Jd0a/2l0<K0_00?0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0
[Jf]0;ji^02n^KP00`2n^KP20:f][@H0_[Vh0P11JN420:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H2000000050:f][@2GH0/0
Uf0;09MP2`2][Jd02@3CQ`h0102][Jd0kiP@0:f][@2][Jd40:BNS`80@FWQ00<0[Jf]0;6[W@2aZid0
102aZid20:f][@D0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f]
[@31^[00`KZ`00D0`KZ`1P2][JfY0;3PiPD0[Jf]3@37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0`kfk00L0`kfk0P11JN440<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]1`2n^KP00`11JN40
[Jf]045Yh@020;B`/@80[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f]
[D00/>3V0@3oool005D0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0[Jf]00T0dhL>0P2][Jd60:BN
S`03045Yh@2TWXl0@FWQ00P0/J^M0P2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg
[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00;0<6j/0D0[Jf]W`2`h>H50:f][A80al6l00<0[Jf]0<K0
_036`;`04036`;`00`2][Jd0`kfk0<>m^`040<>m^`<0@FWQ1P33_K/0102][Jd0_[Vh0:f][@2][Jd8
0;ji^004045Yh@2n^KP0[Jf]045Yh@80];2a0P11JN420:f][@X0^GD;00@0[Jf]08QF1`28EPL0R5H7
0P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0Y9j?045Yh@050:BNS`80@FWQ00@0Y9j?0:f][@11JN40/J^M0P11JN460;6[W@80[Jf]
00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0100`KZ`
1P2][JfD0;3PiPD0[Jf]0P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/01@33_K/2045Yh@D0`kfk0`2][Jd80;ji^080@FWQ0P2n^KP0102][Jd0@FWQ
0;B`/@2d/;42045Yh@80];2a0P2][Jd80;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?oo
o`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd20:BNS`03
045Yh@2TWXl0Y9j?00<0Y9j?0P11JN400`2TWXl0[Jf]045Yh@02045Yh@T0/J^M0`2][Jd?0;VbYP03
0:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[00102][Jd0`kfc0<>m/`33_K<70:f]
[HL0/>3V1P2][Jd70<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`050<>m^`80@FWQ0P33_K/30:f][@030<>m^`2][Jd0_[Vh00H0_[Vh0`11JN430;ji
^0040:f][@11JN40];2a0;B`/@80@FWQ102d/;400`2][Jd0^GD;0;Ue2`050;Ue2`040:f][@28EPL0
R5H708QF1`80[Jf]@02`h>H10?ooo`00E@2`h>H00`000000/>3V0:f][@0309MP2`030:f][@3CQ`h0
dhL>00<0dhL>0P2][Jd00`11JN40Y9j?045Yh@060:BNS`03045Yh@2TWXl0[Jf]0080/J^M00<0@FWQ
0;6[W@2aZid00`2aZid00`11JN40/J^M0;6[W@030;6[W@030:f][@2i/ZH0[Jf]00<0[Jf]2`2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<8
0:f][GX0/>3V1@2][Jd=0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`0
0`2][Jd0`kfk0<>m^`050<>m^`80@FWQ0P2][Jd40<>m^`040:f][@2n^KP0_[Vh0;ji^0<0@FWQ0`2n
^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2d/;40];2a0080@FWQ1@2d/;420:f][@D0^GD;00@0
[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00<0
[Jf]0=>73P3CQ`h00P3CQ`h01@2][Jd0RXEe08Z5M@11JN40Y9j?0080@FWQ1@2TWXl00`11JN40Y9j?
0:f][@020;6[W@03045Yh@2aZid0/J^M00<0/J^M00<0@FWQ0;6[W@2aZid00`2aZid00`2][Jd0^K:V
0;VbYP030;VbYP<0[Jf]202i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04033_K<90:f][FT0/>3V202][JdB0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`020<>m^`<0[Jf]0P11JN460<>m^`030:f]
[@2n^KP0_[Vh00<0@FWQ102n^KP00`11JN40_[Vh0;ji^0020;ji^003045Yh@2d/;40];2a0080@FWQ
102d/;400`2][Jd0@FWQ045Yh@020:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40
oooo001E0;3PiP030000002`h>H0[Jf]00<0Uf0;00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0308Z5M@04
045Yh@2][Jd0@FWQ045Yh@D0Y9j?00<0@FWQ0:BNS`2][Jd00P2aZid00`11JN40/J^M0;6[W@030;6[
W@07045Yh@2aZid0/J^M0;6[W@11JN40/J^M0:f][@080;VbYP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg
[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd00P2][Jd30<>m^`80@FWQ1P33
_K/0102][Jd0_[Vh0;ji^02n^KP2045Yh@@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP00`11JN40];2a
0;B`/@02045Yh@<0];2a00L0@FWQ0;B`/@11JN40[Jf]09nKX011JN40[Jf]0080^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je00;3PiP40oooo001G0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P2]
[Jd01P11JN40RXEe08Z5M@2:QGD0@FWQ0:BNS`80@FWQ1@2TWXl2045Yh@040:f][@2aZid0/J^M045Y
h@D0/J^M00L0@FWQ0;6[W@2aZid0/J^M045Yh@2aZid0[Jf]00/0^K:V102][Jd00`2i/ZH0[Jf]0;jg
[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd60<>m^`80@FWQ1P33_K/0102][Jd0_[Vh0;ji
^02n^KP2045Yh@@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP00`11JN40];2a0;B`/@02045Yh@080;B`
/@2][Jd0@FWQ045Yh@2d/;40@FWQ0:f][@2OVj02045Yh@<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n
0;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd00`2:QGD0@FWQ045Yh@0308Z5
M@04045Yh@2TWXl0@FWQ045Yh@80[Jf]0`2TWXl2045Yh@040:f][@2aZid0/J^M045Yh@@0/J^M0P11
JN430;6[W@03045Yh@2aZid0[Jf]00l0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0
[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng;`2]
[Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04P38`K/00`2][Jd0al6l0<O1
_00B0<O1_0030:f][@36`;`0a/2l00/0a/2l102][Jd00`36`;`0[Jf]0<>m^`060<>m^`80@FWQ0P33
_K/3045Yh@030<>m^`2][Jd0_[Vh0080_[Vh0P11JN440;ji^003045Yh@2n^KP0_[Vh0080_[Vh0P11
JN40102d/;40@FWQ045Yh@2][Jd20;B`/@06045Yh@2d/;40];2a045Yh@2OVj00@FWQ0P2OVj000`11
JN40[Jf]08QF1`0308QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2G
H0/00P2GH0/00`2][Jd0RXEe08Z5M@02045Yh@<0RXEe00@0@FWQ0:BNS`11JN40@FWQ0P2TWXl20:f]
[@80Y9j?00D0@FWQ0:f][@2aZid0/J^M045Yh@040;6[W@<0@FWQ0P2aZid00`11JN40/J^M0:f][@0@
0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0
b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`0
0`2][Jd0`kfk0<>m^`050<>m^`80@FWQ00L0`kfk045Yh@33_K/0`kfk045Yh@33_K/0[Jf]00<0_[Vh
0P11JN440;ji^080@FWQ0`2n^KP2045Yh@030;B`/@11JN40@FWQ00<0];2a00<0@FWQ0;B`/@2d/;40
0P11JN4309nKX003045Yh@2OVj00[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`
h>H0102][Jd0Uf0;09MP2`2GH0/20:f][@80RXEe0P11JN4308Z5M@04045Yh@2TWXl0@FWQ045Yh@80
Y9j?00<0@FWQ0:BNS`2][Jd00P2TWXl01011JN40/J^M0;6[W@11JN440;6[W@<0@FWQ00D0/J^M045Y
h@11JN40/J^M0:f][@060;VbYP@0@FWQ1P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`0
0`2][Jd0`KZ`0<6j/0030<6j/0<0@FWQ2`31^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0140al6l00<0[Jf]0<K0_036`;`00`36`;`40:f][@T0a/2l00<0[Jf]0<>m^`33_K/00P33_K/2
045Yh@040<>m^`11JN40@FWQ045Yh@@0`kfk00<0@FWQ0<>m^`2][Jd00P2n^KP2045Yh@@0_[Vh0P11
JN430;ji^080@FWQ00<0[Jf]0;B`/@11JN400`2d/;401011JN40];2a0;B`/@2][Jd409nKX003045Y
h@2OVj00[Jf]00<0R5H700<0[Jf]0;3PiP2`h>H0?P2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;09MP
2`2GH0/20:f][@80RXEe0P11JN4208Z5M@05045Yh@2][Jd0@FWQ045Yh@2TWXl00`11JN420:BNS`<0
[Jf]00<0@FWQ0;6[W@11JN40102aZid3045Yh@050;6[W@11JN40@FWQ045Yh@2][Jd01@2i/ZH2045Y
h@80^K:V00@0@FWQ0;VbYP2i/ZH0@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`0
0`2][Jd0`KZ`0<6j/0050<6j/0@0@FWQ2031^[000`2][Jd0`kfc0<>m/`0D0<>m/`030:f][@35_[D0
aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0
al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0
al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0040:f][@11JN40`kfk0<>m^`80@FWQ0P33
_K/2045Yh@D0`kfk00<0@FWQ0<>m^`2][Jd00P2n^KP2045Yh@@0_[Vh0P11JN420;ji^0030:f][@11
JN40@FWQ0080];2a00D0@FWQ0;B`/@2d/;40];2a045Yh@020;B`/@030:f][@2OVj00Wi^P0080Wi^P
00@0@FWQ09nKX02OVj00[Jf]0P28EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40oooo001F0;3PiP030:f]
[@2GH0/0Uf0;00<0[Jf]0P2:QGD2045Yh@80RXEe00D0@FWQ0:f][@2TWXl0@FWQ0:BNS`03045Yh@@0
Y9j?0P2][Jd2045Yh@@0/J^M00@0@FWQ0;6[W@11JN40/J^M0`11JN400`2][Jd0^K:V0;VbYP020;Vb
YP80@FWQ102i/ZH00`11JN40^K:V045Yh@030;VbYP03045Yh@2n]j`0_[N/00/0_[N/102][Jd00`2n
]j`0[Jf]0<6j/0060<6j/080@FWQ2P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje
01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00l0al6l102][Jd@0<K0_080@FWQ00<0`kfk045Yh@33_K/00P11JN420<>m^`80@FWQ1@33_K/2045Y
h@030:f][@2n^KP0_[Vh0080@FWQ102n^KP2045Yh@80[Jf]00<0_[Vh045Yh@11JN400P2d/;42045Y
h@030;B`/@11JN40];2a0080];2a00<0[Jf]09nKX02OVj000P2OVj000`11JN40Wi^P09nKX0020:f]
[@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP2`2][Jd0Hf1C0P2][Jd208Z5
M@80@FWQ0P2:QGD00`11JN40Y9j?0:BNS`020:BNS`<0@FWQ0P2TWXl2045Yh@040:f][@2aZid0@FWQ
045Yh@@0/J^M00P0@FWQ0;6[W@11JN40/J^M045Yh@2aZid0@FWQ0:f][@@0^K:V0P11JN440;VbYP03
045Yh@2i/ZH0@FWQ00<0^K:V00<0[Jf]045Yh@11JN403`2n]j`40:f][@D0`KZ`0P11JN4:0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05@35_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`03
0:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02P37`K`50:f][@80al6l00<0[Jf]0<K0_036
`;`03P36`;`00`11JN40a/2l0:f][@020<>m^`80@FWQ0`33_K/2045Yh@H0`kfk00@0@FWQ0:f][@2n
^KP0_[Vh0P11JN440;ji^080@FWQ0`2n^KP2045Yh@<0];2a0P11JN440;B`/@030:f][@2OVj00Wi^P
0080Wi^P00D0@FWQ09nKX02OVj00[Jf]071^N@020:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=P
D`030:f][@2:QGD0RXEe0080@FWQ0P2:QGD00`11JN40Y9j?0:BNS`030:BNS`04045Yh@2TWXl0Y9j?
0:BNS`80@FWQ00@0[Jf]0;6[W@2aZid0@FWQ0`2][Jd02@2aZid0@FWQ0;6[W@11JN40/J^M045Yh@2a
Zid0@FWQ0:f][@040;VbYP03045Yh@2i/ZH0^K:V00@0^K:V0P11JN430;VbYP030:f][@2n]j`0@FWQ
0080@FWQ3P2n]j`00`2][Jd0`KZ`0<6j/0050:f][@80@FWQ2P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1
^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00d0a/2l0P11JN400`36
`;`0[Jf]0<>m^`020<>m^`03045Yh@33_K/0`kfk0080`kfk0P11JN450<>m^`04045Yh@2][Jd0_[Vh
0;ji^080@FWQ00@0_[Vh0:f][@2][Jd0[Jf]0P11JN430;ji^080@FWQ2@2d/;400`2][Jd0Wi^P09nK
X00209nKX005045Yh@2OVj00[Jf]0:f][@1`KWT00P2][Je00;3PiP40oooo001F0;3PiP80[Jf]0`1S
H5<20:f][@0308Z5M@11JN40@FWQ0080RXEe00<0@FWQ0:BNS`2TWXl0202TWXl01@11JN40[Jf]0;6[
W@2aZid0@FWQ00<0/J^M00T0[Jf]045Yh@2aZid0@FWQ0;6[W@11JN40/J^M045Yh@2][Jd0102i/ZH0
0`11JN40^K:V0;VbYP040;VbYP80@FWQ0`2i/ZH00`2][Jd0_[N/045Yh@0@0;jg[0030:f][@31^[00
`KZ`00D0`KZ`0P11JN430:f][@L0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E
0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_005
0:f][@`0al6l00<0[Jf]0<K0_036`;`00P36`;`3045Yh@P0a/2l00@0@FWQ0<K0_036`;`0[Jf]0`33
_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ1@33_K/01011JN40[Jf]0;ji^02n^KP2045Yh@040:f]
[@2n^KP0_[Vh0;ji^080@FWQ0`2n^KP2045Yh@T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2][Jd0
Wi^P0:f][@02071^N@80[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f]
[@2:QGD0[Jf]0080@FWQ00<0RXEe045Yh@2][Jd02P2TWXl01@11JN40[Jf]0;6[W@2aZid0@FWQ00<0
/J^M0P11JN401`2][Jd0@FWQ0:f][@11JN40/J^M045Yh@2][Jd0102i/ZH00`11JN40^K:V0;VbYP04
0;VbYP80@FWQ0P2i/ZH0102][Jd0_[N/0;jg[011JN4<0;jg[080@FWQ0P2n]j`00`2][Jd0`KZ`0<6j
/0050<6j/080@FWQ0`31^[050:f][@80`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn
]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0
[Jf]0<K0_036`;`00`11JN4:0<K0_004045Yh@36`;`0a/2l0:f][@<0`kfk00<0@FWQ0<>m^`33_K/0
0P33_K/2045Yh@D0`kfk00@0@FWQ0000002n^KP0[Jf]0P11JN440;ji^080@FWQ0`2n^KP2045Yh@T0
];2a00<0[Jf]09nKX02OVj000P2OVj00102][Jd0Wi^P09nKX02][Jd2071^N@80[Jf]?`2`h>H10?oo
o`00EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`050:f][@2:QGD0RXEe0:f][@2:QGD00P11JN400`2]
[Jd0Y9j?0:BNS`080:BNS`04045Yh@2][Jd0/J^M045Yh@@0/J^M0P11JN401`2aZid0@FWQ0;6[W@11
JN40[Jf]045Yh@2][Jd00`2i/ZH2045Yh@H0^K:V0P11JN420;VbYP040:f][@2n]j`0_[N/045Yh@X0
_[N/0`11JN40102n]j`0@FWQ045Yh@2][Jd70<6j/080@FWQ2031^[080:f][A00`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1
^`030:f][@37`K`0al6l00l0al6l0P11JN400`2][Jd0a/2l0<K0_0020<K0_003045Yh@36`;`0a/2l
00P0a/2l00@0@FWQ0<K0_036`;`0[Jf]0`33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ1@33_K/0
1011JN40[Jf]0:f][@2n^KP3045Yh@<0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN4:0;B`/@030:f]
[@2OVj00Wi^P0080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0
[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]0080RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl2045Yh@D0/J^M00@0@FWQ0;6[W@2aZid0/J^M0P11JN40102aZid0@FWQ0:f][@2][Jd20;Vb
YP80@FWQ1P2i/ZH2045Yh@80^K:V00@0[Jf]0;jg[02n]j`0@FWQ2P2n]j`00`11JN40_[N/0;jg[003
0;jg[003045Yh@31^[00`KZ`0080@FWQ0`31^[02045Yh@X0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<;
0:f][@D0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0
b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00:0<O1_0<0@FWQ0P37`K`2045Yh@030:f][@36
`;`0a/2l0080a/2l00<0@FWQ0<K0_036`;`02036`;`2045Yh@030<K0_02][Jd0`kfk0080`kfk00<0
@FWQ0<>m^`33_K/00P33_K/2045Yh@80`kfk0P2][Jd2045Yh@040:f][@2n^KP0_[Vh0;ji^080@FWQ
0`2n^KP00`11JN40_[Vh0;ji^0020;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]09nKX02][Jd0
1@2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1S
H5<00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2:QGD0[Jf]00/0Y9j?00<0[Jf]0;6[W@2aZid0102a
Zid01@11JN40/J^M0;6[W@2aZid0@FWQ0080/J^M00<0@FWQ0:f][@2i/ZH00P2][Jd2045Yh@H0^K:V
0P11JN420;VbYP040:f][@2n]j`0_[N/045Yh@X0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`01011JN40
`KZ`045Yh@11JN440<6j/080@FWQ00<0`KZ`045Yh@31^[001`31^[000`2][Jd0`kfc0<>m/`0>0<>m
/`/0[Jf]4@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1
^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_0090<O1
_004045Yh@37`K`0al6l0<O1_0@0@FWQ00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l0<K0_008
0<K0_080@FWQ00<0a/2l0:f][@33_K/00P33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ0P2][Jd2
0<>m^`80@FWQ00@0[Jf]0;ji^02n^KP0_[Vh0`11JN400`2n^KP0@FWQ0;ji^0040;ji^0030:f][@2d
/;40];2a00P0];2a0P2][Jd609nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H0
0`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00<0RXEe0P2][Jd;0:BNS`030:f][@2aZid0
/J^M0080/J^M0`11JN430;6[W@05045Yh@2aZid0/J^M0;6[W@11JN400`2i/ZH2045Yh@80[Jf]0P2i
/ZH4045Yh@80^K:V00@0[Jf]0;jg[02n]j`0@FWQ2P2n]j`00`11JN40_[N/0;jg[0030;jg[0030:f]
[@11JN40@FWQ00D0`KZ`0`11JN400`31^[00@FWQ045Yh@060<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`11JN40al6l0<O1_0080<O1_003045Yh@37`K`0al6l00<0al6l
0`11JN400`2][Jd0a/2l0<K0_0020<K0_003045Yh@36`;`0a/2l00P0a/2l0P11JN400`36`;`0[Jf]
0<>m^`020<>m^`05045Yh@33_K/0`kfk0<>m^`2][Jd00P11JN440<>m^`80@FWQ00@0[Jf]0;ji^02n
^KP0_[Vh0P11JN400`2n^KP0@FWQ0;ji^0050;ji^0030:f][@2d/;40];2a00P0];2a00<0[Jf]0000
002OVj001@2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=P
D`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[
W@2aZid0102aZid3045Yh@030;6[W@11JN40/J^M0080/J^M00D0@FWQ0;VbYP2i/ZH0^K:V045Yh@03
0;VbYP@0[Jf]00H0^K:V045Yh@11JN40@FWQ0:f][@2n]j`2045Yh@X0_[N/00<0@FWQ0;jg[02n]j`0
0P2n]j`0102][Jd0`KZ`045Yh@11JN450<6j/080@FWQ1031^[02045Yh@@0`KZ`00<0[Jf]0<>m/`11
JN400`11JN4@0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h01@0
al6h00<0[Jf]0<O1^P37`KX02P37`KXA0:f][A40b<6k00<0[Jf]0<S1^`38`K/03@38`K/00`11JN40
b<6k0<S1^`030<S1^`03045Yh@37`K`0al6l00L0al6l0P11JN460<O1_080@FWQ00<0[Jf]0<K0_036
`;`00P36`;`00`11JN40a/2l0<K0_0090<K0_0L0@FWQ0`2][Jd00`33_K/0@FWQ045Yh@040<>m^`03
045Yh@33_K/0[Jf]00<0_[Vh0P11JN480;ji^0030:f][@2d/;40];2a00H0];2a0`2][Jd709nKX005
0:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0[Jf]
00L0RXEe0`2][Jd90:BNS`030:f][@2aZid0/J^M00P0/J^M00D0@FWQ0;6[W@2aZid0/J^M045Yh@03
0;VbYP03045Yh@2i/ZH0^K:V00D0^K:V0`2][Jd00`2i/ZH0[Jf]0;jg[002045Yh@X0_[N/00<0@FWQ
0;jg[02n]j`00P2n]j`0102][Jd0`KZ`045Yh@11JN450<6j/080@FWQ1@31^[000`11JN40`KZ`0<6j
/0020<6j/0040:f][@33_K<0`kfc0<>m/`@0@FWQ0P33_K<3045Yh@T0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k00D0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k00<0b<6k00<0@FWQ0<O1_037`K`0
1`37`K`00`11JN40al6l0<O1_0050<O1_080@FWQ00<0[Jf]0<K0_036`;`00P36`;`00`11JN40a/2l
0<K0_00;0<K0_0050:f][@33_K/0[Jf]0:f][@11JN401033_K/2045Yh@<0`kfk0P11JN400`33_K/0
[Jf]0;ji^0020;ji^080@FWQ202n^KP00`2][Jd0@FWQ0;B`/@050;B`/@040:f][@2d/;40];2a0:f]
[@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C
06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]0;6[W@2aZid02P2aZid3
045Yh@<0^K:V00<0@FWQ0;VbYP2i/ZH0202i/ZH30:f][@80@FWQ2P2n]j`00`11JN40_[N/0;jg[002
0;jg[0040:f][@31^[00@FWQ045Yh@@0`KZ`0P11JN460<6j/080@FWQ0`31^[00102][Jd0`kfc0<>m
/`33_K<2045Yh@H0`kfc1011JN420<>m/`<0@FWQ00<0`kfc0:f][@35_[D05@35_[D00`2][Jd0a[ng
0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k
0<S1^`0D0<S1^`040:f][@11JN40@FWQ045Yh@<0b<6k0P11JN470<S1^`03045Yh@38`K/0b<6k0080
b<6k00<0@FWQ0:f][@11JN402037`K`00`11JN40al6l0<O1_0050<O1_080@FWQ00<0[Jf]0<K0_036
`;`00P36`;`00`11JN40a/2l0<K0_0090<K0_0@0[Jf]0P33_K/00`11JN40`kfk0<>m^`020<>m^`80
@FWQ0`33_K/01011JN40`kfk0<>m^`2][Jd30;ji^080@FWQ202n^KP2045Yh@@0];2a0P2][Jd30;B`
/@030:f][@2OVj00Wi^P00D0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001G0;3P
iP040:f][@1SH5<0Hf1C0:f][@L0RXEe00<0[Jf]0:BNS`2TWXl00P2TWXl00`2][Jd0Y9j?0:BNS`04
0:BNS`030:f][@2aZid0/J^M00`0/J^M0`11JN400`2i/ZH0@FWQ0;VbYP0:0;VbYP040:f][@2n]j`0
@FWQ045Yh@80[Jf]202n]j`2045Yh@<0_[N/00@0[Jf]0<6j/011JN40@FWQ1031^[02045Yh@L0`KZ`
00D0@FWQ0<6j/031^[00`KZ`0:f][@030<>m/`80@FWQ1P33_K<2045Yh@L0`kfc1011JN4D0<Fn]@03
0:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P03
0:f][@38`K/0b<6k01<0b<6k0P11JN430<S1^`80@FWQ00<0b<6k045Yh@11JN401P38`K/00`11JN40
b<6k045Yh@030<S1^`<0@FWQ1`37`K`2045Yh@L0al6l0P11JN400`2][Jd0a/2l0<K0_0020<K0_080
@FWQ1@36`;`50:f][@80a/2l00D0[Jf]0<>m^`33_K/0`kfk045Yh@040<>m^`<0@FWQ00<0`kfk045Y
h@33_K/00P33_K/0102][Jd0_[Vh0;ji^02n^KP2045Yh@P0_[Vh0P11JN420;B`/@80[Jf]1@2d/;40
0`2][Jd0Wi^P09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]
06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0/J^M0;6[
W@0<0;6[W@050:f][@2i/ZH0^K:V0;VbYP11JN402`2i/ZH00`2][Jd0_[N/045Yh@02045Yh@030;jg
[02][Jd0[Jf]0080[Jf]1@2n]j`01P11JN40_[N/0;jg[02n]j`0[Jf]0<6j/080@FWQ1031^[02045Y
h@L0`KZ`00D0@FWQ0<6j/031^[00`KZ`0:f][@030<>m/`80@FWQ1P33_K<2045Yh@L0`kfc00<0@FWQ
0:f][@35_[D01`35_[D4045Yh@P0aKje00<0@FWQ0<Fn]@2][Jd05`36_kL00`2][Jd0al6h0<O1^00D
0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00P38`K/6045Yh@X0b<6k0P11JN40
0`2][Jd0b<6k0<S1^`020<S1^`<0@FWQ1`38`K/3045Yh@<0b<6k0`11JN470<O1_080@FWQ1`37`K`2
045Yh@030:f][@36`;`0a/2l0080a/2l0P11JN400`36`;`0[Jf]0:f][@020:f][@D0a/2l00<0@FWQ
0<K0_02][Jd00`33_K/00`11JN40`kfk0<>m^`020<>m^`80@FWQ00<0`kfk045Yh@33_K/00`33_K/0
102][Jd0_[Vh0;ji^02n^KP2045Yh@P0_[Vh00@0[Jf]045Yh@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P
09nKX00509nKX0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd0
1`2:QGD00`2][Jd0Y9j?0:BNS`050:BNS`80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f]
[@2i/ZH0^K:V0080^K:V00<0@FWQ0;VbYP2i/ZH02@2i/ZH00`2][Jd0_[N/045Yh@02045Yh@D0_[N/
102][Jd20;jg[005045Yh@2n]j`0_[N/0:f][@31^[000P11JN440<6j/080@FWQ1`31^[02045Yh@80
`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN460<>m/`80@FWQ1`33_K<00`11JN40[Jf]0<Fn]@050<Fn
]@<0@FWQ0`35_[D2045Yh@H0aKje00<0@FWQ0<Fn]@2][Jd01011JN480<Jo]`03045Yh@36_kL0a[ng
00P0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P090<O1^PT0@FWQ0`37`KX00`2]
[Jd0b<6k0<S1^`040<S1^`80@FWQ3038`K/00`11JN40b<6k0:f][@050<S1^`80@FWQ1`38`K/3045Y
h@<0b<6k0`11JN470<O1_003045Yh@37`K`0al6l00H0al6l1011JN400`36`;`0[Jf]0:f][@02045Y
h@030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_02][Jd00P33_K/01011JN40`kfk0<>m^`33_K/2
045Yh@P0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P11JN480;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nK
X00509nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD0
0`2][Jd0Y9j?0:BNS`070:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP020;VbYP80@FWQ2P2i/ZH0
0`2][Jd0_[N/045Yh@02045Yh@<0_[N/00<0@FWQ0;jg[02n]j`00`2n]j`30:f][@80@FWQ00@0[Jf]
0<6j/011JN40@FWQ1031^[02045Yh@L0`KZ`0P11JN420<6j/0040:f][@33_K<0`kfc0<>m/`80@FWQ
1P33_K<2045Yh@L0`kfc00<0@FWQ0:f][@35_[D01035_[D2045Yh@H0aKje00<0@FWQ0<Fn]@35_[D0
1035_[D3045Yh@@0a[ng0P11JN460<Jo]`80@FWQ2@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f]
[@37`KX0al6j00/0al6j0P11JN450<O1^P80@FWQ00<0al6j0:f][@38`K/01@38`K/2045Yh@`0b<6k
00<0@FWQ0<S1^`2][Jd01@38`K/2045Yh@L0b<6k0`11JN430<S1^`<0@FWQ1P37`K`2045Yh@H0al6l
0`11JN440:f][@80a/2l0P11JN440<K0_003045Yh@36`;`0a/2l00<0a/2l00D0@FWQ0<K0_02][Jd0
`kfk045Yh@0>0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ1`2n^KP20:f][@X0];2a00<0[Jf]09nK
X02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2][Jd0
Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP020;VbYP80@FWQ2P2i/ZH01`2][Jd0
_[N/045Yh@11JN40_[N/045Yh@2n]j`00P11JN490;jg[0030:f][@11JN40@FWQ0080@FWQ1031^[02
045Yh@L0`KZ`0P11JN420<6j/0040:f][@33_K<0`kfc0<>m/`80@FWQ1P33_K<2045Yh@L0`kfc00<0
@FWQ0:f][@35_[D01035_[D2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D00`35_[D2045Yh@030:f][@36
_kL0a[ng00@0a[ng00<0@FWQ0<Jo]`36_kL00`36_kL00`11JN40a[ng0<Jo]`080<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX02`37`KX2045Yh@H0al6j0P11JN400`2][Jd0b<6k0<S1
^`040<S1^`80@FWQ3038`K/00`11JN40b<6k0:f][@050<S1^`80@FWQ1`38`K/3045Yh@<0b<6k00<0
@FWQ0:f][@11JN401P37`K`2045Yh@<0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0080a/2l0P11
JN430<K0_003045Yh@36`;`0@FWQ00@0a/2l1@11JN4>0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ
1@2n^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V
0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2]
[Jd90;6[W@030:f][@2i/ZH0^K:V0080^K:V0P11JN470;VbYP03045Yh@2i/ZH0^K:V00@0@FWQ00H0
_[N/045Yh@2n]j`0@FWQ0;jg[011JN440;jg[080@FWQ0`2n]j`0102][Jd0`KZ`045Yh@11JN440:f]
[@80@FWQ00<0[Jf]0<6j/031^[001031^[02045Yh@80`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN46
0<>m/`80@FWQ1`33_K<00`11JN40[Jf]0<Fn]@040<Fn]@80@FWQ3@35_[D00`11JN40aKje0:f][@06
0<Jo]`03045Yh@36_kL0a[ng00h0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0;
0<O1^P80@FWQ1`37`KX2045Yh@H0b<6k0P11JN4<0<S1^`03045Yh@38`K/0[Jf]00D0b<6k0P11JN47
0<S1^`03045Yh@38`K/0@FWQ0080b<6k0P11JN400`2][Jd0al6l045Yh@050<O1_080@FWQ0`2][Jd7
0<O1_0030:f][@36`;`0a/2l0080a/2l0`11JN430<K0_080@FWQ1P36`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`040:f][@2n^KP0_[Vh0;ji^080@FWQ0`2n^KP20:f][@<0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H00`2][Jd0RXEe08Z5M@05
08Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M00<0[Jf]
0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP050;VbYP04045Yh@2i/ZH0^K:V0:f][@D0_[N/00@0
@FWQ0;jg[011JN40@FWQ102n]j`2045Yh@<0_[N/00<0[Jf]0<6j/011JN401@31^[02045Yh@030<6j
/02][Jd0[Jf]00@0[Jf]0P11JN420<6j/0040:f][@33_K<0`kfc0<>m/`80@FWQ1P33_K<2045Yh@L0
`kfc00<0@FWQ0:f][@35_[D00`35_[D2045Yh@h0aKje00<0@FWQ0<Fn]@2][Jd01P36_kL00`11JN40
a[ng0<Jo]`0>0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02P37`KX2045Yh@L0
al6j0P11JN460<S1^`80@FWQ3038`K/00`11JN40b<6k0:f][@050<S1^`80@FWQ1P38`K/2045Yh@80
b<6k00L0@FWQ0<S1^`11JN40@FWQ0:f][@000000@FWQ00D0[Jf]0P11JN4:0<O1_0030:f][@36`;`0
a/2l0080a/2l0P11JN401@36`;`0@FWQ0<K0_036`;`0@FWQ00L0a/2l00<0[Jf]0<>m^`33_K/03P33
_K/00`2][Jd0_[Vh0;ji^002045Yh@040;ji^02][Jd0[Jf]0:f][@D0_[Vh00<0[Jf]0;B`/@2d/;40
2@2d/;400`2][Jd0Wi^P09nKX00409nKX0030:f][@2`h>H0/>3V0440/>3V0@3oool005/0/>3V00<0
[Jf]08Z5M@2:QGD0102:QGD00`2][Jd0Y9j?0:BNS`090:BNS`030:f][@2aZid0/J^M00@0/J^M0`2]
[Jd40;6[W@030:f][@2i/ZH0^K:V00<0^K:V00<0@FWQ0;VbYP2i/ZH0102i/ZH2045Yh@80^K:V00<0
[Jf]0;jg[02n]j`0102n]j`2045Yh@H0_[N/00L0@FWQ0;jg[02n]j`0_[N/0:f][@31^[00@FWQ00D0
`KZ`0P11JN460<6j/080@FWQ1`2][Jd2045Yh@H0`kfc0P11JN470<>m/`03045Yh@2][Jd0aKje00<0
aKje0P11JN4@0<Fn]@030:f][@36_kL0a[ng00<0a[ng0P11JN4@0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX02P37`KX2045Yh@P0al6j0P11JN450<S1^`80@FWQ3038`K/2045Yh@03
0:f][@38`K/0b<6k00<0b<6k0P11JN460<S1^`80@FWQ0P38`K/01011JN40[Jf]045Yh@11JN420:f]
[@03045Yh@37`K`0al6l00<0al6l0P11JN4:0<O1_0030:f][@36`;`0a/2l0080a/2l0P11JN420<K0
_080@FWQ2@36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]202n^KP0
0`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]0;3PiP2`h>H0@P2`h>H1
0?ooo`00G02`h>H00`2][Jd0RXEe08Z5M@0308Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[
W@2aZid01`2aZid30:f][@030;6[W@2][Jd0^K:V00D0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Y
h@80^K:V00<0[Jf]0;jg[02n]j`0302n]j`01P11JN40_[N/0;jg[02n]j`0[Jf]045Yh@H0`KZ`0P11
JN460<6j/080@FWQ0`31^[00102][Jd0`kfc0<>m/`33_K<2045Yh@D0[Jf]00<0`kfc045Yh@11JN40
1P33_K<2045Yh@030:f][@35_[D0aKje0080aKje0P11JN4@0<Fn]@030:f][@36_kL0a[ng00<0a[ng
0P11JN4@0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02P37`KX2045Yh@P0al6j
0P11JN450<S1^`80@FWQ3P38`K/4045Yh@80b<6k0P11JN440<S1^`80[Jf]0P11JN420:f][@07045Y
h@38`K/0@FWQ045Yh@2][Jd0al6l045Yh@050<O1_080@FWQ2P37`K`00`2][Jd0a/2l0<K0_004045Y
h@d0a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd:0;ji^0030:f][@2d/;40
];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0/>3V0;3PiP130;3PiP40oooo001M0;3P
iP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[
W@<0[Jf]1@2i/ZH00`11JN40^K:V0;VbYP020;VbYP80@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[00=0;jg
[0@0@FWQ1`31^[03045Yh@D0`KZ`0P11JN430<6j/0030:f][@33_K<0`kfc0080@FWQ1P33_K<00`2]
[Jd0@FWQ045Yh@050:f][@040<>m/`11JN40@FWQ0:f][@@0aKje0P11JN4@0<Fn]@040:f][@36_kL0
a[ng0<Jo]`<0@FWQ4@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00X0al6j0P11
JN480<O1^P030:f][@11JN40@FWQ00@0b<6k0P11JN4>0<S1^`040:f][@000000b<6k0<S1^`@0@FWQ
102][Jd20<S1^`80@FWQ0P38`K/01`11JN40b<6k045Yh@11JN40[Jf]0<O1_011JN401@37`K`2045Y
h@X0al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0`kfk0<>m^`0<0<>m^`<0[Jf]302n^KP00`2]
[Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080[Jf]AP2`h>H10?ooo`00GP2`h>H20:f][@80
RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@0;0;6[W@030:f][@2i/ZH0[Jf]00<0
[Jf]0P2i/ZH01011JN40^K:V0;VbYP2i/ZH2045Yh@<0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2]
[Jd0`KZ`0<6j/0030<6j/0D0@FWQ1031^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<00P11JN470<>m
/`80@FWQ1@33_K<00`2][Jd0@FWQ045Yh@050:f][@80@FWQ4035_[D00`2][Jd0a[ng045Yh@03045Y
h@L0a[ng00<0@FWQ0<Jo]`36_kL02036_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
00X0al6j0P11JN480<O1^P030:f][@11JN40@FWQ00@0b<6k0P11JN490<S1^`T0[Jf]0P38`K/2045Y
h@H0b<6k0P11JN420<S1^`05045Yh@38`K/0@FWQ0<S1^`2][Jd00P37`K`00`11JN40al6l0<O1_002
0<O1_080@FWQ2@37`K`00`11JN40[Jf]0<K0_00B0<K0_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd0
0`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H1
0?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;Vb
YP2i/ZH00`2i/ZH30:f][@<0@FWQ00<0^K:V045Yh@2i/ZH00P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00D0`KZ`0P11JN400`31^[00@FWQ045Yh@020<6j/080@FWQ1031^[000`2]
[Jd0`kfc0<>m/`03045Yh@H0`kfc0P11JN460<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D00P35_[D2045Y
h@L0[Jf]00@0@FWQ0:f][@2][Jd0[Jf]1@35_[D4045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL02036_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00X0al6j0P11JN480<O1^P030:f][@11JN40
@FWQ00<0b<6k00<0[Jf]045Yh@11JN402@2][Jd50<S1^`030:f][@38`K/0b<6k00<0b<6k00<0@FWQ
0<S1^`38`K/01@38`K/00`11JN40b<6k0<S1^`020<S1^`80@FWQ00D0b<6k0:f][@37`K`0al6l045Y
h@040<O1_080@FWQ2@37`K`00`11JN40al6l0:f][@0B0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2]
[Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;420:f][DT0/>3V0@3o
ool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH3
0:f][@030;VbYP11JN40^K:V0080^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00:
0<6j/080@FWQ1P31^[000`2][Jd0`kfc0<>m/`03045Yh@D0`kfc0P11JN470<>m/`80@FWQ00<0[Jf]
0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@050<Fn]@80@FWQ0P35_[D40:f][@<0@FWQ2P2][Jd0
0`36_kL0@FWQ0<Jo]`090<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02@37`KX0
0`2][Jd0@FWQ045Yh@090:f][@80@FWQ0`2][Jd01038`K/0@FWQ045Yh@11JN4<0<S1^`03045Yh@2]
[Jd0b<6k00@0b<6k00<0@FWQ0<S1^`38`K/01038`K/2045Yh@@0b<6k0P11JN400`38`K/0[Jf]045Y
h@04045Yh@<0al6l0P11JN470<O1_080@FWQ00<0al6l0:f][@36`;`04@36`;`00`2][Jd0`kfk0<>m
^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0];2a00<0
[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f][@2aZid0
/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0140_[N/00<0[Jf]
0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`02045Yh@030<>m/`11JN40`kfc00<0`kfc0P11JN47
0<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D00`35_[D00`11JN40aKje0<Fn]@050<Fn]@80@FWQ1@35_[D2
045Yh@030:f][@36_kL0a[ng00@0a[ng00<0@FWQ0<Jo]`36_kL00P36_kL00`2][Jd0@FWQ0:f][@0]
0:f][@030<O1^P11JN40@FWQ00P0al6j00<0[Jf]045Yh@11JN401038`K/3045Yh@@0b<6k00<0@FWQ
0<S1^`38`K/01@38`K/00`11JN40[Jf]0<S1^`040<S1^`03045Yh@38`K/0b<6k00@0b<6k1011JN42
0<S1^`80@FWQ00<0b<6k0:f][@37`K`01`37`K`2045Yh@L0al6l0P11JN400`37`K`0[Jf]0<K0_00A
0<K0_0030:f][@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40
];2a00H0];2a0P2][Je;0;3PiP40oooo001S0;3PiP80[Jf]202TWXl00`2][Jd0/J^M0;6[W@0<0;6[
W@030:f][@2i/ZH0^K:V00d0^K:V0`2][JdA0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m
/`33_K<00P11JN420<>m/`D0@FWQ2033_K<2045Yh@030:f][@35_[D0aKje00<0aKje0P11JN470<Fn
]@03045Yh@35_[D0aKje00<0aKje00<0@FWQ0<Fn]@2][Jd01@36_kL2045Yh@D0a[ng00<0@FWQ0<Jo
]`36_kL02036_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00X0al6j0P11JN480<O1
^P030:f][@11JN40@FWQ00@0b<6k0`11JN440<S1^`80@FWQ1P38`K/00`11JN40[Jf]0<S1^`040<S1
^`03045Yh@38`K/0b<6k0080b<6k1011JN470<S1^`030:f][@37`K`0al6l00H0al6l0P11JN470<O1
_080@FWQ00<0al6l0:f][@36`;`03`36`;`40:f][@h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2]
[Jd0];2a0;B`/@050;B`/@030:f][@2`h>H0/>3V04/0/>3V0@3oool006D0/>3V0P2][Jd60:BNS`03
0:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0:f][@030:f][@d0
_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`02045Yh@d0`kfc1011JN400`2][Jd0
aKje0<Fn]@040<Fn]@80@FWQ1@35_[D00`11JN40aKje0<Fn]@040<Fn]@03045Yh@35_[D0[Jf]00D0
a[ng0P11JN450<Jo]`03045Yh@36_kL0a[ng00P0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0
al6j0<O1^P0:0<O1^P80@FWQ2037`KX00`2][Jd0@FWQ045Yh@040<S1^`80@FWQ00<0b<6k045Yh@38
`K/00P38`K/2045Yh@L0b<6k1P11JN4@0<S1^`030:f][@37`K`0al6l00L0al6l0P11JN450<O1_0<0
@FWQ00<0al6l0:f][@36`;`02P36`;`50:f][@80a/2l00<0[Jf]0<>m^`33_K/03@33_K/00`2][Jd0
_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3PiP40oooo001W0;3PiP80[Jf]
102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0
0`2n]j`40:f][@T0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`02045YhA40`kfc
00<0[Jf]0<Fn]@35_[D01P35_[D2045Yh@<0aKje00<0@FWQ0<Fn]@35_[D01@35_[D00`11JN40[Jf]
0<Jo]`030<Jo]`<0@FWQ1@36_kL00`11JN40a[ng0<Jo]`080<Jo]`030:f][@37`KP0al6h01D0al6h
00<0[Jf]0<O1^P37`KX02P37`KX2045Yh@P0al6j00<0[Jf]045Yh@11JN401038`K/2045Yh@80b<6k
1011JN480<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01`37`K`2045Yh@D0al6l
00D0@FWQ0<O1_011JN40al6l0:f][@070<K0_0@0[Jf]1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`03
0:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80
[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n
]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`02045YhA40
`kfc00<0[Jf]0<Fn]@35_[D02035_[D3045Yh@T0aKje0P11JN430<Jo]`03045Yh@36_kL0@FWQ00D0
a[ng00<0@FWQ0<Jo]`36_kL02036_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j00X0
al6j0P11JN480<O1^P030:f][@11JN40@FWQ0080b<6k1011JN4>0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`02037`K`2045Yh@<0al6l00H0@FWQ0<O1_037`K`0@FWQ0<O1_02][Jd2
0<K0_0D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]
0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc0<>m/`02
045YhA40`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng045Yh@02045Yh@80a[ng00<0@FWQ
0<Jo]`36_kL00`36_kL2045Yh@T0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0:
0<O1^P80@FWQ2037`KX2045YhAD0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_008
0<O1_0D0@FWQ0`37`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;
0;ji^0<0[Jf]D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2]
[Jd0_[N/0;jg[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`02045YhA40`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0:0<Jo]`80@FWQ2@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j00X0al6j0P11JN480<O1^P80@FWQ5@38`K/00`2][Jd0b<6k0<S1^`0C0<S1
^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m
^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0
/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j
/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`02045YhA40`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2]
[Jd0a[ng0<Jo]`0:0<Jo]`80@FWQ2@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j
00X0al6j0P11JN480<O1^P80@FWQ5@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l
00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i
/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/003
0:f][@11JN40@FWQ0080@FWQ3`33_K<00`11JN40`kfc0:f][@0F0<Fn]@030:f][@36_kL0a[ng00X0
a[ng0P11JN490<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02P37`KX2045Yh@L0
al6j0P11JN4F0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`01@2][Jd=0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0050;ji^080
[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/
0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][Jd@0<>m/`80@FWQ00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0:0<Jo]`80@FWQ2@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f]
[@37`KX0al6j00X0al6j0P11JN470<O1^P80@FWQ5P38`K/00`2][Jd0b<6k0<S1^`0@0<S1^`H0[Jf]
4P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0
0P2n^KP30:f][E`0/>3V0@3oool007H0/>3V0`2][Jd30;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]
2@33_K<00`11JN40`kfc0:f][@0F0<Fn]@030:f][@36_kL0a[ng00X0a[ng0P11JN490<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02P37`KX2045Yh@H0al6j0P11JN400`2][Jd0b<6k
0<S1^`0D0<S1^`030:f][@38`K/0000000T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0[Jf]0080[Jf]
G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0[Jf]0;jg[02n]j`0402n
]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202][Jd30<>m/`030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL02P36_kL2045Yh@T0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0:0<O1^P80@FWQ1P37`KX00`11JN40al6j0:f][@0F0<S1^`040:f][@00
0000b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]4@35
_[D00`2][Jd0a[ng0<Jo]`0:0<Jo]`03045Yh@36_kL0a[ng00P0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0:0<O1^P80@FWQ00<0al6j045Yh@11JN400`11JN420<O1^P030:f][@38
`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036
`;`00`2][Jd0`kfk0<>m^`090<>m^`@0[Jf]I@2`h>H10?ooo`00OP2`h>H40:f][@/0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D00`35_[D<0:f][@D0aKje00<0[Jf]0<Jo]`36_kL02P36_kL00`11JN40a[ng0<Jo]`08
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX02037`KX5045Yh@L0al6j00<0[Jf]
0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B
0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool0
0880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h
00X0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0
[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33
_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0
/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`
00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng
00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l
0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`
h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool0
09D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0
[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2]
[Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3o
ool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2]
[JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m
/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1
^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1
^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0
al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]
_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51859 .33861 m
.52024 .34087 L
s
.51693 .34086 m
.51859 .33861 L
s
.51859 .34312 m
.52024 .34087 L
s
.51693 .34086 m
.51859 .34312 L
s
.49378 .33825 m
.50039 .3384 L
s
.50039 .3384 m
.50369 .34071 L
s
.50369 .34071 m
.50534 .34299 L
s
.49047 .34042 m
.49378 .33825 L
s
.50532 .34976 m
.50534 .34299 L
s
.48718 .33807 m
.48881 .34263 L
s
.48714 .34709 m
.48718 .33807 L
s
.48881 .34263 m
.49047 .34042 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50367 .34974 m
.50533 .34751 L
s
.48714 .34709 m
.48881 .34263 L
s
.50366 .352 m
.50532 .34976 L
s
.50035 .35194 m
.50367 .34974 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.50034 .3542 m
.50366 .352 L
s
.47236 .33977 m
.47562 .34442 L
s
.46746 .33728 m
.47236 .33977 L
s
.49206 .35628 m
.50035 .35194 L
s
.46418 .33712 m
.46746 .33728 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.51858 .3544 m
.52023 .38163 L
s
.5169 .38162 m
.51858 .3544 L
s
.5 Mabswid
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4609 .3392 m
.46418 .33712 L
s
.45926 .33911 m
.46418 .33712 L
s
.49205 .35854 m
.50034 .3542 L
s
.45759 .34354 m
.4609 .3392 L
s
.48874 .35845 m
.49206 .35628 L
s
.45596 .34345 m
.45926 .33911 L
s
.50363 .36558 m
.5053 .36107 L
s
.50528 .37014 m
.5053 .36107 L
s
.48873 .36071 m
.49205 .35854 L
s
.48708 .36067 m
.48874 .35845 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48707 .36293 m
.48873 .36071 L
s
.50196 .36782 m
.50363 .36558 L
s
.50363 .36558 m
.50528 .37014 L
s
.48706 .3652 m
.48708 .36067 L
s
.51857 .38162 m
.51857 .36799 L
s
.45591 .35024 m
.45759 .34354 L
s
.43657 .33534 m
.44789 .33616 L
s
.45428 .35014 m
.45596 .34345 L
s
.49864 .37003 m
.50196 .36782 L
s
.47389 .35793 m
.47553 .36026 L
s
.47223 .36013 m
.47389 .35793 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48706 .3652 m
.4887 .36752 L
s
.47551 .36253 m
.47553 .36026 L
s
.49201 .36988 m
.49864 .37003 L
s
.4887 .36752 m
.49201 .36988 L
s
.47223 .36013 m
.47387 .36246 L
s
.47219 .36694 m
.47551 .36253 L
s
.45587 .35477 m
.45591 .35024 L
s
.5 Mabswid
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44272 .36759 m
.44303 .33582 L
s
.44109 .36748 m
.44141 .3357 L
s
.45424 .35468 m
.45428 .35014 L
s
.45587 .35477 m
.45745 .36167 L
s
.46888 .36907 m
.47219 .36694 L
s
.51856 .38618 m
.52023 .38163 L
s
.5169 .38162 m
.51856 .38618 L
s
.45424 .35468 m
.45581 .36158 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60889 .33534 m
.62491 .33397 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.41895 .33383 m
.43014 .33482 L
s
.46395 .36883 m
.46888 .36907 L
s
.5 Mabswid
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.45745 .36167 m
.46069 .36639 L
s
.45581 .36158 m
.45905 .36631 L
s
.46069 .36639 m
.46395 .36883 L
s
.45905 .36631 m
.46395 .36883 L
s
.42503 .3594 m
.42533 .33441 L
s
0 0 0 r
.40438 .32462 m
.4085 .32788 L
s
.255 .412 .882 r
.42343 .35926 m
.42373 .33427 L
s
0 0 0 r
.40752 .32819 m
.40438 .32462 L
s
.40752 .32819 m
.40847 .33028 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62491 .33397 m
.62812 .33594 L
s
.62491 .33397 m
.62971 .33578 L
s
.62812 .33594 m
.63135 .34017 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.62971 .33578 m
.63294 .34001 L
s
.43623 .36713 m
.44272 .36759 L
s
.40159 .33203 m
.41261 .33321 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63135 .34017 m
.633 .34456 L
s
.63294 .34001 m
.63458 .3444 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.61532 .33482 m
.61586 .38264 L
s
.61371 .33495 m
.61425 .38276 L
s
.42337 .36383 m
.42503 .3594 L
s
.633 .34456 m
.63468 .35123 L
s
.42177 .36369 m
.42343 .35926 L
s
.44098 .37889 m
.44258 .38128 L
s
.43933 .38106 m
.44098 .37889 L
s
.63458 .3444 m
.63626 .35107 L
s
.44093 .38346 m
.44258 .38128 L
s
.43933 .38106 m
.44093 .38346 L
s
.41855 .36569 m
.42337 .36383 L
s
.41855 .36569 m
.42177 .36369 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.63468 .35123 m
.63483 .36265 L
s
.63626 .35107 m
.63642 .36249 L
s
.41536 .36539 m
.41855 .36569 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64699 .33167 m
.64748 .36362 L
s
.64855 .33148 m
.64904 .36345 L
s
.6423 .3322 m
.65321 .33092 L
s
.41062 .36265 m
.41536 .36539 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40752 .35777 m
.41062 .36265 L
s
.63334 .36966 m
.63483 .36265 L
s
.36809 .31162 m
.37868 .31319 L
s
.63493 .36951 m
.63642 .36249 L
s
.63181 .37439 m
.63334 .36966 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.60939 .38312 m
.62551 .38184 L
s
.38756 .33263 m
.39058 .33758 L
s
.39058 .33758 m
.39202 .34461 L
s
.38298 .32975 m
.38756 .33263 L
s
.5 Mabswid
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6334 .37424 m
.63493 .36951 L
s
.62551 .38184 m
.62868 .37927 L
s
.62551 .38184 m
.63028 .37913 L
s
.38602 .33243 m
.38903 .33738 L
s
.38903 .33738 m
.39047 .34442 L
s
.62868 .37927 m
.63181 .37439 L
s
.64883 .34972 m
.6505 .3564 L
s
.38298 .32975 m
.38602 .33243 L
s
.63028 .37913 m
.6334 .37424 L
s
.37324 .36058 m
.37412 .31253 L
s
.39195 .34918 m
.39202 .34461 L
s
.37992 .32934 m
.38298 .32975 L
s
.39039 .34899 m
.39047 .34442 L
s
.37172 .36037 m
.37261 .31231 L
s
.64277 .36413 m
.64904 .36345 L
s
0 0 0 r
.36395 .32255 m
.3643 .32236 L
s
.255 .412 .882 r
.39028 .35586 m
.39195 .34918 L
s
.37683 .3312 m
.37992 .32934 L
s
.38873 .35567 m
.39039 .34899 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40561 .38052 m
.4063 .33255 L
s
.40719 .38067 m
.40787 .33272 L
s
.40087 .38003 m
.40719 .38067 L
s
.37371 .33534 m
.37683 .3312 L
s
.3871 .36007 m
.39028 .35586 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6505 .3564 m
.65369 .36062 L
s
.65369 .36062 m
.65683 .36254 L
s
.38556 .35988 m
.38873 .35567 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.38243 .36179 m
.3871 .36007 L
s
.65683 .36254 m
.66148 .36197 L
s
.65985 .35758 m
.66144 .35968 L
s
.65985 .35758 m
.66136 .35509 L
s
.66136 .35509 m
.66294 .35719 L
s
.67469 .33032 m
.67916 .32736 L
s
.67326 .33512 m
.67469 .33032 L
s
.38243 .36179 m
.38556 .35988 L
s
.67326 .33512 m
.67335 .33969 L
s
.6762 .3301 m
.67916 .32736 L
s
.67477 .3349 m
.6762 .3301 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66294 .35719 m
.66298 .35948 L
s
.67477 .3349 m
.67486 .33948 L
s
.67916 .32736 m
.68365 .32666 L
s
.67335 .33969 m
.67495 .34406 L
s
.66148 .36197 m
.66298 .35948 L
s
.36329 .32691 m
.36479 .32714 L
s
.37936 .36139 m
.38243 .36179 L
s
.67486 .33948 m
.67646 .34384 L
s
.36026 .32872 m
.36329 .32691 L
s
.36175 .32896 m
.36329 .32691 L
s
.67495 .34406 m
.67952 .3457 L
s
.37634 .35869 m
.37936 .36139 L
s
.68365 .32666 m
.68667 .32848 L
s
.67646 .34384 m
.67952 .3457 L
s
.36017 .33331 m
.36175 .32896 L
s
.37337 .35368 m
.37634 .35869 L
s
.35868 .33307 m
.36026 .32872 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.68667 .32848 m
.68973 .33258 L
s
.67512 .35325 m
.67516 .35555 L
s
.67512 .35325 m
.67663 .35303 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.36083 .34771 m
.36109 .34969 L
s
.5 Mabswid
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.35985 .3494 m
.36017 .33331 L
s
.36718 .35973 m
.37324 .36058 L
s
.67516 .35555 m
.67672 .35763 L
s
.67663 .35303 m
.67667 .35533 L
s
.35581 .328 m
.35868 .33307 L
s
.35827 .35377 m
.35868 .33307 L
s
.35291 .32521 m
.35581 .328 L
s
.67672 .35763 m
.67978 .3595 L
s
.68973 .33258 m
.69111 .32775 L
s
.34852 .32446 m
.35291 .32521 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67952 .3457 m
.68853 .34662 L
s
.68973 .33258 m
.69015 .3533 L
s
.69111 .32775 m
.694 .32495 L
s
.69258 .3275 m
.694 .32495 L
s
.6912 .33234 m
.69258 .3275 L
s
.694 .32495 m
.69547 .3247 L
s
.6912 .33234 m
.69154 .34845 L
s
.67978 .3595 m
.68578 .35861 L
s
.35827 .35377 m
.35985 .3494 L
s
.34556 .32624 m
.34852 .32446 L
s
.34411 .32598 m
.34852 .32446 L
s
.35692 .34663 m
.35836 .34916 L
s
.34812 .34287 m
.35692 .34663 L
s
.68853 .34662 m
.69006 .34868 L
s
.35673 .35585 m
.35827 .35377 L
s
.344 .33058 m
.34556 .32624 L
s
.68578 .35861 m
.68872 .35584 L
s
.69015 .3533 m
.69154 .34845 L
s
.34256 .33032 m
.34411 .32598 L
s
.35372 .35769 m
.35673 .35585 L
s
.68872 .35584 m
.69015 .3533 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.3439 .33519 m
.344 .33058 L
s
.34525 .34005 m
.34812 .34287 L
s
.3438 .3398 m
.34812 .34287 L
s
.34245 .33493 m
.34256 .33032 L
s
.34783 .35673 m
.35372 .35769 L
s
.3439 .33519 m
.34525 .34005 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.34245 .33493 m
.3438 .3398 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.70849 .32232 m
.71494 .35362 L
s
.70345 .35572 m
.70849 .32232 L
s
.3436 .34904 m
.34505 .34929 L
s
.345 .3516 m
.34505 .34929 L
s
.34495 .35392 m
.34783 .35673 L
s
.7049 .35547 m
.70864 .32924 L
s
.34355 .35135 m
.3436 .34904 L
s
.69909 .35647 m
.70923 .35469 L
s
.34355 .35135 m
.34495 .35392 L
s
0 0 0 r
.72717 .31146 m
.72803 .31058 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71979 .32006 m
.72616 .35139 L
s
.71494 .35362 m
.71979 .32006 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31461 .31767 m
.32426 .31978 L
s
.71635 .35335 m
.71996 .32699 L
s
.33067 .34667 m
.33204 .34926 L
s
.33199 .35158 m
.33204 .34926 L
s
.3292 .34871 m
.33067 .34667 L
s
.33051 .35363 m
.33199 .35158 L
s
.3292 .34871 m
.33056 .35131 L
s
.32627 .35281 m
.33051 .35363 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31929 .3514 m
.3201 .31889 L
s
.3179 .35111 m
.31872 .31859 L
s
.32352 .34993 m
.32627 .35281 L
s
.31964 .33744 m
.32085 .3447 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32085 .3447 m
.32352 .34993 L
s
.72198 .35224 m
.73029 .35052 L
s
.31378 .35024 m
.31929 .3514 L
s
.30603 .3344 m
.30652 .31577 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73777 .32305 m
.74031 .31776 L
s
.73655 .32802 m
.73777 .32305 L
s
.30469 .33409 m
.30519 .31545 L
s
.73538 .33532 m
.73655 .32802 L
s
.74031 .31776 m
.74422 .31446 L
s
.7391 .32274 m
.74164 .31744 L
s
.73789 .32771 m
.7391 .32274 L
s
.30071 .33313 m
.31006 .33533 L
s
.73673 .33501 m
.73789 .32771 L
s
.74164 .31744 m
.74422 .31446 L
s
.30248 .31713 m
.305 .32243 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73673 .33501 m
.73704 .34669 L
s
.73538 .33532 m
.73569 .34699 L
s
.2986 .3138 m
.30248 .31713 L
s
.74422 .31446 m
.74684 .31379 L
s
.73569 .34699 m
.73722 .35371 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73704 .34669 m
.73857 .3534 L
s
.296 .31313 m
.2986 .3138 L
s
.74684 .31379 m
.7508 .31511 L
s
.73722 .35371 m
.7387 .35809 L
s
.29335 .31478 m
.296 .31313 L
s
.29207 .31444 m
.296 .31313 L
s
.73857 .3534 m
.74004 .35779 L
s
.5 Mabswid
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.30521 .36485 m
.30559 .35077 L
s
.30406 .3575 m
.30559 .35077 L
s
.7508 .31511 m
.7535 .3191 L
s
.29066 .31877 m
.29335 .31478 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74004 .35779 m
.74284 .36188 L
s
.7387 .35809 m
.74151 .36218 L
s
.7533 .31209 m
.75384 .33081 L
s
.28938 .31842 m
.29207 .31444 L
s
.30127 .36159 m
.30406 .3575 L
s
.30406 .3575 m
.30521 .36485 L
s
.75458 .31174 m
.75512 .33047 L
s
.74996 .33181 m
.75893 .32944 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74151 .36218 m
.74556 .36362 L
s
.28925 .32311 m
.29066 .31877 L
s
.74284 .36188 m
.74556 .36362 L
s
.29724 .36301 m
.30127 .36159 L
s
.28798 .32276 m
.28938 .31842 L
s
.28777 .3298 m
.28925 .32311 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76602 .33012 m
.76626 .33796 L
s
.5 Mabswid
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.74556 .36362 m
.7482 .363 L
s
.28651 .32946 m
.28798 .32276 L
s
.29462 .36238 m
.29724 .36301 L
s
.7482 .363 m
.75205 .35969 L
s
.28743 .34156 m
.28777 .3298 L
s
.28617 .34122 m
.28651 .32946 L
s
.29209 .35938 m
.29462 .36238 L
s
.2908 .35906 m
.29462 .36238 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75205 .35969 m
.75451 .35433 L
s
.75559 .34693 m
.75599 .36108 L
s
.75451 .35433 m
.75559 .34693 L
s
.75451 .35433 m
.75599 .36108 L
s
.28743 .34156 m
.2885 .34896 L
s
.28965 .35401 m
.29209 .35938 L
s
.2885 .34896 m
.28965 .35401 L
s
.28837 .35368 m
.2908 .35906 L
s
.28617 .34122 m
.28723 .34863 L
s
.28723 .34863 m
.28837 .35368 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76585 .30853 m
.76684 .3415 L
s
.76707 .30817 m
.76807 .34115 L
s
.76214 .30962 m
.77071 .30705 L
s
.76311 .34254 m
.76807 .34115 L
s
.27352 .30669 m
.27737 .34116 L
s
.26773 .33829 m
.27352 .30669 L
s
.76764 .32698 m
.76908 .3337 L
s
.27371 .3401 m
.28108 .34221 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26891 .33865 m
.2733 .31375 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76908 .3337 m
.77165 .33772 L
s
.77165 .33772 m
.77413 .33936 L
s
.26411 .30362 m
.26773 .33829 L
s
.25846 .33529 m
.26411 .30362 L
s
.77413 .33936 m
.77771 .33827 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77637 .33389 m
.77763 .3359 L
s
.77637 .33389 m
.77748 .33115 L
s
.2596 .33567 m
.26388 .31071 L
s
.77748 .33115 m
.77874 .33315 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77874 .33315 m
.77881 .33553 L
s
.77771 .33827 m
.77881 .33553 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78709 .30398 m
.79036 .3004 L
s
.78612 .30912 m
.78709 .30398 L
s
.78612 .30912 m
.78628 .31386 L
s
.78821 .30358 m
.79036 .3004 L
s
.78725 .30872 m
.78821 .30358 L
s
.78725 .30872 m
.7874 .31347 L
s
.78628 .31386 m
.78756 .31822 L
s
.25509 .33413 m
.26305 .3368 L
s
.7874 .31347 m
.78868 .31782 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79036 .3004 m
.79364 .29917 L
s
0 0 0 r
.79795 .2915 m
.79922 .29292 L
s
.255 .412 .882 r
.78756 .31822 m
.79099 .31941 L
s
.25288 .2996 m
.25397 .30001 L
s
.78868 .31782 m
.79099 .31941 L
s
.25063 .30115 m
.25288 .2996 L
s
.25171 .30156 m
.25288 .2996 L
s
.78787 .32773 m
.78795 .33012 L
s
.78787 .32773 m
.78899 .32735 L
s
.79364 .29917 m
.79588 .30072 L
s
.78795 .33012 m
.78915 .33211 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25047 .30591 m
.25171 .30156 L
s
.78899 .32735 m
.78907 .32973 L
s
.79099 .31941 m
.7976 .31938 L
s
.24939 .30549 m
.25063 .30115 L
s
.78915 .33211 m
.79146 .33373 L
s
.79588 .30072 m
.79818 .30465 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24991 .3226 m
.25047 .30591 L
s
.24742 .2999 m
.24939 .30549 L
s
.24867 .32698 m
.24939 .30549 L
s
.79146 .33373 m
.79585 .33215 L
s
.24539 .29667 m
.24742 .2999 L
s
.79818 .30465 m
.79907 .29946 L
s
.24867 .32698 m
.24991 .3226 L
s
.24228 .29539 m
.24539 .29667 L
s
.79923 .30423 m
.80012 .29904 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79818 .30465 m
.79891 .32616 L
s
.79923 .30423 m
.7998 .32096 L
s
.80012 .29904 m
.80108 .29623 L
s
.79907 .29946 m
.80108 .29623 L
s
.80359 .27827 m
.81054 .27513 L
s
.24783 .3194 m
.24883 .32219 L
s
.80108 .29623 m
.80212 .2958 L
s
.24162 .31452 m
.24783 .3194 L
s
.7976 .31938 m
.79874 .32137 L
s
.24751 .32897 m
.24867 .32698 L
s
.79585 .33215 m
.79792 .32896 L
s
.24016 .29692 m
.24228 .29539 L
s
.23915 .29648 m
.24228 .29539 L
s
.2453 .33056 m
.24751 .32897 L
s
.79792 .32896 m
.79891 .32616 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79891 .32616 m
.7998 .32096 L
s
.23898 .30127 m
.24016 .29692 L
s
.24112 .32893 m
.2453 .33056 L
s
.23798 .30084 m
.23915 .29648 L
s
.23966 .31128 m
.24162 .31452 L
s
.23865 .31086 m
.24162 .31452 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8076 .27649 m
.80938 .32684 L
s
.80661 .27694 m
.80838 .32726 L
s
.23881 .30606 m
.23898 .30127 L
s
.23881 .30606 m
.23966 .31128 L
s
.23781 .30563 m
.23798 .30084 L
s
.23781 .30563 m
.23865 .31086 L
s
.80845 .30038 m
.81025 .29471 L
s
.23915 .3257 m
.24112 .32893 L
s
.23831 .32047 m
.23932 .32089 L
s
.23924 .32329 m
.23932 .32089 L
s
.81025 .29471 m
.81211 .29143 L
s
.80534 .3285 m
.80938 .32684 L
s
.23822 .32287 m
.23915 .3257 L
s
.23822 .32287 m
.23831 .32047 L
s
.81211 .29143 m
.81402 .29053 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80913 .31961 m
.81128 .32358 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.82575 .27734 m
.82581 .27731 L
s
.255 .412 .882 r
.81402 .29053 m
.816 .29203 L
s
.81402 .29053 m
.81693 .29158 L
s
.81128 .32358 m
.81331 .32514 L
s
.816 .29203 m
.81803 .29594 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81693 .29158 m
.81895 .29549 L
s
.81331 .32514 m
.81524 .32428 L
s
.81803 .29594 m
.81921 .30273 L
s
.2295 .31661 m
.23036 .31946 L
s
.23028 .32188 m
.23036 .31946 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21966 .28456 m
.22583 .28782 L
s
.22924 .32387 m
.23028 .32188 L
s
.22847 .31859 m
.2295 .31661 L
s
.81895 .29549 m
.82013 .30228 L
s
.81524 .32428 m
.81705 .321 L
s
.81524 .32428 m
.81798 .32056 L
s
.22847 .31859 m
.22932 .32145 L
s
.22642 .32257 m
.22924 .32387 L
s
.81921 .30273 m
.81939 .30757 L
s
.81705 .321 m
.81874 .31528 L
s
.81874 .31528 m
.81939 .30757 L
s
.82013 .30228 m
.8203 .30712 L
s
.22188 .32036 m
.22314 .28643 L
s
.81798 .32056 m
.81966 .31483 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81966 .31483 m
.8203 .30712 L
s
.22468 .31926 m
.22642 .32257 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.221 .31992 m
.22226 .28597 L
s
.22305 .31352 m
.22468 .31926 L
s
.22243 .30579 m
.22305 .31352 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8249 .28501 m
.83075 .28168 L
s
.21839 .31857 m
.22188 .32036 L
s
0 0 0 r
.82849 .35021 m
.82855 .35018 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2144 .28899 m
.21502 .29433 L
s
.21502 .29433 m
.21557 .3021 L
s
.21298 .28316 m
.2144 .28899 L
s
.2151 .31431 m
.21557 .3021 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82745 .28359 m
.82938 .33478 L
s
.82829 .28311 m
.83023 .33433 L
s
.8293 .30986 m
.83114 .31383 L
s
.21359 .28851 m
.21421 .29385 L
s
.21421 .29385 m
.21475 .30164 L
s
.21219 .28268 m
.21359 .28851 L
s
.21073 .27927 m
.21298 .28316 L
s
.82681 .3361 m
.83023 .33433 L
s
.21428 .31385 m
.21475 .30164 L
s
.21073 .27927 m
.21219 .28268 L
s
.214 .32119 m
.2151 .31431 L
s
.83392 .27974 m
.83915 .27628 L
s
.21318 .32073 m
.21428 .31385 L
s
.83114 .31383 m
.83366 .31489 L
s
.20345 .2743 m
.21073 .27927 L
s
.213 .32564 m
.214 .32119 L
s
.83621 .27827 m
.83726 .30518 L
s
.21219 .32518 m
.21318 .32073 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2112 .32964 m
.213 .32564 L
s
.83696 .27777 m
.83801 .3047 L
s
.83366 .31489 m
.83524 .31396 L
s
.2104 .32919 m
.21219 .32518 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83524 .31396 m
.83669 .31056 L
s
.83524 .31396 m
.83745 .31009 L
s
.20874 .33074 m
.2112 .32964 L
s
.20424 .32797 m
.20626 .2763 L
s
.83669 .31056 m
.83726 .30518 L
s
.20874 .33074 m
.2104 .32919 L
s
.20351 .3275 m
.20555 .2758 L
s
.83745 .31009 m
.83801 .3047 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2014 .32609 m
.20874 .33074 L
s
.84197 .27428 m
.84656 .27071 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84778 .27183 m
.8485 .2663 L
s
.255 .412 .882 r
.84399 .27276 m
.84536 .30728 L
s
0 0 0 r
.84803 .27803 m
.84812 .27383 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84464 .27225 m
.84602 .30679 L
s
0 0 0 r
.84884 .29816 m
.84926 .30199 L
s
.255 .412 .882 r
.84333 .30873 m
.84602 .30679 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84529 .32264 m
.84586 .31968 L
s
.84529 .32264 m
.84606 .32465 L
s
.84586 .31968 m
.84662 .32169 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84606 .32465 m
.84662 .32169 L
s
.84989 .27554 m
.85084 .26955 L
s
.8496 .28348 m
.84989 .27554 L
s
.8496 .28348 m
.8498 .28844 L
s
.85047 .27502 m
.8514 .26903 L
s
.85019 .28297 m
.85047 .27502 L
s
.85084 .26955 m
.85239 .2655 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85019 .28297 m
.85039 .28793 L
s
.8498 .28844 m
.8507 .29538 L
s
.8514 .26903 m
.85239 .2655 L
s
.85039 .28793 m
.85128 .29488 L
s
.8507 .29538 m
.85205 .29935 L
s
.85239 .2655 m
.85345 .26445 L
s
.85128 .29488 m
.85262 .29885 L
s
.85345 .26445 m
.85508 .26534 L
s
.85205 .29935 m
.85382 .30034 L
s
.85262 .29885 m
.85382 .30034 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85508 .26534 m
.85625 .26926 L
s
.85382 .30034 m
.85541 .29882 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85541 .29882 m
.85631 .2953 L
s
.856 .28779 m
.85639 .28477 L
s
.856 .28779 m
.8566 .28977 L
s
.85639 .28477 m
.85698 .28675 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85631 .2953 m
.85708 .28926 L
s
.85698 .28675 m
.85708 .28926 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85904 .25801 m
.85966 .26247 L
s
.85904 .25801 m
.85946 .26802 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8645 .26864 m
.86457 .26856 L
s
.5 Mabswid
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85946 .26802 m
.85966 .26247 L
s
.1852 .26174 m
.1857 .25977 L
s
.18541 .25673 m
.1857 .25977 L
s
.85966 .26247 m
.85995 .25942 L
s
.18492 .25869 m
.18541 .25673 L
s
.85995 .25942 m
.8606 .25583 L
s
.18492 .25869 m
.1852 .26174 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.8606 .25583 m
.86201 .25363 L
s
.86009 .28309 m
.86039 .28005 L
s
.86009 .28309 m
.8603 .28813 L
s
.86019 .28561 m
.8605 .28256 L
s
.86039 .28005 m
.86107 .27647 L
s
.8603 .28813 m
.86081 .29012 L
s
.8605 .28256 m
.86118 .27899 L
s
.1838 .3051 m
.18467 .27429 L
s
.18302 .30408 m
.18467 .27429 L
s
.86107 .27647 m
.86265 .26874 L
s
.86081 .29012 m
.8617 .2916 L
s
.86118 .27899 m
.86276 .27126 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86452 .2685 m
.86455 .27611 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1834 .30459 m
.18404 .28941 L
s
.86201 .25363 m
.86277 .25504 L
s
.8617 .2916 m
.86316 .2895 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18319 .30966 m
.1838 .3051 L
s
.86277 .25504 m
.86318 .25701 L
s
.86265 .26874 m
.86319 .26513 L
s
.86276 .27126 m
.8633 .26766 L
s
.18221 .25429 m
.1824 .25737 L
s
.18208 .26494 m
.1824 .25737 L
s
.18302 .30408 m
.18319 .30966 L
s
.18173 .25066 m
.18221 .25429 L
s
.86318 .25701 m
.8635 .26459 L
s
.18178 .26439 m
.18219 .26241 L
s
.86319 .26513 m
.86339 .26206 L
s
.18167 .26692 m
.18208 .26494 L
s
.8633 .26766 m
.8635 .26459 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86316 .2895 m
.86373 .28591 L
s
.18069 .24843 m
.18173 .25066 L
s
.18109 .26583 m
.18178 .26439 L
s
.18098 .26836 m
.18167 .26692 L
s
.86373 .28591 m
.86394 .28285 L
s
.18103 .28212 m
.18155 .27758 L
s
.18112 .28773 m
.18155 .27758 L
s
.86394 .28285 m
.86404 .27724 L
s
.86394 .28285 m
.86447 .28739 L
s
.86404 .27724 m
.86447 .28739 L
s
.17959 .26817 m
.18109 .26583 L
s
0 0 0 r
.17559 .23494 m
.17669 .23793 L
s
.255 .412 .882 r
.18103 .28212 m
.18112 .28773 L
s
.17948 .27072 m
.18098 .26836 L
s
.18062 .28413 m
.18103 .28212 L
s
.18012 .24985 m
.18069 .24843 L
s
.17995 .28561 m
.18062 .28413 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86496 .2506 m
.86508 .24751 L
s
.86496 .2506 m
.8653 .25258 L
s
.86508 .24751 m
.86541 .24949 L
s
.1798 .25182 m
.18012 .24985 L
s
.8653 .25258 m
.86541 .24949 L
s
.17894 .28347 m
.17995 .28561 L
s
.1798 .25182 m
.17981 .24619 L
s
.17937 .25635 m
.1798 .25182 L
s
.17937 .25635 m
.17981 .24619 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17904 .26963 m
.17959 .26817 L
s
.86584 .26528 m
.86736 .29539 L
s
.86584 .26528 m
.86691 .29644 L
s
.17893 .27218 m
.17948 .27072 L
s
.17872 .27163 m
.17904 .26963 L
s
.1786 .27984 m
.17894 .28347 L
s
.86649 .28057 m
.86714 .29592 L
s
.17861 .27419 m
.17893 .27218 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.1785 .27674 m
.17872 .27163 L
s
.1785 .27674 m
.1786 .27984 L
s
.86691 .29644 m
.86736 .30105 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86736 .30105 m
.86736 .29539 L
s
0 0 0 r
.1747 .23146 m
.17418 .22795 L
s
.255 .412 .882 r
.17831 .24365 m
.17833 .24988 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17814 .23939 m
.17831 .24365 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17177 .31013 m
.17431 .22912 L
s
.17225 .29905 m
.17439 .22971 L
s
.5 Mabswid
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17177 .31013 m
.17639 .23724 L
s
.17364 .25276 m
.17503 .25785 L
s
.255 .412 .882 r
.17745 .27036 m
.17756 .2678 L
s
.17754 .26468 m
.17756 .2678 L
s
.17699 .27441 m
.17745 .27036 L
s
.17732 .2667 m
.17754 .26468 L
s
.178 .23825 m
.17814 .23939 L
s
.17732 .2667 m
.17732 .26981 L
s
.1778 .23967 m
.178 .23825 L
s
.17777 .2391 m
.178 .23825 L
s
.17668 .27589 m
.17699 .27441 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1741 .22678 m
.17413 .22266 L
s
.255 .412 .882 r
.17753 .24367 m
.1778 .23967 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17668 .27589 m
.17646 .27425 L
s
.17752 .2431 m
.17777 .2391 L
s
0 0 0 r
.1718 .27663 m
.17404 .22502 L
s
.1718 .27608 m
.17405 .22443 L
s
.255 .412 .882 r
.17719 .25083 m
.17753 .24367 L
s
.17646 .27425 m
.17648 .27057 L
s
.17646 .27425 m
.17644 .27002 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17719 .25026 m
.17752 .2431 L
s
.17648 .27057 m
.17665 .2643 L
s
.17697 .25599 m
.17719 .25083 L
s
.17665 .2643 m
.17697 .25599 L
s
.17644 .27002 m
.17664 .26374 L
s
.17697 .25543 m
.17719 .25026 L
s
.17664 .26374 m
.17697 .25543 L
s
0 0 0 r
.17186 .27829 m
.1718 .27608 L
s
.255 .412 .882 r
.17797 .23251 m
.17859 .22847 L
s
0 0 0 r
.17277 .25386 m
.1723 .2644 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1723 .2644 m
.17204 .2707 L
s
.255 .412 .882 r
.17661 .26711 m
.17817 .23078 L
s
.1767 .26655 m
.17826 .2302 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17204 .2707 m
.17198 .27331 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17198 .27331 m
.17222 .27165 L
s
.255 .412 .882 r
.17661 .26711 m
.17702 .2649 L
s
0 0 0 r
.17245 .26475 m
.17238 .26791 L
s
.1727 .26046 m
.17245 .26475 L
s
.17264 .26362 m
.1727 .26046 L
s
.5 Mabswid
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17591 .28485 m
.17594 .28278 L
s
.17594 .28278 m
.17614 .27962 L
s
0 0 0 r
.17248 .26736 m
.17264 .26362 L
s
.17222 .27165 m
.17248 .26736 L
s
.17494 .22669 m
.17563 .21809 L
s
.17429 .23842 m
.17494 .22669 L
s
.255 .412 .882 r
.17612 .28169 m
.17614 .27962 L
s
0 0 0 r
.17563 .21809 m
.17643 .2126 L
s
.17396 .24587 m
.17429 .23842 L
s
.255 .412 .882 r
.17591 .28485 m
.17612 .28169 L
s
0 0 0 r
.17512 .2261 m
.17583 .2175 L
s
.17445 .23785 m
.17512 .2261 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17583 .2175 m
.17643 .2126 L
s
.17413 .2453 m
.17445 .23785 L
s
.17364 .25651 m
.17396 .24587 L
s
.17382 .25595 m
.17413 .2453 L
s
.17643 .2126 m
.17691 .21141 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17369 .26288 m
.17364 .25651 L
s
.17691 .21141 m
.17756 .21336 L
s
.17389 .26232 m
.17382 .25595 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17416 .26496 m
.17369 .26288 L
s
.17756 .21336 m
.17783 .21966 L
s
.17416 .26496 m
.17389 .26232 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17416 .26496 m
.1749 .26329 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1761 .24709 m
.17656 .24276 L
s
.1761 .24709 m
.17623 .25029 L
s
.17656 .24276 m
.1767 .24596 L
s
.1749 .26329 m
.17561 .2584 L
s
.18037 .20489 m
.18328 .20075 L
s
.17561 .2584 m
.17653 .24973 L
s
.17653 .24973 m
.1767 .24596 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17815 .28278 m
.18155 .20311 L
s
.17856 .28224 m
.18196 .20252 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18655 .21963 m
.18769 .21319 L
s
.18631 .22218 m
.18655 .21963 L
s
.18621 .22757 m
.187 .21905 L
s
.18562 .23862 m
.18566 .24085 L
s
.85642 .21167 m
.85695 .21075 L
s
.85591 .2111 m
.85694 .21041 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18599 .23288 m
.186 .23268 L
s
.5 Mabswid
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1852 .19839 m
.18899 .19428 L
s
.255 .412 .882 r
.18611 .24029 m
.18599 .23288 L
s
0 0 0 r
.18019 .24408 m
.18074 .25057 L
s
.255 .412 .882 r
.18566 .24085 m
.18635 .24507 L
s
.18683 .24451 m
.18611 .24029 L
s
0 0 0 r
.17696 .28439 m
.17856 .28224 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18074 .25057 m
.18196 .25272 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.185 .23846 m
.18676 .19662 L
s
.18554 .2379 m
.1873 .19604 L
s
.255 .412 .882 r
.85509 .22803 m
.85519 .22474 L
s
0 0 0 r
.18196 .25272 m
.18295 .25161 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18295 .25161 m
.18414 .24667 L
s
.18295 .25161 m
.18467 .24612 L
s
.18414 .24667 m
.185 .23846 L
s
.19142 .19194 m
.19611 .18788 L
s
.18467 .24612 m
.18554 .2379 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19114 .24391 m
.19336 .1902 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19181 .24336 m
.19403 .18962 L
s
.18919 .24555 m
.19181 .24336 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19904 .18558 m
.20461 .18159 L
s
.255 .412 .882 r
.20569 .1966 m
.20614 .1968 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19918 .23795 m
.20136 .18386 L
s
.19998 .23742 m
.20215 .18329 L
s
.18952 .26768 m
.19034 .26327 L
s
.18952 .26768 m
.19002 .27104 L
s
.19034 .26327 m
.19086 .26662 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19002 .27104 m
.19086 .26662 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.20459 .22416 m
.20506 .22385 L
s
0 0 0 r
.19685 .23957 m
.19998 .23742 L
s
.255 .412 .882 r
.20442 .22848 m
.20496 .22656 L
s
.20506 .22385 m
.20496 .22656 L
s
0 0 0 r
.20805 .17933 m
.21451 .17543 L
s
.20045 .22576 m
.20177 .23245 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20908 .22038 m
.21075 .17765 L
s
.255 .412 .882 r
.83732 .2219 m
.83743 .22462 L
s
.83647 .22137 m
.83732 .2219 L
s
0 0 0 r
.21001 .21985 m
.21168 .17709 L
s
.20177 .23245 m
.20415 .23475 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20415 .23475 m
.20591 .23369 L
s
.20591 .23369 m
.20786 .22873 L
s
.20591 .23369 m
.20877 .2282 L
s
.20786 .22873 m
.20908 .22038 L
s
.21845 .17323 m
.22579 .16943 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21001 .21985 m
.21159 .22662 L
s
.20877 .2282 m
.21001 .21985 L
s
.2199 .2146 m
.22153 .17159 L
s
.22096 .21409 m
.22258 .17105 L
s
.21159 .22662 m
.21436 .22899 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21436 .22899 m
.21636 .22795 L
s
.81585 .17531 m
.81683 .17193 L
s
.81556 .16749 m
.81683 .17193 L
s
.21636 .22795 m
.21856 .22299 L
s
.21636 .22795 m
.21961 .22247 L
s
.81457 .17087 m
.81556 .16749 L
s
.21856 .22299 m
.2199 .2146 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81457 .17087 m
.81585 .17531 L
s
.21961 .22247 m
.22096 .21409 L
s
.23094 .17852 m
.23353 .16963 L
s
.22936 .19081 m
.23094 .17852 L
s
.23353 .16963 m
.23722 .16415 L
s
.23209 .178 m
.2347 .16911 L
s
.2305 .1903 m
.23209 .178 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.22907 .19868 m
.22936 .19081 L
s
.2347 .16911 m
.23722 .16415 L
s
.81657 .19493 m
.81945 .2429 L
s
.81657 .19493 m
.81718 .24192 L
s
.23022 .19817 m
.2305 .1903 L
s
.23722 .16415 m
.23964 .16312 L
s
.22907 .19868 m
.22978 .21001 L
s
.80249 .16176 m
.8074 .16382 L
s
.23022 .19817 m
.23094 .2095 L
s
.23964 .16312 m
.24321 .16551 L
s
.255 .412 .882 r
.80709 .19887 m
.8086 .20931 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2436 .19266 m
.24477 .19217 L
s
.23022 .19817 m
.2436 .19266 L
s
.22978 .21001 m
.23181 .21692 L
s
.81744 .2186 m
.81832 .24241 L
s
.23094 .2095 m
.23299 .21643 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24321 .16551 m
.24546 .17239 L
s
.80011 .16468 m
.8029 .17357 L
s
.23181 .21692 m
.23524 .21942 L
s
.79741 .15974 m
.80011 .16468 L
s
.81861 .25038 m
.81945 .2429 L
s
.23299 .21643 m
.23524 .21942 L
s
.7948 .15874 m
.79741 .15974 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.81718 .24192 m
.81861 .25038 L
s
.79229 .16169 m
.7948 .15874 L
s
.79095 .1612 m
.7948 .15874 L
s
.23524 .21942 m
.2389 .21796 L
s
.24308 .20457 m
.2435 .19266 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78986 .16863 m
.79229 .16169 L
s
.2445 .20011 m
.24477 .19217 L
s
.80176 .21222 m
.80402 .20523 L
s
.7885 .16815 m
.79095 .1612 L
s
.2389 .21796 m
.24154 .21301 L
s
.24154 .21301 m
.24308 .20457 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24294 .20855 m
.2445 .20011 L
s
.24154 .21301 m
.24294 .20855 L
s
.7889 .18006 m
.78986 .16863 L
s
.25601 .16846 m
.25902 .15957 L
s
.25425 .18085 m
.25601 .16846 L
s
.79932 .21526 m
.80176 .21222 L
s
.25902 .15957 m
.26334 .15417 L
s
.78752 .17959 m
.7885 .16815 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25738 .16798 m
.2604 .15909 L
s
.25561 .18037 m
.25738 .16798 L
s
.2604 .15909 m
.26334 .15417 L
s
.25399 .1888 m
.25425 .18085 L
s
.26334 .15417 m
.26618 .15322 L
s
.25535 .18833 m
.25561 .18037 L
s
.7967 .21432 m
.79932 .21526 L
s
.7889 .18006 m
.78916 .18802 L
s
.25399 .1888 m
.25494 .2003 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.80249 .16176 m
.80542 .24516 L
s
.80373 .16227 m
.80668 .24563 L
s
.80159 .24378 m
.80668 .24563 L
s
.78752 .17959 m
.78779 .18755 L
s
.26618 .15322 m
.26894 .15625 L
s
.25535 .18833 m
.25632 .19983 L
s
.78916 .18802 m
.79093 .20046 L
s
.7939 .20939 m
.7967 .21432 L
s
.79256 .20892 m
.7967 .21432 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78779 .18755 m
.78956 .2 L
s
.79093 .20046 m
.7939 .20939 L
s
.77539 .15198 m
.77717 .20797 L
s
.25494 .2003 m
.25743 .20738 L
s
.26894 .15625 m
.27161 .16329 L
s
.78956 .2 m
.79256 .20892 L
s
.77392 .15151 m
.77569 .20753 L
s
.25632 .19983 m
.25883 .20692 L
s
.27199 .15135 m
.27796 .14952 L
s
.255 .412 .882 r
.27036 .19429 m
.2714 .18822 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76947 .15013 m
.77972 .15339 L
s
.5 Mabswid
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76646 .18423 m
.7676 .18457 L
s
0 0 0 r
.25743 .20738 m
.26151 .21003 L
s
.25883 .20692 m
.26151 .21003 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26151 .21003 m
.26437 .20913 L
s
.26437 .20913 m
.26741 .20423 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75239 .14527 m
.76339 .14833 L
s
.26741 .20423 m
.2706 .1953 L
s
.28529 .15928 m
.28867 .15041 L
s
.28337 .17173 m
.28529 .15928 L
s
.77121 .20623 m
.77717 .20797 L
s
.28867 .15041 m
.29357 .14512 L
s
.28686 .15884 m
.29026 .14998 L
s
.28493 .1713 m
.28686 .15884 L
s
.29026 .14998 m
.29357 .14512 L
s
.28313 .17977 m
.28337 .17173 L
s
.29357 .14512 m
.29681 .14427 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.26933 .23568 m
.27199 .15135 L
s
.27082 .23526 m
.27347 .15089 L
s
.28469 .17934 m
.28493 .1713 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28313 .17977 m
.28433 .19143 L
s
.29681 .14427 m
.30162 .14703 L
s
.28469 .17934 m
.2859 .19101 L
s
.28469 .17934 m
.30418 .17443 L
s
.26491 .23696 m
.27082 .23526 L
s
.77659 .23583 m
.77794 .2322 L
s
.77633 .22773 m
.77794 .2322 L
s
.77497 .23135 m
.77633 .22773 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30162 .14703 m
.30473 .15426 L
s
.28433 .19143 m
.28725 .19868 L
s
.77497 .23135 m
.77659 .23583 L
s
.2859 .19101 m
.28884 .19827 L
s
.73936 .14596 m
.74292 .15481 L
s
.73417 .14074 m
.73936 .14596 L
s
.28725 .19868 m
.29194 .20151 L
s
.73074 .13996 m
.73417 .14074 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.28884 .19827 m
.29194 .20151 L
s
.72738 .14321 m
.73074 .13996 L
s
.72564 .14283 m
.73074 .13996 L
s
.31699 .13943 m
.31852 .14711 L
s
.31657 .15556 m
.31699 .13943 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75716 .14657 m
.75967 .23133 L
s
.75874 .147 m
.76126 .23173 L
s
.5 Mabswid
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.30217 .18697 m
.3025 .17482 L
s
.29194 .20151 m
.29684 .20032 L
s
.72409 .15053 m
.72738 .14321 L
s
.30395 .18253 m
.30418 .17443 L
s
.74192 .17862 m
.74371 .18306 L
s
.74035 .18228 m
.74192 .17862 L
s
.74371 .18306 m
.74382 .18711 L
s
.72232 .15016 m
.72564 .14283 L
s
.31852 .14711 m
.32037 .1427 L
s
.32037 .1427 m
.324 .13792 L
s
.31657 .15556 m
.31852 .14711 L
s
.74068 .19446 m
.74382 .18711 L
s
.324 .13792 m
.33114 .13645 L
s
.75485 .23015 m
.76126 .23173 L
s
.30205 .19103 m
.30395 .18253 L
s
.30027 .19548 m
.30217 .18697 L
s
.29684 .20032 m
.30027 .19548 L
s
.74035 .18228 m
.74214 .18672 L
s
.30027 .19548 m
.30205 .19103 L
s
.72263 .1623 m
.72409 .15053 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33114 .13645 m
.33466 .13978 L
s
.73739 .19777 m
.74068 .19446 L
s
.33466 .13978 m
.33639 .14348 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72263 .1623 m
.72283 .17042 L
s
.7058 .13482 m
.71309 .13622 L
s
.72085 .16194 m
.72232 .15016 L
s
.31779 .17544 m
.32142 .17065 L
s
.31594 .17987 m
.31779 .17544 L
s
.31573 .18801 m
.31594 .17987 L
s
.72085 .16194 m
.72106 .17006 L
s
.73223 .19666 m
.73739 .19777 L
s
.5 Mabswid
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32142 .17065 m
.33055 .16074 L
s
.31769 .17951 m
.32131 .17471 L
s
.31584 .18394 m
.31769 .17951 L
s
.72283 .17042 m
.72491 .18298 L
s
.3361 .15564 m
.33639 .14348 L
s
.32131 .17471 m
.33045 .1648 L
s
.31573 .18801 m
.31737 .19172 L
s
.72106 .17006 m
.72314 .18262 L
s
.5 Mabswid
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.33055 .16074 m
.33428 .15599 L
s
.72864 .19185 m
.73223 .19666 L
s
.72688 .19149 m
.73223 .19666 L
s
.7022 .13818 m
.70608 .14696 L
s
.69651 .13314 m
.7022 .13818 L
s
.33428 .15599 m
.3362 .15158 L
s
.72491 .18298 m
.72864 .19185 L
s
.33045 .1648 m
.33418 .16005 L
s
.31737 .19172 m
.3208 .19509 L
s
.72314 .18262 m
.72688 .19149 L
s
.33418 .16005 m
.3361 .15564 L
s
.69274 .13249 m
.69651 .13314 L
s
.35143 .13269 m
.35323 .13643 L
s
.34946 .13707 m
.35143 .13269 L
s
.34946 .13707 m
.35125 .14081 L
s
.68903 .13591 m
.69274 .13249 L
s
.68712 .1356 m
.69274 .13249 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.3208 .19509 m
.32795 .1937 L
s
.35125 .14081 m
.35323 .13643 L
s
.68729 .14373 m
.68903 .13591 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.7058 .13482 m
.70711 .19182 L
s
.70763 .13516 m
.70896 .19215 L
s
.68537 .14342 m
.68712 .1356 L
s
.3336 .1845 m
.33563 .176 L
s
.33524 .19236 m
.33563 .176 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.32795 .1937 m
.33168 .18893 L
s
.33168 .18893 m
.3336 .1845 L
s
.3336 .1845 m
.33524 .19236 L
s
.68729 .14373 m
.68822 .18874 L
s
.68537 .14342 m
.6863 .18844 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.35081 .16116 m
.35166 .21013 L
s
.34785 .21072 m
.35081 .16116 L
s
.70153 .19086 m
.70896 .19215 L
s
.66757 .12861 m
.66802 .1531 L
s
.66559 .12834 m
.66802 .1531 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34975 .21042 m
.35028 .18571 L
s
.255 .412 .882 r
.66951 .16593 m
.67039 .16963 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63517 .1247 m
.66757 .12861 L
s
.68047 .18759 m
.68822 .18874 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34785 .21072 m
.34957 .2187 L
s
.5 Mabswid
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.34957 .2187 m
.35166 .21013 L
s
.5 Mabswid
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66715 .21473 m
.6687 .19011 L
s
.6687 .19011 m
.66916 .21498 L
s
.64409 .17073 m
.65635 .17211 L
s
.65607 .15566 m
.65663 .18863 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.6364 .21141 m
.66916 .21498 L
s
.64135 .12536 m
.64265 .21201 L
s
.6434 .12558 m
.64472 .21222 L
s
.255 .412 .882 r
.53839 .15733 m
.53942 .15789 L
s
.54283 .15732 m
.54377 .15796 L
s
.54595 .1609 m
.54377 .15796 L
s
.54378 .16086 m
.53942 .15789 L
s
.56145 .16459 m
.56552 .17014 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]3`3oYA000`2][Jd0oj<@0?nS400I
0?nS40030:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>0>bF3P04
0>bF3P<0[Jf]J`2`h>H10?ooo`00O`2`h>H30:f][@H0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2]
[Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ401@3oYQ4?0:f]
[@L0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400=0?nU41@0[Jf]5`3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh01`3/UPh30:f]
[FP0/>3V0@3oool007`0/>3V0`2][Jd90?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV4@`0[Jf]5P3oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa060:f][@@000003@3oXa000`2][Jd0
o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0
/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40
5`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS40T00000
00<0[Jf]0?nS403oXa000P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh0303/UPh30:f][F<0/>3V0@3oool007L0/>3V0`2][Jd>0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]3P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400;0?nS408000001`3oXa05000000<0[Jf]603lX1000`2][Jd0mY`?0?JL
3`0C0?JL3`030:f][@3/UPh0k9H>00l0k9H>0P2][JeQ0;3PiP40oooo001e0;3PiP80[Jf]4@3lX100
0`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01D0ojHA1`2][JdH0?nV4@030:f][@3oYQ40
ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@00/0oj<@0P00000:0?nS4080000000<0[Jf]0?bP403lX1001P2][JdB0?bP40030:f][@3fW0l0
mY`?01<0mY`?00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP
40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ400`000000ojHA0:f][@040:f]
[@80ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS408000002P3oXa020000
00030:f][@3lX100o:0@00H0o:0@0`2][Jd3000000`0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2]
[Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=0080[Jf]G@2`h>H10?ooo`00L@2`h>H20:f][@80
kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00/0
ojHA0P2][Jd2000000030:f][@3oYQ40ojHA00D0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400;0?nS408000002P3oXa02000000030:f][@3lX100o:0@00L0o:0@0P0000020?bP4004
0:f][@000000[Jf]0:f][@8000001`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>
00l0k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][E/0/>3V0@3oool006l0/>3V0P2][Jd40>nH4003
0:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA0?nV4@030?nV4@80
00001P2][Jd20?nV4@030000003oYQ40000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0
ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400;0?nS408000002`3oXa000`000000[Jf]0?bP40070?bP408000001@3lX1000`000000
o:0@0000000400000080[Jf]0P3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>00l0
k9H>00<0[Jf]0=^:3@3KRPd0103KRPd20:f][ET0/>3V0@3oool006h0/>3V00<0[Jf]0>nH403_V100
103_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A01@0oj@A00<000000?nV4@3oYQ40
0`0000020:f][@030000003oYQ40ojHA00D0ojHA0P0000080?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa002`3oXa02000000/0oj<@00<000000:f][@3lX1001`3lX102000000H0o:0@
0`0000050?bP40@0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00H0fhX=
0P2][JeG0;3PiP40oooo001/0;3PiP80[Jf]1`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3o
Y140oj@A01<0oj@A00@0[Jf]0000002][Jd000001P3oYQ400`000000ojHA0?nV4@050?nV4@030000
003oYQ40ojHA00H0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f]
[@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS40800000
2`3oXa000`000000[Jf]0?bP40060?bP408000001`3lX103000000L0o:0@00<0[Jf]0?JL3`2][Jd0
1000000@0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0203KRPd20:f][ED0/>3V
0@3oool006X0/>3V0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1403`3o
Y1440:f][@040?nT4@000000ojHA000000L0ojHA00<000000?nV4@3oYQ403@3oYQ400`2][Jd0ojHA
0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@
0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@0P00000;0?nS408000001`3lX102000000P0o:0@
0P0000070?bP40040:f][@000000000000000080mY`?00@0[Jf]0000002][Jd0[Jf]3@3fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00X0fhX=0P2][JeC0;3PiP40oooo001X0;3PiP80
[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00P0oj@A0`0000040:f][@D0
oj@A0P0000080?nV4@030000003oYQ40ojHA00d0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0
oj<@0?nS400;0?nS408000002`3oXa02000000L0o:0@0P0000080?bP408000001`3lX1000`2][Jd0
0000000000040?JL3`030000003fW0l0mY`?00@0[Jf]00<0mY`?0000000000001P3fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?ooo`00
I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
1`3oY14200000080[Jf]0P0000070?nT4@800000203oYQ400`000000ojHA0?nV4@0=0?nV4@030:f]
[@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa02000000/0oj<@0P0000070?bP40800000
203lX102000000L0o:0@0P0000060?JL3`030000003fW0l0mY`?00<0mY`?0`2][Jd2000000@0mY`?
00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]D@2`h>H10?ooo`00IP2`
h>H20:f][@d0kiP@00<0[Jf]0?bP403lX1003`3lX100102][Jd0oj@A0?nT4@0000020?nT4@@0[Jf]
00<000000?nT4@3oY1400P3oY1400`000000oj@A0?nT4@050?nT4@800000203oYQ400`000000ojHA
0?nV4@0=0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa02000000`0oj<@
00<000000:f][@3lX1001@3lX102000000P0o:0@0P0000070?bP408000001P3fW0l00`000000mY`?
0?JL3`060?JL3`@0000000<0[Jf]0?JL3`2][Jd04P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0[Jf]0500/>3V0@3oool006D0/>3V00<0[Jf]0=>73P2][Jd03@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@000000000000<0[Jf]0`3oY142000000D0oj@A00<000000?nT4@3oY140103o
Y1400`000000ojHA0?nV4@060?nV4@030000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ406@3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400;0?nS40800000303oXa000`000000[Jf]0?bP40050?bP40800000203l
X102000000L0o:0@0P0000070?JL3`030000003fW0l0mY`?00D0mY`?0P0000030?JL3`80[Jf]0P00
000@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00@0[Jf]0;Ue2`2iM@/0[Jf]C`2`h>H10?ooo`00I02`
h>H0102][Jd0dhL>0=>73P2][Jd=0>nH40030:f][@3lX100o:0@00d0o:0@00@000000:f][@2][Jd0
00001P3oY142000000H0oj@A00<000000?nT4@3oY140103oY1400`000000ojHA0?nV4@060?nV4@03
0000003oYQ40ojHA00h0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;0?nS4080
0000303oXa000`000000[Jf]0?bP40050?bP40800000203lX102000000L0o:0@0P0000070?JL3`03
0000003fW0l0mY`?00D0mY`?0P0000040?JL3`030:f][@3/UPh0000000<000003@3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00H`2`h>H01@2][Jd0
dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1002`3lX103000000030?bP402][Jd00000
00H0oj@A0P0000070?nT4@030000003oY140oj@A00<0oj@A00<000000?nV4@3oYQ401P3oYQ400`00
0000ojHA0?nV4@0>0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa002`3oXa020000
00d0oj<@00<0[Jf]0?bP403lX100103lX102000000P0o:0@0P0000070?bP40800000203fW0l00`00
0000mY`?0?JL3`040?JL3`800000103fW0l01@2][Jd0k9H>000000000000k9H>0080[Jf]303/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3P
iP030:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40090?bP
40030:f][@000000[Jf]0080o:0@00<000000:f][@0000001@3oY142000000h0oj@A00<0[Jf]0?nV
4@3oYQ401P3oYQ400`000000ojHA0?nV4@0>0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV
4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa002`3oXa02000000H0oj<@00<000000?nS
403oXa00103oXa000`2][Jd0o:0@0?bP40040?bP40800000203lX102000000H0o:0@0P00000@0?JL
3`800000103fW0l0102][Jd0k9H>0000000000030>bF3P<0[Jf]2@3/UPh00`2][Jd0fhX=0=^:3@0;
0=^:3@030:f][@2iM@/0^GD;00@0^GD;00<0[Jf]0;3PiP2`h>H0B@2`h>H10?ooo`00H@2`h>H00`2]
[Jd0dhL>0=>73P030=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0?bP403lX1001`3lX1020:f]
[@8000000`3lX1000`000000[Jf]000000050?nT4@8000003@3oY1400`2][Jd0ojHA0?nV4@060?nV
4@030000003oYQ40ojHA00l0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@050?nV
4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0ojD@402][Jd70?nU
40030:f][@3oXa00oj<@00/0oj<@0P0000060?nS40030000003oXa00oj<@00@0oj<@00<0[Jf]0?bP
403lX100103lX102000000P0o:0@0P0000060?bP40800000403fW0l2000000@0mY`?00@0[Jf]0>bF
3P00000000001P3/UPh30:f][@030000003/UPh0k9H>00<0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
0`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600/>3V00<0[Jf]0=>7
3P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00@0o:0@0`2][Jd20?bP
40800000103lX102000000D0oj@A0P00000=0?nT4@030:f][@3oYQ40ojHA00D0ojHA0P0000080?nV
4@030000003oYQ40ojHA00H0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4<0:f][AL0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400E0?nU40`0[Jf]2@3oXa02000000H0oj<@00<000000?nS
403oXa00103oXa000`2][Jd0o:0@0?bP40040?bP40800000203lX102000000H0o:0@0P00000@0?JL
3`800000103fW0l0102][Jd0k9H>0000000000070>bF3P80000000<0[Jf]0000003/UPh00`3/UPh0
0`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]0;3PiP2`h>H0A`2`h>H1
0?ooo`00G`2`h>H00`2][Jd0dhL>0=>73P050=>73P030:f][@3_V100kiP@00/0kiP@00@0[Jf]0?bP
40000000o:0@0`2][Jd50?bP40030000003lX100o:0@00<0o:0@0P0000050?nT4@8000003@3oY140
0`2][Jd0ojHA0?nV4@040?nV4@8000002@3oYQ400`000000ojHA0?nV4@060?nV4@030:f][@3oYQ40
ojHA00`0ojHA2@2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@0080oj<@2@2][Jd2000000H0oj<@00<00000
0?nS403oXa00103oXa000`2][Jd0o:0@0?bP40040?bP40800000203lX102000000H0o:0@0P00000@
0?JL3`800000103fW0l0102][Jd0k9H>0000000000070>bF3P040000003/UPh0k9H>00000080[Jf]
00<000000>bF3P2][Jd03@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@2`h>H0/>3V04H0/>3V
0@3oool005h0/>3V00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@00
0000[Jf]008000001P3lX102000000D0o:0@00<0[Jf]0000003oY140103oY1400`000000oj@A0?nT
4@0<0?nT4@030:f][@3oYQ40ojHA00<0ojHA00<000000?nV4@0000002@3oYQ400`000000ojHA0?nV
4@060?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd=0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40030?nU4003045Yh@3oYA00ojD@01H0ojD@00<0
[Jf]0?nS403oXa002`3oXa02000000H0[Jf]00<000000:f][@2][Jd0103oXa000`2][Jd0o:0@0?bP
40040?bP408000002@3lX102000000D0o:0@0P00000@0?JL3`800000103fW0l0102][Jd0k9H>0000
000000060>bF3P8000000`3/UPh00`000000k9H>00000002000000d0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00D0
00000:f][@3lX100o:0@000000060?bP40030000003lX100o:0@00@0o:0@00<0[Jf]0000003oY140
0`3oY142000000h0oj@A00<0[Jf]0?nV4@3oYQ400P3oYQ400`000000ojHA0000000:0?nV4@030000
003oYQ40ojHA00@0ojHA1`2][JdG0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00
703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00/0oj<@0P0000060?nS40030000
003oXa00oj<@00P0[Jf]103lX1000`000000o:0@0?bP40070?bP408000001@3lX10200000100mY`?
0P0000040?JL3`040:f][@3/UPh00000000000H0k9H>00<000000>bF3P3/UPh00P3/UPh010000000
k9H>0000003/UPh30:f][@030=^:3@000000fhX=00P0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/20:f]
[DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00L0kiP@00<000000>nH402]
[Jd00P0000030?bP40030000003lX100o:0@00@0o:0@00<000000?bP403lX100103lX1000`2][Jd0
00000?nT4@030?nT4@8000003P3oY1401`2][Jd0ojHA0?nV4@3oYQ4000000?nV4@0000002`3oYQ40
0`000000[Jf]0:f][@040:f][@80ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L
0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400;
0?nS408000001P3oXa000`000000oj<@0?nS40040?nS40040:f][@3lX100o:0@0?bP40@0[Jf]0P00
00080?bP408000001@3lX10200000100mY`?0P0000040?JL3`040:f][@3/UPh00000000000H0k9H>
00<000000>bF3P3/UPh00`3/UPh2000000060>bF3P2][Jd0fhX=0=^:3@2][Jd000002@3KRPd00`2]
[Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0[Jf]04H0/>3V0@3oool005`0/>3V00<0[Jf]09MP2`2]
[Jd0203CQ`h00`2][Jd0kiP@0>nH40040>nH40<000000P2][Jd00`3_V1000000000000040?bP4003
0000003lX100o:0@00<0o:0@00<000000?bP403lX100103lX1000`2][Jd000000?nT4@030?nT4@80
00003P3oY1401P2][Jd0ojHA0?nV4@000000ojHA000000P0ojHA102][Jd00`000000ojHA0?nV4@06
0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303oXa04000000<0oj<@00<00000
0?nS403oXa00103oXa000`2][Jd0o:0@0?bP40050?bP408000001`2][Jd00`3lX100000000000005
0?bP40800000403fW0l2000000@0mY`?00@0[Jf]0>bF3P00000000001P3/UPh00`000000k9H>0>bF
3P030>bF3P80000000<0k9H>0:f][@3KRPd00P3KRPd2000000030:f][@3KRPd0fhX=00D0fhX=00<0
[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0
Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_V1000`3_V103000000040:f][@3_V100kiP@0>nH40800000
103lX1000`000000o:0@0?bP40030?bP40030000003lX100o:0@00@0o:0@0P0000040?nT4@800000
3P3oY1401@2][Jd0ojHA0000003oYQ40000000@0ojHA1@2][Jd40?nV4@030000003oYQ40ojHA00H0
ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS408000000P3oXa04000000H0
oj<@00<0[Jf]0?bP403lX1001@3lX102000000L0o:0@00<0[Jf]0000000000000`2][Jd20?bP4080
0000403fW0l2000000@0mY`?00@0[Jf]0>bF3P00000000001P3/UPh00`000000k9H>0>bF3P040>bF
3P030000003/UPh0[Jf]00<0fhX=0P0000000`3KRPd0[Jf]0=^:3@050=^:3@030:f][@2iM@/0^GD;
00L0^GD;00@0[Jf]08QF1`28EPL0[Jf]A@2`h>H10?ooo`00F`2`h>H0102][Jd0Uf0;09MP2`2][Jd8
0=>73P050:f][@3_V100kiP@0>nH400000000P3_V102000000<0kiP@0P0000000`2][Jd0o:0@0?bP
40070?bP40030000003lX100o:0@00D0o:0@0P0000040?nT4@8000001`3oY143000000@0oj@A00@0
[Jf]0000003oYQ4000001@2][Jd80?nV4@800000203oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f]
[@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f]
[@3oXa00oj<@00`0oj<@0P0000050?nS40030000003oXa00oj<@00@0oj<@00<0[Jf]0?bP403lX100
1@3lX102000000P0o:0@0P0000030?bP4080[Jf]0P0000000`2][Jd0mY`?0?JL3`0=0?JL3`800000
103fW0l0102][Jd0k9H>0000000000050>bF3P8000001P3/UPh00`000000k9H>0:f][@030=^:3@04
0000003KRPd0fhX=0=^:3@80[Jf]103KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H7
08QF1`2][Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00D0[Jf]
0>nH4000000000000>nH40020:f][@8000000`3_V102000000030:f][@3lX100o:0@00L0o:0@00<0
00000?bP403lX1001@3lX102000000@0oj@A0P0000020?nT4@D0000000<0oj@A0000000000000`3o
Y1420:f][@8000001`3oYQ400`000000ojHA0?nV4@040?nV4@800000203oYQ400`2][Jd0ojHA0?nV
4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@00`0oj<@0P0000050?nS40030000003oXa00oj<@00@0oj<@00<0
[Jf]0?bP403lX1001@3lX102000000P0o:0@0P0000050?bP4080000000<0mY`?0:f][@2][Jd00P2]
[Jd;0?JL3`800000103fW0l0102][Jd0k9H>0000000000050>bF3P8000001P3/UPh00`000000k9H>
0:f][@090=^:3@80[Jf]0P3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`050:f][@28EPL0R5H708QF1`2]
[Jd0A02`h>H10?ooo`00FP2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00<0[Jf]00000000
00000P2][Jd20>nH408000000`3_V102000000030:f][@3lX100o:0@00L0o:0@00<000000?bP403l
X1001@3lX102000000@0oj@A100000060?nT4@030000002][Jd0[Jf]0080[Jf]00<0oj@A00000000
0000203oYQ400`000000ojHA0?nV4@040?nV4@800000203oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU4003
0:f][@3oXa00oj<@00`0oj<@0P0000050?nS40030000003oXa00oj<@00@0oj<@00<0[Jf]0?bP403l
X1001@3lX102000000P0o:0@0P0000060?bP40800000103fW0l30:f][@030000003fW0l0mY`?00D0
mY`?0P0000040?JL3`040:f][@3/UPh00000000000D0k9H>0P0000060>bF3P030000003/UPh0[Jf]
00/0fhX=0`2][Jd90;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?oo
o`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3CQ`h0dhL>00D0dhL>00@000000:f][@2]
[Jd00000103_V102000000<0kiP@0P0000000`2][Jd0o:0@0?bP40070?bP40030000003lX100o:0@
00D0o:0@0P0000040?nT4@8000001@3oY1430:f][@030000003oY140oj@A00<0oj@A0P0000070?nV
4@8000001P3oYQ42000000P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS
408000001@3oXa000`000000oj<@0?nS40040?nS40030:f][@3lX100o:0@00D0o:0@0P0000080?bP
408000001P3lX102000000L0mY`?00<000000:f][@2][Jd00P2][Jd30?JL3`800000103fW0l0102]
[Jd0k9H>0>bF3P0000050>bF3P8000001P3/UPh00`000000k9H>0:f][@0=0=^:3@030:f][@2iM@/0
^GD;00L0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3P
iP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h2000000040=>73P2][Jd0kiP@000000@0kiP@0P00
00030>nH4080000000<0[Jf]0?bP403lX1001`3lX1000`000000o:0@0?bP40050?bP40800000103o
Y14200000080oj@A0`2][Jd30?nT4@030000003oY140oj@A00<0oj@A00<000000?nV4@3oYQ401P3o
YQ42000000H0ojHA0P0000080?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa00303o
Xa02000000D0oj<@00<000000?nS403oXa00103oXa000`2][Jd0o:0@0?bP40050?bP40800000203l
X102000000H0o:0@0P0000070?JL3`8000000`3fW0l30:f][@800000103fW0l00`2][Jd0k9H>0>bF
3P02000000@0k9H>0P0000060>bF3P030000003/UPh0[Jf]00d0fhX=0P2][Jd80;Ue2`030:f][@28
EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2G
H0/0[Jf]00D0dhL>0`0000020:f][@030>nH40000000kiP@00<0kiP@0P0000020>nH4080000000<0
[Jf]0?bP403lX100203lX1000`000000o:0@0?bP40050?bP40800000103oY14200000080[Jf]1P3o
Y1400`000000oj@A0?nT4@030?nT4@030000003oYQ40ojHA00H0ojHA0P0000060?nV4@800000203o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@0P0000050?nS40030000003o
Xa00oj<@00@0oj<@00<0[Jf]0?bP403lX1001@3lX102000000P0o:0@0P0000060?bP408000001`3f
W0l2000000H0mY`?0P0000030:f][@040?JL3`2][Jd0k9H>0>bF3P800000103/UPh2000000H0k9H>
0P0000000`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28
EPL00P28EPL00`2][Jd0/>3V0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2]
[Jd01P3CQ`h2000000040=>73P2][Jd0kiP@000000@0kiP@0P0000020>nH4080000000<0[Jf]0?bP
403lX100203lX1000`000000o:0@0?bP40050?bP40800000102][Jd00`3oY14000000?nT4@060?nT
4@8000001@3oY1400`000000ojHA0?nV4@050?nV4@<000001P3oYQ42000000L0ojHA00<0[Jf]0?nV
4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS408000001@3oXa000`000000oj<@0?nS40040?nS
40030:f][@3lX100o:0@0080o:0@0P0000000`3lX1000000000000080?bP408000001P3lX1000`2]
[Jd00000000000070?JL3`030000003fW0l0mY`?00@0mY`?0P0000030?JL3`<0[Jf]00<0k9H>0000
00000000103/UPh2000000H0k9H>0P0000000`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;
0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0/>3V0440/>3V0@3oool0
05T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@030=>73P80000000L0[Jf]000000000000dhL>0:f]
[@3_V100000000@0kiP@0P0000020>nH4080000000<0[Jf]0?bP403lX100203lX1000`000000o:0@
0?bP40040?bP40030:f][@000000000000D0oj@A00<000000?nT4@3oY1401@3oY142000000D0oj@A
00<000000?nV4@3oYQ401@3oYQ43000000H0ojHA0P0000070?nV4@030:f][@3oYQ40ojHA01X0ojHA
00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@
00<0[Jf]0?nS403oXa00303oXa02000000D0oj<@00<000000?nS403oXa00103oXa000`2][Jd0o:0@
0?bP40040?bP40<00000203lX102000000H0o:0@00<0[Jf]0000000000001`3fW0l00`000000mY`?
0?JL3`040?JL3`800000103fW0l00`2][Jd0k9H>0:f][@02000000@0k9H>0P0000060>bF3P800000
00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;
00<0[Jf]08QF1`28EPL00P28EPL20:f][D80/>3V0@3oool005T0/>3V00D0[Jf]09MP2`2GH0/0Uf0;
0:f][@020=>73P80000000P0[Jf]0=>73P00000000000=>73P2][Jd0kiP@000000@0kiP@0P000002
0>nH4080000000<0[Jf]0?bP403lX100203lX10010000000o:0@0?bP403lX1030:f][@030?bP4000
0000000000D0oj@A00<000000?nT4@3oY1401@3oY1400`000000oj@A0?nT4@040?nT4@030:f][@00
0000ojHA00@0ojHA00@000000?nV4@3oYQ4000001P3oYQ42000000L0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400<0?nS408000002`3oXa000`000000[Jf]0?bP400=0?bP40800000
00<0o:0@0000000000001P3lX100102][Jd0mY`?0000000000050?JL3`030000003fW0l0mY`?00H0
mY`?0P0000030?JL3`030:f][@3/UPh0k9H>008000000P2][Jd20>bF3P8000001P3/UPh200000003
0:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]
00@0R5H70P2][Je20;3PiP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0`000002
0=>73P80000000@0dhL>0:f][@3_V1000000103_V10010000000kiP@0>nH403_V102000000030:f]
[@3lX100o:0@0080o:0@0P0000040?bP40040000003lX100[Jf]0:f][@@0o:0@00<000000?nT4@3o
Y140103oY1400`000000oj@A0?nT4@050?nT4@030000003oY140oj@A00@0oj@A00<0[Jf]0?nV4@00
00000P3oYQ42000000<0ojHA00<000000?nV4@3oYQ40103oYQ42000000L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400<0?nS408000002`3oXa000`000000[Jf]0?bP400?0?bP40<0
00001P3lX100102][Jd0mY`?0?JL3`0000050?JL3`030000003fW0l0mY`?00H0mY`?0P0000030?JL
3`030:f][@3/UPh0k9H>008000000P3/UPh20:f][@8000001P3/UPh2000000030:f][@3KRPd0fhX=
00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H70P2][Je20;3P
iP40oooo001I0;3PiP070:f][@2GH0/0Uf0;09MP2`2][Jd000000:f][@0200000080dhL>0P000000
103CQ`h0[Jf]0>nH400000040>nH40040000003_V100kiP@0>nH4080000000<0[Jf]0?bP403lX100
100000030?bP40030:f][@000000[Jf]00H0o:0@00<000000?nT4@3oY140103oY142000000H0oj@A
00<000000?nT4@3oY140103oY1400`2][Jd0ojHA0?nV4@02000000`0ojHA0P0000070?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3oYQ4^0:f][AL0ojD@00<0[Jf]0?nS403oXa00
303oXa02000000/0oj<@00<000000:f][@3lX1006@3lX100102][Jd0mY`?0?JL3`0000040?JL3`03
0000003fW0l0mY`?00H0mY`?0P0000030?JL3`030:f][@3/UPh0k9H>008000001@3/UPh00`000000
[Jf]0:f][@040>bF3P80000000<0[Jf]0=^:3@3KRPd00P3KRPd00`000000fhX=0=^:3@060=^:3@03
0:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H01`2][Jd0Uf0;
09MP2`2GH0/000000:f][@3CQ`h00P0000020=>73P80000000@0dhL>0:f][@3_V1000000103_V100
10000000kiP@0>nH403_V102000000030:f][@00000000000080o:0@0P0000030:f][@030?bP4000
0000000000H0o:0@00<000000?nT4@3oY1401@3oY1400`000000oj@A0?nT4@030?nT4@030000003o
Y140oj@A00D0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ42000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@00D0ojD@402][Jd70?nU40030:f][@3oXa00oj<@00`0oj<@0P00000;0?nS40030000002]
[Jd0o:0@01T0o:0@00D0[Jf]0?JL3`3fW0l0mY`?000000020?JL3`030000003fW0l0mY`?00L0mY`?
0P0000030?JL3`030:f][@3/UPh0k9H>008000001@3/UPh2000000030>bF3P2][Jd0[Jf]0080k9H>
0P0000000`2][Jd0fhX=0=^:3@020=^:3@030000003KRPd0fhX=00H0fhX=00<0[Jf]0;Ue2`2iM@/0
1`2iM@/00`2][Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00<0
[Jf]09MP2`2GH0/00P0000020=>73P8000000P3CQ`h2000000040=>73P2][Jd00000000000@0kiP@
00@000000>nH403_V100kiP@0`0000040?bP40800000103lX102000000D0o:0@0P0000070?nT4@80
0000103oY1400`000000oj@A0?nT4@050?nT4@030:f][@3oYQ40ojHA00d0ojHA0`0000070?nV4@03
0:f][@3oYQ40ojHA01H0ojHA302][JdG0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA005@3oYA0<0:f][@X0oj<@0P00000;0?nS40030000002][Jd0o:0@01T0o:0@00<0[Jf]0?JL3`3f
W0l00P3fW0l2000000X0mY`?0P0000030?JL3`030:f][@3/UPh0k9H>008000001@3/UPh2000000<0
k9H>0P2][Jd200000003045Yh@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd01`3KRPd00`2][Jd0
^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f]
[@2GH0/000000:f][@0000000P3CQ`h200000080dhL>0P000000102][Jd0kiP@0000000000040>nH
40040000003_V100kiP@0>nH4080000000<0[Jf]0?bP402][Jd00P2][Jd2000000@0o:0@0P000005
0?bP40800000203oY145000000P0oj@A00<0[Jf]0?nV4@3oYQ403@3oYQ43000000L0ojHA00<0[Jf]
0?nV4@3oYQ40303oYQ4:0:f][@@0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L
0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][@8000002`3oXa00
0`000000[Jf]0?bP400I0?bP40030:f][@3fW0l0mY`?00h0mY`?0P0000030?JL3`030:f][@3/UPh0
k9H>008000001@3/UPh2000000D0k9H>0P0000020:f][@<0fhX=00<000000=^:3@3KRPd01`3KRPd0
0`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3P
iP050:f][@00000000000:f][@0000000P3CQ`h200000080dhL>0P000000102][Jd0kiP@00000000
00040>nH40040000003_V100kiP@0>nH408000000P2][Jd30?bP40800000103lX102000000@0o:0@
00<000000?bP400000005@3oY1400`2][Jd0ojHA0?nV4@0=0?nV4@<000001`3oYQ400`2][Jd0ojHA
0?nV4@020?nV4@X0[Jf]3P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@
00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40800000202][Jd20?nS40800000
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`8000000`3fW0l00`2][Jd0k9H>
0>bF3P02000000D0k9H>0P0000050>bF3P80000000H0[Jf]0=^:3@2][Jd0[Jf]0=^:3@0000090=^:
3@030:f][@2iM@/0^GD;00H0^GD;00<0[Jf]08QF1`2][Jd00`28EPL00`2][Jd0/>3V0;3PiP100;3P
iP40oooo001I0;3PiP050:f][@000000000009MP2`0000000P3CQ`h200000080dhL>0P000000102]
[Jd0kiP@0000000000040>nH40040000003_V100kiP@0>nH4080000000<0[Jf]0?bP403lX1000P3l
X1000`000000o:0@0?bP40040?bP408000000`3lX1000`000000o:0@0000000E0?nT4@030:f][@3o
YQ40ojHA00d0ojHA0`0000040?nV4@P0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3o
YQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40800000203o
Xa020:f][@800000102][JdG0?bP40030:f][@3fW0l0mY`?00h0mY`?0P0000030?JL3`030:f][@3/
UPh0k9H>008000001P3/UPh00`000000k9H>0>bF3P030>bF3P80000000H0[Jf]045Yh@3KRPd0fhX=
0:f][@0000090=^:3@030:f][@2iM@/0^GD;00H0^GD;00@0[Jf]08QF1`28EPL0[Jf]0P28EPL00`2]
[Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@000000000009MP2`0000000P3CQ`h20000
0080dhL>0P000000102][Jd0kiP@0000000000040>nH40040000003_V100[Jf]0:f][@80000000<0
[Jf]0?bP403lX1000P3lX1000`000000o:0@0?bP40040?bP408000000P3lX10010000000o:0@0:f]
[@00000E0?nT4@030:f][@3oYQ40ojHA00d0ojHA0`0000040:f][@<0ojHA00<0[Jf]0?nV4@3oYQ40
6P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
703oYA000`2][Jd0oj<@0?nS400<0?nS408000002P3oXa02000000040:f][@3lX100o:0@0?bP40L0
[Jf]403lX1000`2][Jd0mY`?0?JL3`0>0?JL3`800000103fW0l4000000H0k9H>0P0000040>bF3P80
000000<0[Jf]045Yh@3KRPd00P3KRPd00`000000[Jf]0:f][@070=^:3@030:f][@2iM@/0^GD;00H0
^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]0480/>3V0@3oool005T0/>3V00D0[Jf]0000
00000000Uf0;000000020=>73P8000000P3CQ`h2000000040:f][@3_V1000000000000@0kiP@00@0
00000:f][@3_V100kiP@0P000000102][Jd0o:0@0?bP403lX102000000L0o:0@00L000000?bP403l
X10000000?bP402][Jd0000001D0oj@A00<0[Jf]0?nV4@3oYQ401`3oYQ460:f][@<000001`3oYQ40
0`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@00`0oj<@0P00000:0?nS4080000000<0[Jf]
0?bP403lX100203lX1060:f][@X0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l2000000@0mY`?00@0[Jf]
0>bF3P00000000001`3/UPh02@000000k9H>0>bF3P3/UPh000000>bF3P000000[Jf]045Yh@030=^:
3@030000003KRPd0fhX=0080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H7
08QF1`2][Jd0R5H70:f][@120;3PiP40oooo001H0;3PiP060000002][Jd000000000002GH0/00000
0P3CQ`h200000080dhL>00@000000=>73P2][Jd0kiP@0P0000020>nH4080[Jf]00@000000>nH403_
V100kiP@0P0000001@2][Jd0o:0@0?bP403lX100000000T0o:0@0P0000020?bP40030:f][@000000
oj@A01@0oj@A00@0[Jf]0?nV4@3oYQ40ojHA1P2][Jd60?nV4@<000001`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400L0?nU40030:f][@3oXa00oj<@00T0oj<@1@00000:0?nS4080000000<0[Jf]0?bP403lX1003P3l
X1070:f][@<0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l2000000@0mY`?00<0[Jf]0>bF3P3/UPh02@3/
UPh01`000000k9H>0>bF3P000000k9H>0000002][Jd0103KRPd00`000000fhX=0=^:3@020=^:3@80
[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@11JN40R5H70080R5H70P2][Je20;3PiP40
oooo001H0;3PiP@0000000@0Uf0;0000003CQ`h0dhL>0P0000001P3CQ`h000000000003CQ`h0[Jf]
0>nH408000000P2][Jd20>nH40030000003_V100kiP@0080kiP@00<000000:f][@3lX1000P3lX100
0`000000o:0@0?bP400;0?bP40030:f][@000000oj@A01<0oj@A1@2][Jd<0?nV4@030000003oYQ40
000000L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400<0?nS40T000000`3oXa02
000000030:f][@3lX100o:0@01D0o:0@1P2][Jd>0?JL3`800000103fW0l00`2][Jd0k9H>0>bF3P09
0>bF3P070000003/UPh0k9H>0000003/UPh000000:f][@040=^:3@030000003KRPd0fhX=00@0fhX=
0P2][Jd00`3KRPd0[Jf]0;Ue2`070;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0
@02`h>H10?ooo`00F02`h>H40000000409MP2`000000dhL>0=>73P80000000H0dhL>000000000000
dhL>0:f][@3_V102000000@0kiP@00<000000>nH403_V1000P3_V102000000<0o:0@00<000000?bP
403lX1002`3lX10200000100oj@A102][Jd00`3oY140[Jf]0?nV4@0>0?nV4@800000203oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01D0oj<@1@0000000`2][Jd0o:0@0?bP400H0?bP
40030:f][@3fW0l0mY`?00@0[Jf]2P3fW0l2000000@0mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20000
0080k9H>00<000000:f][@3KRPd00`3KRPd00`000000fhX=0=^:3@060=^:3@80[Jf]2@2iM@/00`2]
[Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00F02`h>H6000000030=>73P00000000000080
dhL>0P0000000`3CQ`h0[Jf]0:f][@02000000@0kiP@00<000000>nH403_V1000`3_V10010000000
o:0@0?bP4000000>0?bP40800000303oY1440:f][@D0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ400`00
0000ojHA0?nV4@060?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?00@0mY`?1@2][Jd50?JL3`800000103fW0l00`2]
[Jd0k9H>0>bF3P0>0>bF3P030000002][Jd0fhX=00<0fhX=00<000000=^:3@3KRPd01`3KRPd20:f]
[@P0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005P0/>3V1@000000102][Jd0
dhL>0000000000020=>73P8000000P2][Jd00`3_V1000000000000030>nH40030000003_V100kiP@
00@0kiP@00@0[Jf]00000000000000003P3lX102000000P0oj@A102][Jd90?nT4@030:f][@3oYQ40
ojHA00h0ojHA00<000000?nV4@3oYQ401P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00
oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`090?JL3`D0[Jf]0P000004
0?JL3`030:f][@3/UPh0k9H>00h0k9H>00<000000:f][@3KRPd00`3KRPd00`000000fhX=0=^:3@07
0=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3o
ool005P0/>3V00<000000:f][@0000000P000000102][Jd0dhL>0000000000020=>73P80000000<0
dhL>0:f][@3_V1000P0000030>nH40030000003_V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3l
X102000000@0oj@A102][Jd=0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3f
W0l200000080[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0>0>bF3P030000003/UPh0[Jf]00<0fhX=0P00
00080=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@@2`h>H10?ooo`00E`2`h>H020000000[Jf]0:f][@000000Uf0;0000002][Jd0dhL>0P0000020=>7
3P80000000<0dhL>0:f][@3_V1000P0000030>nH40030000003_V100kiP@00@0kiP@00<0[Jf]0?bP
403lX1003`3lX102000000@0[Jf]4@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?
00h0mY`?0P0000020?JL3`@0[Jf]3`3/UPh00`000000k9H>0:f][@030=^:3@800000203KRPd00`2]
[Jd0^GD;0;Ue2`020;Ue2`030:f][@2iM@/0^GD;0080^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f]
[D40/>3V0@3oool005L0/>3V00P000000:f][@2][Jd0000009MP2`000000[Jf]0=>73P8000000P2]
[Jd2000000030=>73P2][Jd0kiP@008000000`3_V1000`000000kiP@0>nH40040>nH40030:f][@3l
X100o:0@00h0o:0@00<0[Jf]0000000000005@3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3o
YQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3o
YA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3f
W0l0mY`?00h0mY`?0P0000040?JL3`030:f][@3/UPh0[Jf]0080[Jf]303/UPh2000000040:f][@3K
RPd0fhX=0=^:3@800000203KRPd00`2][Jd0^GD;0;Ue2`030;Ue2`050:f][@2iM@/0^GD;045Yh@2]
[Jd01028EPL20:f][D40/>3V0@3oool005L0/>3V00P000000:f][@2][Jd0000009MP2`000000[Jf]
0=>73P8000000P3CQ`h2000000030=>73P2][Jd0kiP@008000000P3_V1000`000000kiP@0>nH4005
0>nH40030:f][@3lX100o:0@00`0o:0@0P2][Jd00`3lX10000000000000E0?nT4@030:f][@3oYQ40
ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00
ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100
o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l03P3fW0l2000000@0mY`?00D0[Jf]0>bF3P3/UPh000000>bF
3P020:f][@X0k9H>0P000000102][Jd0fhX=0=^:3@3KRPd2000000P0fhX=00<0[Jf]0;Ue2`2iM@/0
102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H70P2][Je10;3PiP40oooo001G0;3PiP080000002]
[Jd0[Jf]0000002GH0/000000:f][@3CQ`h200000080dhL>0P0000001@3CQ`h0[Jf]0>nH40000000
kiP@00<000001`3_V1000`2][Jd0o:0@0?bP40090?bP40<0[Jf]0`3lX102000001D0oj@A00<0[Jf]
0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0>0?JL3`800000103fW0l0102][Jd0k9H>00000000
00030>bF3P<0[Jf]1`3/UPh2000000040:f][@3KRPd0fhX=0=^:3@800000203KRPd00`2][Jd0^GD;
0;Ue2`060;Ue2`80[Jf]1028EPL20:f][D40/>3V0@3oool005L0/>3V00H000000:f][@2][Jd00000
09MP2`0000020:f][@8000000P3CQ`h3000000030:f][@000000kiP@00/0kiP@00<0[Jf]0?bP403l
X1001`3lX1020:f][@H0o:0@0P00000E0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA00703oYA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3f
W0l0303fW0l4000000@0mY`?00@0[Jf]0>bF3P00000000001P3/UPh30:f][@@0k9H>0P000000102]
[Jd0fhX=0=^:3@3KRPd2000000P0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`02
08QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H020000000[Jf]09MP2`000000Uf0;0000002][Jd0dhL>
0P0000020=>73P<0000000<0[Jf]0000003_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]
203lX102000001@0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f]
[@3oYQ40ojHA01D0ojHA;P2][JdG0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100
603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`040:f][@3/UPh00000000000T0k9H>0P2][Jd20>bF3P80
000000@0[Jf]0=^:3@3KRPd0fhX=0P0000080=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF
1`80[Jf]@@2`h>H10?ooo`00E`2`h>H020000000[Jf]09MP2`000000Uf0;0000002][Jd0dhL>0P00
00020=>73P80000000<0[Jf]0000003_V100303_V100102][Jd0o:0@0?bP403lX1030:f][@/0o:0@
0P00000D0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@050?nV4A00[Jf];P2`h>H@0:f][@L0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00@0[Jf]0>bF3P3/UPh000002`3/UPh20:f][@80
000000@0[Jf]0=^:3@3KRPd0fhX=0P0000090=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd308QF
1`80[Jf]@@2`h>H10?ooo`00E`2`h>H020000000[Jf]09MP2`000000Uf0;0000002][Jd0dhL>0P00
00020=>73P80000000<0[Jf]0>nH403_V100303_V100102][Jd0o:0@0:f][@2][Jd<0?bP40800000
00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01H0ojHA
302][Je>0;3PiPl0[Jf]5@3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?
00<0[Jf]0>bF3P3/UPh03P3/UPh200000080[Jf]0P3KRPd2000000T0fhX=00<0[Jf]0;Ue2`2iM@/0
1P2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H020000000[Jf]09MP
2`000000[Jf]0000002][Jd0dhL>0P0000001@3CQ`h000000000003CQ`h0[Jf]00d0kiP@0`2][Jd@
0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0<
0?nV4@X0[Jf]J@2`h>H>0:f][@L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@3/UPh0k9H>00h0k9H>0P000000102][Jd0fhX=0:f][@2][Jd2000000T0fhX=00<0
[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H0
20000000[Jf]09MP2`000000Uf0;0000002][Jd0dhL>0P0000040=>73P030:f][@3_V100kiP@00T0
kiP@0P2][Jd00`3_V100[Jf]0?bP400@0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3o
YQ40603oYQ400`2][Jd0ojHA0?nV4@020?nV4@X0[Jf]P@2`h>H:0:f][AP0o:0@00<0[Jf]0?JL3`3f
W0l0503fW0l00`2][Jd0k9H>0>bF3P0>0>bF3P80000000@0[Jf]0=^:3@3KRPd0fhX=0P0000090=^:
3@030:f][@2iM@/0^GD;00H0^GD;00D0[Jf]08QF1`28EPL0[Jf]08QF1`020:f][D40/>3V0@3oool0
05L0/>3V10000000102GH0/000000:f][@3CQ`h2000000@0dhL>00<0[Jf]0>nH403_V1001`3_V102
0:f][@<0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40
ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E0?JL3`030:f][@3/UPh0
k9H>00/0k9H>10000000102][Jd0fhX=0=^:3@3KRPd200000080[Jf]1`3KRPd00`2][Jd0^GD;0;Ue
2`060;Ue2`040:f][@28EPL0R5H708QF1`<0[Jf]@@2`h>H10?ooo`00E`2`h>H40000000309MP2`00
0000[Jf]008000001@3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2]
[Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03@3/UPh2000000040:f][@3K
RPd0fhX=0=^:3@8000000P3KRPd20:f][@D0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/0102][Jd0R5H7
08QF1`28EPL30:f][D40/>3V0@3oool005L0/>3V100000000`2GH0/000000:f][@070=>73P030:f]
[@3_V100kiP@00<0kiP@0P2][Jd70>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140
4`3oY1400`2][Jd0ojHA0?nV4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l0
5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd0
0P3KRPd20:f][@<0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]
@@2`h>H10?ooo`00E`2`h>H50000000309MP2`2][Jd0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@
0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA
0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@030000003KRPd0fhX=00@0fhX=0P2][Jd00`3KRPd0
[Jf]0;Ue2`080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H600000003
0:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH402][Jd0[Jf]2`3_V1000`2][Jd0o:0@0?bP400?0?bP
40030:f][@3oY140oj@A0140oj@A1P2][Jg70;3PiPD0[Jf]5@3fW0l00`2][Jd0k9H>0>bF3P0?0>bF
3P030:f][@3KRPd0fhX=0080fhX=00<000000=^:3@3KRPd01P3KRPd20:f][@T0^GD;00@0[Jf]08QF
1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiPH0000000<0[Jf]0=>73P3CQ`h01P3CQ`h20:f]
[@d0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0=0?nT4@@0[Jf]dP2`h>H50:f]
[A00mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@<0[Jf]1`2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V1@0000000`2GH0/0[Jf]0=>73P060=>7
3P80[Jf]3P3_V1000`2][Jd0o:0@0?bP400?0?bP40030:f][@3oY140oj@A00T0oj@A102][JgK0;3P
iP@0[Jf]303fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00@0[Jf]0;Ue
2`2iM@/0[Jf]1P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V1@000000
0`2GH0/0[Jf]0=>73P040=>73P80[Jf]00<0dhL>0:f][@3_V100303_V1000`2][Jd0o:0@0?bP400@
0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3fW0l00`2][Jd0k9H>0>bF3P0@
0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@050;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H50000000309MP2`2][Jd0dhL>00<0dhL>00D0
[Jf]0=>73P3CQ`h0dhL>0:f][@0=0>nH40030:f][@3lX100o:0@0100o:0@00<0[Jf]0?nT4@3oY140
102][Jg]0;3PiPD0[Jf]0P3fW0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=
00<0[Jf]0;Ue2`2iM@/00P2iM@/20:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40
oooo001F0;3PiP80000000D0[Jf]000000000000Uf0;0:f][@030=>73P030:f][@3CQ`h0dhL>0080
dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400?0?bP40@0[Jf]mP2`h>H40:f][A40
k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`040:f][@2iM@/0^GD;0:f]
[@<0R5H70P2][Je10;3PiP40oooo001F0;3PiP80000000P0[Jf]0000002GH0/0Uf0;0:f][@3CQ`h0
[Jf]000000D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP400<0?bP40<0[Jf]oP2`
h>H30:f][@h0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`<0[Jf]0`28
EPL20:f][D40/>3V0@3oool005H0/>3V0P000000102][Jd0000009MP2`2GH0/20:f][@8000001@3C
Q`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00X0o:0@0P2][Jd30;VbYP<0[Jf]nP2`
h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;
0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0?`2`h>H10?ooo`00EP2`
h>H010000000[Jf]09MP2`00000209MP2`040:f][@3CQ`h00000000000D0dhL>00<0[Jf]0>nH403_
V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V102][Jd70<>m^`@0
[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`03
0:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00D000000:f][@2GH0/0000009MP2`020:f][@03
0=>73P000000000000D0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0
[Jf]00<0/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@2`h>H0/>3V03l0
/>3V0@3oool005H0/>3V00D000000:f][@2GH0/0000009MP2`020:f][@80dhL>00<000000=>73P3C
Q`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080o:0@0P2][Jd40;6[W@03
0:f][@2i/ZH0^K:V00`0^K:V0`2][JgW0;3PiP@0[Jf]00<0a/2l0:f][@33_K/03`33_K/00`2][Jd0
_[Vh0;ji^0030:f][@030>bF3P2][Jd0fhX=00`0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
R5H70:f][@0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00L000000:f][@2GH0/0
00000:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0:f][@020:f]
[@H0/J^M00<0[Jf]0;VbYP2i/ZH03@2i/ZH00`2][Jd0_[N/0:f][@030:f][N00/>3V0`2][Jd50<K0
_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP00`2n^KP20:f][@d0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@0208QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0
/>3V00@000000:f][@2GH0/000000P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00X0kiP@0`2][Jd80;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f]
[MP0/>3V102][Jd80<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0102n^KP00`11
JN40[Jf]0:f][@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00H0[Jf]08QF1`28EPL0[Jf]08QF1`2]
[Je10;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;00000080Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h00`2][Jd0kiP@0>nH40080>nH4080[Jf]2`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n
]j`0_[N/00L0_[N/102][Jg@0;3PiP@0[Jf]3036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh0080_[Vh0P11JN430;ji^080[Jf]2@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H010000000[Jf]0:f][@00000209MP2`030:f]
[@3CQ`h0dhL>00H0dhL>00<0[Jf]0>nH403_V1001P3_V1040:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]b02`h>H40:f][A00a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^003045Yh@@0_[Vh102][Jd70=^:3@030:f][@2iM@/0^GD;00L0^GD;
00@0[Jf]08QF1`28EPL0R5H70P2][Je10;3PiP40oooo001F0;3PiP040000002][Jd0[Jf]00000080
Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH40030>nH40<0[Jf]00@0Y9j?0:f][@2a
Zid0/J^M0P2][Jd90;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`03`2n]j`40:f]
[Kl0/>3V1@2][Jd20<O1_0030:f][@36`;`0a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2]
[Jd0_[Vh0;ji^0020;ji^003045Yh@2n^KP0_[Vh0080[Jf]102n^KP20:f][@D0fhX=00<0[Jf]0;Ue
2`2iM@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H010000000
[Jf]09MP2`00000209MP2`030:f][@3CQ`h0dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd4
0:BNS`030:f][@2aZid0/J^M0080/J^M0P2][Jd70;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/0050:f][K@0/>3V1P2][Jd70<O1_0030:f][@36`;`0
a/2l00l0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^003045Yh@2][Jd0
[Jf]00H0_[Vh00@0[Jf]045Yh@2][Jd0[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28
EPL0R5H70080R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd000000080Uf0;00<0[Jf]
0=>73P3CQ`h01`3CQ`h01P2][Jd0kiP@0:f][@2][Jd0Y9j?045Yh@80Y9j?0`11JN460;6[W@80[Jf]
1@2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[00
1@31^[060:f][JT0/>3V1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3@33_K/01P2][Jd0_[Vh0;ji^02n^KP0[Jf]045Yh@P0_[Vh0P11JN420;B`/@80[Jf]00<0fhX=0:f]
[@2iM@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005H0/>3V00<000000:f]
[@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]00<0@FWQ0:BNS`2TWXl00P11JN430:BN
S`<0@FWQ1P2aZid20:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg
[0030:f][@31^[00`KZ`00/0`KZ`1@2][JfO0;3PiPD0[Jf]4P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00d0`kfk00H0[Jf]0;ji^02][Jd0[Jf]0;ji^011JN480;ji^0030:f][@11
JN40];2a0080];2a00<0@FWQ0:f][@2][Jd02P2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V
0@3oool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P060=>73P040:f][@2T
WXl0@FWQ045Yh@80Y9j?0P11JN430:BNS`03045Yh@2aZid0/J^M00P0/J^M0P2][Jd00`2aZid0[Jf]
0;VbYP0?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004031^[060:f][I@0/>3V
1@2][Jd20<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk
0<>m^`0<0<>m^`<0[Jf]0`2n^KP00`11JN40_[Vh0;ji^0060;ji^0030:f][@11JN40];2a0080];2a
0P11JN400`2d/;40[Jf]0:f][@080;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00
EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00@0dhL>0P2][Jd20:BNS`80@FWQ
0P2TWXl2045Yh@<0Y9j?00<0@FWQ0;6[W@2aZid02P2aZid30:f][@l0^K:V00<0[Jf]0;jg[02n]j`0
402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m/`L0[Jf]Q`2`h>H60:f][@L0
b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00T0
`kfk0`2][Jd00`33_K/0[Jf]0;ji^0030;ji^003045Yh@2n^KP0@FWQ00<0@FWQ0`2n^KP00`2][Jd0
@FWQ0;B`/@020;B`/@80@FWQ0`2d/;400`2][Jd0^GD;0;Ue2`050;Ue2`040:f][@28EPL0R5H708QF
1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>00<0
dhL>0`2][Jd20:BNS`80@FWQ0`2TWXl01@11JN40Y9j?0:BNS`2][Jd0@FWQ00d0/J^M00<0[Jf]0;Vb
YP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2]
[Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh
0080_[Vh0P11JN420;ji^080@FWQ102n^KP00`11JN40];2a0;B`/@020;B`/@05045Yh@2d/;40];2a
0;B`/@11JN400P2][Jd50;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H0
0`000000[Jf]09MP2`0209MP2`030:f][@3CQ`h0dhL>0080dhL>00@0[Jf]08Z5M@2:QGD0[Jf]0P2T
WXl2045Yh@<0Y9j?00D0@FWQ0:BNS`2TWXl0[Jf]045Yh@090;6[W@05045Yh@2aZid0/J^M0;6[W@2]
[Jd01@2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc0100`kfc2@2][JeY0;3PiPP0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_003
0:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/00P33_K/40:f][@L0`kfk00<0[Jf]0;ji^011
JN400P2n^KP2045Yh@<0_[Vh0P11JN430;ji^003045Yh@2d/;40];2a0080];2a00D0@FWQ0;B`/@2d
/;40];2a045Yh@040:f][@<0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo001F0;3P
iP030000002][Jd0Uf0;0080Uf0;00D0[Jf]0=>73P3CQ`h0dhL>0:f][@0308Z5M@<0[Jf]0P11JN43
0:BNS`05045Yh@2TWXl0Y9j?0:f][@11JN401`2aZid2045Yh@050;6[W@11JN40/J^M0;6[W@2][Jd0
202i/ZH30:f][@D0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D00`35_[D<0:f][E40/>3V302][Jd50<S1^`030:f]
[@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f]
[@33_K/0[Jf]0080[Jf]2`33_K/00`2][Jd0_[Vh045Yh@020;ji^080@FWQ0`2n^KP2045Yh@<0_[Vh
00<0@FWQ0;B`/@2d/;400P2d/;402P11JN40];2a0;B`/@2][Jd0@FWQ0;B`/@2][Jd0@FWQ09nKX02]
[Jd20;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP
2`0209MP2`040:f][@3CQ`h0[Jf]0:f][@@0RXEe00<0[Jf]0:BNS`2TWXl00P11JN430:BNS`05045Y
h@2TWXl0Y9j?0:f][@11JN401`2aZid01`11JN40/J^M0;6[W@2aZid0@FWQ0;6[W@2][Jd00P11JN49
0;VbYP@0[Jf]00<0^K:V0:f][@2n]j`04@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0
`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03`35_[DA0:f][Bl0/>3V4@2][JdA0<S1^`030:f][@38`K/0
b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00?0<K0_0<0[Jf]3033_K/0
1011JN40`kfk0:f][@11JN430;ji^080@FWQ0`2n^KP2045Yh@<0_[Vh00<0@FWQ0;B`/@2d/;400P2d
/;401`11JN40[Jf]0:f][@2d/;40@FWQ0;B`/@2][Jd00`11JN430:f][@@0R5H700<0[Jf]0;3PiP2`
h>H0?P2`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP2`0209MP2`80[Jf]1P2:QGD01P2][Jd0Y9j?
045Yh@2TWXl0@FWQ0:f][@80Y9j?00D0@FWQ0:BNS`2TWXl0[Jf]045Yh@070;6[W@07045Yh@2aZid0
/J^M0;6[W@11JN40/J^M045Yh@0?0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]
2`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02`33_K/01@11JN40`kfk
045Yh@2][Jd0@FWQ00<0_[Vh0P11JN440;ji^005045Yh@2n^KP0_[Vh0;ji^011JN400`2d/;400`2]
[Jd0@FWQ0;B`/@020;B`/@05045Yh@2d/;40[Jf]09nKX011JN400`2OVj000`2][Jd0R5H708QF1`02
08QF1`030:f][@2`h>H0/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2]
[Jd0@FWQ08Z5M@0508Z5M@040:f][@2TWXl0@FWQ045Yh@80Y9j?0P2][Jd00`11JN40Y9j?0:BNS`02
045Yh@H0/J^M0P11JN440;6[W@80@FWQ1P2i/ZH00`11JN40^K:V0;VbYP070;VbYP030:f][@2n]j`0
[Jf]00<0[Jf]3@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]
0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04@37`K`00`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`08
0<>m^`80@FWQ0P33_K/3045Yh@<0_[Vh0P11JN440;ji^005045Yh@2n^KP0_[Vh0;ji^011JN400P2d
/;400`2][Jd0];2a045Yh@030;B`/@03045Yh@2d/;40[Jf]00H0Wi^P00D0[Jf]08QF1`28EPL0R5H7
0:f][@100;3PiP40oooo001F0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P11JN4608Z5M@040:f]
[@2TWXl0@FWQ045Yh@@0Y9j?00<0@FWQ0:BNS`2TWXl00P11JN460;6[W@80@FWQ102aZid2045Yh@H0
^K:V00<0@FWQ0;VbYP2i/ZH01`2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]2@2n]j`00`2][Jd0
`KZ`0<6j/00A0<6j/0030:f][@33_K<0`kfc01@0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`00`2][Jd0
a/2l0<K0_0030<K0_0@0[Jf]2@36`;`00`2][Jd0`kfk0<>m^`080<>m^`03045Yh@33_K/0`kfk0080
`kfk0P11JN430;ji^080@FWQ102n^KP01@11JN40_[Vh0;ji^02n^KP0@FWQ0080[Jf]0P2d/;401`11
JN40];2a0;B`/@2d/;40@FWQ0;B`/@2][Jd01P2OVj001@2][Jd0R5H708QF1`28EPL0[Jf]0400/>3V
0@3oool005H0/>3V00H0[Jf]09MP2`2GH0/0Uf0;0:f][@11JN4708Z5M@040:f][@2TWXl0@FWQ045Y
h@@0Y9j?00<0@FWQ0:f][@2][Jd00P11JN460;6[W@80@FWQ102aZid2045Yh@H0^K:V00D0@FWQ0;Vb
YP2i/ZH0^K:V045Yh@050;VbYP030:f][@2n]j`0_[N/00L0_[N/102][Jd50;jg[0030:f][@31^[00
`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f][@36`;`0
[Jf]00<0[Jf]3@36`;`0102][Jd0@FWQ045Yh@11JN460<>m^`80@FWQ1033_K/2045Yh@<0_[Vh0P11
JN440;ji^005045Yh@2n^KP0_[Vh0:f][@11JN40102d/;401`11JN40];2a0;B`/@2d/;40@FWQ0;B`
/@2][Jd01`2OVj00102][Jd0R5H708QF1`2][Je00;3PiP40oooo001F0;3PiP030:f][@2GH0/0Uf0;
0080[Jf]00<0@FWQ08Z5M@2:QGD01@2:QGD0102][Jd0Y9j?045Yh@11JN440:BNS`03045Yh@2TWXl0
Y9j?0080@FWQ1`2aZid00`11JN40/J^M0;6[W@020;6[W@80@FWQ1@2i/ZH2045Yh@<0^K:V00<0@FWQ
0;VbYP2i/ZH00`2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004P31^[00
0`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL05036_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0
0`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][Jd?0<K0_0@0@FWQ2033_K/2
045Yh@@0`kfk0P11JN430;ji^080@FWQ102n^KP01011JN40[Jf]0:f][@2n^KP2045Yh@<0];2a00@0
@FWQ0;B`/@2d/;40@FWQ0P2d/;400`2][Jd0Wi^P09nKX00509nKX080[Jf]00<0R5H70:f][@2`h>H0
?`2`h>H10?ooo`00EP2`h>H0102][Jd0Uf0;0:f][@1SH5<20:f][@H0RXEe00<0[Jf]0:BNS`2TWXl0
0P11JN440:BNS`03045Yh@2TWXl0Y9j?0080@FWQ0P2][Jd50;6[W@03045Yh@2aZid0/J^M0080/J^M
0P11JN450;VbYP80@FWQ0`2i/ZH00`11JN40^K:V0;VbYP030;VbYP030:f][@2n]j`0_[N/00l0_[N/
102][JdA0<6j/0030:f][@33_K<0@FWQ0080@FWQ4@33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f]
[@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]
0P37`K`00`2][Jd0a/2l0<K0_00:0<K0_080@FWQ1036`;`2045Yh@P0`kfk0P11JN440<>m^`80@FWQ
0`2n^KP2045Yh@<0_[Vh00<0[Jf]045Yh@2n^KP00P2n^KP0102][Jd0@FWQ0;B`/@2d/;42045Yh@D0
];2a00<0[Jf]09nKX02OVj001@2OVj00102][Jd0L6ii0:f][@2][Je00;3PiP40oooo001F0;3PiP80
[Jf]0`1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?0080@FWQ102TWXl00`11JN40
Y9j?0:BNS`02045Yh@80/J^M0`2][Jd20;6[W@03045Yh@2aZid0/J^M0080/J^M0P11JN450;VbYP80
@FWQ0P2i/ZH2045Yh@D0^K:V00<0[Jf]0;jg[02n]j`00P2n]j`3045Yh@/0_[N/00<0[Jf]0<6j/031
^[001@2][Jd<0<6j/0030:f][@33_K<0`kfc0080`kfc1011JN4=0<>m/`030:f][@35_[D0aKje01@0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0
al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l00L0a/2l00<0@FWQ0<K0_036`;`00P11JN440<K0_080
@FWQ2033_K/2045Yh@@0`kfk0P11JN430;ji^080@FWQ0`2][Jd00`2n^KP0@FWQ0;ji^0020;ji^005
0:f][@11JN40@FWQ0;B`/@11JN401P2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]00<0L6ii0:f]
[@2][Jd0@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd508Z5M@030:f][@2TWXl0Y9j?0080
@FWQ102TWXl00`11JN40Y9j?0:BNS`02045Yh@D0/J^M0P2][Jd00`2aZid0@FWQ0;6[W@020;6[W@80
@FWQ1@2i/ZH2045Yh@80^K:V0P11JN450;VbYP050:f][@2n]j`0_[N/0;jg[011JN400`2n]j`01011
JN40_[N/045Yh@11JN470;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0
`kfc0080`kfc00<0@FWQ0<>m/`33_K<03P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0
b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_0050:f][@`0al6l00<0[Jf]
0<K0_036`;`01P36`;`00`11JN40a/2l045Yh@03045Yh@@0a/2l0P11JN480<>m^`80@FWQ1033_K/2
045Yh@<0_[Vh0P11JN440;ji^008045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ0;B`/@11JN470;B`/@03
0:f][@2OVj00Wi^P00<0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool005H0/>3V
00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0408Z5M@030:f][@2TWXl0Y9j?0080@FWQ
0`2TWXl2045Yh@80Y9j?0`11JN400`2aZid0@FWQ0;6[W@030;6[W@80[Jf]0P11JN400`2aZid0@FWQ
045Yh@040;VbYP<0@FWQ0P2i/ZH3045Yh@<0^K:V00D0[Jf]0;jg[02n]j`0_[N/045Yh@050;jg[0<0
@FWQ0`2n]j`3045Yh@030;jg[02][Jd0`KZ`00/0`KZ`1@2][Jd20<6j/0030:f][@33_K<0`kfc0080
`kfc00<0@FWQ0<>m/`33_K<03P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0
a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0
b<6k00<0[Jf]0<S1^`38`K/04038`K/60:f][A40al6l00<0[Jf]0<K0_036`;`01036`;`2045Yh@<0
a/2l0`11JN440<K0_080@FWQ2@33_K/2045Yh@@0`kfk00@0@FWQ0;ji^02][Jd0[Jf]0P11JN440;ji
^006045Yh@2n^KP0_[Vh0;ji^02][Jd0@FWQ2@2d/;400`2][Jd0Wi^P09nKX00209nKX0040:f][@2O
Vj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0
[Jf]08Z5M@2:QGD0[Jf]0`2:QGD00`2][Jd0Y9j?0:BNS`02045Yh@<0Y9j?0P11JN400`2TWXl0@FWQ
045Yh@02045Yh@030;6[W@11JN40@FWQ00H0/J^M00@0[Jf]045Yh@11JN40@FWQ102i/ZH00`11JN40
^K:V045Yh@020;VbYP<0@FWQ0`2i/ZH00`2][Jd0_[N/0;jg[002045Yh@D0_[N/0`11JN450;jg[0@0
@FWQ4031^[070:f][@03045Yh@33_K<0`kfc00h0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l00d0
al6l00D0@FWQ0<O1_037`K`0al6l0:f][@050<K0_080@FWQ1@36`;`2045Yh@@0a/2l0P11JN4:0<>m
^`H0@FWQ00<0[Jf]0;ji^02n^KP00P11JN430;ji^003045Yh@2n^KP0_[Vh0080_[Vh00<0[Jf]045Y
h@2d/;401P2d/;400`11JN40];2a0:f][@0209nKX080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f]
[Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<01@2][Jd0RXEe08Z5M@2:QGD0[Jf]
0080RXEe00<0[Jf]0:BNS`2TWXl00P11JN430:BNS`80@FWQ0P2TWXl3045Yh@030;6[W@11JN40@FWQ
00<0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@050:f][@2i/ZH0^K:V0;VbYP11JN400P2i/ZH0
1@11JN40^K:V045Yh@2i/ZH0@FWQ00<0^K:V00@0[Jf]0;jg[011JN40@FWQ1`2n]j`2045Yh@D0_[N/
00<0@FWQ0;jg[02][Jd04`31^[000`2][Jd0`kfc0<>m/`020<>m/`03045Yh@2][Jd0[Jf]00T0[Jf]
1@33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00@0[Jf]0<S1^`38`K/0
b<6k202][Jd:0<S1^`030:f][@37`K`0al6l00P0al6l00<0@FWQ0<O1_037`K`00P37`K`01@11JN40
al6l0<O1_037`K`0[Jf]00D0a/2l00<0@FWQ0<K0_036`;`01036`;`2045Yh@@0a/2l0P11JN4;0<>m
^`<0[Jf]00<0`kfk045Yh@2n^KP00P2n^KP2045Yh@<0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP00`2]
[Jd0@FWQ0;B`/@060;B`/@80@FWQ00<0[Jf]09nKX02][Jd01@2OVj000`2][Jd0L6ii071^N@020:f]
[Cl0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0208Z5M@03
0:f][@2:QGD0[Jf]0080Y9j?0P11JN430:BNS`05045Yh@2TWXl0Y9j?0:BNS`2][Jd00P2aZid2045Y
h@@0/J^M00<0@FWQ0;6[W@2aZid00P2aZid2045Yh@050;VbYP2][Jd0[Jf]0:f][@11JN400P2i/ZH3
045Yh@030;VbYP11JN40^K:V0080^K:V00@0[Jf]0;jg[011JN40@FWQ1`2n]j`2045Yh@D0_[N/00<0
@FWQ0;jg[02][Jd04`31^[000`2][Jd0`kfc0<>m/`020<>m/`03045Yh@33_K<0`kfc00T0`kfc2`2]
[JdA0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1
^P0E0<O1^P030:f][@38`K/0b<6k00l0b<6k2@2][JdB0<S1^`030:f][@37`K`0al6l00P0al6l00<0
@FWQ0<O1_037`K`00P37`K`01@11JN40al6l0<O1_037`K`0[Jf]00@0a/2l0P11JN460<K0_080@FWQ
1036`;`2045Yh@P0`kfk0`2][Jd40<>m^`04045Yh@2n^KP0_[Vh0;ji^0<0@FWQ00<0_[Vh045Yh@2n
^KP0102n^KP00`2][Jd0@FWQ0;B`/@060;B`/@04045Yh@2d/;40[Jf]0:f][@H0Wi^P00<0[Jf]071^
N@1`KWT00P2][Jdo0;3PiP40oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00<0[Jf]08Z5M@2:
QGD00`2:QGD20:f][@040:BNS`11JN40@FWQ045Yh@<0Y9j?00D0@FWQ0:BNS`2TWXl0Y9j?0:f][@08
0;6[W@03045Yh@2aZid0/J^M0080/J^M00<0@FWQ0:f][@2i/ZH00`2i/ZH00`11JN40[Jf]0:f][@03
045Yh@030;VbYP11JN40^K:V0080^K:V00@0[Jf]0;jg[011JN40@FWQ1`2n]j`00`11JN40_[N/0;jg
[0040;jg[003045Yh@2n]j`0[Jf]00T0`KZ`1P11JN440<6j/0030:f][@33_K<0`kfc0080`kfc00<0
@FWQ0<>m/`33_K<03P33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1
^`030<S1^``0[Jf]1@38`K/00`2][Jd0b<6k0<S1^`0C0<S1^`050:f][@37`K`0al6l0<O1_011JN40
1P37`K`00`11JN40al6l0<O1_0020<O1_080@FWQ0P37`K`00`2][Jd0a/2l0<K0_0020<K0_003045Y
h@36`;`0a/2l00D0a/2l0P11JN440<K0_080@FWQ1P33_K/20:f][@L0`kfk00@0@FWQ0;ji^02n^KP0
_[Vh0P11JN400`2n^KP0@FWQ0;ji^0050;ji^0030:f][@11JN40];2a00H0];2a00<0@FWQ0;B`/@2]
[Jd01`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005H0/>3V00<0[Jf]06=PD`1S
H5<00P1SH5<00`2][Jd0RXEe08Z5M@0408Z5M@030:f][@2TWXl0Y9j?0080@FWQ0P2TWXl00`11JN40
Y9j?0:BNS`020:BNS`030:f][@2aZid0/J^M00H0/J^M00<0@FWQ0;6[W@2aZid00P2aZid00`11JN40
[Jf]0;VbYP030;VbYP03045Yh@2i/ZH0^K:V00<0@FWQ00<0[Jf]045Yh@2i/ZH00P2i/ZH00`2][Jd0
_[N/045Yh@080;jg[003045Yh@2n]j`0_[N/00@0_[N/00<0@FWQ0:f][@31^[002@31^[02045Yh@@0
`KZ`00@0@FWQ0<6j/031^[00`KZ`0P11JN430<>m/`03045Yh@33_K<0`kfc00h0`kfc00<0[Jf]0<Fn
]@35_[D03`35_[DA0:f][@`0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0:0<O1
^Q40[Jf]4@38`K/00`2][Jd0b<6k0<S1^`0?0<S1^`<0@FWQ00<0b<6k0:f][@37`K`00P11JN460<O1
_003045Yh@37`K`0@FWQ00<0al6l0P11JN420<O1_0030:f][@36`;`0a/2l0080a/2l00<0@FWQ0<K0
_036`;`01@36`;`2045Yh@@0a/2l00<0[Jf]045Yh@33_K/00P33_K/30:f][@<0`kfk0P11JN430<>m
^`03045Yh@2][Jd0_[Vh0080_[Vh0P11JN480;ji^0030:f][@11JN40];2a00H0];2a0`2][Jd709nK
X0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00EP2`h>H01@2][Jd0Hf1C06=PD`1SH5<0
[Jf]00L0RXEe0`2][Jd01@2TWXl0@FWQ045Yh@2TWXl0@FWQ00@0Y9j?00<0[Jf]0;6[W@2aZid01`2a
Zid01P11JN40/J^M0;6[W@11JN40/J^M0:f][@<0^K:V0P11JN420;VbYP<0@FWQ00P0^K:V045Yh@2]
[Jd0[Jf]0;VbYP2][Jd0_[N/045Yh@P0_[N/00<0@FWQ0;jg[02n]j`0102n]j`00`11JN40[Jf]0<6j
/0090<6j/003045Yh@31^[00`KZ`00@0`KZ`0`11JN400`2][Jd0`kfc0<>m/`020<>m/`03045Yh@33
_K<0`kfc00<0@FWQ2`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng<02]
[Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/03@38`K/2045Yh@<0b<6k0P11
JN400`37`K`0@FWQ0<O1_0060<O1_0<0@FWQ0P37`K`3045Yh@80al6l00<0[Jf]0<K0_036`;`00P36
`;`00`11JN40a/2l0<K0_0050<K0_0@0@FWQ0P36`;`00`000000@FWQ0:f][@020:f][@H0`kfk0P11
JN430<>m^`04045Yh@2][Jd0_[Vh0;ji^080@FWQ2@2n^KP00`2][Jd0@FWQ0;B`/@050;B`/@040:f]
[@2d/;40];2a0:f][@L0Wi^P00D0[Jf]071^N@1`KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP05
0:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BNS`020:f][@030:BNS`11JN40Y9j?
00@0Y9j?00<0[Jf]0;6[W@2aZid0202aZid2045Yh@80/J^M00D0[Jf]0;VbYP2i/ZH0^K:V045Yh@03
0;VbYP<0@FWQ00@0^K:V045Yh@2i/ZH0^K:V0`2][Jd00`11JN40_[N/0;jg[0060;jg[003045Yh@2n
]j`0_[N/00@0_[N/00<0@FWQ0:f][@31^[002@31^[000`11JN40`KZ`0<6j/0040<6j/080@FWQ00<0
`KZ`0:f][@33_K<00`33_K<00`11JN40`kfc045Yh@020<>m/`80@FWQ1`33_K<3045Yh@030:f][@35
_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/6045Yh@X0b<6k0P11JN440<S1^`<0@FWQ1`37
`K`3045Yh@80al6l0`11JN420<O1_0040:f][@36`;`0a/2l0<K0_080@FWQ1@36`;`4045Yh@80a/2l
0`2][Jd2045Yh@<0`kfk00<0@FWQ0<>m^`33_K/00`33_K/01P11JN40`kfk0<>m^`11JN40`kfk0:f]
[@d0_[Vh00<0[Jf]045Yh@2d/;400`2d/;420:f][@<0];2a00<0[Jf]09nKX02OVj001@2OVj001@2]
[Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD0
0`2][Jd0Y9j?0:BNS`020:BNS`030:f][@2TWXl0Y9j?00@0Y9j?00<0[Jf]0;6[W@2aZid0302aZid0
1@2][Jd0^K:V045Yh@2i/ZH0@FWQ00<0^K:V0P11JN430;VbYP06045Yh@2i/ZH0^K:V0:f][@2n]j`0
@FWQ0`2][Jd30;jg[0<0@FWQ1P2n]j`00`11JN40[Jf]0<6j/0090<6j/003045Yh@31^[00`KZ`00D0
`KZ`00<0@FWQ0<6j/02][Jd01033_K<2045Yh@@0`kfc0P11JN480<>m/`D0@FWQ0P35_[D3045Yh@h0
aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0
al6j00<0[Jf]0<S1^`38`K/02038`K/5045Yh@L0b<6k00@0[Jf]0<S1^`11JN40@FWQ2`38`K/2045Y
h@D0b<6k00<0[Jf]045Yh@11JN401`37`K`3045Yh@80al6l0P11JN401037`K`0@FWQ0<O1_02][Jd3
0<K0_080@FWQ1P36`;`50:f][@80a/2l00<0[Jf]045Yh@11JN400`33_K/2045Yh@D0`kfk0P11JN42
0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]045Yh@2d/;40];2a0P2][Jd50;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0[Jf]@02`h>H10?ooo`00E`2`h>H0102][Jd0Hf1C06=P
D`2][Jd708Z5M@030:f][@2TWXl0Y9j?00<0Y9j?0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M
00<0[Jf]0;VbYP2i/ZH00P11JN430;VbYP80@FWQ0`2i/ZH01P11JN40^K:V0;VbYP2][Jd0_[N/045Y
h@<0_[N/102][Jd0102n]j`0@FWQ045Yh@11JN430;jg[080@FWQ00<0[Jf]0<6j/031^[002031^[00
0`11JN40`KZ`0<6j/0050<6j/003045Yh@31^[00[Jf]00@0`kfc00<0@FWQ0<>m/`33_K<01033_K<2
045Yh@L0`kfc0P11JN470<Fn]@@0@FWQ0P35_[D7045Yh@80aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/00`38`K/5
045Yh@@0b<6k0`11JN450<S1^`040:f][@38`K/0@FWQ045Yh@/0b<6k0P11JN450<S1^`030:f][@11
JN40@FWQ00L0al6l0`11JN420<O1_080@FWQ00@0al6l045Yh@37`K`0[Jf]0`36`;`2045Yh@80a/2l
102][Jd70<K0_0030:f][@11JN40@FWQ00<0`kfk0P11JN490<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
0P11JN400`2d/;40[Jf]0;B`/@060;B`/@030:f][@2OVj00Wi^P00D0Wi^P00@0[Jf]071^N@1`KWT0
[Jf]@02`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@0708Z5M@030:f][@2TWXl0Y9j?00D0Y9j?
0P2][Jd20:BNS`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH2045Yh@030;Vb
YP11JN40@FWQ00<0^K:V00H0@FWQ0;VbYP2i/ZH0[Jf]0;jg[011JN470;jg[0@0[Jf]0`2n]j`2045Y
h@030:f][@31^[00`KZ`00P0`KZ`00<0@FWQ0<6j/031^[001@31^[000`11JN40`KZ`0:f][@030<>m
/`80@FWQ1`33_K<2045Yh@H0`kfc0P11JN470<Fn]@80@FWQ1`35_[D2045Yh@@0aKje00<0[Jf]0<Jo
]`36_kL00P36_kL3045Yh@T0a[ng00<0@FWQ0<Jo]`36_kL00P11JN420<Jo]`030:f][@37`KP0al6h
01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k
00@0b<6k0P11JN450<S1^`040:f][@38`K/0@FWQ045Yh@/0b<6k0P11JN450<S1^`030:f][@11JN40
@FWQ00L0al6l00<0@FWQ0<O1_011JN400P37`K`2045Yh@040<O1_011JN40al6l0:f][@80a/2l00<0
[Jf]045Yh@11JN400P2][Jd;0<K0_0040:f][@11JN40`kfk045Yh@80`kfk00<0@FWQ0<>m^`33_K/0
2033_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]202d/;400`2][Jd0Wi^P09nKX00509nKX0030:f]
[@1`KWT0[Jf]0440/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2][Jd0Y9j?0:BN
S`070:BNS`<0[Jf]3@2aZid00`2][Jd0^K:V0;VbYP070;VbYP03045Yh@2i/ZH0@FWQ0080@FWQ0P2i
/ZH00`2][Jd0_[N/045Yh@0;0;jg[0<0[Jf]0P11JN400`2][Jd0`KZ`0<6j/0080<6j/080@FWQ1P31
^[000`11JN40`KZ`0:f][@030<>m/`80@FWQ1`33_K<2045Yh@H0`kfc0P11JN470<Fn]@80@FWQ1`35
_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36_kL00P11JN430<Jo]`80@FWQ1`36_kL00`11JN40a[ng045Y
h@020<Jo]`80@FWQ00<0[Jf]0<O1^037`KP01@37`KP00`11JN40al6h0<O1^00<0<O1^0030:f][@37
`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`050<S1^`80@FWQ1038
`K/0102][Jd0b<6k045Yh@11JN4;0<S1^`80@FWQ1@38`K/00`2][Jd0@FWQ045Yh@060<O1_080@FWQ
0P37`K`01P11JN40al6l045Yh@11JN40al6l045Yh@@0[Jf]00<0a/2l045Yh@11JN403@36`;`0102]
[Jd0@FWQ0<>m^`33_K/2045Yh@/0`kfk00<0[Jf]0;ji^02n^KP02P2n^KP20:f][@X0];2a00<0[Jf]
09nKX02OVj001@2OVj000`2][Jd0L6ii0:f][@110;3PiP40oooo001I0;3PiP80[Jf]1`2:QGD00`2]
[Jd0Y9j?0:BNS`090:BNS`80[Jf]302aZid00`2][Jd0^K:V0;VbYP0;0;VbYP<0@FWQ00<0[Jf]0;jg
[011JN403P2n]j`2045Yh@@0[Jf]2031^[000`11JN40`KZ`0<6j/0040<6j/003045Yh@31^[00[Jf]
00<0`kfc0P11JN470<>m/`80@FWQ1P33_K<2045Yh@L0aKje0P11JN470<Fn]@80@FWQ1035_[D0102]
[Jd0a[ng045Yh@11JN460<Jo]`03045Yh@36_kL0a[ng00@0a[ng0P11JN450<Jo]`80@FWQ1@37`KP0
0`11JN40al6h045Yh@0=0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/01P38`K/0
0`11JN40b<6k0<S1^`050<S1^`80@FWQ1038`K/0102][Jd0b<6k045Yh@11JN4;0<S1^`80@FWQ1@38
`K/00`2][Jd0@FWQ045Yh@060<O1_080@FWQ0P37`K`00`11JN40[Jf]045Yh@020:f][@030<O1_011
JN40[Jf]00<0a/2l0P11JN4=0<K0_0030:f][@11JN40`kfk00h0`kfk00<0[Jf]0;ji^02n^KP0202n
^KP20:f][@030;ji^02][Jd0];2a00T0];2a00<0[Jf]09nKX02OVj001@2OVj020:f][D80/>3V0@3o
ool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2][Jd00P2][Jd9
0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[011JN403P2n]j`3045Yh@<0`KZ`1`2][Jd2
0<6j/080@FWQ0`31^[02045Yh@030<6j/02][Jd0`kfc0080`kfc0P11JN470<>m/`80@FWQ1P33_K<2
045Yh@L0aKje0P11JN470<Fn]@80@FWQ1035_[D00`2][Jd0@FWQ045Yh@080<Jo]`03045Yh@36_kL0
a[ng00<0a[ng00<0@FWQ0<Jo]`36_kL01036_kL00`2][Jd0al6h045Yh@050<O1^003045Yh@37`KP0
al6h00`0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0
b<6k00H0b<6k0P11JN430<S1^`040:f][@38`K/0@FWQ045Yh@`0b<6k0P11JN440<S1^`030:f][@11
JN40@FWQ00D0al6l00<0[Jf]045Yh@11JN400P2][Jd00`11JN40al6l045Yh@030<O1_003045Yh@2]
[Jd0a/2l0080a/2l0P11JN4<0<K0_080@FWQ4033_K/00`2][Jd0_[Vh0;ji^0060;ji^080[Jf]0`2n
^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0Wi^P0P2][Je20;3PiP40oooo001J
0;3PiP030:f][@2:QGD0RXEe00D0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@02
0;6[W@80[Jf]1`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0@FWQ00h0_[N/0`11JN4:
0<6j/0@0[Jf]0P11JN401@2][Jd0@FWQ045Yh@31^[00[Jf]00<0`kfc0P11JN470<>m/`80@FWQ1P33
_K<2045Yh@L0aKje0P11JN470<Fn]@80@FWQ1035_[D00`2][Jd0@FWQ045Yh@0>0<Jo]`03045Yh@36
_kL0a[ng00@0a[ng00<0[Jf]0<O1^011JN405@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k00H0b<6k00<0@FWQ0<S1^`38`K/01P38`K/2045Yh@<0b<6k00@0[Jf]0<S1^`11JN40@FWQ
3@38`K/4045Yh@040<S1^`2][Jd0al6l045Yh@D0[Jf]00<0al6l045Yh@11JN400P37`K`3045Yh@<0
al6l00<0@FWQ0:f][@36`;`00P36`;`2045Yh@d0a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0
_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P00@0
Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5M@0408Z5M@030:f]
[@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH0102][Jd0_[N/045Yh@11JN4=0;jg[0<0@FWQ1031^[000`11JN40`KZ`0<6j/0090<6j/0<0
@FWQ1@2][Jd2045Yh@L0`kfc0P11JN460<>m/`80@FWQ1`35_[D2045Yh@L0aKje0P11JN440<Fn]@80
@FWQ3`36_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@37`KP0@FWQ01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k00H0b<6k0P11JN430<S1^`04
0:f][@38`K/0@FWQ045Yh@l0b<6k0P2][Jd4045Yh@H0al6l0P11JN420<O1_0<0@FWQ0`37`K`00`11
JN40[Jf]0<K0_0020<K0_080@FWQ2036`;`00`11JN40a/2l0<K0_0030<K0_0030:f][@33_K/0`kfk
00d0`kfk00@0[Jf]0;ji^02n^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]
09nKX02OVj000`2OVj000`2][Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe
00<0RXEe00<0[Jf]0:BNS`2TWXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f]
[@2i/ZH03`2i/ZH0102][Jd0_[N/045Yh@11JN4;0;jg[0@0@FWQ00@0[Jf]045Yh@31^[00`KZ`0P11
JN450<6j/080@FWQ1@31^[02045Yh@030000002][Jd0`kfc0080`kfc0P11JN450:f][@80`kfc0P11
JN460<>m/`80@FWQ1`35_[D2045Yh@L0aKje0P11JN440<Fn]@80@FWQ5P36_kL00`2][Jd0@FWQ045Y
h@0E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1
^`070<S1^`80@FWQ0P38`K/0102][Jd0b<6k045Yh@11JN480<S1^`L0[Jf]0`38`K/00`2][Jd0al6l
045Yh@060<O1_003045Yh@37`K`0al6l0080al6l0P11JN440<O1_0040:f][@36`;`0a/2l0<K0_080
@FWQ2036`;`00`11JN40a/2l0<K0_0030<K0_0030:f][@33_K/0`kfk00d0`kfk00@0[Jf]0;ji^02]
[Jd0[Jf]2P2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f][@2OVj00Wi^P0080Wi^P00<0[Jf]0;3P
iP2`h>H0@`2`h>H10?ooo`00G@2`h>H00`2][Jd0RXEe08Z5M@0208Z5M@030:f][@2TWXl0Y9j?00T0
Y9j?00<0[Jf]0;6[W@2aZid02P2aZid30:f][@l0^K:V00@0[Jf]0;jg[011JN40@FWQ1`2n]j`00`11
JN40_[N/0;jg[0030;jg[080@FWQ00<0[Jf]0<6j/011JN400P31^[000`11JN40`KZ`0<6j/0030<6j
/080@FWQ1@31^[001011JN40`KZ`0<6j/02][Jd30<>m/`80@FWQ1@33_K<20:f][@80@FWQ102][Jd2
0<>m/`80@FWQ1`35_[D2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D00`35_[D2045YhAD0a[ng0`11JN4F
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/01P38`K/00`11JN40b<6k0<S1^`07
0<S1^`80@FWQ0P38`K/0102][Jd0b<6k045Yh@11JN480:f][@X0b<6k00<0[Jf]0<O1_011JN401@37
`K`2045Yh@@0al6l0P11JN400`37`K`0@FWQ045Yh@04045Yh@80a/2l0P11JN470<K0_003045Yh@36
`;`0a/2l00<0a/2l00<0[Jf]0<>m^`33_K/03033_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d
/;400`2][Jd0Wi^P09nKX0020:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0
Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00@0[Jf]
0;jg[02n]j`0@FWQ1`2n]j`00`11JN40_[N/0;jg[0050;jg[0030:f][@31^[00`KZ`00<0@FWQ1P31
^[000`11JN40`KZ`0<6j/0030<6j/004045Yh@31^[00`KZ`0:f][@<0`kfc0P11JN470<>m/`03045Y
h@33_K<0`kfc00<0`kfc0P2][Jd2045Yh@D0[Jf]0P35_[D2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D0
0`35_[D2045YhA<0a[ng1011JN470<O1^003045Yh@37`KP0al6h00d0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`060<S1^`03045Yh@38`K/0b<6k00H0b<6k00<0[Jf]045Yh@11JN40
102][Jd3045Yh@/0b<6k0P11JN440<S1^`030:f][@37`K`0@FWQ00D0al6l0P11JN440<O1_080@FWQ
1037`K`00`2][Jd0a/2l0<K0_0020<K0_080@FWQ1`36`;`00`11JN40a/2l0<K0_0030<K0_0030:f]
[@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40];2a00T0];2a
00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BNS`030:f][@2a
Zid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg[02n]j`00P11
JN450;jg[080@FWQ1`2n]j`00`2][Jd0`KZ`0<6j/0090<6j/003045Yh@31^[00`KZ`00<0`KZ`00@0
@FWQ0<6j/031^[00[Jf]0`33_K<2045Yh@L0`kfc00<0@FWQ0<>m/`33_K<01@33_K<2045Yh@D0aKje
0P2][Jd2045Yh@L0[Jf]00<0@FWQ0<Fn]@35_[D00`35_[D2045YhA40a[ng0P11JN401036_kL0@FWQ
0<Jo]`2][Jd70<O1^003045Yh@37`KP0al6h00d0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`030<S1^`<0[Jf]00<0@FWQ0:f][@2][Jd01P2][Jd00`38`K/0@FWQ045Yh@020<S1^`03
0:f][@38`K/0@FWQ0080@FWQ1038`K/00`11JN40b<6k0<S1^`040<S1^`80@FWQ1038`K/00`2][Jd0
@FWQ0<O1_0030<O1_0H0@FWQ2@37`K`0102][Jd0a/2l0<K0_036`;`2045Yh@H0a/2l0P11JN450<K0
_0030:f][@33_K/0`kfk00H0`kfk0`2][Jd40<>m^`030:f][@2n^KP0_[Vh00/0_[Vh00<0[Jf]0;B`
/@2d/;402@2d/;420:f][DT0/>3V0@3oool00640/>3V0P2][Jd:0:BNS`030:f][@2aZid0/J^M00`0
/J^M00<0[Jf]0;VbYP2i/ZH01P2i/ZH30:f][@D0^K:V00D0[Jf]0;jg[02n]j`0_[N/045Yh@050;jg
[080@FWQ1`2n]j`00`2][Jd0`KZ`0<6j/00:0<6j/0D0@FWQ0`31^[00102][Jd0`kfc0<>m/`33_K<3
045Yh@D0`kfc00<0@FWQ0<>m/`33_K<01P33_K<2045Yh@L0aKje0P11JN470<Fn]@03045Yh@2][Jd0
[Jf]00<0[Jf]0P11JN480:f][@03045Yh@2][Jd0a[ng00@0a[ng0P11JN400`36_kL0@FWQ045Yh@02
0<Jo]`030:f][@37`KP0al6h00D0al6h00<0@FWQ0<O1^037`KP03@37`KP00`2][Jd0al6j0<O1^P09
0<O1^Q40[Jf]0`38`K/00`11JN40b<6k0<S1^`070<S1^`80@FWQ0P38`K/01P2][Jd0b<6k045Yh@11
JN40b<6k045Yh@<0b<6k0P11JN460<S1^`03045Yh@38`K/0b<6k0080b<6k00<0@FWQ0<O1_037`K`0
4P37`K`00`2][Jd0a/2l0<K0_0020<K0_003045Yh@36`;`0a/2l00@0a/2l0P11JN450<K0_0030:f]
[@33_K/0`kfk0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;40
202d/;400`2][Jd0/>3V0;3PiP180;3PiP40oooo001R0;3PiP030:f][@2TWXl0Y9j?00P0Y9j?00<0
[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP090;VbYP@0[Jf]00<0^K:V0:f][@2n]j`00P2n
]j`2045Yh@<0_[N/0`11JN470;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`11JN401011
JN440<>m/`80@FWQ2033_K<3045Yh@H0aKje0P11JN470<Fn]@03045Yh@35_[D0aKje00<0aKje00<0
[Jf]045Yh@11JN401P36_kL00`11JN40a[ng045Yh@050:f][@03045Yh@2][Jd0@FWQ00`0[Jf]00<0
@FWQ0:f][@2][Jd06@2][Jd;0<O1^P030:f][@38`K/0b<6k00H0b<6k00<0@FWQ0<S1^`38`K/01`38
`K/2045Yh@80b<6k00H0[Jf]0<S1^`11JN40@FWQ0<S1^`11JN430<S1^`80@FWQ1`38`K/4045Yh@03
0:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`00P36`;`2045Yh@@0a/2l00<0@FWQ0<K0_011
JN401@36`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0
];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?00<0[Jf]0;6[W@2aZid0
302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]0`2n]j`2045Yh@80_[N/0`11JN470;jg[0030:f]
[@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc0P11JN400`33_K<0@FWQ045Yh@02045Yh@X0
`kfc0`11JN450<Fn]@80@FWQ2035_[D00`11JN40aKje0<Fn]@030<Fn]@030:f][@11JN40@FWQ00L0
a[ng0P11JN450<Jo]`80@FWQ1@36_kL00`2][Jd0al6h045Yh@050<O1^003045Yh@37`KP0al6h00d0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`060<S1^`80@FWQ2038`K/2045Yh@80
b<6k00@0[Jf]0<S1^`11JN40@FWQ0P38`K/01011JN40b<6k0<S1^`11JN4<0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`00`36`;`2045Yh@80a/2l00@0@FWQ0<K0_036`;`0@FWQ0`36
`;`40:f][@h0`kfk00<0[Jf]0;ji^02n^KP0302n^KP00`2][Jd0];2a0;B`/@050;B`/@030:f][@2`
h>H0/>3V04/0/>3V0@3oool006D0/>3V0P2][Jd60:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]
0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0:f][@030:f][@030;jg[011JN40@FWQ0080_[N/00<0@FWQ
0;jg[02n]j`01@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0180`kfc0P11JN40
0`35_[D0@FWQ0<Fn]@030<Fn]@80@FWQ2035_[D00`11JN40aKje0<Fn]@030<Fn]@030:f][@36_kL0
@FWQ00P0a[ng00<0@FWQ0<Jo]`36_kL00`36_kL00`11JN40a[ng0<Jo]`040<Jo]`030:f][@11JN40
@FWQ00D0al6h00<0@FWQ0<O1^037`KP03@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0
b<6k00H0b<6k0P11JN480<S1^`80@FWQ0P38`K/4045Yh@<0b<6k0P11JN4=0<S1^`030:f][@37`K`0
al6l0180al6l00<0[Jf]0<K0_036`;`01036`;`4045Yh@030<K0_02][Jd0[Jf]00<0[Jf]0P36`;`0
0`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;400`2d/;42
0:f][Dh0/>3V0@3oool006L0/>3V0P2][Jd40:BNS`030:f][@2aZid0/J^M00`0/J^M00<0[Jf]0;Vb
YP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0030;jg[0@0[Jf]00<0_[N/045Yh@2n]j`01P2n]j`00`2]
[Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0180`kfc0P11JN420<Fn]@@0@FWQ2P35_[D00`11
JN40aKje0<Fn]@030<Fn]@040:f][@36_kL0a[ng045Yh@H0a[ng00<0@FWQ0<Jo]`36_kL01036_kL0
0`11JN40a[ng0<Jo]`040<Jo]`030:f][@11JN40@FWQ00D0al6h00<0@FWQ0<O1^037`KP03@37`KP0
0`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00H0b<6k0P11JN480<S1^`05045Yh@38`K/0
b<6k0<S1^`2][Jd05@38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00D0a/2l102]
[Jd70<K0_0030:f][@33_K/0`kfk00d0`kfk00<0[Jf]0;ji^02n^KP0302n^KP0102][Jd0];2a0;B`
/@2d/;420:f][E00/>3V0@3oool006T0/>3V0P2][Jd20:BNS`030:f][@2aZid0/J^M00`0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0070;jg[0@0[Jf]1@2n]j`00`2][Jd0`KZ`0<6j
/00B0<6j/0030:f][@33_K<0`kfc0180`kfc0P11JN4=0<Fn]@@0@FWQ1@35_[D01@2][Jd0a[ng0<Jo
]`36_kL0@FWQ00@0a[ng00<0@FWQ0<Jo]`36_kL01@36_kL00`11JN40a[ng0<Jo]`040<Jo]`<0@FWQ
1037`KP2045Yh@l0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`060<S1^`80@FWQ
1`38`K/2045Yh@<0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l00D0[Jf]2`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh
00@0[Jf]0;B`/@2d/;40[Jf]DP2`h>H10?ooo`00J`2`h>H30:f][@h0/J^M00<0[Jf]0;VbYP2i/ZH0
3P2i/ZH00`2][Jd0_[N/0;jg[00;0;jg[0@0[Jf]00<0_[N/0:f][@31^[004`31^[000`2][Jd0`kfc
0<>m/`0B0<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo]`020<Jo]`@0@FWQ2@36_kL6045Yh@030:f]
[@37`KP0@FWQ00@0al6h0`11JN4>0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/0
1P38`K/2045Yh@L0b<6k0P11JN430<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`0
4037`K`50:f][A00a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00;0;ji^0<0[Jf]
D`2`h>H10?ooo`00K@2`h>H20:f][@d0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg
[00?0;jg[0D0[Jf]4@31^[000`2][Jd0`kfc0<>m/`0B0<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00@0al6h0`11JN4>0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/01P38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00/0al6l1@2][Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H2
0:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00
`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m/`0B0<>m/`80@FWQ5P35_[D00`2][Jd0a[ng0<Jo
]`0E0<Jo]`030:f][@37`KP0al6h00@0al6h0`11JN4>0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/01P38`K/2045Yh@L0b<6k00<0@FWQ0<S1^`38`K/00P38`K/00`2][Jd0b<6k0<S1
^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0
[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H3
0:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00
`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33_K<0`kfc0180`kfc0P11JN4F0<Fn]@030:f][@36_kL0
a[ng01D0a[ng00<0[Jf]0<O1^037`KP01037`KP3045Yh@h0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`060<S1^`80@FWQ1P38`K/2045Yh@@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/0
0`2][Jd0al6l0<O1_0050:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>
0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][JeJ0;3PiP40oooo001d0;3PiP80[Jf]1P2aZid00`2]
[Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[003`31^[070:f]
[A40`kfc0P11JN4F0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01037`KP3045Y
h@h0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`060<S1^`80@FWQ1P38`K/00`11
JN40b<6k0<S1^`030<S1^`030:f][@38`K/0b<6k0100b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l
0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?oo
o`00MP2`h>H30:f][@<0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00@0[Jf]0<>m/`33_K<0`kfc1`2][Jd80<>m/`@0@FWQ4035_[D00`11
JN40aKje0<Fn]@030<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01037`KP3045Y
h@h0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`060<S1^`80@FWQ1@38`K/2045Y
h@D0b<6k00<0[Jf]0<S1^`38`K/02@38`K/70:f][@<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02][Jd00P2][JeO0;3P
iP40oooo001i0;3PiP80[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[003
0:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<02033_K<80:f][@80`kfc0P11JN4?0<Fn]@80
@FWQ1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h00@0al6h0`11JN4>0<O1^003
0:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/01P38`K/7045Yh@L0b<6k00@0[Jf]0<S1^`38
`K/0b<6k202][Jd:0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2]
[Jd0`kfk0<>m^`0=0<>m^`<0[Jf]HP2`h>H10?ooo`00N`2`h>H30:f][@l0^K:V00<0[Jf]0;jg[02n
]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc0100`kfc2@2][Jd;0<Fn]@03
045Yh@35_[D0aKje00<0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^0040<O1^080
@FWQ3`37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k00<0b<6k1@11JN470<S1^`T0
[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33
_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00<0aKje
302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP01@37`KP00`11JN40al6h
0<O1^00=0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k
00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l
00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n
]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35
_[D0aKje00l0aKje4@2][Jd<0<Jo]`030:f][@37`KP0al6h00X0al6h:02][JdA0<S1^`030:f][@38
`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33
_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo00250;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@
0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D
0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]
0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]
0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@030:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i
/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2]
[Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2]
[Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2]
[Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0
[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35
_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37
`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037
`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/
00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje
00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l
00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V0@3oool009D0/>3V102][Jd70;jg[0030:f][@31
^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36
_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38
`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36
`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B
0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E
0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D
0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@03
0:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn
]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1
^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1
_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0
`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0
al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0
b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f]
[@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f]
[@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f]
[@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]
4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP0
5@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/0
4038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2][Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0
[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0
[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H8
0:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0
al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0
b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H90:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL0
0`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?
0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1
^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .45893 
%%ImageSize: 500 229.465 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
-3.54534e-017 1.04539 -0.250736 1.04539 [
[ 0 0 0 0 ]
[ 1 .45893 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .45893 L
0 .45893 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.776 .75 .716 r
.45459 .32808 m .50171 .32994 L .50179 .30087 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50179 .30087 m .45483 .29894 L .45459 .32808 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54908 .30075 m .50179 .30087 L .50171 .32994 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50171 .32994 m .54917 .32982 L .54908 .30075 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59595 .29858 m .54908 .30075 L .54917 .32982 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.52582 .3309 m
.49908 .33066 L
s
.5 Mabswid
.771 .745 .709 r
.40855 .32425 m .45459 .32808 L .45483 .29894 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45483 .29894 m .40896 .29496 L .40855 .32425 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.54917 .32982 m .59621 .32773 L .59595 .29858 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64164 .29437 m .59595 .29858 L .59621 .32773 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.45434 .35743 m .50164 .35921 L .50171 .32994 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49908 .33147 m
.49908 .33066 L
s
.5 Mabswid
.776 .75 .716 r
.50171 .32994 m .45459 .32808 L .45434 .35743 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54917 .32982 m .50171 .32994 L .50164 .35921 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50164 .35921 m .54927 .3591 L .54917 .32982 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59621 .32773 m .54917 .32982 L .54927 .3591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52496 .33862 m
.52662 .34312 L
s
.52496 .33862 m
.52496 .34763 L
s
.52827 .34086 m
.53158 .33858 L
s
.53158 .33858 m
.5382 .33851 L
s
.5382 .33851 m
.54152 .34072 L
s
.50509 .33848 m
.51006 .3408 L
s
.50179 .33843 m
.50509 .33848 L
s
.49847 .34062 m
.50179 .33843 L
s
.49682 .34058 m
.50179 .33843 L
s
.52662 .34312 m
.52827 .34086 L
s
.51006 .3408 m
.51336 .34534 L
s
.54152 .34072 m
.54318 .34294 L
s
.52496 .34763 m
.52662 .34312 L
s
.49515 .34505 m
.49847 .34062 L
s
.4935 .34501 m
.49682 .34058 L
s
.55638 .33812 m
.55804 .34033 L
s
.55474 .34042 m
.55638 .33812 L
s
.54318 .34294 m
.54319 .34971 L
s
.47377 .33757 m
.48528 .33801 L
s
.55474 .34042 m
.5564 .34263 L
s
.5564 .34263 m
.55804 .34033 L
s
.5 Mabswid
.771 .745 .709 r
.40814 .35376 m .45434 .35743 L .45459 .32808 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45459 .32808 m .40855 .32425 L .40814 .35376 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49348 .35179 m
.49515 .34505 L
s
.54154 .34974 m
.54319 .34746 L
s
.49182 .35175 m
.4935 .34501 L
s
.53823 .35205 m
.54154 .34974 L
s
.54154 .352 m
.54319 .34971 L
s
.5 Mabswid
.781 .756 .727 r
.54927 .3591 m .59648 .3571 L .59621 .32773 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64207 .32368 m .59621 .32773 L .59648 .3571 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59621 .32773 m .64207 .32368 L .64164 .29437 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52994 .35665 m
.53823 .35205 L
s
0 0 0 r
.51911 .36632 m
.50904 .36625 L
s
.255 .412 .882 r
.53823 .35431 m
.54154 .352 L
s
.45577 .33665 m
.46721 .33727 L
s
.5 Mabswid
.776 .75 .716 r
.45409 .38699 m .50156 .3887 L .50164 .35921 L p F P
.678 .678 .678 r
s
.776 .75 .716 r
.50164 .35921 m .45434 .35743 L .45409 .38699 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.48017 .36952 m
.48034 .33784 L
s
.47852 .36946 m
.47869 .33777 L
s
.5 Mabswid
.779 .754 .722 r
.54927 .3591 m .50164 .35921 L .50156 .3887 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52995 .35891 m
.53823 .35431 L
s
.49346 .35631 m
.49348 .35179 L
s
.5 Mabswid
.779 .754 .722 r
.50156 .3887 m .54937 .38859 L .54927 .3591 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59648 .3571 m .54927 .3591 L .54937 .38859 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52663 .35893 m
.52994 .35665 L
s
.49181 .35627 m
.49182 .35175 L
s
.46211 .36192 m
.4623 .33702 L
s
.52497 .3612 m
.52663 .35893 L
s
.52663 .36119 m
.52995 .35891 L
s
.46047 .36184 m
.46066 .33693 L
s
.51169 .35888 m
.51334 .36116 L
s
.51002 .36113 m
.51169 .35888 L
s
.52497 .3612 m
.52497 .36573 L
s
.49346 .35631 m
.49509 .36315 L
s
.52497 .36346 m
.52663 .36119 L
s
.51334 .36343 m
.51334 .36116 L
s
.49181 .35627 m
.49344 .36311 L
s
.51002 .36113 m
.51168 .36341 L
s
.54157 .36558 m
.54322 .36102 L
s
.54322 .36102 m
.54325 .37009 L
s
.51001 .36793 m
.51334 .36343 L
s
.5 Mabswid
.765 .739 .7 r
.36438 .3185 m .40855 .32425 L .40896 .29496 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40896 .29496 m .36495 .28898 L .36438 .3185 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.52497 .36573 m
.52663 .36799 L
s
.49509 .36315 m
.49839 .36775 L
s
.53992 .36788 m
.54157 .36558 L
s
.54157 .36558 m
.54325 .37009 L
s
.43794 .33545 m
.44926 .33625 L
s
.49344 .36311 m
.49674 .36772 L
s
.52663 .36799 m
.52996 .37025 L
s
.50669 .37016 m
.51001 .36793 L
s
.5366 .37019 m
.53992 .36788 L
s
.52996 .37025 m
.5366 .37019 L
s
.49839 .36775 m
.50171 .37009 L
s
.49674 .36772 m
.50171 .37009 L
s
.50171 .37009 m
.50669 .37016 L
s
.5 Mabswid
.782 .757 .734 r
.68538 .28816 m .64164 .29437 L .64207 .32368 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.40772 .38347 m .45409 .38699 L .45434 .35743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.4498 .35996 m
.45032 .35711 L
s
.5 Mabswid
.771 .745 .709 r
.45434 .35743 m .40814 .35376 L .40772 .38347 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.47357 .36927 m
.48017 .36952 L
s
.5 Mabswid
.781 .756 .727 r
.54937 .38859 m .59675 .38667 L .59648 .3571 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5565 .36752 m
.55656 .38116 L
s
.5549 .38121 m
.55644 .35393 L
s
.55644 .35393 m
.55821 .38112 L
s
.5 Mabswid
.783 .757 .731 r
.64251 .35321 m .59648 .3571 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59648 .3571 m .64251 .35321 L .64207 .32368 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.46044 .36638 m
.46211 .36192 L
s
.4588 .36629 m
.46047 .36184 L
s
.5 Mabswid
.776 .75 .716 r
.45384 .41676 m .50149 .4184 L .50156 .3887 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.49891 .39026 m
.49892 .3886 L
s
.49974 .38863 m
.49983 .38972 L
s
.5 Mabswid
.776 .75 .716 r
.50156 .3887 m .45409 .38699 L .45384 .41676 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.54937 .38859 m .50156 .3887 L .50149 .4184 L p F P
.678 .678 .678 r
s
.779 .754 .722 r
.50149 .4184 m .54946 .4183 L .54937 .38859 L p F P
.678 .678 .678 r
s
.781 .756 .727 r
.59675 .38667 m .54937 .38859 L .54946 .4183 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.5549 .38121 m
.55657 .38572 L
s
.40315 .31631 m
.41416 .31749 L
s
0 0 0 r
.40732 .32493 m
.40853 .32589 L
s
.255 .412 .882 r
.55657 .38572 m
.55821 .38112 L
s
.45551 .36839 m
.46044 .36638 L
s
0 0 0 r
.40732 .32493 m
.40852 .3263 L
s
.255 .412 .882 r
.45551 .36839 m
.4588 .36629 L
s
0 0 0 r
.40732 .32493 m
.40414 .32459 L
s
.255 .412 .882 r
.47846 .38084 m
.4801 .38317 L
s
.4768 .38305 m
.47846 .38084 L
s
.40876 .36476 m
.40943 .317 L
s
.47844 .38539 m
.4801 .38317 L
s
.41871 .3338 m
.42346 .33651 L
s
.42346 .33651 m
.42661 .34133 L
s
.45224 .3682 m
.45551 .36839 L
s
.5 Mabswid
.765 .739 .7 r
.3638 .34823 m .40814 .35376 L .40855 .32425 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40855 .32425 m .36438 .3185 L .3638 .34823 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.4768 .38305 m
.47844 .38539 L
s
.42661 .34133 m
.42813 .34827 L
s
.41871 .3338 m
.42187 .33637 L
s
.42187 .33637 m
.42501 .34119 L
s
.44416 .36086 m
.44737 .36562 L
s
.44737 .36562 m
.45224 .3682 L
s
.42501 .34119 m
.42653 .34814 L
s
.41554 .3335 m
.41871 .3338 L
s
.42808 .35282 m
.42813 .34827 L
s
.41234 .33545 m
.41554 .3335 L
s
.5 Mabswid
.782 .757 .734 r
.68598 .31771 m .64207 .32368 L .64251 .35321 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64207 .32368 m .68598 .31771 L .68538 .28816 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42647 .35269 m
.42653 .34814 L
s
.42639 .35952 m
.42808 .35282 L
s
.42479 .35938 m
.42647 .35269 L
s
.40911 .33967 m
.41234 .33545 L
s
.5 Mabswid
.771 .745 .709 r
.4073 .41341 m .45384 .41676 L .45409 .38699 L p F P
.678 .678 .678 r
s
.771 .745 .709 r
.45409 .38699 m .40772 .38347 L .4073 .41341 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.44231 .38356 m
.44278 .3358 L
s
.44394 .38366 m
.4444 .33592 L
s
.5 Mabswid
.781 .756 .727 r
.54946 .4183 m .59702 .41646 L .59675 .38667 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.64295 .38295 m .59675 .38667 L .59702 .41646 L p F P
.678 .678 .678 r
s
.783 .757 .731 r
.59675 .38667 m .64295 .38295 L .64251 .35321 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.42313 .3638 m
.42639 .35952 L
s
.42153 .36367 m
.42479 .35938 L
s
.43744 .38322 m
.44394 .38366 L
s
.39822 .33165 m
.39979 .33183 L
s
.4183 .36566 m
.42313 .3638 L
s
.4183 .36566 m
.42153 .36367 L
s
.39507 .33355 m
.39822 .33165 L
s
.39663 .33374 m
.39822 .33165 L
s
.5 Mabswid
.765 .739 .7 r
.36321 .37818 m .40772 .38347 L .40814 .35376 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40814 .35376 m .3638 .34823 L .36321 .37818 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40718 .3646 m
.40786 .31683 L
s
.395 .33811 m
.39663 .33374 L
s
.41511 .36537 m
.4183 .36566 L
s
.39345 .33792 m
.39507 .33355 L
s
.5 Mabswid
.782 .757 .734 r
.68658 .34747 m .64251 .35321 L .64295 .38295 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64251 .35321 m .68658 .34747 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64519 .33187 m
.6607 .32998 L
s
.41197 .36278 m
.41511 .36537 L
s
.5 Mabswid
.756 .73 .688 r
.32286 .31085 m .36438 .3185 L .36495 .28898 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36495 .28898 m .3236 .28104 L .32286 .31085 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.40886 .3579 m
.41197 .36278 L
s
.39475 .35409 m
.395 .33811 L
s
.39042 .33299 m
.39345 .33792 L
s
.39312 .35849 m
.39345 .33792 L
s
.38736 .33032 m
.39042 .33299 L
s
.38275 .32972 m
.38736 .33032 L
s
.40245 .36411 m
.40876 .36476 L
s
.5 Mabswid
.783 .757 .731 r
.59702 .41646 m .64339 .41291 L .64295 .38295 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.72638 .27999 m .68538 .28816 L .68598 .31771 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.6607 .32998 m
.66381 .33185 L
s
.6607 .32998 m
.66534 .33164 L
s
0 0 0 r
.36227 .31902 m
.36436 .31934 L
s
.255 .412 .882 r
.37965 .33159 m
.38275 .32972 L
s
.37812 .33138 m
.38275 .32972 L
s
.39312 .35849 m
.39475 .35409 L
s
.66381 .33185 m
.66695 .336 L
s
.39167 .35144 m
.39319 .35391 L
s
.38244 .348 m
.39167 .35144 L
s
.66534 .33164 m
.66847 .33579 L
s
.5 Mabswid
.765 .739 .7 r
.36262 .40835 m .4073 .41341 L .40772 .38347 L p F P
.678 .678 .678 r
s
.765 .739 .7 r
.40772 .38347 m .36321 .37818 L .36262 .40835 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37804 .33595 m
.37965 .33159 L
s
.37652 .33574 m
.37812 .33138 L
s
.39153 .3606 m
.39312 .35849 L
s
.5 Mabswid
.782 .757 .734 r
.68718 .37745 m .64295 .38295 L .64339 .41291 L p F P
.678 .678 .678 r
s
.782 .757 .734 r
.64295 .38295 m .68718 .37745 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64987 .33133 m
.65062 .37938 L
s
.65142 .33114 m
.65219 .3792 L
s
.66695 .336 m
.66855 .34037 L
s
.37796 .34052 m
.37804 .33595 L
s
.38838 .36252 m
.39153 .3606 L
s
.66847 .33579 m
.67008 .34016 L
s
.5 Mabswid
.756 .73 .688 r
.32212 .34089 m .3638 .34823 L .36438 .3185 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36438 .3185 m .32286 .31085 L .32212 .34089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37643 .34031 m
.37652 .33574 L
s
.37941 .3453 m
.38244 .348 L
s
.37788 .3451 m
.38244 .348 L
s
.37796 .34052 m
.37941 .3453 L
s
.66855 .34037 m
.6702 .34703 L
s
.37643 .34031 m
.37788 .3451 L
s
.3822 .36176 m
.38838 .36252 L
s
.67008 .34016 m
.67172 .34682 L
s
.5 Mabswid
.78 .756 .736 r
.72713 .30985 m .68598 .31771 L .68658 .34747 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.67743 .32762 m
.68788 .32598 L
s
.5 Mabswid
.78 .756 .736 r
.68598 .31771 m .72713 .30985 L .72638 .27999 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.37771 .35427 m
.37925 .35447 L
s
.3792 .35677 m
.37925 .35447 L
s
.6702 .34703 m
.67041 .35851 L
s
.37916 .35907 m
.3822 .36176 L
s
.37767 .35657 m
.37771 .35427 L
s
.67172 .34682 m
.67193 .3583 L
s
.68193 .32693 m
.68256 .35909 L
s
.37767 .35657 m
.37916 .35907 L
s
.68342 .3267 m
.68406 .35887 L
s
.66901 .36562 m
.67041 .35851 L
s
.5 Mabswid
.782 .757 .734 r
.64339 .41291 m .68779 .40766 L .68718 .37745 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.64591 .37989 m
.66152 .37811 L
s
.67054 .36541 m
.67193 .3583 L
s
.66152 .37811 m
.66456 .37543 L
s
.66152 .37811 m
.6661 .37523 L
s
.34684 .32416 m
.35712 .32592 L
s
.66756 .37042 m
.66901 .36562 L
s
.5 Mabswid
.756 .73 .688 r
.32138 .37115 m .36321 .37818 L .3638 .34823 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.3638 .34823 m .32212 .34089 L .32138 .37115 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66456 .37543 m
.66756 .37042 L
s
.66909 .37022 m
.67054 .36541 L
s
.6661 .37523 m
.66909 .37022 L
s
.35202 .35742 m
.35269 .32518 L
s
.68379 .34505 m
.68542 .35173 L
s
.5 Mabswid
.78 .756 .736 r
.72789 .33993 m .68658 .34747 L .68718 .37745 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68658 .34747 m .72789 .33993 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.36407 .35235 m
.36553 .35487 L
s
.36548 .35717 m
.36553 .35487 L
s
.36252 .35442 m
.36407 .35235 L
s
.67804 .35975 m
.68406 .35887 L
s
.35054 .35718 m
.35122 .32493 L
s
.36393 .35926 m
.36548 .35717 L
s
.36252 .35442 m
.36398 .35695 L
s
.35944 .35858 m
.36393 .35926 L
s
.68542 .35173 m
.68849 .35588 L
s
.35651 .35581 m
.35944 .35858 L
s
.35231 .34357 m
.35364 .35073 L
s
.68849 .35588 m
.69151 .35772 L
s
.35364 .35073 m
.35651 .35581 L
s
.5 Mabswid
.756 .73 .688 r
.32062 .40164 m .36262 .40835 L .36321 .37818 L p F P
.678 .678 .678 r
s
.756 .73 .688 r
.36321 .37818 m .32138 .37115 L .32062 .40164 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.28483 .3014 m .32286 .31085 L .3236 .28104 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.3236 .28104 m .28572 .27121 L .28483 .3014 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69436 .35262 m
.69578 .35006 L
s
.5 Mabswid
.78 .756 .736 r
.72866 .37023 m .68718 .37745 L .68779 .40766 L p F P
.678 .678 .678 r
s
.78 .756 .736 r
.68718 .37745 m .72866 .37023 L .72789 .33993 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.69578 .35006 m
.6973 .35213 L
s
.69436 .35262 m
.69588 .35469 L
s
.69151 .35772 m
.69593 .357 L
s
.33775 .34102 m
.33817 .32257 L
s
.34614 .35644 m
.35202 .35742 L
s
.5 Mabswid
.775 .751 .735 r
.7638 .26995 m .72638 .27999 L .72713 .30985 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33632 .34076 m
.33674 .32229 L
s
.6973 .35213 m
.69735 .35444 L
s
.70832 .32467 m
.71254 .32153 L
s
.70699 .32955 m
.70832 .32467 L
s
.70699 .32955 m
.7071 .33416 L
s
.69593 .357 m
.69735 .35444 L
s
.70975 .32439 m
.71254 .32153 L
s
.70843 .32928 m
.70975 .32439 L
s
.33204 .33994 m
.34208 .34181 L
s
.70843 .32928 m
.70853 .33389 L
s
.33384 .32405 m
.33658 .32921 L
s
.7071 .33416 m
.70864 .33851 L
s
.32965 .32089 m
.33384 .32405 L
s
.71254 .32153 m
.71678 .32068 L
s
.70853 .33389 m
.71007 .33825 L
s
.70864 .33851 m
.71297 .34002 L
s
.32684 .32032 m
.32965 .32089 L
s
.5 Mabswid
.743 .718 .673 r
.28394 .33181 m .32212 .34089 L .32286 .31085 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32286 .31085 m .28483 .3014 L .28394 .33181 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71007 .33825 m
.71297 .34002 L
s
.71678 .32068 m
.71964 .32241 L
s
.32399 .32205 m
.32684 .32032 L
s
.3226 .32175 m
.32684 .32032 L
s
0 0 0 r
.72722 .31321 m
.72921 .31032 L
s
.255 .412 .882 r
.70885 .34777 m
.7089 .35009 L
s
.70885 .34777 m
.71028 .34751 L
s
.5 Mabswid
.78 .756 .736 r
.68779 .40766 m .72943 .40076 L .72866 .37023 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7089 .35009 m
.71039 .35214 L
s
.71297 .34002 m
.72148 .34066 L
s
.71028 .34751 m
.71034 .34982 L
s
.71964 .32241 m
.72254 .32646 L
s
.5 Mabswid
.775 .751 .735 r
.76471 .30019 m .72713 .30985 L .72789 .33993 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72713 .30985 m .76471 .30019 L .7638 .26995 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.33707 .37119 m
.33739 .35724 L
s
.33579 .36395 m
.33739 .35724 L
s
.71039 .35214 m
.7133 .35393 L
s
.3211 .32608 m
.32399 .32205 L
s
.31972 .32579 m
.3226 .32175 L
s
.72381 .32153 m
.72651 .31862 L
s
.72254 .32646 m
.72381 .32153 L
s
.72254 .32646 m
.72305 .34735 L
s
.7133 .35393 m
.71896 .35284 L
s
.33281 .36809 m
.33579 .36395 L
s
.33579 .36395 m
.33707 .37119 L
s
.72519 .32123 m
.72651 .31862 L
s
.72392 .32616 m
.72519 .32123 L
s
.72392 .32616 m
.72433 .34241 L
s
0 0 0 r
.32065 .34119 m
.32198 .34479 L
s
.255 .412 .882 r
.72651 .31862 m
.72789 .31832 L
s
0 0 0 r
.32011 .34041 m
.32065 .34119 L
s
.255 .412 .882 r
.3196 .33043 m
.3211 .32608 L
s
0 0 0 r
.32057 .3445 m
.3219 .34811 L
s
.5 Mabswid
.743 .718 .673 r
.28304 .36246 m .32138 .37115 L .32212 .34089 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32212 .34089 m .28394 .33181 L .28304 .36246 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31822 .33013 m
.31972 .32579 L
s
.72148 .34066 m
.72294 .3427 L
s
.31805 .3371 m
.3196 .33043 L
s
.32849 .36963 m
.33281 .36809 L
s
.71896 .35284 m
.72171 .34996 L
s
.31667 .3368 m
.31822 .33013 L
s
.5 Mabswid
.775 .751 .735 r
.76562 .33065 m .72789 .33993 L .72866 .37023 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72789 .33993 m .76562 .33065 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.72171 .34996 m
.72305 .34735 L
s
.72305 .34735 m
.72433 .34241 L
s
.31775 .34874 m
.31805 .3371 L
s
.32566 .36909 m
.32849 .36963 L
s
.31637 .34845 m
.31667 .3368 L
s
.32291 .36621 m
.32566 .36909 L
s
.32151 .36593 m
.32566 .36909 L
s
.31775 .34874 m
.31896 .35603 L
s
.5 Mabswid
.743 .718 .673 r
.28213 .39333 m .32062 .40164 L .32138 .37115 L p F P
.678 .678 .678 r
s
.743 .718 .673 r
.32138 .37115 m .28304 .36246 L .28213 .39333 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.32023 .36098 m
.32291 .36621 L
s
.31896 .35603 m
.32023 .36098 L
s
.31637 .34845 m
.31758 .35574 L
s
.31884 .3607 m
.32151 .36593 L
s
.31758 .35574 m
.31884 .3607 L
s
.30234 .31475 m
.30679 .34869 L
s
.29619 .34617 m
.30234 .31475 L
s
.5 Mabswid
.775 .751 .735 r
.76654 .36134 m .72866 .37023 L .72943 .40076 L p F P
.678 .678 .678 r
s
.775 .751 .735 r
.72866 .37023 m .76654 .36134 L .76562 .33065 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.73689 .34907 m
.74024 .32247 L
s
.73146 .35027 m
.74092 .34815 L
s
.73554 .34937 m
.74005 .31549 L
s
.74005 .31549 m
.74623 .3469 L
s
.30278 .34776 m
.31085 .3496 L
s
.2975 .34649 m
.30215 .32173 L
s
.5 Mabswid
.724 .699 .65 r
.25113 .29023 m .28483 .3014 L .28572 .27121 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28572 .27121 m .25215 .2596 L .25113 .29023 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.79681 .25815 m .7638 .26995 L .76471 .30019 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75054 .31283 m
.75661 .34429 L
s
.74623 .3469 m
.75054 .31283 L
s
.74755 .34658 m
.75073 .31983 L
s
.5 Mabswid
.775 .751 .735 r
.72943 .40076 m .76746 .39227 L .76654 .36134 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.29194 .31205 m
.29619 .34617 L
s
.28591 .34353 m
.29194 .31205 L
s
0 0 0 r
.76483 .30435 m
.76506 .30449 L
s
.5 Mabswid
.724 .699 .65 r
.25009 .32109 m .28394 .33181 L .28483 .3014 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28483 .3014 m .25113 .29023 L .25009 .32109 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28717 .34386 m
.29174 .31906 L
s
.5 Mabswid
.765 .742 .732 r
.79785 .28883 m .76471 .30019 L .76562 .33065 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76471 .30019 m .79785 .28883 L .79681 .25815 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.75275 .34528 m
.76041 .34328 L
s
.5 Mabswid
.724 .699 .65 r
.24904 .35218 m .28304 .36246 L .28394 .33181 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28394 .33181 m .25009 .32109 L .24904 .35218 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.28214 .3425 m
.29101 .34487 L
s
.2794 .30849 m
.28063 .30886 L
s
.27689 .3101 m
.2794 .30849 L
s
.27811 .31047 m
.2794 .30849 L
s
.27675 .3148 m
.27811 .31047 L
s
.5 Mabswid
.765 .742 .732 r
.79891 .31974 m .76562 .33065 L .76654 .36134 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76706 .32878 m
.7671 .33016 L
s
.76584 .33037 m
.76584 .33058 L
s
.5 Mabswid
.765 .742 .732 r
.76562 .33065 m .79891 .31974 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.7671 .31527 m
.76939 .30983 L
s
.76601 .32033 m
.7671 .31527 L
s
.76499 .32775 m
.76601 .32033 L
s
.27553 .31444 m
.27689 .3101 L
s
.76499 .32775 m
.76534 .33954 L
s
.76939 .30983 m
.77293 .30636 L
s
.76832 .3149 m
.7706 .30946 L
s
.76724 .31997 m
.76832 .3149 L
s
.76622 .32739 m
.76724 .31997 L
s
.27625 .3313 m
.27675 .3148 L
s
.76622 .32739 m
.76658 .33919 L
s
.7706 .30946 m
.77293 .30636 L
s
.27327 .30899 m
.27553 .31444 L
s
.27489 .33567 m
.27553 .31444 L
s
.27095 .30588 m
.27327 .30899 L
s
.77293 .30636 m
.77531 .3056 L
s
.76534 .33954 m
.76679 .34628 L
s
.5 Mabswid
.724 .699 .65 r
.24799 .38352 m .28213 .39333 L .28304 .36246 L p F P
.678 .678 .678 r
s
.724 .699 .65 r
.28304 .36246 m .24904 .35218 L .24799 .38352 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26742 .30473 m
.27095 .30588 L
s
.27489 .33567 m
.27625 .3313 L
s
.77531 .3056 m
.77891 .3068 L
s
.27389 .32822 m
.27503 .33094 L
s
.26682 .32363 m
.27389 .32822 L
s
.5 Mabswid
.765 .742 .732 r
.79997 .35089 m .76654 .36134 L .76746 .39227 L p F P
.678 .678 .678 r
s
.765 .742 .732 r
.76654 .36134 m .79997 .35089 L .79891 .31974 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.76679 .34628 m
.76817 .35067 L
s
.76658 .33919 m
.76802 .34594 L
s
.76802 .34594 m
.76939 .35033 L
s
.2736 .33768 m
.27489 .33567 L
s
.26501 .30631 m
.26742 .30473 L
s
.26386 .30592 m
.26742 .30473 L
s
.76817 .35067 m
.77076 .35473 L
s
.27112 .33932 m
.2736 .33768 L
s
.77891 .3068 m
.78138 .31075 L
s
.76939 .35033 m
.77198 .35438 L
s
.26371 .31065 m
.26501 .30631 L
s
.78115 .30366 m
.78176 .32259 L
s
.26637 .33786 m
.27112 .33932 L
s
.26256 .31026 m
.26386 .30592 L
s
.7823 .30327 m
.78291 .32221 L
s
.77826 .32373 m
.78634 .32105 L
s
.5 Mabswid
.693 .67 .617 r
.22262 .27748 m .25113 .29023 L .25215 .2596 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25215 .2596 m .22378 .24636 L .22262 .27748 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.26456 .3205 m
.26682 .32363 L
s
.2634 .32012 m
.26682 .32363 L
s
.26355 .31538 m
.26371 .31065 L
s
.2624 .31499 m
.26256 .31026 L
s
.26355 .31538 m
.26456 .3205 L
s
.5 Mabswid
.765 .742 .732 r
.76746 .39227 m .80104 .38228 L .79997 .35089 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.77198 .35438 m
.77447 .35605 L
s
.77076 .35473 m
.77447 .35605 L
s
.2624 .31499 m
.2634 .32012 L
s
.77447 .35605 m
.77686 .35534 L
s
.26411 .33474 m
.26637 .33786 L
s
.5 Mabswid
.746 .724 .721 r
.82453 .24472 m .79681 .25815 L .79785 .28883 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.2631 .32961 m
.26426 .32999 L
s
.26418 .33236 m
.26426 .32999 L
s
.77686 .35534 m
.78033 .35188 L
s
.26302 .33199 m
.2631 .32961 L
s
.26302 .33199 m
.26411 .33474 L
s
.78908 .30087 m
.79671 .29799 L
s
.5 Mabswid
.693 .67 .617 r
.22145 .30884 m .25009 .32109 L .25113 .29023 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25113 .29023 m .22262 .27748 L .22145 .30884 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.78033 .35188 m
.78252 .34637 L
s
.78344 .33885 m
.7839 .35317 L
s
.78252 .34637 m
.78344 .33885 L
s
.78252 .34637 m
.7839 .35317 L
s
.79239 .29965 m
.7935 .333 L
s
.79348 .29923 m
.79459 .33261 L
s
.5 Mabswid
.746 .724 .721 r
.8257 .27591 m .79785 .28883 L .79891 .31974 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79785 .28883 m .8257 .27591 L .82453 .24472 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.79018 .33417 m
.79459 .33261 L
s
.25294 .32612 m
.25396 .3289 L
s
.25388 .33129 m
.25396 .3289 L
s
.2411 .2949 m
.2484 .29788 L
s
.5 Mabswid
.693 .67 .617 r
.22028 .34045 m .24904 .35218 L .25009 .32109 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.25009 .32109 m .22145 .30884 L .22028 .34045 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.25176 .32812 m
.25294 .32612 L
s
.2527 .33329 m
.25388 .33129 L
s
.79411 .31827 m
.79544 .32503 L
s
.25176 .32812 m
.25278 .3309 L
s
.24942 .33211 m
.2527 .33329 L
s
.24408 .3301 m
.24523 .29661 L
s
.79544 .32503 m
.79776 .32902 L
s
.5 Mabswid
.746 .724 .721 r
.82688 .30733 m .79891 .31974 L .79997 .35089 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79891 .31974 m .82688 .30733 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24304 .32969 m
.24419 .29618 L
s
.24735 .32891 m
.24942 .33211 L
s
.79776 .32902 m
.79997 .33061 L
s
.24538 .32331 m
.24735 .32891 L
s
.5 Mabswid
.693 .67 .617 r
.21909 .37231 m .24799 .38352 L .24904 .35218 L p F P
.678 .678 .678 r
s
.693 .67 .617 r
.24904 .35218 m .22028 .34045 L .21909 .37231 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.24458 .31571 m
.24538 .32331 L
s
.5 Mabswid
.746 .724 .721 r
.82807 .33901 m .79997 .35089 L .80104 .38228 L p F P
.678 .678 .678 r
s
.746 .724 .721 r
.79997 .35089 m .82807 .33901 L .82688 .30733 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80191 .32499 m
.80287 .32218 L
s
.80191 .32499 m
.80303 .32699 L
s
.79997 .33061 m
.80312 .32939 L
s
.23994 .32846 m
.24408 .3301 L
s
.80287 .32218 m
.80399 .32417 L
s
.80312 .32939 m
.80407 .32657 L
s
.80399 .32417 m
.80407 .32657 L
s
.81027 .29958 m
.81108 .29434 L
s
.81027 .29958 m
.81044 .30438 L
s
.81108 .29434 m
.81388 .2906 L
s
.23486 .29946 m
.23567 .3047 L
s
.23567 .3047 m
.23641 .31234 L
s
.23309 .29378 m
.23486 .29946 L
s
.23598 .32438 m
.23641 .31234 L
s
.81044 .30438 m
.81159 .30875 L
s
.81125 .29914 m
.81205 .2939 L
s
.81125 .29914 m
.81142 .30394 L
s
.81205 .2939 m
.81388 .2906 L
s
.23388 .29902 m
.23469 .30426 L
s
.23469 .30426 m
.23541 .31191 L
s
.23213 .29333 m
.23388 .29902 L
s
.23031 .29003 m
.23309 .29378 L
s
.23499 .32395 m
.23541 .31191 L
s
.5 Mabswid
.746 .724 .721 r
.80104 .38228 m .82927 .37093 L .82807 .33901 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81142 .30394 m
.81256 .30832 L
s
.23031 .29003 m
.23213 .29333 L
s
.5 Mabswid
.641 .619 .561 r
.20019 .26334 m .22262 .27748 L .22378 .24636 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22378 .24636 m .20146 .23166 L .20019 .26334 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81388 .2906 m
.8167 .28924 L
s
.81159 .30875 m
.81457 .30985 L
s
.23473 .3312 m
.23598 .32438 L
s
.81256 .30832 m
.81457 .30985 L
s
.23374 .33078 m
.23499 .32395 L
s
.81194 .31839 m
.81202 .3208 L
s
.81194 .31839 m
.81291 .31796 L
s
.81202 .3208 m
.81308 .32279 L
s
.23357 .33562 m
.23473 .3312 L
s
.8167 .28924 m
.81863 .29074 L
s
.81291 .31796 m
.81299 .32037 L
s
.5 Mabswid
.707 .688 .694 r
.84608 .22988 m .82453 .24472 L .8257 .27591 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.81457 .30985 m
.82025 .30961 L
s
.23259 .3352 m
.23374 .33078 L
s
.81308 .32279 m
.81509 .32435 L
s
.23144 .33963 m
.23357 .33562 L
s
.81863 .29074 m
.82063 .29465 L
s
.23048 .33921 m
.23259 .3352 L
s
.5 Mabswid
.641 .619 .561 r
.19891 .29526 m .22145 .30884 L .22262 .27748 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22262 .27748 m .20019 .26334 L .19891 .29526 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.22126 .28543 m
.23031 .29003 L
s
.81509 .32435 m
.81886 .32262 L
s
.22291 .33823 m
.22479 .28729 L
s
.22848 .3408 m
.23144 .33963 L
s
.22201 .3378 m
.2239 .28683 L
s
.82063 .29465 m
.82135 .28936 L
s
.82063 .29465 m
.82143 .31644 L
s
.82135 .28936 m
.82303 .28602 L
s
.22848 .3408 m
.23048 .33921 L
s
.5 Mabswid
.707 .688 .694 r
.84736 .26161 m .8257 .27591 L .82688 .30733 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.8257 .27591 m .84736 .26161 L .84608 .22988 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82152 .29419 m
.82224 .2889 L
s
.82152 .29419 m
.82215 .31114 L
s
.82224 .2889 m
.82303 .28602 L
s
.82303 .28602 m
.8239 .28555 L
s
.82025 .30961 m
.82125 .31159 L
s
.81886 .32262 m
.82061 .31931 L
s
.5 Mabswid
.641 .619 .561 r
.19763 .32744 m .22028 .34045 L .22145 .30884 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22145 .30884 m .19891 .29526 L .19763 .32744 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82061 .31931 m
.82143 .31644 L
s
.82143 .31644 m
.82215 .31114 L
s
.5 Mabswid
.707 .688 .694 r
.84865 .2936 m .82688 .30733 L .82807 .33901 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82688 .30733 m .84865 .2936 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.825 .26771 m
.83078 .2643 L
s
.5 Mabswid
.641 .619 .561 r
.19633 .35987 m .21909 .37231 L .22028 .34045 L p F P
.678 .678 .678 r
s
.641 .619 .561 r
.22028 .34045 m .19763 .32744 L .19633 .35987 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.21935 .33649 m
.22848 .3408 L
s
.82927 .28999 m
.83072 .28418 L
s
.83072 .28418 m
.83223 .28078 L
s
.5 Mabswid
.707 .688 .694 r
.84995 .32585 m .82807 .33901 L .82927 .37093 L p F P
.678 .678 .678 r
s
.707 .688 .694 r
.82807 .33901 m .84995 .32585 L .84865 .2936 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.82691 .31862 m
.83028 .3168 L
s
.82835 .26577 m
.83028 .3168 L
s
.82752 .26626 m
.82945 .31726 L
s
.83223 .28078 m
.8338 .27981 L
s
.83001 .30947 m
.83183 .31343 L
s
.8338 .27981 m
.83543 .28127 L
s
.8338 .27981 m
.83619 .28078 L
s
.83183 .31343 m
.83354 .31496 L
s
.83543 .28127 m
.83713 .28517 L
s
.83619 .28078 m
.83787 .28468 L
s
.5 Mabswid
.707 .688 .694 r
.82927 .37093 m .85127 .35835 L .84995 .32585 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83354 .31496 m
.83512 .31403 L
s
.83713 .28517 m
.83816 .29203 L
s
.5 Mabswid
.541 .523 .459 r
.1847 .24803 m .20019 .26334 L .20146 .23166 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20146 .23166 m .18606 .21576 L .1847 .24803 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83512 .31403 m
.83657 .31063 L
s
.83512 .31403 m
.83733 .31016 L
s
.83787 .28468 m
.83889 .29154 L
s
.83816 .29203 m
.83835 .29693 L
s
.83657 .31063 m
.83789 .30477 L
s
.83789 .30477 m
.83835 .29693 L
s
.83889 .29154 m
.83909 .29645 L
s
.83733 .31016 m
.83864 .3043 L
s
.5 Mabswid
.623 .608 .628 r
.86063 .21385 m .84608 .22988 L .84736 .26161 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.83864 .3043 m
.83909 .29645 L
s
.5 Mabswid
.541 .523 .459 r
.18333 .28055 m .19891 .29526 L .20019 .26334 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.20019 .26334 m .1847 .24803 L .18333 .28055 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84255 .27385 m
.84709 .27028 L
s
.84455 .27233 m
.84662 .32425 L
s
.5 Mabswid
.623 .608 .628 r
.862 .24619 m .84736 .26161 L .84865 .2936 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84736 .26161 m .862 .24619 L .86063 .21385 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84519 .27182 m
.84727 .32377 L
s
0 0 0 r
.84939 .29098 m
.84939 .29098 L
s
.84887 .29283 m
.84982 .30157 L
s
.5 Mabswid
.541 .523 .459 r
.18195 .31334 m .19763 .32744 L .19891 .29526 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19891 .29526 m .18333 .28055 L .18195 .31334 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.86337 .27878 m .84865 .2936 L .84995 .32585 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.84939 .29098 m
.84958 .29268 L
s
.5 Mabswid
.623 .608 .628 r
.84865 .2936 m .86337 .27878 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84628 .29895 m
.84776 .30292 L
s
.19648 .27384 m
.19718 .27188 L
s
.19668 .2689 m
.19718 .27188 L
s
.8446 .32567 m
.84727 .32377 L
s
.19599 .27085 m
.19668 .2689 L
s
.19599 .27085 m
.19648 .27384 L
s
.8495 .2682 m
.85337 .26453 L
s
.5 Mabswid
.541 .523 .459 r
.18056 .3464 m .19633 .35987 L .19763 .32744 L p F P
.678 .678 .678 r
s
.541 .523 .459 r
.19763 .32744 m .18195 .31334 L .18056 .3464 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.84776 .30292 m
.84971 .30392 L
s
.19538 .31654 m
.19598 .28621 L
s
.19417 .31556 m
.19598 .28621 L
s
.5 Mabswid
.623 .608 .628 r
.86476 .31165 m .84995 .32585 L .85127 .35835 L p F P
.678 .678 .678 r
s
.623 .608 .628 r
.84995 .32585 m .86476 .31165 L .86337 .27878 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.85121 .26664 m
.85233 .29394 L
s
.85177 .26611 m
.85288 .29344 L
s
.84971 .30392 m
.85091 .30292 L
s
.19477 .31605 m
.19538 .3011 L
s
.19457 .32105 m
.19538 .31654 L
s
.85091 .30292 m
.85197 .29943 L
s
.85091 .30292 m
.85253 .29893 L
s
.19157 .26666 m
.19199 .26967 L
s
.19168 .27713 m
.19199 .26967 L
s
.85197 .29943 m
.85233 .29394 L
s
.19417 .31556 m
.19457 .32105 L
s
.19066 .26312 m
.19157 .26666 L
s
.19116 .27661 m
.19178 .27464 L
s
.85253 .29893 m
.85288 .29344 L
s
.19106 .2791 m
.19168 .27713 L
s
.5 Mabswid
.623 .608 .628 r
.85127 .35835 m .86616 .34478 L .86476 .31165 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18874 .26098 m
.19066 .26312 L
s
.19004 .27805 m
.19116 .27661 L
s
.18994 .28055 m
.19106 .2791 L
s
.19044 .29407 m
.19117 .28958 L
s
.19076 .29958 m
.19117 .28958 L
s
.85539 .2624 m
.85856 .25863 L
s
.5 Mabswid
.388 .377 .328 r
.17695 .23184 m .1847 .24803 L .18606 .21576 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18606 .21576 m .17837 .19896 L .17695 .23184 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18745 .28043 m
.19004 .27805 L
s
.18735 .28294 m
.18994 .28055 L
s
.19044 .29407 m
.19076 .29958 L
s
.18982 .29606 m
.19044 .29407 L
s
.18773 .26239 m
.18874 .26098 L
s
.85681 .26079 m
.85826 .29583 L
s
.18872 .29754 m
.18982 .29606 L
s
0 0 0 r
.86215 .24983 m
.86237 .24885 L
s
.255 .412 .882 r
.85726 .26026 m
.85872 .29532 L
s
0 0 0 r
.86217 .25018 m
.86237 .24885 L
s
.5 Mabswid
.439 .432 .474 r
.86738 .19696 m .86063 .21385 L .862 .24619 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18719 .26435 m
.18773 .26239 L
s
.18683 .29549 m
.18872 .29754 L
s
0 0 0 r
.86237 .24885 m
.8632 .24773 L
s
.255 .412 .882 r
.85684 .29737 m
.85872 .29532 L
s
.5 Mabswid
.388 .377 .328 r
.17552 .265 m .18333 .28055 L .1847 .24803 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.1847 .24803 m .17695 .23184 L .17552 .265 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18697 .25882 m
.18719 .26435 L
s
.18655 .26882 m
.18719 .26435 L
s
.18655 .26882 m
.18697 .25882 L
s
.18646 .28189 m
.18745 .28043 L
s
.18635 .2844 m
.18735 .28294 L
s
.18592 .28388 m
.18646 .28189 L
s
.18604 .29194 m
.18683 .29549 L
s
.5 Mabswid
.439 .432 .474 r
.8688 .22992 m .862 .24619 L .86337 .27878 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.862 .24619 m .8688 .22992 L .86738 .19696 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18582 .28639 m
.18635 .2844 L
s
.85842 .31145 m
.85878 .30842 L
s
.85842 .31145 m
.85899 .31347 L
s
0 0 0 r
.86421 .29863 m
.86449 .29902 L
s
.255 .412 .882 r
.18571 .28891 m
.18592 .28388 L
s
.85878 .30842 m
.85934 .31044 L
s
.18571 .28891 m
.18604 .29194 L
s
0 0 0 r
.8642 .29828 m
.86449 .29902 L
s
.255 .412 .882 r
.85899 .31347 m
.85934 .31044 L
s
.5 Mabswid
.388 .377 .328 r
.17408 .29844 m .18195 .31334 L .18333 .28055 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18333 .28055 m .17552 .265 L .17408 .29844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86086 .26344 m
.86138 .25733 L
s
.8608 .27152 m
.86086 .26344 L
s
.8608 .27152 m
.86101 .27655 L
s
.86123 .2629 m
.86173 .25678 L
s
.86118 .27098 m
.86123 .2629 L
s
.86101 .27655 m
.86171 .28358 L
s
.86138 .25733 m
.86229 .25316 L
s
.86118 .27098 m
.86139 .27602 L
s
.18343 .25641 m
.18392 .26254 L
s
.5 Mabswid
.439 .432 .474 r
.87024 .26316 m .86337 .27878 L .86476 .31165 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.86679 .2937 m
.86688 .29587 L
s
.5 Mabswid
.439 .432 .474 r
.86337 .27878 m .87024 .26316 L .8688 .22992 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86139 .27602 m
.86208 .28305 L
s
.86173 .25678 m
.86229 .25316 L
s
.18257 .25224 m
.18343 .25641 L
s
.86171 .28358 m
.86265 .28758 L
s
.86229 .25316 m
.86292 .25206 L
s
.5 Mabswid
.388 .377 .328 r
.17263 .33215 m .18056 .3464 L .18195 .31334 L p F P
.678 .678 .678 r
s
.388 .377 .328 r
.18195 .31334 m .17408 .29844 L .17263 .33215 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86208 .28305 m
.863 .28705 L
s
.18307 .2827 m
.18318 .28018 L
s
.18293 .27712 m
.18318 .28018 L
s
.18216 .2867 m
.18307 .2827 L
s
.18248 .27911 m
.18293 .27712 L
s
.18197 .25114 m
.18257 .25224 L
s
.86292 .25206 m
.8639 .25291 L
s
.18248 .27911 m
.18272 .28217 L
s
.86265 .28758 m
.86378 .28853 L
s
.863 .28705 m
.86378 .28853 L
s
.18131 .25255 m
.18197 .25114 L
s
.18104 .25199 m
.18197 .25114 L
s
.5 Mabswid
.439 .432 .474 r
.87168 .29667 m .86476 .31165 L .86616 .34478 L p F P
.678 .678 .678 r
s
.439 .432 .474 r
.86476 .31165 m .87168 .29667 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18139 .28818 m
.18216 .2867 L
s
0 0 0 r
.17594 .236 m
.17669 .23784 L
s
.255 .412 .882 r
.8639 .25291 m
.86465 .25686 L
s
.86378 .28853 m
.86472 .28694 L
s
.18057 .2565 m
.18131 .25255 L
s
.18047 .28659 m
.18139 .28818 L
s
.18033 .25594 m
.18104 .25199 L
s
0 0 0 r
.17439 .28858 m
.17658 .23773 L
s
.255 .412 .882 r
.18001 .26356 m
.18057 .2565 L
s
.86472 .28694 m
.86519 .28333 L
s
.86487 .27571 m
.86503 .27263 L
s
.86487 .27571 m
.86525 .27771 L
s
.5 Mabswid
.439 .432 .474 r
.86616 .34478 m .87314 .33046 L .87168 .29667 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.87003 .25843 m
.871 .25588 L
s
.255 .412 .882 r
.18002 .28298 m
.18047 .28659 L
s
.17975 .28244 m
.18047 .28659 L
s
.86503 .27263 m
.8654 .27463 L
s
.17977 .26301 m
.18033 .25594 L
s
.86519 .28333 m
.86551 .27717 L
s
.17971 .27681 m
.18002 .28298 L
s
.17979 .26864 m
.18001 .26356 L
s
.8654 .27463 m
.86551 .27717 L
s
.17971 .27681 m
.17979 .26864 L
s
.17947 .27627 m
.17975 .28244 L
s
.17955 .26809 m
.17977 .26301 L
s
.5 Mabswid
.134 .135 .124 r
.17764 .21514 m .17695 .23184 L .17837 .19896 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17837 .19896 m .17909 .18161 L .17764 .21514 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.8697 .23523 m
.87063 .23175 L
s
.17439 .28858 m
.1745 .2888 L
s
.255 .412 .882 r
.17947 .27627 m
.17955 .26809 L
s
0 0 0 r
.17464 .27708 m
.17533 .26671 L
s
.255 .412 .882 r
.17851 .24158 m
.17958 .24554 L
s
.86587 .24535 m
.86627 .24987 L
s
.86587 .24535 m
.8663 .25552 L
s
.86627 .24987 m
.8663 .25552 L
s
.86627 .24987 m
.86633 .24676 L
s
.5 Mabswid
.203 .129 .013 r
.86565 .17958 m .86738 .19696 L .8688 .22992 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1739 .2833 m
.17464 .27708 L
s
.255 .412 .882 r
.86633 .24676 m
.86653 .24309 L
s
0 0 0 r
.87036 .23292 m
.8724 .31332 L
s
.255 .412 .882 r
.86653 .24309 m
.86702 .24082 L
s
.5 Mabswid
.134 .135 .124 r
.17618 .24895 m .17552 .265 L .17695 .23184 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17695 .23184 m .17764 .21514 L .17618 .24895 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17738 .27907 m
.17891 .24328 L
s
.17753 .27961 m
.17906 .24385 L
s
.86696 .27082 m
.86703 .26772 L
s
.86696 .27082 m
.86717 .27593 L
s
.86707 .27337 m
.86714 .27027 L
s
.86703 .26772 m
.86725 .26406 L
s
.86717 .27593 m
.86747 .27795 L
s
.86714 .27027 m
.86736 .26662 L
s
0 0 0 r
.1739 .2833 m
.17336 .28587 L
s
.255 .412 .882 r
.86747 .27795 m
.86791 .27943 L
s
.5 Mabswid
.203 .129 .013 r
.86709 .21318 m .8688 .22992 L .87024 .26316 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86736 .26662 m
.86779 .25873 L
s
.86725 .26406 m
.86768 .25616 L
s
.5 Mabswid
.203 .129 .013 r
.8688 .22992 m .86709 .21318 L .86565 .17958 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86702 .24082 m
.86732 .24223 L
s
0 0 0 r
.17336 .28587 m
.17286 .28424 L
s
.255 .412 .882 r
.17697 .27744 m
.17753 .27961 L
s
0 0 0 r
.17333 .27744 m
.17302 .28057 L
s
.17334 .27323 m
.17333 .27744 L
s
.255 .412 .882 r
.86791 .27943 m
.86845 .27726 L
s
0 0 0 r
.17303 .27634 m
.17334 .27323 L
s
.5 Mabswid
.134 .135 .124 r
.17472 .28304 m .17408 .29844 L .17552 .265 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17552 .265 m .17618 .24895 L .17472 .28304 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86732 .24223 m
.86751 .24423 L
s
.86768 .25616 m
.86776 .25248 L
s
.17786 .23529 m
.17813 .2393 L
s
0 0 0 r
.17288 .28002 m
.17303 .27634 L
s
.255 .412 .882 r
.86779 .25873 m
.86787 .25504 L
s
0 0 0 r
.17286 .28424 m
.17288 .28002 L
s
.255 .412 .882 r
.17661 .29709 m
.17687 .29504 L
s
.17683 .29193 m
.17687 .29504 L
s
0 0 0 r
.17383 .23999 m
.17402 .23152 L
s
.17343 .25154 m
.17383 .23999 L
s
.255 .412 .882 r
.17657 .29398 m
.17683 .29193 L
s
.86773 .24935 m
.86776 .25248 L
s
0 0 0 r
.17402 .23152 m
.17406 .2261 L
s
.17311 .25887 m
.17343 .25154 L
s
.17376 .23941 m
.17397 .23093 L
s
.17335 .25097 m
.17376 .23941 L
s
.255 .412 .882 r
.17657 .29398 m
.17661 .29709 L
s
.5 Mabswid
.203 .129 .013 r
.86855 .24707 m .87024 .26316 L .87168 .29667 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86845 .27726 m
.86855 .27359 L
s
.5 Mabswid
.203 .129 .013 r
.87024 .26316 m .86855 .24707 L .86709 .21318 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86784 .25192 m
.86787 .25504 L
s
.86751 .24423 m
.86784 .25192 L
s
0 0 0 r
.17397 .23093 m
.17406 .2261 L
s
.17303 .25831 m
.17335 .25097 L
s
.17255 .26934 m
.17311 .25887 L
s
.255 .412 .882 r
.17673 .26587 m
.17795 .23759 L
s
.86853 .27047 m
.86855 .27359 L
s
0 0 0 r
.17248 .26879 m
.17303 .25831 L
s
.255 .412 .882 r
.17669 .26532 m
.17791 .23701 L
s
0 0 0 r
.17406 .2261 m
.17404 .22493 L
s
.255 .412 .882 r
.86839 .26477 m
.86853 .27047 L
s
.86853 .27047 m
.86883 .27508 L
s
.86839 .26477 m
.86883 .27508 L
s
.5 Mabswid
.134 .135 .124 r
.17323 .31743 m .17263 .33215 L .17408 .29844 L p F P
.678 .678 .678 r
s
.134 .135 .124 r
.17408 .29844 m .17472 .28304 L .17323 .31743 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1721 .27561 m
.17255 .26934 L
s
.17404 .22493 m
.17394 .22684 L
s
.17205 .27506 m
.17248 .26879 L
s
.255 .412 .882 r
.17647 .27049 m
.17673 .26587 L
s
.86753 .23453 m
.86764 .23767 L
s
.86764 .23767 m
.86775 .23967 L
s
.5 Mabswid
.203 .129 .013 r
.87002 .28124 m .87168 .29667 L .87314 .33046 L p F P
.678 .678 .678 r
s
.203 .129 .013 r
.87168 .29667 m .87002 .28124 L .86855 .24707 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86753 .23453 m
.86762 .23652 L
s
.17644 .26994 m
.17669 .26532 L
s
0 0 0 r
.17182 .27766 m
.1721 .27561 L
s
.255 .412 .882 r
.86762 .23652 m
.86775 .23967 L
s
.1763 .27143 m
.17647 .27049 L
s
0 0 0 r
.17394 .22684 m
.1737 .23303 L
s
.17182 .27766 m
.17205 .27506 L
s
.255 .412 .882 r
.1763 .27143 m
.17644 .26994 L
s
.17793 .233 m
.17848 .22896 L
s
.8683 .25257 m
.86962 .28315 L
s
.8683 .25257 m
.86964 .28423 L
s
0 0 0 r
.1718 .276 m
.17182 .27766 L
s
.255 .412 .882 r
.17632 .27033 m
.1763 .27143 L
s
.5 Mabswid
.203 .129 .013 r
.87314 .33046 m .8715 .31571 L .87002 .28124 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.86897 .2681 m
.86964 .28369 L
s
.17653 .26608 m
.17632 .27033 L
s
0 0 0 r
.17249 .26004 m
.17269 .25577 L
s
.17237 .26319 m
.17249 .26004 L
s
.255 .412 .882 r
.86964 .28423 m
.86986 .2889 L
s
0 0 0 r
.17269 .25577 m
.17258 .25891 L
s
.17201 .27117 m
.1718 .276 L
s
.5 Mabswid
.59 .378 .044 r
.18731 .19832 m .17764 .21514 L .17909 .18161 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17909 .18161 m .18875 .16415 L .18731 .19832 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17241 .26263 m
.17201 .27117 L
s
.17471 .21844 m
.17582 .21429 L
s
.17258 .25891 m
.17241 .26263 L
s
.255 .412 .882 r
.86962 .28315 m
.86986 .2889 L
s
.17653 .26608 m
.17688 .25977 L
s
.5 Mabswid
.534 .337 .031 r
.85492 .16214 m .86565 .17958 L .86709 .21318 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.18587 .23279 m .17618 .24895 L .17764 .21514 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17584 .28531 m
.17749 .24676 L
s
.17576 .28585 m
.17743 .24686 L
s
.5 Mabswid
.59 .378 .044 r
.17764 .21514 m .18731 .19832 L .18587 .23279 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17613 .28369 m
.17576 .28585 L
s
.5 Mabswid
.534 .337 .031 r
.85635 .19639 m .86709 .21318 L .86855 .24707 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86709 .21318 m .85635 .19639 L .85492 .16214 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.17849 .24634 m
.17854 .24501 L
s
.5 Mabswid
.59 .378 .044 r
.18441 .26755 m .17472 .28304 L .17618 .24895 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17171 .2951 m
.17512 .21666 L
s
.5 Mabswid
.59 .378 .044 r
.17618 .24895 m .18587 .23279 L .18441 .26755 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1735 .25699 m
.17353 .26336 L
s
.1767 .21191 m
.17867 .20776 L
s
.17131 .29671 m
.17187 .29456 L
s
.5 Mabswid
.534 .337 .031 r
.8578 .23092 m .86855 .24707 L .87002 .28124 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.86855 .24707 m .8578 .23092 L .85635 .19639 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1757 .25134 m
.17748 .21013 L
s
.17353 .26336 m
.17397 .26544 L
s
.17598 .25077 m
.17776 .20954 L
s
.5 Mabswid
.59 .378 .044 r
.18294 .30261 m .17323 .31743 L .17472 .28304 L p F P
.678 .678 .678 r
s
.59 .378 .044 r
.17472 .28304 m .18441 .26755 L .18294 .30261 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17187 .29456 m
.17528 .21607 L
s
.17397 .26544 m
.17444 .26432 L
s
.5 Mabswid
.534 .337 .031 r
.85925 .26576 m .87002 .28124 L .8715 .31571 L p F P
.678 .678 .678 r
s
.534 .337 .031 r
.87002 .28124 m .85925 .26576 L .8578 .23092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17444 .26432 m
.17511 .25943 L
s
.17444 .26432 m
.17538 .25887 L
s
.17511 .25943 m
.1757 .25134 L
s
.17538 .25887 m
.17598 .25077 L
s
.18005 .20539 m
.1829 .20125 L
s
.17894 .25652 m
.1812 .20361 L
s
.5 Mabswid
.534 .337 .031 r
.8715 .31571 m .86072 .30091 L .85925 .26576 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17935 .25596 m
.18161 .20302 L
s
.5 Mabswid
.827 .528 .058 r
.20627 .18188 m .18731 .19832 L .18875 .16415 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18875 .16415 m .20765 .14709 L .20627 .18188 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18658 .21573 m
.18684 .21425 L
s
.5 Mabswid
.726 .459 .043 r
.83494 .14515 m .85492 .16214 L .85635 .19639 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.18684 .21425 m
.18787 .21046 L
s
0 0 0 r
.17779 .25819 m
.17935 .25596 L
s
.5 Mabswid
.827 .528 .058 r
.20488 .21698 m .18587 .23279 L .18731 .19832 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18731 .19832 m .20627 .18188 L .20488 .21698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18478 .19889 m
.1885 .19477 L
s
.255 .412 .882 r
.18575 .23549 m
.18791 .23108 L
s
.18527 .24706 m
.18584 .2482 L
s
.5 Mabswid
.726 .459 .043 r
.83631 .18002 m .85635 .19639 L .8578 .23092 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85635 .19639 m .83631 .18002 L .83494 .14515 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.17757 .27995 m
.17813 .27558 L
s
.17757 .27995 m
.1778 .28323 L
s
.17813 .27558 m
.17837 .27887 L
s
.1778 .28323 m
.17837 .27887 L
s
.5 Mabswid
.827 .528 .058 r
.20347 .25239 m .18441 .26755 L .18587 .23279 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18587 .23279 m .20488 .21698 L .20347 .25239 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18406 .25042 m
.1863 .19712 L
s
.18459 .24987 m
.18684 .19653 L
s
.18253 .25208 m
.18459 .24987 L
s
.5 Mabswid
.726 .459 .043 r
.83769 .21519 m .8578 .23092 L .85925 .26576 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.8578 .23092 m .83769 .21519 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19089 .19244 m
.19551 .18837 L
s
.18508 .23838 m
.18586 .24492 L
s
.5 Mabswid
.827 .528 .058 r
.20206 .28811 m .18294 .30261 L .18441 .26755 L p F P
.678 .678 .678 r
s
.827 .528 .058 r
.18441 .26755 m .20347 .25239 L .20206 .28811 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19106 .23281 m
.1928 .19069 L
s
.18586 .24492 m
.18744 .24711 L
s
.19172 .23225 m
.19346 .19011 L
s
.5 Mabswid
.726 .459 .043 r
.83909 .25067 m .85925 .26576 L .86072 .30091 L p F P
.678 .678 .678 r
s
.726 .459 .043 r
.85925 .26576 m .83909 .25067 L .83769 .21519 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.18744 .24711 m
.18866 .24601 L
s
.18866 .24601 m
.19009 .24106 L
s
.18866 .24601 m
.19074 .24051 L
s
.19009 .24106 m
.19106 .23281 L
s
.5 Mabswid
.726 .459 .043 r
.86072 .30091 m .8405 .28647 L .83909 .25067 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.1984 .18607 m
.20391 .18207 L
s
.5 Mabswid
.935 .597 .063 r
.23452 .16632 m .20627 .18188 L .20765 .14709 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20765 .14709 m .2358 .13094 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19172 .23225 m
.19276 .23887 L
s
.19074 .24051 m
.19172 .23225 L
s
.19898 .22676 m
.20069 .18435 L
s
.5 Mabswid
.856 .542 .052 r
.80573 .12915 m .83494 .14515 L .83631 .18002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19276 .23887 m
.19473 .24111 L
s
.19977 .22622 m
.20148 .18378 L
s
.5 Mabswid
.935 .597 .063 r
.23323 .20202 m .20488 .21698 L .20627 .18188 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20627 .18188 m .23452 .16632 L .23323 .20202 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19473 .24111 m
.19621 .24003 L
s
.19621 .24003 m
.19789 .23506 L
s
.19621 .24003 m
.19867 .23452 L
s
.5 Mabswid
.856 .542 .052 r
.807 .1646 m .83631 .18002 L .83769 .21519 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83631 .18002 m .807 .1646 L .80573 .12915 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.19789 .23506 m
.19898 .22676 L
s
.19867 .23452 m
.19977 .22622 L
s
.5 Mabswid
.935 .597 .063 r
.23192 .23804 m .20347 .25239 L .20488 .21698 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20488 .21698 m .23323 .20202 L .23192 .23804 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20773 .19084 m
.20983 .18199 L
s
.20639 .203 m
.20773 .19084 L
s
.20983 .18199 m
.21275 .17645 L
s
.20862 .19028 m
.21074 .18143 L
s
.20727 .20246 m
.20862 .19028 L
s
.20608 .21077 m
.20639 .203 L
s
.21074 .18143 m
.21275 .17645 L
s
.20696 .21022 m
.20727 .20246 L
s
.5 Mabswid
.856 .542 .052 r
.80828 .20036 m .83769 .21519 L .83909 .25067 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83769 .21519 m .80828 .20036 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.20608 .21077 m
.2065 .2219 L
s
.21275 .17645 m
.21466 .17535 L
s
.20696 .21022 m
.2074 .22137 L
s
.20696 .21022 m
.21844 .2038 L
s
.21466 .17535 m
.21746 .17758 L
s
.5 Mabswid
.935 .597 .063 r
.23061 .27439 m .20206 .28811 L .20347 .25239 L p F P
.678 .678 .678 r
s
.935 .597 .063 r
.20347 .25239 m .23192 .23804 L .23061 .27439 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2065 .2219 m
.208 .22865 L
s
.2074 .22137 m
.20891 .22812 L
s
.21746 .17758 m
.21918 .18427 L
s
.5 Mabswid
.856 .542 .052 r
.80957 .23645 m .83909 .25067 L .8405 .28647 L p F P
.678 .678 .678 r
s
.856 .542 .052 r
.83909 .25067 m .80957 .23645 L .80828 .20036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.208 .22865 m
.21063 .23099 L
s
.20891 .22812 m
.21063 .23099 L
s
.21063 .23099 m
.21352 .22942 L
s
.5 Mabswid
.985 .628 .066 r
.27169 .1522 m .23452 .16632 L .2358 .13094 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.2358 .13094 m .27283 .11629 L .27169 .1522 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21697 .21608 m
.21742 .20433 L
s
.5 Mabswid
.856 .542 .052 r
.8405 .28647 m .81087 .27287 L .80957 .23645 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21814 .21164 m
.21844 .2038 L
s
.21352 .22942 m
.21566 .22446 L
s
.5 Mabswid
.924 .587 .057 r
.76772 .11471 m .80573 .12915 L .807 .1646 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.21566 .22446 m
.21697 .21608 L
s
.21682 .22001 m
.21814 .21164 L
s
.21566 .22446 m
.21682 .22001 L
s
.22772 .18001 m
.23026 .17113 L
s
.22618 .19229 m
.22772 .18001 L
s
.5 Mabswid
.985 .628 .066 r
.27055 .18844 m .23323 .20202 L .23452 .16632 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23026 .17113 m
.23385 .16564 L
s
.5 Mabswid
.985 .628 .066 r
.23452 .16632 m .27169 .1522 L .27055 .18844 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80717 .17675 m
.80744 .17687 L
s
0 0 0 r
.22884 .17948 m
.2314 .1706 L
s
.22729 .19177 m
.22884 .17948 L
s
.22589 .20015 m
.22618 .19229 L
s
.2314 .1706 m
.23385 .16564 L
s
.227 .19963 m
.22729 .19177 L
s
.23385 .16564 m
.23621 .16459 L
s
.22589 .20015 m
.22656 .21145 L
s
.227 .19963 m
.22768 .21094 L
s
.5 Mabswid
.924 .587 .057 r
.76883 .15068 m .807 .1646 L .80828 .20036 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.807 .1646 m .76883 .15068 L .76772 .11471 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23621 .16459 m
.23847 .16748 L
s
.22656 .21145 m
.22852 .21834 L
s
.22768 .21094 m
.22967 .21784 L
s
.23847 .16748 m
.24063 .17432 L
s
.5 Mabswid
.985 .628 .066 r
.26939 .22501 m .23192 .23804 L .23323 .20202 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23323 .20202 m .27055 .18844 L .26939 .22501 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.24105 .16253 m
.24607 .16049 L
s
.22852 .21834 m
.23185 .22082 L
s
.22967 .21784 m
.23185 .22082 L
s
.5 Mabswid
.924 .587 .057 r
.76996 .18698 m .80828 .20036 L .80957 .23645 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.80767 .20015 m
.80812 .20017 L
s
.5 Mabswid
.924 .587 .057 r
.80828 .20036 m .76996 .18698 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.23185 .22082 m
.23422 .21983 L
s
.5 Mabswid
.985 .628 .066 r
.26823 .26192 m .23061 .27439 L .23192 .23804 L p F P
.678 .678 .678 r
s
.985 .628 .066 r
.23192 .23804 m .26939 .22501 L .26823 .26192 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2381 .24586 m
.24105 .16253 L
s
.23935 .24539 m
.24229 .16201 L
s
.23422 .21983 m
.23677 .21488 L
s
.23677 .21488 m
.23951 .20596 L
s
.5 Mabswid
.924 .587 .057 r
.77109 .22361 m .80957 .23645 L .81087 .27287 L p F P
.678 .678 .678 r
s
.924 .587 .057 r
.80957 .23645 m .77109 .22361 L .76996 .18698 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25218 .16984 m
.25513 .16095 L
s
.25045 .18222 m
.25218 .16984 L
s
.25513 .16095 m
.25936 .15554 L
s
.5 Mabswid
1 .643 .067 r
.31702 .14005 m .27169 .1522 L .27283 .11629 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27283 .11629 m .31796 .10368 L .31702 .14005 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25351 .16935 m
.25648 .16047 L
s
.25177 .18173 m
.25351 .16935 L
s
.25648 .16047 m
.25936 .15554 L
s
.25017 .19016 m
.25045 .18222 L
s
.7872 .16378 m
.78844 .1603 L
s
.78694 .15586 m
.78844 .1603 L
s
.78569 .15933 m
.78694 .15586 L
s
.25936 .15554 m
.26214 .15458 L
s
.2515 .18968 m
.25177 .18173 L
s
.23442 .24727 m
.23935 .24539 L
s
.25017 .19016 m
.2511 .20163 L
s
.78569 .15933 m
.7872 .16378 L
s
.5 Mabswid
.964 .612 .061 r
.72171 .10237 m .76772 .11471 L .76883 .15068 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2515 .18968 m
.25244 .20116 L
s
.2515 .18968 m
.26827 .1841 L
s
.26214 .15458 m
.26627 .15712 L
s
.5 Mabswid
.924 .587 .057 r
.81087 .27287 m .77224 .26058 L .77109 .22361 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.2511 .20163 m
.25352 .20869 L
s
.78786 .18364 m
.79084 .23217 L
s
.78786 .18364 m
.78807 .23128 L
s
.25244 .20116 m
.25488 .20822 L
s
.26627 .15712 m
.26891 .16414 L
s
.5 Mabswid
1 .643 .067 r
.31607 .17675 m .27055 .18844 L .27169 .1522 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27169 .1522 m .31702 .14005 L .31607 .17675 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77119 .15066 m
.77706 .15252 L
s
.25352 .20869 m
.25751 .21132 L
s
.77267 .15112 m
.77533 .23548 L
s
.5 Mabswid
.964 .612 .061 r
.72263 .13879 m .76883 .15068 L .76996 .18698 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76883 .15068 m .72263 .13879 L .72171 .10237 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.25488 .20822 m
.25751 .21132 L
s
.78866 .20761 m
.78946 .23172 L
s
.25751 .21132 m
.26173 .20996 L
s
.76832 .15373 m
.77156 .16261 L
s
.76516 .14884 m
.76832 .15373 L
s
.26643 .19657 m
.26681 .18455 L
s
.27971 .149 m
.281 .15653 L
s
.27922 .16496 m
.27971 .149 L
s
.76209 .14795 m
.76516 .14884 L
s
.26801 .19211 m
.26827 .1841 L
s
.5 Mabswid
1 .643 .067 r
.31511 .2138 m .26939 .22501 L .27055 .18844 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.27055 .18844 m .31607 .17675 L .31511 .2138 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.78973 .23979 m
.79084 .23217 L
s
.26173 .20996 m
.26472 .20505 L
s
.26472 .20505 m
.26643 .19657 L
s
.2663 .20058 m
.26801 .19211 L
s
.27922 .16496 m
.281 .15653 L
s
.281 .15653 m
.28266 .15209 L
s
.28266 .15209 m
.28588 .14722 L
s
.26472 .20505 m
.2663 .20058 L
s
.78807 .23128 m
.78973 .23979 L
s
.28588 .14722 m
.29221 .14548 L
s
.5 Mabswid
.964 .612 .061 r
.72356 .17554 m .76996 .18698 L .77109 .22361 L p F P
.678 .678 .678 r
s
.964 .612 .061 r
.76996 .18698 m .72356 .17554 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.75752 .15063 m
.76209 .14795 L
s
.75909 .15106 m
.76209 .14795 L
s
.75618 .1582 m
.75909 .15106 L
s
.75458 .15777 m
.75752 .15063 L
s
.76981 .20183 m
.77257 .19465 L
s
.29221 .14548 m
.29532 .14863 L
s
.75493 .16982 m
.75618 .1582 L
s
.5 Mabswid
1 .643 .067 r
.31414 .25119 m .26823 .26192 L .26939 .22501 L p F P
.678 .678 .678 r
s
1 .643 .067 r
.26939 .22501 m .31511 .2138 L .31414 .25119 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27848 .18903 m
.28014 .18458 L
s
.27824 .19709 m
.27848 .18903 L
s
.28014 .18458 m
.28336 .1797 L
s
.75333 .1694 m
.75458 .15777 L
s
.5 Mabswid
1 .65 .067 r
.36929 .13037 m .31702 .14005 L .31796 .10368 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31796 .10368 m .37 .09364 L .36929 .13037 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27836 .19306 m
.28002 .1886 L
s
.28002 .1886 m
.28324 .18372 L
s
.28336 .1797 m
.29151 .16954 L
s
.29532 .14863 m
.29683 .15222 L
s
.27824 .19709 m
.27965 .2007 L
s
.28324 .18372 m
.29139 .17357 L
s
.29648 .16428 m
.29683 .15222 L
s
.5 Mabswid
.964 .612 .061 r
.72449 .21264 m .77109 .22361 L .77224 .26058 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.77119 .15066 m
.77383 .23506 L
s
.5 Mabswid
.964 .612 .061 r
.77109 .22361 m .72449 .21264 L .72356 .17554 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.76688 .20502 m
.76981 .20183 L
s
.73272 .14041 m
.7445 .14323 L
s
.75493 .16982 m
.75517 .17787 L
s
.5 Mabswid
.988 .628 .063 r
.66896 .09266 m .72171 .10237 L .72263 .13879 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.27965 .2007 m
.28264 .2039 L
s
.29151 .16954 m
.29486 .16469 L
s
.76378 .20418 m
.76688 .20502 L
s
.75333 .1694 m
.75356 .17746 L
s
.29486 .16469 m
.2966 .16026 L
s
.29139 .17357 m
.29474 .16871 L
s
.75517 .17787 m
.75712 .19039 L
s
.76928 .23381 m
.77533 .23548 L
s
.29474 .16871 m
.29648 .16428 L
s
.7395 .14201 m
.74105 .19858 L
s
.76053 .1993 m
.76378 .20418 L
s
.75895 .19889 m
.76378 .20418 L
s
.75356 .17746 m
.75552 .18998 L
s
.28264 .2039 m
.28897 .20226 L
s
.73782 .1416 m
.73936 .1982 L
s
.75712 .19039 m
.76053 .1993 L
s
.75552 .18998 m
.75895 .19889 L
s
.31038 .14094 m
.31198 .14457 L
s
.30857 .14536 m
.31038 .14094 L
s
.30857 .14536 m
.31016 .14898 L
s
.5 Mabswid
1 .65 .067 r
.36858 .16744 m .31607 .17675 L .31702 .14005 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31702 .14005 m .36929 .13037 L .36858 .16744 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.31016 .14898 m
.31198 .14457 L
s
.29405 .19294 m
.29591 .18445 L
s
.29545 .20066 m
.29591 .18445 L
s
.28897 .20226 m
.29231 .1974 L
s
.29231 .1974 m
.29405 .19294 L
s
.29405 .19294 m
.29545 .20066 L
s
.5 Mabswid
.964 .612 .061 r
.77224 .26058 m .72544 .25008 L .72449 .21264 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.66965 .12943 m .72263 .13879 L .72356 .17554 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72263 .13879 m .66965 .12943 L .66896 .09266 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71336 .13628 m
.7258 .13886 L
s
.30962 .16916 m
.31004 .21764 L
s
.3066 .21837 m
.30962 .16916 L
s
.5 Mabswid
1 .65 .067 r
.36785 .20487 m .31511 .2138 L .31607 .17675 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.31654 .17701 m
.31655 .17667 L
s
.5 Mabswid
1 .65 .067 r
.31607 .17675 m .36858 .16744 L .36785 .20487 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73422 .19708 m
.74105 .19858 L
s
.30832 .21801 m
.30897 .19351 L
s
.5 Mabswid
.988 .628 .063 r
.67034 .16654 m .72356 .17554 L .72449 .21264 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.71953 .1721 m
.7196 .17487 L
s
.5 Mabswid
.988 .628 .063 r
.72356 .17554 m .67034 .16654 L .66965 .12943 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .36929 .13037 L .37 .09364 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.37 .09364 m .42736 .08661 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61111 .08601 m .66896 .09266 L .66965 .12943 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73991 .21862 m
.74172 .22308 L
s
.73831 .22234 m
.73991 .21862 L
s
.74013 .22681 m
.74172 .22308 L
s
.69876 .13757 m
.70266 .14634 L
s
.69303 .13254 m
.69876 .13757 L
s
.3066 .21837 m
.3081 .22621 L
s
.68924 .1319 m
.69303 .13254 L
s
.5 Mabswid
1 .65 .067 r
.36712 .24264 m .31414 .25119 L .31511 .2138 L p F P
.678 .678 .678 r
s
1 .65 .067 r
.31511 .2138 m .36785 .20487 L .36712 .24264 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.73831 .22234 m
.74013 .22681 L
s
.3081 .22621 m
.31004 .21764 L
s
.6855 .13534 m
.68924 .1319 L
s
.68357 .13503 m
.68924 .1319 L
s
.5 Mabswid
.988 .628 .063 r
.67103 .204 m .72449 .21264 L .72544 .25008 L p F P
.678 .678 .678 r
s
.988 .628 .063 r
.72449 .21264 m .67103 .204 L .67034 .16654 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.72052 .13774 m
.72265 .22329 L
s
.71874 .13737 m
.72086 .22295 L
s
.68181 .14287 m
.6855 .13534 L
s
.5 Mabswid
1 .652 .067 r
.42646 .16092 m .36858 .16744 L .36929 .13037 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36929 .13037 m .42692 .12359 L .42646 .16092 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67987 .14257 m
.68357 .13503 L
s
.70135 .17044 m
.70331 .17484 L
s
.69957 .1742 m
.70135 .17044 L
s
.5 Mabswid
1 .638 .064 r
.61152 .12301 m .66965 .12943 L .67034 .16654 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.66965 .12943 m .61152 .12301 L .61111 .08601 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.70331 .17484 m
.7034 .17893 L
s
.68011 .15481 m
.68181 .14287 L
s
.69984 .18649 m
.7034 .17893 L
s
.69957 .1742 m
.70154 .17861 L
s
.67816 .15452 m
.67987 .14257 L
s
.66191 .12784 m
.66985 .12893 L
s
.255 .412 .882 r
.66949 .16728 m
.67035 .1672 L
s
.5 Mabswid
1 .652 .067 r
.48795 .12002 m .42692 .12359 L .42736 .08661 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42736 .08661 m .48811 .08291 L .48795 .12002 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69616 .18998 m
.69984 .18649 L
s
.68011 .15481 m
.68027 .16299 L
s
.5 Mabswid
1 .645 .065 r
.5501 .0827 m .61111 .08601 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.67816 .15452 m
.67832 .16271 L
s
.5 Mabswid
.988 .628 .063 r
.72544 .25008 m .67173 .24181 L .67103 .204 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.71542 .22196 m
.72265 .22329 L
s
.65798 .1314 m
.66213 .14008 L
s
.65186 .12657 m
.65798 .1314 L
s
.68027 .16299 m
.68246 .17558 L
s
.5 Mabswid
1 .652 .067 r
.42601 .19861 m .36785 .20487 L .36858 .16744 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36858 .16744 m .42646 .16092 L .42601 .19861 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.69044 .18907 m
.69616 .18998 L
s
.6478 .12609 m
.65186 .12657 L
s
.255 .412 .882 r
.66759 .16989 m
.66949 .16728 L
s
0 0 0 r
.67832 .16271 m
.68052 .17529 L
s
.5 Mabswid
1 .638 .064 r
.61194 .16036 m .67034 .16654 L .67103 .204 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.66551 .16297 m
.66557 .16603 L
s
.66749 .16443 m
.66753 .16624 L
s
.5 Mabswid
1 .638 .064 r
.67034 .16654 m .61194 .16036 L .61152 .12301 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.66391 .12811 m
.66493 .18551 L
s
.64172 .12947 m
.6478 .12609 L
s
.64377 .1297 m
.6478 .12609 L
s
.68246 .17558 m
.6865 .18437 L
s
.6865 .18437 m
.69044 .18907 L
s
.68457 .18409 m
.69044 .18907 L
s
.68052 .17529 m
.68457 .18409 L
s
.64185 .13765 m
.64377 .1297 L
s
.63979 .13743 m
.64172 .12947 L
s
.5 Mabswid
1 .65 .066 r
.55023 .11982 m .48795 .12002 L .48811 .08291 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48811 .08291 m .5501 .0827 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61152 .12301 m .55023 .11982 L .5501 .0827 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48778 .15749 m .42646 .16092 L .42692 .12359 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42692 .12359 m .48795 .12002 L .48778 .15749 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55023 .11982 m .61152 .12301 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.62089 .12332 m
.6212 .14794 L
s
.5918 .1212 m
.62089 .12332 L
s
.5868 .12084 m
.5918 .1212 L
s
.61879 .12314 m
.6212 .14794 L
s
.5 Mabswid
1 .652 .067 r
.42555 .23665 m .36712 .24264 L .36785 .20487 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.36785 .20487 m .42601 .19861 L .42555 .23665 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.61237 .19807 m .67103 .204 L .67173 .24181 L p F P
.678 .678 .678 r
s
1 .638 .064 r
.67103 .204 m .61237 .19807 L .61194 .16036 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.65686 .18453 m
.66493 .18551 L
s
.63979 .13743 m
.64046 .18274 L
s
.64185 .13765 m
.64253 .18295 L
s
.66191 .12784 m
.66292 .18526 L
s
.5 Mabswid
1 .65 .066 r
.55036 .1573 m .48778 .15749 L .48795 .12002 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48795 .12002 m .55023 .11982 L .55036 .1573 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61194 .16036 m .55036 .1573 L .55023 .11982 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.48762 .19531 m .42601 .19861 L .42646 .16092 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42646 .16092 m .48778 .15749 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55036 .1573 m .61194 .16036 L .61237 .19807 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.63422 .18212 m
.64253 .18295 L
s
.255 .412 .882 r
.48821 .15749 m
.48969 .15823 L
s
.5 Mabswid
1 .638 .064 r
.67173 .24181 m .61279 .23614 L .61237 .19807 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49302 .15747 m
.49403 .15812 L
s
0 0 0 r
.59582 .1667 m
.6087 .16757 L
s
.255 .412 .882 r
.49402 .16102 m
.48969 .15823 L
s
.49619 .16097 m
.49403 .15812 L
s
.51361 .15781 m
.51143 .16073 L
s
0 0 0 r
.61984 .20999 m
.62166 .18515 L
s
.62166 .18515 m
.62197 .21016 L
s
.5 Mabswid
1 .65 .066 r
.55049 .19513 m .48762 .19531 L .48778 .15749 L p F P
.678 .678 .678 r
s
.255 .412 .882 r
1 Mabswid
.49619 .16253 m
.49619 .16097 L
s
.49402 .16102 m
.49431 .16141 L
s
.5 Mabswid
1 .65 .066 r
.48778 .15749 m .55036 .1573 L .55049 .19513 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61237 .19807 m .55049 .19513 L .55036 .1573 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.60853 .15103 m
.60888 .18417 L
s
.5 Mabswid
1 .652 .067 r
.48745 .23349 m .42555 .23665 L .42601 .19861 L p F P
.678 .678 .678 r
s
1 .652 .067 r
.42601 .19861 m .48762 .19531 L .48745 .23349 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.55049 .19513 m .61237 .19807 L .61279 .23614 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.55063 .23332 m .48745 .23349 L .48762 .19531 L p F P
.678 .678 .678 r
s
1 .65 .066 r
.48762 .19531 m .55049 .19513 L .55063 .23332 L p F P
.678 .678 .678 r
s
1 .645 .065 r
.61279 .23614 m .55063 .23332 L .55049 .19513 L p F P
.678 .678 .678 r
s
0 0 0 r
1 Mabswid
.5875 .20789 m
.59256 .20823 L
s
.59256 .20823 m
.62197 .21016 L
s
.59326 .12122 m
.59403 .20825 L
s
.5954 .12136 m
.5962 .20837 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 229.438},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0000iB000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003/0;3PiRh0[Jf]f@2`h>H10?ooo`00g@2`h>H?0:f][@L0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU40050?nU40l0[Jf]bP2`h>H10?ooo`00
dP2`h>H;0:f][AH0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400D0?nU40`0[Jf]
_P2`h>H10?ooo`00b`2`h>H70:f][@<0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa000P3oXa0:0:f][K@0/>3V0@3o
ool00<<0/>3V202][Jd:0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ00
0`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@00`0oj<@2P2][JfZ0;3PiP40oooo002l0;3P
iPL0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU
403oYA006`3oYA000`2][Jd0oj<@0?nS400F0?nS40L0[Jf]X`2`h>H10?ooo`00]P2`h>H60:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01/0
ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP40050:f][Ih0/>3V0@3oool00;40/>3V
1@2][Jd20?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@
0?bP40050?bP40D0[Jf]V@2`h>H10?ooo`00[02`h>H50:f][@L0ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3o
YA000`2][Jd0oj<@0?nS400J0?nS40030:f][@3lX100o:0@00X0o:0@1P2][JfC0;3PiP40oooo002V
0;3PiPH0[Jf]303oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]
0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400K0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]
0?bP403lX100403lX1050:f][Hh0/>3V0@3oool00:40/>3V1@2][JdB0?nV4@030:f][@3oYQ40ojHA
01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@
01/0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400E0?bP40@0[Jf]RP2`h>H10?oo
o`00W@2`h>H40:f][AL0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@03
0:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA006`3oYA000`2][Jd0oj<@0?nS400J0?nS4003
0:f][@3lX100o:0@01L0o:0@00<0[Jf]0?JL3`2][Jd00`2][Jf60;3PiP40oooo002I0;3PiP@0[Jf]
00<0oj@A0:f][@3oYQ40603oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`030?JL3`@0[Jf]PP2`h>H10?ooo`00U@2`
h>H40:f][@D0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3o
YQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3o
Xa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`070?JL3`@0[Jf]OP2`
h>H10?ooo`00TP2`h>H30:f][@T0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0;
0?JL3`@0[Jf]NP2`h>H10?ooo`00SP2`h>H40:f][@`0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2]
[Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3lX1000`2]
[Jd0mY`?0?JL3`0?0?JL3`@0[Jf]MP2`h>H10?ooo`00RP2`h>H40:f][A00oj@A00<0[Jf]0?nV4@3o
YQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403o
YQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403l
X1005`3lX1000`2][Jd0mY`?0?JL3`0C0?JL3`<0[Jf]L`2`h>H10?ooo`00Q`2`h>H30:f][A@0oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@
00<0[Jf]0?bP403lX1005`3lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0[Jf]0080[Jf]
L02`h>H10?ooo`00Q02`h>H30:f][@030?bP402][Jd0oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3o
YQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@01T0oj<@00<0[Jf]0?bP403lX1005`3l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0080k9H>0P2][Je^0;3PiP40oooo0022
0;3PiP80[Jf]103lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0D0?nV4CH0[Jf]0P3oYA0:000000<0ojD@00<0[Jf]
0?nS403oXa006@3oXa000`2][Jd0o:0@0?bP400G0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]
0>bF3P3/UPh0103/UPh30:f][F/0/>3V0@3oool007l0/>3V0`2][Jd60?bP40030:f][@3oY140oj@A
01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
00D0ojHA3`2][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA003@3oYA050:f]
[@8000001@2][Jd8000001L0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL
3`030:f][@3/UPh0k9H>00L0k9H>0`2][JeX0;3PiP40oooo001l0;3PiP<0[Jf]2@3lX1000`2][Jd0
oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][AH0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400B0?nU40800000203oYA000`2][Jd0
oj<@0?nS4002000000T0[Jf]3P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh02P3/UPh20:f][FH0/>3V0@3oool007X0/>3V0P2][Jd<0?bP40030:f]
[@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0<0?nV4@X0[Jf]
103oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00
4P3oYA02000000P0ojD@00<0[Jf]0?nS403oXa000P0000090?nS40@0[Jf]0`0000030:f][@@0oj<@
00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0C0?JL3`030:f][@3/UPh0k9H>00`0k9H>
0`2][JeS0;3PiP40oooo001g0;3PiP<0[Jf]3P3lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ406`3o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@0180ojD@0P0000080?nU40030:f][@3o
Xa00oj<@008000002`3oXa02000000<0oj<@0P0000000`3oXa00[Jf]00000004000000030:f][@3l
X100o:0@01H0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P80[Jf]H@2`
h>H10?ooo`00M@2`h>H20:f][A40o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0E
0?nV4@L0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]
0?nU403oYA004P3oYA02000000P0ojD@00<0[Jf]0?nS403oXa000P00000:0?nS408000001P3oXa00
1P000000oj<@000000000000oj<@0:f][@80o:0@1P2][JdB0?bP40030:f][@3fW0l0mY`?01<0mY`?
00<0[Jf]0>bF3P3/UPh0403/UPh30:f][El0/>3V0@3oool007<0/>3V0`2][JdB0?bP40030:f][@3o
Y140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ40403oYQ450:f][@80ojHA00<0[Jf]0?nV4@3oYQ406P3o
YQ400`2][Jd0ojHA0?nV4@0K0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA004P3o
YA02000000P0ojD@00<0[Jf]0?nS403oXa000P00000:0?nS408000001P3oXa001P000000oj<@0000
00000000oj<@0:f][@P0o:0@100000000`2][Jd0o:0@0?bP400;0?bP40030:f][@3fW0l0mY`?01<0
mY`?00<0[Jf]0>bF3P3/UPh0403/UPh00`2][Jd0fhX=0=^:3@020:f][Ed0/>3V0@3oool00740/>3V
0P2][Jd20>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY140503oY1400`2][Jd0ojHA
0?nV4@0;0?nV4@D0[Jf]1`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA
00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400B0?nU40800000203oYA000`2][Jd0oj<@
0?nS4002000000T0oj<@0P0000080?nS40<0000000<0oj<@0:f][@3lX1001@3lX103000000<0o:0@
00<000000:f][@2][Jd00`2][Jd80?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]0>bF3P3/UPh0
3`3/UPh00`2][Jd0fhX=0=^:3@020=^:3@80[Jf]F`2`h>H10?ooo`00K`2`h>H20:f][@@0kiP@00<0
[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3oYQ40ojHA00D0ojHA1P2]
[Jd<0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ406`3oYQ400`2][Jd0ojH@0?nV
400L0?nV40030:f][@3oYA00ojD@0180ojD@0P0000080?nU40050:f][@3oXa00oj<@0?nS40000000
2@3oXa02000000P0oj<@0`0000000`3oXa00[Jf]0?bP40050?bP40030000003lX100o:0@00@0o:0@
00<000000?bP403lX1000P3lX1030:f][@@0000000<0o:0@0:f][@3fW0l05@3fW0l00`2][Jd0k9H>
0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00@0fhX=0P2][JeI0;3PiP40oooo001^0;3PiP030:f][@3_
V100kiP@00@0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@0D0?nT4@030:f][@3o
YQ40ojHA00D0[Jf]4P3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400B0?nU40800000203oYA001@2][Jd0oj<@0?nS
403oXa00000000T0oj<@0P0000090?nS4080000000<0oj<@0:f][@3lX100103lX102000000L0o:0@
00<000000?bP403lX1001`3lX104000001D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=
0=^:3@060=^:3@80[Jf]E`2`h>H10?ooo`00K02`h>H20:f][@L0kiP@00<0[Jf]0?bP403lX1003`3l
X1000`2][Jd0oj@A0?nT4@0A0?nT4@030000003oY140[Jf]00<0[Jf]5`3oYQ400`2][Jd0ojHA0?nV
4@0J0?nV4@030:f][@3oYQ40ojHA01/0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU
400B0?nU40800000203oYA001@2][Jd0oj<@0?nS403oXa00000000T0oj<@0P0000090?nS40800000
00<0oj<@0:f][@3lX100103lX1000`000000o:0@0?bP40060?bP40030000003lX100o:0@00L0o:0@
0P0000000`2][Jd0mY`?0:f][@020:f][@<000003`3fW0l00`2][Jd0k9H>0>bF3P0?0>bF3P030:f]
[@3KRPd0fhX=00P0fhX=0P2][JeE0;3PiP40oooo001Z0;3PiP80[Jf]2@3_V1000`2][Jd0o:0@0?bP
400?0?bP40030:f][@3oY140oj@A00l0oj@A00H0[Jf]000000000000[Jf]0?nT4@2][JdI0?nV4@03
0:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV4003
0:f][@3oYA00ojD@0180ojD@0P0000080?nU40050:f][@3oXa00oj<@0?nS400000002@3oXa020000
00T0oj<@0P0000000`3oXa00[Jf]0?bP40040?bP40030000003lX100o:0@00L0o:0@00<000000?bP
403lX1001P3lX102000000030:f][@3fW0l0mY`?00<0mY`?00<0[Jf]0000000000000`00000;0?JL
3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd02P3KRPd20:f][E<0/>3V0@3oool006P0
/>3V0P2][Jd;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3oY1401`3oY14200000080
oj@A102][Jd00`3oY1400000000000020?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3o
YQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403o
YA004P3oYA02000000P0ojD@00D0[Jf]0?nS403oXa00oj<@000000090?nS408000002@3oXa020000
00030?nS402][Jd0o:0@00@0o:0@00<000000?bP403lX1001`3lX1000`000000o:0@0?bP40060?bP
4080000000<0[Jf]0?JL3`3fW0l0103fW0l2000000030?JL3`2][Jd0[Jf]0080[Jf]2@3fW0l00`2]
[Jd0k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=00<0[Jf]0;3PiP2`h>H0D02`h>H10?oo
o`00I`2`h>H00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00l0o:0@00<0[Jf]0?nT4@3o
Y140103oY143000000040:f][@000000[Jf]0:f][@D0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA
01L0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA004P3oYA02000000P0ojD@00D0[Jf]0?nS403oXa00oj<@00000009
0?nS408000002@3oXa02000000030?nS402][Jd0o:0@00@0o:0@00<000000?bP403lX100203lX100
0`000000o:0@0?bP40050?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l2000000D0mY`?102][Jd5
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd0303KRPd20:f][E40/>3V0@3oool0
06H0/>3V0P2][Jd=0>nH40030:f][@3lX100o:0@00l0o:0@00P0[Jf]0?nT4@3oY140oj@A0000003o
Y140[Jf]00000080[Jf]0P3oY1400`000000oj@A0?nT4@050?nT4@040000003oY140oj@A0:f][AT0
ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0
ojH@00<0[Jf]0?nU403oYA004P3oYA02000000P0ojD@00D0[Jf]0?nS403oXa00oj<@000000090?nS
408000002@3oXa0200000080oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP4080000000<0[Jf]
0?JL3`3fW0l0103fW0l2000000T0mY`?00H0[Jf]00000000000000000?JL3`2][JdB0>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2][Jd0D02`h>H10?ooo`00I@2`h>H00`2][Jd0dhL>0:f]
[@0=0>nH40030:f][@3lX100o:0@00l0o:0@00L0[Jf]0?nT4@2][Jd0[Jf]0000002][Jd0000000D0
oj@A00<000000?nT4@3oY140203oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@0180
ojD@0P0000060?nU40030000003oYA00[Jf]00d0oj<@0P0000090?nS408000000P3oXa00102][Jd0
o:0@0?bP403lX10200000180o:0@0P0000000`2][Jd0mY`?0?JL3`040?JL3`800000203fW0l20000
00<0mY`?00@000000:f][@0000000000403/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@040:f][@2iM@/0
^GD;0:f][Dl0/>3V0@3oool006@0/>3V00@0[Jf]0=>73P3CQ`h0[Jf]3@3_V1000`2][Jd0o:0@0?bP
400>0?bP40<0[Jf]0P3oY1400`000000oj@A000000060?nT4@030000003oY140oj@A00L0oj@A00<0
[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0
[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400B0?nU408000001P3oYA000`000000ojD@0:f]
[@0=0?nS408000002@3oXa0200000080oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP40800000
00<0[Jf]0?JL3`3fW0l0103fW0l2000000P0mY`?0P0000030?JL3`030000002][Jd0000000<00000
3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2][Jd0CP2`h>H10?ooo`00
H`2`h>H01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP403lX1002@3lX10300000080
[Jf]00<0o:0@0:f][@3oY1400P3oY142000000L0oj@A00<000000?nT4@3oY1401`3oY1400`2][Jd0
ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0
ojH@0?nV400L0?nV40030:f][@3oYA00ojD@0180ojD@0P0000060?nU40030000003oYA00[Jf]00d0
oj<@0P0000090?nS408000000P3oXa00102][Jd0o:0@0?bP403lX10200000180o:0@0P0000000`2]
[Jd0mY`?0?JL3`040?JL3`8000001`3fW0l2000000D0mY`?0`0000020>bF3P80[Jf]303/UPh00`2]
[Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;0080^GD;0P2][Je<0;3PiP40oooo001R0;3PiP03
0:f][@3CQ`h0dhL>0080dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40080?bP4080
00000P2][Jd2000000030?bP402][Jd0oj@A0080oj@A0P0000070?nT4@030000003oY140oj@A00L0
oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01D0
ojHA;P2][Jd=0?nU408000001P3oYA000`000000ojD@0:f][@0=0?nS408000002@3oXa0200000080
oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l20000
00L0mY`?0P0000050?JL3`<00000103/UPh20:f][@030000003/UPh0k9H>00L0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`040;Ue2`030:f][@2`h>H0/>3V04T0/>3V0@3oool00640
/>3V00<0[Jf]0=>73P3CQ`h00`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00L0
o:0@00<0[Jf]0000003lX1000`3lX1000`000000o:0@0:f][@030?nT4@8000001`3oY1400`000000
oj@A0?nT4@060?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0
ojHA0?nV4@050?nV4A00[Jf]1`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@00D0
ojD@3@2][Jd2000000030:f][@3oYA00ojD@00<0ojD@00<000000?nU402][Jd03@3oXa02000000T0
oj<@0P0000020?nS40040:f][@3lX100o:0@0?bP408000004P3lX102000000030:f][@3fW0l0mY`?
00@0mY`?0P0000070?JL3`8000001@3fW0l3000000D0k9H>0P0000030:f][@H0k9H>00<0[Jf]0=^:
3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`050;Ue2`030:f][@2`h>H0/>3V04P0/>3V0@3oool00600
/>3V00<0[Jf]0=>73P3CQ`h0103CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@0080
o:0@0P0000030:f][@800000103lX1000`000000o:0@0:f][@030?nT4@030000003oY140oj@A00H0
oj@A00<000000?nT4@3oY1401P3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01D0
ojHA302][JdG0?nV4@040:f][@3oYQ00ojH@045YhA/0ojH@00<0[Jf]0?nU403oYA004P3oYA020000
00030?nU402][Jd0[Jf]00<0[Jf]00<000000:f][@2][Jd0102][Jd90?nS408000002@3oXa020000
0080oj<@00@0[Jf]0?bP403lX100o:0@0P00000B0?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l2
000000L0mY`?0P0000050?JL3`030:f][@000000000000D0k9H>00<000000>bF3P0000000P3/UPh2
0:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`030:f][@2`h>H0
/>3V04L0/>3V0@3oool005l0/>3V00<0[Jf]0=>73P3CQ`h01@3CQ`h00`2][Jd0kiP@0>nH400;0>nH
40030:f][@3lX100o:0@008000000P2][Jd30?bP40030000003lX100o:0@00@0o:0@00<000000:f]
[@3oY1400P3oY1400`000000oj@A0?nT4@050?nT4@800000203oY1400`2][Jd0ojHA0?nV4@0H0?nV
4@030:f][@3oYQ40ojHA00`0ojHA2@2][Jd40?nV4@030:f][@3oYQ40ojHA01`0ojHA00D0[Jf]0?nV
403oYQ00ojH@045Yh@0J0?nV40030:f][@3oYA00ojD@0180ojD@0P0000060?nU40030000003oYA00
[Jf]00@0oj<@2@2][Jd2000000T0oj<@0P0000020?nS40040:f][@3lX100o:0@0?bP408000004P3l
X102000000030:f][@3fW0l0mY`?00@0mY`?0P0000070?JL3`8000001@3fW0l00`2][Jd000000000
00060>bF3P030000003/UPh0k9H>00<0k9H>0`2][Jd00`3/UPh0[Jf]0=^:3@0<0=^:3@030:f][@2i
M@/0^GD;00L0^GD;00<0[Jf]0;3PiP2`h>H0AP2`h>H10?ooo`00GP2`h>H00`2][Jd0dhL>0=>73P06
0=>73P030:f][@3_V100kiP@00/0kiP@00<0[Jf]0000002][Jd00P0000050?bP40030000003lX100
o:0@00@0o:0@00<000000:f][@3oY1400P3oY1400`000000oj@A0?nT4@050?nT4@800000203oY140
0`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jd=0?nV4@030:f][@3oYQ40
ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400B0?nU408000001P3oYA00
0`000000ojD@0:f][@0=0?nS408000002@2][Jd200000080oj<@00@0[Jf]0?bP403lX100o:0@0P00
000B0?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l2000000H0mY`?0P0000060?JL3`030:f][@00
0000000000H0k9H>00<000000>bF3P3/UPh01P3/UPh20:f][@d0fhX=00<0[Jf]0;Ue2`2iM@/01`2i
M@/20:f][DL0/>3V0@3oool005d0/>3V0P2][Jd80=>73P030:f][@3_V100kiP@00/0kiP@00<00000
0:f][@0000000P0000040?bP40030000003lX100o:0@00H0o:0@00<0[Jf]0?nT4@3oY140203oY142
000000T0oj@A00<0[Jf]0?nV4@3oYQ405P3oYQ470:f][AL0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@200000000`3oYA00[Jf]0?nS400<
0?nS408000002@3oXa02000000H0[Jf]0P00000B0?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l2
000000H0mY`?0P0000060?JL3`030:f][@00000000000100k9H>0`2][Jd;0=^:3@030:f][@2iM@/0
^GD;00L0^GD;0P2][Je70;3PiP40oooo001M0;3PiP80[Jf]203CQ`h00`2][Jd0kiP@0>nH40090>nH
40040:f][@000000[Jf]0?bP40<00000103lX1000`000000o:0@0?bP40060?bP40030:f][@3oY140
oj@A00L0oj@A00<000000?nT4@0000001P3oY14010000000oj@A0?nT4@2][JdB0?nV4@H0[Jf]0P3o
YQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703o
YQ000`2][Jd0ojD@0?nU400C0?nU408000001@3oYA000`000000ojD@0:f][@0=0?nS408000002@3o
Xa0200000080oj<@00@0[Jf]0?bP403lX100o:0@0P0000040:f][@h0o:0@0P0000000`2][Jd0mY`?
0?JL3`040?JL3`8000001P3fW0l2000000H0mY`?00<0[Jf]000000000000403/UPh00`2][Jd0fhX=
0=^:3@020:f][@T0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0R5H70:f][@160;3PiP40oooo
001L0;3PiP030:f][@2GH0/0[Jf]00P0dhL>00<0[Jf]0>nH403_V1001`3_V1020:f][@040000003_
V100[Jf]0?bP40<00000103lX1000`000000o:0@0?bP40060?bP40030:f][@3oY140oj@A00H0oj@A
00<000000?nT4@0000001`3oY14010000000oj@A0?nT4@2][Jd=0?nV4@D0[Jf]203oYQ400`2][Jd0
ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0
ojD@0?nU400C0?nU408000001@3oYA000`000000ojD@0:f][@0=0?nS408000002@3oXa0200000080
oj<@00<0[Jf]0?bP403lX1000P3lX102000000<0o:0@1@2][Jd00`000000[Jf]0?bP40060?bP4080
000000<0[Jf]0?JL3`3fW0l0103fW0l2000000H0mY`?0P0000060?JL3`030:f][@00000000000100
k9H>00<0[Jf]0=^:3@3KRPd00P3KRPd20:f][@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/00`2][Jd0
R5H70:f][@160;3PiP40oooo001K0;3PiP040:f][@2GH0/0Uf0;0:f][@P0dhL>00<0[Jf]0>nH403_
V1001@3_V1020:f][@80kiP@00<000000>nH402][Jd00P3lX102000000@0o:0@00<000000?bP403l
X1001P3lX1000`2][Jd0oj@A0?nT4@060?nT4@800000203oY14010000000oj@A0?nT4@2][Jd80?nV
4@D0[Jf]3@3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV
403oYQ00703oYQ000`2][Jd0ojD@0?nU400C0?nU408000001@3oYA000`000000ojD@0:f][@0=0?nS
408000002@3oXa0200000080oj<@00<0[Jf]0?bP403lX1000P3lX102000000L0o:0@0P0000000`3l
X100[Jf]0:f][@040:f][@040?bP4000000000000:f][@L0mY`?0P0000050?JL3`8000001P3fW0l0
0`2][Jd000000000000@0>bF3P030:f][@3KRPd0fhX=00@0fhX=00<0[Jf]0=^:3@3KRPd0103KRPd0
0`2][Jd0^GD;0;Ue2`070;Ue2`040:f][@28EPL0R5H70:f][DD0/>3V0@3oool005/0/>3V00@0[Jf]
09MP2`2GH0/0[Jf]203CQ`h01@2][Jd0kiP@0>nH403_V10000000080kiP@00D0[Jf]0>nH403_V100
kiP@000000020>nH40030:f][@3lX100o:0@00800000103lX1000`000000o:0@0?bP40060?bP4003
0:f][@3oY140oj@A00D0oj@A0P0000090?nT4@040000003oY140oj@A0:f][@80ojHA1P2][JdB0?nV
4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV
40030:f][@3oYA00ojD@01<0ojD@0P0000050?nU40030000003oYA00[Jf]00d0oj<@0P0000090?nS
408000000P3oXa000`2][Jd0o:0@0?bP40020?bP408000001`3lX1000`000000o:0@000000060?bP
40030:f][@00000000000080[Jf]1P3fW0l2000000D0mY`?0P0000060?JL3`030:f][@0000000000
0100k9H>00<0[Jf]0=^:3@3KRPd01@3KRPd20:f][@@0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2]
[Jd0R5H708QF1`28EPL0[Jf]04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@08
0=>73P070:f][@3_V100kiP@0000003_V10000000:f][@040>nH40040000003_V100kiP@0:f][@80
o:0@0P0000030?bP40030000003lX100o:0@00L0o:0@00<0[Jf]0?nT4@3oY140103oY1400`000000
oj@A000000090?nT4@030000003oY140[Jf]00<0[Jf]603oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400C0?nU4080
00001@3oYA000`000000ojD@0:f][@0=0?nS408000002@3oXa0200000080oj<@00<0[Jf]0?bP403l
X1000P3lX102000000L0o:0@00<000000?bP400000001`3lX102000000030:f][@3fW0l0[Jf]00<0
[Jf]0P3fW0l2000000D0mY`?0P0000060?JL3`030:f][@00000000000100k9H>00<0[Jf]0=^:3@3K
RPd01`3KRPd20:f][@80fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/01@2][Jd0R5H708QF1`28EPL0[Jf]
04@0/>3V0@3oool005X0/>3V00D0[Jf]09MP2`2GH0/0Uf0;0:f][@080=>73P060:f][@3_V1000000
0000002][Jd00000103_V10200000080kiP@00<0[Jf]0?bP403lX1000P0000030?bP40030000003l
X100o:0@00L0o:0@00<0[Jf]0?nT4@3oY140103oY142000000P0oj@A0P2][Jd010000000[Jf]0?nT
4@2][JdJ0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@
0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@0P0000050?nU40030000003oYA00[Jf]00d0oj<@
0P0000090?nS408000000P3oXa000`2][Jd0o:0@0?bP40030?bP408000001`3lX102000000L0o:0@
0P0000000`2][Jd0mY`?0?JL3`030?JL3`80[Jf]0P0000050?JL3`8000001P3fW0l00`2][Jd00000
0000000@0>bF3P030:f][@3KRPd0fhX=00T0fhX=0`2][Jd90;Ue2`030:f][@28EPL0R5H70080R5H7
00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F@2`h>H00`2][Jd0Uf0;09MP2`0209MP2`030:f][@3C
Q`h0dhL>00H0dhL>0P2][Jd010000000kiP@0>nH400000040>nH408000000P3_V1000`2][Jd0o:0@
0?bP4002000000<0o:0@00<000000?bP403lX1001`3lX1000`2][Jd0oj@A0?nT4@030?nT4@800000
1@3oY1440:f][@80oj@A00@000000?nT4@3oY140[Jf]6P3oYQ400`2][Jd0ojHA0?nV4@0I0?nV4@03
0:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400C0?nU4080
00001@3oYA000`000000ojD@0:f][@0=0?nS408000002@3oXa0200000080oj<@00<0[Jf]0?bP403l
X1000`3lX102000000L0o:0@00<000000?bP403lX1001`3lX1000`000000[Jf]0?JL3`060?JL3`80
0000102][Jd00`3fW0l00000000000060?JL3`030:f][@00000000000100k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0@@2`h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00P0dhL>00@000000:f][@3_
V10000000`3_V10010000000kiP@0>nH403_V10200000080kiP@00<0[Jf]0?bP403lX1000P000003
0?bP40030000003lX100o:0@00L0o:0@00<0[Jf]0?nT4@3oY1400P3oY1400`000000oj@A00000002
0?nT4@<0[Jf]1P3oY14010000000oj@A0?nT4@2][JdJ0?nV4@030:f][@3oYQ40ojHA01T0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@0P00
00050?nU40030000003oYA00[Jf]00X0oj<@1@0000090?nS408000000P3oXa000`2][Jd0o:0@0?bP
40040?bP408000001P3lX1000`000000o:0@0?bP40070?bP408000001`3fW0l2000000@0mY`?00@0
[Jf]000000000000[Jf]1@3fW0l00`2][Jd00000000000060>bF3P030000003/UPh0k9H>00L0k9H>
00<0[Jf]0=^:3@3KRPd02`3KRPd20:f][@P0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V
0;3PiP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd01P3CQ`h200000080[Jf]
00<0kiP@0000003_V1000P3_V10010000000kiP@0>nH403_V102000000030>nH402][Jd0o:0@0080
o:0@00<000000?bP403lX1000P3lX1000`000000o:0@0?bP40040?bP40<0000000<0[Jf]0?nT4@3o
Y1400P3oY142000000<0[Jf]0P3oY1400`000000oj@A0?nT4@040?nT4@040000003oY140oj@A0:f]
[AX0ojHA00<0[Jf]0?nV4@3oYQ406@3oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA004`3oYA02000000D0ojD@00<000000?nU402][Jd0103oXa000`00
0000oj<@0?nS400>0?nS40D000000P3oXa000`2][Jd0o:0@0?bP40040?bP408000001@3lX1000`00
0000o:0@0?bP40080?bP408000001`3fW0l2000000H0mY`?00<000000?JL3`2][Jd00`2][Jd0103f
W0l0[Jf]0000000000060>bF3P030000003/UPh0k9H>00L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
102][Jd0^GD;0:f][@2][Jd60;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`h>H0@@2`
h>H10?ooo`00F@2`h>H01@2][Jd0Uf0;09MP2`2GH0/0[Jf]00D0dhL>0P000000102][Jd0dhL>0:f]
[@0000080>nH40040000003_V100kiP@0:f][@<0o:0@00<000000?bP403lX1000P3lX1000`000000
o:0@0?bP4004000000050?bP4000000000000:f][@3oY1400P2][Jd2000000H0oj@A00<000000?nT
4@3oY140103oY14010000000oj@A0?nT4@2][JdI0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]
0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@0P000007
0?nU40030:f][@3oXa00oj<@0080oj<@00<000000?nS403oXa005@3oXa000`2][Jd0o:0@0?bP4005
0?bP40800000103lX1000`000000o:0@0?bP40080?bP408000001`3fW0l2000000H0mY`?0P000004
0?JL3`80[Jf]0P0000060>bF3P030000003/UPh0k9H>00L0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd0
1@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00D0^GD;00<0[Jf]08QF1`28EPL00P28EPL00`2][Jd0/>3V0;3P
iP110;3PiP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00`3CQ`h010000000dhL>0:f]
[@0000020=>73P030:f][@000000kiP@00L0kiP@00@000000>nH403_V100[Jf]0`3lX1000`000000
o:0@0?bP40020?bP40<000001@3lX10200000080[Jf]0P3oY142000000D0oj@A0P0000060?nT4@04
0000003oY140oj@A0:f][AT0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0L0?nV
4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA004`3oYA02000000L0ojD@00<0[Jf]0?nS
403oXa000P3oXa000`000000oj<@0?nS400E0?nS40030:f][@3lX100o:0@00L0o:0@0P0000000`3l
X10000000?bP400:0?bP408000001`3fW0l2000000H0mY`?0P0000050?JL3`030:f][@0000000000
0080[Jf]103/UPh00`000000k9H>0>bF3P070>bF3P030:f][@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue
2`2iM@/00P2iM@/00`2][Jd0^GD;0;Ue2`020;Ue2`030:f][@28EPL0R5H70080R5H70P2][Je20;3P
iP40oooo001I0;3PiP050:f][@2GH0/0Uf0;09MP2`2][Jd00P3CQ`h01@000000dhL>0:f][@3CQ`h0
00000080dhL>00<0[Jf]0000003_V1001`3_V10010000000kiP@0>nH402][Jd30?bP40030000003l
X100o:0@0080o:0@00<000000?bP403lX1000`3lX1020:f][@80000000D0[Jf]0?nT4@3oY140oj@A
000000060?nT4@8000001P3oY14010000000oj@A0?nT4@2][JdI0?nV4@030:f][@3oYQ40ojHA01X0
ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0
ojD@0P0000070?nU40030:f][@3oXa00oj<@0080oj<@00<000000?nS403oXa005@3oXa000`2][Jd0
o:0@0?bP40090?bP408000002`3lX102000000L0mY`?0P0000060?JL3`8000001@3fW0l00`2][Jd0
0000000000020>bF3P80[Jf]0P3/UPh00`000000k9H>0>bF3P070>bF3P030:f][@3KRPd0fhX=00/0
fhX=00<0[Jf]0;Ue2`2iM@/00`2iM@/01@2][Jd0^GD;0;Ue2`2iM@/0[Jf]00@0R5H70P2][Je20;3P
iP40oooo001I0;3PiP060:f][@2GH0/0Uf0;09MP2`2][Jd0dhL>0P000000102][Jd0dhL>0=>73P00
00020=>73P030:f][@000000kiP@00L0kiP@00@000000>nH403_V100[Jf]0`3lX1000`000000o:0@
0?bP40020?bP40040000003lX100o:0@0?bP4080[Jf]0P3lX102000000050:f][@3oY140oj@A0?nT
4@0000001P3oY142000000H0oj@A00@000000?nT4@3oY140[Jf]6@3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400C
0?nU408000001`3oYA000`2][Jd0oj<@0?nS40020?nS40030000003oXa00oj<@01D0oj<@00<0[Jf]
0?bP403lX1005P3lX102000000L0mY`?0P0000060?JL3`8000001@3fW0l00`2][Jd0000000000004
0>bF3P80[Jf]00<000000>bF3P3/UPh01`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00@0^GD;0P2][Jd00`2iM@/0[Jf]08QF1`0308QF1`80[Jf]@P2`h>H10?ooo`00F@2`h>H0202]
[Jd0Uf0;09MP2`2GH0/0[Jf]0000002][Jd000000`3CQ`h01@000000dhL>0=>73P2][Jd0000000P0
kiP@00@000000>nH403_V100[Jf]0`3lX1000`000000o:0@0?bP40020?bP40040000002][Jd0[Jf]
0:f][@@0o:0@0P0000001@2][Jd0oj@A0?nT4@3oY140000000H0oj@A0P0000050?nT4@8000000P3o
Y1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ405@3o
YQ4^0:f][@h0ojD@0P0000070?nU40030:f][@3oXa00oj<@0080oj<@00<000000?nS403oXa005@3o
Xa000`2][Jd0o:0@0?bP400F0?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l2000000L0mY`?0P00
00040?JL3`040:f][@3/UPh00000000000D0k9H>00@000000:f][@2][Jd0[Jf]1P3/UPh00`2][Jd0
fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80[Jf]@P2`h>H10?ooo`00
F@2`h>H0202][Jd0Uf0;09MP2`2GH0/000000:f][@3CQ`h000000`3CQ`h010000000dhL>0=>73P00
00090>nH40040000003_V100kiP@0:f][@<0o:0@00<000000?bP403lX1000P2][Jd2000000H0o:0@
00<000000?bP402][Jd00`3oY1400`000000oj@A0?nT4@040?nT4@8000001@3oY14200000080oj@A
00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA00D0ojHA
402][Jd70?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA001@3oYA0>0:f][@800000
1`3oYA000`2][Jd0oj<@0?nS40020?nS40030000003oXa00oj<@01D0oj<@00<0[Jf]0?bP403lX100
5P3lX102000000030:f][@3fW0l0mY`?0080mY`?100000070?JL3`800000103fW0l0102][Jd00000
0000000000050>bF3P8000000P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0
^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H700<0R5H700<0[Jf]0;3PiP2`h>H0@02`h>H10?ooo`00
F@2`h>H00`2][Jd0Uf0;09MP2`0200000080dhL>00D000000=>73P3CQ`h0dhL>000000020=>73P03
0000003_V100kiP@00L0kiP@00@000000>nH403_V100[Jf]0`3lX1000`000000[Jf]0:f][@020?bP
408000001P3lX1000`000000o:0@0:f][@030?nT4@030000003oY140oj@A00<0oj@A00<000000?nT
4@0000001@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0F0?nV
4@`0[Jf]5`3oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@0P00000;0:f]
[@8000005`3oXa000`2][Jd0o:0@0?bP400F0?bP4080000000<0[Jf]0?JL3`3fW0l0103fW0l20000
00P0mY`?0P0000030?JL3`040:f][@0000000000000000D0k9H>0P0000040>bF3P<0[Jf]00<0k9H>
0:f][@3KRPd03@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP10
0;3PiP40oooo001I0;3PiP050:f][@2GH0/000000:f][@0000000P3CQ`h020000000dhL>0=>73P3C
Q`h000000=>73P2][Jd000002@3_V1001@000000kiP@0>nH402][Jd0o:0@0080[Jf]00<000000?bP
403lX1000P3lX102000000D0o:0@0P0000000`3lX100[Jf]0?nT4@020?nT4@030000003oY140oj@A
00<0oj@A00<000000?nT4@0000001@3oY14200000080oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2]
[Jd0ojHA0?nV4@0<0?nV4@X0[Jf]103oYQ400`2][Jd0ojHA0?nV4@0L0?nV4@030:f][@3oYQ00ojH@
01`0ojH@00<0[Jf]0?nU403oYA004`3oYA02000000L0ojD@00@0[Jf]0?nS403oXa00oj<@0P000009
0:f][@h0oj<@00<0[Jf]0?bP403lX1005P3lX102000000030:f][@3fW0l0mY`?00l0mY`?00H00000
0?JL3`3fW0l0mY`?0000003/UPh2000000D0k9H>0P0000070>bF3P<0[Jf]3@3KRPd00`2][Jd0^GD;
0;Ue2`060;Ue2`80[Jf]1028EPL00`2][Jd0/>3V0;3PiP100;3PiP40oooo001I0;3PiP050:f][@00
000000000:f][@0000000P3CQ`h020000000dhL>0=>73P3CQ`h000000=>73P2][Jd000002@3_V100
0`000000kiP@0>nH40020:f][@80o:0@00<000000?bP403lX1000P3lX102000000D0o:0@00@00000
0?bP403lX100[Jf]103oY1400`000000oj@A0?nT4@02000000P0oj@A0P0000020?nT4@030:f][@3o
YQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ400P3oYQ4:0:f][@h0ojHA00<0[Jf]0?nV4@3oYQ40703o
YQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@0P0000070?nU40040:f][@3o
Xa00oj<@0?nS408000002@3oXa0:0:f][@@0oj<@00<0[Jf]0?bP403lX1005P3lX102000000030:f]
[@3fW0l0mY`?00l0mY`?0P0000020?JL3`040000003/UPh00000000000D0k9H>0P0000080>bF3P04
0:f][@3KRPd0[Jf]0:f][@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0308QF
1`030:f][@2`h>H0/>3V0400/>3V0@3oool005T0/>3V00D0[Jf]000000000000Uf0;000000020=>7
3P080000003CQ`h0dhL>0=>73P000000dhL>0:f][@0000040>nH408000000`3_V10010000000[Jf]
0:f][@2][Jd20?bP40800000103lX102000000D0o:0@00@000000?bP403lX100[Jf]1@3oY1420000
00X0oj@A0P0000020?nT4@030:f][@3oYQ40ojHA01@0ojHA202][JdH0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400C0?nU408000001`3oYA00102]
[Jd0oj<@0?nS403oXa02000001<0oj<@202][JdE0?bP4080000000<0[Jf]0?JL3`3fW0l0403fW0l3
000000040:f][@3/UPh00000000000D0k9H>0P0000080>bF3P040:f][@3KRPd0fhX=0=^:3@80[Jf]
2@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H70:f][@80R5H700<0[Jf]0;3PiP2`
h>H0@02`h>H10?ooo`00F@2`h>H30000000509MP2`000000dhL>0=>73P0000000P3CQ`h200000003
0=>73P2][Jd0000000<0kiP@0`0000020>nH40050:f][@000000kiP@0>nH402][Jd00P3lX1020000
00D0o:0@0P0000030?bP40040000003lX100o:0@0:f][A80oj@A0P0000020?nT4@030:f][@3oYQ40
ojHA00h0ojHA1P2][Jd30?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01<0ojD@0P0000070?nU40040:f][@3oXa00
oj<@0?nS408000005`3oXa00102][Jd0o:0@0?bP403lX1070:f][@h0o:0@0P0000000`2][Jd0mY`?
0?JL3`0D0?JL3`030:f][@000000000000D0k9H>0P0000080>bF3P030:f][@3KRPd0fhX=00<0fhX=
0P2][Jd70=^:3@030:f][@2iM@/0^GD;00H0^GD;00L0[Jf]08QF1`28EPL0R5H70:f][@28EPL0[Jf]
0480/>3V0@3oool005T0/>3V0`0000001@2GH0/000000=>73P3CQ`h000000080dhL>0P000000103C
Q`h0[Jf]0000003_V102000000030>nH4000000000000080[Jf]00D0kiP@0000003_V100kiP@0:f]
[@020?bP408000001@3lX102000000<0o:0@00@000000?bP403lX100[Jf]4P3oY14200000080oj@A
00<0[Jf]0?nV4@3oYQ401`3oYQ470:f][@T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA
0?nV4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00403oYA0:00000080ojD@
00@0[Jf]0?nS403oXa00oj<@0P00000G0?nS40030:f][@3lX100o:0@00P0o:0@1P2][Jd80?bP4080
000000<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd00000000000050>bF3P800000203/UPh00`2][Jd0
fhX=0=^:3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`070:f][@28EPL0R5H708QF
1`2][Jd0R5H70:f][@120;3PiP40oooo001H0;3PiP@0000000D0Uf0;0000003CQ`h0dhL>00000002
0=>73P80000000@0dhL>0:f][@00000000000`3_V102000000<0kiP@00D000000>nH403_V100[Jf]
0?bP4003000000H0o:0@100000030?bP40030:f][@3oY140oj@A0100oj@A0P0000020?nT4@040:f]
[@3oYQ40ojHA0?nV4@H0[Jf]403oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA01`0
ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400J0?nU40P000005`3oXa000`2][Jd0
o:0@0?bP400>0?bP40L0[Jf]00@0o:0@000000000000[Jf]5P3fW0l00`2][Jd00000000000050>bF
3P800000203/UPh00`2][Jd0fhX=0=^:3@070=^:3@80[Jf]0`3KRPd00`2][Jd0^GD;0;Ue2`060;Ue
2`030:f][@28EPL0R5H70080R5H70P2][Je20;3PiP40oooo001H0;3PiP@0000000<0Uf0;0000003C
Q`h00P0000020=>73P80000000<0dhL>0:f][@0000000P3_V1020:f][@8000000`3_V1001@000000
kiP@0>nH402][Jd0o:0@00<000003@3lX1000`2][Jd0oj@A0?nT4@0@0?nT4@80000000<0oj@A0:f]
[@2][Jd00`2][JdF0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2]
[Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2]
[Jd0o:0@0?bP400E0?bP40030:f][@000000000000<0[Jf]503fW0l00`2][Jd00000000000050>bF
3P800000203/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]00<0fhX=0:f][@2iM@/01`2iM@/00`2]
[Jd0R5H708QF1`0308QF1`030:f][@2`h>H0/>3V0400/>3V0@3oool005P0/>3V100000000`2GH0/0
00000=>73P0200000080dhL>0P0000000`3CQ`h0[Jf]000000020:f][@80kiP@0P0000030>nH4080
000000<0kiP@0:f][@3lX1000`00000=0?bP40030:f][@3oY140oj@A00l0oj@A00H0[Jf]00000000
0000[Jf]0?nT4@2][JdI0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ40
0`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa00
0`2][Jd0o:0@0?bP400F0?bP4080000000<0[Jf]0?JL3`3fW0l0102][Jd@0?JL3`030:f][@000000
000000D0k9H>0P0000080>bF3P030:f][@3KRPd0fhX=00/0fhX=0P2][Jd90;Ue2`030:f][@28EPL0
R5H70080R5H70P2][Je10;3PiP40oooo001G0;3PiP@000000P2GH0/010000000dhL>000000000002
0=>73P80000000<0dhL>0:f][@000000103_V1000`000000kiP@0>nH40030>nH40050000003_V100
[Jf]0000003lX1000P00000=0?bP40030:f][@3oY140oj@A00/0oj@A102][Jd00`3oY14000000000
00020?nT4@030:f][@3oYQ40ojHA01L0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01H0o:0@0P0000000`2][Jd0mY`?0?JL3`040?JL3`D0[Jf]2`3f
W0l00`2][Jd00000000000050>bF3P800000203/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@80[Jf]202i
M@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H400000080Uf0;00@00000
0=>73P00000000000P3CQ`h200000080[Jf]00<000000>nH403_V1000P3_V1000`000000kiP@0>nH
40030>nH4080000000<0[Jf]0000003lX1000P00000=0?bP40030:f][@3oY140oj@A00L0oj@A102]
[Jd50?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0
[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400F0?bP4080000000<0[Jf]0?JL3`3fW0l0103f
W0l00`000000mY`?0?JL3`020?JL3`D0[Jf]1P3fW0l00`2][Jd00000000000050>bF3P800000203/
UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0[Jf]0:f][@H0^GD;00<0[Jf]08QF1`28EPL0
0P28EPL20:f][D40/>3V0@3oool005L0/>3V1000000209MP2`040000003CQ`h0000000000080dhL>
0P0000000`3CQ`h0[Jf]000000030>nH408000001P3_V10200000080o:0@0P00000=0?bP40030:f]
[@3oY140oj@A00<0oj@A102][Jd90?nT4@8000000P3oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f]
[@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3oYQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f]
[@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403oXa006P3oXa000`2][Jd0o:0@0?bP400F0?bP40800000
00<0[Jf]0?JL3`3fW0l0103fW0l00`000000mY`?0?JL3`070?JL3`@0[Jf]0P3fW0l00`2][Jd00000
000000050>bF3P<00000203/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@050:f][@2iM@/0^GD;0;Ue2`2]
[Jd01@2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H40000000409MP
2`00000000000=>73P8000000P3CQ`h2000000030=>73P2][Jd0000000<0kiP@00<000000>nH403_
V1001P3_V1000`2][Jd0o:0@0?bP4002000000d0o:0@00<0[Jf]0?nT4@2][Jd00`2][Jd=0?nT4@05
0000003oY140oj@A0?nT4@2][Jd06@3oYQ400`2][Jd0ojHA0?nV4@0J0?nV4@030:f][@3oYQ40ojHA
01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L0?nU40030:f][@3oXa00oj<@
01X0oj<@00<0[Jf]0?bP403lX1004`3lX105000000030:f][@3fW0l0mY`?00@0mY`?0P00000<0?JL
3`<0[Jf]0P0000050>bF3P<00000203/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;
0080^GD;00<0[Jf]0;Ue2`2iM@/00P2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@@2`h>H10?oo
o`00E`2`h>H40000000409MP2`000000[Jf]0=>73P8000000P2][Jd2000000030=>73P2][Jd00000
00<0kiP@00<000000>nH403_V1001P3_V100102][Jd0o:0@0?bP4000000=0?bP40<0[Jf]4@3oY140
1@000000oj@A0?nT4@3oY140[Jf]01T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0103fW0l2000000h0mY`?00<0
[Jf]0000000000000P2][Jd30>bF3P<00000203/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2i
M@/0^GD;00<0^GD;00D0[Jf]0;Ue2`2iM@/0^GD;0:f][@0408QF1`80[Jf]@@2`h>H10?ooo`00E`2`
h>H40000000409MP2`000000[Jf]0=>73P8000000P3CQ`h2000000060=>73P2][Jd0kiP@0000003_
V10000002@3_V100102][Jd0o:0@0?bP4000000;0?bP4080[Jf]00<0o:0@0:f][@3oY1404@3oY140
1@000000oj@A0?nT4@3oY140[Jf]01T0ojHA00<0[Jf]0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV
4@0L0?nV4@030:f][@3oYQ00ojH@01`0ojH@00<0[Jf]0?nU403oYA00703oYA000`2][Jd0oj<@0?nS
400J0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l01@3fW0l00`000000mY`?0?JL
3`0<0?JL3`030:f][@00000000000080k9H>0P2][Jd0103/UPh000000000000000080>bF3P030:f]
[@3KRPd0fhX=00/0fhX=00<0[Jf]0;Ue2`2iM@/0102iM@/20:f][@030;Ue2`2][Jd0R5H700<0R5H7
0P2][Je10;3PiP40oooo001G0;3PiP@0000000@0Uf0;0000002][Jd0dhL>0P0000020=>73P800000
00H0dhL>0:f][@3_V10000000>nH400000090>nH40040:f][@3lX100o:0@000000P0o:0@0`2][Jd3
0?bP40030:f][@3oY140oj@A01@0oj@A00<0[Jf]0?nV4@3oYQ405`3oYQ400`2][Jd0ojHA0?nV4@0J
0?nV4@030:f][@3oYQ40ojHA01`0ojHA00<0[Jf]0?nV403oYQ00703oYQ000`2][Jd0ojD@0?nU400L
0?nU40030:f][@3oXa00oj<@01X0oj<@00<0[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D
0?JL3`030:f][@000000000000@0k9H>00@0[Jf]0000000000000000203/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00H0^GD;0P2][Jd408QF1`80[Jf]@@2`h>H10?ooo`00E`2`h>H4
0000000409MP2`000000[Jf]0:f][@8000000P3CQ`h010000000dhL>0=>73P2][Jd20>nH40030000
003_V100kiP@00P0kiP@00@0[Jf]0?bP403lX10000001P3lX1020:f][@H0o:0@00<0[Jf]0?nT4@3o
Y140503oY1400`2][Jd0ojHA0?nV4@0G0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0[Jf]0?nV4@3o
YQ40703oYQ400`2][Jd0ojH@0?nV400L0?nV40030:f][@3oYA00ojD@01`0ojD@00<0[Jf]0?nS403o
Xa006P3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0mY`?00<0[Jf]00000000
00001@3/UPh300000080[Jf]1P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0
^GD;00<0[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005L0/>3V10000000102GH0/00000
0:f][@3CQ`h200000080dhL>00@000000=>73P3CQ`h0[Jf]3@3_V100102][Jd0o:0@0?bP40000003
0?bP40<0[Jf]203lX1000`2][Jd0oj@A0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]
0?nV4@3oYQ406P3oYQ400`2][Jd0ojHA0?nV4@0E0?nV4Bh0[Jf]5`3oYA000`2][Jd0oj<@0?nS400J
0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l04`3fW0l4000000D0k9H>00<00000
0>bF3P0000000P3/UPh20:f][@@0k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`07
0;Ue2`80[Jf]0`28EPL20:f][D40/>3V0@3oool005L0/>3V10000000102GH0/000000:f][@3CQ`h2
00000080dhL>00<000000=>73P2][Jd03P3_V100102][Jd0o:0@0?bP400000030:f][@/0o:0@00<0
[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA01X0ojHA00<0
[Jf]0?nV4@3oYQ401@3oYQ4@0:f][Bh0/>3V402][Jd70?nU40030:f][@3oXa00oj<@01X0oj<@00<0
[Jf]0?bP403lX100603lX1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@000000000000D0k9H>00<0
00000>bF3P000000103/UPh30:f][@030>bF3P2][Jd0fhX=00d0fhX=00<0[Jf]0;Ue2`2iM@/01P2i
M@/20:f][@<0R5H70P2][Je10;3PiP40oooo001G0;3PiP@0000000@0Uf0;0000002][Jd0dhL>0P00
00020=>73P030000003CQ`h0[Jf]00h0kiP@00@0[Jf]0?bP402][Jd000003P3lX1000`2][Jd0oj@A
0?nT4@0C0?nT4@030:f][@3oYQ40ojHA01P0ojHA00<0[Jf]0?nV4@3oYQ405P3oYQ4<0:f][Dh0/>3V
3`2][JdE0?nS40030:f][@3lX100o:0@01P0o:0@00<0[Jf]0?JL3`3fW0l0503fW0l00`2][Jd0k9H>
0>bF3P060>bF3P030000003/UPh0k9H>00H0k9H>0`2][Jd=0=^:3@030:f][@2iM@/0^GD;00H0^GD;
00<0[Jf]08QF1`2][Jd00P28EPL20:f][D40/>3V0@3oool005L0/>3V10000000102][Jd000000:f]
[@3CQ`h2000000050=>73P000000dhL>0=>73P2][Jd03@3_V1030:f][@030?bP40000000o:0@00d0
o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA00`0
ojHA2P2][JeY0;3PiPh0[Jf]1`3oXa000`2][Jd0o:0@0?bP400H0?bP40030:f][@3fW0l0mY`?01@0
mY`?00<0[Jf]0>bF3P3/UPh01P3/UPh00`000000k9H>0>bF3P070>bF3P040:f][@3KRPd0[Jf]0:f]
[@/0fhX=00<0[Jf]0;Ue2`2iM@/01P2iM@/00`2][Jd0R5H70:f][@0208QF1`80[Jf]@@2`h>H10?oo
o`00E`2`h>H40000000609MP2`000000[Jf]0=>73P000000dhL>0P0000020=>73P030:f][@3_V100
kiP@00T0kiP@0P2][Jd01@3_V100[Jf]0?bP403lX100000000h0o:0@00<0[Jf]0?nT4@3oY1404`3o
Y1400`2][Jd0ojHA0?nV4@0H0?nV4@030:f][@3oYQ40ojHA0080ojHA2P2][Jf10;3PiPX0[Jf]603l
X1000`2][Jd0mY`?0?JL3`0D0?JL3`030:f][@3/UPh0k9H>0100k9H>00@0[Jf]0=^:3@3KRPd0fhX=
0P2][Jd90=^:3@030:f][@2iM@/0^GD;00H0^GD;00D0[Jf]08QF1`28EPL0[Jf]08QF1`020:f][D40
/>3V0@3oool005L0/>3V0`0000001P2][Jd0Uf0;000000000000dhL>000000D0dhL>00<0[Jf]0>nH
403_V1001`3_V1020:f][@<0kiP@00@0[Jf]0?bP403lX10000003P3lX1000`2][Jd0oj@A0?nT4@0C
0?nT4@030:f][@3oYQ40ojHA01D0ojHA202][JfE0;3PiPH0[Jf]4P3lX1000`2][Jd0mY`?0?JL3`0E
0?JL3`030:f][@3/UPh0k9H>00l0k9H>00<0[Jf]0=^:3@3KRPd00`3KRPd20:f][@L0fhX=00<0[Jf]
0;Ue2`2iM@/01P2iM@/0102][Jd0R5H708QF1`28EPL30:f][D40/>3V0@3oool005H0/>3V10000002
09MP2`<000001P3CQ`h00`2][Jd0kiP@0>nH40050>nH4080[Jf]1@3_V100102][Jd0o:0@0?bP4000
000>0?bP40030:f][@3oY140oj@A01<0oj@A00<0[Jf]0?nV4@3oYQ403P3oYQ470:f][J<0/>3V1@2]
[Jd=0?bP40030:f][@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:
3@050=^:3@80[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`060;Ue2`040:f][@28EPL0R5H708QF1`<0[Jf]
@@2`h>H10?ooo`00EP2`h>H400000080Uf0;0`0000060=>73P030:f][@3_V100kiP@00<0kiP@0P2]
[Jd70>nH40030:f][@000000000000l0o:0@00<0[Jf]0?nT4@3oY1404`3oY1400`2][Jd0ojHA0?nV
4@080?nV4@H0[Jf][`2`h>H50:f][@P0o:0@00<0[Jf]0?JL3`3fW0l05@3fW0l00`2][Jd0k9H>0>bF
3P0?0>bF3P030:f][@3KRPd0fhX=00L0fhX=0P2][Jd30=^:3@030:f][@2iM@/0^GD;00H0^GD;00<0
[Jf]08QF1`28EPL00P28EPL20:f][D40/>3V0@3oool005H0/>3V1000000209MP2`030000002][Jd0
dhL>00H0dhL>00@0[Jf]0>nH403_V100kiP@0P2][Jd90>nH40030:f][@3lX100o:0@00l0o:0@00<0
[Jf]0?nT4@3oY1404`3oY140102][Jd0ojHA0?nV4@3oYQ470:f][KX0/>3V1P2][Jd20?bP40030:f]
[@3fW0l0mY`?01D0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@090=^:3@80[Jf]
00<0fhX=0:f][@2iM@/0202iM@/0102][Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V
100000000`2GH0/00000000000080=>73P040:f][@3_V100[Jf]0:f][@/0kiP@00<0[Jf]0?bP403l
X1003`3lX1000`2][Jd0oj@A0?nT4@0A0?nT4@H0[Jf]a`2`h>H50:f][AD0mY`?00<0[Jf]0>bF3P3/
UPh03`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@80[Jf]2@2iM@/0102][Jd0R5H708QF1`28EPL20:f]
[D40/>3V0@3oool005H0/>3V100000000`2GH0/000000:f][@080=>73P80[Jf]3@3_V1000`2][Jd0
o:0@0?bP400?0?bP40030:f][@3oY140oj@A00d0oj@A102][JgB0;3PiPD0[Jf]403fW0l00`2][Jd0
k9H>0>bF3P0?0>bF3P030:f][@3KRPd0fhX=00`0fhX=0`2][Jd70;Ue2`040:f][@28EPL0R5H708QF
1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000050:f][@000000Uf0;09MP2`2][Jd01`3CQ`h20:f]
[@h0kiP@00<0[Jf]0?bP403lX1003`3lX1000`2][Jd0oj@A0?nT4@090?nT4@@0[Jf]f`2`h>H40:f]
[@`0mY`?00<0[Jf]0>bF3P3/UPh03`3/UPh00`2][Jd0fhX=0=^:3@0<0=^:3@040:f][@2iM@/0^GD;
0:f][@H0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Jd00`000000/>3V0;3PiP0n0;3PiP40oooo001F
0;3PiP80000000D0[Jf]0000002GH0/0Uf0;0:f][@050=>73P80[Jf]00<0dhL>0:f][@3_V100303_
V1000`2][Jd0o:0@0?bP400@0?bP40030:f][@3oY140oj@A00@0oj@A1@2][JgS0;3PiPD0[Jf]1`3f
W0l00`2][Jd0k9H>0>bF3P0@0>bF3P030:f][@3KRPd0fhX=00/0fhX=00D0[Jf]0;Ue2`2iM@/0^GD;
0:f][@050;Ue2`040:f][@28EPL0R5H708QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000050:f]
[@000000Uf0;09MP2`2][Jd0103CQ`h01@2][Jd0dhL>0=>73P3CQ`h0[Jf]00d0kiP@00<0[Jf]0?bP
403lX100403lX1000`2][Jd0oj@A0?nT4@040:f][Nd0/>3V1@2][Jd20?JL3`030:f][@3/UPh0k9H>
0100k9H>00<0[Jf]0=^:3@3KRPd02`3KRPd00`2][Jd0^GD;0;Ue2`020;Ue2`80[Jf]0`2iM@/0102]
[Jd0R5H708QF1`28EPL20:f][D40/>3V0@3oool005H0/>3V0P0000001@2][Jd0Uf0;09MP2`2GH0/0
[Jf]00<0dhL>00<0[Jf]0=>73P3CQ`h00P3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100
o:0@00l0o:0@102][Jgf0;3PiP@0[Jf]4@3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0
^GD;00@0^GD;00@0[Jf]0;Ue2`2iM@/0[Jf]0`28EPL20:f][D40/>3V0@3oool005H0/>3V0P000000
1P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80[Jf]1@3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f]
[@3lX100o:0@00`0o:0@0`2][Jgn0;3PiP<0[Jf]3P3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f]
[@2iM@/0^GD;00D0^GD;0`2][Jd308QF1`80[Jf]@@2`h>H10?ooo`00EP2`h>H2000000040:f][@2G
H0/0Uf0;09MP2`80[Jf]1`3CQ`h00`2][Jd0kiP@0>nH400;0>nH40030:f][@3lX100o:0@00X0o:0@
0P2][Jd30;VbYP<0[Jf]nP2`h>H30:f][@040<>m^`2][Jd0[Jf]0:f][@/0k9H>00<0[Jf]0=^:3@3K
RPd02`3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H700<0[Jf]0;3PiP2`
h>H0?`2`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0309MP2`030:f][@3CQ`h0dhL>00H0dhL>
00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40070?bP40<0[Jf]202i/ZH20:f][O@0/>3V
102][Jd70<>m^`@0[Jf]1`3/UPh00`2][Jd0fhX=0=^:3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;
0P2][Jd308QF1`030:f][@2`h>H0/>3V03l0/>3V0@3oool005H0/>3V00<000000:f][@2GH0/00P2G
H0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V1000`2][Jd0o:0@0?bP40040?bP40<0[Jf]00<0
/J^M0:f][@2i/ZH02P2i/ZH30:f][Nh0/>3V0`2][Jd?0<>m^`<0[Jf]103/UPh00`2][Jd0fhX=0=^:
3@0;0=^:3@030:f][@2iM@/0^GD;00L0^GD;0P2][Jd308QF1`030:f][@2`h>H0/>3V03l0/>3V0@3o
ool005H0/>3V00<000000:f][@2GH0/00P2GH0/20:f][@P0dhL>00<0[Jf]0>nH403_V1002`3_V100
0`2][Jd0o:0@0?bP40020?bP4080[Jf]102aZid00`2][Jd0^K:V0;VbYP0<0;VbYP<0[Jf]i`2`h>H4
0:f][@030<K0_02][Jd0`kfk00l0`kfk00<0[Jf]0;ji^02n^KP00`2][Jd00`3/UPh0[Jf]0=^:3@0<
0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28EPL00`2][Jd0/>3V0;3PiP0o
0;3PiP40oooo001F0;3PiP070000002][Jd0Uf0;09MP2`2][Jd0Uf0;0:f][@080=>73P030:f][@3_
V100kiP@00/0kiP@00<0[Jf]0?bP402][Jd00P2][Jd60;6[W@030:f][@2i/ZH0^K:V00d0^K:V00<0
[Jf]0;jg[02][Jd00`2][JgP0;3PiP<0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n
^KP0_[Vh00<0_[Vh0P2][Jd=0=^:3@030:f][@2iM@/0^GD;00L0^GD;00<0[Jf]08QF1`2][Jd00P28
EPL00`2][Jd0/>3V0;3PiP0o0;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;00000080Uf0;00<0
[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0kiP@0>nH400:0>nH40<0[Jf]202aZid00`2][Jd0^K:V0;Vb
YP0>0;VbYP030:f][@2n]j`0_[N/00<0_[N/102][JgH0;3PiP@0[Jf]2036`;`00`2][Jd0`kfk0<>m
^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2][Jd;0=^:3@030:f][@2iM@/0^GD;00L0^GD;00L0
[Jf]08QF1`28EPL0[Jf]08QF1`2][Jd000000400/>3V0@3oool005H0/>3V00@000000:f][@2GH0/0
00000P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@00P0kiP@0P2][Jd;0;6[W@03
0:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][M00/>3V102][Jd<0<K0_003
0:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP20:f][@T0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0/>3V03h0/>3V0@3oool005H0
/>3V00@000000:f][@2][Jd000000P2GH0/00`2][Jd0dhL>0=>73P060=>73P030:f][@3_V100kiP@
00H0kiP@102][Jd;0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`02`2n]j`40:f]
[LP0/>3V102][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP01`2n^KP40:f]
[@L0fhX=00<0[Jf]0;Ue2`2iM@/01`2iM@/0102][Jd0R5H708QF1`28EPL20:f][@030000002`h>H0
/>3V03h0/>3V0@3oool005H0/>3V00@000000:f][@2][Jd000000P2GH0/00`2][Jd0dhL>0=>73P06
0=>73P030:f][@3_V100kiP@00<0kiP@0`2][Jd0102TWXl0[Jf]0;6[W@2aZid20:f][@T0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00?0;jg[0@0[Jf]_`2`h>H50:f][@80al6l00<0
[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f][@2n^KP0_[Vh00D0_[Vh0P2]
[Jd40;ji^080[Jf]1@3KRPd00`2][Jd0^GD;0;Ue2`070;Ue2`030:f][@28EPL0R5H70080R5H70P2]
[Je00;3PiP40oooo001F0;3PiP040000002][Jd0Uf0;00000080Uf0;00<0[Jf]0=>73P3CQ`h01P3C
Q`h0102][Jd0kiP@0>nH403_V1020:f][@@0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid20:f][@L0/J^M
00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00D0[Jf]
]02`h>H60:f][@L0al6l00<0[Jf]0<K0_036`;`03`36`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0_[Vh00<0_[Vh0P2][Jd60;ji^0040:f][@11JN40[Jf]0:f][@<0fhX=00<0[Jf]0;Ue2`2i
M@/01`2iM@/00`2][Jd0R5H708QF1`0208QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]
09MP2`0209MP2`030:f][@3CQ`h0dhL>00L0dhL>00@0[Jf]0>nH402][Jd0[Jf]1@2TWXl2045Yh@H0
/J^M0P2][Jd50;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0
`KZ`0<6j/0050<6j/0H0[Jf]Z@2`h>H50:f][@d0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`0=0<>m^`040:f][@2n^KP0_[Vh0;ji^080[Jf]1`2n^KP01@11JN40[Jf]045Yh@2d/;40
@FWQ0080[Jf]00<0fhX=0:f][@2iM@/02@2iM@/0102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3o
ool005H0/>3V00<000000:f][@2GH0/00P2GH0/00`2][Jd0dhL>0=>73P070=>73P80[Jf]202TWXl0
0`2][Jd0@FWQ045Yh@060;6[W@80[Jf]0`2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0
_[N/0100_[N/00<0[Jf]0<6j/031^[002`31^[050:f][Il0/>3V1@2][JdB0<O1_0030:f][@36`;`0
a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/0102][Jd0_[Vh0:f][@2][Jd80;ji^003045Yh@2n
^KP0[Jf]0080@FWQ0`2d/;420:f][@X0^GD;00@0[Jf]08QF1`28EPL0R5H70P2][Je00;3PiP40oooo
001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h01P3CQ`h00`2][Jd0Y9j?0:BN
S`080:BNS`030:f][@11JN40/J^M0080@FWQ1P2aZid20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00@0<6j/0H0[Jf]U02`h>H50:f][@80b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00`0`kfk0`2]
[Jd80;ji^005045Yh@2n^KP0@FWQ0;ji^02][Jd00P11JN430;B`/@80@FWQ0P2][Jd80;Ue2`040:f]
[@28EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f]
[@3CQ`h0dhL>00@0dhL>0P2][Jd;0:BNS`050:f][@11JN40/J^M0;6[W@11JN40202aZid30:f][@l0
^K:V00<0[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0040:f][@33_K<0`kfc0<>m
/`L0[Jf]Q`2`h>H60:f][@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0030:f][@33_K/0`kfk00T0`kfk0`2][Jd00`33_K/0[Jf]0;ji^0060;ji^080@FWQ00H0_[Vh045Y
h@11JN40_[Vh0:f][@11JN440;B`/@80@FWQ0P2d/;400`2][Jd0^GD;0;Ue2`050;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00EP2`h>H00`000000[Jf]09MP2`0209MP2`030:f][@3C
Q`h0dhL>00<0dhL>00<0[Jf]045Yh@2][Jd02P2TWXl00`2][Jd0/J^M045Yh@030;6[W@03045Yh@2a
Zid0/J^M00H0/J^M00<0[Jf]0;VbYP2][Jd00`2][Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0
[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`080<>m/`P0[Jf]NP2`h>H50:f][@d0b<6k00<0
[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00H0`kfk0`2]
[Jd40<>m^`030:f][@2n^KP0_[Vh00@0_[Vh00@0@FWQ0;ji^02n^KP0_[Vh0P11JN420;ji^0030:f]
[@11JN40];2a0080];2a0P11JN420;B`/@03045Yh@2][Jd0[Jf]00D0^GD;00@0[Jf]08QF1`28EPL0
R5H70P2][Je00;3PiP40oooo001F0;3PiP030000002][Jd0Uf0;0080Uf0;00<0[Jf]0=>73P3CQ`h0
0P3CQ`h0102][Jd0RXEe045Yh@2][Jd:0:BNS`030:f][@2aZid0@FWQ00<0/J^M00@0@FWQ0;6[W@2a
Zid0/J^M0`11JN420;6[W@030:f][@2i/ZH0^K:V00<0^K:V0`2][Jd80;VbYP030:f][@2n]j`0_[N/
0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]J@2`h>H80:f]
[A80b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk
0080`kfk102][Jd70<>m^`030:f][@2n^KP0_[Vh00@0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP01@11
JN40_[Vh0;ji^02][Jd0@FWQ00<0];2a0P11JN420;B`/@03045Yh@2][Jd0[Jf]0080[Jf]0`2iM@/0
102][Jd0R5H708QF1`28EPL20:f][D00/>3V0@3oool005D0/>3V00<000000;3PiP2][Jd00`2GH0/0
1@2][Jd0dhL>0=>73P3CQ`h0[Jf]0080RXEe00@0@FWQ0:f][@2][Jd0[Jf]202TWXl00`2][Jd0/J^M
045Yh@040;6[W@03045Yh@2aZid0/J^M0080/J^M0`11JN400`2][Jd0^K:V0;VbYP060;VbYP<0[Jf]
1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<0
4`33_K<00`2][Jd0aKje0<Fn]@030<Fn]@`0[Jf]D@2`h>H<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/0
4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`2][Jd0
0P2][Jd;0<>m^`030:f][@2n^KP0_[Vh00<0_[Vh0P11JN440;ji^005045Yh@2n^KP0_[Vh0:f][@11
JN400`2d/;42045Yh@080;B`/@2][Jd0@FWQ0;B`/@2][Jd0@FWQ09nKX02][Jd20;Ue2`040:f][@28
EPL0R5H708QF1`80[Jf]@02`h>H10?ooo`00E`2`h>H01P2][Jd0Uf0;09MP2`2GH0/0[Jf]0=>73P80
[Jf]00D0@FWQ08Z5M@2:QGD0@FWQ0:f][@020:BNS`030:f][@2TWXl0Y9j?00D0Y9j?00<0[Jf]0;6[
W@11JN40102aZid00`11JN40/J^M0;6[W@020;6[W@04045Yh@2aZid0/J^M0:f][@/0^K:V102][Jd0
0`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<0
0`2][Jd0aKje0<Fn]@0?0<Fn]A40[Jf];`2`h>HA0:f][A40b<6k00<0[Jf]0<S1^`38`K/04P38`K/0
0`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00l0a/2l0`2][Jd<0<>m^`80@FWQ00<0[Jf]
0;ji^02n^KP00`2n^KP2045Yh@@0_[Vh00D0@FWQ0;ji^02n^KP0[Jf]045Yh@030;B`/@80@FWQ00H0
[Jf]0;B`/@11JN40@FWQ0:f][@11JN4209nKX0<0[Jf]1028EPL00`2][Jd0/>3V0;3PiP0n0;3PiP40
oooo001F0;3PiP030:f][@2GH0/0Uf0;0080Uf0;0P2][Jd408Z5M@80@FWQ00@0[Jf]0:BNS`2TWXl0
Y9j?0P2][Jd50:BNS`030:f][@2aZid0@FWQ00@0/J^M00<0@FWQ0;6[W@2aZid00P2aZid01011JN40
/J^M0;6[W@2][Jd?0;VbYP<0[Jf]4@2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc
01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`090<Jo]bl0[Jf]2`37`KX00`2]
[Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k0180b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2]
[Jd0a/2l0<K0_00;0<K0_0@0[Jf]00<0a/2l0:f][@33_K/02P33_K/3045Yh@030<>m^`2][Jd0_[Vh
00@0_[Vh0P11JN440;ji^005045Yh@2n^KP0_[Vh0:f][@11JN400P2d/;400`2][Jd0@FWQ045Yh@02
0;B`/@80@FWQ00<0[Jf]045Yh@2OVj000`2OVj000`2][Jd0R5H708QF1`0208QF1`030:f][@2`h>H0
/>3V03h0/>3V0@3oool005H0/>3V00<0[Jf]09MP2`2GH0/00P2GH0/00`2][Jd0RXEe08Z5M@0308Z5
M@03045Yh@2:QGD0[Jf]00D0Y9j?0P2][Jd30:BNS`030:f][@2aZid0@FWQ00@0/J^M00<0@FWQ0;6[
W@2aZid00P2aZid01011JN40/J^M0;6[W@2][Jd@0;VbYP030:f][@2n]j`0[Jf]00<0[Jf]3@2n]j`0
0`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0D0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04@37`K`0
0`2][Jd0a/2l0<K0_0070<K0_0@0[Jf]1@36`;`00`2][Jd0`kfk0<>m^`050<>m^`80@FWQ1033_K/0
0`11JN40`kfk0:f][@060;ji^003045Yh@2n^KP0_[Vh0080_[Vh00P0@FWQ0;ji^02n^KP0[Jf]045Y
h@2d/;40[Jf]0;B`/@80@FWQ0`2d/;43045Yh@D0Wi^P00D0[Jf]08QF1`28EPL0R5H70:f][@100;3P
iP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1@2:QGD00`11JN40RXEe0:f][@070:BN
S`060:f][@2TWXl0Y9j?0:f][@2aZid0@FWQ102aZid00`11JN40/J^M0;6[W@020;6[W@04045Yh@2a
Zid0/J^M0:f][@D0^K:V1@11JN460;VbYP030:f][@2n]j`0_[N/00<0_[N/102][Jd90;jg[0030:f]
[@31^[00`KZ`0140`KZ`00<0[Jf]0<>m/`33_K<05033_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01@0a[ng00<0[Jf]0<O1^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00A0<O1_0030:f]
[@36`;`0a/2l00<0a/2l102][Jd90<K0_0030:f][@33_K/0`kfk0080`kfk00<0@FWQ0<>m^`33_K/0
0P11JN440<>m^`04045Yh@33_K/0`kfk0:f][@D0_[Vh00<0@FWQ0;ji^02n^KP00P2n^KP01P11JN40
_[Vh0;ji^02][Jd0@FWQ0:f][@80];2a0P11JN430;B`/@03045Yh@2][Jd0Wi^P00D0Wi^P00D0[Jf]
08QF1`28EPL0R5H70:f][@100;3PiP40oooo001F0;3PiP040:f][@2GH0/0Uf0;09MP2`80[Jf]1@2:
QGD00`11JN40RXEe0:f][@080:BNS`<0[Jf]00<0/J^M045Yh@2aZid00`2aZid00`11JN40/J^M0;6[
W@020;6[W@04045Yh@2aZid0/J^M0:f][@D0^K:V0P11JN420;VbYP03045Yh@2i/ZH0^K:V00@0^K:V
00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]0<6j/031^[004@31^[000`2][Jd0`kfc
0<>m/`0D0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05036_kL00`2][Jd0al6h
0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0140al6l00<0[Jf]0<K0_02][Jd00`2][Jd=0<K0_0060:f]
[@33_K/0`kfk0<>m^`11JN40`kfk1011JN440<>m^`04045Yh@33_K/0`kfk0:f][@D0_[Vh0P11JN43
0;ji^005045Yh@2n^KP0[Jf]0:f][@11JN400`2d/;400`11JN40];2a0;B`/@020;B`/@03045Yh@2]
[Jd0Wi^P00H0Wi^P00@0[Jf]08QF1`28EPL0[Jf]@02`h>H10?ooo`00EP2`h>H00`2][Jd0Uf0;09MP
2`030:f][@D0RXEe00<0@FWQ08Z5M@2][Jd02P2TWXl20:f][@03045Yh@2aZid0/J^M0080/J^M00<0
@FWQ0;6[W@2aZid00P2aZid01011JN40/J^M0;6[W@2][Jd50;VbYP03045Yh@2i/ZH0^K:V0080^K:V
00<0@FWQ0;VbYP11JN400P11JN400`2i/ZH0[Jf]0;jg[00<0;jg[0@0[Jf]00<0_[N/0:f][@31^[00
4P31^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01D0aKje00<0[Jf]0<Jo]`36_kL0
5036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/0
5038`K/00`2][Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00l0al6l102][JdA0<K0_0040:f]
[@33_K/0@FWQ045Yh@<0`kfk0`11JN440<>m^`04045Yh@33_K/0`kfk0:f][@D0_[Vh1P11JN40102]
[Jd0_[Vh0:f][@11JN430;B`/@03045Yh@2d/;40];2a0080];2a00<0@FWQ0:f][@2OVj000`2OVj00
0`11JN40Wi^P09nKX0020:f][@0308QF1`2][Jd0/>3V03l0/>3V0@3oool005H0/>3V00@0[Jf]09MP
2`2][Jd0Hf1C0P2][Jd508Z5M@03045Yh@2][Jd0Y9j?00X0Y9j?00@0[Jf]0;6[W@11JN40[Jf]0`2a
Zid2045Yh@<0/J^M00@0@FWQ0;6[W@2aZid0[Jf]1@2i/ZH00`11JN40^K:V0;VbYP020;VbYP04045Y
h@2i/ZH0@FWQ045Yh@80^K:V00@0[Jf]0;jg[02n]j`0@FWQ3P2n]j`40:f][A40`KZ`00<0[Jf]0<>m
/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<0[Jf]0<O1
^037`KP05037`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1
^`38`K/04`38`K/00`2][Jd0al6l0<O1_00:0<O1_0D0[Jf]0P37`K`00`2][Jd0a/2l0<K0_00@0<K0
_0040:f][@33_K/0@FWQ045Yh@@0`kfk0P11JN440<>m^`04045Yh@33_K/0`kfk0:f][@P0_[Vh0P2]
[Jd01@11JN40_[Vh0;ji^02][Jd0@FWQ0080];2a0P11JN440;B`/@03045Yh@2][Jd0Wi^P0080Wi^P
0P11JN4209nKX0040:f][@1`KWT0[Jf]0:f][D00/>3V0@3oool005H0/>3V0P2][Jd306=PD`030:f]
[@2:QGD0RXEe00<0RXEe00<0@FWQ0:f][@2TWXl02P2TWXl0102][Jd0@FWQ0;6[W@2aZid30:f][@80
@FWQ0P2aZid2045Yh@80/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH00`11JN40^K:V0;VbYP030;VbYP80
@FWQ0`2i/ZH0102][Jd0_[N/0;jg[011JN4?0;jg[0030:f][@31^[00`KZ`00D0[Jf]3031^[000`2]
[Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2]
[Jd0b<6k0<S1^`0C0<S1^`030:f][@37`K`0al6l00D0al6l1@2][Jd70<O1_0030:f][@36`;`0a/2l
00T0a/2l00<0@FWQ0<K0_036`;`01036`;`00`2][Jd0@FWQ045Yh@050<>m^`80@FWQ1033_K/01011
JN40`kfk0<>m^`2][Jd50;ji^0<0[Jf]0P2n^KP01011JN40_[Vh0;ji^02][Jd2045Yh@030;B`/@11
JN40];2a00@0];2a00<0@FWQ0:f][@2OVj000`2OVj001@11JN40Wi^P0:f][@2][Jd0L6ii0080[Jf]
@02`h>H10?ooo`00EP2`h>H20:f][@<0Hf1C0P2][Jd408Z5M@03045Yh@2][Jd0Y9j?00X0Y9j?00<0
[Jf]045Yh@2aZid0102aZid2045Yh@80/J^M0P11JN420;6[W@030:f][@2i/ZH0^K:V00<0^K:V00<0
@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@<0^K:V00@0[Jf]0;jg[02n]j`0@FWQ1@2n]j`00`11JN40_[N/
0;jg[0070;jg[0030:f][@31^[00`KZ`00D0`KZ`1@2][Jd70<6j/0030:f][@33_K<0`kfc01<0`kfc
00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h
00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k
00<0[Jf]0<O1_037`K`01@2][Jd<0<O1_0030:f][@36`;`0a/2l00<0a/2l00<0@FWQ0<K0_036`;`0
0`36`;`00`11JN40a/2l0<K0_0040<K0_0030:f][@11JN40@FWQ00D0`kfk0P11JN440<>m^`04045Y
h@33_K/0`kfk0:f][@<0_[Vh0P2][Jd50;ji^007045Yh@2n^KP0_[Vh0:f][@11JN40];2a045Yh@06
0;B`/@03045Yh@2][Jd0Wi^P00@0Wi^P00<0[Jf]09nKX02][Jd00P1`KWT20:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe0:f][@0308Z5M@03045Yh@2][Jd0Y9j?
00X0Y9j?00<0[Jf]045Yh@2aZid0102aZid2045Yh@80[Jf]0P11JN420;6[W@030:f][@2i/ZH0^K:V
00<0^K:V00<0@FWQ0;VbYP2i/ZH00`2i/ZH2045Yh@80^K:V00H0[Jf]0;jg[02n]j`0@FWQ0;jg[011
JN440;jg[003045Yh@2n]j`0_[N/00L0_[N/00<0[Jf]0<6j/031^[002P31^[050:f][@80`KZ`00<0
[Jf]0<>m/`33_K<04@33_K<6045YhA<0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`0@0<S1^`H0[Jf]4@37`K`00`2][Jd0a/2l0<K0_0030<K0_003045Yh@36`;`0a/2l00<0a/2l00<0
@FWQ0<K0_036`;`01036`;`00`2][Jd0@FWQ0<>m^`050<>m^`80@FWQ1033_K/2045Yh@030<>m^`2]
[Jd0_[Vh0080[Jf]0`2n^KP01@11JN40_[Vh0;ji^02n^KP0@FWQ0080_[Vh00<0[Jf]045Yh@2d/;40
1`2d/;400`11JN40[Jf]09nKX00309nKX0040:f][@2OVj00Wi^P0:f][@80L6ii0P2][Jdo0;3PiP40
oooo001F0;3PiP030:f][@1SH5<0Hf1C0080Hf1C00@0[Jf]08Z5M@2:QGD0[Jf]0P2:QGD00`11JN40
[Jf]0:BNS`0:0:BNS`030:f][@11JN40/J^M00@0/J^M0P11JN420;6[W@80@FWQ00<0[Jf]0;6[W@2]
[Jd01@2i/ZH2045Yh@@0^K:V0P11JN420;VbYP030:f][@2n]j`0_[N/00<0@FWQ102n]j`00`11JN40
_[N/0;jg[0070;jg[0030:f][@31^[00`KZ`00l0`KZ`202][Jd@0<>m/`80@FWQ5@35_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00T0b<6k1`2][Jd30<S1^`030:f][@37`K`0al6l0140
al6l00<0@FWQ0<K0_036`;`00`36`;`00`11JN40a/2l0<K0_0030<K0_080@FWQ1@36`;`2045Yh@H0
`kfk0P11JN440<>m^`80@FWQ0`2][Jd40;ji^080@FWQ0`2n^KP01011JN40_[Vh0;ji^011JN490;B`
/@04045Yh@2][Jd0Wi^P09nKX080[Jf]0`2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool0
05H0/>3V00<0[Jf]06=PD`1SH5<00P1SH5<0202][Jd0RXEe08Z5M@2:QGD0[Jf]08Z5M@11JN40[Jf]
2`2TWXl00`2][Jd0@FWQ0;6[W@040;6[W@80@FWQ0P2aZid2045Yh@040;6[W@2][Jd0[Jf]0:f][@D0
^K:V00<0@FWQ0;VbYP2i/ZH00P2i/ZH2045Yh@80^K:V00<0[Jf]0;jg[02n]j`00`11JN430;jg[080
@FWQ2@2n]j`4045Yh@<0`KZ`00<0@FWQ0<6j/031^[002P31^[000`2][Jd0`kfc0<>m/`030<>m/`/0
[Jf]1@33_K<2045YhAD0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^003
0:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/80:f]
[@X0b<6k00<0[Jf]0<O1_037`K`02P37`K`3045Yh@80al6l0P11JN400`2][Jd0a/2l0<K0_0030<K0
_080@FWQ1036`;`2045Yh@D0a/2l0P11JN460<>m^`@0@FWQ00P0`kfk0:f][@11JN40@FWQ0<>m^`2]
[Jd0_[Vh045Yh@<0_[Vh0P11JN420;ji^005045Yh@2n^KP0_[Vh0;ji^02][Jd02@2d/;401011JN40
[Jf]09nKX02][Jd509nKX0030:f][@1`KWT0L6ii0080[Jf]?`2`h>H10?ooo`00EP2`h>H00`2][Jd0
Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe0080RXEe00<0[Jf]08Z5M@2][Jd02`2TWXl00`2][Jd0
@FWQ0;6[W@040;6[W@80@FWQ0P2aZid2045Yh@80/J^M00<0[Jf]0;VbYP2][Jd00P2][Jd30;VbYP04
045Yh@2i/ZH0^K:V0;VbYP80@FWQ0P2i/ZH00`2][Jd0_[N/0;jg[003045Yh@<0_[N/0P11JN480;jg
[003045Yh@2][Jd0`KZ`0080`KZ`0P11JN400`31^[00@FWQ0<6j/0030<6j/0<0@FWQ1@31^[000`2]
[Jd0`kfc0<>m/`0>0<>m/`D0[Jf]0P11JN440:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2]
[Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38`K/03`38`K/90:f]
[A80b<6k00<0[Jf]0<O1_037`K`02@37`K`02@11JN40al6l0<O1_037`K`0@FWQ0<O1_011JN40al6l
0:f][@050<K0_080@FWQ0`36`;`3045Yh@D0a/2l0P11JN450<>m^`<0@FWQ0`2][Jd01@33_K/0@FWQ
045Yh@33_K/0[Jf]0080@FWQ102n^KP01011JN40_[Vh0;ji^011JN430;ji^0030:f][@2d/;40];2a
00L0];2a00<0@FWQ0:f][@2][Jd01P2OVj000`2][Jd0L6ii071^N@020:f][Cl0/>3V0@3oool005H0
/>3V00<0[Jf]06=PD`1SH5<00P1SH5<00`2][Jd0RXEe08Z5M@0308Z5M@80[Jf]2`2TWXl00`2][Jd0
@FWQ0;6[W@040;6[W@80@FWQ0P2aZid2045Yh@80/J^M00<0[Jf]045Yh@2i/ZH00P2i/ZH30:f][@04
0;VbYP11JN40@FWQ0;VbYP80@FWQ0P2i/ZH01P2][Jd0_[N/0;jg[011JN40_[N/045Yh@<0_[N/0`11
JN460;jg[080@FWQ00<0[Jf]0<6j/031^[000`31^[02045Yh@H0`KZ`1011JN420<6j/0030:f][@33
_K<0`kfc01<0`kfc0P11JN440<Fn]@`0[Jf]1@35_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37
`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38
`K/00`2][Jd0b<6k0<S1^`0B0<S1^`<0@FWQ2@37`K`00`11JN40al6l0<O1_0030<O1_080@FWQ00<0
al6l0:f][@36`;`00`36`;`00`11JN40a/2l045Yh@030<K0_0<0@FWQ1@36`;`2045Yh@H0`kfk0P2]
[Jd40<>m^`80@FWQ00@0`kfk0:f][@11JN40@FWQ1@2n^KP2045Yh@@0_[Vh00<0[Jf]0;B`/@2d/;40
1P2d/;400`11JN40];2a0:f][@0709nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?ooo`00
EP2`h>H00`2][Jd0Hf1C06=PD`0206=PD`030:f][@2:QGD0RXEe00@0RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2aZid0@FWQ0080/J^M0`11JN400`2aZid0@FWQ
045Yh@060;VbYP<0[Jf]0`11JN420;VbYP060:f][@2n]j`0@FWQ045Yh@2n]j`0@FWQ0`2n]j`00`11
JN40_[N/045Yh@060;jg[080@FWQ1P31^[02045Yh@H0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc
01<0`kfc0P11JN4@0<Fn]A40[Jf]3036_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j
00X0al6j4@2][JdA0<S1^`030:f][@38`K/0b<6k00h0b<6k1011JN400`38`K/0[Jf]0<O1_0080<O1
_080@FWQ1P37`K`00`11JN40al6l0:f][@040<K0_003045Yh@36`;`0@FWQ00<0a/2l00<0@FWQ0<K0
_011JN401@36`;`2045Yh@<0`kfk0`2][Jd60<>m^`80@FWQ00@0`kfk0:f][@2n^KP0@FWQ2`2n^KP0
0`2][Jd0];2a0;B`/@060;B`/@<0[Jf]1`2OVj001@2][Jd0L6ii071^N@1`KWT0[Jf]03l0/>3V0@3o
ool005H0/>3V00D0[Jf]06=PD`1SH5<0Hf1C0:f][@0708Z5M@<0[Jf]2@2TWXl00`2][Jd0@FWQ0;6[
W@030;6[W@80@FWQ0P2aZid4045Yh@040;6[W@11JN40^K:V045Yh@<0^K:V0P11JN430;VbYP<0@FWQ
00@0[Jf]0;VbYP2][Jd0_[N/0P11JN420;jg[006045Yh@2n]j`0_[N/045Yh@2n]j`0@FWQ1P2n]j`0
0`11JN40[Jf]0<6j/0060<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN440<6j/0030:f][@33_K<0
`kfc00H0`kfc1011JN490<>m/`80@FWQ5@35_[D00`2][Jd0a[ng0<Jo]`090<Jo]c00[Jf]2`37`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k00<0b<6k1011JN4:0<S1^`03045Yh@38`K/0
[Jf]00T0al6l0P11JN460<O1_003045Yh@37`K`0[Jf]00@0a/2l00@0@FWQ0<K0_011JN40@FWQ0P36
`;`01011JN40a/2l0<K0_011JN440<K0_080@FWQ0`2][Jd90<>m^`<0@FWQ00<0[Jf]0;ji^011JN40
2`2n^KP00`2][Jd0];2a0;B`/@050;B`/@040:f][@2d/;40];2a0:f][@L0Wi^P00D0[Jf]071^N@1`
KWT0L6ii0:f][@0o0;3PiP40oooo001F0;3PiP050:f][@1SH5<0Hf1C06=PD`2][Jd01`2:QGD00`2]
[Jd0Y9j?0:BNS`020:f][@L0Y9j?00<0[Jf]045Yh@2aZid00`2aZid2045Yh@H0/J^M00<0@FWQ0:f]
[@11JN40102i/ZH2045Yh@@0^K:V0P11JN40102i/ZH0[Jf]0:f][@2][Jd2045Yh@80_[N/00H0@FWQ
0;jg[011JN40@FWQ0;jg[011JN460;jg[003045Yh@2][Jd0`KZ`00H0`KZ`00<0@FWQ0<6j/031^[00
1031^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<01033_K<3045Yh@80`kfc00<0@FWQ0<>m/`33_K<0
0P33_K<2045Yh@<0`kfc0P11JN4E0<Fn]@030:f][@36_kL0a[ng01@0a[ng00<000000:f][@37`KP0
5@37`KP00`2][Jd0al6j0<O1^P0E0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]045Yh@11JN40
0`11JN440<S1^`80@FWQ2038`K/00`11JN40b<6k0:f][@090<O1_080@FWQ1P37`K`00`11JN40al6l
0:f][@040<K0_080@FWQ00D0a/2l045Yh@36`;`0a/2l045Yh@020<K0_003045Yh@36`;`0a/2l0080
[Jf]0P11JN4<0<>m^`80@FWQ00<0`kfk045Yh@11JN40302n^KP00`2][Jd0];2a0;B`/@030;B`/@80
[Jf]0`2d/;400`2][Jd0Wi^P09nKX00509nKX0050:f][@1`KWT0L6ii071^N@2][Jd0?`2`h>H10?oo
o`00E`2`h>H0102][Jd0Hf1C06=PD`2][Jd708Z5M@030:f][@2TWXl0Y9j?0080Y9j?00<0[Jf]0:BN
S`2TWXl0102TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2aZid0/J^M00H0/J^M0P11JN440;Vb
YP03045Yh@2i/ZH0^K:V00<0^K:V00H0@FWQ0;VbYP2i/ZH0^K:V0:f][@2n]j`2045Yh@80[Jf]00H0
@FWQ0;jg[011JN40@FWQ0;jg[011JN450;jg[080@FWQ00<0[Jf]0<6j/031^[001@31^[000`11JN40
`KZ`0<6j/0040<6j/080@FWQ1031^[000`2][Jd0`kfc0<>m/`040<>m/`03045Yh@33_K<0`kfc00<0
`kfc00<0@FWQ0<>m/`33_K<00P11JN440<>m/`80@FWQ0P35_[D3045YhA00aKje00<0[Jf]0<Jo]`36
_kL05@36_kL00`2][Jd0al6h0<O1^00D0<O1^0030:f][@37`KX0al6j01D0al6j00<0[Jf]0<S1^`38
`K/05038`K/01@2][Jd0b<6k0<S1^`38`K/0@FWQ00H0b<6k0P11JN470<S1^`03045Yh@38`K/0[Jf]
00T0al6l0P11JN460<O1_003045Yh@37`K`0[Jf]00@0a/2l0P11JN401@36`;`0@FWQ0<K0_036`;`0
@FWQ0080[Jf]00<0@FWQ0:f][@2][Jd00P36`;`2045Yh@X0`kfk1011JN400`33_K/0[Jf]0;ji^00<
0;ji^0040:f][@2d/;40];2a0;B`/@80[Jf]1@2d/;400`2][Jd0Wi^P09nKX00509nKX0040:f][@1`
KWT0L6ii0:f][D00/>3V0@3oool005L0/>3V00@0[Jf]06=PD`1SH5<0[Jf]1`2:QGD00`2][Jd0Y9j?
0:BNS`030:BNS`80[Jf]102TWXl00`2][Jd0@FWQ0;6[W@030;6[W@03045Yh@2aZid0/J^M00H0/J^M
00<0[Jf]0;VbYP2i/ZH0102i/ZH00`11JN40^K:V0;VbYP020;VbYP06045Yh@2i/ZH0^K:V0;VbYP2]
[Jd0_[N/0P11JN420;jg[006045Yh@2][Jd0@FWQ0:f][@2n]j`0@FWQ1@2n]j`00`11JN40_[N/0:f]
[@070<6j/003045Yh@31^[00`KZ`00@0`KZ`0P11JN440<6j/0030:f][@33_K<0`kfc00@0`kfc00<0
@FWQ0<>m/`33_K<01033_K<3045Yh@D0`kfc1011JN430<Fn]@03045Yh@35_[D0aKje00D0aKje1`11
JN400`35_[D0[Jf]0<Jo]`0F0<Jo]`030:f][@37`KP0al6h01@0al6h00<0[Jf]0<O1^P37`KX05@37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`050:f][@38`K/0b<6k0<S1^`11JN401`38`K/2045Yh@H0b<6k
00<0@FWQ0<S1^`2][Jd02@37`K`2045Yh@H0al6l0P11JN400`2][Jd0a/2l0<K0_0020<K0_080@FWQ
00D0a/2l045Yh@2][Jd0[Jf]045Yh@020<K0_003045Yh@36`;`0a/2l0080a/2l0P11JN4?0<>m^`03
0:f][@2n^KP0_[Vh00/0_[Vh00@0[Jf]0;B`/@2d/;40[Jf]1`2d/;400`2][Jd0Wi^P09nKX00509nK
X0040:f][@1`KWT0L6ii0:f][D00/>3V0@3oool005P0/>3V00<0[Jf]06=PD`2][Jd01`2:QGD00`2]
[Jd0Y9j?0:BNS`050:BNS`80[Jf]00@0Y9j?045Yh@11JN40@FWQ0`2aZid00`11JN40/J^M0;6[W@06
0;6[W@030:f][@2i/ZH0^K:V00H0^K:V00@0@FWQ0;VbYP2i/ZH0@FWQ102i/ZH00`2][Jd0_[N/045Y
h@030;jg[006045Yh@2n]j`0@FWQ0;jg[02][Jd0@FWQ0P2][Jd30;jg[003045Yh@2n]j`0[Jf]00L0
`KZ`00<0@FWQ0<6j/031^[001031^[02045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<2045Yh@L0
`kfc0P11JN450<>m/`80@FWQ1P35_[D00`11JN40aKje0<Fn]@070<Fn]@03045Yh@35_[D0aKje0080
aKje00<0[Jf]045Yh@11JN401@11JN420<Jo]`L0@FWQ1`36_kL00`2][Jd0al6h0<O1^00D0<O1^005
0:f][@37`KX0al6j0<O1^P11JN404`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`050:f][@38`K/0b<6k
0<S1^`11JN401`38`K/2045Yh@H0b<6k00<0@FWQ0<S1^`2][Jd02P37`K`2045Yh@D0al6l0P11JN40
0`2][Jd0a/2l0<K0_0020:f][@80@FWQ00D0[Jf]0<K0_011JN40a/2l045Yh@020<K0_003045Yh@36
`;`0a/2l0080a/2l0P11JN4?0<>m^`030:f][@2n^KP0_[Vh00/0_[Vh0`2][Jd80;B`/@030:f][@2O
Vj00Wi^P00D0Wi^P00<0[Jf]071^N@2][Jd0@@2`h>H10?ooo`00F02`h>H00`2][Jd0Hf1C0:f][@07
08Z5M@030:f][@2TWXl0Y9j?00L0Y9j?0`2][Jd2045Yh@80/J^M00<0@FWQ0;6[W@2aZid01P2aZid0
0`2][Jd0^K:V0;VbYP070;VbYP80@FWQ1@2i/ZH00`2][Jd0@FWQ045Yh@030;jg[003045Yh@2n]j`0
@FWQ0080_[N/00<0@FWQ0;jg[02n]j`00`2][Jd00`11JN40_[N/0:f][@040<6j/0@0@FWQ1P31^[02
045Yh@@0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<2045Yh@L0`kfc0P11JN450<>m/`80@FWQ1P35_[D0
0`11JN40aKje0<Fn]@070<Fn]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL00P11JN47
0<Jo]`80@FWQ2@36_kL4045Yh@P0al6h00@0@FWQ0<O1^037`KP0al6h1011JN440<O1^0060:f][@37
`KX0al6j045Yh@37`KX0@FWQ4P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`050:f][@38`K/0b<6k0<S1
^`11JN402038`K/2045Yh@D0b<6k00<0@FWQ0<S1^`2][Jd02P37`K`4045Yh@<0al6l0P11JN430:f]
[@80a/2l0P11JN420<K0_0<0@FWQ0`36`;`01011JN40a/2l0<K0_036`;`2045Yh@L0`kfk00<0@FWQ
0<>m^`33_K/01@33_K/00`2][Jd0_[Vh0;ji^00:0;ji^080[Jf]2P2d/;400`2][Jd0Wi^P09nKX005
09nKX0030:f][@1`KWT0[Jf]0440/>3V0@3oool005T0/>3V0P2][Jd708Z5M@030:f][@2TWXl0Y9j?
00T0Y9j?0P2][Jd00`2aZid0@FWQ045Yh@090;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]045Y
h@11JN40102n]j`2045Yh@<0_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40[Jf]0:f][@030:f]
[@@0`KZ`0`11JN440<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0[Jf]0<>m/`33_K<00`33_K<2045Y
h@L0`kfc0P11JN450<>m/`80@FWQ1`35_[D00`11JN40aKje0<Fn]@060<Fn]@03045Yh@35_[D0aKje
0080aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ1`36_kL3045Yh@030:f][@37`KP0al6h
0080@FWQ1P37`KP01011JN40al6h045Yh@11JN440<O1^080@FWQ0P37`KP00`2][Jd0al6j0<O1^P02
045YhA<0al6j00<0[Jf]0<S1^`38`K/05038`K/01@2][Jd0b<6k0<S1^`38`K/0@FWQ00P0b<6k0P11
JN450<S1^`03045Yh@38`K/0[Jf]00`0al6l0P2][Jd5045Yh@070:f][@36`;`0a/2l0<K0_011JN40
a/2l045Yh@020<K0_080@FWQ1036`;`01011JN40a/2l0<K0_036`;`2045Yh@L0`kfk00<0@FWQ0<>m
^`33_K/01@33_K/00`2][Jd0_[Vh0;ji^0080;ji^080[Jf]00<0_[Vh0:f][@2d/;402@2d/;400`2]
[Jd0Wi^P09nKX00509nKX080[Jf]@P2`h>H10?ooo`00F@2`h>H20:f][@L0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0:f][@020:f][@T0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH3045Yh@@0
_[N/00<0@FWQ0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0020;jg[003045Yh@2n]j`0[Jf]00<0
`KZ`1`2][Jd40<6j/003045Yh@31^[00`KZ`00<0`KZ`00<0[Jf]0<>m/`33_K<01033_K<00`11JN40
`kfc0<>m/`050<>m/`80@FWQ1@33_K<2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D01P35_[D00`11JN40
aKje0<Fn]@020<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@H0a[ng0P11JN420<Jo]`03
0:f][@37`KP0al6h0080al6h00<0@FWQ0<O1^037`KP00`37`KP2045Yh@L0al6h00@0@FWQ0<O1^037
`KP0[Jf]0`37`KX00`11JN40al6j0<O1^P0A0<O1^P030:f][@38`K/0b<6k01@0b<6k00D0[Jf]0<S1
^`38`K/0b<6k045Yh@080<S1^`80@FWQ1@38`K/00`11JN40b<6k0:f][@070<O1_0D0[Jf]1@37`K`2
045Yh@040:f][@36`;`0a/2l0<K0_080@FWQ0`36`;`2045Yh@@0a/2l0`11JN400`36`;`0[Jf]045Y
h@070<>m^`03045Yh@33_K/0`kfk00D0`kfk00<0[Jf]0;ji^02n^KP01P2n^KP20:f][@<0_[Vh00<0
[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX00409nKX080[Jf]@P2`h>H10?ooo`00FP2`h>H0
0`2][Jd0RXEe08Z5M@0508Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid00P2aZid2
0:f][@L0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/045Yh@02045Yh@80_[N/00<0@FWQ
0;jg[02n]j`00P2n]j`00`11JN40_[N/0;jg[0020;jg[003045Yh@2n]j`0[Jf]00X0`KZ`102][Jd0
0`11JN40[Jf]0:f][@030<6j/0030:f][@33_K<0`kfc00@0`kfc0P11JN460<>m/`80@FWQ1@33_K<2
045Yh@L0aKje0P11JN470<Fn]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL00P11JN47
0<Jo]`80@FWQ1P36_kL2045Yh@80a[ng00<0[Jf]0<O1^037`KP00`37`KP00`11JN40al6h0<O1^002
0<O1^003045Yh@37`KP0al6h00H0al6h00D0@FWQ0<O1^037`KP0al6h0:f][@0F0<O1^P030:f][@38
`K/0b<6k01@0b<6k00D0[Jf]0<S1^`38`K/0b<6k045Yh@090<S1^`03045Yh@38`K/0b<6k00<0b<6k
0P11JN400`2][Jd0al6l0<O1_0050:f][@X0al6l00<0@FWQ0<O1_02][Jd00`36`;`2045Yh@@0a/2l
00<0@FWQ0<K0_036`;`00`11JN430<K0_0030:f][@11JN40`kfk00H0`kfk00<0@FWQ0<>m^`33_K/0
1@33_K/00`2][Jd0_[Vh0;ji^0030;ji^0<0[Jf]1@2n^KP00`2][Jd0];2a0;B`/@090;B`/@030:f]
[@2OVj00Wi^P00@0Wi^P00<0[Jf]0;3PiP2`h>H0@@2`h>H10?ooo`00F`2`h>H00`2][Jd0RXEe08Z5
M@0408Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[W@2aZid0102aZid30:f][@@0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[0040;jg[003045Yh@2n]j`0_[N/00<0@FWQ102n
]j`00`11JN40_[N/0:f][@0>0<6j/003045Yh@31^[00`KZ`00L0[Jf]1033_K<3045Yh@@0`kfc0P11
JN450<>m/`80@FWQ1`35_[D2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D00P35_[D00`2][Jd0a[ng0<Jo
]`02045Yh@L0a[ng0P11JN460<Jo]`80@FWQ0P36_kL00`2][Jd0al6h0<O1^0080<O1^003045Yh@37
`KP0al6h00L0al6h00@0@FWQ0<O1^037`KP0[Jf]5P37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`050:f]
[@38`K/0b<6k0<S1^`11JN402@38`K/00`11JN40b<6k0<S1^`020<S1^`030:f][@11JN40@FWQ00<0
[Jf]2037`K`2045Yh@D0al6l00<0@FWQ0<O1_02][Jd00`36`;`4045Yh@80a/2l00<0@FWQ0<K0_036
`;`01`36`;`00`11JN40`kfk0<>m^`050<>m^`03045Yh@33_K/0`kfk00D0`kfk00@0[Jf]0;ji^02n
^KP0_[Vh0P2][Jd80;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000`2OVj000`2]
[Jd0/>3V0;3PiP120;3PiP40oooo001L0;3PiP030:f][@2:QGD0RXEe00<0RXEe00<0[Jf]0:BNS`2T
WXl02@2TWXl00`2][Jd0/J^M0;6[W@070;6[W@<0[Jf]00<0/J^M0:f][@2i/ZH03`2i/ZH00`2][Jd0
_[N/0;jg[0090;jg[0<0@FWQ0P2n]j`00`11JN40_[N/0:f][@0>0<6j/080@FWQ1031^[00102][Jd0
`kfc0<>m/`33_K<70:f][@80@FWQ0P33_K<2045Yh@D0`kfc0P11JN470<Fn]@80@FWQ1`35_[D00`11
JN40aKje0<Fn]@020<Fn]@030:f][@36_kL0a[ng0080@FWQ1`36_kL2045Yh@D0a[ng0P11JN430<Jo
]`030:f][@37`KP0al6h0140al6h0P11JN420<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1
^`38`K/05038`K/01@2][Jd0b<6k0<S1^`38`K/0@FWQ00L0b<6k0P2][Jd00`11JN40[Jf]0:f][@02
0:f][@040<S1^`11JN40@FWQ0:f][@<0al6l00<0@FWQ0<O1_037`K`01037`K`2045Yh@@0al6l00D0
@FWQ0<O1_037`K`0[Jf]0<K0_004045Yh@h0a/2l0P11JN450<>m^`80@FWQ1`33_K/0102][Jd0_[Vh
0:f][@2][Jd:0;ji^0030:f][@2d/;40];2a00T0];2a00<0[Jf]09nKX02OVj000P2OVj000`2][Jd0
/>3V0;3PiP130;3PiP40oooo001M0;3PiP030:f][@2:QGD0RXEe0080RXEe00<0[Jf]0:BNS`2TWXl0
2@2TWXl00`2][Jd0/J^M0;6[W@0:0;6[W@<0[Jf]3`2i/ZH00`2][Jd0_[N/0;jg[00>0;jg[003045Y
h@2n]j`0[Jf]00h0`KZ`0P11JN440<6j/003045Yh@33_K<0`kfc00P0`kfc0P2][Jd4045Yh@80[Jf]
0`33_K<2045Yh@L0aKje0P11JN470<Fn]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL0
0P11JN470<Jo]`80@FWQ1@36_kL2045Yh@<0a[ng00<0[Jf]0<O1^037`KP03`37`KP3045Yh@<0al6h
00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`050:f][@38`K/0b<6k0<S1^`11
JN401`2][Jd20<S1^`03045Yh@38`K/0b<6k00<0b<6k0P11JN40102][Jd0al6l0<O1_037`K`2045Y
h@H0al6l00D0@FWQ0<O1_037`K`0al6l045Yh@030<O1_0030:f][@36`;`0a/2l0140a/2l0P11JN45
0<>m^`80@FWQ1P33_K/30:f][@`0_[Vh00<0[Jf]0;B`/@2d/;402@2d/;400`2][Jd0Wi^P09nKX002
0:f][DH0/>3V0@3oool005h0/>3V0P2][Jd208Z5M@030:f][@2TWXl0Y9j?00T0Y9j?00<0[Jf]0;6[
W@2aZid02`2aZid00`2][Jd0^K:V0:f][@030:f][@/0^K:V00<0[Jf]0;jg[02n]j`03P2n]j`2045Y
h@030:f][@31^[00`KZ`00`0`KZ`00<0@FWQ0<6j/011JN400`31^[000`11JN40`kfc0<>m/`040<>m
/`03045Yh@33_K<0`kfc00D0`kfc0P11JN420<>m/`<0[Jf]0P11JN440:f][@<0aKje0P11JN470<Fn
]@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ1@36_kL2045Y
h@<0a[ng00<0[Jf]0<O1^037`KP03P37`KP3045Yh@@0al6h00@0[Jf]0<O1^P37`KX0@FWQ4`37`KX0
0`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]00<0@FWQ0<S1^`38`K/01`38`K/2045Yh@@0b<6k0`11JN43
0<O1_080@FWQ1`37`K`4045Yh@<0al6l00<0[Jf]0<K0_036`;`04@36`;`00`2][Jd0@FWQ045Yh@03
0<>m^`03045Yh@33_K/0@FWQ00<0`kfk0`2][Jd00`33_K/0[Jf]0;ji^00<0;ji^0030:f][@2d/;40
];2a00T0];2a00<0[Jf]09nKX02][Jd0B02`h>H10?ooo`00H02`h>H00`2][Jd0RXEe0:f][@0;0:BN
S`030:f][@2aZid0/J^M00/0/J^M00<0[Jf]0;VbYP2i/ZH00`2i/ZH30:f][@P0^K:V00<0[Jf]0;jg
[02n]j`03P2n]j`2045Yh@030:f][@31^[00`KZ`00T0`KZ`0P11JN401@31^[00@FWQ0<6j/031^[00
@FWQ0080`KZ`0P11JN450<>m/`80@FWQ1P33_K<2045Yh@D0`kfc0P11JN440<Fn]@<0[Jf]0P11JN47
0:f][@03045Yh@35_[D0aKje0080aKje00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ1@36_kL2
045Yh@<0a[ng00<0[Jf]0<O1^037`KP03037`KP3045Yh@H0al6h00@0[Jf]0<O1^P37`KX0@FWQ4`37
`KX00`2][Jd0b<6k0<S1^`030<S1^``0[Jf]1@38`K/01@2][Jd0b<6k0<S1^`38`K/0@FWQ00T0b<6k
0P11JN440<S1^`80@FWQ00<0[Jf]045Yh@37`K`00P37`K`00`11JN40al6l0<O1_00=0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`11JN400`11JN430<>m^`<0[Jf]1033_K/00`2][Jd0_[Vh
0;ji^00;0;ji^0030:f][@2d/;40];2a00T0];2a0P2][Je90;3PiP40oooo001Q0;3PiP80[Jf]2P2T
WXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00H0^K:V0`2][Jd50;VbYP030:f][@2n
]j`0_[N/00h0_[N/0P11JN400`2][Jd0`KZ`0<6j/0050<6j/003045Yh@31^[00`KZ`00<0`KZ`0P11
JN420<6j/003045Yh@31^[00`KZ`0080@FWQ1@33_K<2045Yh@H0`kfc00<0@FWQ0<>m/`33_K<01033
_K<2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D01P35_[D00`11JN40[Jf]0:f][@050:f][@80@FWQ1`2]
[Jd2045Yh@D0a[ng0P11JN430<Jo]`030:f][@37`KP0al6h00/0al6h0`11JN470<O1^0040:f][@37
`KX0al6j045Yh@P0al6j4@2][JdA0<S1^`040:f][@38`K/0b<6k0<S1^`80@FWQ2038`K/2045Yh@@0
b<6k0P11JN400`2][Jd0al6l045Yh@03045Yh@l0al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0
`kfk0<>m^`020<>m^`@0[Jf]1`33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00P0
];2a00<0[Jf]0;3PiP2`h>H0B02`h>H10?ooo`00HP2`h>H00`2][Jd0Y9j?0:BNS`080:BNS`030:f]
[@2aZid0/J^M00`0/J^M00<0[Jf]0;VbYP2i/ZH02@2i/ZH40:f][@030;VbYP2][Jd0_[N/0100_[N/
0P11JN470<6j/003045Yh@31^[00`KZ`00P0`KZ`0`11JN470<>m/`03045Yh@33_K<0`kfc00@0`kfc
00<0@FWQ0<>m/`33_K<01033_K<2045Yh@L0aKje00<0@FWQ0<Fn]@35_[D01@35_[D2045Yh@@0aKje
00<0[Jf]0<Jo]`36_kL00P11JN470<Jo]`80@FWQ1@2][Jd2045Yh@P0[Jf]00<0@FWQ0:f][@2][Jd0
102][Jd3045Yh@`0[Jf]00<0@FWQ0:f][@2][Jd01P2][Jd;0<O1^P030:f][@38`K/0b<6k01@0b<6k
00@0[Jf]0<S1^`38`K/0b<6k0P11JN480<S1^`80@FWQ0P38`K/4045Yh@030:f][@37`K`0al6l0180
al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@020:f][@/0`kfk00<0[Jf]0;ji^02n
^KP0302n^KP00`2][Jd0];2a0;B`/@060;B`/@80[Jf]B`2`h>H10?ooo`00H`2`h>H20:f][@P0Y9j?
00<0[Jf]0;6[W@2aZid0302aZid00`2][Jd0^K:V0;VbYP0=0;VbYP<0[Jf]402n]j`2045Yh@H0`KZ`
0P11JN4<0<6j/0030:f][@33_K<0`kfc00H0`kfc0P11JN430<>m/`03045Yh@33_K<0`kfc00D0`kfc
0`11JN450<Fn]@03045Yh@35_[D0aKje00H0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng0080@FWQ
1`36_kL2045Yh@H0a[ng0P11JN420<Jo]`070:f][@37`KP0al6h0<O1^011JN40al6h045Yh@040<O1
^0<0@FWQ1`37`KP01011JN40al6h0<O1^02][Jd20<O1^P03045Yh@37`KX0al6j0140al6j00<0[Jf]
0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@P0b<6k00<0@FWQ0<S1^`38`K/01@38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00h0a/2l102][Jd>0<>m^`030:f][@2n
^KP0_[Vh00`0_[Vh00<0[Jf]0;B`/@2d/;401@2d/;400`2][Jd0/>3V0;3PiP1;0;3PiP40oooo001U
0;3PiP80[Jf]1P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02][Jd00`2][Jd<0;jg[080@FWQ1P31^[02045Yh@`0`KZ`00<0[Jf]0<>m/`33_K<02033_K<3
045Yh@D0`kfc0P11JN401033_K<0@FWQ045Yh@11JN440<Fn]@80@FWQ2035_[D3045Yh@<0aKje00@0
[Jf]0<Jo]`11JN40@FWQ2036_kL2045Yh@H0a[ng0P11JN420<Jo]`030:f][@37`KP0al6h0080al6h
0P11JN440<O1^003045Yh@37`KP0al6h00H0al6h0P11JN420<O1^0040:f][@37`KX0al6j045YhA<0
al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@L0b<6k0P11JN470<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`02@36`;`50:f][@80a/2l00<0[Jf]0<>m
^`33_K/03@33_K/00`2][Jd0_[Vh0;ji^00<0;ji^0030:f][@2d/;40];2a00<0];2a0P2][Je>0;3P
iP40oooo001W0;3PiP80[Jf]102TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f][@2i/ZH0^K:V00h0
^K:V00<0[Jf]0;jg[02n]j`00`2n]j`40:f][@T0_[N/0P11JN440<6j/0<0@FWQ3031^[000`2][Jd0
`kfc0<>m/`0B0<>m/`<0@FWQ00<0aKje045Yh@11JN400P11JN4:0<Fn]@80@FWQ00H0aKje045Yh@35
_[D0aKje0:f][@36_kL2045Yh@P0a[ng0P11JN460<Jo]`80@FWQ0P36_kL00`2][Jd0al6h0<O1^002
0<O1^003045Yh@37`KP0al6h00<0al6h00<0@FWQ0<O1^037`KP01P37`KP2045Yh@80al6h00@0[Jf]
0<O1^P37`KX0@FWQ4`37`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`80@FWQ
1`38`K/2045Yh@L0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_0050<K0_0@0[Jf]
1`36`;`00`2][Jd0`kfk0<>m^`0=0<>m^`030:f][@2n^KP0_[Vh00`0_[Vh00@0[Jf]0;B`/@2d/;40
];2a0P2][Je@0;3PiP40oooo001Y0;3PiP80[Jf]0P2TWXl00`2][Jd0/J^M0;6[W@0<0;6[W@030:f]
[@2i/ZH0^K:V00h0^K:V00<0[Jf]0;jg[02n]j`01`2n]j`40:f][@D0_[N/00<0[Jf]045Yh@31^[00
0`31^[03045Yh@`0`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0>0<Fn]@80@FWQ
0P35_[D5045Yh@T0a[ng0P11JN470<Jo]`80@FWQ00<0a[ng0:f][@37`KP00P37`KP00`11JN40al6h
0<O1^0050<O1^003045Yh@37`KP0al6h00@0al6h0`11JN420<O1^0040:f][@37`KX0@FWQ045YhA<0
al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@H0b<6k0P11JN480<S1
^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01@2][Jd;0<K0_0030:f][@33_K/0`kfk
00h0`kfk00<0[Jf]0;ji^02n^KP02`2n^KP0102][Jd0];2a0;B`/@2][JeB0;3PiP40oooo001[0;3P
iP<0[Jf]3P2aZid00`2][Jd0^K:V0;VbYP0>0;VbYP030:f][@2n]j`0_[N/00/0_[N/102][Jd00`2n
]j`0[Jf]0<6j/004045Yh@80`KZ`00<0@FWQ0<6j/031^[002P31^[000`2][Jd0`kfc0<>m/`0C0<>m
/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng00L0a[ng1011JN490<Jo
]`D0@FWQ2@37`KP6045Yh@80al6h00D0@FWQ0<O1^037`KP0[Jf]0<O1^P03045YhA80al6j00<0[Jf]
0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@H0b<6k0P11JN480<S1^`030:f][@37
`K`0al6l0100al6l1@2][Jd@0<K0_0030:f][@33_K/0`kfk00h0`kfk00<0[Jf]0;ji^02n^KP02`2n
^KP30:f][E<0/>3V0@3oool006d0/>3V0P2][Jd=0;6[W@030:f][@2i/ZH0^K:V00h0^K:V00<0[Jf]
0;jg[02n]j`03`2n]j`50:f][@@0`KZ`00<0@FWQ0<6j/031^[002P31^[000`2][Jd0`kfc0<>m/`0C
0<>m/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]
0<O1^037`KP05@37`KP00`2][Jd0al6j045Yh@02045YhA80al6j00<0[Jf]0<S1^`38`K/05038`K/0
102][Jd0b<6k0<S1^`38`K/2045Yh@H0b<6k0P11JN480<S1^`030:f][@37`K`0al6l00/0al6l1@2]
[Jd20<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh0;ji
^00:0;ji^080[Jf]E@2`h>H10?ooo`00K`2`h>H20:f][@/0/J^M00<0[Jf]0;VbYP2i/ZH03P2i/ZH0
0`2][Jd0_[N/0;jg[00@0;jg[0040:f][@31^[00`KZ`0<6j/0L0[Jf]2P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0
[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j045Yh@02045YhA80al6j00<0[Jf]0<S1^`38`K/05038
`K/0102][Jd0b<6k0<S1^`38`K/2045Yh@D0b<6k0P11JN490<S1^`030:f][@37`K`0al6l00D0al6l
1P2][Jd70<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0070;ji^0<0[Jf]E`2`h>H10?ooo`00L@2`h>H30:f][@P0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00P0`KZ`1`2][Jd30<6j/0030:f][@33
_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D03P35_[D2045Yh@@0aKje00<0[Jf]0<Jo]`36_kL05@36
_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0@FWQ0080@FWQ4P37`KX00`2][Jd0b<6k0<S1
^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`80@FWQ1@38`K/2045Yh@T0b<6k00<0[Jf]0<O1_037`K`0
1@2][Jd=0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03P33_K/00`2][Jd0_[Vh
0;ji^0050;ji^080[Jf]FP2`h>H10?ooo`00M02`h>H20:f][@H0/J^M00<0[Jf]0;VbYP2i/ZH03P2i
/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`00l0`KZ`1`2][JdB0<>m/`030:f][@35
_[D0aKje00h0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j045Yh@02045YhA80al6j00<0[Jf]0<S1^`38`K/05038`K/0102][Jd0b<6k0<S1
^`38`K/7045Yh@P0b<6k1P2][JdB0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/0
3P33_K/00`2][Jd0_[Vh0;ji^0020;ji^0<0[Jf]G02`h>H10?ooo`00MP2`h>H30:f][@<0/J^M00<0
[Jf]0;VbYP2i/ZH03P2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00@0
[Jf]0<>m/`33_K<0`kfc1`2][Jd;0<>m/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j045Yh@02045YhA80al6j
00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k045Yh@03045Yh@H0b<6k1`2][Jd30<S1^`030:f]
[@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0<>m^`0>0<>m^`030:f]
[@2n^KP0[Jf]0080[Jf]G`2`h>H10?ooo`00N@2`h>H20:f][@030;6[W@2][Jd0^K:V00l0^K:V00<0
[Jf]0;jg[02n]j`0402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc00P0`kfc202]
[Jd30<>m/`030:f][@35_[D0aKje00h0aKje0P11JN440<Fn]@030:f][@36_kL0a[ng00T0a[ng00<0
@FWQ0<Jo]`36_kL02@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0@FWQ0080@FWQ4P37
`KX00`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]2P38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/03@33_K/30:f][F80/>3V
0@3oool007/0/>3V0`2][Jd?0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0@0<>m/`T0[Jf]2@35_[D4045Yh@@0aKje00<0[Jf]0<Jo]`36_kL02036
_kL00`11JN40a[ng045Yh@0:0<Jo]`030:f][@37`KP0al6h01D0al6h00@0[Jf]0<O1^P11JN40@FWQ
4`37`KX00`2][Jd0b<6k0<S1^`0?0<S1^`T0[Jf]4P38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f]
[@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/02@33_K/40:f][FD0/>3V0@3oool007h0/>3V102]
[Jd;0;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc0<>m
/`0C0<>m/`030:f][@35_[D0aKje00<0aKje302][Jd50<Fn]@030:f][@36_kL0a[ng00T0a[ng00<0
@FWQ0<Jo]`36_kL02@36_kL00`2][Jd0al6h0<O1^00E0<O1^0040:f][@37`KX0al6j045YhA<0al6j
00<0[Jf]0<S1^`38`K/00`38`K/<0:f][@D0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l
0<O1_00B0<O1_0030:f][@36`;`0a/2l0100a/2l00<0[Jf]0<>m^`33_K/01P33_K/30:f][FT0/>3V
0@3oool00880/>3V0`2][Jd80;VbYP030:f][@2n]j`0_[N/0100_[N/00<0[Jf]0<6j/031^[004P31
^[000`2][Jd0`kfc0<>m/`0C0<>m/`030:f][@35_[D0aKje00l0aKje4@2][Jd:0<Jo]`0300000036
_kL0[Jf]00`0al6h:02][JdA0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37
`K`00`2][Jd0a/2l0<K0_00@0<K0_0030:f][@33_K/0`kfk00<0`kfk0`2][Je/0;3PiP40oooo0025
0;3PiP<0[Jf]1@2i/ZH00`2][Jd0_[N/0;jg[00@0;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]
0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng00T0a[ng6@2][Jd;
0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1^`0C
0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`04036`;`00`2][Jd0`kfk0:f][@03
0:f][Fl0/>3V0@3oool008P0/>3V102][Jd00`2i/ZH0[Jf]0;jg[00A0;jg[0030:f][@31^[00`KZ`
0180`KZ`00<0[Jf]0<>m/`33_K<04`33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng
01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k
01@0b<6k00<0[Jf]0<S1^`38`K/04`38`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l
00l0a/2l0`2][Jec0;3PiP40oooo002<0;3PiP@0[Jf]402n]j`00`2][Jd0`KZ`0<6j/00B0<6j/003
0:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`03
0:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`03
0:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`04P37`K`00`2][Jd0a/2l0<K0_00;0<K0_0@0
[Jf]MP2`h>H10?ooo`00T02`h>H50:f][@/0_[N/00<0[Jf]0<6j/031^[004P31^[000`2][Jd0`kfc
0<>m/`0C0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h
0<O1^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k
0<S1^`0C0<S1^`030:f][@37`K`0al6l0180al6l00<0[Jf]0<K0_036`;`01`36`;`40:f][GX0/>3V
0@3oool009D0/>3V102][Jd70;jg[0030:f][@31^[00`KZ`0180`KZ`00<0[Jf]0<>m/`33_K<04`33
_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37
`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f][@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04`38
`K/00`2][Jd0al6l0<O1_00B0<O1_0030:f][@36`;`0a/2l00<0a/2l102][Jen0;3PiP40oooo002I
0;3PiPD0[Jf]0P2n]j`00`2][Jd0`KZ`0<6j/00B0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]
0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]
0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]
0<O1_037`K`04P37`K`00`2][Jd0a/2l0:f][@030:f][H80/>3V0@3oool009h0/>3V1P2][JdA0<6j
/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo
]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0b<6k0<S1^`0D0<S1
^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`03`37`K`50:f][HH0/>3V0@3oool00:@0
/>3V1`2][Jd:0<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D00`2][Jd0
a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX00`2][Jd0
b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00<0[Jf]0<O1_037`K`02037`K`70:f][H/0
/>3V0@3oool00:/0/>3V1`2][Jd30<6j/0030:f][@33_K<0`kfc01<0`kfc00<0[Jf]0<Fn]@35_[D0
5035_[D00`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX0
5037`KX00`2][Jd0b<6k0<S1^`0D0<S1^`030:f][@38`K/0b<6k01<0b<6k00@0[Jf]0<O1_037`K`0
al6l1`2][JfB0;3PiP40oooo002b0;3PiPL0[Jf]4P33_K<00`2][Jd0aKje0<Fn]@0D0<Fn]@030:f]
[@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P0D0<O1^P030:f]
[@38`K/0b<6k01@0b<6k00<0[Jf]0<S1^`38`K/04038`K/70:f][IT0/>3V0@3oool00;T0/>3V1`2]
[Jd;0<>m/`030:f][@35_[D0aKje01@0aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1
^00E0<O1^0030:f][@37`KX0al6j01@0al6j00<0[Jf]0<S1^`38`K/05038`K/00`2][Jd0b<6k0<S1
^`090<S1^`L0[Jf]X02`h>H10?ooo`00`02`h>H80:f][@<0`kfc00<0[Jf]0<Fn]@35_[D05035_[D0
0`2][Jd0a[ng0<Jo]`0E0<Jo]`030:f][@37`KP0al6h01D0al6h00<0[Jf]0<O1^P37`KX05037`KX0
0`2][Jd0b<6k0<S1^`0D0<S1^`040:f][@38`K/0b<6k0<S1^`P0[Jf]Y`2`h>H10?ooo`00b02`h>H9
0:f][A40aKje00<0[Jf]0<Jo]`36_kL05@36_kL00`2][Jd0al6h0<O1^00E0<O1^0030:f][@37`KX0
al6j01@0al6j00<0[Jf]0<S1^`38`K/02@38`K/?0:f][Jl0/>3V0@3oool00=40/>3V302][Jd50<Fn
]@030:f][@36_kL0a[ng01D0a[ng00<0[Jf]0<O1^037`KP05@37`KP00`2][Jd0al6j0<O1^P090<O1
^QL0[Jf]_P2`h>H10?ooo`00g@2`h>I10:f][MD0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {228.438, 0}} -> {-0.00119524, 0.239847, \
0.00192179, 0.00192179}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Show[
      RotateShape[
        Graphics3D[{EdgeForm[], MoebiusStrip[]}, \ 
          AmbientLight -> RGBColor[0, \ 0, \ 1], \ Boxed -> False], Pi/4, 
        Pi/3, Pi/2]]\)\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.15492 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0861925 1.24159 -1.27123e-016 1.24159 [
[ 0 0 0 0 ]
[ 1 1.15492 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.15492 L
0 1.15492 L
closepath
clip
newpath
.426 .258 1 r
.77355 .72988 m .6089 .71268 L .58124 .80727 L F
.77355 .72988 m .58124 .80727 L .72791 .78014 L F
.416 .103 1 r
.6089 .71268 m .72791 .78014 L .58124 .80727 L F
.6089 .71268 m .77355 .72988 L .72791 .78014 L F
.489 .39 1 r
.80949 .66012 m .6089 .71268 L .77355 .72988 L F
.80949 .66012 m .61856 .61937 L .6089 .71268 L F
.512 .305 1 r
.61856 .61937 m .77355 .72988 L .6089 .71268 L F
.61856 .61937 m .80949 .66012 L .77355 .72988 L F
.527 .49 1 r
.83105 .5753 m .61856 .61937 L .80949 .66012 L F
.83105 .5753 m .61149 .53563 L .61856 .61937 L F
.553 .419 1 r
.61149 .53563 m .80949 .66012 L .61856 .61937 L F
.284 .026 1 r
.72791 .78014 m .58124 .80727 L .53609 .89363 L F
.082 0 1 r
.58124 .80727 m .67724 .8089 L .53609 .89363 L F
.58124 .80727 m .72791 .78014 L .67724 .8089 L F
.553 .419 1 r
.61149 .53563 m .83105 .5753 L .80949 .66012 L F
.558 .586 1 r
.83401 .48214 m .61149 .53563 L .83105 .5753 L F
.83401 .48214 m .59047 .46817 L .61149 .53563 L F
.581 .505 1 r
.59047 .46817 m .83105 .5753 L .61149 .53563 L F
.559 .918 1 r
.53609 .89363 m .67724 .8089 L .62581 .81656 L F
.284 .026 1 r
.72791 .78014 m .63683 .83403 L .67724 .8089 L F
.63683 .83403 m .53609 .89363 L .61557 .84592 L F
.63683 .83403 m .61557 .84592 L .67724 .8089 L F
.706 .819 1 r
.47602 .96136 m .57708 .80557 L .40611 .99968 L F
0 0 1 r
.56245 .87781 m .53609 .89363 L .47602 .96136 L F
.67724 .8089 m .56245 .87781 L .47602 .96136 L F
.559 .918 1 r
.53609 .89363 m .62581 .81656 L .47602 .96136 L F
.706 .819 1 r
.47602 .96136 m .62581 .81656 L .57708 .80557 L F
.682 .974 1 r
.53962 .8884 m .47602 .96136 L .40611 .99968 L F
.62581 .81656 m .5678 .87264 L .53962 .8884 L F
.5678 .87264 m .47602 .96136 L .53962 .8884 L F
.594 .696 1 r
.8149 .38944 m .59047 .46817 L .83401 .48214 L F
.8149 .38944 m .55958 .42173 L .59047 .46817 L F
.581 .505 1 r
.59047 .46817 m .83401 .48214 L .83105 .5753 L F
.608 .585 1 r
.55958 .42173 m .83401 .48214 L .59047 .46817 L F
.55958 .42173 m .8149 .38944 L .83401 .48214 L F
.644 .829 1 r
.77158 .30784 m .55958 .42173 L .8149 .38944 L F
.77158 .30784 m .52378 .39859 L .55958 .42173 L F
.643 .67 1 r
.52378 .39859 m .8149 .38944 L .55958 .42173 L F
0 0 1 r
.67724 .8089 m .47602 .96136 L .62581 .81656 L F
.702 .957 1 r
.70397 .24933 m .52378 .39859 L .77158 .30784 L F
.70397 .24933 m .48823 .39833 L .52378 .39859 L F
.643 .67 1 r
.52378 .39859 m .77158 .30784 L .8149 .38944 L F
.691 .762 1 r
.48823 .39833 m .77158 .30784 L .52378 .39859 L F
.729 .722 1 r
.40611 .99968 m .53342 .77969 L .33432 .99873 L F
.40611 .99968 m .57708 .80557 L .53342 .77969 L F
.83 .945 1 r
.57708 .80557 m .40611 .99968 L .33432 .99873 L F
.682 .974 1 r
.62581 .81656 m .40611 .99968 L .57708 .80557 L F
.691 .762 1 r
.48823 .39833 m .70397 .24933 L .77158 .30784 L F
.75 .986 1 r
.61511 .22605 m .48823 .39833 L .70397 .24933 L F
.61511 .22605 m .45752 .41799 L .48823 .39833 L F
.754 .852 1 r
.45752 .41799 m .61511 .22605 L .70397 .24933 L F
.45752 .41799 m .59611 .32315 L .48823 .39833 L F
.825 .916 1 r
.435 .4529 m .54256 .31744 L .45752 .41799 L F
.54256 .31744 m .61511 .22605 L .57067 .28019 L F
.54256 .31744 m .57067 .28019 L .45752 .41799 L F
.821 .919 1 r
.51224 .24792 m .45752 .41799 L .61511 .22605 L F
.51224 .24792 m .435 .4529 L .45752 .41799 L F
.825 .916 1 r
.435 .4529 m .44578 .4243 L .47141 .40705 L F
.44578 .4243 m .51224 .24792 L .47141 .40705 L F
.887 .932 1 r
.4224 .49781 m .51224 .24792 L .435 .4529 L F
.945 .854 1 r
.40705 .31911 m .435 .4529 L .51224 .24792 L F
.887 .932 1 r
.43691 .45744 m .40705 .31911 L .51224 .24792 L F
.945 .854 1 r
.40705 .31911 m .4224 .49781 L .435 .4529 L F
.887 .932 1 r
.4224 .49781 m .42077 .47883 L .43691 .45744 L F
.42077 .47883 m .40705 .31911 L .43691 .45744 L F
.825 .916 1 r
.47141 .40705 m .51224 .24792 L .61511 .22605 L F
.754 .852 1 r
.59611 .32315 m .70397 .24933 L .63413 .29756 L F
.59611 .32315 m .63413 .29756 L .48823 .39833 L F
.746 .665 1 r
.33432 .99873 m .49613 .74301 L .27137 .95187 L F
.33432 .99873 m .53342 .77969 L .49613 .74301 L F
.846 .861 1 r
.53342 .77969 m .33432 .99873 L .27137 .95187 L F
.83 .945 1 r
.57708 .80557 m .33432 .99873 L .53342 .77969 L F
.998 .775 1 r
.31441 .43459 m .4224 .49781 L .40705 .31911 L F
.31441 .43459 m .41998 .54795 L .4224 .49781 L F
.922 .906 1 r
.41998 .54795 m .40705 .31911 L .4224 .49781 L F
.846 .861 1 r
.53342 .77969 m .27137 .95187 L .49613 .74301 L F
.922 .906 1 r
.41998 .54795 m .31441 .43459 L .40705 .31911 L F
.942 .691 1 r
.24882 .57872 m .41998 .54795 L .31441 .43459 L F
.24882 .57872 m .42704 .59973 L .41998 .54795 L F
.924 .861 1 r
.42704 .59973 m .31441 .43459 L .41998 .54795 L F
.771 .634 1 r
.27137 .95187 m .49613 .74301 L .46575 .69913 L F
.27137 .95187 m .46575 .69913 L .22955 .85874 L F
.857 .817 1 r
.49613 .74301 m .22955 .85874 L .46575 .69913 L F
.49613 .74301 m .27137 .95187 L .22955 .85874 L F
.868 .641 1 r
.21997 .72822 m .42704 .59973 L .24882 .57872 L F
.21997 .72822 m .44257 .65073 L .42704 .59973 L F
.924 .861 1 r
.42704 .59973 m .24882 .57872 L .31441 .43459 L F
.903 .823 1 r
.44257 .65073 m .24882 .57872 L .42704 .59973 L F
.81 .625 1 r
.22955 .85874 m .46575 .69913 L .44257 .65073 L F
.22955 .85874 m .44257 .65073 L .21997 .72822 L F
.878 .807 1 r
.46575 .69913 m .21997 .72822 L .44257 .65073 L F
.46575 .69913 m .22955 .85874 L .21997 .72822 L F
.903 .823 1 r
.44257 .65073 m .21997 .72822 L .24882 .57872 L F
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{249.313, 287.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003i00017b000`400?l00000o`00003on@3oool0
0?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3o
ool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00
n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?oo
o`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i
0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo
003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0
oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00T`3oool50=?Zo`@0`M[oG@3oool008h0oooo
2@3Cj_l90<7JoeT0oooo00290?ooo`d0dn[o3@31f_mF0?ooo`00Q03ooolA0=?Zoa80`M[oDP3oool0
07l0oooo5P3Cj_lF0<7Jodh0oooo001n0?ooo`030>?^o`3Cj_l0dn[o01<0dn[o6P31f_m;0?ooo`00
O@3oool20>?^oa@0dn[o6P31f_l30;33odT0oooo001k0?ooo`<0hnko503Cj_lJ0<7Jo`D0/<?oB03o
ool007X0oooo103Sk_lC0=?ZoaT0`M[o202``om70?ooo`00N03oool60>?^oa<0dn[o6031f_l:0;33
odH0oooo001g0?ooo`H0hnko4`3Cj_lG0<7Jo`h0/<?oA03oool007D0oooo203Sk_lB0=?ZoaL0`M[o
402``om30?ooo`00M03oool90>?^oa40dn[o5`31f_lB0;33od80oooo001b0?ooo`X0hnko4P3Cj_lE
0<7JoaD0/<?o@@3oool00740oooo2`3Sk_lA0=?ZoaD0`M[o5`2``om00?ooo`00L03oool;0>?^oa40
dn[o5031f_lK0;33och0oooo001^0?ooo`d0hnko403Cj_lC0<7Jo`030;olo`2``ol0/<?o01/0/<?o
?@3oool006d0oooo3P3Sk_l?0=?Zoa<0`M[o802``oll0?ooo`00J`3oool?0>?^oa00dn[o4@31f_l0
0`2oo?l0/<?o0;33o`0P0;33oc/0oooo001Z0?oooa00hnko3`3Cj_lB0<7Job@0/<?o>P3oool006P0
oooo4P3Sk_l>0=?Zoa00`M[o00<0_oco0;33o`2``ol08P2``ol30:B[ocT0oooo001W0?oooa80hnko
3P3Cj_lA0<7Job80/<?o1`2TZolh0?ooo`00I@3ooolD0>?^o`h0dn[o3P31f_l00`2oo?l0/<?o0;33
o`0P0;33o`T0Y:_o>03oool006D0oooo00<0k>Oo0>?^o`3Sk_l04@3Sk_l=0=?Zo`l0`M[o802``ol=
0:B[ocL0oooo001T0?ooo`80k>Oo4P3Sk_l=0=?Zo`d0`M[o00<0_oco0;33o`2``ol07@2``ol@0:B[
ocL0oooo001S0?ooo`<0k>Oo4P3Sk_l<0=?Zo`h0`M[o7P2``olC0:B[ocH0oooo001R0?ooo`@0k>Oo
4@3Sk_l<0=?Zo``0`M[o00<0_oco0<7Jo`2``ol06`2``olF0:B[ocH0oooo001R0?ooo`@0k>Oo4@3S
k_l<0=?Zo``0`M[o6`2``olJ0:B[ocD0oooo001Q0?ooo`D0k>Oo4@3Sk_l;0=?Zo`X0`M[o00<0_oco
0<7Jo`2``ol06@2``olL0:B[ocD0oooo001P0?ooo`H0k>Oo403Sk_l;0=?Zo`/0`M[o6@2``olP0:B[
oc@0oooo001O0?ooo`L0k>Oo403Sk_l:0=?Zo`T0`M[o00<0_oco0<7Jo`2``ol05P2``olT0:B[oc<0
oooo001N0?ooo`P0k>Oo403Sk_l:0=?Zo`T0`M[o5`2``olV0:B[oc<0oooo001N0?ooo`P0k>Oo3`3S
k_l:0=?Zo`L0`M[o00<0_oco0<7Jo`2``ol0502``olZ0:B[oc80oooo001M0?ooo`T0k>Oo3`3Sk_l9
0=?Zo`P0`M[o502``ol]0:B[oc80oooo001L0?ooo`X0k>Oo3`3Sk_l80=?Zo`H0`M[o00<0_oco0<7J
o`2``ol04P2``ol`0:B[oc40oooo001K0?ooo`/0k>Oo3P3Sk_l80=?Zo`P0`M[o4@2``olc0:B[oc40
oooo001J0?ooo``0k>Oo00<0lM[o0>?^o`3Sk_l02`3Sk_l80=?Zo`@0`M[o00<0_oco0<7Jo`2``ol0
3`2``olg0:B[oc00oooo001J0?ooo`d0k>Oo303Sk_l80=?Zo`H0`M[o3`2``oli0:B[oc00oooo001I
0?ooo`h0k>Oo303Sk_l70=?Zo`<0`M[o00<0_oco0<7Jo`2``ol03@2``olm0:B[obl0oooo001H0?oo
o`l0k>Oo303Sk_l60=?Zo`D0`M[o302``om00:B[obl0oooo001G0?oooa00k>Oo2`3Sk_l70=?Zo`03
0<7Jo`2oo?l0`M[o00`0/<?o>P2TZol909^Eobh0oooo001F0?oooa40k>Oo0P3Sk_l00`3af_l0hnko
0>?^o`060>?^o`H0dn[o0`31f_l:0;33ocD0Y:_o4@2KUOl^0?ooo`00EP3ooolA0>cWo`/0hnko1@3C
j_l00`2oo?l0`M[o0;33o`080;33oc00Y:_o6@2KUOl^0?ooo`00E@3ooolB0>cWo`X0hnko1@3Cj_l0
0`31f_l0oooo0?ooo`0;0?ooobH0Y:_o8@2KUOl^0?ooo`00E03ooolC0>cWo`X0hnko103Cj_lA0?oo
oa`0Y:_o:P2KUOl]0?ooo`00D`3ooolD0>cWo`X0hnko103Cj_lB0?oooa<0Y:_o<P2KUOl]0?ooo`00
DP3ooolE0>cWo`<0hnko00<0lM[o0>?^o`3Sk_l00`3Sk_l40=?ZoaD0oooo2@2TZolj09^Eobd0oooo
001B0?oooaD0k>Oo2@3Sk_l30=?ZoaL0oooo@P2KUOl]0?ooo`00D@3ooolF0>cWo`P0hnko0`3Cj_lI
0?oood40ViGo;@3oool00500oooo5`3/iol00`3af_l0hnko0>?^o`050>?^o`80dn[o6`3ooom109^E
ob`0oooo001?0?oooaP0k>Oo00<0lM[o0>?^o`3Sk_l01@3Sk_l20=?Zoa/0oooo@@2KUOl/0?ooo`00
CP3ooolI0>cWo`050?7Jo`3Sk_l0hnko0>?^o`3af_l00P3Sk_l20=?Zoad0oooo@02KUOl/0?ooo`00
CP3oool00`3/g?l0k>Oo0>cWo`0G0>cWo`H0hnko00<0dn[o0?ooo`3oool07@3ooolo09^Eob`0oooo
001>0?ooo`80k=co603/iol60>?^ob00oooo@02KUOl[0?ooo`00C@3oool40>cLoaL0k>Oo1@3Sk_lR
0?ooocl0ViGo:`3oool004d0oooo1@3/g?lF0>cWo`D0hnko8`3oooln09^Eob/0oooo001<0?ooo`L0
k=co5@3/iol40>?^ob@0oooo?P2KUOl[0?ooo`00C03oool80>cLoa@0k>Oo103Sk_lU0?ooocd0ViGo
:`3oool004/0oooo2P3/g?lC0>cWo`@0hnko9P3ooolm09^EobX0oooo001;0?ooo`/0k=co4P3/iol3
0>?^obL0oooo?@2KUOlZ0?ooo`00BP3oool=0>cLoa40k>Oo0`3Sk_lX0?oooa@0U87o:02KUOlZ0?oo
o`00BP3oool>0>cLoa00k>Oo0P3Sk_lY0?ooobP0U87o502KUOlZ0?ooo`00B@3oool@0>cLo`l0k>Oo
0P3Sk_lY0?oooc`0U87o:P3oool004T0oooo4@3/g?l>0>cWo`80hnko:P3ooolk09B1obX0oooo0018
0?oooa<0k=co3@3/iol00`3Sk_l0oooo0?ooo`0Y0?oooc/0U87o:P3oool004P0oooo4`3/g?l=0>cW
o`030>?^o`3oool0oooo02T0oooo>`2DPOlZ0?ooo`00A`3ooolE0>cLo``0k>Oo;@3ooolj09B1obX0
oooo00170?oooaH0k=co2`3/iol]0?ooocX0U87o:P3oool004H0oooo603/g?l:0>cWobd0oooo>P2D
POlZ0?ooo`00AP3ooolI0>cLo`T0k>Oo;@3ooolj09B1obX0oooo00150?oooa/0k=co203/iol^0?oo
ocT0U87o:P3oool004D0oooo703/g?l70>cWobh0oooo>@2DPOlZ0?ooo`00A03ooolN0>cLo`H0k>Oo
;P3oooli09B1obX0oooo00140?oooal0k=co1@3/iol_0?ooocP0U87o:P3oool004<0oooo8@3/g?l4
0>cWobl0oooo>02DPOlZ0?ooo`00@`3ooolR0>cLo`<0k>Oo;`3ooolh09B1obX0oooo00120?ooob@0
k=co0P3/iol_0?ooocP0U87o:P3oool00480oooo9@3/g?l00`3/iol0oooo0?ooo`0^0?ooo`D0SF_o
<P2DPOlZ0?ooo`00@@3ooolW0>cLoc00oooo2P2=Jol]09B1obX0oooo00110?ooobL0k=co<03oool@
08e[obL0U87o:P3oool00400oooo:@3/g?l_0?oooaD0SF_o8P2DPOlZ0?ooo`00@03ooolY0>cLobl0
oooo6`2=JolL09B1obX0oooo000o0?ooobX0k=co;`3ooolP08e[oaL0U87o:P3oool003l0oooo:P3/
g?l_0?ooobH0SF_o4@2DPOlZ0?ooo`00?P3oool[0>cLobl0oooo:`2=Jol<09B1obX0oooo000n0?oo
ob/0k=co;`3ooola08e[o`H0U87o:P3oool003d0oooo;@3/g?l^0?ooocH0SF_o:`3oool003d0oooo
203Wd_lU0>cLobl0oooo=@2=Jol[0?ooo`00?@3oool?0>OBoah0k=co;`3ooole08e[ob/0oooo000m
0?oooaL0im;o5P3/g?l_0?ooocD0SF_o:`3oool003d0oooo7P3Wd_l?0>cLobl0oooo=@2=Jol[0?oo
o`00?@3ooolV0>OBo`L0k=co;`3ooold08e[ob`0oooo000l0?ooobh0im;o;`3ooold08e[ob`0oooo
000l0?ooobl0im;o;P3ooold08e[ob`0oooo000l0?ooobl0im;o;P3ooold08e[ob`0oooo000l0?oo
obl0im;o;P3ooolc08e[obd0oooo000l0?ooobl0im;o;P3ooolc08e[obd0oooo000k0?oooc40im;o
;@3oool508=>obh0SF_o;@3oool003/0oooo<@3Wd_l]0?ooo`T0Pdko:P2=Jol]0?ooo`00>`3ooola
0>OBobd0oooo3P23C_lT08e[obh0oooo000k0?oooc40im;o;@3ooolB08=>ob00SF_o;P3oool003/0
oooo<P3Wd_l/0?oooaH0Pdko702=Jol^0?ooo`00>P3ooolc0>OBob`0oooo6`23C_lG08e[obh0oooo
000j0?oooc<0im;o;03ooolO08=>oa80SF_o;`3oool003X0oooo<`3Wd_l/0?ooob<0Pdko3P2=Jol_
0?ooo`00>P3ooola0>OBo`<0h<ko:`3ooolX08=>o`T0SF_o;`3oool003X0oooo;P3Wd_l60>3>ob/0
oooo;023C_l508e[obl0oooo000j0?ooob/0im;o2P3Pc_lZ0?oooc00Pdko<03oool003T0oooo:@3W
d_l=0>3>obT0oooo<@23C_l`0?ooo`00>@3ooolV0>OBoa40h<ko:03oool`08=>oc40oooo000i0?oo
ob<0im;o503Pc_lX0?oooc00Pdko<@3oool003T0oooo803Wd_lH0>3>obL0oooo;`23C_lb0?ooo`00
>@3ooolM0>OBoa/0h<ko9`3oool_08=>oc80oooo000h0?oooa/0im;o7`3Pc_lV0?ooobh0Pdko<`3o
ool003P0oooo6@3Wd_lQ0>3>obH0oooo;P23C_lc0?ooo`00>03ooolF0>OBobD0h<ko9@3oool]08=>
oc@0oooo000h0?oooa<0im;o:03Pc_lU0?ooobd0Pdko=03oool003P0oooo403Wd_lZ0>3>o`80fm7o
903oool/08=>ocD0oooo000g0?ooo`h0im;o;03Pc_l40=_Aob<0oooo;023C_le0?ooo`00=`3oool;
0>OBobd0h<ko1`3KdOlR0?ooob/0Pdko=P3oool003L0oooo203Wd_l_0>3>o`P0fm7o8@3oool/08=>
ocH0oooo000g0?ooo`D0im;o<03Pc_l;0=_Aob00oooo2`1Z6_lP08=>ocL0oooo000g0?ooo`80im;o
<P3Pc_l=0=_Aoal0oooo5@1Z6_lF08=>ocL0oooo000f0?oooc<0h<ko403KdOlN0?oooal0JQ[o2`23
C_lh0?ooo`00=`3ooola0>3>oa40fm7o7@3ooolZ06XJocT0oooo000g0?ooobl0h<ko503KdOlL0?oo
obT0JQ[o>P3oool003L0oooo;P3Pc_lF0=_Aoa/0oooo:01Z6_lk0?ooo`00=`3oool]0>3>oaL0fm7o
6P3ooolX06XJoc`0oooo000g0?ooob/0h<ko603KdOl20=SLoaT0oooo9`1Z6_lm0?ooo`00=`3ooolZ
0>3>oaP0fm7o103Hg?lH0?ooobH0JQ[o?P3oool003L0oooo:03Pc_lI0=_Ao`H0f=co5P3ooolV06XJ
ocl0oooo000g0?ooobL0h<ko6@3KdOl80=SLoaD0oooo9@1Z6_m00?ooo`00=`3ooolU0>3>oaX0fm7o
2P3Hg?lD0?ooob@0JQ[o@@3oool003L0oooo903Pc_lJ0=_Ao``0f=co4`3ooolS06XJod80oooo000g
0?ooob80h<ko6`3KdOl>0=SLoa40oooo8`1Z6_m30?ooo`00>03ooolP0>3>oa/0fm7o403Hg?l@0?oo
ob80JQ[oA03oool003P0oooo7P3Pc_lL0=_Aoa80f=co3`3ooolQ06XJodD0oooo000h0?oooad0h<ko
703KdOlC0=SLo`80e?7o303ooolM06XJo`@0503oAP3oool003P0oooo703Pc_lL0=_Aoa<0f=co1@3D
lOl:0?oooaP0JQ[o1`0D0?m80?ooo`00>03ooolJ0>3>oad0fm7o4`3Hg?l70=Cao`T0oooo4`1Z6_l;
01@0odT0oooo000h0?oooaT0h<ko703KdOlD0=SLo`X0e?7o1P3oool?06XJo`h0503oB`3oool003P0
oooo5`3Pc_lM0=_Aoa@0f=co303DlOl50?ooo`X0JQ[o4P0D0?m<0?ooo`00>03ooolF0>3>oad0fm7o
503Hg?l?0=Cao`<0oooo1@1Z6_lE01@0odh0oooo000h0?oooa@0h<ko7P3KdOlD0=SLoa40e?7o00<0
oooo01@0o`0D0?l05`0D0?l00`181_l0oooo0?ooo`1=0?ooo`00>03ooolC0>3>oah0fm7o503Hg?lB
0=Cao`H0[_Wo4`0D0?mA0?ooo`00>03ooolA0>3>oal0fm7o503Hg?lB0=Cao`d0[_Wo30000?mB0?oo
o`00>@3oool?0>3>oal0fm7o5@3Hg?lA0=Cao`d0[_Wo30000?mC0?ooo`00>@3oool>0>3>oal0fm7o
5@3Hg?lA0=Cao`d0[_Wo2`000?mE0?ooo`00>@3oool<0>3>ob00fm7o5@3Hg?lA0=Cao`d0[_Wo2`00
0?mF0?ooo`00>@3oool;0>3>ob00fm7o5@3Hg?lA0=Cao`d0[_Wo2`000?mG0?ooo`00>@3oool90>3>
ob40fm7o5@3Hg?lA0=Cao`d0[_Wo2P000?mI0?ooo`00>@3oool80>3>ob40fm7o5@3Hg?lA0=Cao`d0
[_Wo2P000?mJ0?ooo`00>@3oool60>3>ob80fm7o5@3Hg?lA0=Cao`d0[_Wo2P000?mK0?ooo`00>@3o
ool50>3>ob40fm7o5P3Hg?lB0=Cao``0[_Wo2@000?mM0?ooo`00>@3oool30>3>ob80fm7o5P3Hg?lB
0=Cao``0[_Wo2@000?mN0?ooo`00>@3oool20>3>ob80fm7o5`3Hg?lA0=Cao``0[_Wo2@000?mO0?oo
o`00>@3ooolS0=_AoaL0f=co4@3DlOl<0:kio`P0003oH@3oool003X0oooo8@3KdOlG0=SLoa40e?7o
302^nOl80000of80oooo000j0?ooob00fm7o5`3Hg?lA0=Cao``0[_Wo20000?mS0?ooo`00>`3ooolN
0=_AoaL0f=co4@3DlOl;0:kio`030;CAo`000?l0003o00D0003oI@3oool003/0oooo7@3KdOlG0=SL
oa40e?7o2`2^nOl00`2ddOl0003o0000o`050000ofH0oooo000l0?oooa/0fm7o5`3Hg?lA0=Cao`/0
[_Wo00<0]=7o0000o`000?l01@000?mW0?ooo`00?03ooolJ0=_AoaL0f=co4@3DlOl;0:kio`030;CA
o`000?l0003o00@0003oJ@3oool003d0oooo603KdOlG0=SLoa80e?7o2P2^nOl00`2ddOl0003o0000
o`040000ofX0oooo000m0?oooaL0fm7o603Hg?lA0=Cao`X0[_Wo00<0]=7o0000o`000?l00`000?m/
0?ooo`00?@3ooolF0=_AoaP0f=co4@3DlOl:0:kio`030;CAo`000?l0003o00<0003oK@3oool003h0
oooo4`3KdOlI0=SLoa40e?7o2P2^nOl00`2ddOl0003o0000o`030000ofh0oooo000n0?oooa80fm7o
6@3Hg?lA0=Cao`X0[_Wo00<0]=7o0000o`000?l00P000?m`0?ooo`00?`3oool@0=_AoaT0f=co4@3D
lOl:0:kio`030;CAo`000?l0003o0080003oL@3oool003l0oooo3`3KdOlI0=SLoa40e?7o2P2^nOl0
0`2ddOl0003o0000o`020000og80oooo00100?ooo`d0fm7o6@3Hg?lA0=Cao`X0[_Wo00@0]=7o0000
o`000?l0003oM03oool00400oooo303KdOlI0=SLoa40e?7o2P2^nOl0102ddOl0003o0000o`000?me
0?ooo`00@03oool;0=_AoaT0f=co4P3DlOl90:kio`040;CAo`000?l0003o0000ogH0oooo00110?oo
o`T0fm7o6P3Hg?lA0=Cao`T0[_Wo00<0]=7o0000o`000?l0N03oool00440oooo203KdOlJ0=SLoa40
e?7o2@2^nOl00`2ddOl0003o0000o`1i0?ooo`00@P3oool60=_AoaX0f=co4@3DlOl90:kio`030;CA
o`000?l0003o07X0oooo00120?ooo`D0fm7o6P3Hg?lA0=Cao`T0[_Wo00<0]=7o0000o`3oool0N`3o
ool004<0oooo0`3KdOlJ0=SLoa40e?7o2@2^nOl00`2ddOl0003o0?ooo`1l0?ooo`00@`3oool20=_A
oaX0f=co4@3DlOl90:kio`030;CAo`000?l0oooo07d0oooo00130?oooa/0f=co4@3DlOl90:kio`03
0;CAo`3oool0oooo07h0oooo00150?oooaP0f=co4@3DlOl90:kio`030;CAo`3oool0oooo07l0oooo
00160?oooaH0f=co4@3DlOl90:kioh<0oooo00170?oooaD0f=co4@3DlOl80:kioh@0oooo00190?oo
oa80f=co4@3DlOl70:kiohH0oooo001:0?oooa00f=co4@3DlOl60:kiohP0oooo001;0?ooo`h0f=co
4@3DlOl50:kiohX0oooo001=0?ooo`/0f=co4@3DlOl40:kioh`0oooo001>0?ooo`T0f=co4@3DlOl4
0:kiohd0oooo001?0?ooo`L0f=co4@3DlOl30:kiohl0oooo001A0?ooo`@0f=co4@3DlOl20:kioi40
oooo001B0?ooo`80f=co4@3DlOl00`2^nOl0oooo0?ooo`2A0?ooo`00D`3ooolA0=CaoiD0oooo003i
0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo
003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0
oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool0
0?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3oool00?T0oooo003i0?ooo`00n@3o
ool00?T0oooo003i0?ooo`00n@3oool00001\
\>"],
  ImageRangeCache->{{{0, 248.313}, {286.875, 0}} -> {0.069417, -0.000156983, \
0.0032436, 0.0032436}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Putting Text on a Sphere Using a Stereographic Projection", "Subsection"],

Cell["\<\
In this section we will write text onto a unit sphere. To do so we first \
transform the text to lie along a circle of a given radius. A radius of 1 \
will put the text along the equator of the sphere. A radius greater than 1 \
will put the text in the northern hemisphere. A radius of less than 1 will \
put the text in the southern hemisphere. The complications of using 3D text \
become apparent because the maginification of the text when projected onto \
the sphere varies according to latitude.\
\>", "Text"],

Cell["\<\
After arranging the text on a circle, we have to use the following inverse \
stereographic projection to project the text onto a sphere. The following \
routine will project the text onto sphere of various radius r. We need this \
to project the text just outside the surface of the unit sphere.\
\>", "Text"],

Cell[BoxData[
    \(InverseStereographicProjection[
        r_] := \[IndentingNewLine]{x_?NumericQ, y_?NumericQ, 
          z_} \[RuleDelayed] \[IndentingNewLine]Module[{xp = x/r, yp = y/r, 
            t}, \[IndentingNewLine]t = 
            xp\^2 + yp\^2; \[IndentingNewLine]r {2  x, 2  y, 
                t - 1}/\((t + 1)\)]\)], "Input"],

Cell["\<\
The following projects two text strings onto a sphere. The first is in the \
northern hemisphere and the second is on the opposite side in the southern \
hemisphere.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plot1 = \[IndentingNewLine]Module[{textstring1, 
            textstring2}, \[IndentingNewLine]textstring1 = \
\(Text3D["\<Olimpiada\>", \ {0, 0, 0}, \ {0.2, 0.25}, \ {0, 0, 0}, 
                  Font3D \[Rule] FuturaFont3D] /. 
                DrawingTransform3D[\((1.5 + #2)\) Cos[#1] &, \((1.5 + #2)\) 
                      Sin[#1] &, #3 &]\) /. 
              InverseStereographicProjection[
                1.005]; \[IndentingNewLine]textstring2 = \
\(Text3D["\<Interna\>", \ {0, 0, 0}, \ {0.2, 0.25}, \ {0, 0, 0}, 
                  Font3D \[Rule] FuturaFont3D] /. 
                DrawingTransform3D[\((1 + #2)\) Cos[#1] &, \((1 + #2)\) 
                      Sin[#1] &, #3 &]\) /. 
              InverseStereographicProjection[
                1.005]; \[IndentingNewLine]textstring3 = \(Text3D["\<2005\>", \
\ {0, 0, 0}, \ {0.2, 0.25}, \ {0, 0, 0}, Font3D \[Rule] FuturaFont3D] /. 
                DrawingTransform3D[\((0.5 + #2)\) Cos[#1] &, \((0.5 + #2)\) 
                      Sin[#1] &, #3 &]\) /. 
              InverseStereographicProjection[
                1.005]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]Draw3DItems[\[IndentingNewLine]{SurfaceColor[
                DarkSeaGreen], 
              EdgeForm[], \[IndentingNewLine]ParametricDraw3D[{Cos[\[Theta]] 
                    Sin[\[Phi]], Sin[\[Theta]] Sin[\[Phi]], 
                  Cos[\[Phi]]}, {\[Phi], 0, \[Pi]}, {\[Theta], 0, 2  \[Pi]}, 
                PlotPoints \[Rule] {21, 
                    31}], \[IndentingNewLine]AbsoluteThickness[1], 
              textstring1, \ 
              textstring2, \ \ textstring3}, \[IndentingNewLine]AmbientLight -> 
              RGBColor[0, \ 0, \ 1], \[IndentingNewLine]Boxed \[Rule] 
              False, \[IndentingNewLine]PlotRange \[Rule] {{\(-1\), 
                    1}, {\(-1\), 1}, {\(-1\), 1}} 
                1.1, \[IndentingNewLine]\[IndentingNewLine]ViewPoint -> \
{3.332, \ 0.254, \ \(-0.531\)}, \[IndentingNewLine]ImageSize \[Rule] 
              500\[IndentingNewLine]]\[IndentingNewLine]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98207 
%%ImageSize: 500 491.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0250724 1.1131 -0.131029 1.1131 [
[ 0 0 0 0 ]
[ 1 .98207 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .98207 L
0 .98207 L
closepath
clip
newpath
.399 .438 .965 r
.55659 .4255 m .48691 .37338 L .48752 .42581 L F
.55659 .4255 m .55694 .3731 L .48691 .37338 L F
.399 .42 .949 r
.55569 .47789 m .55659 .4255 L .48752 .42581 L F
.377 .414 .965 r
.62493 .42746 m .55694 .3731 L .55659 .4255 L F
.378 .396 .949 r
.62158 .48 m .55659 .4255 L .55569 .47789 L F
.62158 .48 m .62493 .42746 L .55659 .4255 L F
.421 .46 .964 r
.48752 .42581 m .41815 .37569 L .41972 .42838 L F
.48752 .42581 m .48691 .37338 L .41815 .37569 L F
.42 .442 .948 r
.48909 .47823 m .48752 .42581 L .41972 .42838 L F
.399 .42 .949 r
.55569 .47789 m .48752 .42581 L .48909 .47823 L F
.399 .402 .932 r
.55426 .52945 m .55569 .47789 L .48909 .47823 L F
.378 .378 .931 r
.61623 .53163 m .55569 .47789 L .55426 .52945 L F
.61623 .53163 m .62158 .48 L .55569 .47789 L F
.399 .455 .981 r
.55694 .3731 m .48726 .32179 L .48691 .37338 L F
.55694 .3731 m .55673 .32155 L .48726 .32179 L F
.376 .43 .981 r
.62624 .37486 m .55673 .32155 L .55694 .3731 L F
.377 .414 .965 r
.62493 .42746 m .62624 .37486 L .55694 .3731 L F
.42 .442 .948 r
.48909 .47823 m .41972 .42838 L .42374 .481 L F
.419 .422 .93 r
.4916 .52979 m .48909 .47823 L .42374 .481 L F
.399 .402 .932 r
.55426 .52945 m .48909 .47823 L .4916 .52979 L F
.42 .478 .981 r
.48691 .37338 m .41906 .32378 L .41815 .37569 L F
.48691 .37338 m .48726 .32179 L .41906 .32378 L F
.352 .386 .963 r
.69054 .43165 m .62624 .37486 L .62493 .42746 L F
.354 .369 .945 r
.68479 .48452 m .62493 .42746 L .62158 .48 L F
.68479 .48452 m .69054 .43165 L .62493 .42746 L F
.354 .351 .927 r
.67562 .53632 m .62158 .48 L .61623 .53163 L F
.67562 .53632 m .68479 .48452 L .62158 .48 L F
.397 .381 .913 r
.55231 .57931 m .55426 .52945 L .4916 .52979 L F
.377 .359 .912 r
.60896 .58149 m .55426 .52945 L .55231 .57931 L F
.60896 .58149 m .61623 .53163 L .55426 .52945 L F
.397 .472 .997 r
.55673 .32155 m .4886 .27188 L .48726 .32179 L F
.55673 .32155 m .55597 .27168 L .4886 .27188 L F
.374 .447 .997 r
.62548 .32306 m .55597 .27168 L .55673 .32155 L F
.376 .43 .981 r
.62624 .37486 m .62548 .32306 L .55673 .32155 L F
.351 .403 .979 r
.6928 .37862 m .62548 .32306 L .62624 .37486 L F
.352 .386 .963 r
.69054 .43165 m .6928 .37862 L .62624 .37486 L F
.419 .422 .93 r
.4916 .52979 m .42374 .481 L .43014 .53267 L F
.416 .4 .911 r
.49501 .57966 m .4916 .52979 L .43014 .53267 L F
.397 .381 .913 r
.55231 .57931 m .4916 .52979 L .49501 .57966 L F
.442 .482 .961 r
.41972 .42838 m .3527 .37999 L .35521 .43319 L F
.41972 .42838 m .41815 .37569 L .3527 .37999 L F
.441 .462 .944 r
.42374 .481 m .41972 .42838 L .35521 .43319 L F
.419 .496 .997 r
.48726 .32179 m .42248 .27353 L .41906 .32378 L F
.48726 .32179 m .4886 .27188 L .42248 .27353 L F
.441 .462 .944 r
.42374 .481 m .35521 .43319 L .3616 .48617 L F
.439 .441 .926 r
.43014 .53267 m .42374 .481 L .3616 .48617 L F
.442 .502 .979 r
.41815 .37569 m .35416 .32749 L .3527 .37999 L F
.41815 .37569 m .41906 .32378 L .35416 .32749 L F
.354 .332 .907 r
.66315 .58615 m .61623 .53163 L .60896 .58149 L F
.66315 .58615 m .67562 .53632 L .61623 .53163 L F
.374 .447 .997 r
.62548 .32306 m .62263 .27293 L .55597 .27168 L F
.348 .421 .996 r
.69149 .3263 m .62263 .27293 L .62548 .32306 L F
.351 .403 .979 r
.6928 .37862 m .69149 .3263 L .62548 .32306 L F
.439 .441 .926 r
.43014 .53267 m .3616 .48617 L .3718 .53802 L F
.435 .417 .906 r
.43885 .58252 m .43014 .53267 L .3718 .53802 L F
.416 .4 .911 r
.49501 .57966 m .43014 .53267 L .43885 .58252 L F
.441 .521 .996 r
.41906 .32378 m .35959 .2766 L .35416 .32749 L F
.41906 .32378 m .42248 .27353 L .35959 .2766 L F
.394 .358 .892 r
.54987 .62661 m .55231 .57931 L .49501 .57966 L F
.375 .336 .89 r
.59984 .62868 m .55231 .57931 L .54987 .62661 L F
.59984 .62868 m .60896 .58149 L .55231 .57931 L F
.395 .49 1 r
.55597 .27168 m .49091 .22453 L .4886 .27188 L F
.55597 .27168 m .55465 .22437 L .49091 .22453 L F
.371 .465 1 r
.62263 .27293 m .55465 .22437 L .55597 .27168 L F
.412 .376 .889 r
.49929 .62694 m .49501 .57966 L .43885 .58252 L F
.394 .358 .892 r
.54987 .62661 m .49501 .57966 L .49929 .62694 L F
.323 .353 .958 r
.75138 .43803 m .6928 .37862 L .69054 .43165 L F
.325 .336 .939 r
.74332 .49137 m .69054 .43165 L .68479 .48452 L F
.74332 .49137 m .75138 .43803 L .69054 .43165 L F
.417 .514 1 r
.4886 .27188 m .42838 .22584 L .42248 .27353 L F
.4886 .27188 m .49091 .22453 L .42838 .22584 L F
.327 .317 .92 r
.73048 .54341 m .68479 .48452 L .67562 .53632 L F
.73048 .54341 m .74332 .49137 L .68479 .48452 L F
.32 .371 .976 r
.75453 .38433 m .69149 .3263 L .6928 .37862 L F
.323 .353 .958 r
.75138 .43803 m .75453 .38433 L .6928 .37862 L F
.354 .309 .885 r
.64755 .63311 m .60896 .58149 L .59984 .62868 L F
.64755 .63311 m .66315 .58615 L .60896 .58149 L F
.465 .505 .956 r
.35521 .43319 m .29265 .38622 L .29605 .44014 L F
.35521 .43319 m .3527 .37999 L .29265 .38622 L F
.463 .483 .937 r
.3616 .48617 m .35521 .43319 L .29605 .44014 L F
.371 .465 1 r
.62263 .27293 m .6177 .22537 L .55465 .22437 L F
.345 .439 1 r
.6866 .27562 m .6177 .22537 L .62263 .27293 L F
.348 .421 .996 r
.69149 .3263 m .6866 .27562 L .62263 .27293 L F
.463 .483 .937 r
.3616 .48617 m .29605 .44014 L .30472 .49364 L F
.46 .458 .917 r
.3718 .53802 m .3616 .48617 L .30472 .49364 L F
.328 .297 .899 r
.71307 .5932 m .67562 .53632 L .66315 .58615 L F
.71307 .5932 m .73048 .54341 L .67562 .53632 L F
.435 .417 .906 r
.43885 .58252 m .3718 .53802 L .38564 .58785 L F
.43 .39 .883 r
.44977 .62966 m .43885 .58252 L .38564 .58785 L F
.412 .376 .889 r
.49929 .62694 m .43885 .58252 L .44977 .62966 L F
.466 .527 .974 r
.3527 .37999 m .29463 .33286 L .29265 .38622 L F
.3527 .37999 m .35416 .32749 L .29463 .33286 L F
.439 .541 1 r
.42248 .27353 m .36899 .22828 L .35959 .2766 L F
.42248 .27353 m .42838 .22584 L .36899 .22828 L F
.317 .389 .994 r
.7527 .33123 m .6866 .27562 L .69149 .3263 L F
.32 .371 .976 r
.75453 .38433 m .7527 .33123 L .69149 .3263 L F
.46 .458 .917 r
.3718 .53802 m .30472 .49364 L .31851 .54576 L F
.455 .431 .895 r
.38564 .58785 m .3718 .53802 L .31851 .54576 L F
.39 .33 .866 r
.54695 .67045 m .54987 .62661 L .49929 .62694 L F
.372 .309 .864 r
.58898 .67231 m .54987 .62661 L .54695 .67045 L F
.58898 .67231 m .59984 .62868 L .54987 .62661 L F
.391 .509 1 r
.55465 .22437 m .49418 .18064 L .49091 .22453 L F
.55465 .22437 m .55278 .18052 L .49418 .18064 L F
.367 .484 1 r
.6177 .22537 m .55278 .18052 L .55465 .22437 L F
.465 .549 .993 r
.35416 .32749 m .302 .28105 L .29463 .33286 L F
.35416 .32749 m .35959 .2766 L .302 .28105 L F
.407 .346 .863 r
.50439 .67074 m .49929 .62694 L .44977 .62966 L F
.39 .33 .866 r
.54695 .67045 m .49929 .62694 L .50439 .67074 L F
.413 .534 1 r
.49091 .22453 m .43674 .18163 L .42838 .22584 L F
.49091 .22453 m .49418 .18064 L .43674 .18163 L F
.328 .275 .875 r
.69134 .6398 m .66315 .58615 L .64755 .63311 L F
.69134 .6398 m .71307 .5932 L .66315 .58615 L F
.352 .283 .858 r
.62901 .67628 m .59984 .62868 L .58898 .67231 L F
.62901 .67628 m .64755 .63311 L .59984 .62868 L F
.345 .439 1 r
.6866 .27562 m .67814 .2275 L .6177 .22537 L F
.312 .408 1 r
.74585 .2797 m .67814 .2275 L .6866 .27562 L F
.317 .389 .994 r
.7527 .33123 m .74585 .2797 L .6866 .27562 L F
.367 .484 1 r
.6177 .22537 m .61072 .18127 L .55278 .18052 L F
.34 .458 1 r
.67814 .2275 m .61072 .18127 L .6177 .22537 L F
.455 .431 .895 r
.38564 .58785 m .31851 .54576 L .33721 .59553 L F
.448 .401 .871 r
.40297 .63472 m .38564 .58785 L .33721 .59553 L F
.43 .39 .883 r
.44977 .62966 m .38564 .58785 L .40297 .63472 L F
.423 .358 .856 r
.46276 .67319 m .44977 .62966 L .40297 .63472 L F
.407 .346 .863 r
.50439 .67074 m .44977 .62966 L .46276 .67319 L F
.285 .31 .949 r
.80529 .44647 m .75453 .38433 L .75138 .43803 L F
.288 .291 .928 r
.79508 .50044 m .75138 .43803 L .74332 .49137 L F
.79508 .50044 m .80529 .44647 L .75138 .43803 L F
.292 .272 .907 r
.77885 .55278 m .74332 .49137 L .73048 .54341 L F
.77885 .55278 m .79508 .50044 L .74332 .49137 L F
.435 .562 1 r
.42838 .22584 m .38229 .18347 L .36899 .22828 L F
.42838 .22584 m .43674 .18163 L .38229 .18347 L F
.28 .329 .969 r
.8093 .39189 m .7527 .33123 L .75453 .38433 L F
.285 .31 .949 r
.80529 .44647 m .8093 .39189 L .75453 .38433 L F
.462 .571 1 r
.35959 .2766 m .31472 .2318 L .302 .28105 L F
.35959 .2766 m .36899 .22828 L .31472 .2318 L F
.295 .252 .883 r
.75688 .60249 m .73048 .54341 L .71307 .5932 L F
.75688 .60249 m .77885 .55278 L .73048 .54341 L F
.49 .53 .945 r
.29605 .44014 m .24019 .39427 L .24441 .44911 L F
.29605 .44014 m .29265 .38622 L .24019 .39427 L F
.487 .503 .924 r
.30472 .49364 m .29605 .44014 L .24441 .44911 L F
.30472 .49364 m .24441 .44911 L .25518 .50328 L F
.482 .474 .902 r
.31851 .54576 m .30472 .49364 L .25518 .50328 L F
.328 .25 .846 r
.66558 .68226 m .64755 .63311 L .62901 .67628 L F
.66558 .68226 m .69134 .6398 L .64755 .63311 L F
.276 .349 .99 r
.80697 .33775 m .74585 .2797 L .7527 .33123 L F
.28 .329 .969 r
.8093 .39189 m .80697 .33775 L .7527 .33123 L F
.492 .556 .967 r
.29265 .38622 m .24264 .3398 L .24019 .39427 L F
.29265 .38622 m .29463 .33286 L .24264 .3398 L F
.482 .474 .902 r
.31851 .54576 m .25518 .50328 L .27228 .55571 L F
.475 .443 .877 r
.33721 .59553 m .31851 .54576 L .27228 .55571 L F
.383 .295 .833 r
.54361 .7099 m .54695 .67045 L .50439 .67074 L F
.367 .276 .831 r
.57652 .71144 m .54695 .67045 L .54361 .7099 L F
.57652 .71144 m .58898 .67231 L .54695 .67045 L F
.448 .401 .871 r
.40297 .63472 m .33721 .59553 L .36054 .642 L F
.438 .365 .842 r
.42353 .67773 m .40297 .63472 L .36054 .642 L F
.423 .358 .856 r
.46276 .67319 m .40297 .63472 L .42353 .67773 L F
.384 .53 1 r
.55278 .18052 m .4984 .14114 L .49418 .18064 L F
.55278 .18052 m .55037 .14106 L .4984 .14114 L F
.36 .505 1 r
.61072 .18127 m .55037 .14106 L .55278 .18052 L F
.34 .458 1 r
.67814 .2275 m .66617 .18289 L .61072 .18127 L F
.306 .429 1 r
.73401 .23074 m .66617 .18289 L .67814 .2275 L F
.312 .408 1 r
.74585 .2797 m .73401 .23074 L .67814 .2275 L F
.398 .309 .83 r
.51025 .71015 m .50439 .67074 L .46276 .67319 L F
.383 .295 .833 r
.54361 .7099 m .50439 .67074 L .51025 .71015 L F
.297 .23 .857 r
.72954 .64858 m .71307 .5932 L .69134 .6398 L F
.72954 .64858 m .75688 .60249 L .71307 .5932 L F
.406 .555 1 r
.49418 .18064 m .4475 .14185 L .43674 .18163 L F
.49418 .18064 m .4984 .14114 L .4475 .14185 L F
.349 .251 .825 r
.60779 .71473 m .58898 .67231 L .57652 .71144 L F
.60779 .71473 m .62901 .67628 L .58898 .67231 L F
.491 .581 .988 r
.29463 .33286 m .2518 .2868 L .24264 .3398 L F
.29463 .33286 m .302 .28105 L .2518 .2868 L F
.457 .593 1 r
.36899 .22828 m .33269 .18613 L .31472 .2318 L F
.36899 .22828 m .38229 .18347 L .33269 .18613 L F
.36 .505 1 r
.61072 .18127 m .60174 .1416 L .55037 .14106 L F
.333 .48 1 r
.66617 .18289 m .60174 .1416 L .61072 .18127 L F
.412 .317 .822 r
.47766 .71217 m .46276 .67319 L .42353 .67773 L F
.398 .309 .83 r
.51025 .71015 m .46276 .67319 L .47766 .71217 L F
.475 .443 .877 r
.33721 .59553 m .27228 .55571 L .2954 .60539 L F
.466 .407 .851 r
.36054 .642 m .33721 .59553 L .2954 .60539 L F
.27 .37 1 r
.79828 .2851 m .73401 .23074 L .74585 .2797 L F
.276 .349 .99 r
.80697 .33775 m .79828 .2851 L .74585 .2797 L F
.427 .584 1 r
.43674 .18163 m .39937 .14317 L .38229 .18347 L F
.43674 .18163 m .4475 .14185 L .39937 .14317 L F
.299 .206 .827 r
.69728 .69008 m .69134 .6398 L .66558 .68226 L F
.69728 .69008 m .72954 .64858 L .69134 .6398 L F
.327 .219 .812 r
.63621 .71965 m .62901 .67628 L .60779 .71473 L F
.63621 .71965 m .66558 .68226 L .62901 .67628 L F
.487 .606 1 r
.302 .28105 m .26758 .23635 L .2518 .2868 L F
.302 .28105 m .31472 .2318 L .26758 .23635 L F
.237 .228 .908 r
.83794 .51152 m .80529 .44647 L .79508 .50044 L F
.243 .208 .884 r
.81869 .5642 m .79508 .50044 L .77885 .55278 L F
.81869 .5642 m .83794 .51152 L .79508 .50044 L F
.438 .365 .842 r
.42353 .67773 m .36054 .642 L .38816 .68423 L F
.424 .32 .807 r
.44706 .71592 m .42353 .67773 L .38816 .68423 L F
.412 .317 .822 r
.47766 .71217 m .42353 .67773 L .44706 .71592 L F
.23 .248 .932 r
.85007 .4568 m .8093 .39189 L .80529 .44647 L F
.237 .228 .908 r
.83794 .51152 m .85007 .4568 L .80529 .44647 L F
.466 .407 .851 r
.36054 .642 m .2954 .60539 L .32415 .65131 L F
.453 .366 .82 r
.38816 .68423 m .36054 .642 L .32415 .65131 L F
.333 .48 1 r
.66617 .18289 m .65079 .14275 L .60174 .1416 L F
.298 .452 1 r
.71728 .18533 m .65079 .14275 L .66617 .18289 L F
.306 .429 1 r
.73401 .23074 m .71728 .18533 L .66617 .18289 L F
.249 .188 .857 r
.79273 .61377 m .77885 .55278 L .75688 .60249 L F
.79273 .61377 m .81869 .5642 L .77885 .55278 L F
.223 .269 .956 r
.85484 .40116 m .80697 .33775 L .8093 .39189 L F
.23 .248 .932 r
.85007 .4568 m .85484 .40116 L .8093 .39189 L F
.262 .393 1 r
.7833 .23501 m .71728 .18533 L .73401 .23074 L F
.27 .37 1 r
.79828 .2851 m .7833 .23501 L .73401 .23074 L F
.447 .616 1 r
.38229 .18347 m .3557 .14506 L .33269 .18613 L F
.38229 .18347 m .39937 .14317 L .3557 .14506 L F
.372 .248 .79 r
.53987 .74401 m .54361 .7099 L .51025 .71015 L F
.358 .231 .788 r
.56264 .74513 m .54361 .7099 L .53987 .74401 L F
.56264 .74513 m .57652 .71144 L .54361 .7099 L F
.373 .553 1 r
.55037 .14106 m .50352 .10699 L .4984 .14114 L F
.55037 .14106 m .54745 .10694 L .50352 .10699 L F
.349 .529 1 r
.60174 .1416 m .54745 .10694 L .55037 .14106 L F
.385 .258 .786 r
.51678 .74419 m .51025 .71015 L .47766 .71217 L F
.372 .248 .79 r
.53987 .74401 m .51025 .71015 L .51678 .74419 L F
.395 .579 1 r
.4984 .14114 m .46054 .10747 L .4475 .14185 L F
.4984 .14114 m .50352 .10699 L .46054 .10747 L F
.255 .168 .829 r
.76054 .6592 m .75688 .60249 L .72954 .64858 L F
.76054 .6592 m .79273 .61377 L .75688 .60249 L F
.515 .524 .9 r
.25518 .50328 m .20252 .45992 L .21513 .51486 L F
.25518 .50328 m .24441 .44911 L .20252 .45992 L F
.508 .488 .875 r
.27228 .55571 m .25518 .50328 L .21513 .51486 L F
.52 .557 .926 r
.24441 .44911 m .19757 .40396 L .20252 .45992 L F
.24441 .44911 m .24019 .39427 L .19757 .40396 L F
.215 .291 .98 r
.85207 .34574 m .79828 .2851 L .80697 .33775 L F
.223 .269 .956 r
.85484 .40116 m .85207 .34574 L .80697 .33775 L F
.342 .209 .781 r
.58419 .7475 m .57652 .71144 L .56264 .74513 L F
.58419 .7475 m .60779 .71473 L .57652 .71144 L F
.301 .177 .791 r
.66064 .72606 m .66558 .68226 L .63621 .71965 L F
.66064 .72606 m .69728 .69008 L .66558 .68226 L F
.508 .488 .875 r
.27228 .55571 m .21513 .51486 L .23511 .56765 L F
.497 .449 .847 r
.2954 .60539 m .27228 .55571 L .23511 .56765 L F
.48 .631 1 r
.31472 .2318 m .28982 .18954 L .26758 .23635 L F
.31472 .2318 m .33269 .18613 L .28982 .18954 L F
.395 .264 .778 r
.49426 .74566 m .47766 .71217 L .44706 .71592 L F
.385 .258 .786 r
.51678 .74419 m .47766 .71217 L .49426 .74566 L F
.349 .529 1 r
.60174 .1416 m .59084 .1073 L .54745 .10694 L F
.321 .505 1 r
.65079 .14275 m .59084 .1073 L .60174 .1416 L F
.521 .589 .95 r
.24019 .39427 m .20044 .34816 L .19757 .40396 L F
.24019 .39427 m .24264 .3398 L .20044 .34816 L F
.453 .366 .82 r
.38816 .68423 m .32415 .65131 L .35803 .69251 L F
.435 .316 .784 r
.41962 .72127 m .38816 .68423 L .35803 .69251 L F
.424 .32 .807 r
.44706 .71592 m .38816 .68423 L .41962 .72127 L F
.414 .607 1 r
.4475 .14185 m .42003 .10834 L .39937 .14317 L F
.4475 .14185 m .46054 .10747 L .42003 .10834 L F
.497 .449 .847 r
.2954 .60539 m .23511 .56765 L .26205 .61717 L F
.484 .406 .818 r
.32415 .65131 m .2954 .60539 L .26205 .61717 L F
.262 .145 .797 r
.72274 .6995 m .72954 .64858 L .69728 .69008 L F
.72274 .6995 m .76054 .6592 L .72954 .64858 L F
.323 .18 .767 r
.60367 .75105 m .60779 .71473 L .58419 .7475 L F
.60367 .75105 m .63621 .71965 L .60779 .71473 L F
.52 .62 .975 r
.24264 .3398 m .21117 .2937 L .20044 .34816 L F
.24264 .3398 m .2518 .2868 L .21117 .2937 L F
.207 .314 1 r
.84175 .29171 m .7833 .23501 L .79828 .2851 L F
.215 .291 .98 r
.85207 .34574 m .84175 .29171 L .79828 .2851 L F
.404 .263 .763 r
.47319 .74836 m .44706 .71592 L .41962 .72127 L F
.395 .264 .778 r
.49426 .74566 m .44706 .71592 L .47319 .74836 L F
.298 .452 1 r
.71728 .18533 m .69585 .14448 L .65079 .14275 L F
.251 .418 1 r
.76218 .18854 m .69585 .14448 L .71728 .18533 L F
.262 .393 1 r
.7833 .23501 m .76218 .18854 L .71728 .18533 L F
.484 .406 .818 r
.32415 .65131 m .26205 .61717 L .2954 .66239 L F
.466 .358 .786 r
.35803 .69251 m .32415 .65131 L .2954 .66239 L F
.321 .505 1 r
.65079 .14275 m .63217 .10807 L .59084 .1073 L F
.285 .478 1 r
.69585 .14448 m .63217 .10807 L .65079 .14275 L F
.467 .655 1 r
.33269 .18613 m .3182 .14748 L .28982 .18954 L F
.33269 .18613 m .3557 .14506 L .3182 .14748 L F
.431 .639 1 r
.39937 .14317 m .38345 .1096 L .3557 .14506 L F
.39937 .14317 m .42003 .10834 L .38345 .1096 L F
.514 .649 1 r
.2518 .2868 m .22963 .24179 L .21117 .2937 L F
.2518 .2868 m .26758 .23635 L .22963 .24179 L F
.301 .142 .747 r
.62028 .75564 m .63621 .71965 L .60367 .75105 L F
.62028 .75564 m .66064 .72606 L .63621 .71965 L F
.268 .121 .76 r
.68004 .73375 m .69728 .69008 L .66064 .72606 L F
.68004 .73375 m .72274 .6995 L .69728 .69008 L F
.196 .34 1 r
.82397 .24022 m .76218 .18854 L .7833 .23501 L F
.207 .314 1 r
.84175 .29171 m .82397 .24022 L .7833 .23501 L F
.435 .316 .784 r
.41962 .72127 m .35803 .69251 L .39646 .72805 L F
.41 .254 .74 r
.45442 .75221 m .41962 .72127 L .39646 .72805 L F
.404 .263 .763 r
.47319 .74836 m .41962 .72127 L .45442 .75221 L F
.156 .128 .87 r
.86974 .52433 m .85007 .4568 L .83794 .51152 L F
.169 .109 .841 r
.84802 .57738 m .83794 .51152 L .81869 .5642 L F
.84802 .57738 m .86974 .52433 L .83794 .51152 L F
.466 .358 .786 r
.35803 .69251 m .2954 .66239 L .33451 .70231 L F
.443 .302 .749 r
.39646 .72805 m .35803 .69251 L .33451 .70231 L F
.352 .18 .727 r
.53581 .77182 m .53987 .74401 L .51678 .74419 L F
.342 .167 .725 r
.54753 .77242 m .53987 .74401 L .53581 .77182 L F
.54753 .77242 m .56264 .74513 L .53987 .74401 L F
.182 .091 .811 r
.81882 .62674 m .81869 .5642 L .79273 .61377 L F
.81882 .62674 m .84802 .57738 L .81869 .5642 L F
.354 .578 1 r
.54745 .10694 m .50948 .07916 L .50352 .10699 L F
.54745 .10694 m .54404 .07912 L .50948 .07916 L F
.33 .555 1 r
.59084 .1073 m .54404 .07912 L .54745 .10694 L F
.361 .187 .724 r
.5239 .77192 m .51678 .74419 L .49426 .74566 L F
.352 .18 .727 r
.53581 .77182 m .51678 .74419 L .5239 .77192 L F
.373 .603 1 r
.50352 .10699 m .47572 .07945 L .46054 .10747 L F
.50352 .10699 m .50948 .07916 L .47572 .07945 L F
.143 .148 .898 r
.88347 .46877 m .85484 .40116 L .85007 .4568 L F
.156 .128 .87 r
.86974 .52433 m .88347 .46877 L .85007 .4568 L F
.329 .15 .718 r
.5586 .77368 m .56264 .74513 L .54753 .77242 L F
.5586 .77368 m .58419 .7475 L .56264 .74513 L F
.195 .075 .781 r
.78279 .67135 m .79273 .61377 L .76054 .6592 L F
.78279 .67135 m .81882 .62674 L .79273 .61377 L F
.368 .189 .716 r
.51231 .7727 m .49426 .74566 L .47319 .74836 L F
.361 .187 .724 r
.5239 .77192 m .49426 .74566 L .51231 .7727 L F
.33 .555 1 r
.59084 .1073 m .57815 .07935 L .54404 .07912 L F
.301 .531 1 r
.63217 .10807 m .57815 .07935 L .59084 .1073 L F
.13 .17 .926 r
.88887 .41191 m .85207 .34574 L .85484 .40116 L F
.143 .148 .898 r
.88347 .46877 m .88887 .41191 L .85484 .40116 L F
.503 .676 1 r
.26758 .23635 m .25555 .19363 L .22963 .24179 L F
.26758 .23635 m .28982 .18954 L .25555 .19363 L F
.285 .478 1 r
.69585 .14448 m .66997 .10922 L .63217 .10807 L F
.236 .445 1 r
.73521 .14677 m .66997 .10922 L .69585 .14448 L F
.251 .418 1 r
.76218 .18854 m .73521 .14677 L .69585 .14448 L F
.389 .63 1 r
.46054 .10747 m .44399 .07999 L .42003 .10834 L F
.46054 .10747 m .47572 .07945 L .44399 .07999 L F
.315 .126 .706 r
.56854 .77556 m .58419 .7475 L .5586 .77368 L F
.56854 .77556 m .60367 .75105 L .58419 .7475 L F
.273 .093 .717 r
.63329 .76112 m .66064 .72606 L .62028 .75564 L F
.63329 .76112 m .68004 .73375 L .66064 .72606 L F
.209 .06 .748 r
.7407 .71021 m .76054 .6592 L .72274 .6995 L F
.7407 .71021 m .78279 .67135 L .76054 .6592 L F
.372 .185 .702 r
.5015 .77414 m .47319 .74836 L .45442 .75221 L F
.368 .189 .716 r
.51231 .7727 m .47319 .74836 L .5015 .77414 L F
.533 .492 .823 r
.23511 .56765 m .18671 .52809 L .20899 .58124 L F
.23511 .56765 m .21513 .51486 L .18671 .52809 L F
.518 .443 .793 r
.26205 .61717 m .23511 .56765 L .20899 .58124 L F
.544 .539 .853 r
.21513 .51486 m .17262 .47229 L .18671 .52809 L F
.21513 .51486 m .20252 .45992 L .17262 .47229 L F
.117 .195 .954 r
.88573 .355 m .84175 .29171 L .85207 .34574 L F
.13 .17 .926 r
.88887 .41191 m .88573 .355 L .85207 .34574 L F
.518 .443 .793 r
.26205 .61717 m .20899 .58124 L .23891 .63053 L F
.498 .39 .762 r
.2954 .66239 m .26205 .61717 L .23891 .63053 L F
.182 .368 1 r
.79899 .19245 m .73521 .14677 L .76218 .18854 L F
.196 .34 1 r
.82397 .24022 m .79899 .19245 L .76218 .18854 L F
.55 .582 .883 r
.20252 .45992 m .16708 .41507 L .17262 .47229 L F
.20252 .45992 m .19757 .40396 L .16708 .41507 L F
.445 .676 1 r
.3557 .14506 m .35227 .11121 L .3182 .14748 L F
.3557 .14506 m .38345 .1096 L .35227 .11121 L F
.443 .302 .749 r
.39646 .72805 m .33451 .70231 L .37861 .73604 L F
.412 .236 .707 r
.43873 .75706 m .39646 .72805 L .37861 .73604 L F
.41 .254 .74 r
.45442 .75221 m .39646 .72805 L .43873 .75706 L F
.301 .531 1 r
.63217 .10807 m .61056 .07982 L .57815 .07935 L F
.263 .506 1 r
.66997 .10922 m .61056 .07982 L .63217 .10807 L F
.298 .097 .689 r
.57693 .77799 m .60367 .75105 L .56854 .77556 L F
.57693 .77799 m .62028 .75564 L .60367 .75105 L F
.224 .045 .713 r
.69346 .74244 m .72274 .6995 L .68004 .73375 L F
.69346 .74244 m .7407 .71021 L .72274 .6995 L F
.498 .39 .762 r
.2954 .66239 m .23891 .63053 L .27578 .67489 L F
.474 .334 .73 r
.33451 .70231 m .2954 .66239 L .27578 .67489 L F
.551 .623 .912 r
.19757 .40396 m .1703 .35773 L .16708 .41507 L F
.19757 .40396 m .20044 .34816 L .1703 .35773 L F
.374 .174 .683 r
.49195 .77618 m .45442 .75221 L .43873 .75706 L F
.372 .185 .702 r
.5015 .77414 m .45442 .75221 L .49195 .77618 L F
.401 .659 1 r
.42003 .10834 m .41552 .08077 L .38345 .1096 L F
.42003 .10834 m .44399 .07999 L .41552 .08077 L F
.482 .699 1 r
.28982 .18954 m .2885 .15036 L .25555 .19363 L F
.28982 .18954 m .3182 .14748 L .2885 .15036 L F
.103 .222 .982 r
.87405 .29935 m .82397 .24022 L .84175 .29171 L F
.117 .195 .954 r
.88573 .355 m .87405 .29935 L .84175 .29171 L F
.474 .334 .73 r
.33451 .70231 m .27578 .67489 L .31879 .71332 L F
.445 .272 .697 r
.37861 .73604 m .33451 .70231 L .31879 .71332 L F
.547 .661 .942 r
.20044 .34816 m .18229 .30159 L .1703 .35773 L F
.20044 .34816 m .21117 .2937 L .18229 .30159 L F
.278 .061 .664 r
.58342 .78086 m .62028 .75564 L .57693 .77799 L F
.58342 .78086 m .63329 .76112 L .62028 .75564 L F
.239 .031 .675 r
.64208 .76727 m .68004 .73375 L .63329 .76112 L F
.64208 .76727 m .69346 .74244 L .68004 .73375 L F
.412 .236 .707 r
.43873 .75706 m .37861 .73604 L .42682 .76274 L F
.371 .156 .657 r
.48404 .77873 m .43873 .75706 L .42682 .76274 L F
.374 .174 .683 r
.49195 .77618 m .43873 .75706 L .48404 .77873 L F
.236 .445 1 r
.73521 .14677 m .70277 .11074 L .66997 .10922 L F
.164 .398 1 r
.7672 .14953 m .70277 .11074 L .73521 .14677 L F
.182 .368 1 r
.79899 .19245 m .7672 .14953 L .73521 .14677 L F
.263 .506 1 r
.66997 .10922 m .64004 .08053 L .61056 .07982 L F
.212 .473 1 r
.70277 .11074 m .64004 .08053 L .66997 .10922 L F
.445 .272 .697 r
.37861 .73604 m .31879 .71332 L .36697 .74495 L F
.409 .204 .661 r
.42682 .76274 m .37861 .73604 L .36697 .74495 L F
.087 .253 1 r
.85397 .24624 m .79899 .19245 L .82397 .24022 L F
.103 .222 .982 r
.87405 .29935 m .85397 .24624 L .82397 .24022 L F
.313 .074 .63 r
.53148 .79236 m .53581 .77182 L .5239 .77192 L F
.309 .069 .629 r
.53148 .79236 m .54753 .77242 L .53581 .77182 L F
.535 .693 .97 r
.21117 .2937 m .20289 .248 L .18229 .30159 L F
.21117 .2937 m .22963 .24179 L .20289 .248 L F
.317 .077 .628 r
.53148 .79236 m .5239 .77192 L .51231 .7727 L F
.315 .6 1 r
.54404 .07912 m .51621 .0586 L .50948 .07916 L F
.54404 .07912 m .5402 .05858 L .51621 .0586 L F
.293 .579 1 r
.57815 .07935 m .5402 .05858 L .54404 .07912 L F
.332 .622 1 r
.50948 .07916 m .4928 .05876 L .47572 .07945 L F
.50948 .07916 m .51621 .0586 L .4928 .05876 L F
.303 .061 .625 r
.53148 .79236 m .5586 .77368 L .54753 .77242 L F
.319 .077 .623 r
.53148 .79236 m .51231 .7727 L .5015 .77414 L F
.406 .69 1 r
.38345 .1096 m .39146 .08175 L .35227 .11121 L F
.38345 .1096 m .41552 .08077 L .39146 .08175 L F
.296 .05 .619 r
.53148 .79236 m .56854 .77556 L .5586 .77368 L F
.293 .579 1 r
.57815 .07935 m .56386 .0587 L .5402 .05858 L F
.264 .556 1 r
.61056 .07982 m .56386 .0587 L .57815 .07935 L F
.319 .073 .617 r
.53148 .79236 m .5015 .77414 L .49195 .77618 L F
.449 .714 1 r
.3182 .14748 m .32787 .11311 L .2885 .15036 L F
.3182 .14748 m .35227 .11121 L .32787 .11311 L F
.343 .644 1 r
.47572 .07945 m .47089 .05906 L .44399 .07999 L F
.47572 .07945 m .4928 .05876 L .47089 .05906 L F
.255 .017 .633 r
.58769 .78407 m .63329 .76112 L .58342 .78086 L F
.58769 .78407 m .64208 .76727 L .63329 .76112 L F
.07 0 .725 r
.83352 .64098 m .84802 .57738 L .81882 .62674 L F
.1 0 .696 r
.79492 .68462 m .81882 .62674 L .78279 .67135 L F
.79492 .68462 m .83352 .64098 L .81882 .62674 L F
.04 0 .754 r
.86495 .5919 m .86974 .52433 L .84802 .57738 L F
.07 0 .725 r
.83352 .64098 m .86495 .5919 L .84802 .57738 L F
.131 0 .668 r
.7501 .72184 m .78279 .67135 L .7407 .71021 L F
.7501 .72184 m .79492 .68462 L .78279 .67135 L F
.289 .037 .61 r
.53148 .79236 m .57693 .77799 L .56854 .77556 L F
.012 0 .785 r
.88842 .5385 m .88347 .46877 L .86974 .52433 L F
.04 0 .754 r
.86495 .5919 m .88842 .5385 L .86974 .52433 L F
.318 .067 .607 r
.53148 .79236 m .49195 .77618 L .48404 .77873 L F
.409 .204 .661 r
.42682 .76274 m .36697 .74495 L .41926 .76903 L F
.365 .129 .623 r
.47814 .78171 m .42682 .76274 L .41926 .76903 L F
.371 .156 .657 r
.48404 .77873 m .42682 .76274 L .47814 .78171 L F
.163 0 .642 r
.70013 .7518 m .7407 .71021 L .69346 .74244 L F
.70013 .7518 m .7501 .72184 L .7407 .71021 L F
.513 .719 .997 r
.22963 .24179 m .23171 .19826 L .20289 .248 L F
.22963 .24179 m .25555 .19363 L .23171 .19826 L F
.264 .556 1 r
.61056 .07982 m .58627 .05897 L .56386 .0587 L F
.225 .53 1 r
.64004 .08053 m .58627 .05897 L .61056 .07982 L F
0 0 .817 r
.9033 .48203 m .88887 .41191 L .88347 .46877 L F
.012 0 .785 r
.88842 .5385 m .9033 .48203 L .88347 .46877 L F
.071 .285 1 r
.82586 .19695 m .7672 .14953 L .79899 .19245 L F
.087 .253 1 r
.85397 .24624 m .82586 .19695 L .79899 .19245 L F
.281 .022 .599 r
.53148 .79236 m .58342 .78086 L .57693 .77799 L F
.196 0 .617 r
.64619 .77384 m .69346 .74244 L .64208 .76727 L F
.64619 .77384 m .70013 .7518 L .69346 .74244 L F
.315 .057 .595 r
.53148 .79236 m .48404 .77873 L .47814 .78171 L F
.346 .665 1 r
.44399 .07999 m .45136 .05949 L .41552 .08077 L F
.44399 .07999 m .47089 .05906 L .45136 .05949 L F
.496 .341 .663 r
.27578 .67489 m .22759 .64502 L .26663 .68838 L F
.27578 .67489 m .23891 .63053 L .22759 .64502 L F
.467 .279 .639 r
.31879 .71332 m .27578 .67489 L .26663 .68838 L F
.521 .402 .689 r
.23891 .63053 m .19575 .59604 L .22759 .64502 L F
.23891 .63053 m .20899 .58124 L .19575 .59604 L F
0 0 .849 r
.90916 .42382 m .88573 .355 L .88887 .41191 L F
0 0 .817 r
.9033 .48203 m .90916 .42382 L .88887 .41191 L F
.467 .279 .639 r
.31879 .71332 m .26663 .68838 L .31189 .72512 L F
.433 .216 .617 r
.36697 .74495 m .31879 .71332 L .31189 .72512 L F
.539 .462 .717 r
.20899 .58124 m .17196 .54255 L .19575 .59604 L F
.20899 .58124 m .18671 .52809 L .17196 .54255 L F
.212 .473 1 r
.70277 .11074 m .66541 .08146 L .64004 .08053 L F
.139 .427 1 r
.72915 .11257 m .66541 .08146 L .70277 .11074 L F
.164 .398 1 r
.7672 .14953 m .72915 .11257 L .70277 .11074 L F
.272 .005 .586 r
.53148 .79236 m .58769 .78407 L .58342 .78086 L F
.229 0 .593 r
.58954 .78746 m .64208 .76727 L .58769 .78407 L F
.58954 .78746 m .64619 .77384 L .64208 .76727 L F
.433 .216 .617 r
.36697 .74495 m .31189 .72512 L .36225 .75443 L F
.394 .154 .598 r
.41926 .76903 m .36697 .74495 L .36225 .75443 L F
.551 .519 .746 r
.18671 .52809 m .15685 .48583 L .17196 .54255 L F
.18671 .52809 m .17262 .47229 L .15685 .48583 L F
.365 .129 .623 r
.47814 .78171 m .41926 .76903 L .47451 .78498 L F
.311 .045 .582 r
.53148 .79236 m .47814 .78171 L .47451 .78498 L F
.478 .735 1 r
.25555 .19363 m .26818 .15362 L .23171 .19826 L F
.25555 .19363 m .2885 .15036 L .26818 .15362 L F
0 .015 .88 r
.90576 .36527 m .87405 .29935 L .88573 .355 L F
0 0 .849 r
.90916 .42382 m .90576 .36527 L .88573 .355 L F
.394 .154 .598 r
.41926 .76903 m .36225 .75443 L .41649 .77568 L F
.351 .091 .581 r
.47451 .78498 m .41926 .76903 L .41649 .77568 L F
.225 .53 1 r
.64004 .08053 m .60653 .05936 L .58627 .05897 L F
.173 .497 1 r
.66541 .08146 m .60653 .05936 L .64004 .08053 L F
.396 .714 1 r
.35227 .11121 m .37289 .08291 L .32787 .11311 L F
.35227 .11121 m .39146 .08175 L .37289 .08291 L F
.554 .573 .778 r
.17262 .47229 m .15091 .42723 L .15685 .48583 L F
.17262 .47229 m .16708 .41507 L .15091 .42723 L F
.263 0 .57 r
.53148 .79236 m .58954 .78746 L .58769 .78407 L F
.052 .32 1 r
.79023 .1527 m .72915 .11257 L .7672 .14953 L F
.071 .285 1 r
.82586 .19695 m .79023 .1527 L .7672 .14953 L F
.339 .681 1 r
.41552 .08077 m .43502 .06003 L .39146 .08175 L F
.41552 .08077 m .45136 .05949 L .43502 .06003 L F
.351 .091 .581 r
.47451 .78498 m .41649 .77568 L .47334 .78841 L F
.305 .03 .566 r
.53148 .79236 m .47451 .78498 L .47334 .78841 L F
.548 .62 .81 r
.16708 .41507 m .15437 .3682 L .15091 .42723 L F
.16708 .41507 m .1703 .35773 L .15437 .3682 L F
0 .049 .91 r
.89309 .30781 m .85397 .24624 L .87405 .29935 L F
0 .015 .88 r
.90576 .36527 m .89309 .30781 L .87405 .29935 L F
.199 0 .561 r
.58886 .79091 m .64619 .77384 L .58954 .78746 L F
.254 0 .561 r
.53148 .79236 m .58886 .79091 L .58954 .78746 L F
.14 0 .561 r
.64532 .78057 m .70013 .7518 L .64619 .77384 L F
.199 0 .561 r
.58886 .79091 m .64532 .78057 L .64619 .77384 L F
.237 0 .561 r
.53148 .79236 m .51478 .80407 L .52697 .80472 L F
.246 0 .561 r
.53148 .79236 m .50336 .80271 L .51478 .80407 L F
.256 0 .561 r
.53148 .79236 m .49324 .8007 L .50336 .80271 L F
.266 0 .561 r
.53148 .79236 m .48487 .79813 L .49324 .8007 L F
.277 0 .561 r
.53148 .79236 m .47861 .79513 L .48487 .79813 L F
.288 0 .561 r
.53148 .79236 m .47472 .79184 L .47861 .79513 L F
.297 .012 .561 r
.53148 .79236 m .47334 .78841 L .47472 .79184 L F
.246 0 .561 r
.53148 .79236 m .58565 .79426 L .58886 .79091 L F
.238 0 .561 r
.53148 .79236 m .58001 .79735 L .58565 .79426 L F
.232 0 .561 r
.53148 .79236 m .57219 .80005 L .58001 .79735 L F
.228 0 .561 r
.53148 .79236 m .5625 .80222 L .57219 .80005 L F
.227 0 .561 r
.53148 .79236 m .55139 .80377 L .5625 .80222 L F
.228 0 .561 r
.53148 .79236 m .53936 .80461 L .55139 .80377 L F
.231 0 .561 r
.53148 .79236 m .52697 .80472 L .53936 .80461 L F
.234 .597 1 r
.5402 .05858 m .52358 .04623 L .51621 .0586 L F
.5402 .05858 m .53599 .04622 L .52358 .04623 L F
.216 .579 1 r
.56386 .0587 m .53599 .04622 L .5402 .05858 L F
.426 .734 1 r
.2885 .15036 m .31151 .11525 L .26818 .15362 L F
.2885 .15036 m .32787 .11311 L .31151 .11525 L F
.246 .612 1 r
.51621 .0586 m .51151 .0463 L .4928 .05876 L F
.51621 .0586 m .52358 .04623 L .51151 .0463 L F
.078 0 .561 r
.69952 .76145 m .7501 .72184 L .70013 .7518 L F
.14 0 .561 r
.64532 .78057 m .69952 .76145 L .70013 .7518 L F
.531 .659 .841 r
.1703 .35773 m .16722 .31022 L .15437 .3682 L F
.1703 .35773 m .18229 .30159 L .16722 .31022 L F
.331 .043 .561 r
.47334 .78841 m .41875 .78239 L .47472 .79184 L F
.47334 .78841 m .41649 .77568 L .41875 .78239 L F
.013 0 .561 r
.75011 .73391 m .79492 .68462 L .7501 .72184 L F
.078 0 .561 r
.69952 .76145 m .75011 .73391 L .7501 .72184 L F
.216 .579 1 r
.56386 .0587 m .5482 .04628 L .53599 .04622 L F
.19 .557 1 r
.58627 .05897 m .5482 .04628 L .56386 .0587 L F
.363 .079 .561 r
.41649 .77568 m .36491 .76409 L .41875 .78239 L F
.41649 .77568 m .36225 .75443 L .36491 .76409 L F
.249 .623 1 r
.4928 .05876 m .50025 .04643 L .47089 .05906 L F
.4928 .05876 m .51151 .0463 L .50025 .04643 L F
0 .089 .938 r
.87138 .25288 m .82586 .19695 L .85397 .24624 L F
0 .049 .91 r
.89309 .30781 m .87138 .25288 L .85397 .24624 L F
.173 .497 1 r
.66541 .08146 m .62382 .05987 L .60653 .05936 L F
.104 .45 1 r
.68558 .08257 m .62382 .05987 L .66541 .08146 L F
.139 .427 1 r
.72915 .11257 m .68558 .08257 L .66541 .08146 L F
0 0 .561 r
.79581 .69849 m .83352 .64098 L .79492 .68462 L F
.013 0 .561 r
.75011 .73391 m .79581 .69849 L .79492 .68462 L F
.167 0 .561 r
.58565 .79426 m .64532 .78057 L .58886 .79091 L F
.393 .12 .561 r
.36225 .75443 m .31454 .73722 L .36491 .76409 L F
.36225 .75443 m .31189 .72512 L .31454 .73722 L F
.033 .354 1 r
.74783 .11465 m .68558 .08257 L .72915 .11257 L F
.052 .32 1 r
.79023 .1527 m .74783 .11465 L .72915 .11257 L F
.502 .687 .872 r
.18229 .30159 m .18924 .25477 L .16722 .31022 L F
.18229 .30159 m .20289 .248 L .18924 .25477 L F
.19 .557 1 r
.58627 .05897 m .55973 .04639 L .5482 .04628 L F
.155 .53 1 r
.60653 .05936 m .55973 .04639 L .58627 .05897 L F
.301 0 .561 r
.47472 .79184 m .42606 .78888 L .47861 .79513 L F
.47472 .79184 m .41875 .78239 L .42606 .78888 L F
0 0 .561 r
.83541 .65594 m .86495 .5919 L .83352 .64098 L F
.79581 .69849 m .83541 .65594 L .83352 .64098 L F
.314 .684 1 r
.39146 .08175 m .4226 .06066 L .37289 .08291 L F
.39146 .08175 m .43502 .06003 L .4226 .06066 L F
.243 .629 1 r
.47089 .05906 m .49029 .04662 L .45136 .05949 L F
.47089 .05906 m .50025 .04643 L .49029 .04662 L F
.418 .166 .561 r
.31189 .72512 m .26896 .70231 L .31454 .73722 L F
.31189 .72512 m .26663 .68838 L .26896 .70231 L F
0 0 .572 r
.86783 .60723 m .88842 .5385 L .86495 .5919 L F
0 0 .561 r
.83541 .65594 m .86783 .60723 L .86495 .5919 L F
.167 0 .561 r
.58565 .79426 m .63939 .78715 L .64532 .78057 L F
.133 0 .561 r
.58001 .79735 m .63939 .78715 L .58565 .79426 L F
0 .135 .96 r
.84107 .20189 m .79023 .1527 L .82586 .19695 L F
0 .089 .938 r
.87138 .25288 m .84107 .20189 L .82586 .19695 L F
.073 0 .561 r
.63939 .78715 m .69952 .76145 L .64532 .78057 L F
.355 .71 1 r
.32787 .11311 m .36074 .0842 L .31151 .11525 L F
.32787 .11311 m .37289 .08291 L .36074 .0842 L F
.437 .216 .561 r
.26663 .68838 m .22939 .66008 L .26896 .70231 L F
.26663 .68838 m .22759 .64502 L .22939 .66008 L F
.262 0 .561 r
.47861 .79513 m .4382 .79484 L .48487 .79813 L F
.47861 .79513 m .42606 .78888 L .4382 .79484 L F
.459 .701 .899 r
.20289 .248 m .21994 .20329 L .18924 .25477 L F
.20289 .248 m .23171 .19826 L .21994 .20329 L F
.155 .53 1 r
.60653 .05936 m .57009 .04656 L .55973 .04639 L F
.11 .497 1 r
.62382 .05987 m .57009 .04656 L .60653 .05936 L F
.308 0 .561 r
.41875 .78239 m .37511 .77349 L .42606 .78888 L F
.41875 .78239 m .36491 .76409 L .37511 .77349 L F
0 0 .593 r
.89214 .55352 m .9033 .48203 L .88842 .5385 L F
0 0 .572 r
.86783 .60723 m .89214 .55352 L .88842 .5385 L F
.226 .625 1 r
.45136 .05949 m .48205 .04685 L .43502 .06003 L F
.45136 .05949 m .49029 .04662 L .48205 .04685 L F
.448 .267 .561 r
.22759 .64502 m .19695 .61148 L .22939 .66008 L F
.22759 .64502 m .19575 .59604 L .19695 .61148 L F
.133 0 .561 r
.58001 .79735 m .62853 .79328 L .63939 .78715 L F
.102 0 .561 r
.57219 .80005 m .62853 .79328 L .58001 .79735 L F
.218 0 .561 r
.48487 .79813 m .45472 .79997 L .49324 .8007 L F
.48487 .79813 m .4382 .79484 L .45472 .79997 L F
0 0 .561 r
.69138 .77097 m .75011 .73391 L .69952 .76145 L F
.073 0 .561 r
.63939 .78715 m .69138 .77097 L .69952 .76145 L F
.104 .45 1 r
.68558 .08257 m .63738 .06048 L .62382 .05987 L F
.012 .382 1 r
.69958 .08383 m .63738 .06048 L .68558 .08257 L F
.033 .354 1 r
.74783 .11465 m .69958 .08383 L .68558 .08257 L F
0 .184 .975 r
.80287 .15616 m .74783 .11465 L .79023 .1527 L F
0 .135 .96 r
.84107 .20189 m .80287 .15616 L .79023 .1527 L F
0 0 .619 r
.9076 .49612 m .90916 .42382 L .9033 .48203 L F
0 0 .593 r
.89214 .55352 m .9076 .49612 L .9033 .48203 L F
.403 .698 .922 r
.23171 .19826 m .2586 .15714 L .21994 .20329 L F
.23171 .19826 m .26818 .15362 L .2586 .15714 L F
.447 .316 .561 r
.19575 .59604 m .1726 .55769 L .19695 .61148 L F
.19575 .59604 m .17196 .54255 L .1726 .55769 L F
.102 0 .561 r
.57219 .80005 m .61315 .79866 L .62853 .79328 L F
.077 0 .561 r
.5625 .80222 m .61315 .79866 L .57219 .80005 L F
.172 0 .561 r
.49324 .8007 m .4749 .80401 L .50336 .80271 L F
.49324 .8007 m .45472 .79997 L .4749 .80401 L F
.11 .497 1 r
.62382 .05987 m .57884 .04678 L .57009 .04656 L F
.056 .454 1 r
.63738 .06048 m .57884 .04678 L .62382 .05987 L F
.306 0 .561 r
.36491 .76409 m .32709 .7491 L .37511 .77349 L F
.36491 .76409 m .31454 .73722 L .32709 .7491 L F
0 0 .561 r
.62853 .79328 m .69138 .77097 L .63939 .78715 L F
.262 .657 1 r
.37289 .08291 m .4147 .06135 L .36074 .0842 L F
.37289 .08291 m .4226 .06066 L .4147 .06135 L F
0 0 .648 r
.91369 .43648 m .90576 .36527 L .90916 .42382 L F
0 0 .619 r
.9076 .49612 m .91369 .43648 L .90916 .42382 L F
.077 0 .561 r
.5625 .80222 m .59389 .80303 L .61315 .79866 L F
.062 0 .561 r
.55139 .80377 m .59389 .80303 L .5625 .80222 L F
.196 .608 1 r
.43502 .06003 m .47589 .04712 L .4226 .06066 L F
.43502 .06003 m .48205 .04685 L .47589 .04712 L F
0 0 .561 r
.74028 .74591 m .79581 .69849 L .75011 .73391 L F
.69138 .77097 m .74028 .74591 L .75011 .73391 L F
.436 .362 .561 r
.17196 .54255 m .1571 .50004 L .1726 .55769 L F
.17196 .54255 m .15685 .48583 L .1571 .50004 L F
.129 0 .561 r
.50336 .80271 m .49781 .80676 L .51478 .80407 L F
.50336 .80271 m .4749 .80401 L .49781 .80676 L F
.229 0 .561 r
.42606 .78888 m .39263 .78219 L .4382 .79484 L F
.42606 .78888 m .37511 .77349 L .39263 .78219 L F
.336 .676 .938 r
.26818 .15362 m .30425 .11754 L .2586 .15714 L F
.26818 .15362 m .31151 .11525 L .30425 .11754 L F
0 .235 .981 r
.75767 .11691 m .69958 .08383 L .74783 .11465 L F
0 .184 .975 r
.80287 .15616 m .75767 .11691 L .74783 .11465 L F
.062 0 .561 r
.55139 .80377 m .57161 .80615 L .59389 .80303 L F
.059 0 .561 r
.53936 .80461 m .57161 .80615 L .55139 .80377 L F
.094 0 .561 r
.51478 .80407 m .52238 .80807 L .52697 .80472 L F
.51478 .80407 m .49781 .80676 L .52238 .80807 L F
0 0 .679 r
.91015 .37617 m .89309 .30781 L .90576 .36527 L F
0 0 .648 r
.91369 .43648 m .91015 .37617 L .90576 .36527 L F
.059 0 .561 r
.53936 .80461 m .54739 .80786 L .57161 .80615 L F
.07 0 .561 r
.52697 .80472 m .54739 .80786 L .53936 .80461 L F
.52697 .80472 m .52238 .80807 L .54739 .80786 L F
.074 .498 1 r
.53599 .04622 m .53148 .04288 L .52358 .04623 L F
.066 .49 1 r
.5482 .04628 m .53148 .04288 L .53599 .04622 L F
.078 .502 1 r
.52358 .04623 m .53148 .04288 L .51151 .0463 L F
.414 .402 .561 r
.15685 .48583 m .15099 .44001 L .1571 .50004 L F
.15685 .48583 m .15091 .42723 L .15099 .44001 L F
.054 .478 1 r
.55973 .04639 m .53148 .04288 L .5482 .04628 L F
.077 .502 1 r
.51151 .0463 m .53148 .04288 L .50025 .04643 L F
.291 0 .561 r
.31454 .73722 m .28332 .71606 L .32709 .7491 L F
.31454 .73722 m .26896 .70231 L .28332 .71606 L F
0 0 .561 r
.78476 .71235 m .83541 .65594 L .79581 .69849 L F
.74028 .74591 m .78476 .71235 L .79581 .69849 L F
.056 .454 1 r
.63738 .06048 m .5856 .04705 L .57884 .04678 L F
0 .398 1 r
.64657 .06116 m .5856 .04705 L .63738 .06048 L F
.012 .382 1 r
.69958 .08383 m .64657 .06116 L .63738 .06048 L F
.038 .462 1 r
.57009 .04656 m .53148 .04288 L .55973 .04639 L F
0 0 .712 r
.89698 .31677 m .87138 .25288 L .89309 .30781 L F
0 0 .679 r
.91015 .37617 m .89698 .31677 L .89309 .30781 L F
.259 .637 .948 r
.31151 .11525 m .35576 .08557 L .30425 .11754 L F
.31151 .11525 m .36074 .0842 L .35576 .08557 L F
0 0 .561 r
.62853 .79328 m .67581 .77991 L .69138 .77097 L F
.61315 .79866 m .67581 .77991 L .62853 .79328 L F
.071 .498 1 r
.50025 .04643 m .53148 .04288 L .49029 .04662 L F
0 0 .561 r
.15091 .42723 m .15455 .3792 L .15099 .44001 L F
.15091 .42723 m .15437 .3682 L .15455 .3792 L F
.67581 .77991 m .74028 .74591 L .69138 .77097 L F
.151 .571 1 r
.4226 .06066 m .4721 .04742 L .4147 .06135 L F
.4226 .06066 m .47589 .04712 L .4721 .04742 L F
0 .285 .977 r
.70658 .08519 m .64657 .06116 L .69958 .08383 L F
0 .235 .981 r
.75767 .11691 m .70658 .08519 L .69958 .08383 L F
.133 0 .561 r
.4382 .79484 m .41686 .78973 L .45472 .79997 L F
.4382 .79484 m .39263 .78219 L .41686 .78973 L F
.019 .443 .996 r
.57884 .04678 m .53148 .04288 L .57009 .04656 L F
.061 .489 .992 r
.49029 .04662 m .53148 .04288 L .48205 .04685 L F
0 0 .712 r
.89698 .31677 m .87448 .2599 L .87138 .25288 L F
.358 .167 .561 r
.87448 .2599 m .84107 .20189 L .87138 .25288 L F
0 0 .561 r
.78476 .71235 m .82355 .67099 L .83541 .65594 L F
.358 .622 .812 r
.82355 .67099 m .86783 .60723 L .83541 .65594 L F
0 0 .561 r
.15437 .3682 m .16775 .31926 L .15455 .3792 L F
.15437 .3682 m .16722 .31022 L .16775 .31926 L F
0 .01 .857 r
.26896 .70231 m .2451 .67502 L .28332 .71606 L F
.26896 .70231 m .22939 .66008 L .2451 .67502 L F
0 .194 .921 r
.37511 .77349 m .34938 .76015 L .39263 .78219 L F
.37511 .77349 m .32709 .7491 L .34938 .76015 L F
.177 .582 .95 r
.36074 .0842 m .41178 .06209 L .35576 .08557 L F
.36074 .0842 m .4147 .06135 L .41178 .06209 L F
0 .422 .98 r
.5856 .04705 m .53148 .04288 L .57884 .04678 L F
.047 .475 .975 r
.48205 .04685 m .53148 .04288 L .47589 .04712 L F
.338 .092 .561 r
.84319 .20709 m .80287 .15616 L .84107 .20189 L F
.358 .167 .561 r
.87448 .2599 m .84319 .20709 L .84107 .20189 L F
0 0 .561 r
.61315 .79866 m .65333 .78781 L .67581 .77991 L F
.124 .545 .975 r
.59389 .80303 m .65333 .78781 L .61315 .79866 L F
0 0 .561 r
.16722 .31022 m .19029 .26184 L .16775 .31926 L F
.16722 .31022 m .18924 .25477 L .19029 .26184 L F
0 .398 1 r
.64657 .06116 m .59007 .04734 L .5856 .04705 L F
0 .331 .962 r
.65088 .06189 m .59007 .04734 L .64657 .06116 L F
0 .285 .977 r
.70658 .08519 m .65088 .06189 L .64657 .06116 L F
0 .37 .992 r
.45472 .79997 m .44679 .79571 L .4749 .80401 L F
.45472 .79997 m .41686 .78973 L .44679 .79571 L F
.436 .645 .811 r
.85547 .62273 m .89214 .55352 L .86783 .60723 L F
.358 .622 .812 r
.82355 .67099 m .85547 .62273 L .86783 .60723 L F
0 .398 .961 r
.59007 .04734 m .53148 .04288 L .5856 .04705 L F
.306 .01 .561 r
.80395 .15978 m .75767 .11691 L .80287 .15616 L F
.338 .092 .561 r
.84319 .20709 m .80395 .15978 L .80287 .15616 L F
0 0 .561 r
.67581 .77991 m .72061 .75724 L .74028 .74591 L F
.299 .661 .949 r
.72061 .75724 m .78476 .71235 L .74028 .74591 L F
0 0 .561 r
.4147 .06135 m .47087 .04773 L .41178 .06209 L F
.4147 .06135 m .4721 .04742 L .47087 .04773 L F
0 0 .872 r
.22939 .66008 m .2136 .6269 L .2451 .67502 L F
.22939 .66008 m .19695 .61148 L .2136 .6269 L F
0 0 .561 r
.47589 .04712 m .53148 .04288 L .4721 .04742 L F
.18924 .25477 m .22161 .20852 L .19029 .26184 L F
.18924 .25477 m .21994 .20329 L .22161 .20852 L F
.262 0 .561 r
.75781 .11925 m .70658 .08519 L .75767 .11691 L F
.306 .01 .561 r
.80395 .15978 m .75781 .11925 L .75767 .11691 L F
.124 .545 .975 r
.59389 .80303 m .62484 .79425 L .65333 .78781 L F
.151 .572 1 r
.57161 .80615 m .62484 .79425 L .59389 .80303 L F
.248 .645 1 r
.65333 .78781 m .72061 .75724 L .67581 .77991 L F
0 0 .561 r
.21994 .20329 m .26083 .16078 L .22161 .20852 L F
.21994 .20329 m .2586 .15714 L .26083 .16078 L F
0 .331 .962 r
.65088 .06189 m .59201 .04765 L .59007 .04734 L F
.048 0 .561 r
.59201 .04765 m .53148 .04288 L .59007 .04734 L F
.039 .45 1 r
.4749 .80401 m .48101 .7998 L .49781 .80676 L F
.4749 .80401 m .44679 .79571 L .48101 .7998 L F
.491 .639 .797 r
.87951 .56875 m .9076 .49612 L .89214 .55352 L F
.436 .645 .811 r
.85547 .62273 m .87951 .56875 L .89214 .55352 L F
0 .224 .986 r
.32709 .7491 m .30971 .72895 L .34938 .76015 L F
.32709 .7491 m .28332 .71606 L .30971 .72895 L F
.207 0 .561 r
.70602 .08659 m .65088 .06189 L .70658 .08519 L F
.262 0 .561 r
.75781 .11925 m .70602 .08659 L .70658 .08519 L F
0 0 .561 r
.4721 .04742 m .53148 .04288 L .47087 .04773 L F
.2586 .15714 m .30687 .1199 L .26083 .16078 L F
.2586 .15714 m .30425 .11754 L .30687 .1199 L F
0 .343 1 r
.39263 .78219 m .38072 .7698 L .41686 .78973 L F
.39263 .78219 m .34938 .76015 L .38072 .7698 L F
0 0 .869 r
.19695 .61148 m .18986 .57285 L .2136 .6269 L F
.19695 .61148 m .1726 .55769 L .18986 .57285 L F
.151 .572 1 r
.57161 .80615 m .59163 .79888 L .62484 .79425 L F
.154 .57 1 r
.54739 .80786 m .59163 .79888 L .57161 .80615 L F
.142 0 .561 r
.65002 .06263 m .59201 .04765 L .65088 .06189 L F
.207 0 .561 r
.70602 .08659 m .65002 .06263 L .65088 .06189 L F
.097 .508 1 r
.49781 .80676 m .51782 .80174 L .52238 .80807 L F
.49781 .80676 m .48101 .7998 L .51782 .80174 L F
0 0 .561 r
.30425 .11754 m .35844 .08697 L .30687 .1199 L F
.30425 .11754 m .35576 .08557 L .35844 .08697 L F
.07 0 .561 r
.59131 .04796 m .53148 .04288 L .59201 .04765 L F
.142 0 .561 r
.65002 .06263 m .59131 .04796 L .59201 .04765 L F
.524 .611 .773 r
.89483 .51043 m .91369 .43648 L .9076 .49612 L F
.491 .639 .797 r
.87951 .56875 m .89483 .51043 L .9076 .49612 L F
0 0 .561 r
.35576 .08557 m .41409 .06284 L .35844 .08697 L F
.35576 .08557 m .41178 .06209 L .41409 .06284 L F
.154 .57 1 r
.54739 .80786 m .55535 .80143 L .59163 .79888 L F
.136 .547 1 r
.52238 .80807 m .55535 .80143 L .54739 .80786 L F
.409 .721 .979 r
.76162 .72555 m .82355 .67099 L .78476 .71235 L F
.299 .661 .949 r
.72061 .75724 m .76162 .72555 L .78476 .71235 L F
.136 .547 1 r
.52238 .80807 m .51782 .80174 L .55535 .80143 L F
.013 0 .561 r
.47087 .04773 m .53148 .04288 L .4723 .04804 L F
.09 0 .561 r
.58797 .04826 m .53148 .04288 L .59131 .04796 L F
.107 0 .561 r
.5821 .04855 m .53148 .04288 L .58797 .04826 L F
.058 0 .561 r
.47634 .04834 m .53148 .04288 L .48286 .04862 L F
.036 0 .561 r
.4723 .04804 m .53148 .04288 L .47634 .04834 L F
.121 0 .561 r
.57394 .04879 m .53148 .04288 L .5821 .04855 L F
.13 0 .561 r
.56385 .04899 m .53148 .04288 L .57394 .04879 L F
.097 0 .561 r
.49159 .04885 m .53148 .04288 L .50215 .04903 L F
.079 0 .561 r
.48286 .04862 m .53148 .04288 L .49159 .04885 L F
.135 0 .561 r
.55226 .04913 m .53148 .04288 L .56385 .04899 L F
.124 0 .561 r
.51405 .04916 m .53148 .04288 L .52677 .04922 L F
.112 0 .561 r
.50215 .04903 m .53148 .04288 L .51405 .04916 L F
.135 0 .561 r
.5397 .04921 m .53148 .04288 L .55226 .04913 L F
.132 0 .561 r
.52677 .04922 m .53148 .04288 L .5397 .04921 L F
0 0 .561 r
.41178 .06209 m .4723 .04804 L .41409 .06284 L F
.41178 .06209 m .47087 .04773 L .4723 .04804 L F
0 0 .852 r
.1726 .55769 m .17471 .5143 L .18986 .57285 L F
.1726 .55769 m .1571 .50004 L .17471 .5143 L F
.539 .565 .741 r
.90088 .44937 m .91015 .37617 L .91369 .43648 L F
.524 .611 .773 r
.89483 .51043 m .90088 .44937 L .91369 .43648 L F
.199 0 .561 r
.64387 .06336 m .59131 .04796 L .65002 .06263 L F
.64387 .06336 m .58797 .04826 L .59131 .04796 L F
.248 .645 1 r
.65333 .78781 m .69163 .76734 L .72061 .75724 L F
.296 .677 1 r
.62484 .79425 m .69163 .76734 L .65333 .78781 L F
0 .23 1 r
.28332 .71606 m .27486 .68911 L .30971 .72895 L F
.28332 .71606 m .2451 .67502 L .27486 .68911 L F
.041 0 .561 r
.41409 .06284 m .4723 .04804 L .47634 .04834 L F
.539 .508 .703 r
.89736 .38725 m .89698 .31677 L .91015 .37617 L F
.539 .565 .741 r
.90088 .44937 m .89736 .38725 L .91015 .37617 L F
.378 .72 1 r
.69163 .76734 m .76162 .72555 L .72061 .75724 L F
.089 .447 1 r
.41686 .78973 m .41983 .77749 L .44679 .79571 L F
.41686 .78973 m .38072 .7698 L .41983 .77749 L F
.291 0 .561 r
.69765 .08798 m .65002 .06263 L .70602 .08659 L F
.69765 .08798 m .64387 .06336 L .65002 .06263 L F
0 0 .825 r
.1571 .50004 m .16872 .45284 L .17471 .5143 L F
.1571 .50004 m .15099 .44001 L .16872 .45284 L F
.481 .733 .981 r
.7976 .68539 m .85547 .62273 L .82355 .67099 L F
.409 .721 .979 r
.76162 .72555 m .7976 .68539 L .82355 .67099 L F
.241 0 .561 r
.63259 .06405 m .58797 .04826 L .64387 .06336 L F
.63259 .06405 m .5821 .04855 L .58797 .04826 L F
.528 .44 .661 r
.8843 .32587 m .87448 .2599 L .89698 .31677 L F
.539 .508 .703 r
.89736 .38725 m .8843 .32587 L .89698 .31677 L F
.366 .071 .561 r
.74775 .12159 m .70602 .08659 L .75781 .11925 L F
.74775 .12159 m .69765 .08798 L .70602 .08659 L F
.041 0 .561 r
.41409 .06284 m .47634 .04834 L .42166 .06356 L F
.04 0 .561 r
.35844 .08697 m .41409 .06284 L .42166 .06356 L F
.102 0 .561 r
.42166 .06356 m .47634 .04834 L .48286 .04862 L F
.061 .37 1 r
.34938 .76015 m .34739 .74026 L .38072 .7698 L F
.34938 .76015 m .30971 .72895 L .34739 .74026 L F
.505 .364 .614 r
.86203 .26699 m .84319 .20709 L .87448 .2599 L F
.528 .44 .661 r
.8843 .32587 m .86203 .26699 L .87448 .2599 L F
.426 .18 .561 r
.79272 .1634 m .75781 .11925 L .80395 .15978 L F
.79272 .1634 m .74775 .12159 L .75781 .11925 L F
0 0 .792 r
.15099 .44001 m .1722 .39025 L .16872 .45284 L F
.15099 .44001 m .15455 .3792 L .1722 .39025 L F
.471 .277 .562 r
.8312 .21232 m .80395 .15978 L .84319 .20709 L F
.505 .364 .614 r
.86203 .26699 m .8312 .21232 L .84319 .20709 L F
.471 .277 .562 r
.8312 .21232 m .79272 .1634 L .80395 .15978 L F
.296 .677 1 r
.62484 .79425 m .65449 .77561 L .69163 .76734 L F
.309 .667 1 r
.59163 .79888 m .65449 .77561 L .62484 .79425 L F
.268 0 .561 r
.61659 .06465 m .5821 .04855 L .63259 .06405 L F
.61659 .06465 m .57394 .04879 L .5821 .04855 L F
.04 0 .561 r
.35844 .08697 m .42166 .06356 L .36896 .08834 L F
.034 0 .561 r
.30687 .1199 m .35844 .08697 L .36896 .08834 L F
.153 0 .561 r
.43429 .06422 m .48286 .04862 L .49159 .04885 L F
.102 0 .561 r
.42166 .06356 m .48286 .04862 L .43429 .06422 L F
.014 .221 1 r
.2451 .67502 m .246 .64148 L .27486 .68911 L F
.2451 .67502 m .2136 .6269 L .246 .64148 L F
0 0 .754 r
.15455 .3792 m .18512 .32832 L .1722 .39025 L F
.15455 .3792 m .16775 .31926 L .18512 .32832 L F
.174 .517 1 r
.44679 .79571 m .46483 .78276 L .48101 .7998 L F
.44679 .79571 m .41983 .77749 L .46483 .78276 L F
.523 .715 .965 r
.82735 .63762 m .87951 .56875 L .85547 .62273 L F
.481 .733 .981 r
.7976 .68539 m .82735 .63762 L .85547 .62273 L F
.034 0 .561 r
.30687 .1199 m .36896 .08834 L .31974 .12221 L F
.023 0 .561 r
.26083 .16078 m .30687 .1199 L .31974 .12221 L F
.341 .038 .561 r
.68154 .08927 m .64387 .06336 L .69765 .08798 L F
.68154 .08927 m .63259 .06405 L .64387 .06336 L F
.282 0 .561 r
.59653 .06513 m .57394 .04879 L .61659 .06465 L F
.59653 .06513 m .56385 .04899 L .57394 .04879 L F
0 0 .711 r
.16775 .31926 m .20712 .2689 L .18512 .32832 L F
.16775 .31926 m .19029 .26184 L .20712 .2689 L F
.195 0 .561 r
.45147 .06479 m .49159 .04885 L .50215 .04903 L F
.153 0 .561 r
.43429 .06422 m .49159 .04885 L .45147 .06479 L F
.023 0 .561 r
.26083 .16078 m .31974 .12221 L .27549 .16437 L F
.01 0 .61 r
.22161 .20852 m .26083 .16078 L .27549 .16437 L F
0 0 .663 r
.19029 .26184 m .23756 .21373 L .20712 .2689 L F
.19029 .26184 m .22161 .20852 L .23756 .21373 L F
.01 0 .61 r
.22161 .20852 m .27549 .16437 L .23756 .21373 L F
.129 0 .561 r
.36896 .08834 m .42166 .06356 L .43429 .06422 L F
.309 .667 1 r
.59163 .79888 m .61089 .78158 L .65449 .77561 L F
.299 .64 1 r
.55535 .80143 m .61089 .78158 L .59163 .79888 L F
.453 .729 1 r
.72692 .73736 m .7976 .68539 L .76162 .72555 L F
.378 .72 1 r
.69163 .76734 m .72692 .73736 L .76162 .72555 L F
.286 0 .561 r
.57332 .06548 m .56385 .04899 L .59653 .06513 L F
.57332 .06548 m .55226 .04913 L .56385 .04899 L F
.233 .567 1 r
.48101 .7998 m .51344 .78528 L .51782 .80174 L F
.48101 .7998 m .46483 .78276 L .51344 .78528 L F
.227 0 .561 r
.47249 .06524 m .50215 .04903 L .51405 .04916 L F
.195 0 .561 r
.45147 .06479 m .50215 .04903 L .47249 .06524 L F
.397 .705 1 r
.65449 .77561 m .72692 .73736 L .69163 .76734 L F
.282 0 .561 r
.54807 .06567 m .55226 .04913 L .57332 .06548 L F
.54807 .06567 m .5397 .04921 L .55226 .04913 L F
.252 0 .561 r
.49638 .06555 m .51405 .04916 L .52677 .04922 L F
.227 0 .561 r
.47249 .06524 m .51405 .04916 L .49638 .06555 L F
.299 .64 1 r
.55535 .80143 m .56302 .78488 L .61089 .78158 L F
.273 .607 1 r
.51782 .80174 m .56302 .78488 L .55535 .80143 L F
.51782 .80174 m .51344 .78528 L .56302 .78488 L F
.27 0 .561 r
.52199 .06569 m .5397 .04921 L .54807 .06567 L F
.52199 .06569 m .52677 .04922 L .5397 .04921 L F
.545 .682 .94 r
.84985 .58343 m .89483 .51043 L .87951 .56875 L F
.523 .715 .965 r
.82735 .63762 m .84985 .58343 L .87951 .56875 L F
.252 0 .561 r
.49638 .06555 m .52677 .04922 L .52199 .06569 L F
.054 .203 .985 r
.2136 .6269 m .22416 .58725 L .246 .64148 L F
.2136 .6269 m .18986 .57285 L .22416 .58725 L F
.412 .168 .571 r
.72748 .1238 m .69765 .08798 L .74775 .12159 L F
.72748 .1238 m .68154 .08927 L .69765 .08798 L F
.174 .457 1 r
.38072 .7698 m .39484 .74932 L .41983 .77749 L F
.38072 .7698 m .34739 .74026 L .39484 .74932 L F
.123 .364 1 r
.30971 .72895 m .31795 .70154 L .34739 .74026 L F
.30971 .72895 m .27486 .68911 L .31795 .70154 L F
.364 .097 .561 r
.65821 .09042 m .63259 .06405 L .68154 .08927 L F
.65821 .09042 m .61659 .06465 L .63259 .06405 L F
.129 0 .561 r
.36896 .08834 m .43429 .06422 L .38711 .08961 L F
.145 0 .598 r
.31974 .12221 m .36896 .08834 L .38711 .08961 L F
.197 0 .577 r
.38711 .08961 m .43429 .06422 L .45147 .06479 L F
.554 .641 .911 r
.86423 .52427 m .90088 .44937 L .89483 .51043 L F
.545 .682 .94 r
.84985 .58343 m .86423 .52427 L .89483 .51043 L F
.462 .273 .645 r
.76898 .16686 m .74775 .12159 L .79272 .1634 L F
.76898 .16686 m .72748 .1238 L .74775 .12159 L F
.084 .182 .959 r
.18986 .57285 m .21019 .52787 L .22416 .58725 L F
.18986 .57285 m .17471 .5143 L .21019 .52787 L F
.492 .707 1 r
.75803 .69835 m .82735 .63762 L .7976 .68539 L F
.453 .729 1 r
.72692 .73736 m .75803 .69835 L .7976 .68539 L F
.397 .705 1 r
.65449 .77561 m .68194 .74711 L .72692 .73736 L F
.388 .669 1 r
.61089 .78158 m .68194 .74711 L .65449 .77561 L F
.37 .131 .616 r
.62861 .09136 m .61659 .06465 L .65821 .09042 L F
.62861 .09136 m .59653 .06513 L .61659 .06465 L F
.555 .595 .878 r
.86991 .46183 m .89736 .38725 L .90088 .44937 L F
.554 .641 .911 r
.86423 .52427 m .86991 .46183 L .90088 .44937 L F
.497 .358 .706 r
.80471 .21734 m .79272 .1634 L .8312 .21232 L F
.80471 .21734 m .76898 .16686 L .79272 .1634 L F
.145 0 .598 r
.31974 .12221 m .38711 .08961 L .34274 .12437 L F
.151 0 .673 r
.27549 .16437 m .31974 .12221 L .34274 .12437 L F
.247 .006 .627 r
.41226 .0907 m .45147 .06479 L .47249 .06524 L F
.197 0 .577 r
.38711 .08961 m .45147 .06479 L .41226 .0907 L F
.248 .513 1 r
.41983 .77749 m .4498 .75556 L .46483 .78276 L F
.41983 .77749 m .39484 .74932 L .4498 .75556 L F
.423 .221 .657 r
.69753 .12577 m .68154 .08927 L .72748 .1238 L F
.69753 .12577 m .65821 .09042 L .68154 .08927 L F
.446 .687 1 r
.68194 .74711 m .75803 .69835 L .72692 .73736 L F
.549 .545 .842 r
.86661 .39797 m .8843 .32587 L .89736 .38725 L F
.555 .595 .878 r
.86991 .46183 m .86661 .39797 L .89736 .38725 L F
.163 .346 1 r
.27486 .68911 m .29347 .65441 L .31795 .70154 L F
.27486 .68911 m .246 .64148 L .29347 .65441 L F
.521 .429 .758 r
.83349 .27382 m .8312 .21232 L .86203 .26699 L F
.83349 .27382 m .80471 .21734 L .8312 .21232 L F
.106 .158 .929 r
.17471 .5143 m .20467 .46507 L .21019 .52787 L F
.17471 .5143 m .16872 .45284 L .20467 .46507 L F
.538 .49 .802 r
.85434 .33465 m .86203 .26699 L .8843 .32587 L F
.549 .545 .842 r
.86661 .39797 m .85434 .33465 L .8843 .32587 L F
.538 .49 .802 r
.85434 .33465 m .83349 .27382 L .86203 .26699 L F
.365 .145 .651 r
.59408 .09204 m .59653 .06513 L .62861 .09136 L F
.59408 .09204 m .57332 .06548 L .59653 .06513 L F
.151 0 .673 r
.27549 .16437 m .34274 .12437 L .30258 .16775 L F
.153 .001 .733 r
.23756 .21373 m .27549 .16437 L .30258 .16775 L F
.221 .013 .674 r
.34274 .12437 m .38711 .08961 L .41226 .0907 L F
.285 .063 .658 r
.44336 .09158 m .47249 .06524 L .49638 .06555 L F
.247 .006 .627 r
.41226 .0907 m .47249 .06524 L .44336 .09158 L F
.388 .669 1 r
.61089 .78158 m .62876 .75416 L .68194 .74711 L F
.367 .631 1 r
.56302 .78488 m .62876 .75416 L .61089 .78158 L F
.223 .44 1 r
.34739 .74026 m .3727 .71153 L .39484 .74932 L F
.34739 .74026 m .31795 .70154 L .3727 .71153 L F
.511 .675 1 r
.78387 .65109 m .84985 .58343 L .82735 .63762 L F
.492 .707 1 r
.75803 .69835 m .78387 .65109 L .82735 .63762 L F
.123 .133 .897 r
.16872 .45284 m .20788 .40076 L .20467 .46507 L F
.16872 .45284 m .1722 .39025 L .20788 .40076 L F
.3 .556 1 r
.46483 .78276 m .50935 .75854 L .51344 .78528 L F
.46483 .78276 m .4498 .75556 L .50935 .75854 L F
.353 .144 .672 r
.55632 .09241 m .57332 .06548 L .59408 .09204 L F
.55632 .09241 m .54807 .06567 L .57332 .06548 L F
.153 .001 .733 r
.23756 .21373 m .30258 .16775 L .26796 .21863 L F
.15 .041 .782 r
.20712 .2689 m .23756 .21373 L .26796 .21863 L F
.314 .104 .675 r
.47896 .09217 m .49638 .06555 L .52199 .06569 L F
.285 .063 .658 r
.44336 .09158 m .49638 .06555 L .47896 .09217 L F
.135 .106 .863 r
.1722 .39025 m .2198 .33694 L .20788 .40076 L F
.1722 .39025 m .18512 .32832 L .2198 .33694 L F
.367 .631 1 r
.56302 .78488 m .57015 .75806 L .62876 .75416 L F
.338 .593 1 r
.51344 .78528 m .57015 .75806 L .56302 .78488 L F
.336 .13 .679 r
.51727 .09245 m .54807 .06567 L .55632 .09241 L F
.51727 .09245 m .52199 .06569 L .54807 .06567 L F
.338 .593 1 r
.51344 .78528 m .50935 .75854 L .57015 .75806 L F
.15 .041 .782 r
.20712 .2689 m .26796 .21863 L .24005 .2756 L F
.144 .075 .825 r
.18512 .32832 m .20712 .2689 L .24005 .2756 L F
.314 .104 .675 r
.47896 .09217 m .52199 .06569 L .51727 .09245 L F
.46 .312 .729 r
.73327 .16995 m .72748 .1238 L .76898 .16686 L F
.73327 .16995 m .69753 .12577 L .72748 .1238 L F
.144 .075 .825 r
.18512 .32832 m .24005 .2756 L .2198 .33694 L F
.418 .245 .71 r
.65907 .12739 m .65821 .09042 L .69753 .12577 L F
.65907 .12739 m .62861 .09136 L .65821 .09042 L F
.19 .324 1 r
.246 .64148 m .27489 .60005 L .29347 .65441 L F
.246 .64148 m .22416 .58725 L .27489 .60005 L F
.221 .013 .674 r
.34274 .12437 m .41226 .0907 L .37515 .12625 L F
.233 .077 .745 r
.30258 .16775 m .34274 .12437 L .37515 .12625 L F
.274 .096 .721 r
.37515 .12625 m .41226 .0907 L .44336 .09158 L F
.52 .639 .986 r
.80348 .59676 m .86423 .52427 L .84985 .58343 L F
.511 .675 1 r
.78387 .65109 m .80348 .59676 L .84985 .58343 L F
.446 .687 1 r
.68194 .74711 m .70625 .70908 L .75803 .69835 L F
.425 .642 1 r
.62876 .75416 m .70625 .70908 L .68194 .74711 L F
.47 .657 1 r
.70625 .70908 m .78387 .65109 L .75803 .69835 L F
.287 .49 1 r
.39484 .74932 m .43644 .71843 L .4498 .75556 L F
.39484 .74932 m .3727 .71153 L .43644 .71843 L F
.484 .382 .784 r
.7642 .22185 m .76898 .16686 L .80471 .21734 L F
.7642 .22185 m .73327 .16995 L .76898 .16686 L F
0 g
1 Mabswid
[ ] 0 setdash
.24247 .6292 m
.24836 .63792 L
s
.24836 .63792 m
.25307 .64373 L
s
.25307 .64373 m
.26019 .65004 L
s
.23661 .61484 m
.24247 .6292 L
s
.251 .417 1 r
.31795 .70154 m .35421 .66485 L .3727 .71153 L F
.31795 .70154 m .29347 .65441 L .35421 .66485 L F
.405 .25 .743 r
.61386 .12856 m .62861 .09136 L .65907 .12739 L F
.61386 .12856 m .59408 .09204 L .62861 .09136 L F
0 g
.26019 .65004 m
.26626 .65382 L
s
.208 .3 .992 r
.22416 .58725 m .26296 .53996 L .27489 .60005 L F
.22416 .58725 m .21019 .52787 L .26296 .53996 L F
.523 .603 .958 r
.81605 .53685 m .86991 .46183 L .86423 .52427 L F
.52 .639 .986 r
.80348 .59676 m .81605 .53685 L .86423 .52427 L F
0 g
.23558 .60628 m
.23661 .61484 L
s
.26626 .65382 m
.27653 .65653 L
s
.313 .155 .749 r
.41566 .12776 m .44336 .09158 L .47896 .09217 L F
.274 .096 .721 r
.37515 .12625 m .44336 .09158 L .41566 .12776 L F
.233 .077 .745 r
.30258 .16775 m .37515 .12625 L .34138 .17071 L F
.238 .126 .798 r
.26796 .21863 m .30258 .16775 L .34138 .17071 L F
.499 .438 .829 r
.78921 .28 m .80471 .21734 L .83349 .27382 L F
.78921 .28 m .7642 .22185 L .80471 .21734 L F
.425 .642 1 r
.62876 .75416 m .64465 .71688 L .70625 .70908 L F
.398 .602 1 r
.57015 .75806 m .64465 .71688 L .62876 .75416 L F
.445 .324 .777 r
.68689 .17251 m .69753 .12577 L .73327 .16995 L F
.68689 .17251 m .65907 .12739 L .69753 .12577 L F
0 g
.23558 .60628 m
.23581 .6005 L
s
.522 .565 .929 r
.82103 .47317 m .86661 .39797 L .86991 .46183 L F
.523 .603 .958 r
.81605 .53685 m .82103 .47317 L .86991 .46183 L F
.333 .529 1 r
.4498 .75556 m .50571 .72173 L .50935 .75854 L F
.4498 .75556 m .43644 .71843 L .50571 .72173 L F
0 g
.27653 .65653 m
.28082 .65548 L
s
.388 .243 .761 r
.5642 .1292 m .59408 .09204 L .61386 .12856 L F
.5642 .1292 m .55632 .09241 L .59408 .09204 L F
0 g
.23581 .6005 m
.23873 .59517 L
s
.481 .624 1 r
.72652 .66228 m .80348 .59676 L .78387 .65109 L F
.47 .657 1 r
.70625 .70908 m .72652 .66228 L .78387 .65109 L F
.51 .485 .866 r
.80741 .34263 m .83349 .27382 L .85434 .33465 L F
.80741 .34263 m .78921 .28 L .83349 .27382 L F
.287 .16 .786 r
.34138 .17071 m .37515 .12625 L .41566 .12776 L F
.343 .196 .763 r
.46233 .12879 m .47896 .09217 L .51727 .09245 L F
.313 .155 .749 r
.41566 .12776 m .47896 .09217 L .46233 .12879 L F
.22 .277 .965 r
.21019 .52787 m .25824 .47597 L .26296 .53996 L F
.21019 .52787 m .20467 .46507 L .25824 .47597 L F
.517 .527 .899 r
.81813 .40772 m .85434 .33465 L .86661 .39797 L F
.522 .565 .929 r
.82103 .47317 m .81813 .40772 L .86661 .39797 L F
0 g
.28082 .65548 m
.28424 .65188 L
s
.517 .527 .899 r
.81813 .40772 m .80741 .34263 L .85434 .33465 L F
.238 .126 .798 r
.26796 .21863 m .34138 .17071 L .31211 .22297 L F
.24 .165 .841 r
.24005 .2756 m .26796 .21863 L .31211 .22297 L F
.398 .602 1 r
.57015 .75806 m .57651 .72121 L .64465 .71688 L F
.368 .565 1 r
.50935 .75854 m .57651 .72121 L .57015 .75806 L F
.367 .225 .767 r
.51276 .12928 m .55632 .09241 L .5642 .1292 L F
.51276 .12928 m .51727 .09245 L .55632 .09241 L F
.368 .565 1 r
.50935 .75854 m .50571 .72173 L .57651 .72121 L F
0 g
.23873 .59517 m
.24296 .59309 L
s
.343 .196 .763 r
.46233 .12879 m .51727 .09245 L .51276 .12928 L F
.442 .611 1 r
.64465 .71688 m .72652 .66228 L .70625 .70908 L F
.269 .393 1 r
.29347 .65441 m .34014 .61041 L .35421 .66485 L F
.29347 .65441 m .27489 .60005 L .34014 .61041 L F
0 g
.28424 .65188 m
.28499 .64744 L
s
.229 .252 .937 r
.20467 .46507 m .26099 .41013 L .25824 .47597 L F
.20467 .46507 m .20788 .40076 L .26099 .41013 L F
0 g
.24296 .59309 m
.25404 .59578 L
s
.24 .165 .841 r
.24005 .2756 m .31211 .22297 L .28841 .28153 L F
.239 .198 .877 r
.2198 .33694 m .24005 .2756 L .28841 .28153 L F
.308 .464 1 r
.3727 .71153 m .42526 .67206 L .43644 .71843 L F
.3727 .71153 m .35421 .66485 L .42526 .67206 L F
0 g
.2848 .64008 m
.28499 .64744 L
s
.462 .382 .826 r
.71108 .2256 m .73327 .16995 L .7642 .22185 L F
.71108 .2256 m .68689 .17251 L .73327 .16995 L F
.235 .226 .908 r
.20788 .40076 m .27116 .3446 L .26099 .41013 L F
.20788 .40076 m .2198 .33694 L .27116 .3446 L F
.426 .321 .805 r
.632 .17436 m .65907 .12739 L .68689 .17251 L F
.632 .17436 m .61386 .12856 L .65907 .12739 L F
.239 .198 .877 r
.2198 .33694 m .28841 .28153 L .27116 .3446 L F
0 g
.27971 .6257 m
.2848 .64008 L
s
.486 .592 1 r
.74194 .60786 m .81605 .53685 L .80348 .59676 L F
0 g
.78054 .64206 m
.78328 .63365 L
s
.481 .624 1 r
.72652 .66228 m .74194 .60786 L .80348 .59676 L F
0 g
.78328 .63365 m
.7946 .5989 L
s
.77566 .6406 m
.78366 .63376 L
s
.76859 .64455 m
.77566 .6406 L
s
.25404 .59578 m
.26082 .60056 L
s
.326 .217 .81 r
.39033 .17309 m .41566 .12776 L .46233 .12879 L F
.287 .16 .786 r
.34138 .17071 m .41566 .12776 L .39033 .17309 L F
0 g
.30403 .63306 m
.31412 .66463 L
s
.294 .206 .834 r
.31211 .22297 m .34138 .17071 L .39033 .17309 L F
0 g
.75924 .64635 m
.76859 .64455 L
s
.26082 .60056 m
.26871 .60861 L
s
.27369 .61576 m
.27971 .6257 L
s
.26871 .60861 m
.27369 .61576 L
s
.78747 .60363 m
.79173 .60914 L
s
.442 .611 1 r
.64465 .71688 m .65793 .67044 L .72652 .66228 L F
.414 .571 1 r
.57651 .72121 m .65793 .67044 L .64465 .71688 L F
0 g
.75375 .64479 m
.75924 .64635 L
s
.28 .369 1 r
.27489 .60005 m .33109 .54977 L .34014 .61041 L F
0 g
.29469 .60381 m
.30403 .63306 L
s
.28 .369 1 r
.27489 .60005 m .26296 .53996 L .33109 .54977 L F
.472 .428 .865 r
.73071 .28515 m .7642 .22185 L .78921 .28 L F
.73071 .28515 m .71108 .2256 L .7642 .22185 L F
.405 .308 .819 r
.57145 .17538 m .61386 .12856 L .632 .17436 L F
.57145 .17538 m .5642 .1292 L .61386 .12856 L F
.35 .502 1 r
.43644 .71843 m .50267 .67553 L .50571 .72173 L F
.43644 .71843 m .42526 .67206 L .50267 .67553 L F
0 g
.74898 .64033 m
.75375 .64479 L
s
.451 .581 1 r
.65793 .67044 m .74194 .60786 L .72652 .66228 L F
0 g
.3368 .66846 m
.34102 .67129 L
s
.3368 .66846 m
.33933 .6666 L
s
.34102 .67129 m
.34357 .66948 L
s
.488 .562 .976 r
.75185 .54736 m .82103 .47317 L .81605 .53685 L F
.486 .592 1 r
.74194 .60786 m .75185 .54736 L .81605 .53685 L F
0 g
.78203 .60136 m
.78747 .60363 L
s
.357 .257 .822 r
.44708 .17472 m .46233 .12879 L .51276 .12928 L F
.326 .217 .81 r
.39033 .17309 m .46233 .12879 L .44708 .17472 L F
0 g
.33933 .6666 m
.34357 .66948 L
s
.77218 .60314 m
.78203 .60136 L
s
.74825 .63208 m
.74898 .64033 L
s
.71306 .67038 m
.72086 .64141 L
s
.40251 .15079 m
.43148 .15156 L
s
.43148 .15156 m
.44121 .15182 L
s
.40251 .15079 m
.40283 .16999 L
s
.414 .571 1 r
.57651 .72121 m .58182 .67497 L .65793 .67044 L F
.384 .536 1 r
.50571 .72173 m .58182 .67497 L .57651 .72121 L F
.294 .206 .834 r
.31211 .22297 m .39033 .17309 L .36829 .22645 L F
.297 .243 .871 r
.28841 .28153 m .31211 .22297 L .36829 .22645 L F
.383 .287 .825 r
.50861 .17551 m .5642 .1292 L .57145 .17538 L F
.50861 .17551 m .51276 .12928 L .5642 .1292 L F
.321 .439 1 r
.35421 .66485 m .41673 .61759 L .42526 .67206 L F
.35421 .66485 m .34014 .61041 L .41673 .61759 L F
.384 .536 1 r
.50571 .72173 m .50267 .67553 L .58182 .67497 L F
.439 .372 .849 r
.64781 .22832 m .68689 .17251 L .71108 .2256 L F
.64781 .22832 m .632 .17436 L .68689 .17251 L F
.357 .257 .822 r
.44708 .17472 m .51276 .12928 L .50861 .17551 L F
.48 .466 .897 r
.74503 .34928 m .78921 .28 L .80741 .34263 L F
.74503 .34928 m .73071 .28515 L .78921 .28 L F
0 g
.32296 .60812 m
.33196 .6426 L
s
.33196 .6426 m
.33426 .65139 L
s
.74825 .63208 m
.74998 .62592 L
s
.487 .531 .951 r
.75577 .48264 m .81813 .40772 L .82103 .47317 L F
.488 .562 .976 r
.75185 .54736 m .75577 .48264 L .82103 .47317 L F
0 g
.76458 .60777 m
.77218 .60314 L
s
.288 .346 .979 r
.26296 .53996 m .32751 .48482 L .33109 .54977 L F
.26296 .53996 m .25824 .47597 L .32751 .48482 L F
0 g
.74998 .62592 m
.75601 .61567 L
s
.75601 .61567 m
.76458 .60777 L
s
.334 .261 .854 r
.36829 .22645 m .39033 .17309 L .44708 .17472 L F
0 g
.40283 .16999 m
.40304 .18273 L
s
.484 .5 .925 r
.75349 .41586 m .80741 .34263 L .81813 .40772 L F
.75349 .41586 m .74503 .34928 L .80741 .34263 L F
.487 .531 .951 r
.75577 .48264 m .75349 .41586 L .81813 .40772 L F
0 g
.71225 .65105 m
.72107 .6445 L
s
.70416 .65468 m
.71225 .65105 L
s
.297 .243 .871 r
.28841 .28153 m .36829 .22645 L .35038 .28632 L F
.297 .273 .902 r
.27116 .3446 m .28841 .28153 L .35038 .28632 L F
.455 .553 1 r
.66806 .61598 m .75185 .54736 L .74194 .60786 L F
0 g
.72086 .64141 m
.72173 .63819 L
s
.451 .581 1 r
.65793 .67044 m .66806 .61598 L .74194 .60786 L F
0 g
.72173 .63819 m
.72944 .60952 L
s
.69296 .65599 m
.70416 .65468 L
s
.59584 .15228 m
.60474 .15214 L
s
.60474 .15214 m
.61594 .1592 L
s
.293 .324 .955 r
.25824 .47597 m .32959 .41773 L .32751 .48482 L F
.25824 .47597 m .26099 .41013 L .32959 .41773 L F
0 g
.58848 .15965 m
.59584 .15228 L
s
.421 .544 1 r
.58182 .67497 m .66806 .61598 L .65793 .67044 L F
0 g
.68602 .6541 m
.69296 .65599 L
s
.61594 .1592 m
.62686 .17387 L
s
.4766 .15241 m
.48264 .15248 L
s
.46573 .15952 m
.4766 .15241 L
s
.48264 .15248 m
.49059 .15982 L
s
.297 .273 .902 r
.27116 .3446 m .35038 .28632 L .33731 .3508 L F
.296 .3 .93 r
.26099 .41013 m .27116 .3446 L .33731 .3508 L F
0 g
.36026 .64402 m
.37374 .65376 L
s
.37374 .65376 m
.38207 .65727 L
s
.296 .3 .93 r
.26099 .41013 m .33731 .3508 L .32959 .41773 L F
.415 .354 .862 r
.57777 .22983 m .632 .17436 L .64781 .22832 L F
.57777 .22983 m .57145 .17538 L .632 .17436 L F
0 g
.67953 .6493 m
.68602 .6541 L
s
.38207 .65727 m
.39375 .6584 L
s
.72114 .61397 m
.72724 .61982 L
s
.446 .411 .884 r
.66068 .28889 m .71108 .2256 L .73071 .28515 L F
.66068 .28889 m .64781 .22832 L .71108 .2256 L F
.36 .476 1 r
.42526 .67206 m .50034 .62104 L .50267 .67553 L F
.42526 .67206 m .41673 .61759 L .50034 .62104 L F
0 g
.54408 .15272 m
.55397 .15995 L
s
.53791 .15274 m
.54408 .15272 L
s
.52856 .16001 m
.53791 .15274 L
s
.58688 .16707 m
.58848 .15965 L
s
.28312 .51546 m
.28357 .54096 L
s
.28198 .45079 m
.28293 .5046 L
s
.28293 .5046 m
.28312 .51546 L
s
.28148 .42212 m
.28198 .45079 L
s
.329 .416 1 r
.34014 .61041 m .41124 .55657 L .41673 .61759 L F
0 g
.35341 .61189 m
.3612 .64665 L
s
.3612 .64665 m
.36312 .6552 L
s
.329 .416 1 r
.34014 .61041 m .33109 .54977 L .41124 .55657 L F
.365 .301 .863 r
.43378 .22886 m .44708 .17472 L .50861 .17551 L F
.334 .261 .854 r
.36829 .22645 m .44708 .17472 L .43378 .22886 L F
0 g
.39375 .6584 m
.40109 .65639 L
s
.62686 .17387 m
.63698 .19652 L
s
.63698 .19652 m
.63709 .19677 L
s
.6774 .64087 m
.67953 .6493 L
s
.7141 .61138 m
.72114 .61397 L
s
.58639 .18222 m
.58688 .16707 L
s
.40109 .65639 m
.40347 .64826 L
s
.337 .296 .888 r
.35038 .28632 m .36829 .22645 L .43378 .22886 L F
0 g
.40345 .20734 m
.4038 .228 L
s
.40304 .18273 m
.40345 .20734 L
s
.421 .544 1 r
.58182 .67497 m .58589 .62049 L .66806 .61598 L F
.392 .51 1 r
.50267 .67553 m .58589 .62049 L .58182 .67497 L F
0 g
.56106 .6817 m
.56508 .68392 L
s
.56508 .68392 m
.56938 .68151 L
s
.6774 .64087 m
.67858 .6347 L
s
.391 .331 .866 r
.50499 .23002 m .57145 .17538 L .57777 .22983 L F
.50499 .23002 m .50861 .17551 L .57145 .17538 L F
0 g
.55397 .15995 m
.56264 .18246 L
s
.52145 .18256 m
.52856 .16001 L
s
.56538 .67926 m
.56938 .68151 L
s
.41721 .65767 m
.42584 .66096 L
s
.40347 .64826 m
.41721 .65767 L
s
.456 .526 .984 r
.67458 .55504 m .75577 .48264 L .75185 .54736 L F
.455 .553 1 r
.66806 .61598 m .67458 .55504 L .75185 .54736 L F
0 g
.70228 .61268 m
.7141 .61138 L
s
.392 .51 1 r
.50267 .67553 m .50034 .62104 L .58589 .62049 L F
0 g
.42584 .66096 m
.43819 .66175 L
s
.56106 .6817 m
.56538 .67926 L
s
.365 .301 .863 r
.43378 .22886 m .50861 .17551 L .50499 .23002 L F
0 g
.49059 .15982 m
.49406 .18241 L
s
.45379 .18187 m
.46573 .15952 L
s
.39832 .6161 m
.40347 .64826 L
s
.44159 .22104 m
.45379 .18187 L
s
.62958 .66145 m
.63825 .65821 L
s
.63825 .65821 m
.6474 .65204 L
s
.67858 .6347 m
.68438 .62459 L
s
.61715 .66218 m
.62958 .66145 L
s
.43819 .66175 m
.44613 .65951 L
s
.69365 .617 m
.70228 .61268 L
s
.63709 .19677 m
.64144 .2125 L
s
.60912 .6599 m
.61715 .66218 L
s
.68438 .62459 m
.69365 .617 L
s
.451 .444 .913 r
.67009 .35414 m .73071 .28515 L .74503 .34928 L F
.67009 .35414 m .66068 .28889 L .73071 .28515 L F
0 g
.44613 .65951 m
.44929 .65126 L
s
.49372 .22188 m
.49406 .18241 L
s
.60126 .6547 m
.60912 .6599 L
s
.56264 .18246 m
.56986 .22187 L
s
.51653 .22203 m
.52145 .18256 L
s
.334 .394 .985 r
.33109 .54977 m .40907 .49096 L .41124 .55657 L F
.33109 .54977 m .32751 .48482 L .40907 .49096 L F
.426 .518 1 r
.58589 .62049 m .67458 .55504 L .66806 .61598 L F
0 g
.64724 .65178 m
.65258 .61698 L
s
.64593 .66034 m
.64724 .65178 L
s
.49737 .66411 m
.51027 .66433 L
s
.48862 .6612 m
.49737 .66411 L
s
.51027 .66433 m
.51884 .66171 L
s
.4796 .65536 m
.48862 .6612 L
s
.5978 .64606 m
.60126 .6547 L
s
.456 .5 .961 r
.67716 .48958 m .75349 .41586 L .75577 .48264 L F
.456 .526 .984 r
.67458 .55504 m .67716 .48958 L .75577 .48264 L F
0 g
.51884 .66171 m
.52747 .65617 L
s
.421 .39 .894 r
.58293 .29098 m .64781 .22832 L .66068 .28889 L F
.58293 .29098 m .57777 .22983 L .64781 .22832 L F
0 g
.64144 .2125 m
.64373 .23661 L
s
.31042 .50973 m
.31101 .44932 L
s
.31101 .44932 m
.31124 .42535 L
s
.337 .296 .888 r
.35038 .28632 m .43378 .22886 L .42294 .28964 L F
0 g
.4038 .228 m
.40508 .25241 L
s
.339 .324 .916 r
.33731 .3508 m .35038 .28632 L .42294 .28964 L F
0 g
.64356 .62107 m
.65122 .62732 L
s
.454 .473 .938 r
.67566 .42182 m .74503 .34928 L .75349 .41586 L F
.67566 .42182 m .67009 .35414 L .74503 .34928 L F
.365 .453 1 r
.41673 .61759 m .49885 .55984 L .50034 .62104 L F
0 g
.44597 .61907 m
.44929 .65126 L
s
.47965 .65367 m
.48026 .66366 L
s
.365 .453 1 r
.41673 .61759 m .41124 .55657 L .49885 .55984 L F
0 g
.47595 .59358 m
.47965 .65367 L
s
.52747 .65617 m
.53184 .64736 L
s
.5978 .64606 m
.59834 .63989 L
s
.456 .5 .961 r
.67716 .48958 m .67566 .42182 L .75349 .41586 L F
0 g
.30968 .48753 m
.32201 .50563 L
s
.35673 .28276 m
.35874 .27475 L
s
.369 .335 .896 r
.42294 .28964 m .43378 .22886 L .50499 .23002 L F
0 g
.63529 .61809 m
.64356 .62107 L
s
.59834 .63989 m
.60356 .62997 L
s
.32201 .50563 m
.3303 .5119 L
s
.53184 .64736 m
.53185 .64118 L
s
.63959 .25301 m
.64373 .23661 L
s
.337 .372 .963 r
.32751 .48482 m .41033 .42301 L .40907 .49096 L F
.32751 .48482 m .32959 .41773 L .41033 .42301 L F
0 g
.62214 .61881 m
.63529 .61809 L
s
.3303 .5119 m
.34264 .5131 L
s
.60356 .62997 m
.61299 .62276 L
s
.339 .324 .916 r
.33731 .3508 m .42294 .28964 L .41502 .3551 L F
0 g
.35673 .28276 m
.35674 .29891 L
s
.338 .349 .94 r
.32959 .41773 m .33731 .3508 L .41502 .3551 L F
0 g
.35674 .29891 m
.35886 .30706 L
s
.52734 .63143 m
.53185 .64118 L
s
.72867 .44583 m
.72925 .51224 L
s
.72852 .42746 m
.72867 .44583 L
s
.40508 .25241 m
.40546 .26874 L
s
.61299 .62276 m
.62214 .61881 L
s
.47788 .63063 m
.48648 .62404 L
s
.426 .518 1 r
.58589 .62049 m .5885 .55932 L .67458 .55504 L F
.397 .486 1 r
.50034 .62104 m .5885 .55932 L .58589 .62049 L F
0 g
.56629 .66409 m
.56669 .65548 L
s
.338 .349 .94 r
.32959 .41773 m .41502 .3551 L .41033 .42301 L F
0 g
.72122 .5076 m
.72981 .49566 L
s
.396 .365 .898 r
.50204 .29123 m .57777 .22983 L .58293 .29098 L F
.50204 .29123 m .50499 .23002 L .57777 .22983 L F
0 g
.35886 .30706 m
.36506 .31541 L
s
.56986 .22187 m
.57184 .2462 L
s
.34264 .5131 m
.35083 .50842 L
s
.397 .486 1 r
.50034 .62104 m .49885 .55984 L .5885 .55932 L F
0 g
.56669 .65548 m
.56833 .62071 L
s
.71263 .5138 m
.72122 .5076 L
s
.369 .335 .896 r
.42294 .28964 m .50499 .23002 L .50204 .29123 L F
0 g
.49178 .24621 m
.49372 .22188 L
s
.43699 .24524 m
.44159 .22104 L
s
.52734 .63143 m
.51821 .62455 L
s
.51576 .24638 m
.51653 .22203 L
s
.43462 .28599 m
.43699 .24524 L
s
.62938 .26147 m
.63959 .25301 L
s
.48648 .62404 m
.49538 .62072 L
s
.427 .494 .987 r
.5885 .55932 m .67716 .48958 L .67458 .55504 L F
0 g
.40239 .28491 m
.40546 .26874 L
s
.69983 .51489 m
.71263 .5138 L
s
.36506 .31541 m
.38089 .31623 L
s
.50903 .62094 m
.51821 .62455 L
s
.72066 .43482 m
.72947 .44721 L
s
.49538 .62072 m
.50903 .62094 L
s
.35083 .50842 m
.35467 .49186 L
s
.425 .42 .921 r
.5867 .35684 m .66068 .28889 L .67009 .35414 L F
.5867 .35684 m .58293 .29098 L .66068 .28889 L F
0 g
.5995 .24581 m
.60448 .25388 L
s
.60125 .25649 m
.61148 .31879 L
s
.5995 .24581 m
.60125 .25649 L
s
.61751 .26177 m
.62938 .26147 L
s
.3956 .30084 m
.40239 .28491 L
s
.69134 .51011 m
.69983 .51489 L
s
.71195 .42877 m
.72066 .43482 L
s
.35467 .49186 m
.35562 .44423 L
s
.35562 .44423 m
.35593 .42913 L
s
.369 .431 .988 r
.41124 .55657 m .49825 .49392 L .49885 .55984 L F
.41124 .55657 m .40907 .49096 L .49825 .49392 L F
0 g
.60448 .25388 m
.61751 .26177 L
s
.38089 .31623 m
.39024 .30866 L
s
.57035 .28711 m
.57184 .2462 L
s
.39024 .30866 m
.3956 .30084 L
s
.4848 .28701 m
.49178 .24621 L
s
.371 .363 .922 r
.41502 .3551 m .42294 .28964 L .50204 .29123 L F
0 g
.39892 .45824 m
.40005 .51454 L
s
.40005 .51454 m
.40083 .55315 L
s
.51576 .24638 m
.51897 .2873 L
s
.6828 .49952 m
.69134 .51011 L
s
.6992 .42968 m
.71195 .42877 L
s
.38575 .51657 m
.41746 .51846 L
s
.428 .471 .966 r
.58954 .49344 m .67566 .42182 L .67716 .48958 L F
.427 .494 .987 r
.5885 .55932 m .58954 .49344 L .67716 .48958 L F
0 g
.67851 .48224 m
.6828 .49952 L
s
.69086 .43698 m
.6992 .42968 L
s
.427 .446 .945 r
.58894 .42514 m .67009 .35414 L .67566 .42182 L F
.58894 .42514 m .5867 .35684 L .67009 .35414 L F
0 g
.61148 .31879 m
.65409 .31746 L
s
.68254 .4507 m
.69086 .43698 L
s
.399 .463 .988 r
.49885 .55984 m .58954 .49344 L .5885 .55932 L F
0 g
.67846 .47003 m
.67851 .48224 L
s
.428 .471 .966 r
.58954 .49344 m .58894 .42514 L .67566 .42182 L F
.399 .394 .924 r
.49988 .35717 m .58293 .29098 L .5867 .35684 L F
.49988 .35717 m .50204 .29123 L .58293 .29098 L F
0 g
.67846 .47003 m
.68254 .4507 L
s
.371 .41 .967 r
.40907 .49096 m .4986 .42554 L .49825 .49392 L F
.40907 .49096 m .41033 .42301 L .4986 .42554 L F
.399 .463 .988 r
.49885 .55984 m .49825 .49392 L .58954 .49344 L F
.371 .363 .922 r
.41502 .3551 m .50204 .29123 L .49988 .35717 L F
0 g
.43462 .28599 m
.44006 .31045 L
s
.372 .387 .946 r
.41033 .42301 m .41502 .3551 L .49988 .35717 L F
0 g
.44006 .31045 m
.45219 .31881 L
s
.47458 .31122 m
.4848 .28701 L
s
.56278 .31155 m
.57035 .28711 L
s
.64176 .51317 m
.64664 .49589 L
s
.63236 .5191 m
.64176 .51317 L
s
.51897 .2873 m
.52742 .31169 L
s
.6183 .51969 m
.63236 .5191 L
s
.39892 .45824 m
.40397 .4388 L
s
.372 .387 .946 r
.41033 .42301 m .49988 .35717 L .4986 .42554 L F
0 g
.64602 .44787 m
.64664 .49589 L
s
.64582 .43265 m
.64602 .44787 L
s
.45219 .31881 m
.4609 .319 L
s
.4609 .319 m
.47458 .31122 L
s
.40397 .4388 m
.41331 .43248 L
s
.60894 .51453 m
.6183 .51969 L
s
.5497 .3197 m
.56278 .31155 L
s
.41331 .43248 m
.42249 .43287 L
s
.5948 .49786 m
.60894 .51453 L
s
.44519 .50293 m
.4548 .51455 L
s
.4548 .51455 m
.46439 .52036 L
s
.46439 .52036 m
.47874 .52073 L
s
.44037 .48507 m
.44519 .50293 L
s
.52742 .31169 m
.54078 .31973 L
s
.59444 .46833 m
.59458 .52047 L
s
.59435 .43436 m
.59444 .46833 L
s
.47874 .52073 m
.4883 .51542 L
s
.44037 .48507 m
.44041 .47279 L
s
.44037 .48507 m
.49786 .48654 L
s
.4 .441 .968 r
.49825 .49392 m .58894 .42514 L .58954 .49344 L F
0 g
.54078 .31973 m
.5497 .3197 L
s
.4 .418 .947 r
.4986 .42554 m .5867 .35684 L .58894 .42514 L F
.4986 .42554 m .49988 .35717 L .5867 .35684 L F
0 g
.44041 .47279 m
.44534 .45379 L
s
.55126 .52125 m
.56576 .52108 L
s
.4883 .51542 m
.49309 .5099 L
s
.4 .441 .968 r
.49825 .49392 m .4986 .42554 L .58894 .42514 L F
0 g
.54159 .5158 m
.55126 .52125 L
s
.52703 .52133 m
.52705 .43508 L
s
.49788 .49846 m
.49309 .5099 L
s
.53188 .5045 m
.54159 .5158 L
s
.44534 .45379 m
.45503 .4408 L
s
.49786 .48654 m
.49788 .49846 L
s
.52701 .48676 m
.53188 .5045 L
s
.45503 .4408 m
.46464 .43427 L
s
.46464 .43427 m
.47894 .43458 L
s
.47894 .43458 m
.48843 .44155 L
s
.48843 .44155 m
.49795 .455 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{154, 151.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40002J0000Ub000`400?l00000o`00003oVP3oool0
09X0oooo002J0?ooo`00VP3oool009X0oooo002J0?ooo`00VP3oool004T0oooo2@0?OOd700AaoT40
oooo00160?ooo`80<Y_o00@03P2?01@0S`0D08l0602?0P0L08l201l0S`808@2?100R08l0100Q08l0
7P2?01h0S`0G08l200idoch0oooo00120?ooo`80<Y_o0P0J08l202L0S`80<@2?0`0j08l30400S`<0
A@2?0`1808l304T0S`80B02?0P1408l00`0m08l0<P2?0?ooo`0j0?ooo`00?`3oool00`0:08l06P2?
01X0S`0302L0S`<0<@2?0`0j08l40400S`@0A@2?101808l404T0S`<0B02?0P1408l203d0S`030380
S`3oool0oooo03D0oooo000l0?ooo`030000S`0:08l08@2?00808@2?0`0b09<303l1X0@0B12X101@
6Z`505HQ[@@0FRB/1@1M9JH305hQW@80GAR?0P1G2Hl204X0Sc@0oooo000i0?ooo`80002?00@02P2?
0240S`0Q08l08@2?0`0b09<403l1X0@0B12X1@1@6Z`505HQ[@D0FRB/1@1M9JH305hQW@<0GAR?0P1G
2Hl204X0S`0303@0S`3oool0oooo02l0oooo000f0?ooo`<0002?00@02P2?0240S`0Q08l08@2?100b
09<403l1X0D0B12X1@1@6Z`605HQ[@D0FRB/1@1M9JH405hQW@<0GAR?0P1G2Hl204X0S`80=02?;P3o
ool003D0oooo00<0002?00X0S`0:08l00`0Q08l40380T`@0?`6P1P184:P6050J[0H0ER6]1@1J9:`6
05dUYP@0GR6M101M68l205L9S`80BP2?0P1308l/0?ooo`00<`3oool20000S`80202?0`0U09T403P3
[0D0AQRh1P1@9kl605Lb``L0GCW41@1S?/8606Lo_P@0Jcje1@1/>:P206T[TP80GA:?00<0@`2?0?oo
o`3oool0:@3oool00380oooo00<0002?00P0S`0808l0100U09T403P3[0D0AQRh1P1@9kl705Lb``L0
GCW41@1S?/8706Lo_P@0Jcje1@1/>:P306T[TP0305dBS`1308l0@`2?02T0oooo000`0?ooo`80002?
0P0808l302D0V@D0>0>/1@166;P7050W_`L0Ec;31`1M>L@606<n`PH0Icnn1@1[?[D606`hZ080JB^B
0P1M4Xl00`1308l0oooo0?ooo`0V0?ooo`00;P3oool20000S`80202?100U09T503P3[0H0AQRh1P1@
9kl805Lb``L0GCW41P1S?/8706Lo_PD0Jcje1P1/>:P306T[TP0305dBS`1308l0oooo02H0oooo000]
0?ooo`030000S`0808l0202?00@09@2I1P0h0j`604HH^0L0D2No201G</<705dia0L0Hck21`1W?kh5
06/n]@H0K3RX0`1Y:i800`1M4Xl0CP:?04h2S`0U0?ooo`00;03oool00`0008l01@2?00D0S`0502H0
[0D0>a>n1P166;P7050W_`P0Ec;3201M>L@706<n`PL0Icnn1P1[?[D607E?^P@0MTFU00<0KBj?04h2
S`3oool08`3oool002/0oooo00<0002?00D0S`0508l01@0V0:`603/C_PH0BBS91`1C=ll805]1dPT0
HTWC1`1WC]4706eBcPH0LE;61P1eCkX407I5Y@0306d^S`1>0Xl0oooo0280oooo000Z0?ooo`030000
S`0508l01@2?00D09P2/1P0k4kh604TXb@P0DcO?201K@M890699d`L0IdkA201]D/h6075BaPH0MDnj
101fAJD00`1];Xl0CP:?0?ooo`0Q0?ooo`00:@3oool00`0008l01@2?00D0S`0502H0[0H0>a>n1P19
:<T6000000<0DcO?201K@M890699d`P0IdkA201]D/h6075BaPH0MDnj101fAJD00`1];Xl0CP:?0?oo
o`0P0?ooo`009`3oool20000S`801@2?1@0V0:`603/C_PL0BBS900<0000005<gc`1C=ll00`1C=ll0
0`000000DcO?05]1dP0205]1dP800000101K@M840699d`8000000`1RBM<406M>d@8000000P1WC]48
06eBcPL0LE;61P1eCkX407I5Y@0306d^S`1>0Xl0oooo01l0oooo000W0?ooo`<01@2?1@0V0:`603/C
_PP0BBS900<0000005<gc`1C=ll01@1C=ll205]1dP030000001K@M80Fd7B008000000P1K@M820699
d`8000000P1RBM<00`000000HTWC0699d`0306M>d@030000001WC]40IdkA0080000000<0IdkA06eB
cP1]D/h01P1]D/h7075BaPH0MDnj101fAJD00`1];Xl0EQN?0?ooo`0N0?ooo`009P3oool0100008l0
0P2L0080W00209`402L0^`H0>a>n2019:<T00`1C=ll0000005<gc`0605<gc`0305]1dP000000Fd7B
00<0Fd7B00<0000005]1dP1K@M800P1RBM<00`000000HTWC0699d`020699d`050000001RBM<0IdkA
06M>d@000000101WC]400`000000IdkA06eBcP0806eBcPL0LE;61@1eCkX507mK]00307Q6S`1F5hl0
oooo01d0oooo000U0?ooo`040000S`0209`00P2L0080W0D09`2k1P0l8<`704/de@80DcO?00<00000
05<gc`1C=ll0101C=ll205]1dP030000001K@M80Fd7B0080Fd7B00D0000005]1dP1RBM<0HTWC0000
00050699d`050000001RBM<0IdkA06M>d@0000001@1WC]400`000000KE;>06eBcP0706eBcPP0MV7C
1@1kHLP507mK]00307Q6S`1F5hl0oooo01`0oooo000T0?ooo`040000S`0209`00P2L0080W0D09`2k
1P0l8<`804/de@80ED;J00<0000005E2fP1E@]X0101E@]X00`1MCM`0000005e=g00405e=g0050000
001MCM`0I5CM06ADg@0000001P1TE=d010000000I5CM06YJg000000606YJg0030000001`GmT0L5oI
00L0L5oI1`1fHM<607]Qb0D0Oe^d00<0N4J?05HGS`3oool06`3oool002<0oooo00@0002?0080W002
09`00P2L1P0W0;/603`Pc0P0BcCE0P1E@]X00`000000ED;J05E2fP0405E2fP0305e=g0000000GDgL
00@0GDgL00D0000005e=g01TE=d0I5CM0000000606ADg@030000001TE=d0JU[L00L0JU[L00<00000
071Of@1`GmT01`1`GmT807IQd`H0Nf78101oFk@207Q6S`0305HGS`3oool0oooo01T0oooo000R0?oo
o`030000S`0209`00P2L00800P2L1@0W0;/603`Pc0P0BcCE0`1E@]X00`000000ED;J05E2fP0405E2
fP030000001MCM`0GDgL00@0GDgL00D0000005e=g01TE=d0I5CM0000000606ADg@030000001TE=d0
JU[L00P0JU[L00<00000071Of@1`GmT01`1`GmT707IQd`H0Nf781@1oFk@207Q6S`0305HGS`3oool0
oooo01P0oooo000Q0?ooo`030000S`0209`00P2L00800P2L1@0W0;/603`Pc0T0BcCE0`1E@]X00`00
0000ED;J05E2fP0305E2fP0305e=g0000000GDgL00D0GDgL00D0000005e=g01TE=d0I5CM00000006
06ADg@030000001TE=d0JU[L00P0JU[L00<00000071Of@1`GmT01`1`GmT807IQd`H0Nf781@1oFk@2
07Q6SaX0oooo000Q0?ooo`@00P2L1P0W0;/603`Pc0T0BcCE0`1E@]X00`000000ED;J05E2fP0305E2
fP0305e=g0000000GDgL00D0GDgL00D0000005e=g01TE=d0I5CM0000000706ADg@030000001ZF]`0
JU[L00P0JU[L00<00000071Of@1`GmT01P1`GmT807IQd`L0Nf781@1oFk@00`1hAXl0FbZ?0?ooo`0H
0?ooo`00803oool0100008l0002Y0000Z@000:T602L0^`H0?23<2@1;==D405E2fP030000001E@]X0
ED;J00<0ED;J00<0000005e=g01MCM`01@1MCM`01@000000GDgL06ADg@1TE=d0000000L0I5CM00<0
000006YJg01ZF]`0201ZF]`00`000000L5oI071Of@07071Of@P0MV7C1`1kHLP407mK]080PEfM00<0
FbZ?0?ooo`3oool05P3oool00200oooo10000:T502H:b0H0?23<2P1;==D405E2fP030000001E@]X0
ED;J00<0ED;J00<0000005e=g01MCM`01@1MCM`01@000000GDgL06ADg@1TE=d0000000L0I5CM00<0
000006YJg01ZF]`0201ZF]`00`000000L5oI071Of@07071Of@P0MV7C1`1kHLP508E]`P80PEfM603o
ool001l0oooo00@0002?0000Z@000:T0002Y1P0V2/P603dZe`T0C3kN1@1E@]X00`000000ED;J05E2
fP0205E2fP0305e=g0000000GDgL00H0GDgL00D0000005e=g01TE=d0I5CM0000000706ADg@030000
001ZF]`0JU[L00P0JU[L00<00000071Of@1`GmT01`1`GmT907Q]g@L0Og3D1025KL82085MW@0305/Z
S`3oool0oooo01D0oooo000N0?ooo`030000S`000:T0002Y0080002Y1@0V2/P703dZe`T0C3kN1@1F
Bn<00`000000ET_S05I;h`0205I;h`030000001NEND0GUGU00H0GUGU00@0000005iEi@1UGND00000
201UGND00`000000IEgU06]Si00806]Si0030000001[Hn@0LVWR00P0LVWR201hKMd707m`e0D0QFg2
0P21GId00`1K:Xl0oooo0?ooo`0D0?ooo`007P3oool0100008l0002Y0000Z@000:T602H:b0H0?B[G
2P1<?]h505I;h`030000001FBn<0ET_S0080ET_S00<0000005iEi@1NEND01P1NEND010000000GUGU
06EMi@00000806EMi@030000001UGND0Jf?T00P0Jf?T00<0000006]Si01bJN80201bJN8907Q]g@L0
Og3D1025KL83085MWAH0oooo000M0?ooo`040000S`000:T0002Y0000Z@H09P[81`0m:]L904`ngPH0
ET_S00<0000005I;h`1FBn<00P1FBn<00`000000GUGU05iEi@0605iEi@040000001NEND0IEgU0000
00P0IEgU00D0000006EMi@1[Hn@0Jf?T0000000506]Si0030000001[Hn@0Jf?T00T0LVWR2@1hKMd7
07m`e0D0QFg20P21GId00`1K:Xl0oooo0?ooo`0C0?ooo`00703oool20000S`<0002Y1@0V2/P803dZ
e`T0C3kN1P1FBn<00`000000ET_S05I;h`0205I;h`030000001NEND0GUGU00H0GUGU00@0000005iE
i@1UGND00000201UGND010000000IEgU06]Si01[Hn@2000000@0Jf?T00<0000006]Si01[Hn@02P1b
JN8907Q]g@L0Og3D1025KL83085MWAD0oooo000L0?ooo`040000S`000:T0002Y0000Z@H09P[81`0m
:]L:04`ngPH0ET_S00H0000005I;h`1FBn<0ET_S05iEi@00000805iEi@040000001NEND0IEgU0000
00P0IEgU00H0000006EMi@1[Hn@0Jf?T0000001[Hn@4000000@0Jf?T2@1bJN8907Q]g@L0Og3D1@25
KL82085MW@030000]P3oool0oooo0180oooo000L0?ooo`030000S`000;H0002f00H09P[8200m:]L9
04`ngPP0ET_S00D0000005I;h`1FBn<0GUGU0000000705iEi@050000001NEND0GUGU06EMi@000000
201UGND01@000000IEgU06]Si01[Hn@0000000T0Jf?T2@1bJN8:07Q]g@L0Og3D1025KL8308M`ZA@0
oooo000K0?ooo`80002?0P000;H502@Cd`T0?B[G2@1<?]h00`000000ET_S05I;h`0505I;h`050000
001FBn<0ET_S05iEi@0000001`1NEND00`000000GUGU05iEi@0206EMi@030000001UGND0IEgU00D0
IEgU00D0000006EMi@1[Hn@0Jf?T0000000906]Si0X0LVWR2@1hKMd707m`e0D0RGg=0P27L:T00`00
0;H0oooo0?ooo`0A0?ooo`006`3oool0100008l0002f0000]P000;H502@Cd`P0?C;P2P1<?]h00`00
0000ET_S05I;h`0405I;h`060000001FBn<0ET_S05I;h`1NEND000001`1NEND00`000000GUGU05iE
i@0206EMi@030000001UGND0IEgU00D0IEgU00<0000006EMi@1[Hn@00P1[Hn@00`000000Jf?T06]S
i00606]Si0X0LVWR2@1hKMd8089lg@@0RGg=0`27L:TC0?ooo`006`3oool0100008l0002f0000]P00
0;H502@Cd`P0?C;P2@1<ANH00`1FBn<0000005I;h`0505I;h`060000001FBn<0ET_S05I;h`1NEND0
00001`1NEND00`000000GUGU05iEi@0206EMi@030000001UGND0IEgU00D0IEgU00<0000006EMi@1[
Hn@00P1[Hn@00`000000Jf?T06]Si00606]Si0X0LVWR2P1jMnD7089lg@D0RGg=0P27L:TC0?ooo`00
6P3oool0100008l0002f0000]P000;H602@Cd`P0?C;P2@1<ANH00`1FD^X0000005IBjP0405IBjP04
0000001FD^X0EU;Z05IBjP80GUGU00<0000005iEi@1NEND0101NEND00`000000GUGU05iEi@0306EM
i@030000001UGND0IEgU00D0IEgU00<0000006EMi@1/Jn/00P1/Jn/00`000000K6_[06a[j`0706a[
j`X0Lg7Y2@1jMnD7089lg@D0RGg=0`27L:TB0?ooo`006P3oool0100008l0002f0000]P000;H502@C
d`T0?C;P2@1<ANH00`1FD^X0000005IBjP0405IBjP040000001FD^X0EU;Z05IBjP80GUc/00<00000
05iLk01NG>`0101NG>`00`000000GUc/05iLk00306ITk0030000001VI>`0IVC/00@0IVC/00<00000
06ITk01VI>`00`1/Jn/00`000000K6_[06a[j`0706a[j`X0Lg7Y2@1jMnD8089lg@D0RGg=0P27L:TB
0?ooo`006P3oool40000]PD091?C200m<^0:04a5iP0305IBjP000000EU;Z00<0EU;Z00<0000005IB
jP1FD^X00P1FD^X305iLk0030000001NG>`0GUc/0080GUc/00@0000005iLk01NG>`0GUc/101VI>`0
0`000000IVC/06ITk00306ITk0030000001VI>`0IVC/00@0K6_[00<0000006a[j`1/Jn/01P1/Jn/:
07=aj@X0NWOU1`22O=d508Umc@<0Qg2Y4@3oool001T0oooo00@0002?0000]P000;H0002f1P0T4m<8
03dbh0X0C4GV00<0EU;Z0000001FD^X00`1FD^X00`000000EU;Z05IBjP0205IBjP<0GUc/00<00000
05iLk01NG>`00P1NG>`010000000GUc/05iLk01NG>`406ITk0030000001VI>`0IVC/00<0IVC/00<0
000006ITk01VI>`0101/Jn/00`000000K6_[06a[j`0606a[j`X0Lg7Y2P1jMnD7089lg@H0RGg=0P27
L:TA0?ooo`006@3oool40000]PD091?C2@0m<^0904a5iP<0EU;Z1000000505IBjP@0GUc/10000004
05iLk0D0IVC/1@00000306ITk0@0K6_[200000000`1/Jn/0Lg7Y07=aj@0807=aj@X0NWOU2022O=d5
08Umc@80Qg2Y4@3oool001T0oooo0P000<420000]PD091?C200m<^0:04a5iP`0EU;Z301NG>`=06IT
k0d0K6_[2`1cLNT:07Ygi@L0PWcM1@29OLd308V2/a00oooo000I0?ooo`<000311P0T4m<803dbh0X0
C4GV301FD^X<05iLk0d0IVC/3@1/Jn/;07=aj@X0NWOU1`22O=d608b;e`80RH:c403oool001T0oooo
0`000<45028Kg0T0?C;P2P1<ANH<05IBjP`0GUc/3@1VI>`=06a[j`/0Lg7Y2P1jMnD4089lg@@0Q8KV
1@2<RmL208V2/a00oooo000H0?ooo`040000S`000<4000310000`@D08Q_L200l>NP;04a5iP`0EU;Z
301NG>`=06ITk0d0K6_[2`1cLNT:07Ygi@P0Q8KV1@2<RmL208V2/a00oooo000H0?ooo`@000311@0R
6m`803`ij0X0Bdc^3@1FD^X<05iLk0d0IVC/3@1/Jn/;07=aj@/0Ngo/1`24Q^H508b;e`<0RH:c3`3o
ool001P0oooo10000<45028Kg0P0?3WX2P1;C>h<05IIl0d0GUc/3@1VI>`>06ebl@/0M7W`2P1kOn`7
08B6iPD0S8_G0`29P[<?0?ooo`00603oool30000`@H08Q_L200l>NP:04]<kP`0EUW`3@1OHo8>06I[
lPd0KG;a2`1dNO0:07]ok0L0Q8KV1P2<RmL208V2/`l0oooo000G0?ooo`040000S`000<4000310000
`@D08Q_L2@0l>NP:04]<kP`0EUW`3@1OHo8>06I[lPd0KG;a2`1dNO0:07]ok0P0Q8KV1@2<RmL208V2
/`l0oooo000G0?ooo`@000311@0R6m`803`ij0/0Bdc^301FFO0=05mSlPh0IV_b3@1]L_4;07Ail0X0
Ngo/2024Q^H508b;e`80RH:c3`3oool001L0oooo0P000<X20000`@D08Q_L200l>NP;04]<kP`0EUW`
3@1OHo8>06I[lPd0KG;a2`1dNO0;07]ok0L0Q8KV1@2<RmL00`29P[<0RI2m0?ooo`0>0?ooo`005`3o
ool30000bPH08Q_L200l>NP;04]<kP`0EUW`3@1OHo8>06I[lPd0KG;a301dNO0:07]ok0L0Q8KV1@2<
RmL208V@_@l0oooo000G0?ooo`<0003:0`0O8^D3028Kg0P0?3WX2`1;C>h<05IIl0d0Gf?b3P1VJo8=
06ebl@`0M7W`2P1kOn`708B6iPD0SYSP0P29T;d?0?ooo`005`3oool30000bPD07b;U2@0l>NP;04]<
kP`0EUW`3@1OHo8>06I[lPd0KG;a301dNO0:07]ok0@0Q8KV1025T>d408jHh080RI2m3`3oool001L0
oooo0`000<X501lRi@P0>T3_301;C>h<05IIl0d0Gf?b3P1VJo8=06ebl@`0M7W`2P1kOn`808F@k@@0
SYSP0P29T;d?0?ooo`005`3oool30000bPD07b;U200j@>l;04]Bm0d0EUW`3@1OHo8>06I[lPd0KG;a
301dNO0:07b7l`P0QI3]102>V>0208V@_@l0oooo000G0?ooo`<0003:1@0O8^D803Y0k`@0Be;d00D0
000004]Bm01;D_@0Be;d0000000204]Bm0`0EUof3P1OHo8>06I[lPd0KG;a301dOoH:07b7l`P0QI3]
102>V>0208V@_@l0oooo000G0?ooo`<0003:1@0O8^D803Y0k`@0Be;d00D0000004]Bm01;D_@0Be;d
0000000204]Bm0@0EUof00<0000005IOmP1FGoH01@1FGoH00`1NJ?L0000005iXm`0;05iXm`h0IW3g
201]N?L00`000000KGSg06ehm`0206ehm`<0M7of0`00000207AomP040000001dOoH0M7of07AomPX0
O8Oc2025T>d408jHh080RI2m3`3oool001L0oooo0`000<X501lRi@P0>T3_101;D_@01@000000Be;d
04]Bm01;D_@000000080Be;d101FGoH00`000000EUof05IOmP0405IOmP80000000<0GVSg0000001N
J?L01@1NJ?L300000080GVSg101VL?L00`000000IW3g06I`m`0706I`m`030000001]N?L0KGSg00D0
KGSg00<0000006ehm`1]N?L00P1]N?L207AomP040000001dOoH0M7of07AomP<000000`1dOoH:07b7
l`P0QI3]102>V>0208V@_@l0oooo000G0?ooo`<0003:1@0O8^D803Y0k`@0Be;d00D0000004]Bm01;
D_@0Be;d0000000204]Bm0@0EUof00<0000005IOmP1FGoH0101FGoH00`000000GVSg05iXm`0505iX
m`8000000`1NJ?L00`000000GVSg06I`m`0306I`m`030000001VL?L0IW3g00L0IW3g00<0000006eh
m`1]N?L01@1]N?L00`000000KGSg06ehm`0206ehm`0307AomP000000M7of00@0M7of0P00000307Ao
mPX0O8Oc2025T>d408jHh00308V@_@26W<D0oooo00h0oooo000H0?ooo`80003:1@0O8^D803Y0k`@0
Be;d00D0000004]Bm01;D_@0Be;d0000000204]Bm0@0EUof00<0000005IOmP1FGoH0101FGoH00`00
0000GVSg05iXm`0405iXm`030000001NJ?L0GVSg00@0GVSg00<0000006I`m`1VL?L00P1VL?L00`00
0000IW3g06I`m`0706I`m`030000001]N?L0KGSg00D0KGSg00<0000006ehm`1]N?L00P1]N?L00`1d
OoH0000007AomP0507AomP040000001dOoH0M7of07AomPX0O8Oc2025T>d408jHh080QYc53`3oool0
01P0oooo00<0003C01lRi@0O8^D0100O8^D803Y0k`@0Be;d00D0000004]Bm01;D_@0Be;d00000002
04]Bm0@0EUof00<0000005IOmP1FGoH0101FGoH00`000000GVSg05iXm`0405iXm`030000001NJ?L0
GVSg00D0GVSg00D0000006I`m`1VL?L0IW3g0000000906I`m`030000001]N?L0KGSg00D0KGSg00<0
000006ehm`1]N?L00P1]N?L00`1dOoH0000007AomP0507AomP040000001dOoH0M7of07AomPX0O8Oc
2025T>d208jHh080SJCY0P26W<D?0?ooo`00603oool20000d`D06bS]200j@>l404]Bm0050000001;
D_@0Be;d04]Bm00000000P1;D_@405IOmP030000001FGoH0EUof00@0EUof00<0000005iXm`1NJ?L0
101NJ?L00`000000GVSg05iXm`0505iXm`@0IW3g00<0000006I`m`1VL?L01`1VL?L00`000000KGSg
06ehm`0506ehm`030000001]N?L0KGSg0080KGSg00<0000007AomP1dOoH01@1dOoH010000000M7of
07AomP1dOoH:07b7l`P0QI3]102=Y>T208JLa@l0oooo000H0?ooo`80003C1P0K:>d303Q6m`@0>T3_
101;D_@01@000000Be;d04]Bm01;D_@000000080Be;d101FGoH00`000000EUof05IOmP0405IOmP03
0000001NJ?L0GVSg00<0GVSg00<0000005iXm`1NJ?L01P1NJ?L406I`m`030000001VL?L0IW3g00L0
IW3g00<0000006ehm`1]N?L01@1]N?L00`000000KGSg06ehm`0206ehm`030000001dOoH0M7of00D0
M7of00@0000007AomP1dOoH0M7of2P1lQo<408F@k@@0QI[e102=Y>T208JLa@l0oooo000H0?ooo`80
003C1P0K:>d703Q6m`@0Be;d00D0000004]Bm01;D_@0Be;d0000000204]Bm0@0EUof00<0000005IO
mP1FGoH0101FGoH00`000000GVSg05iXm`0305iXm`030000001NJ?L0GVSg00H0GVSg101VL?L00`00
0000IW3g06I`m`0706I`m`030000001]N?L0KGSg00D0KGSg00<0000006ehm`1]N?L00P1]N?L00`00
0000M7of07AomP0507AomP040000001dOoH0M7of07AomPX0O8Oc2025V_D408fTj@80QYc53`3oool0
01P0oooo0P000=<601/Xk@P0>4Kg0`19F?X01@000000BESj04UHnP19F?X000000080BESj101FGoH0
0`000000EUof05IOmP0405IOmP030000001NJ?L0GVSg00<0GVSg1@00000405iXm`@0IW3g00<00000
06I`m`1VL?L01`1VL?L00`000000KGSg06ehm`0506ehm`030000001]N?L0KGSg0080KGSg00<00000
07AomP1dOoH01@1dOoH010000000M7of07AomP1dOoH:07b?n@P0QI[e102=Y>T208JLa@l0oooo000H
0?ooo`80003C1P0K:>d803Q6m`<0BESj00D0000004UHnP19F?X0BESj0000000204UHnP@0EFCl00<0
000005ETo01EI?`0101EI?`00`000000GVSg05iXm`0305iXm`030000001NJ?L0GVSg0080GVSg1@00
000306I`m`030000001VL?L0IW3g00L0IW3g00<0000006ehm`1]N?L01@1]N?L00`000000KGSg06eh
m`0206ehm`030000001dQ_/0M8Kk00D0M8Kk00@0000007B6n`1dQ_/0M8Kk2P1lSoT808FJm@@0SJCY
0P26W<D?0?ooo`00603oool20000d`H06bS]200hA_L304UHnP0400000019F?X0BESj04UHnP800000
00<0BESj05ETo01EI?`00P1EI?`00`000000EFCl05ETo00405ETo0030000001NK_`0GVkl00@0GVkl
00<0000005i^o01NK_`01@1NK_`01@000000IW3g06I`m`1VL?L0000000T0IW3g00<0000006eno01]
O_`01@1]O_`00`000000KGkl06eno00206eno00307B6n`000000M8Kk00D0M8Kk00@0000007B6n`1d
Q_/0M8Kk2P1lSoT808FJm@@0SJCY00<0QYc50?ooo`3oool03P3oool001P0oooo0P000=<601/Xk@P0
>4Kg0`19F?X010000000BESj04UHnP19F?X20000000504UHnP1EI?`0EFCl05ETo00000001`1EI?`0
0`000000GVkl05i^o00405i^o0030000001NK_`0GVkl00D0GVkl00@0000006Ifo01VM_`0IWKl0P00
000806Ifo08000001P1]O_`00`000000KGkl06eno00206eno00307B6n`000000M8Kk00@0M8Kk0P00
000307B6n`X0O8oi2025V_D408fTj@0307fSc03oool0oooo00h0oooo000I0?ooo`030000d`0K:>d0
6bS]00@06bS]200hA_L304UHnP0700000019F?X0BESj04UHnP000000BESj0000000305ETo0030000
001EI?`0EFCl00D0EFCl00<0000005i^o01NK_`0101NK_`00`000000GVkl05i^o00405i^o0030000
001VM_`0IWKl0080IWKl0P00000806Ifo0030000001]O_`0000000D0KGkl00<0000006eno01]O_`0
0P1]O_`207B6n`030000001dQ_/0M8Kk0080M8Kk0P00000307B6n`X0O8oi2025V_D308fTj@80OJ?<
403oool001T0oooo00<0003J01/Xk@0K:>d0100K:>d803Q6m`<0BESj00<0000004UHnP19F?X01019
F?X3000000H0EFCl0`00000705i^o0030000001NK_`0GVkl0080GVkl00<0000005i^o01VM_`00`1V
M_`00`000000IWKl0000000706Ifo0040000001]O_`0KGkl000000@0KGkl00<0000006eno01]O_`0
0P1]O_`307B6n`@0000000<0M8Kk0000001dQ_/00P1dQ_/:07b?n@P0QI[e00<0SJCY08^^l02;[_00
0P1mXl`@0?ooo`006@3oool20000fP805Bke0`0K:>d803Q6m`<0BESj00<0000004UHnP19F?X01019
F?X;05ETo0<000001P1NK_`400000080GVkl101VM_`00`000000IWKl06Ifo004000000<0IWKl00@0
000006eno01]O_`0KGkl1000000506eno0`0M8Kk2P1lSoT708FJm@@0Rjk`0P1mXl`@0?ooo`006@3o
ool20000fPD05Bke200hA_L304UHnP0300000019F?X0BESj00@0BESj2`1EI?`00`000000GVkl05i^
o00<05i^o0h0IWKl3@1]O_`<07B6n`X0O8oi0`25V_D408FSo0@0Rjk`00<0OJ?<0?ooo`3oool03`3o
ool001X0oooo00<0003J01D^m@0E;_D0100E;_D303E<o@@0>4Kg0`19F?X00`000000BESj04UHnP04
04UHnP/0EFCl00<0000005i^o01NK_`0301NK_`>06Ifo0d0KGkl301dQ_/907b?n@P0QJ?l102;[_00
0`1mXl`0oooo0?ooo`0?0?ooo`006P3oool20000fPD05Bke1`0eC?d304UHnP0300000019F?X0BESj
00@0BESj2`1EI?`00`000000GVkl05i^o00<05i^o0h0IWKl3@1]O_`<07B6n`D0O8oi101lUol808FS
o0<0Rjk`0P1mXl`A0?ooo`006P3oool20000fPD05Bke200eC?d904MNo`/0EFCl00<0000005i^o01N
K_`0301NK_`>06Ifo0d0KGkl301dQ_/907bGo`P0QJ?l0`2;[_0207fSc140oooo000J0?ooo`80003J
1@0E;_D803E<o@X0Aeko2P1DJ_l00`000000GVkl05i^o00<05i^o0h0IWKl3@1]O_`<07B=o`T0O9Oo
1`25Xo`408^^l00307fSc03oool0oooo0100oooo000J0?ooo`<0003J1@0E;_D703E<o@X0Aeko301D
J_l=05eco`h0IWKl3@1]Q?l<07B=o`T0O9Oo1`25Xo`408^^l00306nUc`3oool0oooo0100oooo000K
0?ooo`030000gP000=X05Bke00@05Bke1`0eC?d:04MNo``0E6[o3@1MLol>06Elo`d0KHCo301dSOl8
07bGo`P0QJ?l0`2;[_000`1_YLl0oooo0?ooo`0A0?ooo`006`3oool20000gPD05Bke200eC?d904MN
o``0E6[o3@1MLol>06Elo`d0KHCo301dSOl807bGo`P0QJ?l0P2;[_000`25]oL0KjG?0?ooo`0B0?oo
o`00703oool20000gP803C?l0P0E;_D803E<o@T0Aeko301DJ_l=05eco`h0IGco3@1]Q?l;07B=o`T0
O9Oo2025Xo`00`2;[_00QKOg08Fgm`0D0?ooo`00703oool20000gP@03C?l200eC?d:04MNo`/0E6[o
3@1MLol>06Elo`d0KHCo2`1dSOl907bGo`L0QJ?l0`25]oL00`1_YLl0oooo0?ooo`0B0?ooo`007@3o
ool20000gP@03C?l00@0<5;o00000000000000000`0eC?d:04MNo`/0E6[o2@1MLol010000000GG?o
05eco`1MLol>06Elo`d0KHCo2`1dSOl907bGo`<0QJ?l1022[?l308FgmaD0oooo000M0?ooo`80003N
100=<o`01@0`D_l00000031Bo`0`D_l000000080<5;o2P17G_l;05AZo`T0GG?o00@0000005eco`1M
Lol0GG?o3P1UO?l=06f4o`/0M8go1@1lUol00`000000O9Oo0000000708:/o`<0QKOg00<0KjG?0?oo
o`3oool04`3oool001h0oooo00<0003N00dco00=<o`00`0=<o`010000000<5;o031Bo`0`D_l20000
0005031Bo`14I?l0A6Co00000014I?l00P17G_l00`000000Aeko04MNo`0;05AZo`T0GG?o00@00000
05eco`1MLol0GG?o3P1UO?l=06f4o`X0M8go0`1kWol30000000307^Oo`000000000000L0PZco0`25
]oLF0?ooo`007P3oool20000gP@03C?l00<00000031Bo`0`D_l00P0`D_l01@000000<5;o04ATo`14
I?l0000000<0A6Co00<0000004ATo`14I?l00P1DJ_l00`000000E6[o05AZo`0605AZo`T0GG?o00@0
000005eco`1MLol0GG?o3P1UO?l=06f4o`@0M8go1@000000101cU?l0Nioo07^Oo`00000407^Oo`03
0000001kWol0PZco00D0PZco0`25]oL00`1_YLl0oooo0?ooo`0D0?ooo`007`3oool00`000=h03C?l
00dco00200dco0030000000`D_l0<5;o0080<5;o00D00000031Bo`14I?l0A6Co0000000304ATo`06
00000014I?l0A6Co04ATo`1BL?l000001@1BL?l00`000000DW3o059`o`0505eco`050000001MLol0
GG?o05eco`0000000P1MLol3000000P0IGco00<0000006Elo`1UO?l01P1]Q?l500000080KHCo101c
U?l00`000000LiCo07>Do`0207>Do`040000001cU?l0Nioo000000D0Nioo00<0000008:/o`22[?l0
1@22[?l308FgmaL0oooo000P0?ooo`D03C?l00<00000031Bo`0`D_l00P0`D_l01@000000A6Co04AT
o`14I?l000000080A6Co00H0000004ATo`14I?l0A6Co059`o`000005059`o`040000001BL?l0DW3o
059`o`@0G7Wo00<0000005aio`1LNOl00P1LNOl20000000305aio`1TP_l0I8;o008000001P1TP_l0
0`000000I8;o06B2o`0406^;o`800000101[Rol00`000000Jh_o06^;o`0207>Do`800000101cU?l0
1@000000LiCo07>Do`1kWol0000000@0Nioo00<0000007^Oo`22[?l01@22[?l308Fgm`0305^Oc`3o
ool0oooo01D0oooo000Q0?ooo`800cSo0P0=<o`00`000000<5;o031Bo`02031Bo`050000000`D_l0
A6Co04ATo`0000000`14I?l00`000000A6Co04ATo`02059`o`030000001BL?l0DW3o0080DW3o00@0
0000059`o`1BL?l0DW3o101LNOl00`000000G7Wo05aio`0205aio`030000001LNOl0G7Wo00@0I8;o
00<0000006B2o`1TP_l00`1TP_l00`000000I8;o06B2o`0306^;o`030000001[Rol0Jh_o00@0Jh_o
00D0000006^;o`1[Rol0LiCo0000000607>Do`050000001cU?l0LiCo07^Oo`000000101kWol00`00
0000Nioo08:/o`0508:/o`0308Fgm`1k^o/0Nk_k01P0oooo000Q0?ooo`060000g`03>?l00cSo00<h
o`0`D_l00000100`D_l010000000A6Co04ATo`00000304ATo`0300000014I?l0A6Co0080DW3o00<0
0000059`o`1BL?l00`1BL?l00`000000DW3o059`o`0405aio`030000001LNOl0G7Wo0080G7Wo00<0
000005aio`1LNOl01@1TP_l00`000000I8;o06B2o`0206B2o`030000001TP_l0I8;o0080Jh_o00<0
000006^;o`1[Rol01@1[Rol01@000000Jh_o06^;o`1cU?l0000000H0LiCo00D0000007>Do`1kWol0
Nioo0000000307^Oo`8000001P22[?l307^knaT0oooo000R0?ooo`@00cSo00<0000002UHo`0YF?l0
0P0`D_l01@000000A6Co04ATo`14I?l000000080A6Co00H0000004ATo`14I?l0A6Co059`o`000005
059`o`030000001BL?l0DW3o00@0G7Wo00<0000005aio`1LNOl00P1LNOl00`000000G7Wo05aio`05
06B2o`030000001TP_l0I8;o0080I8;o00<0000006B2o`1TP_l00P1[Rol00`000000Jh_o06^;o`05
06^;o`050000001[Rol0LiCo07>Do`0000001P1cU?l00`000000LiCo07^Oo`0207^Oo`<0000000<0
Nioo00000022[?l00P22[?l307fdo`80Nk_k00<0Fio?0?ooo`3oool05`3oool002<0oooo1003>?l2
00000080:ESo00D0000004ATo`14I?l0A6Co0000000304ATo`0400000014I?l0A6Co059`o`<00000
0`1BL?l200000080DW3o0`1LNOl00`000000G7Wo05aio`0205aio`030000001LNOl0G7Wo00@0I8;o
00<0000006B2o`1TP_l00`1TP_l00`000000I8;o06B2o`0206^;o`030000001[Rol0Jh_o00D0Jh_o
00@0000006^;o`1cU?l0LiCo0P00000207>Do`@0000000<0LiCo07^Oo`1kWol01@1kWol607fdo`<0
Nk_k6P3oool002<0oooo00@0003O00<ho`03>?l00cSo0P0YF?l200000080:ESo0`10J_l00`000000
A6Co04ATo`0304ATo`04059`o`000000DW3o059`o`@0000000@0DW3o00000000000000000P1LNOl0
0`000000G7Wo05aio`0205aio`80000000<0G7Wo06B2o`1TP_l00P1TP_l00`000000I8;o06B2o`03
06B2o`030000001TP_l0I8;o00<0Jh_o0P00000206^;o`<000000P1[Rol407>Do`8000000P1cU?l0
0`000000LiCo07>Do`0307^Oo`@0N:So1P1m]?l207^kna/0oooo000T0?ooo`@00cSo1@0YF?l3041Z
o`0400000010J_l0@6[o00000080@6[o2`1BL?l00`1LNOl000000000000505aio`030000001LNOl0
000000@000001P1TP_l00`000000I8;o06B2o`0506^;o`8000001@1[Rol807>Do`030000001cU?l0
N:So00H0N:So1P1m]?l207^kn`030000S`3oool0oooo01T0oooo000U0?ooo`@00cSo1@0YF?l5041Z
o`8000000P10J_l:04ifo`/0G7Wo3@1TP_l;06^;o`T0LIco00<00000076Lo`1hZ?l01P1hZ?l607fd
o`0307^kn`0008l0oooo01/0oooo000U0?ooo`@00cSo1@0YF?l9041Zo`/0CWKo2P1IP?l:06B2o`03
0000001TP_l0I8;o00/0JI;o2`1aW?l607RXo`H0OKCo00<0Nk_k06RhnP3oool0703oool002H0oooo
0P00>_l200<ho`D0:ESo2@10J_l:04ifo`/0FH3o201RROl30000000306:9o`1YT_l0JI;o00T0JI;o
2P1aW?l707RXo`D0OKCo0P1X^?XN0?ooo`009`3oool3000jo`D0:ESo2@10J_l:04ifo`/0FH3o301R
ROl;06VBo`X0LIco1P1hZ?l307fdo`80Lk[o0P1X^?XO0?ooo`00:03oool3000jo`807ego0`0YF?l9
041Zo`T0CWKo2`1IP?l<06:9o`X0JI;o2P1aW?l607RXo`D0Lk[o0P1X^?XP0?ooo`00:@3oool3000j
o`@07ego2@10J_l904ifo`/0FH3o301RROl:06VBo`X0LIco0`1hZ?l307:_o`@0Lk[o0P1X^?XQ0?oo
o`00:P3oool3000jo`@07ego200iL?l904ifo`/0FH3o301RROl:06VBo`T0LIco1P1b[ol407>jo`80
J;Sj8P3oool002/0oooo0`00>_l401mMo`P0>G3o2019OOl;05V0o``0HXWo2@1YT_l:06bTo`D0LZoo
101c^_l00`1X^?X0C:Wb0?ooo`0R0?ooo`00;@3oool2000jo`@07ego1`0iL?l904Umo`X0EHOo2`1R
ROl:06FJo`T0K:Co1P1b[ol307>jo`80C:Wb903oool002h0oooo00<003Wl01mMo`0OGOl00`0OGOl7
03U`o`P0BGgo2P1EQol;05j@o`X0II[o201/Y?l607:_o`80Lk[o00<0H;So04bYlP3oool09@3oool0
0300oooo00<003Wl00mNo`0OGOl00P0OGOl603U`o`P0BGgo2P1EQol;05j@o`T0II[o2@1/Y?l507:_
o`<0H;So00<0C:Wb0?ooo`3oool09@3oool00340oooo00@003Wl00mNo`0?G_l03eko1`0iL?l804Um
o`T0EHOo2`1NT?l906FJo`P0K:Co0`1b[ol206Fdo`<0H;So:@3oool00380oooo00<003Wl00mNo`0?
G_l00P0?G_l502ado`P0BGgo2@1EQol;05j@o`T0II[o1`1/Y?l506Fdo`<0H;So:P3oool003@0oooo
100?G_l502ado`L0?h?o2@1EQol:05j@o`T0II[o1`1SZol506Fdo`80H;So;03oool003D0oooo100?
G_l502ado`L0?h?o2@1<S_l905JGo`T0GJ7o1P1SZol506Fdo`03062ho`0oYOl0oooo02`0oooo000g
0?ooo`03000aj`00Eol005Oo00D0;7Co1`0oPol804b>o`T0EYOo201MXOl606>[o`@0IKCo0P0oYOl_
0?ooo`00>@3oool00`00<N/005Oo001Go`0401Ibo`L0?h?o1`1<S_l905JGo`L0GJ7o1P1SZol304^]
o`80?jGo<@3oool003`0oooo0P00Eol401Ibo`D0;8Co1`1<S_l805JGo`L0GJ7o1P1?Z_l204^]o`80
?jGo<`3oool003l0oooo100FL_l502b4o`L0>i7o1`15Vol604bSo`D0Cj[o0P1;[Ol00`0008l0oooo
0?ooo`0d0?ooo`00@P3oool2001No@D0;8Co1P0kTOl604FKo`D0C:?o1@1?Z_l00`0008l0oooo0?oo
o`0h0?ooo`00A@3oool3001No@0300Uco`0kTOl0>i7o00@0>i7o1@15Vol502NAo`809Y;o?`3oool0
04`0oooo0`0HP_l402:<o`@09i7o@`3oool009X0oooo002J0?ooo`00VP3oool009X0oooo002J0?oo
o`00VP3oool009X0oooo002J0?ooo`00VP3oool009X0oooo002J0?ooo`00VP3oool009X0oooo002J
0?ooo`00VP3oool009X0oooo002J0?ooo`00VP3oool009X0oooo002J0?ooo`00VP3oool009X0oooo
002J0?ooo`00VP3oool009X0oooo002J0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 153}, {150.188, 0}} -> {0.0223133, 0.117711, \
0.00587461, 0.00587461}}]
}, Open  ]],

Cell["\<\
In the previous examples we rotated only the text. Here we spin the whole \
graphic.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(SpinShow[plot1, SpinOrigin \[Rule] {0, 0, 0}, 
      SpinRange \[Rule] {360  \[Degree], 
          0  \[Degree]}]\), "\[IndentingNewLine]", 
    \(SelectionMove[EvaluationNotebook[], All, GeneratedCell]\), "\n", 
    \(FrontEndTokenExecute["\<OpenCloseGroup\>"]\), "\n", 
    \(FrontEndTokenExecute["\<SelectionAnimate\>"]\)}], "Input"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.606 .779 .568 r
.46017 .46966 m .45976 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.5 .5 m .5 .46978 L .46017 .46966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.5 .53022 m .5 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.5 .46978 m .5 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.5 .5 m .5 .53022 L .53983 .53034 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.53983 .53034 m .54024 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.46139 .43966 m .46017 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.5 .46978 m .5 .43989 L .46139 .43966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.45976 .5 m .46017 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.5 .56011 m .5 .53022 L .46017 .53034 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.5 .43989 m .5 .46978 L .53983 .46966 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.54024 .5 m .53983 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.5 .53022 m .5 .56011 L .53861 .56034 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.53861 .56034 m .53983 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.42114 .46929 m .42033 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.45976 .5 m .46017 .46966 L .42114 .46929 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.46017 .53034 m .45976 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.53983 .46966 m .54024 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.54024 .5 m .53983 .53034 L .57886 .53071 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.57886 .53071 m .57967 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.42358 .43896 m .42114 .46929 L .46017 .46966 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.46017 .46966 m .46139 .43966 L .42358 .43896 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.42033 .5 m .42114 .53071 L .46017 .53034 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.46139 .56034 m .46017 .53034 L .42114 .53071 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.46017 .53034 m .46139 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.53983 .46966 m .53861 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.53861 .43966 m .53983 .46966 L .57886 .46929 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.57967 .5 m .57886 .46929 L .53983 .46966 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.53983 .53034 m .53861 .56034 L .57642 .56104 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.57642 .56104 m .57886 .53071 L .53983 .53034 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.49082 .43984 m
.49236 .4354 L
s
.50917 .4354 m
.51072 .43983 L
s
.5 Mabswid
.633 .822 .603 r
.46342 .41036 m .46139 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.5 .43989 m .5 .41069 L .46342 .41036 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.5 .41069 m .5 .43989 L .53861 .43966 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.5 .58931 m .5 .56011 L .46139 .56034 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.5 .56011 m .5 .58931 L .53658 .58964 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.53658 .58964 m .53861 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54463 .44275 m
.54538 .44465 L
s
.55481 .45159 m
.5574 .45155 L
s
.54444 .4397 m
.54463 .44275 L
s
.5 Mabswid
.625 .813 .592 r
.42766 .40937 m .42358 .43896 L .46139 .43966 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.46139 .43966 m .46342 .41036 L .42766 .40937 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.42114 .53071 m .42358 .56104 L .46139 .56034 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.46342 .58964 m .46139 .56034 L .42358 .56104 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.46139 .56034 m .46342 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.53861 .43966 m .53658 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.53658 .41036 m .53861 .43966 L .57642 .43896 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54444 .4397 m
.54448 .43955 L
s
.5 Mabswid
.626 .809 .6 r
.57886 .46929 m .57642 .43896 L .53861 .43966 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.53861 .56034 m .53658 .58964 L .57234 .59063 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.57234 .59063 m .57642 .56104 L .53861 .56034 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.38378 .46868 m .38255 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.42033 .5 m .42114 .46929 L .38378 .46868 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.42114 .53071 m .42033 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.57886 .46929 m .57967 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.57967 .5 m .57886 .53071 L .61622 .53132 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.61622 .53132 m .61745 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.38745 .43778 m .38378 .46868 L .42114 .46929 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.42114 .46929 m .42358 .43896 L .38745 .43778 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.38255 .5 m .38378 .53132 L .42114 .53071 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.42358 .56104 m .42114 .53071 L .38378 .53132 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.57642 .43896 m .57886 .46929 L .61622 .46868 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.61745 .5 m .61622 .46868 L .57886 .46929 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.57886 .53071 m .57642 .56104 L .61255 .56222 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.61255 .56222 m .61622 .53132 L .57886 .53071 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.46628 .38215 m .46342 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.5 .41069 m .5 .38255 L .46628 .38215 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.5 .61745 m .5 .58931 L .46342 .58964 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.5 .38255 m .5 .41069 L .53658 .41036 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.5 .58931 m .5 .61745 L .53372 .61785 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.53372 .61785 m .53658 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.57475 .43776 m
.57543 .43443 L
s
.42292 .43595 m
.42415 .43481 L
s
.5 Mabswid
.636 .831 .608 r
.43336 .38095 m .42766 .40937 L .46342 .41036 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.46342 .41036 m .46628 .38215 L .43336 .38095 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.42358 .56104 m .42766 .59063 L .46342 .58964 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.46628 .61785 m .46342 .58964 L .42766 .59063 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.46342 .58964 m .46628 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.53658 .41036 m .53372 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.53372 .38215 m .53658 .41036 L .57234 .40937 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.57642 .43896 m .57234 .40937 L .53658 .41036 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.53658 .58964 m .53372 .61785 L .56664 .61905 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.56664 .61905 m .57234 .59063 L .53658 .58964 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.39355 .40772 m .38745 .43778 L .42358 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.42358 .43896 m .42766 .40937 L .39355 .40772 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.38378 .53132 m .38745 .56222 L .42358 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.42766 .59063 m .42358 .56104 L .38745 .56222 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.57642 .56104 m .57234 .59063 L .60645 .59228 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.60645 .59228 m .61255 .56222 L .57642 .56104 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.57234 .40937 m .57642 .43896 L .61255 .43778 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.61622 .46868 m .61255 .43778 L .57642 .43896 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.40208 .37896 m .39355 .40772 L .42766 .40937 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.42766 .40937 m .43336 .38095 L .40208 .37896 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.38745 .56222 m .39355 .59228 L .42766 .59063 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.43336 .61905 m .42766 .59063 L .39355 .59228 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.42766 .59063 m .43336 .61905 L .46628 .61785 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.57234 .40937 m .56664 .38095 L .53372 .38215 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.56664 .38095 m .57234 .40937 L .60645 .40772 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.61255 .43778 m .60645 .40772 L .57234 .40937 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.57234 .59063 m .56664 .61905 L .59792 .62104 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.59792 .62104 m .60645 .59228 L .57234 .59063 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.34905 .46783 m .34741 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.38255 .5 m .38378 .46868 L .34905 .46783 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.38378 .53132 m .38255 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.46995 .35545 m .46628 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.5 .38255 m .5 .35589 L .46995 .35545 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.5 .64411 m .5 .61745 L .46628 .61785 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.5 .35589 m .5 .38255 L .53372 .38215 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.5 .61745 m .5 .64411 L .53005 .64455 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.53005 .64455 m .53372 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.61622 .46868 m .61745 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.61745 .5 m .61622 .53132 L .65095 .53217 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.65095 .53217 m .65259 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.35394 .43614 m .34905 .46783 L .38378 .46868 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.38378 .46868 m .38745 .43778 L .35394 .43614 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.34741 .5 m .34905 .53217 L .38378 .53132 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.38745 .56222 m .38378 .53132 L .34905 .53217 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.61255 .43778 m .61622 .46868 L .65095 .46783 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.61464 .43941 m
.61637 .43935 L
s
.5 Mabswid
.597 .769 .578 r
.65259 .5 m .65095 .46783 L .61622 .46868 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.61622 .53132 m .61255 .56222 L .64606 .56386 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.64606 .56386 m .65095 .53217 L .61622 .53132 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.44068 .35415 m .43336 .38095 L .46628 .38215 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.46628 .38215 m .46995 .35545 L .44068 .35415 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.46995 .64455 m .46628 .61785 L .43336 .61905 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.46628 .61785 m .46995 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.53372 .38215 m .53005 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.53005 .35545 m .53372 .38215 L .56664 .38095 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.53372 .61785 m .53005 .64455 L .55932 .64585 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.55932 .64585 m .56664 .61905 L .53372 .61785 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.36206 .40542 m .35394 .43614 L .38745 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.38745 .43778 m .39355 .40772 L .36206 .40542 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.34905 .53217 m .35394 .56386 L .38745 .56222 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.39355 .59228 m .38745 .56222 L .35394 .56386 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.60645 .40772 m .61255 .43778 L .64606 .43614 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.65095 .46783 m .64606 .43614 L .61255 .43778 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.61255 .56222 m .60645 .59228 L .63794 .59458 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.63794 .59458 m .64606 .56386 L .61255 .56222 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.41299 .35198 m .40208 .37896 L .43336 .38095 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.43336 .38095 m .44068 .35415 L .41299 .35198 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.39355 .59228 m .40208 .62104 L .43336 .61905 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.44068 .64585 m .43336 .61905 L .40208 .62104 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.43336 .61905 m .44068 .64585 L .46995 .64455 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.56664 .38095 m .55932 .35415 L .53005 .35545 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.55932 .35415 m .56664 .38095 L .59792 .37896 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.60645 .40772 m .59792 .37896 L .56664 .38095 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.56664 .61905 m .55932 .64585 L .58701 .64802 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.58701 .64802 m .59792 .62104 L .56664 .61905 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.37336 .37619 m .36206 .40542 L .39355 .40772 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.39355 .40772 m .40208 .37896 L .37336 .37619 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.35394 .56386 m .36206 .59458 L .39355 .59228 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.40208 .62104 m .39355 .59228 L .36206 .59458 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.59792 .37896 m .60645 .40772 L .63794 .40542 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.64606 .43614 m .63794 .40542 L .60645 .40772 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.60645 .59228 m .59792 .62104 L .62664 .62381 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.62664 .62381 m .63794 .59458 L .60645 .59228 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.47443 .33074 m .46995 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.5 .35589 m .5 .33118 L .47443 .33074 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.5 .33118 m .5 .35589 L .53005 .35545 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.5 .66882 m .5 .64411 L .46995 .64455 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.5 .64411 m .5 .66882 L .52557 .66926 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.52557 .66926 m .53005 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.4496 .32944 m .44068 .35415 L .46995 .35545 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.46995 .35545 m .47443 .33074 L .4496 .32944 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.47443 .66926 m .46995 .64455 L .44068 .64585 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.46995 .64455 m .47443 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.53005 .35545 m .52557 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.52557 .33074 m .53005 .35545 L .55932 .35415 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.53005 .64455 m .52557 .66926 L .5504 .67056 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.5504 .67056 m .55932 .64585 L .53005 .64455 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.31808 .46673 m .31604 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.34741 .5 m .34905 .46783 L .31808 .46673 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.34905 .53217 m .34741 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.65095 .46783 m .65259 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.65259 .5 m .65095 .53217 L .68192 .53327 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.68192 .53327 m .68396 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.32417 .43403 m .31808 .46673 L .34905 .46783 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.34905 .46783 m .35394 .43614 L .32417 .43403 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.31604 .5 m .31808 .53327 L .34905 .53217 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.35394 .56386 m .34905 .53217 L .31808 .53327 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.64606 .43614 m .65095 .46783 L .68192 .46673 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.68396 .5 m .68192 .46673 L .65095 .46783 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.65095 .53217 m .64606 .56386 L .67583 .56597 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.67583 .56597 m .68192 .53327 L .65095 .53217 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.38776 .34897 m .37336 .37619 L .40208 .37896 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.40208 .37896 m .41299 .35198 L .38776 .34897 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.36206 .59458 m .37336 .62381 L .40208 .62104 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.41299 .64802 m .40208 .62104 L .37336 .62381 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.40208 .62104 m .41299 .64802 L .44068 .64585 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.59792 .37896 m .58701 .35198 L .55932 .35415 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.58701 .35198 m .59792 .37896 L .62664 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.63794 .40542 m .62664 .37619 L .59792 .37896 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.59792 .62104 m .58701 .64802 L .61224 .65103 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.61224 .65103 m .62664 .62381 L .59792 .62104 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.42624 .32729 m .41299 .35198 L .44068 .35415 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.44068 .35415 m .4496 .32944 L .42624 .32729 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.4496 .67056 m .44068 .64585 L .41299 .64802 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.44068 .64585 m .4496 .67056 L .47443 .66926 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.55932 .35415 m .5504 .32944 L .52557 .33074 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.5504 .32944 m .55932 .35415 L .58701 .35198 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.55932 .64585 m .5504 .67056 L .57376 .67271 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.57376 .67271 m .58701 .64802 L .55932 .64585 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.33425 .40248 m .32417 .43403 L .35394 .43614 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.35394 .43614 m .36206 .40542 L .33425 .40248 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.31808 .53327 m .32417 .56597 L .35394 .56386 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.36206 .59458 m .35394 .56386 L .32417 .56597 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.63794 .40542 m .64606 .43614 L .67583 .43403 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.68192 .46673 m .67583 .43403 L .64606 .43614 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.64606 .56386 m .63794 .59458 L .66575 .59752 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.66575 .59752 m .67583 .56597 L .64606 .56386 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.34822 .37266 m .33425 .40248 L .36206 .40542 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.36206 .40542 m .37336 .37619 L .34822 .37266 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.32417 .56597 m .33425 .59752 L .36206 .59458 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.37336 .62381 m .36206 .59458 L .33425 .59752 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.62664 .37619 m .63794 .40542 L .66575 .40248 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.67583 .43403 m .66575 .40248 L .63794 .40542 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.63794 .59458 m .62664 .62381 L .65178 .62734 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.65178 .62734 m .66575 .59752 L .63794 .59458 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.47972 .30855 m .47443 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.5 .33118 m .5 .30894 L .47972 .30855 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.5 .69106 m .5 .66882 L .47443 .66926 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.5 .30894 m .5 .33118 L .52557 .33074 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.5 .66882 m .5 .69106 L .52028 .69145 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.52028 .69145 m .52557 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.46008 .30739 m .4496 .32944 L .47443 .33074 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.47443 .33074 m .47972 .30855 L .46008 .30739 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.47972 .69145 m .47443 .66926 L .4496 .67056 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.47443 .66926 m .47972 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.52557 .33074 m .52028 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.52028 .30855 m .52557 .33074 L .5504 .32944 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.52557 .66926 m .52028 .69145 L .53992 .69261 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.53992 .69261 m .5504 .67056 L .52557 .66926 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.40515 .32433 m .38776 .34897 L .41299 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.41299 .35198 m .42624 .32729 L .40515 .32433 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.37336 .62381 m .38776 .65103 L .41299 .64802 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.42624 .67271 m .41299 .64802 L .38776 .65103 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.41299 .64802 m .42624 .67271 L .4496 .67056 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.58701 .35198 m .57376 .32729 L .5504 .32944 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.57376 .32729 m .58701 .35198 L .61224 .34897 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.62664 .37619 m .61224 .34897 L .58701 .35198 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.58701 .64802 m .57376 .67271 L .59485 .67567 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.59485 .67567 m .61224 .65103 L .58701 .64802 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.36592 .34517 m .34822 .37266 L .37336 .37619 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.37336 .37619 m .38776 .34897 L .36592 .34517 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.33425 .59752 m .34822 .62734 L .37336 .62381 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.38776 .65103 m .37336 .62381 L .34822 .62734 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.61224 .34897 m .62664 .37619 L .65178 .37266 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.66575 .40248 m .65178 .37266 L .62664 .37619 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.62664 .62381 m .61224 .65103 L .63408 .65483 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.63408 .65483 m .65178 .62734 L .62664 .62381 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.44174 .30547 m .42624 .32729 L .4496 .32944 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.4496 .32944 m .46008 .30739 L .44174 .30547 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.46008 .69261 m .4496 .67056 L .42624 .67271 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.4496 .67056 m .46008 .69261 L .47972 .69145 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.5504 .32944 m .53992 .30739 L .52028 .30855 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.53992 .30739 m .5504 .32944 L .57376 .32729 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.5504 .67056 m .53992 .69261 L .55826 .69453 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.55826 .69453 m .57376 .67271 L .5504 .67056 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.29221 .4654 m .28979 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.31604 .5 m .31808 .46673 L .29221 .4654 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.31808 .53327 m .31604 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.68192 .46673 m .68396 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.68396 .5 m .68192 .53327 L .70779 .5346 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.70779 .5346 m .71021 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.29943 .43148 m .29221 .4654 L .31808 .46673 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.31808 .46673 m .32417 .43403 L .29943 .43148 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.28979 .5 m .29221 .5346 L .31808 .53327 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.32417 .56597 m .31808 .53327 L .29221 .5346 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.67583 .43403 m .68192 .46673 L .70779 .4654 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.71021 .5 m .70779 .4654 L .68192 .46673 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.68192 .53327 m .67583 .56597 L .70057 .56852 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.70057 .56852 m .70779 .5346 L .68192 .53327 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.31135 .39893 m .29943 .43148 L .32417 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.32417 .43403 m .33425 .40248 L .31135 .39893 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.29221 .5346 m .29943 .56852 L .32417 .56597 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.33425 .59752 m .32417 .56597 L .29943 .56852 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42535 .30284 m .40515 .32433 L .42624 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42624 .32729 m .44174 .30547 L .42535 .30284 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.38776 .65103 m .40515 .67567 L .42624 .67271 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.44174 .69453 m .42624 .67271 L .40515 .67567 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.42624 .67271 m .44174 .69453 L .46008 .69261 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.66575 .40248 m .67583 .43403 L .70057 .43148 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.70779 .4654 m .70057 .43148 L .67583 .43403 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.67583 .56597 m .66575 .59752 L .68865 .60107 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.68865 .60107 m .70057 .56852 L .67583 .56597 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.57376 .32729 m .55826 .30547 L .53992 .30739 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.55826 .30547 m .57376 .32729 L .59485 .32433 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.61224 .34897 m .59485 .32433 L .57376 .32729 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57376 .67271 m .55826 .69453 L .57465 .69716 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57465 .69716 m .59485 .67567 L .57376 .67271 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38713 .32061 m .36592 .34517 L .38776 .34897 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38776 .34897 m .40515 .32433 L .38713 .32061 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.34822 .62734 m .36592 .65483 L .38776 .65103 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.40515 .67567 m .38776 .65103 L .36592 .65483 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.59485 .32433 m .61224 .34897 L .63408 .34517 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.65178 .37266 m .63408 .34517 L .61224 .34897 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61224 .65103 m .59485 .67567 L .61287 .67939 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61287 .67939 m .63408 .65483 L .61224 .65103 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.48578 .28949 m .47972 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.5 .30894 m .5 .28979 L .48578 .28949 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.5 .28979 m .5 .30894 L .52028 .30855 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.5 .71021 m .5 .69106 L .47972 .69145 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.5 .69106 m .5 .71021 L .51422 .71051 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51422 .71051 m .52028 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.32778 .36843 m .31135 .39893 L .33425 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.33425 .40248 m .34822 .37266 L .32778 .36843 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.29943 .56852 m .31135 .60107 L .33425 .59752 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.34822 .62734 m .33425 .59752 L .31135 .60107 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.65178 .37266 m .66575 .40248 L .68865 .39893 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.70057 .43148 m .68865 .39893 L .66575 .40248 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.66575 .59752 m .65178 .62734 L .67222 .63157 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.67222 .63157 m .68865 .60107 L .66575 .59752 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47206 .28859 m .46008 .30739 L .47972 .30855 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47972 .30855 m .48578 .28949 L .47206 .28859 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.48578 .71051 m .47972 .69145 L .46008 .69261 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47972 .69145 m .48578 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.52028 .30855 m .51422 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.51422 .28949 m .52028 .30855 L .53992 .30739 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52028 .69145 m .51422 .71051 L .52794 .71141 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52794 .71141 m .53992 .69261 L .52028 .69145 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.45934 .28712 m .44174 .30547 L .46008 .30739 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.46008 .30739 m .47206 .28859 L .45934 .28712 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.47206 .71141 m .46008 .69261 L .44174 .69453 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.46008 .69261 m .47206 .71141 L .48578 .71051 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.53992 .30739 m .52794 .28859 L .51422 .28949 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.52794 .28859 m .53992 .30739 L .55826 .30547 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.53992 .69261 m .52794 .71141 L .54066 .71288 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.54066 .71288 m .55826 .69453 L .53992 .69261 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34844 .34065 m .32778 .36843 L .34822 .37266 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34822 .37266 m .36592 .34517 L .34844 .34065 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.31135 .60107 m .32778 .63157 L .34822 .62734 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.36592 .65483 m .34822 .62734 L .32778 .63157 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.63408 .34517 m .65178 .37266 L .67222 .36843 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.68865 .39893 m .67222 .36843 L .65178 .37266 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65178 .62734 m .63408 .65483 L .65156 .65935 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65156 .65935 m .67222 .63157 L .65178 .62734 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.41156 .29957 m .38713 .32061 L .40515 .32433 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.40515 .32433 m .42535 .30284 L .41156 .29957 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.36592 .65483 m .38713 .67939 L .40515 .67567 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.42535 .69716 m .40515 .67567 L .38713 .67939 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.40515 .67567 m .42535 .69716 L .44174 .69453 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.59485 .32433 m .57465 .30284 L .55826 .30547 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.57465 .30284 m .59485 .32433 L .61287 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.63408 .34517 m .61287 .32061 L .59485 .32433 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.59485 .67567 m .57465 .69716 L .58844 .70043 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.58844 .70043 m .61287 .67939 L .59485 .67567 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44812 .28512 m .42535 .30284 L .44174 .30547 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44174 .30547 m .45934 .28712 L .44812 .28512 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.45934 .71288 m .44174 .69453 L .42535 .69716 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.44174 .69453 m .45934 .71288 L .47206 .71141 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.55826 .30547 m .54066 .28712 L .52794 .28859 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.54066 .28712 m .55826 .30547 L .57465 .30284 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55826 .69453 m .54066 .71288 L .55188 .71488 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55188 .71488 m .57465 .69716 L .55826 .69453 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.37301 .31621 m .34844 .34065 L .36592 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.36592 .34517 m .38713 .32061 L .37301 .31621 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.32778 .63157 m .34844 .65935 L .36592 .65483 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.38713 .67939 m .36592 .65483 L .34844 .65935 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.61287 .32061 m .63408 .34517 L .65156 .34065 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.67222 .36843 m .65156 .34065 L .63408 .34517 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.63408 .65483 m .61287 .67939 L .62699 .68379 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.62699 .68379 m .65156 .65935 L .63408 .65483 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.27297 .46384 m .2702 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.28979 .5 m .29221 .4654 L .27297 .46384 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.29221 .5346 m .28979 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.70779 .4654 m .71021 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.71021 .5 m .70779 .5346 L .72703 .53616 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.72703 .53616 m .7298 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.49256 .27421 m .48578 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.5 .28979 m .5 .27438 L .49256 .27421 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.5 .27438 m .5 .28979 L .51422 .28949 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.5 .72562 m .5 .71021 L .48578 .71051 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.5 .71021 m .5 .72562 L .50744 .72579 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.50744 .72579 m .51422 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.2812 .42852 m .27297 .46384 L .29221 .4654 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.29221 .4654 m .29943 .43148 L .2812 .42852 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.2702 .5 m .27297 .53616 L .29221 .5346 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.29943 .56852 m .29221 .5346 L .27297 .53616 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.70057 .43148 m .70779 .4654 L .72703 .46384 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.7298 .5 m .72703 .46384 L .70779 .4654 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.70779 .5346 m .70057 .56852 L .7188 .57148 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.7188 .57148 m .72703 .53616 L .70779 .5346 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.43884 .28266 m .41156 .29957 L .42535 .30284 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.42535 .30284 m .44812 .28512 L .43884 .28266 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.38713 .67939 m .41156 .70043 L .42535 .69716 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.44812 .71488 m .42535 .69716 L .41156 .70043 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.42535 .69716 m .44812 .71488 L .45934 .71288 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.57465 .30284 m .55188 .28512 L .54066 .28712 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.55188 .28512 m .57465 .30284 L .58844 .29957 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.61287 .32061 m .58844 .29957 L .57465 .30284 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.57465 .69716 m .55188 .71488 L .56116 .71734 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.56116 .71734 m .58844 .70043 L .57465 .69716 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48542 .27371 m .47206 .28859 L .48578 .28949 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48578 .28949 m .49256 .27421 L .48542 .27371 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51422 .28949 m .50744 .27421 L .5 .27438 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.50744 .27421 m .51422 .28949 L .52794 .28859 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.49256 .72579 m .48578 .71051 L .47206 .71141 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.48578 .71051 m .49256 .72579 L .5 .72562 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51422 .71051 m .50744 .72579 L .51458 .72629 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51458 .72629 m .52794 .71141 L .51422 .71051 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29473 .39483 m .2812 .42852 L .29943 .43148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29943 .43148 m .31135 .39893 L .29473 .39483 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.27297 .53616 m .2812 .57148 L .29943 .56852 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.31135 .60107 m .29943 .56852 L .2812 .57148 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.40102 .29574 m .37301 .31621 L .38713 .32061 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.38713 .32061 m .41156 .29957 L .40102 .29574 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.34844 .65935 m .37301 .68379 L .38713 .67939 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.41156 .70043 m .38713 .67939 L .37301 .68379 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.58844 .29957 m .61287 .32061 L .62699 .31621 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.65156 .34065 m .62699 .31621 L .61287 .32061 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.68865 .39893 m .70057 .43148 L .7188 .42852 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.72703 .46384 m .7188 .42852 L .70057 .43148 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.61287 .67939 m .58844 .70043 L .59898 .70426 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.59898 .70426 m .62699 .68379 L .61287 .67939 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70057 .56852 m .68865 .60107 L .70527 .60517 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70527 .60517 m .7188 .57148 L .70057 .56852 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47886 .27289 m .45934 .28712 L .47206 .28859 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47206 .28859 m .48542 .27371 L .47886 .27289 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.48542 .72629 m .47206 .71141 L .45934 .71288 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.47206 .71141 m .48542 .72629 L .49256 .72579 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.52794 .28859 m .51458 .27371 L .50744 .27421 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.51458 .27371 m .52794 .28859 L .54066 .28712 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52794 .71141 m .51458 .72629 L .52114 .72711 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52114 .72711 m .54066 .71288 L .52794 .71141 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31326 .36358 m .29473 .39483 L .31135 .39893 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31135 .39893 m .32778 .36843 L .31326 .36358 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.2812 .57148 m .29473 .60517 L .31135 .60107 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.32778 .63157 m .31135 .60107 L .29473 .60517 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.67222 .36843 m .68865 .39893 L .70527 .39483 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.7188 .42852 m .70527 .39483 L .68865 .39893 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68865 .60107 m .67222 .63157 L .68674 .63642 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68674 .63642 m .70527 .60517 L .68865 .60107 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.3364 .3355 m .31326 .36358 L .32778 .36843 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.32778 .36843 m .34844 .34065 L .3364 .3355 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.29473 .60517 m .31326 .63642 L .32778 .63157 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.34844 .65935 m .32778 .63157 L .31326 .63642 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.47314 .27179 m .44812 .28512 L .45934 .28712 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.45934 .28712 m .47886 .27289 L .47314 .27179 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.47886 .72711 m .45934 .71288 L .44812 .71488 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.45934 .71288 m .47886 .72711 L .48542 .72629 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.65156 .34065 m .67222 .36843 L .68674 .36358 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.70527 .39483 m .68674 .36358 L .67222 .36843 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.67222 .63157 m .65156 .65935 L .6636 .6645 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.6636 .6645 m .68674 .63642 L .67222 .63157 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.54066 .28712 m .52114 .27289 L .51458 .27371 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.52114 .27289 m .54066 .28712 L .55188 .28512 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.54066 .71288 m .52114 .72711 L .52686 .72821 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.52686 .72821 m .55188 .71488 L .54066 .71288 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.43196 .2798 m .40102 .29574 L .41156 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.41156 .29957 m .43884 .28266 L .43196 .2798 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.37301 .68379 m .40102 .70426 L .41156 .70043 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.43884 .71734 m .41156 .70043 L .40102 .70426 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.41156 .70043 m .43884 .71734 L .44812 .71488 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.58844 .29957 m .56116 .28266 L .55188 .28512 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.56116 .28266 m .58844 .29957 L .59898 .29574 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.62699 .31621 m .59898 .29574 L .58844 .29957 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.58844 .70043 m .56116 .71734 L .56804 .7202 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.56804 .7202 m .59898 .70426 L .58844 .70043 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.36362 .31126 m .3364 .3355 L .34844 .34065 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.34844 .34065 m .37301 .31621 L .36362 .31126 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.31326 .63642 m .3364 .6645 L .34844 .65935 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.37301 .68379 m .34844 .65935 L .3364 .6645 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.62699 .31621 m .65156 .34065 L .6636 .3355 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.68674 .36358 m .6636 .3355 L .65156 .34065 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.65156 .65935 m .62699 .68379 L .63638 .68874 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.63638 .68874 m .6636 .6645 L .65156 .65935 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.46851 .27044 m .43884 .28266 L .44812 .28512 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.44812 .28512 m .47314 .27179 L .46851 .27044 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.47314 .72821 m .44812 .71488 L .43884 .71734 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.44812 .71488 m .47314 .72821 L .47886 .72711 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.55188 .28512 m .52686 .27179 L .52114 .27289 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.52686 .27179 m .55188 .28512 L .56116 .28266 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.55188 .71488 m .52686 .72821 L .53149 .72956 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.53149 .72956 m .56116 .71734 L .55188 .71488 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.39434 .29148 m .36362 .31126 L .37301 .31621 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.37301 .31621 m .40102 .29574 L .39434 .29148 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.3364 .6645 m .36362 .68874 L .37301 .68379 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.40102 .70426 m .37301 .68379 L .36362 .68874 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.59898 .29574 m .62699 .31621 L .63638 .31126 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.6636 .3355 m .63638 .31126 L .62699 .31621 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.62699 .68379 m .59898 .70426 L .60566 .70852 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.60566 .70852 m .63638 .68874 L .62699 .68379 L p F P
.505 .664 .505 r
s
.555 .774 .586 r
.5 .27438 m .5 .26345 L .49256 .27421 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50744 .27421 m .5 .26345 L .5 .27438 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .5 .72562 L .49256 .72579 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50744 .72579 L .5 .72562 L closepath p F P
.505 .664 .505 r
s
.55 .764 .57 r
.46519 .2689 m .43196 .2798 L .43884 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.43884 .28266 m .46851 .27044 L .46519 .2689 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.40102 .70426 m .43196 .7202 L .43884 .71734 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.46851 .72956 m .43884 .71734 L .43196 .7202 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.43884 .71734 m .46851 .72956 L .47314 .72821 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.56116 .28266 m .53149 .27044 L .52686 .27179 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.53149 .27044 m .56116 .28266 L .56804 .2798 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.59898 .29574 m .56804 .2798 L .56116 .28266 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.56116 .71734 m .53149 .72956 L .53481 .7311 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.53481 .7311 m .56804 .7202 L .56116 .71734 L p F P
.505 .664 .505 r
s
.553 .771 .583 r
.49256 .27421 m .5 .26345 L .48542 .27371 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51458 .27371 m .5 .26345 L .50744 .27421 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .49256 .72579 L .48542 .72629 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51458 .72629 L .50744 .72579 L closepath p F P
.505 .664 .505 r
s
.549 .766 .579 r
.48542 .27371 m .5 .26345 L .47886 .27289 L closepath p F P
.505 .664 .505 r
s
.552 .771 .585 r
.52114 .27289 m .5 .26345 L .51458 .27371 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .48542 .72629 L .47886 .72711 L closepath p F P
.505 .664 .505 r
s
.197 .204 .155 r
.5 .73655 m .52114 .72711 L .51458 .72629 L closepath p F P
.505 .664 .505 r
s
.524 .728 .536 r
.42783 .27666 m .39434 .29148 L .40102 .29574 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.40102 .29574 m .43196 .2798 L .42783 .27666 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.36362 .68874 m .39434 .70852 L .40102 .70426 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.43196 .7202 m .40102 .70426 L .39434 .70852 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.56804 .2798 m .59898 .29574 L .60566 .29148 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.63638 .31126 m .60566 .29148 L .59898 .29574 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.59898 .70426 m .56804 .7202 L .57217 .72334 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.57217 .72334 m .60566 .70852 L .59898 .70426 L p F P
.505 .664 .505 r
s
.543 .759 .573 r
.47886 .27289 m .5 .26345 L .47314 .27179 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .47886 .72711 L .47314 .72821 L closepath p F P
.505 .664 .505 r
s
.548 .765 .582 r
.52686 .27179 m .5 .26345 L .52114 .27289 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .52686 .72821 L .52114 .72711 L closepath p F P
.505 .664 .505 r
s
.535 .75 .567 r
.47314 .27179 m .5 .26345 L .46851 .27044 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .47314 .72821 L .46851 .72956 L closepath p F P
.505 .664 .505 r
s
.541 .758 .578 r
.53149 .27044 m .5 .26345 L .52686 .27179 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .53149 .72956 L .52686 .72821 L closepath p F P
.505 .664 .505 r
s
.279 .362 .238 r
.26206 .46211 m .25902 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.2702 .5 m .27297 .46384 L .26206 .46211 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.27297 .53616 m .2702 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.72703 .46384 m .7298 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.7298 .5 m .72703 .53616 L .73794 .53789 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.73794 .53789 m .74098 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27109 .42521 m .26206 .46211 L .27297 .46384 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27297 .46384 m .2812 .42852 L .27109 .42521 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.25902 .5 m .26206 .53789 L .27297 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.2812 .57148 m .27297 .53616 L .26206 .53789 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.7188 .42852 m .72703 .46384 L .73794 .46211 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.74098 .5 m .73794 .46211 L .72703 .46384 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72703 .53616 m .7188 .57148 L .72891 .57479 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72891 .57479 m .73794 .53789 L .72703 .53616 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.28585 .39028 m .27109 .42521 L .2812 .42852 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.2812 .42852 m .29473 .39483 L .28585 .39028 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.26206 .53789 m .27109 .57479 L .2812 .57148 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.29473 .60517 m .2812 .57148 L .27109 .57479 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.70527 .39483 m .7188 .42852 L .72891 .42521 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.73794 .46211 m .72891 .42521 L .7188 .42852 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.7188 .57148 m .70527 .60517 L .71415 .60972 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.71415 .60972 m .72891 .57479 L .7188 .57148 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.46333 .26722 m .42783 .27666 L .43196 .2798 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.43196 .2798 m .46519 .2689 L .46333 .26722 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.39434 .70852 m .42783 .72334 L .43196 .7202 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.46519 .7311 m .43196 .7202 L .42783 .72334 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.43196 .7202 m .46519 .7311 L .46851 .72956 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.56804 .2798 m .53481 .2689 L .53149 .27044 L p F P
.505 .664 .505 r
s
.544 .761 .586 r
.53481 .2689 m .56804 .2798 L .57217 .27666 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.60566 .29148 m .57217 .27666 L .56804 .2798 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.56804 .7202 m .53481 .7311 L .53667 .73278 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.53667 .73278 m .57217 .72334 L .56804 .7202 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.30594 .35823 m .28585 .39028 L .29473 .39483 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.29473 .39483 m .31326 .36358 L .30594 .35823 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.27109 .57479 m .28585 .60972 L .29473 .60517 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.31326 .63642 m .29473 .60517 L .28585 .60972 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.68674 .36358 m .70527 .39483 L .71415 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.72891 .42521 m .71415 .39028 L .70527 .39483 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.70527 .60517 m .68674 .63642 L .69406 .64177 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.69406 .64177 m .71415 .60972 L .70527 .60517 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.33081 .32987 m .30594 .35823 L .31326 .36358 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.31326 .36358 m .3364 .3355 L .33081 .32987 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.28585 .60972 m .30594 .64177 L .31326 .63642 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.3364 .6645 m .31326 .63642 L .30594 .64177 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.6636 .3355 m .68674 .36358 L .69406 .35823 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.71415 .39028 m .69406 .35823 L .68674 .36358 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.68674 .63642 m .6636 .6645 L .66919 .67013 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.66919 .67013 m .69406 .64177 L .68674 .63642 L p F P
.505 .664 .505 r
s
.527 .74 .559 r
.46851 .27044 m .5 .26345 L .46519 .2689 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .46851 .72956 L .46519 .7311 L closepath p F P
.505 .664 .505 r
s
.533 .749 .571 r
.53481 .2689 m .5 .26345 L .53149 .27044 L closepath p F P
.505 .664 .505 r
s
.183 .19 .145 r
.5 .73655 m .53481 .7311 L .53149 .72956 L closepath p F P
.505 .664 .505 r
s
.425 .593 .423 r
.35976 .30591 m .33081 .32987 L .3364 .3355 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.3364 .3355 m .36362 .31126 L .35976 .30591 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.30594 .64177 m .33081 .67013 L .3364 .6645 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.36362 .68874 m .3364 .6645 L .33081 .67013 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.63638 .31126 m .6636 .3355 L .66919 .32987 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.69406 .35823 m .66919 .32987 L .6636 .3355 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.6636 .6645 m .63638 .68874 L .64024 .69409 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.64024 .69409 m .66919 .67013 L .6636 .6645 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.39203 .28693 m .35976 .30591 L .36362 .31126 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.36362 .31126 m .39434 .29148 L .39203 .28693 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.33081 .67013 m .35976 .69409 L .36362 .68874 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.39434 .70852 m .36362 .68874 L .35976 .69409 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.60566 .29148 m .63638 .31126 L .64024 .30591 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.66919 .32987 m .64024 .30591 L .63638 .31126 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.63638 .68874 m .60566 .70852 L .60797 .71307 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.60797 .71307 m .64024 .69409 L .63638 .68874 L p F P
.505 .664 .505 r
s
.517 .728 .55 r
.46519 .2689 m .5 .26345 L .46333 .26722 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42783 .72334 m .46333 .73278 L .46519 .7311 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .46519 .7311 L .46333 .73278 L closepath p F P
.505 .664 .505 r
s
.524 .738 .564 r
.53667 .26722 m .5 .26345 L .53481 .2689 L closepath p F P
.505 .664 .505 r
s
.544 .761 .586 r
.57217 .27666 m .53667 .26722 L .53481 .2689 L p F P
.505 .664 .505 r
s
.176 .185 .14 r
.5 .73655 m .53667 .73278 L .53481 .7311 L closepath p F P
.505 .664 .505 r
s
.475 .67 .494 r
.42676 .27336 m .39203 .28693 L .39434 .29148 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.39434 .29148 m .42783 .27666 L .42676 .27336 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.35976 .69409 m .39203 .71307 L .39434 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.42783 .72334 m .39434 .70852 L .39203 .71307 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.57217 .27666 m .60566 .29148 L .60797 .28693 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.64024 .30591 m .60797 .28693 L .60566 .29148 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.60566 .70852 m .57217 .72334 L .57324 .72664 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.57324 .72664 m .60797 .71307 L .60566 .70852 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.46306 .26549 m .42676 .27336 L .42783 .27666 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.42783 .27666 m .46333 .26722 L .46306 .26549 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.39203 .71307 m .42676 .72664 L .42783 .72334 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.46333 .73278 m .42783 .72334 L .42676 .72664 L p F P
.505 .664 .505 r
s
.515 .726 .562 r
.53667 .26722 m .57217 .27666 L .57324 .27336 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.60797 .28693 m .57324 .27336 L .57217 .27666 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.57217 .72334 m .53667 .73278 L .53694 .73451 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.53694 .73451 m .57324 .72664 L .57217 .72334 L p F P
.505 .664 .505 r
s
.506 .715 .541 r
.46333 .26722 m .5 .26345 L .46306 .26549 L closepath p F P
.505 .664 .505 r
s
.177 .185 .14 r
.42676 .72664 m .46306 .73451 L .46333 .73278 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .46333 .73278 L .46306 .73451 L closepath p F P
.505 .664 .505 r
s
.514 .725 .555 r
.53694 .26549 m .5 .26345 L .53667 .26722 L closepath p F P
.505 .664 .505 r
s
.515 .726 .562 r
.57324 .27336 m .53694 .26549 L .53667 .26722 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .53694 .73451 L .53667 .73278 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49203 .74206 L .5 .74225 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .48444 .74148 L .49203 .74206 L closepath p F P
.505 .664 .505 r
s
.141 .152 .116 r
.5 .73655 m .4776 .74056 L .48444 .74148 L closepath p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .73655 m .47183 .73933 L .4776 .74056 L closepath p F P
.505 .664 .505 r
s
.152 .162 .123 r
.5 .73655 m .46737 .73787 L .47183 .73933 L closepath p F P
.505 .664 .505 r
s
.159 .168 .128 r
.5 .73655 m .46442 .73624 L .46737 .73787 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .46306 .73451 L .46442 .73624 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .53558 .73624 L .53694 .73451 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .53263 .73787 L .53558 .73624 L closepath p F P
.505 .664 .505 r
s
.149 .16 .121 r
.5 .73655 m .52817 .73933 L .53263 .73787 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .73655 m .5224 .74056 L .52817 .73933 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .51556 .74148 L .5224 .74056 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50797 .74206 L .51556 .74148 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .5 .74225 L .50797 .74206 L closepath p F P
.505 .664 .505 r
s
.503 .712 .546 r
.53558 .26376 m .5 .26345 L .53694 .26549 L closepath p F P
.505 .664 .505 r
s
.496 .702 .532 r
.46306 .26549 m .5 .26345 L .46442 .26376 L closepath p F P
.505 .664 .505 r
s
.492 .698 .536 r
.53263 .26213 m .5 .26345 L .53558 .26376 L closepath p F P
.505 .664 .505 r
s
.485 .689 .523 r
.46442 .26376 m .5 .26345 L .46737 .26213 L closepath p F P
.505 .664 .505 r
s
.481 .685 .526 r
.52817 .26067 m .5 .26345 L .53263 .26213 L closepath p F P
.505 .664 .505 r
s
.471 .673 .518 r
.5224 .25944 m .5 .26345 L .52817 .26067 L closepath p F P
.505 .664 .505 r
s
.475 .677 .515 r
.46737 .26213 m .5 .26345 L .47183 .26067 L closepath p F P
.505 .664 .505 r
s
.463 .663 .51 r
.51556 .25852 m .5 .26345 L .5224 .25944 L closepath p F P
.505 .664 .505 r
s
.466 .667 .508 r
.47183 .26067 m .5 .26345 L .4776 .25944 L closepath p F P
.505 .664 .505 r
s
.457 .656 .504 r
.50797 .25794 m .5 .26345 L .51556 .25852 L closepath p F P
.505 .664 .505 r
s
.459 .658 .503 r
.4776 .25944 m .5 .26345 L .48444 .25852 L closepath p F P
.505 .664 .505 r
s
.453 .652 .5 r
.5 .25775 m .5 .26345 L .50797 .25794 L closepath p F P
.505 .664 .505 r
s
.455 .653 .499 r
.48444 .25852 m .5 .26345 L .49203 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49203 .25794 m .5 .26345 L .5 .25775 L closepath p F P
.505 .664 .505 r
s
.155 .165 .125 r
.42894 .72997 m .46442 .73624 L .46306 .73451 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.46306 .73451 m .42676 .72664 L .42894 .72997 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.42676 .27336 m .46306 .26549 L .46442 .26376 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.57324 .72664 m .53694 .73451 L .53558 .73624 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.53694 .26549 m .57324 .27336 L .57106 .27003 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.57106 .27003 m .53558 .26376 L .53694 .26549 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.3945 .71771 m .42894 .72997 L .42676 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.42676 .72664 m .39203 .71307 L .3945 .71771 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.46442 .26376 m .42894 .27003 L .42676 .27336 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.39203 .28693 m .42676 .27336 L .42894 .27003 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60797 .71307 m .57324 .72664 L .57106 .72997 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.53558 .73624 m .57106 .72997 L .57324 .72664 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.57324 .27336 m .60797 .28693 L .6055 .28229 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.6055 .28229 m .57106 .27003 L .57324 .27336 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.36207 .69962 m .3945 .71771 L .39203 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.39203 .71307 m .35976 .69409 L .36207 .69962 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.42894 .27003 m .3945 .28229 L .39203 .28693 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.35976 .30591 m .39203 .28693 L .3945 .28229 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.64024 .69409 m .60797 .71307 L .6055 .71771 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.57106 .72997 m .6055 .71771 L .60797 .71307 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.60797 .28693 m .64024 .30591 L .63793 .30038 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.63793 .30038 m .6055 .28229 L .60797 .28693 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.43439 .73316 m .46737 .73787 L .46442 .73624 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.46442 .73624 m .42894 .72997 L .43439 .73316 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.42894 .27003 m .46442 .26376 L .46737 .26213 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.57106 .72997 m .53558 .73624 L .53263 .73787 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.53558 .26376 m .57106 .27003 L .56561 .26684 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.56561 .26684 m .53263 .26213 L .53558 .26376 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.33261 .67601 m .36207 .69962 L .35976 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.35976 .69409 m .33081 .67013 L .33261 .67601 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.3945 .28229 m .36207 .30038 L .35976 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.33081 .32987 m .35976 .30591 L .36207 .30038 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.66919 .67013 m .64024 .69409 L .63793 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.6055 .71771 m .63793 .69962 L .64024 .69409 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.64024 .30591 m .66919 .32987 L .66739 .32399 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.66739 .32399 m .63793 .30038 L .64024 .30591 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.30703 .64742 m .33261 .67601 L .33081 .67013 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.33081 .67013 m .30594 .64177 L .30703 .64742 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.36207 .30038 m .33261 .32399 L .33081 .32987 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.30594 .35823 m .33081 .32987 L .33261 .32399 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.69406 .64177 m .66919 .67013 L .66739 .67601 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.63793 .69962 m .66739 .67601 L .66919 .67013 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.66919 .32987 m .69406 .35823 L .69297 .35258 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.69297 .35258 m .66739 .32399 L .66919 .32987 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.443 .73607 m .47183 .73933 L .46737 .73787 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.46737 .73787 m .43439 .73316 L .443 .73607 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.53263 .73787 m .56561 .73316 L .57106 .72997 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.56561 .73316 m .53263 .73787 L .52817 .73933 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.43439 .26684 m .46737 .26213 L .47183 .26067 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.46737 .26213 m .43439 .26684 L .42894 .27003 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.53263 .26213 m .56561 .26684 L .557 .26393 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.557 .26393 m .52817 .26067 L .53263 .26213 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.33261 .32399 m .30703 .35258 L .30594 .35823 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.28585 .39028 m .30594 .35823 L .30703 .35258 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.28616 .61456 m .30703 .64742 L .30594 .64177 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.30594 .64177 m .28585 .60972 L .28616 .61456 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.69406 .35823 m .71415 .39028 L .71384 .38544 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.71384 .38544 m .69297 .35258 L .69406 .35823 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.71415 .60972 m .69406 .64177 L .69297 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66739 .67601 m .69297 .64742 L .69406 .64177 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.27072 .57833 m .28616 .61456 L .28585 .60972 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.28585 .60972 m .27109 .57479 L .27072 .57833 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.30703 .35258 m .28616 .38544 L .28585 .39028 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.27109 .42521 m .28585 .39028 L .28616 .38544 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.71415 .39028 m .72891 .42521 L .72928 .42167 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.72928 .42167 m .71384 .38544 L .71415 .39028 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.72891 .57479 m .71415 .60972 L .71384 .61456 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.69297 .64742 m .71384 .61456 L .71415 .60972 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.40194 .72224 m .43439 .73316 L .42894 .72997 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.42894 .72997 m .3945 .71771 L .40194 .72224 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.3945 .28229 m .42894 .27003 L .43439 .26684 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.6055 .71771 m .57106 .72997 L .56561 .73316 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.57106 .27003 m .6055 .28229 L .59806 .27776 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.59806 .27776 m .56561 .26684 L .57106 .27003 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.28616 .38544 m .27072 .42167 L .27109 .42521 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.26206 .46211 m .27109 .42521 L .27072 .42167 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.26123 .53976 m .27072 .57833 L .27109 .57479 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.27109 .57479 m .26206 .53789 L .26123 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.73794 .53789 m .72891 .57479 L .72928 .57833 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.71384 .61456 m .72928 .57833 L .72891 .57479 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.72891 .42521 m .73794 .46211 L .73877 .46024 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.73877 .46024 m .72928 .42167 L .72891 .42521 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.27072 .42167 m .26123 .46024 L .26206 .46211 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.25902 .5 m .26206 .46211 L .26123 .46024 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.25803 .5 m .26123 .53976 L .26206 .53789 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.26206 .53789 m .25902 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.73794 .46211 m .74098 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.74197 .5 m .73877 .46024 L .73794 .46211 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.74098 .5 m .73794 .53789 L .73877 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.72928 .57833 m .73877 .53976 L .73794 .53789 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.26123 .46024 m .25803 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.73877 .53976 m .74197 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.52817 .73933 m .557 .73607 L .56561 .73316 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.557 .73607 m .52817 .73933 L .5224 .74056 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.45445 .73853 m .4776 .74056 L .47183 .73933 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.47183 .73933 m .443 .73607 L .45445 .73853 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.52817 .26067 m .557 .26393 L .54555 .26147 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.54555 .26147 m .5224 .25944 L .52817 .26067 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.443 .26393 m .47183 .26067 L .4776 .25944 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.47183 .26067 m .443 .26393 L .43439 .26684 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.5224 .74056 m .54555 .73853 L .557 .73607 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.54555 .73853 m .5224 .74056 L .51556 .74148 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.46823 .7404 m .48444 .74148 L .4776 .74056 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.4776 .74056 m .45445 .73853 L .46823 .7404 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.5224 .25944 m .54555 .26147 L .53177 .2596 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.53177 .2596 m .51556 .25852 L .5224 .25944 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.45445 .26147 m .4776 .25944 L .48444 .25852 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.4776 .25944 m .45445 .26147 L .443 .26393 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.37097 .70507 m .40194 .72224 L .3945 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.3945 .71771 m .36207 .69962 L .37097 .70507 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.43439 .26684 m .40194 .27776 L .3945 .28229 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.36207 .30038 m .3945 .28229 L .40194 .27776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63793 .69962 m .6055 .71771 L .59806 .72224 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.56561 .73316 m .59806 .72224 L .6055 .71771 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.6055 .28229 m .63793 .30038 L .62903 .29493 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.62903 .29493 m .59806 .27776 L .6055 .28229 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.51556 .74148 m .53177 .7404 L .54555 .73853 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.53177 .7404 m .51556 .74148 L .50797 .74206 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48368 .74157 m .49203 .74206 L .48444 .74148 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48444 .74148 m .46823 .7404 L .48368 .74157 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51556 .25852 m .53177 .2596 L .51632 .25843 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51632 .25843 m .50797 .25794 L .51556 .25852 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.46823 .2596 m .48444 .25852 L .49203 .25794 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.48444 .25852 m .46823 .2596 L .45445 .26147 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.50797 .74206 m .51632 .74157 L .53177 .7404 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.51632 .74157 m .50797 .74206 L .5 .74225 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.5 .74197 m .5 .74225 L .49203 .74206 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.49203 .74206 m .48368 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50797 .25794 m .51632 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.5 .25803 m .5 .25775 L .50797 .25794 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.49203 .25794 m .48368 .25843 L .46823 .2596 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.48368 .25843 m .49203 .25794 L .5 .25775 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.41427 .7264 m .443 .73607 L .43439 .73316 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.43439 .73316 m .40194 .72224 L .41427 .7264 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .56561 .73316 L .557 .73607 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.40194 .27776 m .43439 .26684 L .443 .26393 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.56561 .26684 m .59806 .27776 L .58573 .2736 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.58573 .2736 m .557 .26393 L .56561 .26684 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.5 .74225 m .5 .74197 L .51632 .74157 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.5 .25775 m .5 .25803 L .48368 .25843 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.34248 .68188 m .37097 .70507 L .36207 .69962 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.36207 .69962 m .33261 .67601 L .34248 .68188 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.40194 .27776 m .37097 .29493 L .36207 .30038 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.33261 .32399 m .36207 .30038 L .37097 .29493 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .62903 .70507 L .63793 .69962 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.66739 .67601 m .63793 .69962 L .62903 .70507 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.63793 .30038 m .66739 .32399 L .65752 .31812 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.65752 .31812 m .62903 .29493 L .63793 .30038 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.557 .73607 m .58573 .7264 L .59806 .72224 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.58573 .7264 m .557 .73607 L .54555 .73853 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.43113 .72997 m .45445 .73853 L .443 .73607 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.443 .73607 m .41427 .7264 L .43113 .72997 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.557 .26393 m .58573 .2736 L .56887 .27003 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.56887 .27003 m .54555 .26147 L .557 .26393 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.443 .26393 m .41427 .2736 L .40194 .27776 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.41427 .2736 m .443 .26393 L .45445 .26147 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.31748 .65312 m .34248 .68188 L .33261 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.33261 .67601 m .30703 .64742 L .31748 .65312 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.37097 .29493 m .34248 .31812 L .33261 .32399 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.30703 .35258 m .33261 .32399 L .34248 .31812 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.69297 .64742 m .66739 .67601 L .65752 .68188 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.62903 .70507 m .65752 .68188 L .66739 .67601 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.66739 .32399 m .69297 .35258 L .68252 .34688 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.68252 .34688 m .65752 .31812 L .66739 .32399 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.38653 .71016 m .41427 .7264 L .40194 .72224 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.40194 .72224 m .37097 .70507 L .38653 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.62903 .70507 m .59806 .72224 L .58573 .7264 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.37097 .29493 m .40194 .27776 L .41427 .2736 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.59806 .27776 m .62903 .29493 L .61347 .28984 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.61347 .28984 m .58573 .2736 L .59806 .27776 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.34248 .31812 m .31748 .34688 L .30703 .35258 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.28616 .38544 m .30703 .35258 L .31748 .34688 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.2969 .61949 m .31748 .65312 L .30703 .64742 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.30703 .64742 m .28616 .61456 L .2969 .61949 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.54555 .73853 m .56887 .72997 L .58573 .7264 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.56887 .72997 m .54555 .73853 L .53177 .7404 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.69297 .35258 m .71384 .38544 L .7031 .38051 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.7031 .38051 m .68252 .34688 L .69297 .35258 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.71384 .61456 m .69297 .64742 L .68252 .65312 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.65752 .68188 m .68252 .65312 L .69297 .64742 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54555 .26147 m .56887 .27003 L .54823 .2673 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54823 .2673 m .53177 .2596 L .54555 .26147 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45177 .7327 m .46823 .7404 L .45445 .73853 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45445 .73853 m .43113 .72997 L .45177 .7327 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.43113 .27003 m .45445 .26147 L .46823 .2596 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.45445 .26147 m .43113 .27003 L .41427 .2736 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.31748 .34688 m .2969 .38051 L .28616 .38544 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.27072 .42167 m .28616 .38544 L .2969 .38051 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28156 .58196 m .2969 .61949 L .28616 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28616 .61456 m .27072 .57833 L .28156 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.72928 .57833 m .71384 .61456 L .7031 .61949 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.68252 .65312 m .7031 .61949 L .71384 .61456 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71384 .38544 m .72928 .42167 L .71844 .41804 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71844 .41804 m .7031 .38051 L .71384 .38544 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.53177 .7404 m .54823 .7327 L .56887 .72997 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.54823 .7327 m .53177 .7404 L .51632 .74157 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53177 .2596 m .54823 .2673 L .52483 .26557 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.52483 .26557 m .51632 .25843 L .53177 .2596 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.47517 .73443 m .48368 .74157 L .46823 .7404 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.46823 .7404 m .45177 .7327 L .47517 .73443 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.45177 .2673 m .46823 .2596 L .48368 .25843 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.46823 .2596 m .45177 .2673 L .43113 .27003 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27208 .54168 m .28156 .58196 L .27072 .57833 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27072 .57833 m .26123 .53976 L .27208 .54168 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.2969 .38051 m .28156 .41804 L .27072 .42167 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.26123 .46024 m .27072 .42167 L .28156 .41804 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.36072 .68742 m .38653 .71016 L .37097 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.37097 .70507 m .34248 .68188 L .36072 .68742 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72928 .42167 m .73877 .46024 L .72792 .45832 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72792 .45832 m .71844 .41804 L .72928 .42167 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.73877 .53976 m .72928 .57833 L .71844 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.7031 .61949 m .71844 .58196 L .72928 .57833 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.65752 .68188 m .62903 .70507 L .61347 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.58573 .7264 m .61347 .71016 L .62903 .70507 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.41427 .2736 m .38653 .28984 L .37097 .29493 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.34248 .31812 m .37097 .29493 L .38653 .28984 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.62903 .29493 m .65752 .31812 L .63928 .31258 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.63928 .31258 m .61347 .28984 L .62903 .29493 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.51632 .74157 m .52483 .73443 L .54823 .7327 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.52483 .73443 m .51632 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.5 .73502 m .5 .74197 L .48368 .74157 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.48368 .74157 m .47517 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.51632 .25843 m .52483 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .26498 m .5 .25803 L .51632 .25843 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.47517 .26557 m .48368 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.48368 .25843 m .47517 .26557 L .45177 .2673 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.61347 .71016 m .58573 .7264 L .56887 .72997 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.40837 .71456 m .43113 .72997 L .41427 .7264 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.41427 .7264 m .38653 .71016 L .40837 .71456 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.58573 .2736 m .61347 .28984 L .59163 .28544 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.59163 .28544 m .56887 .27003 L .58573 .2736 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.38653 .28984 m .41427 .2736 L .43113 .27003 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.28156 .41804 m .27208 .45832 L .26123 .46024 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.25803 .5 m .26123 .46024 L .27208 .45832 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26887 .5 m .27208 .54168 L .26123 .53976 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26123 .53976 m .25803 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73877 .46024 m .74197 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73113 .5 m .72792 .45832 L .73877 .46024 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.74197 .5 m .73877 .53976 L .72792 .54168 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.71844 .58196 m .72792 .54168 L .73877 .53976 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.27208 .45832 m .26887 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.5 .74197 m .5 .73502 L .52483 .73443 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.72792 .54168 m .73113 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .25803 m .5 .26498 L .47517 .26557 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.33783 .65855 m .36072 .68742 L .34248 .68188 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.34248 .68188 m .31748 .65312 L .33783 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.68252 .65312 m .65752 .68188 L .63928 .68742 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.61347 .71016 m .63928 .68742 L .65752 .68188 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.38653 .28984 m .36072 .31258 L .34248 .31812 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.31748 .34688 m .34248 .31812 L .36072 .31258 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.65752 .31812 m .68252 .34688 L .66217 .34145 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.66217 .34145 m .63928 .31258 L .65752 .31812 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.56887 .72997 m .59163 .71456 L .61347 .71016 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.59163 .71456 m .56887 .72997 L .54823 .7327 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56887 .27003 m .59163 .28544 L .56441 .28202 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56441 .28202 m .54823 .2673 L .56887 .27003 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43559 .71798 m .45177 .7327 L .43113 .72997 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43113 .72997 m .40837 .71456 L .43559 .71798 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.40837 .28544 m .43113 .27003 L .45177 .2673 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.43113 .27003 m .40837 .28544 L .38653 .28984 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.63928 .68742 m .61347 .71016 L .59163 .71456 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61347 .28984 m .63928 .31258 L .61301 .30773 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61301 .30773 m .59163 .28544 L .61347 .28984 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38699 .69227 m .40837 .71456 L .38653 .71016 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38653 .71016 m .36072 .68742 L .38699 .69227 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.36072 .31258 m .38653 .28984 L .40837 .28544 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.36072 .31258 m .33783 .34145 L .31748 .34688 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.2969 .38051 m .31748 .34688 L .33783 .34145 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31882 .62423 m .33783 .65855 L .31748 .65312 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31748 .65312 m .2969 .61949 L .31882 .62423 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68252 .34688 m .7031 .38051 L .68118 .37577 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68118 .37577 m .66217 .34145 L .68252 .34688 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.7031 .61949 m .68252 .65312 L .66217 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.63928 .68742 m .66217 .65855 L .68252 .65312 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.54823 .7327 m .56441 .71798 L .59163 .71456 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.56441 .71798 m .54823 .7327 L .52483 .73443 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.46675 .72014 m .47517 .73443 L .45177 .7327 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.45177 .7327 m .43559 .71798 L .46675 .72014 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.54823 .2673 m .56441 .28202 L .53325 .27986 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.53325 .27986 m .52483 .26557 L .54823 .2673 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.43559 .28202 m .45177 .2673 L .47517 .26557 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.45177 .2673 m .43559 .28202 L .40837 .28544 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.52483 .73443 m .53325 .72014 L .56441 .71798 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.53325 .72014 m .52483 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.5 .72088 m .5 .73502 L .47517 .73443 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.47517 .73443 m .46675 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.52483 .26557 m .53325 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.5 .27912 m .5 .26498 L .52483 .26557 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.46675 .27986 m .47517 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.47517 .26557 m .46675 .27986 L .43559 .28202 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.30454 .58546 m .31882 .62423 L .2969 .61949 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.2969 .61949 m .28156 .58196 L .30454 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.71844 .58196 m .7031 .61949 L .68118 .62423 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.66217 .65855 m .68118 .62423 L .7031 .61949 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.33783 .34145 m .31882 .37577 L .2969 .38051 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.28156 .41804 m .2969 .38051 L .31882 .37577 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.7031 .38051 m .71844 .41804 L .69546 .41454 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.69546 .41454 m .68118 .37577 L .7031 .38051 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.5 .73502 m .5 .72088 L .53325 .72014 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5 .26498 m .5 .27912 L .46675 .27986 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.66217 .65855 m .63928 .68742 L .61301 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.59163 .71456 m .61301 .69227 L .63928 .68742 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63928 .31258 m .66217 .34145 L .63214 .33666 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63214 .33666 m .61301 .30773 L .63928 .31258 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.40837 .28544 m .38699 .30773 L .36072 .31258 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.33783 .34145 m .36072 .31258 L .38699 .30773 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36786 .66334 m .38699 .69227 L .36072 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36072 .68742 m .33783 .65855 L .36786 .66334 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.61301 .69227 m .59163 .71456 L .56441 .71798 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.29568 .54355 m .30454 .58546 L .28156 .58196 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.28156 .58196 m .27208 .54168 L .29568 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.72792 .54168 m .71844 .58196 L .69546 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.68118 .62423 m .69546 .58546 L .71844 .58196 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.59163 .28544 m .61301 .30773 L .57974 .30395 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.57974 .30395 m .56441 .28202 L .59163 .28544 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.42026 .69605 m .43559 .71798 L .40837 .71456 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.40837 .71456 m .38699 .69227 L .42026 .69605 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.31882 .37577 m .30454 .41454 L .28156 .41804 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.27208 .45832 m .28156 .41804 L .30454 .41454 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.71844 .41804 m .72792 .45832 L .70432 .45645 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.70432 .45645 m .69546 .41454 L .71844 .41804 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.38699 .30773 m .40837 .28544 L .43559 .28202 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.30454 .41454 m .29568 .45645 L .27208 .45832 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.26887 .5 m .27208 .45832 L .29568 .45645 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.29268 .5 m .29568 .54355 L .27208 .54168 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.27208 .54168 m .26887 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.72792 .45832 m .73113 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.70732 .5 m .70432 .45645 L .72792 .45832 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.73113 .5 m .72792 .54168 L .70432 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.69546 .58546 m .70432 .54355 L .72792 .54168 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69788 .62492 m
.70966 .59837 L
s
.5 Mabswid
.438 .56 .442 r
.29568 .45645 m .29268 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.70432 .54355 m .70732 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29405 .60449 m
.30657 .62596 L
s
.28075 .58167 m
.29275 .60226 L
s
.29275 .60226 m
.29405 .60449 L
s
.28927 .59815 m
.30148 .6003 L
s
.71361 .58718 m
.71545 .58463 L
s
.71512 .58242 m
.71545 .58463 L
s
.30383 .60701 m
.30657 .62596 L
s
.30327 .6031 m
.30383 .60701 L
s
.71325 .58501 m
.71361 .58718 L
s
.71325 .58501 m
.71512 .58242 L
s
.5 Mabswid
.565 .775 .569 r
.56441 .71798 m .57974 .69605 L .61301 .69227 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.56441 .28202 m .57974 .30395 L .54126 .30153 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.54126 .30153 m .53325 .27986 L .56441 .28202 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.57974 .69605 m .56441 .71798 L .53325 .72014 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.45874 .69847 m .46675 .72014 L .43559 .71798 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.43559 .71798 m .42026 .69605 L .45874 .69847 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.42026 .30395 m .43559 .28202 L .46675 .27986 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.43559 .28202 m .42026 .30395 L .38699 .30773 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.66217 .34145 m .68118 .37577 L .64816 .37157 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.64816 .37157 m .63214 .33666 L .66217 .34145 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.68118 .62423 m .66217 .65855 L .63214 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.61301 .69227 m .63214 .66334 L .66217 .65855 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.38699 .30773 m .36786 .33666 L .33783 .34145 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.31882 .37577 m .33783 .34145 L .36786 .33666 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.35184 .62843 m .36786 .66334 L .33783 .65855 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.33783 .65855 m .31882 .62423 L .35184 .62843 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.63214 .66334 m .61301 .69227 L .57974 .69605 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.61301 .30773 m .63214 .33666 L .59355 .33289 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.59355 .33289 m .57974 .30395 L .61301 .30773 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.36786 .33666 m .38699 .30773 L .42026 .30395 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.40645 .66711 m .42026 .69605 L .38699 .69227 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.38699 .69227 m .36786 .66334 L .40645 .66711 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.53325 .72014 m .54126 .69847 L .57974 .69605 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.54126 .69847 m .53325 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.5 .6993 m .5 .72088 L .46675 .72014 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.46675 .72014 m .45874 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.53325 .27986 m .54126 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.5 .3007 m .5 .27912 L .53325 .27986 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45874 .30153 m .46675 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.46675 .27986 m .45874 .30153 L .42026 .30395 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69373 .61267 m
.69671 .60847 L
s
.5 Mabswid
.304 .342 .242 r
.5 .27912 m .5 .3007 L .45874 .30153 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.5 .72088 m .5 .6993 L .54126 .69847 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.69546 .58546 m .68118 .62423 L .64816 .62843 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68869 .6153 m
.69373 .61267 L
s
.5 Mabswid
.543 .728 .52 r
.63214 .66334 m .64816 .62843 L .68118 .62423 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.68118 .37577 m .69546 .41454 L .66026 .41141 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.66026 .41141 m .64816 .37157 L .68118 .37577 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.33974 .58859 m .35184 .62843 L .31882 .62423 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.31882 .62423 m .30454 .58546 L .33974 .58859 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.36786 .33666 m .35184 .37157 L .31882 .37577 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.30454 .41454 m .31882 .37577 L .35184 .37157 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70222 .59339 m
.70298 .59108 L
s
.6993 .5981 m
.70222 .59339 L
s
.70298 .59108 m
.70308 .58652 L
s
.69568 .60072 m
.6993 .5981 L
s
.68417 .61598 m
.68869 .6153 L
s
.5 Mabswid
.525 .685 .48 r
.70432 .54355 m .69546 .58546 L .66026 .58859 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6994 .58462 m
.70308 .58652 L
s
.5 Mabswid
.54 .713 .505 r
.64816 .62843 m .66026 .58859 L .69546 .58546 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68013 .61469 m
.68417 .61598 L
s
.68723 .60392 m
.69568 .60072 L
s
.5 Mabswid
.428 .533 .361 r
.69546 .41454 m .70432 .45645 L .6678 .45478 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.6678 .45478 m .66026 .41141 L .69546 .41454 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.3322 .54522 m .33974 .58859 L .30454 .58546 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.30454 .58546 m .29568 .54355 L .3322 .54522 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3006 .58462 m
.30196 .59404 L
s
.30196 .59404 m
.30327 .6031 L
s
.5 Mabswid
.43 .529 .404 r
.35184 .37157 m .33974 .41141 L .30454 .41454 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.29568 .45645 m .30454 .41454 L .33974 .41141 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69469 .58515 m
.6994 .58462 L
s
.30695 .58533 m
.31497 .60902 L
s
.31497 .60902 m
.3174 .61621 L
s
.5 Mabswid
.594 .801 .583 r
.57974 .69605 m .59355 .66711 L .63214 .66334 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.59355 .66711 m .57974 .69605 L .54126 .69847 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.57974 .30395 m .59355 .33289 L .54851 .33047 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.54851 .33047 m .54126 .30153 L .57974 .30395 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.45149 .66953 m .45874 .69847 L .42026 .69605 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.42026 .69605 m .40645 .66711 L .45149 .66953 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.40645 .33289 m .42026 .30395 L .45874 .30153 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.42026 .30395 m .40645 .33289 L .36786 .33666 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68318 .60648 m
.68723 .60392 L
s
.31277 .60392 m
.31669 .61045 L
s
.31669 .61045 m
.32154 .61491 L
s
.67998 .61087 m
.68013 .61469 L
s
.5 Mabswid
.389 .466 .316 r
.63214 .33666 m .64816 .37157 L .60519 .36823 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.60519 .36823 m .59355 .33289 L .63214 .33666 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.64816 .62843 m .63214 .66334 L .59355 .66711 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.35184 .37157 m .36786 .33666 L .40645 .33289 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.39481 .63177 m .40645 .66711 L .36786 .66334 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.36786 .66334 m .35184 .62843 L .39481 .63177 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.70432 .45645 m .70732 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.67037 .5 m .6678 .45478 L .70432 .45645 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.70732 .5 m .70432 .54355 L .6678 .54522 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.66026 .58859 m .6678 .54522 L .70432 .54355 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68898 .58816 m
.69469 .58515 L
s
.5 Mabswid
.483 .607 .465 r
.33974 .41141 m .3322 .45478 L .29568 .45645 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.29268 .5 m .29568 .45645 L .3322 .45478 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.32963 .5 m .3322 .54522 L .29568 .54355 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.29568 .54355 m .29268 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32154 .61491 m
.32573 .61731 L
s
.67998 .61087 m
.68318 .60648 L
s
.5 Mabswid
.501 .645 .448 r
.6678 .54522 m .67037 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.3322 .45478 m .32963 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32573 .61731 m
.33111 .61795 L
s
.68585 .59317 m
.68898 .58816 L
s
.5 Mabswid
.63 .845 .621 r
.54126 .69847 m .54851 .66953 L .59355 .66711 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.54851 .66953 m .54126 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.54126 .30153 m .54851 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.5 .32963 m .5 .3007 L .54126 .30153 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.5 .67037 m .5 .6993 L .45874 .69847 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.45874 .69847 m .45149 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.45149 .33047 m .45874 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.45874 .30153 m .45149 .33047 L .40645 .33289 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.5 .6993 m .5 .67037 L .54851 .66953 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.5 .3007 m .5 .32963 L .45149 .33047 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66659 .61436 m
.66993 .61001 L
s
.66993 .61001 m
.67135 .60571 L
s
.66395 .61659 m
.66659 .61436 L
s
.5 Mabswid
.448 .551 .38 r
.64816 .37157 m .66026 .41141 L .61402 .40892 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.61402 .40892 m .60519 .36823 L .64816 .37157 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.66026 .58859 m .64816 .62843 L .60519 .63177 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65932 .61898 m
.66395 .61659 L
s
.5 Mabswid
.601 .8 .579 r
.59355 .66711 m .60519 .63177 L .64816 .62843 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.40645 .33289 m .39481 .36823 L .35184 .37157 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.33974 .41141 m .35184 .37157 L .39481 .36823 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.38598 .59108 m .39481 .63177 L .35184 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.35184 .62843 m .33974 .58859 L .38598 .59108 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65322 .61957 m
.65932 .61898 L
s
.67215 .58968 m
.6748 .59424 L
s
.33654 .60646 m
.34062 .61309 L
s
.34062 .61309 m
.34611 .61757 L
s
.5 Mabswid
.434 .527 .367 r
.59355 .33289 m .60519 .36823 L .55465 .36608 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.55465 .36608 m .54851 .33047 L .59355 .33289 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.60519 .63177 m .59355 .66711 L .54851 .66953 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.39481 .36823 m .40645 .33289 L .45149 .33047 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.44535 .63392 m .45149 .66953 L .40645 .66711 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.40645 .66711 m .39481 .63177 L .44535 .63392 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3352 .60197 m
.33654 .60646 L
s
.64966 .61795 m
.65322 .61957 L
s
.66867 .58748 m
.67215 .58968 L
s
.3352 .60197 m
.33531 .59509 L
s
.34611 .61757 m
.35099 .61995 L
s
.35099 .61995 m
.35753 .62051 L
s
.33531 .59509 m
.33835 .59048 L
s
.5 Mabswid
.494 .619 .432 r
.66026 .41141 m .6678 .45478 L .61955 .45345 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.61955 .45345 m .61402 .40892 L .66026 .41141 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.6678 .54522 m .66026 .58859 L .61402 .59108 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66226 .58794 m
.66867 .58748 L
s
.5 Mabswid
.596 .783 .563 r
.60519 .63177 m .61402 .59108 L .66026 .58859 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64659 .61419 m
.64966 .61795 L
s
.64622 .60787 m
.67135 .60571 L
s
.5 Mabswid
.618 .805 .609 r
.38045 .54655 m .38598 .59108 L .33974 .58859 L p F P
.505 .664 .505 r
s
.618 .805 .609 r
.33974 .58859 m .3322 .54522 L .38045 .54655 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.39481 .36823 m .38598 .40892 L .33974 .41141 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.3322 .45478 m .33974 .41141 L .38598 .40892 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35753 .62051 m
.36141 .61885 L
s
.64622 .60787 m
.64659 .61419 L
s
.33835 .59048 m
.34217 .58824 L
s
.65724 .59078 m
.66226 .58794 L
s
.36141 .61885 m
.36485 .61504 L
s
.62228 .63487 m
.62826 .61152 L
s
.64622 .60787 m
.64744 .60333 L
s
.65152 .59605 m
.65724 .59078 L
s
.34217 .58824 m
.34905 .58867 L
s
.5 Mabswid
.634 .841 .614 r
.54851 .66953 m .55465 .63392 L .60519 .63177 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.54851 .33047 m .55465 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.5 .36534 m .5 .32963 L .54851 .33047 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.55465 .63392 m .54851 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.44535 .36608 m .45149 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.5 .63466 m .5 .67037 L .45149 .66953 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.45149 .66953 m .44535 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.45149 .33047 m .44535 .36608 L .39481 .36823 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64744 .60333 m
.65152 .59605 L
s
.5 Mabswid
.53 .674 .475 r
.6678 .45478 m .67037 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.62143 .5 m .61955 .45345 L .6678 .45478 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.67037 .5 m .6678 .54522 L .61955 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.61402 .59108 m .61955 .54655 L .6678 .54522 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62826 .61152 m
.63387 .58961 L
s
.5 Mabswid
.531 .669 .502 r
.38598 .40892 m .38045 .45345 L .3322 .45478 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.32963 .5 m .3322 .45478 L .38045 .45345 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.37857 .5 m .38045 .54655 L .3322 .54522 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.3322 .54522 m .32963 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3765 .5901 m
.38128 .61031 L
s
.38128 .61031 m
.38242 .61516 L
s
.34905 .58867 m
.35434 .59151 L
s
.5 Mabswid
.465 .568 .41 r
.5 .32963 m .5 .36534 L .44535 .36608 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.61955 .54655 m .62143 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.5 .67037 m .5 .63466 L .55465 .63392 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.38045 .45345 m .37857 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.61402 .59108 m .60519 .63177 L .55465 .63392 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.60519 .36823 m .61402 .40892 L .55932 .4073 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.55932 .4073 m .55465 .36608 L .60519 .36823 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.44068 .5927 m .44535 .63392 L .39481 .63177 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.39481 .63177 m .38598 .59108 L .44068 .5927 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38242 .61516 m
.38724 .63554 L
s
.5 Mabswid
.51 .634 .467 r
.38598 .40892 m .39481 .36823 L .44535 .36608 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62196 .62 m
.62797 .61552 L
s
.35434 .59151 m
.36027 .59679 L
s
.61646 .62234 m
.62196 .62 L
s
.60885 .62278 m
.61646 .62234 L
s
.38145 .61397 m
.39066 .62074 L
s
.60414 .62101 m
.60885 .62278 L
s
.62825 .59245 m
.63232 .59721 L
s
.39066 .62074 m
.39633 .62305 L
s
.39633 .62305 m
.40427 .62344 L
s
.59973 .61707 m
.60414 .62101 L
s
.6235 .5901 m
.62825 .59245 L
s
.40427 .62344 m
.40925 .62164 L
s
.43413 .63788 m
.4372 .63974 L
s
.4372 .63974 m
.43967 .63806 L
s
.43413 .63788 m
.43659 .63617 L
s
.40925 .62164 m
.41079 .61536 L
s
.5 Mabswid
.531 .669 .476 r
.61402 .40892 m .61955 .45345 L .56224 .45258 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.56224 .45258 m .55932 .4073 L .61402 .40892 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.61955 .54655 m .61402 .59108 L .55932 .5927 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61546 .59044 m
.6235 .5901 L
s
.5 Mabswid
.627 .823 .598 r
.55465 .63392 m .55932 .5927 L .61402 .59108 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59831 .61056 m
.59973 .61707 L
s
.5 Mabswid
.633 .824 .615 r
.43776 .54742 m .44068 .5927 L .38598 .59108 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.38598 .59108 m .38045 .54655 L .43776 .54742 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.44535 .36608 m .44068 .4073 L .38598 .40892 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.38045 .45345 m .38598 .40892 L .44068 .4073 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43659 .63617 m
.43967 .63806 L
s
.5 Mabswid
.644 .844 .62 r
.55932 .5927 m .55465 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.5 .59326 m .5 .63466 L .44535 .63392 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.44535 .63392 m .44068 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.55465 .36608 m .55932 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.5 .40674 m .5 .36534 L .55465 .36608 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.44068 .4073 m .44535 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59831 .61056 m
.59915 .60594 L
s
.60955 .59326 m
.61546 .59044 L
s
.40702 .59124 m
.41079 .61536 L
s
.59915 .60594 m
.60317 .59855 L
s
.60317 .59855 m
.60955 .59326 L
s
.56807 .62452 m
.57408 .62227 L
s
.57408 .62227 m
.57725 .62008 L
s
.57725 .62008 m
.58078 .61567 L
s
.55947 .62477 m
.56807 .62452 L
s
.58078 .61567 m
.58149 .6112 L
s
.43076 .59187 m
.43382 .61674 L
s
.43382 .61674 m
.43478 .62461 L
s
.5 Mabswid
.644 .844 .62 r
.5 .63466 m .5 .59326 L .55932 .5927 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.5 .36534 m .5 .40674 L .44068 .4073 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.55391 .62286 m
.55947 .62477 L
s
.54611 .6121 m
.58149 .6112 L
s
.5 Mabswid
.565 .719 .515 r
.61955 .45345 m .62143 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.56324 .5 m .56224 .45258 L .61955 .45345 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.62143 .5 m .61955 .54655 L .56224 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.55932 .5927 m .56224 .54742 L .61955 .54655 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.44068 .4073 m .43776 .45258 L .38045 .45345 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.37857 .5 m .38045 .45345 L .43776 .45258 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.43676 .5 m .43776 .54742 L .38045 .54655 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.38045 .54655 m .37857 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.54848 .61874 m
.55391 .62286 L
s
.57797 .59429 m
.58322 .59924 L
s
.47293 .6254 m
.48192 .62549 L
s
.46681 .62325 m
.47293 .6254 L
s
.54611 .6121 m
.54848 .61874 L
s
.5 Mabswid
.591 .761 .548 r
.56224 .54742 m .56324 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.43776 .45258 m .43676 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4573 .61666 m
.46681 .62325 L
s
.48192 .62549 m
.48788 .62346 L
s
.51507 .62551 m
.52118 .62339 L
s
.50603 .62555 m
.51507 .62551 L
s
.5 .62349 m
.50603 .62555 L
s
.52118 .62339 m
.52452 .61691 L
s
.48788 .62346 m
.49079 .61702 L
s
.49079 .61702 m
.5 .62349 L
s
.57226 .5918 m
.57797 .59429 L
s
.54611 .6121 m
.54651 .60742 L
s
.5 Mabswid
.551 .695 .501 r
.55932 .4073 m .56224 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.5 .45228 m .5 .40674 L .55932 .4073 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.56224 .54742 m .55932 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.43776 .45258 m .44068 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.5 .54772 m .5 .59326 L .44068 .5927 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45763 .61972 m
.45807 .62517 L
s
.5 Mabswid
.636 .826 .61 r
.44068 .5927 m .43776 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45547 .59232 m
.45763 .61972 L
s
.49039 .59261 m
.49079 .61702 L
s
.54651 .60742 m
.55018 .60001 L
s
.56314 .592 m
.57226 .5918 L
s
.55018 .60001 m
.55676 .59476 L
s
.55676 .59476 m
.56314 .592 L
s
.5 Mabswid
.629 .817 .597 r
.5 .59326 m .5 .54772 L .56224 .54742 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.52452 .61691 m
.52557 .59252 L
s
.5 Mabswid
.558 .704 .514 r
.5 .40674 m .5 .45228 L .43776 .45258 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.56224 .45258 m .56324 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.5 .5 m .5 .45228 L .56224 .45258 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.56324 .5 m .56224 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.43676 .5 m .43776 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.5 .5 m .5 .54772 L .43776 .54742 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.43776 .54742 m .43676 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.5 .54772 m .5 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.5 .45228 m .5 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageMargins->{{1, 0}, {0, 1}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>h0/>3V5`21ZH7^0;3PiP40oooo003V0;3PiPP0PJV10P0R9A`0
0`21ZH4092LN02@W7P0602@W7P03086YP@0U:1h09BPN00H09BPN00<0PJV102<V7@0S9Qd02021ZH7V
0;3PiP40oooo003P0;3PiPH0PJV100<0720H086YP@21ZH401P0R9A`00`21ZH4092LN02@W7P0702@W
7P03086YP@0U:1h09BPN00L09BPN00<0PJV102<V7@0S9Qd0100S9Qd2086YP@0301lR6P21ZH40PJV1
00@0PJV1h02`h>H10?ooo`00g02`h>H5086YP@@0720H0P21ZH47028U7003086YP@0T9ah092LN00P0
92LN00<0PJV102DX7P0U:1h0200U:1h00`21ZH408bHM02<V7@0502<V7@80PJV1100O8QX5086YPM`0
/>3V0@3oool00=T0/>3V1@21ZH4501`P6080PJV10`0R9A`S086YP@<08bHM0P21ZH4501lR6PD0PJV1
f@2`h>H10?ooo`00eP2`h>H2086YP@0301DI4`21ZH40PJV10080720H2`21ZH4403<d:003086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@0203Df:@/0PJV100<0
7b8J086YP@21ZH401021ZH7F0;3PiP40oooo003C0;3PiPX0PJV10`0];b@00`21ZH40<c@X03<d:009
03<d:003086YP@0f>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@09
03Df:@04086YP@0`<RH0<38V030b9PX0PJV1d`2`h>H10?ooo`00d02`h>H7086YP@P0;BlT00<0PJV1
03<d:00c=2P02@0c=2P00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0g>2/0=cP[00/0=cP[00<0PJV1
03Df:@0e=RT02@0e=RT00`21ZH40<38V030b9P06030b9PL0PJV1d02`h>H10?ooo`00c@2`h>H4086Y
P@<092HM00<0PJV102d_900];b@01`0];b@00`21ZH40<c@X03<d:00903<d:003086YP@0f>2X0=SPZ
00`0=SPZ00<0PJV103Lh:`0g>2/0300g>2/00`21ZH40=CHY03Df:@0903Df:@03086YP@0`<RH0<38V
00L0<38V00@0PJV102P[800X:b00:2/P1021ZH7=0;3PiP40oooo003:0;3PiP@0PJV1100T9Qd2086Y
P@P0;BlT0P21ZH4;03<d:003086YP@0f>2X0=SPZ00d0=SPZ00<0PJV103Lh:`0g>2/03@0g>2/00`21
ZH40=CHY03Df:@0903Df:@80PJV1200`<RH2086YP@@0:2/P1021ZH7:0;3PiP40oooo00380;3PiP@0
PJV11@0T9Qd00`21ZH40;BlT02d_900702d_9003086YP@0c=2P0<c@X00/0<c@X00<0PJV103Hh:P0f
>2X03@0f>2X00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0e=RT0=CHY00/0=CHY00<0PJV1030b9P0`
<RH01`0`<RH00`21ZH40:2/P02P[800302P[80@0PJV1b02`h>H10?ooo`00aP2`h>H4086YP@D092HM
0P21ZH4902d_9003086YP@0c=2P0<c@X00@0<c@X<@21ZH4603Df:@03086YP@0`<RH0<38V00L0<38V
0P21ZH4502P[8080PJV100<07B0H086YP@2`h>H0a@2`h>H10?ooo`00a02`h>H2086YP@0301LK5021
ZH4092HM00D092HM00<0PJV102d_900];b@01@0];b@;086YP@L0B50i00<0PJV104eG?@1=Ecd03P1=
Ecd00`21ZH40CeTn04mI?P0>04mI?P03086YP@1<E3`0C5@l00D0C5@l2`21ZH47030b9P03086YP@0X
:b00:2/P00@0:2/P00@0PJV101dP6021ZH40PJV1a02`h>H10?ooo`00`P2`h>H2086YP@0301LK5021
ZH40PJV100D092HM0P21ZH400`0];b@0PJV1086YP@05086YP@80?D8`00<0PJV104Q@>@18D3T03018
D3T00`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<
E3`00`21ZH40@dXe04=:=@07086YP@03030b9P21ZH40PJV100D0:2/P0P21ZH400`0M81P0PJV1086Y
P@320;3PiP40oooo00300;3PiPD0PJV1100T9Qd6086YP@T0?D8`00<0PJV104Q@>@18D3T03018D3T0
0`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<E3`0
0`21ZH40@dXe04=:=@0704=:=@H0PJV1100X:b05086YPL00/>3V0@3oool00;h0/>3V2`21ZH400`0`
<BD0PJV103e2<00;03e2<003086YP@18D3T0B50i00d0B50i00<0PJV104eG?@1=Ecd03`1=Ecd00`21
ZH40CeTn04mI?P0?04mI?P03086YP@1<E3`0C5@l00d0C5@l00<0PJV104=:=@13BSD02P13BSD00`21
ZH40=SPZ086YP@0:086YPKh0/>3V0@3oool00;d0/>3V1P21ZH46030a9@03086YP@0m@S00?D8`00X0
?D8`00<0PJV104Q@>@18D3T03@18D3T00`21ZH40CELm04eG?@0@04eG?@03086YP@1?FCh0CeTn0100
CeTn00<0PJV104aD?01<E3`03@1<E3`00`21ZH40@dXe04=:=@0:04=:=@03086YP@0f>2X0=SPZ00@0
=SPZ1P21ZH6m0;3PiP40oooo002k0;3PiPD0PJV1200`<BD00`21ZH40?D8`03e2<00:03e2<003086Y
P@18D3T0B50i00h0B50i00<0PJV104eG?@1=Ecd0401=Ecd00`21ZH40CeTn04mI?P0@04mI?P03086Y
P@1<E3`0C5@l00h0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0603Hh:PD0PJV1
^`2`h>H10?ooo`00^@2`h>H4086YP@03028T7021ZH40<34U00L0<34U00<0PJV103e2<00m@S002`0m
@S000`21ZH40B50i04Q@>@0=04Q@>@03086YP@1=Ecd0CELm0140CELm00<0PJV104mI?P1?FCh04@1?
FCh00`21ZH40C5@l04aD?00=04aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f
>2X00`21ZH40:2/P086YP@03086YPKT0/>3V0@3oool00;L0/>3V1021ZH42028T7003086YP@0`<BD0
<34U00H0<34U00<0PJV103e2<00m@S002`0m@S000`21ZH40B50i04Q@>@0>04Q@>@03086YP@1=Ecd0
CELm0140CELm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40C5@l04aD?00>04aD?003086YP@13BSD0
@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f>2X2086YP@0302P[8021ZH40PJV10080PJV1]`2`h>H1
0?ooo`00]@2`h>H4086YP@<08R@L00<0PJV1030a9@0`<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2
<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=Ecd04@1=Ecd00`21ZH40CeTn04mI?P0A04mI
?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh
:P03086YP@0X:b00:2/P00@0PJV1]@2`h>H10?ooo`00]02`h>H3086YP@@08R@L00<0PJV1030a9@0`
<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=
Ecd04P1=Ecd00`21ZH40CeTn04mI?P0B04mI?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13
BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh:P04086YP@0X:b00:2/P02P[80<0PJV1]02`h>H10?oo
o`00/`2`h>H00`21ZH4041@?086YP@03028T7080PJV12@0`<BD00`21ZH40?D8`03e2<00;03e2<003
086YP@18D3T0B50i00H0B50i?@21ZH4804aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f
>2X0200f>2X01@21ZH40:2/P02P[800X:b00PJV1008061/D/`2`h>H10?ooo`00/@2`h>H4086YP@<0
8R@L00<0PJV1030a9@0`<BD0200`<BD00`21ZH40?D8`03e2<00803e2<0d0PJV12@1QLU<00`21ZH40
I7ME06AgE@0B06AgE@03086YP@1SME80HgEB0180HgEB00<0PJV105e]B`1MKD/01`1MKD/=086YP@X0
@dXe00<0PJV103Hh:P0f>2X0200f>2X01021ZH40:2/P02P[800X:b02086YP@0301PK5021ZH40/>3V
0;00/>3V0@3oool00;00/>3V00<0PJV1010D3`21ZH40100R91`00`21ZH40<34U030a9@08030a9@04
086YP@0m@S00?D8`03e2<0P0PJV10`1GIT/00`21ZH40HG9C065bD`0@065bD`03086YP@1TMeD0I7ME
0180I7ME00<0PJV106=eDP1SME804P1SME800`21ZH40GFe;05e]B`0@05e]B`04086YP@1FI4D0EVA5
05ITA@P0PJV10`13BSD00`21ZH40=SPZ03Hh:P0803Hh:P80PJV10`0X:b000`21ZH4061/D086YP@2`
0;3PiP40oooo002_0;3PiP03086YP@0@50l0PJV100@08R@L00<0PJV1030a9@0`<BD01@0`<BD8086Y
P@X0EfI;00<0PJV1065bD`1QLU<0401QLU<00`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB
01<0HgEB00<0PJV105e]B`1MKD/0401MKD/00`21ZH40EVA505ITA@0805ITA@P0PJV1200f>2X01`21
ZH40:2/P02P[800X:b00PJV101PK5021ZH40[`2`h>H10?ooo`00[P2`h>H3086YP@@08R@L00<0PJV1
030a9@0`<BD01P21ZH4204I??003086YP@1GIT/0EfI;00d0EfI;00<0PJV1065bD`1QLU<0401QLU<0
0`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB01<0HgEB00<0PJV105e]B`1MKD/0401MKD/0
0`21ZH40EVA505ITA@0=05ITA@03086YP@18DSX0B58j00L0PJV10P0f>2X01021ZH40:2/P02P[800X
:b03086YPJh0/>3V0@3oool00:`0/>3V0`21ZH44028T70D0PJV12016Cc`00`21ZH40EfI;05MVB`0<
05MVB`03086YP@1QLU<0HG9C0140HG9C00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgEB06=eDP0C
06=eDP03086YP@1MKD/0GFe;0140GFe;00<0PJV105ITA@1FI4D0301FI4D00`21ZH40B58j04QB>P07
04QB>PD0PJV10`0X:b03086YPJ`0/>3V0@3oool00:/0/>3V00<0PJV1010D3`21ZH400P0R91`4086Y
P@/0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01<0I7ME00<0PJV106=eDP1SME804`1SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00d0EVA500<0PJV104QB>P18DSX02P18DSX4086YP@0402P[8021ZH4061/D086YPJ/0/>3V0@3oool0
0:X0/>3V1P21ZH4202d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21
ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=eDP1SME804`1SME800`21
ZH40GFe;05e]B`0B05e]B`03086YP@1FI4D0EVA500d0EVA500<0PJV104QB>P18DSX02@18DSX01021
ZH40<cHX03<f:00c=RP5086YPJX0/>3V0@3oool00:T0/>3V0`21ZH4602d`9P03086YP@16Cc`0ATll
00P0ATll00<0PJV105MVB`1GIT/03P1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01@0I7ME00<0PJV106=eDP1SME80501SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00h0EVA500<0PJV104QB>P18DSX02@18DSX00`21ZH40<cHX03<f:00303<f:0<0PJV1Z@2`h>H10?oo
o`00Y`2`h>H3086YP@L0;C0V00<0PJV104I??016Cc`02@16Cc`00`21ZH40EfI;05MVB`0=05MVB`03
086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgEB06=eDP0D06=eDP03
086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03@1FI4D00`21ZH40B58j04QB>P0:04QB>P03
086YP@0c=RP0<cHX00@0<cHX0`21ZH6W0;3PiP40oooo002V0;3PiP<0PJV11`0]<2H00`21ZH40ATll
04I??00904I??003086YP@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04P1QLU<00`21ZH40I7ME
06AgE@0D06AgE@03086YP@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04P1MKD/00`21ZH40EVA5
05ITA@0>05ITA@03086YP@18DSX0B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP3086YPJH0/>3V
0@3oool00:D0/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H00`21ZH40ATll04I??00904I??003086Y
P@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04`1QLU<00`21ZH40I7ME06AgE@0D06AgE@03086Y
P@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04`1MKD/00`21ZH40EVA505ITA@0>05ITA@03086Y
P@18DSX0B58j00T0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6U0;3PiP40
oooo002T0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02P16Cc`00`21ZH40
EfI;05MVB`0>05MVB`03086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD05@1TMeD00`21ZH40
HgEB06=eDP0E06=eDP03086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03P1FI4D00`21ZH40
B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1Y02`h>H10?oo
o`00X`2`h>H01021ZH405QXC01HJ4`21ZH4702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MV
B`1GIT/03P1GIT/00`21ZH40HG9C065bD`0C065bD`03086YP@1TMeD0I7ME01D0I7ME00<0PJV106=e
DP1SME805@1SME800`21ZH40GFe;05e]B`0C05e]B`03086YP@1FI4D0EVA500h0EVA500<0PJV104QB
>P18DSX02P18DSX00`21ZH40<cHX03<f:00403<f:004086YP@0O8QX07b8J086YPJ<0/>3V0@3oool0
0:80/>3V00@0PJV101HJ4`0F6Q<0PJV11`0]<2H00`21ZH40ATll04I??00904I??003086YP@1GIT/0
EfI;00l0EfI;00<0PJV1065bD`1QLU<03P1QLU<k086YPA00GFe;00<0PJV105ITA@1FI4D03`1FI4D0
0`21ZH40B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1XP2`
h>H10?ooo`00XP2`h>H00`21ZH405QXC086YP@0702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV1
05MVB`1GIT/03`1GIT/00`21ZH40HG9C065bD`03065bD``0PJV11@1dSFL00`21ZH40Mi5X07NAJ00E
07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0PJV106n6G@1_QUd00`1_QUd<086YP@D0GFe;00<0PJV1
05ITA@1FI4D03`1FI4D00`21ZH40B58j04QB>P0904QB>P03086YP@0c=RP0<cHX00D0<cHX00<0PJV1
01lR6P21ZH40XP2`h>H10?ooo`00X@2`h>H01021ZH405QXC01HJ4`21ZH4602d`9P03086YP@16Cc`0
ATll00X0ATll00<0PJV105MVB`1GIT/01P1GIT/?086YPA40M8eW00<0PJV107NAJ01gTFP05@1gTFP0
0`21ZH40MHmU07F?I@0E07F?I@03086YP@1_QUd0KhIM00l0KhIM3`21ZH4805ITA@03086YP@18DSX0
B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6Q0;3PiP40oooo002P
0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02016Cc`<086YP@T0K8=Q00<0
PJV107B=I`1dSFL04`1dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0
PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00706=gD0`0PJV12P18DSX00`21ZH40<cHX03<f
:00403<f:004086YP@0O8QX07b8J086YPJ00/>3V0@3oool009l0/>3V00@0PJV101HJ4`0F6Q<0PJV1
1`0]<2H00`21ZH40ATll04I??00304I??0D0PJV10P1LKU@00`21ZH40K8=Q06b3H@0?06b3H@03086Y
P@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40MHmU07F?I@0F07F?I@03086Y
P@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe003`1SMe000`21ZH40EfM705MWA`05086YP@H0B58j
00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6O0;3PiP40oooo002N0;3PiP04086Y
P@0F6Q<05QXC086YP@L0;C0V00<0PJV104I??021ZH401021ZH4605a^E003086YP@1/Pf40K8=Q0100
K8=Q00<0PJV107B=I`1dSFL0501dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0
MHmU00<0PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00@06=gD003086YP@1GIdL0EfM700@0
EfM71@21ZH400`18DSX0PJV103<f:00603<f:004086YP@0O8QX07b8J086YPIh0/>3V0@3oool009d0
/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H4086YP@/0G6iD00<0PJV106b3H@1/Pf40401/Pf400`21
ZH40M8eW07B=I`0D07B=I`03086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107F?I@1eSfD05P1eSfD00`21
ZH40KhIM06n6G@0D06n6G@03086YP@1SMe00HgM@0100HgM@00<0PJV105MWA`1GIdL02@1GIdL4086Y
P@H0<cHX00@0PJV101lR6P0O8QX0PJV1W@2`h>H10?ooo`00W02`h>H01@21ZH405QXC01HJ4`0F6Q<0
PJV100<0;C0V1021ZH4=05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL0501dSFL0
0`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd0501_QUd0
0`21ZH40HgM@06=gD00A06=gD003086YP@1GIdL0EfM700/0EfM71021ZH4303<f:005086YP@0O8QX0
7b8J01lR6P21ZH40W02`h>H10?ooo`00W02`h>H301HJ4`D0PJV10`11Bc`00`21ZH40G6iD05a^E00;
05a^E003086YP@1/Pf40K8=Q0100K8=Q00<0PJV107B=I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00F
07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00@
06=gD003086YP@1GIdL0EfM700/0EfM700@0PJV1049<=P12C3H0@T`f1@21ZH4201lR6P03086YP@2`
h>H0/>3V09X0/>3V0@3oool009/0/>3V0P0F6Q<3086YP@H0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0F07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00@0@T`f0`21ZH400`0O8QX0PJV10;3PiP2J
0;3PiP40oooo002J0;3PiP0401HJ4`21ZH40PJV1086YP@P0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f1021ZH6J0;3PiP40oooo002I0;3P
iP80PJV10P0Q9R000`21ZH40@D/l045;?005045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3
H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086YP@1gTFP0Mi5X01L0Mi5X00<0PJV107F?
I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0E06n6G@03086YP@1SMe00HgM@0140HgM@00<0PJV105MW
A`1GIdL02`1GIdL00`21ZH40@T`f049<=P05049<=P03086YP@0U9ah09BLN0080PJV1V@2`h>H10?oo
o`00V02`h>H01@21ZH408BHP024V800Q9R00PJV100P0@D/l00<0PJV105a^E01LKU@02`1LKU@00`21
ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP00`21
ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe000`21
ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f00D0PJV102DW7P0U9ah09BLN086YP@2H
0;3PiP40oooo002H0;3PiP04086YP@0Q9R008BHP086YP@P0@D/l00<0PJV105a^E01LKU@0301LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0<05MWA`03086YP@12C3H0@T`f00D0@T`f00D0PJV102DW7P0U9ah09BLN086Y
P@2H0;3PiP40oooo002G0;3PiP05086YP@0Q9R008BHP024V8021ZH402011Bc`00`21ZH40G6iD05a^
E00;05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL05P1dSFL00`21ZH40Mi5X07NA
J00G07NAJ003086YP@1eSfD0MHmU01L0MHmU00<0PJV106n6G@1_QUd05P1_QUd00`21ZH40HgM@06=g
D00A06=gD003086YP@1GIdL0EfM700/0EfM700<0PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW
7P0U9ah0PJV109L0/>3V0@3oool009H0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086Y
P@1LKU@0G6iD00`0G6iD00<0PJV106b3H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086Y
P@1gTFP0Mi5X01P0Mi5X00<0PJV107F?I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0F06n6G@03086Y
P@1SMe00HgM@0140HgM@00<0PJV105MWA`1GIdL0301GIdL00`21ZH40@T`f049<=P06049<=P05086Y
P@0U9ah09BLN02DW7P21ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH408BHP024V800Q9R00PJV100P0
@D/l00<0PJV105a^E01LKU@02`1LKU@00`21ZH40K8=Q06b3H@0B06b3H@03086YP@1dSFL0M8eW01D0
M8eW00<0PJV107NAJ01gTFP0601gTFP00`21ZH40MHmU07F?I@0H07F?I@03086YP@1_QUd0KhIM01D0
KhIM00<0PJV106=gD01SMe004P1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0
@T`f00D0PJV102DW7P0U9ah09BLN086YP@2F0;3PiP40oooo002E0;3PiP05086YP@0Q9R008BHP024V
8021ZH402011Bc`00`21ZH40G6iD05a^E00<05a^E003086YP@1/Pf40K8=Q0180K8=Q00<0PJV107B=
I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1eSfD0MHmU01P0MHmU00<0PJV106n6
G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0EfM700`0EfM700<0PJV1049<
=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109D0/>3V0@3oool009@0/>3V00D0PJV1024V
800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf404P1/Pf40
0`21ZH40M8eW07B=I`0:07B=Idl0PJV1301_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0
EfM700/0EfM700<0PJV1049<=P12C3H01`12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3o
ool009@0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086YP@1LKU@0G6iD00`0G6iD00<0
PJV106b3H@1/Pf403@1/Pf4B086YP@`0PZ9g00<0PJV108BTM`24Y7L06024Y7L00`21ZH40PZ9d08:R
M00H08:RM003086YP@1mVfd0OI]]00X0OI]]4P21ZH4?06=gD003086YP@1GIdL0EfM700`0EfM700<0
PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3oool009<0/>3V00D0
PJV1024V800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf40
0`1/Pf4;086YP@D0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03086Y
P@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0307:=H@/0PJV1
1@1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00L0@T`f00D0PJV102DW7P0U9ah0
9BLN086YP@2C0;3PiP40oooo002C0;3PiP04086YP@0Q9R008BHP086YP@T0@D/l00<0PJV105a^E01L
KU@02@1LKU@9086YPA00NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03
086YP@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0>07:=H@T0
PJV12`1GIdL00`21ZH40@T`f049<=P06049<=P05086YP@0U9ah09BLN02DW7P21ZH40T`2`h>H10?oo
o`00TP2`h>H01@21ZH408BHP024V800Q9R00PJV100T0@D/l00@0PJV105a^E01LKU@0G6iD2021ZH43
06j7I`03086YP@1kVG80NiUb0180NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0I
08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0B
07:=H@04086YP@1RMe00HWM@069gD0P0PJV10`1GIdL00`21ZH40@T`f049<=P07049<=P05086YP@0U
9ah09BLN02DW7P21ZH40TP2`h>H10?ooo`00T@2`h>H01@21ZH408BHP024V800Q9R00PJV100L0@D/l
1`21ZH4:06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag
08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ
07:=H@0C07:=H@03086YP@1RMe00HWM@00P0HWM@1`21ZH47049<=P05086YP@0U9ah09BLN02DW7P21
ZH40T@2`h>H10?ooo`00T@2`h>H01P21ZH408BHP024V800Q9R00PJV1045;?0H0PJV10P1DIU400`21
ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21
ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00`0HWM@00<0PJV104iN@01>GT001P21ZH400`12
C3H0PJV102DW7P0202DW7P03086YP@2`h>H0/>3V08l0/>3V0@3oool00900/>3V00@0PJV1024V800Q
9R008BHP0`21ZH4705AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG804`1kVG800`21
ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21
ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21
ZH40CUi004iN@00504iN@0<0PJV10`0U9ah00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP03
086YP@0Q9R008BHP00<0PJV12@1DIU400`21ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0
NiUb00<0PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0
PZ9d00<0PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0B07:=H@03086YP@1RMe00HWM@00d0
HWM@00<0PJV104iN@01>GT001`1>GT03086YP@809BLN00<0PJV10;3PiP2`h>H0S@2`h>H10?ooo`00
S`2`h>H01@0Q9R00PJV1086YP@0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40
NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40
PZ9d08:RM00I08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF404`1bSF400`21ZH40
HWM@069gD00=069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@21ZH400P21ZH6?0;3PiP40
oooo002>0;3PiP80PJV10`0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00d0KXMW
00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag
00<0PJV108:RM022XW@06@22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ
00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@004086YP@0^=2D0;S@U02hd9@80
PJV1SP2`h>H10?ooo`00SP2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^
QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01H0PZ9g00<0PJV108BTM`24
Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01H0OI]]00<0PJV107:=H@1b
SF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^
=2D00P0^=2F>0;3PiP40oooo002=0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU40
1`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL0
5`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0PJV107fKK@1mVfd0
5`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00d0HWM@00<0PJV104iN@01>GT00
1`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V00D0
PJV102dd;P0]=2h0;C@^086YP@0:05AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG80
4`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022XW@0
6P22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe00
3@1RMe000`21ZH40CUi004iN@00804iN@005086YP@0^=2D0;S@U02hd9@21ZH40S@2`h>H10?ooo`00
S02`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L0
6P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF40
4`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^=2D0
0P0^=2D00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002<0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0
PJV105AVD@1DIU401`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0
PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0D07:=H@03086YP@1RMe00HWM@00d0HWM@00<0
PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08X0/>3V0@3o
ool008`0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0905AVD@03086YP@1^QfL0KXMW00h0KXMW00<0
PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0H08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0
PJV108:RM022XW@06P22XW@00`21ZH40OI]]07fKK@0H07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0
PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40
S02`h>H10?ooo`00R`2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0
PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0
PJV108BTM`24Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01P0OI]]00<0
PJV107:=H@1bSF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0
PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP05086YP@0]=2h0
;C@^02dd;P21ZH402P1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0K08BTM`03086YP@22XW@0PZ9d01/0PZ9d00<0
PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0
PJV104iN@01>GT00201>GT001@21ZH40;S@U02hd9@0^=2D0PJV108/0/>3V0@3oool008X0/>3V00<0
PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00h0KXMW00<0
PJV107^ILP1kVG80501kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01/0Q:Ag00<0
PJV108:RM022XW@06`22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01@0LXeQ00<0
PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40
R`2`h>H10?ooo`00RP2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0
PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0
PJV108BTM`24Y7L03@24Y7LM086YP@l0PZ9d00<0PJV107fKK@1mVfd0601mVfd00`21ZH40LXeQ07:=
H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd
9@0202hd9@03086YP@2`h>H0/>3V08P0/>3V0@3oool008X0/>3V00D0PJV102dd;P0]=2h0;C@^086Y
P@0905AVD@03086YP@1^QfL0KXMW00l0KXMW00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:R
M`0;08:RMad0PJV13P2>]8<00`21ZH40SK6008faP00<08faP1d0PJV13@1mVfd00`21ZH40LXeQ07:=
H@0C07:=H@03086YP@1RMe00HWM@00l0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd
9@0^=2D0PJV108X0/>3V0@3oool008T0/>3V00<0PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AV
D@0705AVD@03086YP@1^QfL0KXMW00h0KXMW00<0PJV107^ILP1kVG802@1kVG8I086YP@d0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i00/0Qj]i6@21
ZH4;07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd
9@0202hd9@03086YP@2`h>H0/>3V08L0/>3V0@3oool008T0/>3V00D0PJV102dd;P0]=2h0;C@^086Y
P@0905AVD@03086YP@1^QfL0KXMW00L0KXMW5021ZH4;08N[P003086YP@2=/X@0SK:401P0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0
PJV107jNKP1nWVh02@1nWVhD086YP@T0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd
9@0^=2D0PJV108T0/>3V0@3oool008T0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0705AVD@`0PJV1
201kVgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401P0SK:400<0PJV108jdP`2>]8<0
6`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0PJV107jNKP1nWVh0
501nWVh00`21ZH40KHQL06f8G00606f8G0`0PJV11`1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108T0
/>3V0@3oool008P0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0205AVD@H0PJV10P1TO6800`21ZH40
Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@0602=/X@00`21ZH40
S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06027ZgT00`21ZH40
OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P01P21ZH4204iN@005
086YP@0^=2D0;S@U02hd9@21ZH40R02`h>H10?ooo`00R02`h>H00`21ZH40;C@^02dd;P04086YP@P0
I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0
SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0
Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00>06f8G003086YP@1GK4P0Efa800H0
Efa81021ZH4202hd9@03086YP@2`h>H0/>3V08H0/>3V0@3oool008L0/>3V00H0PJV102dd;P21ZH40
PJV103]8?P21ZH4906AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21
ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301/0S[B300<0PJV108faP02=/H006`2=/H000`21
ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21
ZH40Efa805M/B00705M/B006086YP@0g@Rh0PJV1086YP@0^=2D0PJV1Q`2`h>H10?ooo`00Q`2`h>H2
086YP@80>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00
Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00
SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0
KHQL00l0KHQL00<0PJV105M/B01GK4P01`1GK4P01021ZH40=d8^03M2;P0g@Rh2086YPHL0/>3V0@3o
ool008L0/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0:06AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0
PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301/0S[B300<0
PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0
PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00805M/B005086YP@0g@Rh0=d8^03M2;P21ZH40
Q`2`h>H10?ooo`00QP2`h>H00`21ZH40>dPn03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR00<0
PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0
PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0
PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP240;3PiP40oooo00260;3PiP03086YP@0kB3h0
>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0>07^KM`03086YP@27Zh00
Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00
SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@1]R5`0
KHQL00h0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0
/>3V08@0/>3V0@3oool008H0/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0:06AlHP03086YP@1kVgL0
Ni]g00l0Ni]g00<0PJV108N[P027Zh005@27Zh000`21ZH40SK:408fbQ00H08fbQ003086YP@2>]8<0
S[B301`0S[B300<0PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0
OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00705M/B003086YP@0g@Rh0
=d8^0080=d8^00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00QP2`h>H01@21ZH40>dPn03]8?P0kB3h0
PJV100X0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0
SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0
Qj]i01P0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0
Efa800P0Efa800D0PJV103M2;P0g@Rh0=d8^086YP@260;3PiP40oooo00250;3PiP03086YP@0kB3h0
>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00
Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00
SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0
KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0
/>3V08<0/>3V0@3oool008D0/>3V00<0PJV103]8?P0kB3h00P0kB3h00`21ZH40I7aR06AlHP0806Al
HP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fb
Q003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@0I08N[
N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00805M/
B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q@2`h>H01@21ZH40
>dPn03]8?P0kB3h0PJV100/0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[
P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08fa
P003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8
G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP230;3P
iP40oooo00250;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21ZH40Ni]g07^KM`0>07^K
M`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0L08jd
P`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E07jN
KP03086YP@1]R5`0KHQL00h0KHQL00<0PJV105M/B01GK4P02@1GK4P01@21ZH40=d8^03M2;P0g@Rh0
PJV108D0/>3V0@3oool008@0/>3V00<0PJV103]8?P0kB3h00P0kB3h00`21ZH40I7aR06AlHP0806Al
HP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005@27Zh000`21ZH40SK:408fbQ00I08fb
Q003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@0I08N[
N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00805M/
B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00Q02`h>H00`21ZH40
>dPn03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40
Qj^008N[P00E08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40
SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40
KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40
/>3V0;3PiP220;3PiP40oooo00240;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21ZH40
Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40
S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40
OYi^07jNKP0E07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40
=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V0880/>3V0@3oool008@0/>3V00D0PJV103]8?P0kB3h0
>dPn086YP@0;06AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40
SK:408fbQ00J08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21ZH40
Qj]i08N[N@0J08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40
Efa805M/B00905M/B005086YP@0g@Rh0=d8^03M2;P21ZH40Q02`h>H10?ooo`00P`2`h>H00`21ZH40
>dPn03]8?P0203]8?P03086YP@1TO680I7aR00T0I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21ZH40
Qj^008N[P00E08N[P003086YP@2=/X@0SK:401X0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40
SK6008faP00L08faP003086YP@27ZgT0Qj]i01X0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40
KHQL06f8G00>06f8G003086YP@1GK4P0Efa800T0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40
/>3V0;3PiP210;3PiP40oooo00230;3PiP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680
201TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@0
302=/XAK086YP@h0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086Y
P@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP210;3PiP40oooo
00230;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21ZH40Ni]g07^KM`0707^KMbl0PJV1
3P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<0
302@^8<_086YP@T0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086Y
P@2`h>H0/>3V0840/>3V0@3oool008<0/>3V100kB3h00`21ZH40I7aR06AlHP0406AlHPl0PJV12026
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G
`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00607RHJ0l0PJV11P1GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108<0/>3V
0@3oool00880/>3V00<0PJV103]8?P0kB3h02@21ZH45072?L@03086YP@26Zh<0QZ^300l0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0
PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0305igCPT0PJV10P0g@Rh00`21ZH40/>3V0;3P
iP200;3PiP40oooo00220;3PiP<0PJV10P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0
QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0
Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0
?Thd00<0PJV1PP2`h>H10?ooo`00PP2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03
086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03
086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03
086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03
086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003
086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma
072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>
09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3
092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>
05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`
h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G
`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0n
CS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1
072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV1
09JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1
092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV1
05igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V0800/>3V0@3oool0
0840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^3
00l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=
01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai
01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd
00<0?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0304QLCP03
086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03
086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03
086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003
086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40
oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^3
08J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06@2F_hh00`21ZH40Ul2=
09O0S@0M09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai
08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd
03i>=00303i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00`18
G4h00`21ZH40L8ma072?L@08072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A
^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E
_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03P1h
V6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0O`2`
h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV1
08J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV1
09O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV1
08N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV1
03i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>
0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;
01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj9
01d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX
00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V
07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03
086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03
086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03
086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03
086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>
04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj9
09FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V
0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`
Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F
_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@
^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1N
Mdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00800/>3V00<0PJV1
04QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1
096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV1
09FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV1
07RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV1
0;3PiP2`h>H0O`2`h>H10?ooo`00P02`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03
086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03
086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03
086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03
086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003
086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma
072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>
09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3
092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>
05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`
h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G
`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0n
CS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3Pi_<0PJV1P02`h>H10?ooo`00P02`h>H00`21
ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21
ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21
ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01i
WG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2L
bIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G
`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01V
PeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V
00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=
00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E
00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR2
00<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi
00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1i
WG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2L
bIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G
`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1V
PeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n0;3PiP40oooo0020
0;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?
08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M
09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E
08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@02
04=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21
ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21
ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21
ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21
ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?oo
o`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>
^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2M
biD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?
^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13
EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK0080DVaK
00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD
00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB
00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb
00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V
0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>
^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2M
biD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?
^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13
EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`02
059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?
082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP1o
0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`0201iWG`00`21
ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21
ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21
ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00h0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21
ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1B
K5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02H
a9@05@2Ha9@00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2K
b980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20
YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`
h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H
00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1B
K5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2H
a9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2K
b980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20
YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`
h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO009
07VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J
09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J
09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F009
06J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21
ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21
ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01i
WG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2L
bIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G
`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01V
PeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V
00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=
00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E
00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR2
00<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi
00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1i
WG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2L
bIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G
`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1V
PeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP200;3PiP40oooo0022
0;3PiP<0PJV10P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV1
09S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV1
09_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1
082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0PJV1PP2`h>H1
0?ooo`00PP2`h>H00`21ZH40FGQT05UhI008086YP@H0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00@0IX=H2021ZH4204EL?003086YP@2`h>H0/>3V
0800/>3V0@3oool008<0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0507nXQ@l0PJV12@2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP07082ULPl0PJV11@1/SV400`21ZH40AE`l04EL?00204EL?8<0/>3V0@3oool008<0
/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00H0U<:E<021ZH4>09c9
UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00<09O2
S300PJV12026[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3P
iP2`h>H0P@2`h>H10?ooo`00P`2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0
OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M00`0
X]:MF`21ZH4>09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40
K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P@2`h>H10?ooo`00
P`2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500T0OjR500<0PJV109C2U@2D`YD0
3P2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01X0X]:M00<0PJV10:;CW02Rdi`0
702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01X0W<^C00<0PJV109C1RP2D`HX0
5@2D`HX00`21ZH40QZmj08J_NP0>08J_NP03086YP@1/SV40K8iQ00T0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP210;3PiP40oooo00240;3PiP05086YP@1IN6@0FGQT05UhI021ZH40
2`1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd0
6P2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<0
6P2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40
2@1/SV401@21ZH40AE`l04EL?015G3`0PJV108@0/>3V0@3oool008@0/>3V00D0PJV105UhI01IN6@0
FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40
X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40
W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40
K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00
Q02`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD0
3`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0
702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0
5@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP220;3PiP40oooo00240;3PiP03086YP@1IN6@0FGQT0080FGQT00<0
PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0
PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0
PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0880/>3V0@3o
ool008D0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00h0U<:E00<0
PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0
PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0
PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0906b>H@05086YP@15G3`0AE`l04EL?021ZH40
Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40FGQT05UhI01IN6@0PJV100/0OjR500<0PJV109C2U@2D`YD0
3`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0
702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0
502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP230;3PiP40oooo00250;3PiP03086YP@1IN6@0FGQT0080FGQT00<0
PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0
PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0
PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08<0/>3V0@3o
ool008D0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0
U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0
X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0
U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0
AE`l0080AE`l00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00QP2`h>H01@21ZH40FGQT05UhI01IN6@0
PJV100X0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0
X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0
W<^C01P0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40
K8iQ00P0K8iQ00D0PJV104EL?015G3`0AE`l086YP@260;3PiP40oooo00260;3PiP05086YP@1IN6@0
FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0
PJV10:;BW@2RdYd0602RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0
PJV106b>H@1/SV401`1/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08@0/>3V0@3o
ool008H0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0
U<:E00h0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0
X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0
U<6:01D0U<6:00<0PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0
AE`l0080AE`l00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00QP2`h>H00`21ZH40FGQT05UhI00205Uh
I003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>
V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7A
V003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_
NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP240;3P
iP40oooo00270;3PiP05086YP@1IN6@0FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?09C2
U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K0:;C
W003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1
RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40201/SV401@21ZH40AE`l04EL?015G3`0
PJV108L0/>3V0@3oool008L0/>3V0P21ZH4205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2
U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;C
W02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1
RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00L0K8iQ00@0PJV104EL
?015G3`0AE`l0P21ZH670;3PiP40oooo00270;3PiP06086YP@1MP6/0PJV1086YP@1IN6@000002@1o
Z8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2R
dYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2L
bi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV401@1/
SV4010000000K8iQ086YP@15G3`2086YP@0304MR@021ZH40/>3V08H0/>3V0@3oool008P0/>3V00D0
PJV105f0J`1MP6/0PJV100000002086YP@P0OjR500<0PJV109C2U@2D`YD03P2D`YD00`21ZH40W/jK
09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H
0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj
08J_NP0=08J_NP0400000021ZH40K8iQ000000D0K8iQ0`000002086YP@80Af9000<0PJV10;3PiP2`
h>H0QP2`h>H10?ooo`00R02`h>H01021ZH40GH1[05f0J`1MP6/20000000308>_R`21ZH40PJV100@0
PJV10P0000000`21ZH40U<:E0000000?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2R
dYd0602RdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2L
bi<0602Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00`0QZmj1`000003086YP@D0
00000`17HT000`21ZH40/>3V0;3PiP260;3PiP40oooo00290;3PiP04086YP@1MP6/0GH1[05f0J`80
00001P23[h/200000004086YP@0000000000000000D0PJV12@2D`YD00`21ZH40000009k>V`0209k>
V`030000002NcY/0W/jK00l0W/jK00<0PJV10:;BW@2RdYd0602RdYd00`21ZH40X]>L0:;CW00K0:;C
W003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<0602Lbi<00`21ZH40U<6:09C1RP0D09C1
RP05086YP@000000QZmj08J_NP0000001@26[gX4086YP@T000000`1`UVP3000000<0Af9000<0PJV1
0;3PiP2`h>H0Q`2`h>H10?ooo`00R@2`h>H01P21ZH40GH1[05f0J`1MP6/0PJV1000000H0Pjn;0P00
00001021ZH40UlVK00000000000509O9V`P0PJV120000005086YP@H0W/jK00<0000009k>V`2NcY/0
0P2NcY/00`21ZH40X]:M0:;BW@0H0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP0
6`2QdIP00`21ZH40W<^C09c;T`0H09c;T`03086YP@000000U<6:0080U<6:00<0000009C1RP2D`HX0
0P2D`HX00`000000U<6:086YP@08086YP@T000000`21ZH4308ZfP@<000000P2:]X401021ZH40L9IX
000000000005072FJ00300000021ZH40Af900080Af9000<0PJV10;3PiP2`h>H0Q`2`h>H10?ooo`00
R@2`h>H00`21ZH40GH1[05f0J`0205f0J`8000001@23[h/20000000408>_R`21ZH400000000000`0
UlVK2P0000040:7DX@D0PJV10`00000A086YP@d0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40
XM6H0:7AV00K0:7AV003086YP@2Lbi<0000000<0W<^C00<0000009c;T`2Lbi<01@2Lbi<<086YP@T0
000000@0PJV10000000000000000202Hb90;000000D0R[J10P00000208ZfP@03086YP@1`UVP0L9IX
008000001@1`UVP00`000000Af9004MR@00204MR@003086YP@2`h>H0/>3V08L0/>3V0@3oool008X0
/>3V00H0PJV105f0J`1MP6/0GH1[086YP@00000508>_R`80000000<0Pjn;086YP@0000000P00000;
09O9V`80000000<0UlVK086YP@2Qe:400`2Qe:43000000T0XMBQ0P0000030:7DX@03086YP@2UfJ<0
YMVS00P0YMVS0P0000000`2UfJ<0PJV1086YP@05086YP@8000003021ZH42000000D0PJV12@2Rdi`2
000000@0X]>L00<0PJV10:7AV02QdIP02@2QdIP200000080XM6H3021ZH4<000000@0PJV12`2PdYT=
000000T0V<R@0P0000000`21ZH40R[J108ZfP@0408ZfP@8000001@2:]X401@000000R[J108ZfP@2:
]X40PJV10080L9IX0P000005072FJ005086YP@17HT00Af9004MR@021ZH40RP2`h>H10?ooo`00RP2`
h>H00`21ZH40GH1[05f0J`0205f0J`8000001023[h/30000000408>_R`21ZH400000000000X0UlVK
0P00000209O9V`03086YP@2Qe:40XMBQ00<0XMBQ100000070:7DX@8000000`2Qe:400`21ZH40YMVS
0:GIX`080:GIX`8000002@2UfJ<2000000<0YMVS00<0PJV10:KJXP2VfZ801@2VfZ82000000D0Y]ZR
2@21ZH4200000100PJV10P000002086YP@/0Y=RN3P00000<0:3BV@@0000000<0PJV109S8T02Hb900
102Hb904000000P0V<R@0P0000000`2Hb900PJV108ZfP@0608ZfP@030000002:]X40R[J100<0R[J1
00@0000008ZfP@2:]X40PJV10`1`UVP3000000<0L9IX00<0PJV104MR@017HT000P17HT000`21ZH40
/>3V0;3PiP280;3PiP40oooo002:0;3PiP03086YP@1MP6/0GH1[0080GH1[0P00000408>_R`<00000
00@0Pjn;086YP@00000000002P2GbI/200000080UlVK00<0PJV10:7DX@2Qe:40102Qe:44000000H0
XMBQ0`0000030:7DX@03086YP@2UfJ<0YMVS00L0YMVS0P0000090:GIX`8000000`2UfJ<00`21ZH40
Y]ZR0:KJXP050:KJXP8000003P2VfZ82000000@0Y]ZR00<0PJV10:CHWP2Tf9h02@2Tf9h2000000`0
Y=RN0`0000000`2Tf9h0PJV10:3BV@070:3BV@<000002@2PdYT500000003086YP@2Hb900V<R@00H0
V<R@0`00000809S8T0040000002Hb900V<R@086YP@L0R[J100<0000008ZfP@2:]X401P2:]X400`21
ZH40L9IX072FJ003000000<0L9IX00<00000086YP@17HT000P17HT000`21ZH40/>3V0;3PiP290;3P
iP40oooo002;0;3PiP04086YP@1MP6/0GH1[05f0J`T000000P23[h/3000000T0UlVK0P00000209O9
V`03086YP@2Qe:40XMBQ00H0XMBQ00<000000:7DX@2Qe:401P2Qe:42000000<0XMBQ00<0PJV10:GI
X`2UfJ<01`2UfJ<2000000T0YMVS0P0000030:GIX`03086YP@2VfZ80Y]ZR00D0Y]ZR0P00000>0:KJ
XP800000102VfZ800`21ZH40Y=RN0:CHWP090:CHWP8000002`2Tf9h300000080Y=RN00<0PJV10:3B
V@2PdYT01`2PdYT3000000L0X=:I100000020:3BV@03086YP@2Hb900V<R@00H0V<R@0`00000709S8
T080000000<0V<R@086YP@2:]X403`2:]X400`21ZH40L9IX072FJ003000000@0L9IX00<00000086Y
P@17HT000P17HT000`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP03086YP@1MP6/0GH1[0080
GH1[00<0PJV10000000000001@00000208>_R`03086YP@000000000000T0UlVK0P00000309O9V`03
086YP@2Qe:40XMBQ00h0XMBQ0P0000030:7DX@03086YP@2UfJ<0YMVS00L0YMVS0P0000090:GIX`80
0000102UfJ<00`21ZH40Y]ZR0:KJXP040:KJXP8000003P2VfZ82000000@0Y]ZR00<0PJV10:CHWP2T
f9h02@2Tf9h2000000X0Y=RN0`0000020:CHWP03086YP@2PdYT0X=:I00T0X=:I0`0000060:3BV@80
0000102PdYT00`21ZH40V<R@09S8T00609S8T0800000202Hb90010000000V<R@09S8T021ZH4@08Zf
P@D00000101`UVP2000000@0Af9000<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00S02`h>H01@21ZH40
GH1[05f0J`1MP6/0PJV1008000000`23[h/30000000308>_R`21ZH40000000800000202GbI/20000
00<0UlVK00<0PJV10:7DX@2Qe:403P2Qe:42000000<0XMBQ00<0PJV10:GIX`2UfJ<01`2UfJ<20000
00T0YMVS0P0000040:GIX`03086YP@2VfZ80Y]ZR00@0Y]ZR0P00000>0:KJXP800000102VfZ800`21
ZH40Y=RN0:CHWP090:CHWP8000002P2Tf9h2000000<0Y=RN00<0PJV10:3BV@2PdYT02P2PdYT00`00
0000X=:I0:3BV@050:3BV@030000002PdYT0X=:I00<0X=:I00<0PJV109S8T02Hb9001P2Hb9020000
00L0V<R@0P00000209S8T003086YP@2:]X40R[J100`0R[J11P000005072FJ00300000021ZH40Af90
0080Af9000<0PJV10;3PiP2`h>H0RP2`h>H10?ooo`00S02`h>H00`21ZH40GH1[05f0J`0205f0J`80
00000`23[h/2000000<0Pjn;00<0PJV1000000000000202GbI/2000000<0UlVK00<0PJV10:7DX@2Q
e:403P2Qe:43000000<0XMBQ00<0PJV10:GIX`2UfJ<01P2UfJ<2000000T0YMVS0P0000040:GIX`03
086YP@2VfZ80Y]ZR00@0Y]ZR0P00000>0:KJXP800000102VfZ800`21ZH40Y=RN0:CHWP090:CHWP80
00002P2Tf9h00`000000Y=RN0:CHWP020:CHWP03086YP@2PdYT0X=:I0140X=:I0P0000040:3BV@03
086YP@2Hb900V<R@00H0V<R@0`00000709S8T0050000002Hb900V<R@09S8T021ZH401`2:]X400`00
0000R[J108ZfP@0208ZfP@D000001`1`UVP2000000@0Af9000<0PJV10;3PiP2`h>H0RP2`h>H10?oo
o`00S02`h>H00`21ZH40GH1[05f0J`0205f0J`<000000P23[h/2000000<0Pjn;00<0PJV100000000
0000202GbI/2000000@0UlVK00<0PJV10:7DX@2Qe:403P2Qe:42000000<0XMBQ00<0PJV10:GIX`2U
fJ<01P2UfJ<2000000X0YMVS0P0000030:GIX`03086YP@2VfZ80Y]ZR00@0Y]ZR0P00000>0:KJXP80
0000102VfZ800`21ZH40Y=RN0:CHWP090:CHWP8000002@2Tf9h2000000@0Y=RN00<0PJV10:3BV@2P
dYT0402PdYT2000000D0X=:I00<0PJV109S8T02Hb9001P2Hb902000000L0V<R@3P00000308ZfP@@0
000000D0PJV1072FJ01`UVP0L9IX00000004072FJ00300000021ZH40Af9000<0Af9000<0PJV10;3P
iP2`h>H0RP2`h>H10?ooo`00S@2`h>H01`21ZH40GH1[05f0J`1MP6/0PJV108>_R`0000000P23[h/3
000000<0Pjn;0`00000709O9V`<000000`2GbI/00`21ZH40XMBQ0:7DX@0>0:7DX@8000000`2Qe:40
0`21ZH40YMVS0:GIX`060:GIX`8000002P2UfJ<2000000<0YMVS00<0PJV10:KJXP2VfZ80102VfZ82
000000h0Y]ZR0P0000040:KJXP03086YP@2Tf9h0Y=RN00T0Y=RN0P0000080:CHWP8000001@2Tf9h0
0`21ZH40X=:I0:3BV@090:3BV@030000002PdYT0X=:I00@0X=:I0P0000050:3BV@03086YP@2Hb900
V<R@00H0V<R@0P00000609S8T0l000000`2:]X420000000308ZfP@21ZH40L9IX00<0L9IX00@00000
072FJ01`UVP0L9IX0P0000001@21ZH40Af9004MR@017HT00PJV108d0/>3V0@3oool008d0/>3V00<0
PJV105f0J`1MP6/00P1MP6/00`21ZH4000000000000208>_R`8000000`23[h/01021ZH4000000000
0000000809O9V`8000000P2GbI/00`21ZH40XMBQ0:7DX@0>0:7DX@<000000P2Qe:400`21ZH40YMVS
0:GIX`060:GIX`8000002P2UfJ<2000000<0YMVS00<0PJV10:KJXP2VfZ80102VfZ82000000h0Y]ZR
0P0000040:KJXP03086YP@2Tf9h0Y=RN00T0Y=RN0P0000080:CHWQD000001@2PdYT3000000@0X=:I
00<0PJV109S8T02Hb9001P2Hb902000000H0V<R@0P00000309S8T003086YP@2:]X40R[J100@0R[J1
0`00000208ZfP@8000000P2:]X401021ZH40L9IX072FJ01`UVP2000000<0L9IX00<00000086YP@17
HT000`17HT000`21ZH40/>3V0;3PiP2;0;3PiP40oooo002>0;3PiP07086YP@1MP6/0GH1[05f0J`21
ZH40Pjn;0000000208>_R`8000000`23[h/00`21ZH40000000000002000000L0UlVK0`00000209O9
V`03086YP@2Qe:40XMBQ00H0XMBQ00<000000:7DX@2Qe:40102Qe:42000000@0XMBQ00<0PJV10:GI
X`2UfJ<01@2UfJ<2000000X0YMVS0P0000030:GIX`03086YP@2VfZ80Y]ZR00@0Y]ZR0P00000>0:KJ
XP800000102VfZ800`21ZH40Y=RN0:CHWP090:CHWP800000202Tf9hD000000H0X=:I0`0000030:3B
V@03086YP@2Hb900V<R@00H0V<R@0`00000609S8T08000000P2Hb9000`21ZH40R[J108ZfP@0408Zf
P@<000000`2:]X4200000080R[J100<0PJV1072FJ00000000`000003072FJ00300000021ZH40Af90
0080Af9000<0PJV10;3PiP2`h>H0S02`h>H10?ooo`00SP2`h>H00`21ZH40GH1[05f0J`0205f0J`04
086YP@000000000008>_R`8000001023[h/5000000L0UlVK0`0000000`2GbI/0PJV10:7DX@060:7D
X@<000001@2Qe:43000000<0XMBQ00<0PJV10:GIX`2UfJ<01@2UfJ<2000000X0YMVS0P0000040:GI
X`03086YP@2VfZ80Y]ZR00<0Y]ZR0P00000>0:KJXP800000102VfZ800`21ZH40Y=RN0:CHWP090:CH
WP800000202Tf9h3000000<0Y=RN00<0PJV10:3BV@2PdYT02@2PdYT2000000L0X=:I0P0000030:3B
V@03086YP@2Hb900V<R@00H0V<R@0P00000709S8T0<0000000<0V<R@086YP@2:]X40102:]X430000
00@0R[J1100000000`1`UVP0000000000002000000<0L9IX0P00000404MR@003086YP@2`h>H0/>3V
08`0/>3V0@3oool008l0/>3V0P21ZH4205f0J`03086YP@23[h/0000000<000001023[h/6000000L0
UlVK0`0000000`21ZH40XMBQ0:7DX@040:7DX@<000001P2Qe:45000000030:7DX@21ZH40YMVS00H0
YMVS0P00000:0:GIX`<000000`2UfJ<00`21ZH40Y]ZR0:KJXP030:KJXP<000003@2VfZ83000000<0
Y]ZR00<0PJV10:CHWP2Tf9h0202Tf9h3000000T0Y=RN0P0000030:CHWP03086YP@2PdYT0X=:I00P0
X=:I0`0000070:3BV@<000000P2PdYT00`21ZH40V<R@09S8T00509S8T0@000001P2Hb90400000004
086YP@2:]X40R[J108ZfP@@000001@2:]X47000000D0L9IX00@00000086YP@17HT00Af900P21ZH6?
0;3PiP40oooo002?0;3PiP07086YP@1NQ6d0PJV1086YP@1MP6/0PJV108>_R`03000000D0Pjn;00<0
000009O9V`2GbI/01@00000509O9V`D000000P2Qe:44000000P0XMBQ1@0000000`21ZH40YMVS0:GI
X`050:GIX`<000002@2UfJ<3000000<0YMVS00<0PJV10:KJXP2VfZ800`2VfZ85000000/0Y]ZR1000
00020:KJXP03086YP@2Tf9h0Y=RN00P0Y=RN0P00000:0:CHWP<000000P2Tf9h00`21ZH40X=:I0:3B
V@080:3BV@8000002@2PdYT3000000030:3BV@21ZH40V<R@00D0V<R@1000000909S8T0T00000202:
]X44000000D0L9IX0P0000001@17HT00PJV1086YP@19IdD0PJV108l0/>3V0@3oool00900/>3V00<0
PJV105j4K@1NQ6d00`21ZH43000000D0Pjn;00<0PJV109O9V`2GbI/01@00000609O9V`T000002@2Q
e:42000000030:7DX@000000000000<000001@2UfJ<2000000X0YMVS0P0000040:GIX`03086YP@2V
fZ80Y]ZR00<0Y]ZR1P00000:0:KJXPH0000000<0PJV10:CHWP2Tf9h0202Tf9h2000000/0Y=RN1000
00000`21ZH40X=:I0:3BV@060:3BV@@000002P2PdYT4000000<0V<R@1`00000:09S8T0H000002P2:
]X400`21ZH40L9IX072FJ005072FJ004086YP@000000PJV1086YP@80BFM500<0PJV10;3PiP2`h>H0
SP2`h>H10?ooo`00T@2`h>H01P21ZH40GXA]05j4K@1NQ6d0PJV108>aS@8000001021ZH4208>_R`03
086YP@2GbI/0UlVK00`0UlVK1@00000;0:7DX@<0000000<0XMBQ0000000000002P0000090:GIX`80
0000102UfJ<00`21ZH40Y]ZR0:KJXP030:KJXP<0000000@0Y]ZR00000000000000002@2VfZ820000
00030:KJXP0000000000008000002P2Tf9h2000000`0Y=RN1P0000030:3BV@H00000302PdYT<0000
00/0V<R@0P00000=08ZfP@03086YP@1`UVP0L9IX00H0PJV10P00000304UWA@03086YP@2`h>H0/>3V
08l0/>3V0@3oool00940/>3V00H0PJV105j4K@1NQ6d0GXA]086YP@23/Hd2000000@0Pk6=1P21ZH4;
09O9V`03086YP@2Qe:40XMBQ00h0XMBQ0P0000030:7DX@03086YP@000000000000H000002P2UfJ<2
000000@0YMVS00<0PJV10:KJXP2VfZ800`2VfZ82000000<0Y]ZR100000040:KJXPD000000`2VfZ85
000000@0Y=RN1@00000>0:CHWP/000003`2PdYT6000000<0V<R@0P00000;09S8T003086YP@2:]X40
R[J100T0R[J11P21ZH46076JK00300000021ZH40BFM50080BFM500<0PJV10;3PiP2`h>H0S`2`h>H1
0?ooo`00TP2`h>H01P21ZH40GXA]05j4K@1NQ6d0PJV108>aS@8000001P23/Hd00`21ZH40V<bN09S<
WP08086YP@@0UlVK00<0PJV10:7DX@2Qe:403@2Qe:42000000<0XMBQ00<0PJV10:GIX`2UfJ<00P2U
fJ<00`000000YMVS0:GIX`0;0:GIX`800000102UfJ<00`21ZH40Y]ZR0:KJXP030:KJXP800000102V
fZ8;000000D0Y]ZR3000000@0:CHWP03086YP@000000000000@000004P2PdYT00`21ZH40V<R@09S8
T00509S8T0<000002P2Hb9000`21ZH40R[J108ZfP@0208ZfP@P0PJV10P2;^XD00`21ZH40LIY/076J
K007076JK00500000019IdD0BFM504UWA@21ZH40TP2`h>H10?ooo`00T`2`h>H01@21ZH40GXA]05j4
K@21ZH40Pk6=008000001P23/Hd00`21ZH40V<bN09S<WP0809S<WPX0PJV12P2Qe:43000000<0XMBQ
00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP090:KJXPL00000202VfZ800`21ZH40Y=RN
0000000600000180Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00609S8T0800000
1P2Hb90:086YP@X0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109<0
/>3V0@3oool009<0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0908>aS@03086YP@2Hc9h0V<bN00/0
V<bN00<0PJV10:?IY@2SfJD00`2SfJD;086YP@8000000`2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03
086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:CHWP2Tf9h0602Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03
086YP@2Hb900V<R@00<0V<R@0`21ZH42000000H0PJV11@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03
086YP@1aVV`0LIY/00L0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2C0;3PiP40oooo002D0;3PiP05
086YP@1NQ6d0GXA]05j4K@21ZH402023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0XmVU
00d0XmVU0P00000@086YP@`0YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40Y=RN0:CHWP0H0:CH
WP03086YP@2PdYT0X=:I00X0X=:I4P21ZH4309W<U08000002P2Ic9@00`21ZH40RkZ508^jQ@0<08^j
Q@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2D0;3PiP40oooo002D0;3P
iP05086YP@1NQ6d0GXA]05j4K@21ZH402@23/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0
XmVU00d0XmVU0P0000030:?IY@03086YP@2WgZL0YmjW00X0YmjW1`21ZH400`000000PJV1086YP@15
086YP@`0X]NM00<0PJV109W<U02Ic9@01@2Ic9@3000000X0VLbD00<0PJV108^jQ@2;^XD02`2;^XD0
0`21ZH40LIY/076JK007076JK005086YP@19IdD0BFM504UWA@21ZH40U02`h>H10?ooo`00U@2`h>H0
1@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h0302Hc9h00`21ZH40XmVU0:?I
Y@0<0:?IY@<000000`2SfJD00`21ZH40YmjW0:ONY`0?0:ONY`@000000P2WgZL00`21ZH40Z=nV0:SO
YP0H0:SOYP03086YP@2Vg:80Y]bR01P0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<
U00709W<U0030000002Ic9@0VLbD00P0VLbD00<0PJV108^jQ@2;^XD0302;^XD00`21ZH40LIY/076J
K006076JK005086YP@19IdD0BFM504UWA@21ZH40U@2`h>H10?ooo`00UP2`h>H01@21ZH40GXA]05j4
K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0=0:?IY@030000
002SfJD0XmVU0080XmVU00<0PJV10:ONY`2WgZL03P2WgZL6000000030:ONY`21ZH40Z=nV01T0Z=nV
00<0PJV10:KLXP2Vg:80602Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0180VLbD
00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21
ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2H
c9h0302Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW00l0YmjW100000020:ONY`03
086YP@2XgjH0Z=nV01P0Z=nV00<0PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0F0:;GW@03
086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;^XD0302;^XD00`21ZH40LIY/076JK006076JK005
086YP@19IdD0BFM504UWA@21ZH40UP2`h>H10?ooo`00U`2`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV1
00P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW
0140YmjW00<000000:ONY`2WgZL00P2WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR
01L0Y]bR00<0PJV10:;GW@2Reid05P2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ5
00/0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109L0/>3V0@3oool0
09P0/>3V00@0PJV105j4K@1NQ6d0PJV12023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0
XmVU0140XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80
Y]bR01L0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0
RkZ500`0RkZ500<0PJV1076JK01aVV`01@1aVV`01@21ZH40BFM504UWA@19IdD0PJV109P0/>3V0@3o
ool009P0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0
PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV00<0
PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0
PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40
V02`h>H10?ooo`00V@2`h>H2086YP@80GXA]00<0PJV108>aS@23/Hd01@23/Hd00`21ZH40V<bN09S<
WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SO
YP0G0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<
U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01@1aVV`00`21ZH40BFM504UW
A@02086YPIT0/>3V0@3oool009X0/>3V1021ZH4808>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0PJV1
0:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV1
0:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV1
08^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK006076JK0@0PJV1VP2`h>H10?ooo`00V`2`h>H00`21
ZH40Fh9/086YP@02086YP@H0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0A0:?I
Y@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR0:KLXP0F0:KL
XP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0;08^j
Q@03086YP@1aVV`0LIY/00@0LIY/0`21ZH400`18JDP0PJV10;3PiP2J0;3PiP40oooo002L0;3PiP03
086YP@1KPV`0Fh9/00@0PJV11023/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0100
XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0
Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00@09W<U003086YP@2;^XD0RkZ500/0
RkZ500<0PJV1076JK01aVV`00P1aVV`4086YP@80B6U800<0PJV10;3PiP2`h>H0VP2`h>H10?ooo`00
W02`h>H01@21ZH40Fh9/05^2K01KPV`0PJV10080OZj;1@21ZH4=09S<WP03086YP@2SfJD0XmVU0140
XmVU00<0PJV10:ONY`2WgZL0502WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0
Y]bR00<0PJV10:;GW@2Reid0502Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0
RkZ51@21ZH4206jIK005086YP@18JDP0B6U804QYB021ZH40W02`h>H10?ooo`00W@2`h>H01021ZH40
Fh9/05^2K021ZH4607j^R`@0PJV12`2Hc9h00`21ZH40XmVU0:?IY@0@0:?IY@03086YP@2WgZL0YmjW
01@0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086YP@2Reid0X]NM
01@0X]NM00<0PJV109W<U02Ic9@0402Ic9@00`21ZH40RkZ508^jQ@0908^jQ@@0PJV11P1^VF`01021
ZH40B6U804QYB021ZH6M0;3PiP40oooo002N0;3PiP04086YP@1KPV`0Fh9/086YP@L0OZj;00<0PJV1
09C:W@21ZH401021ZH4609S<WP03086YP@2SfJD0XmVU0100XmVU00<0PJV10:ONY`2WgZL0502WgZL0
0`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV10:;GW@2Reid0502Reid0
0`21ZH40VLbD09W<U00@09W<U003086YP@2;^XD0RkZ500@0RkZ51@21ZH400`28^HD0PJV106jIK006
06jIK004086YP@18JDP0B6U8086YPIh0/>3V0@3oool009l0/>3V00@0PJV105^2K01KPV`0PJV11`1n
[X/00`21ZH40U<ZM09C:W@0309C:W@D0PJV10P2Hc9h00`21ZH40XmVU0:?IY@0?0:?IY@03086YP@2W
gZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086YP@2R
eid0X]NM01@0X]NM00<0PJV109W<U02Ic9@03`2Ic9@00`21ZH40RkZ508^jQ@05086YP@H0R;V500<0
PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6O0;3PiP40oooo002P0;3PiP04086YP@1K
PV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2DbYd0202DbYd<086YP@T0XmVU00<0PJV10:ONY`2WgZL0
4`2WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01D0Y]bR00<0PJV10:;GW@2Reid0
502Reid00`21ZH40VLbD09W<U00709W<U0`0PJV12P28^HD00`21ZH40KYU/06jIK00406jIK004086Y
P@18JDP0B6U8086YPJ00/>3V0@3oool00:40/>3V00@0PJV105^2K01KPV`0PJV11P1n[X/00`21ZH40
U<ZM09C:W@0:09C:W@03086YP@2Pf:D0X=RU00H0X=RU3`21ZH4A0:ONY`03086YP@2XgjH0Z=nV01D0
Z=nV00<0PJV10:KLXP2Vg:805@2Vg:800`21ZH40X]NM0:;GW@0?0:;GW@l0PJV1202HcID00`21ZH40
R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1X@2`h>H10?oo
o`00XP2`h>H00`21ZH40Fh9/086YP@0707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2P
f:D03`2Pf:D00`21ZH40Y]jX0:KNZ0030:KNZ0`0PJV11@2WgZL00`21ZH40Z=nV0:SOYP0E0:SOYP03
086YP@2Vg:80Y]bR01D0Y]bR00<0PJV10:;GW@2Reid00`2Reid<086YP@D0XMRN00<0PJV109S=U@2H
cID03`2HcID00`21ZH40R;V508RiQ@0908RiQ@03086YP@1^VF`0KYU/00D0KYU/00<0PJV104QYB021
ZH40XP2`h>H10?ooo`00XP2`h>H01021ZH40Fh9/05^2K021ZH4707j^R`03086YP@2DbYd0U<ZM00T0
U<ZM00<0PJV10:3HY@2Pf:D03`2Pf:D00`21ZH40Y]jX0:KNZ00>0:KNZ3/0PJV1402Qf9h00`21ZH40
V<fE09S=U@0?09S=U@03086YP@28^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40
B6U804QYB021ZH6R0;3PiP40oooo002S0;3PiP04086YP@1KPV`0Fh9/086YP@L0OZj;00<0PJV109C:
W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX01<0Y]jX00<0PJV10:OP
Y`2Wh:L05@2Wh:L00`21ZH40Y]jT0:KNY00E0:KNY003086YP@2Qf9h0XMRN01<0XMRN00<0PJV109S=
U@2HcID03P2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QY
B018JDP0PJV1X`2`h>H10?ooo`00Y02`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2DbYd0
U<ZM00X0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00B0:KNZ003086YP@2Wh:L0
Yn2W01D0Yn2W00<0PJV10:KNY02VgZ@05@2VgZ@00`21ZH40XMRN0:7HWP0B0:7HWP03086YP@2HcID0
V<fE00h0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK00406jIK004086YP@18JDP0
B6U8086YPJ@0/>3V0@3oool00:D0/>3V00@0PJV105^2K01KPV`0PJV11P1n[X/00`21ZH40U<ZM09C:
W@0909C:W@03086YP@2Pf:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04`2VgZP00`21ZH40Yn2W0:OP
Y`0D0:OPY`03086YP@2VgZ@0Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04`2Qf9h00`21ZH40V<fE09S=
U@0>09S=U@03086YP@28^HD0R;V500T0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U804QY
B021ZH6U0;3PiP40oooo002V0;3PiP<0PJV11`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2P
f:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04P2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2V
gZ@0Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0>09S=U@03086YP@28
^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`3086YPJH0/>3V0@3oool00:L0/>3V0`21ZH47
07j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21ZH40Y]jX0:KNZ00B
0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@0502VgZ@00`21ZH40XMRN0:7HWP0B
0:7HWP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK004
06jIK0<0PJV1Y`2`h>H10?ooo`00Z@2`h>H3086YP@H0OZj;00<0PJV109C:W@2DbYd0202DbYd00`21
ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L0502Wh:L00`21
ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0XMRN0140XMRN00<0PJV109S=U@2HcID03P2HcID00`21
ZH40R;V508RiQ@0908RiQ@03086YP@1^VF`0KYU/00<0KYU/0`21ZH6Y0;3PiP40oooo002Z0;3PiPD0
PJV10`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU00d0X=RU00<0PJV10:KNZ02V
gZP04@2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2VgZ@0Y]jT01<0Y]jT00<0PJV10:7HWP2Q
f9h04P2Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28^HD0R;V500T0R;V500@0PJV106jIK01^
VF`0KYU/1@21ZH6Z0;3PiP40oooo002[0;3PiP04086YP@1DNfH0PJV107BTP`D0PJV12`2DbYd00`21
ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L04`2Wh:L00`21
ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0140XMRN00<0PJV109S=U@2HcID03@2HcID00`21
ZH40R;V508RiQ@0:08RiQ@@0PJV100@0IY5X086YP@14IDP0PJV1Z`2`h>H10?ooo`00[02`h>H3086Y
P@@0M:B31@21ZH4809C:W@03086YP@2Pf:D0X=RU00`0X=RU00<0PJV10:KNZ02VgZP04@2VgZP00`21
ZH40Yn2W0:OPY`0C0:OPY`03086YP@2VgZ@0Y]jT01<0Y]jT00<0PJV10:7HWP2Qf9h04@2Qf9h00`21
ZH40V<fE09S=U@0<09S=U@03086YP@28^HD0R;V500L0R;V51@21ZH4306JAJ0<0PJV1[02`h>H10?oo
o`00[P2`h>H3086YP@@0M:B300<0PJV108_0UP2;`9H01P21ZH4209C:W@03086YP@2Pf:D0X=RU00d0
X=RU00<0PJV10:KNZ02VgZP0402VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2VgZ@0Y]jT01<0
Y]jT00<0PJV10:7HWP2Qf9h0402Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28^HD0R;V500L0
PJV10P1o/H401021ZH40IY5X06JAJ01VTFP3086YPJh0/>3V0@3oool00:l0/>3V00<0PJV105AkIP21
ZH40101dY8<00`21ZH40Rl2F08_0UP0508_0UPL0PJV12`2Pf:D00`21ZH40Y]jX0:KNZ00@0:KNZ003
086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7HWP0@0:7HWP03
086YP@2HcID0V<fE00T0V<fE1`21ZH4807naP@07086YP@1VTFP0IY5X06JAJ021ZH40A6E8086YP@2_
0;3PiP40oooo002`0;3PiP03086YP@1DNfH0PJV100@0M:B300<0PJV108_0UP2;`9H0202;`9H00`21
ZH40V=6P09SAX008086YP@@0X=RU00<0PJV10:KNZ02VgZP0402VgZP00`21ZH40Yn2W0:OPY`0B0:OP
Y`03086YP@2VgZ@0Y]jT0180Y]jT00<0PJV10:7HWP2Qf9h0402Qf9h00`21ZH40V<fE09S=U@0209S=
U@P0PJV10P2@aY400`21ZH40Ok6107naP@0807naP@80PJV10`1VTFP00`21ZH40A6E8086YP@2`0;3P
iP40oooo002a0;3PiP@0PJV10`1dY8<00`21ZH40Rl2F08_0UP0808_0UP03086YP@2HdJ00V=6P00L0
V=6P3P21ZH490:KNZ003086YP@2Wh:L0Yn2W0180Yn2W00<0PJV10:KNY02VgZ@04P2VgZ@00`21ZH40
XMRN0:7HWP070:7HWPh0PJV12@2@aY400`21ZH40Ok6107naP@0807naP@04086YP@1VTFP0IY5X06JA
J0@0PJV1/@2`h>H10?ooo`00/`2`h>H00`21ZH40E7]V086YP@0307BTP`03086YP@2;`9H0Rl2F00P0
Rl2F00<0PJV109SAX02HdJ002`2HdJ000`21ZH40WmVU09oIY@0609oIYCd0PJV1202JdY`00`21ZH40
T<JA0936T@0;0936T@03086YP@1o/H40Ok6100P0Ok6100L0PJV106JAJ01VTFP0IY5X086YP@14IDP0
PJV10;<0/>3V0@3oool00;@0/>3V0`21ZH4307BTP`80PJV12@2;`9H00`21ZH40V=6P09SAX00:09SA
X003086YP@2OfJD0WmVU00l0WmVU00<0PJV10:7KY@2QfjD04P2QfjD00`21ZH40X=VR0:3IXP0B0:3I
XP03086YP@2JdY`0V]:L00l0V]:L00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok6107naP@0807na
P@04086YP@1VTFP0IY5X06JAJ0<0PJV1]02`h>H10?ooo`00]@2`h>H4086YP@<0M:B300<0PJV108_0
UP2;`9H01`2;`9H00`21ZH40V=6P09SAX00:09SAX003086YP@2OfJD0WmVU00l0WmVU00<0PJV10:7K
Y@2QfjD04@2QfjD00`21ZH40X=VR0:3IXP0A0:3IXP03086YP@2JdY`0V]:L00l0V]:L00<0PJV10936
T@2@aY402P2@aY400`21ZH40Ok6107naP@0807naP@03086YP@1VTFP0IY5X00@0PJV1]@2`h>H10?oo
o`00]`2`h>H4086YP@80M:B300<0PJV108_0UP2;`9H01P2;`9H00`21ZH40V=6P09SAX00;09SAX003
086YP@2OfJD0WmVU00h0WmVU00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40X=VR0:3IXP0A0:3IXP03
086YP@2JdY`0V]:L00h0V]:L00<0PJV10936T@2@aY402`2@aY400`21ZH40Ok6107naP@0607naP@80
PJV100<0IY5X086YP@21ZH400P21ZH6g0;3PiP40oooo002i0;3PiP@0PJV100<0M:B3086YP@2;`9H0
1`2;`9H00`21ZH40V=6P09SAX00;09SAX003086YP@2OfJD0WmVU00d0WmVU00<0PJV10:7KY@2QfjD0
4@2QfjD00`21ZH40X=VR0:3IXP0A0:3IXP03086YP@2JdY`0V]:L00d0V]:L00<0PJV10936T@2@aY40
2`2@aY400`21ZH40Ok6107naP@0607naP@03086YP@1VTFP0PJV100<0PJV1^@2`h>H10?ooo`00^`2`
h>H5086YP@P0Rl2F00<0PJV109SAX02HdJ002P2HdJ000`21ZH40WmVU09oIY@0>09oIY@03086YP@2Q
fjD0XM^U0100XM^U00<0PJV10:3IXP2PfJ80402PfJ800`21ZH40V]:L09[BW00>09[BW003086YP@2@
aY40T<JA00X0T<JA00<0PJV107naP@1o/H401P1o/H45086YPK/0/>3V0@3oool00;`0/>3V1`21ZH46
08_0UP03086YP@2HdJ00V=6P00X0V=6P00<0PJV109oIY@2OfJD03@2OfJD00`21ZH40XM^U0:7KY@0@
0:7KY@03086YP@2PfJ80X=VR0100X=VR00<0PJV109[BW02JdY`03@2JdY`00`21ZH40T<JA0936T@0:
0936T@03086YP@1o/H40Ok6100@0Ok611`21ZH6l0;3PiP40oooo002n0;3PiP/0PJV100<0Rl2F086Y
P@2HdJ002`2HdJ000`21ZH40WmVU09oIY@0=09oIY@03086YP@2QfjD0XM^U00l0XM^U00<0PJV10:3I
XP2PfJ803`2PfJ800`21ZH40V]:L09[BW00=09[BW003086YP@2@aY40T<JA00X0T<JA00<0PJV107na
P@21ZH402P21ZH6n0;3PiP40oooo00300;3PiPD0PJV1101j[HP6086YP@T0V=6P00<0PJV109oIY@2O
fJD0302OfJD00`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2PfJ80X=VR00l0X=VR00<0PJV109[BW02J
dY`0302JdY`00`21ZH40T<JA0936T@070936T@H0PJV1101`X7H5086YPL00/>3V0@3oool00<80/>3V
0P21ZH400`1TTWD0PJV1086YP@0507Z]R080PJV100<0R;jC086YP@21ZH401@21ZH4209SAX003086Y
P@2OfJD0WmVU00`0WmVU00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40X=VR0:3IXP0?0:3IXP03086Y
P@2JdY`0V]:L00`0V]:L00<0PJV10936T@2@aY401`21ZH400`21]HH0PJV1086YP@05072PMP80PJV1
00<0FH9O086YP@21ZH40`P2`h>H10?ooo`00a02`h>H2086YP@0306BBM@21ZH40NZf800D0NZf800<0
PJV108RnT`28_Y<01@28_Y<;086YP@L0WmVU00<0PJV10:7KY@2QfjD03P2QfjD00`21ZH40X=VR0:3I
XP0>0:3IXP03086YP@2JdY`0V]:L00D0V]:L2`21ZH47086eQP03086YP@1`X7H0L:1f00@0L:1f00@0
PJV105V2G`21ZH40PJV1a02`h>H10?ooo`00a@2`h>H5086YP@D0NZf80P21ZH4908RnT`03086YP@2@
b9T0T<RI00@0T<RI<@21ZH4608c3T@03086YP@21]HH0PKF600L0PKF60P21ZH45072PMPD0PJV1a@2`
h>H10?ooo`00a`2`h>H5086YP@D0NZf800<0PJV108RnT`28_Y<01`28_Y<00`21ZH40T<RI0938V@0;
0938V@03086YP@2Cc9/0TlbK00d0TlbK00<0PJV109;:V02BbYP03@2BbYP00`21ZH40S<>A08c3T@0;
08c3T@03086YP@21]HH0PKF600L0PKF600<0PJV1072PMP1`X7H00`1`X7H5086YPLL0/>3V0@3oool0
0<X0/>3V1021ZH4407Z]R080PJV12028_Y<00`21ZH40T<RI0938V@0:0938V@03086YP@2Cc9/0TlbK
00d0TlbK00<0PJV109;:V02BbYP03@2BbYP00`21ZH40S<>A08c3T@0:08c3T@03086YP@21]HH0PKF6
00H0PKF60P21ZH44072PMP@0PJV1bP2`h>H10?ooo`00c@2`h>H4086YP@<0NZf800<0PJV108RnT`28
_Y<01P28_Y<2086YP@/0T<RI00<0PJV109?<V`2Cc9/0302Cc9/00`21ZH40T/ZH09;:V00<09;:V003
086YP@2<`i40S<>A00T0S<>A0P21ZH48086eQP04086YP@1`X7H0L:1f072PMP@0PJV1c@2`h>H10?oo
o`00d02`h>H7086YP@P0R;jC00<0PJV10938V@2@b9T02@2@b9T00`21ZH40TlbK09?<V`0;09?<V`03
086YP@2BbYP0T/ZH00/0T/ZH00<0PJV108c3T@2<`i402@2<`i400`21ZH40PKF6086eQP06086eQPL0
PJV1d02`h>H10?ooo`00d`2`h>H9086YP@@0R;jC00<0PJV10938V@2@b9T02@2@b9T00`21ZH40TlbK
09?<V`0:09?<V`03086YP@2BbYP0T/ZH00X0T/ZH00<0PJV108c3T@2<`i402@2<`i400`21ZH40PKF6
086eQP02086eQPT0PJV1d`2`h>H10?ooo`00eP2`h>HA086YP@D0T<RI00<0PJV109?<V`2Cc9/02P2C
c9/00`21ZH40T/ZH09;:V00:09;:V003086YP@2<`i40S<>A00<0S<>A2`21ZH400`1XUg80PJV1086Y
P@03086YPMH0/>3V0@3oool00=T0/>3V1@21ZH4406fNO080PJV10`1eZ88U086YP@<0LZAl0P21ZH44
06RGLPD0PJV1f@2`h>H10?ooo`00g02`h>H5086YP@<0KIil0P21ZH4807FXPP03086YP@1h[8@0N:b4
00P0N:b400<0PJV107N[PP1gZh80201gZh800`21ZH40LZAl07:TO00607:TO080PJV10`1XUg85086Y
PM`0/>3V0@3oool00>00/>3V2021ZH4707FXPP03086YP@1h[8@0N:b400L0N:b400<0PJV107N[PP1g
Zh801`1gZh800`21ZH40LZAl07:TO00507:TO0P0PJV1h02`h>H10?ooo`00iP2`h>H7086YP@<0MJR2
00<0PJV107R/Q01h[8@01P1h[8@00`21ZH40Mj^207N[PP0607N[PP04086YP@1bY7`0LZAl07:TO0L0
PJV1iP2`h>H10?ooo`00k@2`h>HI086YPNd0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.608 .781 .571 r
.47008 .46971 m .46978 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.608 .781 .571 r
.51009 .5 m .50999 .46977 L .47008 .46971 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.50999 .53023 m .51009 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.50999 .46977 m .51009 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.51009 .5 m .50999 .53023 L .5497 .53041 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.5497 .53041 m .5502 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.49958 .46343 m
.50116 .46202 L
s
.498 .46202 m
.49958 .46343 L
s
.50116 .46202 m
.49958 .46061 L
s
.49958 .46061 m
.498 .46202 L
s
.5 Mabswid
.601 .771 .56 r
.43078 .46941 m .43007 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.46978 .5 m .47008 .46971 L .43078 .46941 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.47008 .53029 m .46978 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.46978 .5 m .47008 .53029 L .50999 .53023 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.471 .43976 m .47008 .46971 L .50999 .46977 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.50999 .46977 m .50968 .43988 L .471 .43976 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.50968 .56012 m .50999 .53023 L .47008 .53029 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.50968 .43988 m .50999 .46977 L .5497 .46959 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.5502 .5 m .5497 .46959 L .50999 .46977 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.50999 .53023 m .50968 .56012 L .54817 .56047 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.54817 .56047 m .5497 .53041 L .50999 .53023 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.48729 .43981 m
.48733 .43693 L
s
.5 Mabswid
.615 .795 .578 r
.43291 .43918 m .43078 .46941 L .47008 .46971 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.47008 .46971 m .471 .43976 L .43291 .43918 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.43007 .5 m .43078 .53059 L .47008 .53029 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.471 .56024 m .47008 .53029 L .43078 .53059 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.47008 .53029 m .471 .56024 L .50968 .56012 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.52413 .4506 m
.52451 .45041 L
s
.52451 .45041 m
.52902 .44593 L
s
.5 Mabswid
.611 .786 .582 r
.5497 .46959 m .5502 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.5502 .5 m .5497 .53041 L .58839 .53084 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.58839 .53084 m .58931 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.5497 .46959 m .54817 .43953 L .50968 .43988 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.54817 .43953 m .5497 .46959 L .58839 .46916 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.58931 .5 m .58839 .46916 L .5497 .46959 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.5497 .53041 m .54817 .56047 L .58564 .56129 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.58564 .56129 m .58839 .53084 L .5497 .53041 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.47252 .41051 m .471 .43976 L .50968 .43988 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.50968 .43988 m .50918 .41067 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.50918 .41067 m .50968 .43988 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.50918 .58933 m .50968 .56012 L .471 .56024 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.50968 .56012 m .50918 .58933 L .54563 .58982 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.54563 .58982 m .54817 .56047 L .50968 .56012 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.47053 .43681 m
.47118 .43617 L
s
.5 Mabswid
.627 .816 .595 r
.43648 .40968 m .43291 .43918 L .471 .43976 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.471 .43976 m .47252 .41051 L .43648 .40968 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.43078 .53059 m .43291 .56082 L .471 .56024 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.47252 .58949 m .471 .56024 L .43291 .56082 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.471 .56024 m .47252 .58949 L .50918 .58933 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.39291 .46886 m .39179 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.43007 .5 m .43078 .46941 L .39291 .46886 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.43078 .53059 m .43007 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54132 .43446 m
.54353 .43197 L
s
.5 Mabswid
.604 .78 .564 r
.39627 .43812 m .39291 .46886 L .43078 .46941 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.43078 .46941 m .43291 .43918 L .39627 .43812 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.39179 .5 m .39291 .53114 L .43078 .53059 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.43291 .56082 m .43078 .53059 L .39291 .53114 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.54817 .43953 m .54563 .41018 L .50918 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.54563 .41018 m .54817 .43953 L .58564 .43871 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.58839 .46916 m .58564 .43871 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.54817 .56047 m .54563 .58982 L .58106 .59098 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.58106 .59098 m .58564 .56129 L .54817 .56047 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.58839 .46916 m .58931 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.58931 .5 m .58839 .53084 L .62519 .53151 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.62519 .53151 m .62652 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.47466 .38233 m .47252 .41051 L .50918 .41067 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.50918 .41067 m .50846 .38253 L .47466 .38233 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.50846 .61747 m .50918 .58933 L .47252 .58949 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.50846 .38253 m .50918 .41067 L .54563 .41018 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.50918 .58933 m .50846 .61747 L .54206 .61807 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.54206 .61807 m .54563 .58982 L .50918 .58933 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.39291 .53114 m .39627 .56188 L .43291 .56082 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.43648 .59032 m .43291 .56082 L .39627 .56188 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.43291 .56082 m .43648 .59032 L .47252 .58949 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.40187 .4082 m .39627 .43812 L .43291 .43918 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.43291 .43918 m .43648 .40968 L .40187 .4082 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.44147 .38133 m .43648 .40968 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.47252 .41051 m .47466 .38233 L .44147 .38133 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.47466 .61767 m .47252 .58949 L .43648 .59032 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.47252 .58949 m .47466 .61767 L .50846 .61747 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.58564 .43871 m .58839 .46916 L .62519 .46849 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.62652 .5 m .62519 .46849 L .58839 .46916 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.58839 .53084 m .58564 .56129 L .62122 .56259 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.62122 .56259 m .62519 .53151 L .58839 .53084 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.54563 .41018 m .54206 .38193 L .50846 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.54206 .38193 m .54563 .41018 L .58106 .40902 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.58564 .43871 m .58106 .40902 L .54563 .41018 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.54563 .58982 m .54206 .61807 L .57465 .61947 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.57465 .61947 m .58106 .59098 L .54563 .58982 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.58564 .56129 m .58106 .59098 L .61461 .59279 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.61461 .59279 m .62122 .56259 L .58564 .56129 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.58106 .40902 m .58564 .43871 L .62122 .43741 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.62519 .46849 m .62122 .43741 L .58564 .43871 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.35742 .46806 m .35589 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.39179 .5 m .39291 .46886 L .35742 .46806 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.39291 .53114 m .39179 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.40969 .37953 m .40187 .4082 L .43648 .40968 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.43648 .40968 m .44147 .38133 L .40969 .37953 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.39627 .56188 m .40187 .5918 L .43648 .59032 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.44147 .61867 m .43648 .59032 L .40187 .5918 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.43648 .59032 m .44147 .61867 L .47466 .61767 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.36201 .43659 m .35742 .46806 L .39291 .46886 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.39291 .46886 m .39627 .43812 L .36201 .43659 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.35589 .5 m .35742 .53194 L .39291 .53114 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.39627 .56188 m .39291 .53114 L .35742 .53194 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.47742 .35564 m .47466 .38233 L .50846 .38253 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.50846 .38253 m .50754 .35586 L .47742 .35564 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.50754 .64414 m .50846 .61747 L .47466 .61767 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.50754 .35586 m .50846 .38253 L .54206 .38193 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.50846 .61747 m .50754 .64414 L .53747 .64479 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.53747 .64479 m .54206 .61807 L .50846 .61747 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.44788 .35455 m .44147 .38133 L .47466 .38233 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.47466 .38233 m .47742 .35564 L .44788 .35455 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.47742 .64436 m .47466 .61767 L .44147 .61867 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.47466 .61767 m .47742 .64436 L .50754 .64414 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.36963 .40606 m .36201 .43659 L .39627 .43812 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.39627 .43812 m .40187 .4082 L .36963 .40606 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.35742 .53194 m .36201 .56341 L .39627 .56188 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.40187 .5918 m .39627 .56188 L .36201 .56341 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.58106 .40902 m .57465 .38053 L .54206 .38193 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.57465 .38053 m .58106 .40902 L .61461 .40721 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.62122 .43741 m .61461 .40721 L .58106 .40902 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.58106 .59098 m .57465 .61947 L .60538 .62166 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.60538 .62166 m .61461 .59279 L .58106 .59098 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.54206 .38193 m .53747 .35521 L .50754 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.53747 .35521 m .54206 .38193 L .57465 .38053 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.54206 .61807 m .53747 .64479 L .56643 .64632 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.56643 .64632 m .57465 .61947 L .54206 .61807 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.62519 .46849 m .62652 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.62652 .5 m .62519 .53151 L .6591 .53242 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.6591 .53242 m .66083 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.62122 .43741 m .62519 .46849 L .6591 .46758 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.66083 .5 m .6591 .46758 L .62519 .46849 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.62519 .53151 m .62122 .56259 L .6539 .56435 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.6539 .56435 m .6591 .53242 L .62519 .53151 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.62034 .43341 m
.62041 .43279 L
s
.5 Mabswid
.636 .838 .612 r
.41972 .3526 m .40969 .37953 L .44147 .38133 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.44147 .38133 m .44788 .35455 L .41972 .3526 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.40187 .5918 m .40969 .62047 L .44147 .61867 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.44788 .64545 m .44147 .61867 L .40969 .62047 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.44147 .61867 m .44788 .64545 L .47742 .64436 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.38025 .37696 m .36963 .40606 L .40187 .4082 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.40187 .4082 m .40969 .37953 L .38025 .37696 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.36201 .56341 m .36963 .59394 L .40187 .5918 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.40969 .62047 m .40187 .5918 L .36963 .59394 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.61461 .40721 m .62122 .43741 L .6539 .43565 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.6591 .46758 m .6539 .43565 L .62122 .43741 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.62122 .56259 m .61461 .59279 L .64528 .59525 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.64528 .59525 m .6539 .56435 L .62122 .56259 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.57465 .38053 m .56643 .35368 L .53747 .35521 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.56643 .35368 m .57465 .38053 L .60538 .37834 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.61461 .40721 m .60538 .37834 L .57465 .38053 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.57465 .61947 m .56643 .64632 L .59358 .6487 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.59358 .6487 m .60538 .62166 L .57465 .61947 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.3254 .46703 m .32346 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.35589 .5 m .35742 .46806 L .3254 .46703 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.35742 .53194 m .35589 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.48078 .33093 m .47742 .35564 L .50754 .35586 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.50754 .35586 m .50642 .33115 L .48078 .33093 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.50642 .33115 m .50754 .35586 L .53747 .35521 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.50642 .66885 m .50754 .64414 L .47742 .64436 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.50754 .64414 m .50642 .66885 L .53187 .6695 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.53187 .6695 m .53747 .64479 L .50754 .64414 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.33119 .4346 m .3254 .46703 L .35742 .46806 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.35742 .46806 m .36201 .43659 L .33119 .4346 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.32346 .5 m .3254 .53297 L .35742 .53194 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.36201 .56341 m .35742 .53194 L .3254 .53297 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.4557 .32985 m .44788 .35455 L .47742 .35564 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.47742 .35564 m .48078 .33093 L .4557 .32985 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.48078 .66907 m .47742 .64436 L .44788 .64545 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.47742 .64436 m .48078 .66907 L .50642 .66885 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.60538 .37834 m .61461 .40721 L .64528 .40475 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.6539 .43565 m .64528 .40475 L .61461 .40721 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.61461 .59279 m .60538 .62166 L .6333 .62462 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.6333 .62462 m .64528 .59525 L .61461 .59279 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.53747 .35521 m .53187 .3305 L .50642 .33115 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.53187 .3305 m .53747 .35521 L .56643 .35368 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.53747 .64479 m .53187 .6695 L .55641 .67102 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.55641 .67102 m .56643 .64632 L .53747 .64479 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.39379 .3498 m .38025 .37696 L .40969 .37953 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.40969 .37953 m .41972 .3526 L .39379 .3498 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.36963 .59394 m .38025 .62304 L .40969 .62047 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.41972 .6474 m .40969 .62047 L .38025 .62304 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.40969 .62047 m .41972 .6474 L .44788 .64545 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.34079 .40328 m .33119 .4346 L .36201 .43659 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.36201 .43659 m .36963 .40606 L .34079 .40328 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.3254 .53297 m .33119 .5654 L .36201 .56341 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.36963 .59394 m .36201 .56341 L .33119 .5654 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.4319 .32791 m .41972 .3526 L .44788 .35455 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.44788 .35455 m .4557 .32985 L .4319 .32791 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.4557 .67015 m .44788 .64545 L .41972 .6474 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.44788 .64545 m .4557 .67015 L .48078 .66907 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.35411 .37361 m .34079 .40328 L .36963 .40606 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.36963 .40606 m .38025 .37696 L .35411 .37361 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.33119 .5654 m .34079 .59672 L .36963 .59394 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.38025 .62304 m .36963 .59394 L .34079 .59672 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.56643 .35368 m .55641 .32898 L .53187 .3305 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.55641 .32898 m .56643 .35368 L .59358 .3513 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.60538 .37834 m .59358 .3513 L .56643 .35368 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.56643 .64632 m .55641 .67102 L .57927 .67338 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.57927 .67338 m .59358 .6487 L .56643 .64632 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.6591 .46758 m .66083 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.66083 .5 m .6591 .53242 L .68892 .53358 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.68892 .53358 m .69106 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.59358 .3513 m .60538 .37834 L .6333 .37538 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.64528 .40475 m .6333 .37538 L .60538 .37834 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.60538 .62166 m .59358 .6487 L .61805 .65191 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.61805 .65191 m .6333 .62462 L .60538 .62166 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.6539 .43565 m .6591 .46758 L .68892 .46642 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.69106 .5 m .68892 .46642 L .6591 .46758 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.6591 .53242 m .6539 .56435 L .68254 .56657 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.68254 .56657 m .68892 .53358 L .6591 .53242 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.64528 .40475 m .6539 .43565 L .68254 .43343 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.68892 .46642 m .68254 .43343 L .6539 .43565 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.6539 .56435 m .64528 .59525 L .67199 .59835 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.67199 .59835 m .68254 .56657 L .6539 .56435 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41017 .32514 m .39379 .3498 L .41972 .3526 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41972 .3526 m .4319 .32791 L .41017 .32514 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.38025 .62304 m .39379 .6502 L .41972 .6474 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.4319 .67209 m .41972 .6474 L .39379 .6502 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.41972 .6474 m .4319 .67209 L .4557 .67015 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.48475 .30872 m .48078 .33093 L .50642 .33115 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.50642 .33115 m .5051 .30892 L .48475 .30872 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.5051 .30892 m .50642 .33115 L .53187 .3305 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.5051 .69108 m .50642 .66885 L .48078 .66907 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.50642 .66885 m .5051 .69108 L .52528 .69167 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.52528 .69167 m .53187 .6695 L .50642 .66885 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.4649 .30775 m .4557 .32985 L .48078 .33093 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.48078 .33093 m .48475 .30872 L .4649 .30775 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.48475 .69128 m .48078 .66907 L .4557 .67015 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.48078 .66907 m .48475 .69128 L .5051 .69108 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.37101 .34619 m .35411 .37361 L .38025 .37696 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.38025 .37696 m .39379 .3498 L .37101 .34619 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.34079 .59672 m .35411 .62639 L .38025 .62304 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.39379 .6502 m .38025 .62304 L .35411 .62639 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.53187 .3305 m .52528 .30833 L .5051 .30892 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.52528 .30833 m .53187 .3305 L .55641 .32898 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.53187 .6695 m .52528 .69167 L .54465 .69302 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.54465 .69302 m .55641 .67102 L .53187 .6695 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.6333 .37538 m .64528 .40475 L .67199 .40165 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.68254 .43343 m .67199 .40165 L .64528 .40475 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.64528 .59525 m .6333 .62462 L .65738 .62833 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.65738 .62833 m .67199 .59835 L .64528 .59525 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.59358 .3513 m .57927 .32662 L .55641 .32898 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.57927 .32662 m .59358 .3513 L .61805 .34809 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.6333 .37538 m .61805 .34809 L .59358 .3513 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59358 .6487 m .57927 .67338 L .59968 .67653 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59968 .67653 m .61805 .65191 L .59358 .6487 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.44617 .30602 m .4319 .32791 L .4557 .32985 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.4557 .32985 m .4649 .30775 L .44617 .30602 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4649 .69225 m .4557 .67015 L .4319 .67209 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.4557 .67015 m .4649 .69225 L .48475 .69128 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.29812 .46575 m .29579 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.32346 .5 m .3254 .46703 L .29812 .46575 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.3254 .53297 m .32346 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.30507 .43216 m .29812 .46575 L .3254 .46703 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.3254 .46703 m .33119 .4346 L .30507 .43216 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.29579 .5 m .29812 .53425 L .3254 .53297 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.33119 .5654 m .3254 .53297 L .29812 .53425 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.55641 .32898 m .54465 .30698 L .52528 .30833 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.54465 .30698 m .55641 .32898 L .57927 .32662 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.55641 .67102 m .54465 .69302 L .56257 .69512 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.56257 .69512 m .57927 .67338 L .55641 .67102 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.31654 .39987 m .30507 .43216 L .33119 .4346 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.33119 .4346 m .34079 .40328 L .31654 .39987 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.29812 .53425 m .30507 .56784 L .33119 .5654 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.34079 .59672 m .33119 .5654 L .30507 .56784 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.61805 .34809 m .6333 .37538 L .65738 .37167 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.67199 .40165 m .65738 .37167 L .6333 .37538 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6333 .62462 m .61805 .65191 L .6389 .65589 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6389 .65589 m .65738 .62833 L .6333 .62462 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.3913 .3216 m .37101 .34619 L .39379 .3498 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.39379 .3498 m .41017 .32514 L .3913 .3216 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.35411 .62639 m .37101 .65381 L .39379 .6502 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.41017 .67486 m .39379 .6502 L .37101 .65381 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.39379 .6502 m .41017 .67486 L .4319 .67209 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.42923 .30356 m .41017 .32514 L .4319 .32791 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.4319 .32791 m .44617 .30602 L .42923 .30356 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.44617 .69398 m .4319 .67209 L .41017 .67486 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4319 .67209 m .44617 .69398 L .4649 .69225 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.33238 .36955 m .31654 .39987 L .34079 .40328 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.34079 .40328 m .35411 .37361 L .33238 .36955 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.30507 .56784 m .31654 .60013 L .34079 .59672 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.35411 .62639 m .34079 .59672 L .31654 .60013 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.57927 .32662 m .56257 .30488 L .54465 .30698 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.56257 .30488 m .57927 .32662 L .59968 .32347 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.61805 .34809 m .59968 .32347 L .57927 .32662 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57927 .67338 m .56257 .69512 L .57837 .69792 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57837 .69792 m .59968 .67653 L .57927 .67338 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.68892 .46642 m .69106 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.69106 .5 m .68892 .53358 L .71329 .53497 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.71329 .53497 m .7158 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.48931 .28962 m .48475 .30872 L .5051 .30892 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.5051 .30892 m .50357 .28977 L .48931 .28962 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50357 .28977 m .5051 .30892 L .52528 .30833 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.50357 .71023 m .5051 .69108 L .48475 .69128 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.5051 .69108 m .50357 .71023 L .51772 .71068 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.51772 .71068 m .52528 .69167 L .5051 .69108 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.47542 .28887 m .4649 .30775 L .48475 .30872 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.48475 .30872 m .48931 .28962 L .47542 .28887 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.68254 .43343 m .68892 .46642 L .71329 .46503 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.7158 .5 m .71329 .46503 L .68892 .46642 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.68892 .53358 m .68254 .56657 L .7058 .56923 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.7058 .56923 m .71329 .53497 L .68892 .53358 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.48931 .71038 m .48475 .69128 L .4649 .69225 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.48475 .69128 m .48931 .71038 L .50357 .71023 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.59968 .32347 m .61805 .34809 L .6389 .34411 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.65738 .37167 m .6389 .34411 L .61805 .34809 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.61805 .65191 m .59968 .67653 L .6168 .68043 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.6168 .68043 m .6389 .65589 L .61805 .65191 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35235 .34184 m .33238 .36955 L .35411 .37361 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35411 .37361 m .37101 .34619 L .35235 .34184 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.31654 .60013 m .33238 .63045 L .35411 .62639 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.37101 .65381 m .35411 .62639 L .33238 .63045 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.52528 .30833 m .51772 .28932 L .50357 .28977 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.51772 .28932 m .52528 .30833 L .54465 .30698 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.52528 .69167 m .51772 .71068 L .53123 .71173 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.53123 .71173 m .54465 .69302 L .52528 .69167 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.67199 .40165 m .68254 .43343 L .7058 .43077 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.71329 .46503 m .7058 .43077 L .68254 .43343 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.68254 .56657 m .67199 .59835 L .69345 .60204 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.69345 .60204 m .7058 .56923 L .68254 .56657 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4624 .28754 m .44617 .30602 L .4649 .30775 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4649 .30775 m .47542 .28887 L .4624 .28754 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.47542 .71113 m .4649 .69225 L .44617 .69398 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.4649 .69225 m .47542 .71113 L .48931 .71038 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41472 .30044 m .3913 .3216 L .41017 .32514 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41017 .32514 m .42923 .30356 L .41472 .30044 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.37101 .65381 m .3913 .6784 L .41017 .67486 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.42923 .69644 m .41017 .67486 L .3913 .6784 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.41017 .67486 m .42923 .69644 L .44617 .69398 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.54465 .30698 m .53123 .28827 L .51772 .28932 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.53123 .28827 m .54465 .30698 L .56257 .30488 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54465 .69302 m .53123 .71173 L .54362 .71333 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54362 .71333 m .56257 .69512 L .54465 .69302 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.65738 .37167 m .67199 .40165 L .69345 .39796 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.7058 .43077 m .69345 .39796 L .67199 .40165 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67199 .59835 m .65738 .62833 L .67646 .63273 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67646 .63273 m .69345 .60204 L .67199 .59835 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37612 .31737 m .35235 .34184 L .37101 .34619 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37101 .34619 m .3913 .3216 L .37612 .31737 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.33238 .63045 m .35235 .65816 L .37101 .65381 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.3913 .6784 m .37101 .65381 L .35235 .65816 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.45076 .28567 m .42923 .30356 L .44617 .30602 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.44617 .30602 m .4624 .28754 L .45076 .28567 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.4624 .71246 m .44617 .69398 L .42923 .69644 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.44617 .69398 m .4624 .71246 L .47542 .71113 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.59968 .32347 m .57837 .30208 L .56257 .30488 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.57837 .30208 m .59968 .32347 L .6168 .31957 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.6389 .34411 m .6168 .31957 L .59968 .32347 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59968 .67653 m .57837 .69792 L .59141 .70134 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59141 .70134 m .6168 .68043 L .59968 .67653 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.6389 .34411 m .65738 .37167 L .67646 .36727 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.69345 .39796 m .67646 .36727 L .65738 .37167 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65738 .62833 m .6389 .65589 L .65512 .66059 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65512 .66059 m .67646 .63273 L .65738 .62833 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.27706 .46425 m .27438 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.29579 .5 m .29812 .46575 L .27706 .46425 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.29812 .53425 m .29579 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.28506 .42929 m .27706 .46425 L .29812 .46575 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.29812 .46575 m .30507 .43216 L .28506 .42929 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.27438 .5 m .27706 .53575 L .29812 .53425 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.30507 .56784 m .29812 .53425 L .27706 .53575 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.56257 .30488 m .54362 .28667 L .53123 .28827 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.54362 .28667 m .56257 .30488 L .57837 .30208 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.56257 .69512 m .54362 .71333 L .5544 .71545 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.5544 .71545 m .57837 .69792 L .56257 .69512 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.29822 .3959 m .28506 .42929 L .30507 .43216 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.30507 .43216 m .31654 .39987 L .29822 .3959 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.27706 .53575 m .28506 .57071 L .30507 .56784 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.31654 .60013 m .30507 .56784 L .28506 .57071 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.44095 .28331 m .41472 .30044 L .42923 .30356 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.42923 .30356 m .45076 .28567 L .44095 .28331 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.3913 .6784 m .41472 .69956 L .42923 .69644 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.45076 .71433 m .42923 .69644 L .41472 .69956 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.42923 .69644 m .45076 .71433 L .4624 .71246 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.6168 .31957 m .6389 .34411 L .65512 .33941 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.67646 .36727 m .65512 .33941 L .6389 .34411 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.6389 .65589 m .6168 .68043 L .62982 .68498 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.62982 .68498 m .65512 .66059 L .6389 .65589 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.40332 .29675 m .37612 .31737 L .3913 .3216 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.3913 .3216 m .41472 .30044 L .40332 .29675 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.35235 .65816 m .37612 .68263 L .3913 .6784 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.41472 .69956 m .3913 .6784 L .37612 .68263 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31627 .36485 m .29822 .3959 L .31654 .39987 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31654 .39987 m .33238 .36955 L .31627 .36485 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.28506 .57071 m .29822 .6041 L .31654 .60013 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.33238 .63045 m .31654 .60013 L .29822 .6041 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.49441 .27429 m .48931 .28962 L .50357 .28977 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.50357 .28977 m .50187 .27437 L .49441 .27429 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50187 .27437 m .50357 .28977 L .51772 .28932 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.50187 .72563 m .50357 .71023 L .48931 .71038 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50357 .71023 m .50187 .72563 L .50926 .72588 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50926 .72588 m .51772 .71068 L .50357 .71023 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48716 .27387 m .47542 .28887 L .48931 .28962 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48931 .28962 m .49441 .27429 L .48716 .27387 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.49441 .72571 m .48931 .71038 L .47542 .71113 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.48931 .71038 m .49441 .72571 L .50187 .72563 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51772 .28932 m .50926 .27412 L .50187 .27437 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.50926 .27412 m .51772 .28932 L .53123 .28827 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51772 .71068 m .50926 .72588 L .51628 .72647 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51628 .72647 m .53123 .71173 L .51772 .71068 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33884 .33683 m .31627 .36485 L .33238 .36955 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33238 .36955 m .35235 .34184 L .33884 .33683 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.29822 .6041 m .31627 .63515 L .33238 .63045 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.35235 .65816 m .33238 .63045 L .31627 .63515 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.48043 .27312 m .4624 .28754 L .47542 .28887 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.47542 .28887 m .48716 .27387 L .48043 .27312 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.48716 .72613 m .47542 .71113 L .4624 .71246 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.47542 .71113 m .48716 .72613 L .49441 .72571 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.57837 .30208 m .5544 .28455 L .54362 .28667 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.5544 .28455 m .57837 .30208 L .59141 .29866 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.6168 .31957 m .59141 .29866 L .57837 .30208 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.57837 .69792 m .5544 .71545 L .56312 .71802 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.56312 .71802 m .59141 .70134 L .57837 .69792 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.53123 .28827 m .51628 .27353 L .50926 .27412 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.51628 .27353 m .53123 .28827 L .54362 .28667 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.53123 .71173 m .51628 .72647 L .52266 .72736 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.52266 .72736 m .54362 .71333 L .53123 .71173 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.59141 .29866 m .6168 .31957 L .62982 .31502 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.65512 .33941 m .62982 .31502 L .6168 .31957 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.6168 .68043 m .59141 .70134 L .60104 .70529 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.60104 .70529 m .62982 .68498 L .6168 .68043 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.47448 .27209 m .45076 .28567 L .4624 .28754 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.4624 .28754 m .48043 .27312 L .47448 .27209 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.48043 .72688 m .4624 .71246 L .45076 .71433 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.4624 .71246 m .48043 .72688 L .48716 .72613 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.71329 .46503 m .7158 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.7158 .5 m .71329 .53497 L .73061 .53658 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.73061 .53658 m .73345 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.7058 .43077 m .71329 .46503 L .73061 .46342 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.73345 .5 m .73061 .46342 L .71329 .46503 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.71329 .53497 m .7058 .56923 L .72215 .57228 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.72215 .57228 m .73061 .53658 L .71329 .53497 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.36548 .31254 m .33884 .33683 L .35235 .34184 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.35235 .34184 m .37612 .31737 L .36548 .31254 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.31627 .63515 m .33884 .66317 L .35235 .65816 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.37612 .68263 m .35235 .65816 L .33884 .66317 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.43343 .28055 m .40332 .29675 L .41472 .30044 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.41472 .30044 m .44095 .28331 L .43343 .28055 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.37612 .68263 m .40332 .70325 L .41472 .69956 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.44095 .71669 m .41472 .69956 L .40332 .70325 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.41472 .69956 m .44095 .71669 L .45076 .71433 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.69345 .39796 m .7058 .43077 L .72215 .42772 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.73061 .46342 m .72215 .42772 L .7058 .43077 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.7058 .56923 m .69345 .60204 L .70827 .60627 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.70827 .60627 m .72215 .57228 L .7058 .56923 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.54362 .28667 m .52266 .27264 L .51628 .27353 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.52266 .27264 m .54362 .28667 L .5544 .28455 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.54362 .71333 m .52266 .72736 L .52813 .72853 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.52813 .72853 m .5544 .71545 L .54362 .71333 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.67646 .36727 m .69345 .39796 L .70827 .39373 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.72215 .42772 m .70827 .39373 L .69345 .39796 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.69345 .60204 m .67646 .63273 L .68929 .63772 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.68929 .63772 m .70827 .60627 L .69345 .60204 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.46955 .2708 m .44095 .28331 L .45076 .28567 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.45076 .28567 m .47448 .27209 L .46955 .2708 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.47448 .72791 m .45076 .71433 L .44095 .71669 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.45076 .71433 m .47448 .72791 L .48043 .72688 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.33884 .66317 m .36548 .68746 L .37612 .68263 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.40332 .70325 m .37612 .68263 L .36548 .68746 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.39561 .29258 m .36548 .31254 L .37612 .31737 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.37612 .31737 m .40332 .29675 L .39561 .29258 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.65512 .33941 m .67646 .36727 L .68929 .36228 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.70827 .39373 m .68929 .36228 L .67646 .36727 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.67646 .63273 m .65512 .66059 L .66565 .66587 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.66565 .66587 m .68929 .63772 L .67646 .63273 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.59141 .29866 m .56312 .28198 L .5544 .28455 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.56312 .28198 m .59141 .29866 L .60104 .29471 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.62982 .31502 m .60104 .29471 L .59141 .29866 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.59141 .70134 m .56312 .71802 L .56935 .72096 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.56935 .72096 m .60104 .70529 L .59141 .70134 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.5544 .28455 m .52813 .27147 L .52266 .27264 L p F P
.505 .664 .505 r
s
.582 .805 .615 r
.52813 .27147 m .5544 .28455 L .56312 .28198 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.5544 .71545 m .52813 .72853 L .53245 .72993 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.53245 .72993 m .56312 .71802 L .5544 .71545 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.62982 .31502 m .65512 .33941 L .66565 .33413 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.68929 .36228 m .66565 .33413 L .65512 .33941 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.65512 .66059 m .62982 .68498 L .63789 .69005 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.63789 .69005 m .66565 .66587 L .65512 .66059 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.46589 .2693 m .43343 .28055 L .44095 .28331 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.44095 .28331 m .46955 .2708 L .46589 .2693 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.40332 .70325 m .43343 .71945 L .44095 .71669 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.46955 .7292 m .44095 .71669 L .43343 .71945 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.44095 .71669 m .46955 .7292 L .47448 .72791 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.42859 .27747 m .39561 .29258 L .40332 .29675 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.40332 .29675 m .43343 .28055 L .42859 .27747 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.36548 .68746 m .39561 .70742 L .40332 .70325 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.43343 .71945 m .40332 .70325 L .39561 .70742 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.26391 .46256 m .26093 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.27438 .5 m .27706 .46425 L .26391 .46256 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.27706 .53575 m .27438 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.556 .775 .586 r
.50187 .27437 m .5 .26345 L .49441 .27429 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50926 .27412 m .5 .26345 L .50187 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50187 .72563 L .49441 .72571 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .50926 .72588 L .50187 .72563 L closepath p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27276 .42606 m .26391 .46256 L .27706 .46425 L p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27706 .46425 m .28506 .42929 L .27276 .42606 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.26093 .5 m .26391 .53744 L .27706 .53575 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.28506 .57071 m .27706 .53575 L .26391 .53744 L p F P
.505 .664 .505 r
s
.554 .772 .584 r
.49441 .27429 m .5 .26345 L .48716 .27387 L closepath p F P
.505 .664 .505 r
s
.201 .208 .158 r
.5 .73655 m .49441 .72571 L .48716 .72613 L closepath p F P
.505 .664 .505 r
s
.549 .758 .592 r
.60104 .29471 m .62982 .31502 L .63789 .30995 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.66565 .33413 m .63789 .30995 L .62982 .31502 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.62982 .68498 m .60104 .70529 L .60667 .70964 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.60667 .70964 m .63789 .69005 L .62982 .68498 L p F P
.505 .664 .505 r
s
.554 .773 .587 r
.51628 .27353 m .5 .26345 L .50926 .27412 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51628 .72647 L .50926 .72588 L closepath p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28726 .39146 m .27276 .42606 L .28506 .42929 L p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28506 .42929 m .29822 .3959 L .28726 .39146 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.26391 .53744 m .27276 .57394 L .28506 .57071 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.29822 .6041 m .28506 .57071 L .27276 .57394 L p F P
.505 .664 .505 r
s
.55 .767 .58 r
.48716 .27387 m .5 .26345 L .48043 .27312 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48716 .72613 L .48043 .72688 L closepath p F P
.505 .664 .505 r
s
.582 .805 .615 r
.56312 .28198 m .53245 .27007 L .52813 .27147 L p F P
.505 .664 .505 r
s
.563 .782 .6 r
.53245 .27007 m .56312 .28198 L .56935 .27904 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.60104 .29471 m .56935 .27904 L .56312 .28198 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.56312 .71802 m .53245 .72993 L .53542 .73151 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.53542 .73151 m .56935 .72096 L .56312 .71802 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.30703 .35961 m .28726 .39146 L .29822 .3959 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.29822 .3959 m .31627 .36485 L .30703 .35961 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.27276 .57394 m .28726 .60854 L .29822 .6041 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.31627 .63515 m .29822 .6041 L .28726 .60854 L p F P
.505 .664 .505 r
s
.551 .769 .585 r
.52266 .27264 m .5 .26345 L .51628 .27353 L closepath p F P
.505 .664 .505 r
s
.197 .203 .154 r
.5 .73655 m .52266 .72736 L .51628 .72647 L closepath p F P
.505 .664 .505 r
s
.544 .761 .575 r
.48043 .27312 m .5 .26345 L .47448 .27209 L closepath p F P
.505 .664 .505 r
s
.197 .203 .155 r
.5 .73655 m .48043 .72688 L .47448 .72791 L closepath p F P
.505 .664 .505 r
s
.422 .581 .408 r
.33154 .33131 m .30703 .35961 L .31627 .36485 L p F P
.505 .664 .505 r
s
.422 .581 .408 r
.31627 .36485 m .33884 .33683 L .33154 .33131 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.28726 .60854 m .30703 .64039 L .31627 .63515 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.33884 .66317 m .31627 .63515 L .30703 .64039 L p F P
.505 .664 .505 r
s
.546 .764 .581 r
.52813 .27147 m .5 .26345 L .52266 .27264 L closepath p F P
.505 .664 .505 r
s
.192 .199 .152 r
.5 .73655 m .52813 .72853 L .52266 .72736 L closepath p F P
.505 .664 .505 r
s
.547 .76 .59 r
.56935 .27904 m .60104 .29471 L .60667 .29036 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.63789 .30995 m .60667 .29036 L .60104 .29471 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.60104 .70529 m .56935 .72096 L .57273 .72415 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.57273 .72415 m .60667 .70964 L .60104 .70529 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.46365 .26765 m .42859 .27747 L .43343 .28055 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.43343 .28055 m .46589 .2693 L .46365 .26765 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.39561 .70742 m .42859 .72253 L .43343 .71945 L p F P
.505 .664 .505 r
s
.2 .206 .157 r
.46589 .7307 m .43343 .71945 L .42859 .72253 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.43343 .71945 m .46589 .7307 L .46955 .7292 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.36017 .30728 m .33154 .33131 L .33884 .33683 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.33884 .33683 m .36548 .31254 L .36017 .30728 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.30703 .64039 m .33154 .66869 L .33884 .66317 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.36548 .68746 m .33884 .66317 L .33154 .66869 L p F P
.505 .664 .505 r
s
.537 .753 .568 r
.47448 .27209 m .5 .26345 L .46955 .2708 L closepath p F P
.505 .664 .505 r
s
.193 .199 .152 r
.5 .73655 m .47448 .72791 L .46955 .7292 L closepath p F P
.505 .664 .505 r
s
.539 .756 .576 r
.53245 .27007 m .5 .26345 L .52813 .27147 L closepath p F P
.505 .664 .505 r
s
.187 .194 .148 r
.5 .73655 m .53245 .72993 L .52813 .72853 L closepath p F P
.505 .664 .505 r
s
.471 .657 .477 r
.39217 .28809 m .36017 .30728 L .36548 .31254 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.36548 .31254 m .39561 .29258 L .39217 .28809 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.33154 .66869 m .36017 .69272 L .36548 .68746 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.39561 .70742 m .36548 .68746 L .36017 .69272 L p F P
.505 .664 .505 r
s
.529 .742 .561 r
.46955 .2708 m .5 .26345 L .46589 .2693 L closepath p F P
.505 .664 .505 r
s
.187 .195 .148 r
.5 .73655 m .46955 .7292 L .46589 .7307 L closepath p F P
.505 .664 .505 r
s
.563 .782 .6 r
.56935 .27904 m .53542 .26849 L .53245 .27007 L p F P
.505 .664 .505 r
s
.538 .753 .58 r
.53542 .26849 m .56935 .27904 L .57273 .27585 L p F P
.505 .664 .505 r
s
.547 .76 .59 r
.60667 .29036 m .57273 .27585 L .56935 .27904 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.56935 .72096 m .53542 .73151 L .53689 .73321 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.53689 .73321 m .57273 .72415 L .56935 .72096 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.42673 .27419 m .39217 .28809 L .39561 .29258 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.39561 .29258 m .42859 .27747 L .42673 .27419 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.36017 .69272 m .39217 .71191 L .39561 .70742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.42859 .72253 m .39561 .70742 L .39217 .71191 L p F P
.505 .664 .505 r
s
.531 .746 .57 r
.53542 .26849 m .5 .26345 L .53245 .27007 L closepath p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .53542 .73151 L .53245 .72993 L closepath p F P
.505 .664 .505 r
s
.52 .731 .553 r
.46589 .2693 m .5 .26345 L .46365 .26765 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.42859 .72253 m .46365 .73235 L .46589 .7307 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .46589 .7307 L .46365 .73235 L closepath p F P
.505 .664 .505 r
s
.301 .396 .336 r
.73061 .46342 m .73345 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73345 .5 m .73061 .53658 L .73916 .53835 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73916 .53835 m .74225 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.72215 .42772 m .73061 .46342 L .73916 .46165 L p F P
.505 .664 .505 r
s
.301 .396 .336 r
.74225 .5 m .73916 .46165 L .73061 .46342 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.73061 .53658 m .72215 .57228 L .72998 .57566 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.72998 .57566 m .73916 .53835 L .73061 .53658 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.70827 .39373 m .72215 .42772 L .72998 .42434 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.73916 .46165 m .72998 .42434 L .72215 .42772 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.72215 .57228 m .70827 .60627 L .71499 .61091 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.71499 .61091 m .72998 .57566 L .72215 .57228 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.46298 .26592 m .42673 .27419 L .42859 .27747 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.42859 .27747 m .46365 .26765 L .46298 .26592 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.39217 .71191 m .42673 .72581 L .42859 .72253 L p F P
.505 .664 .505 r
s
.182 .189 .144 r
.46365 .73235 m .42859 .72253 L .42673 .72581 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.68929 .36228 m .70827 .39373 L .71499 .38909 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.72998 .42434 m .71499 .38909 L .70827 .39373 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.70827 .60627 m .68929 .63772 L .69462 .64316 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.69462 .64316 m .71499 .61091 L .70827 .60627 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.66565 .33413 m .68929 .36228 L .69462 .35684 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.71499 .38909 m .69462 .35684 L .68929 .36228 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.68929 .63772 m .66565 .66587 L .66947 .67158 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.66947 .67158 m .69462 .64316 L .68929 .63772 L p F P
.505 .664 .505 r
s
.522 .735 .562 r
.53689 .26679 m .5 .26345 L .53542 .26849 L closepath p F P
.505 .664 .505 r
s
.538 .753 .58 r
.57273 .27585 m .53689 .26679 L .53542 .26849 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .53689 .73321 L .53542 .73151 L closepath p F P
.505 .664 .505 r
s
.461 .645 .517 r
.63789 .30995 m .66565 .33413 L .66947 .32842 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.69462 .35684 m .66947 .32842 L .66565 .33413 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.66565 .66587 m .63789 .69005 L .64026 .69546 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.64026 .69546 m .66947 .67158 L .66565 .66587 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.63789 .69005 m .60667 .70964 L .60781 .71423 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.60781 .71423 m .64026 .69546 L .63789 .69005 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.60667 .29036 m .63789 .30995 L .64026 .30454 L p F P
.505 .664 .505 r
s
.461 .645 .517 r
.66947 .32842 m .64026 .30454 L .63789 .30995 L p F P
.505 .664 .505 r
s
.509 .719 .544 r
.46365 .26765 m .5 .26345 L .46298 .26592 L closepath p F P
.505 .664 .505 r
s
.182 .189 .144 r
.42673 .72581 m .46298 .73408 L .46365 .73235 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .46365 .73235 L .46298 .73408 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.60667 .70964 m .57273 .72415 L .573 .72747 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.573 .72747 m .60781 .71423 L .60667 .70964 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.57273 .27585 m .60667 .29036 L .60781 .28577 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.64026 .30454 m .60781 .28577 L .60667 .29036 L p F P
.505 .664 .505 r
s
.507 .716 .555 r
.53689 .26679 m .57273 .27585 L .573 .27253 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.60781 .28577 m .573 .27253 L .57273 .27585 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.57273 .72415 m .53689 .73321 L .53675 .73495 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.53675 .73495 m .573 .72747 L .57273 .72415 L p F P
.505 .664 .505 r
s
.511 .722 .553 r
.53675 .26505 m .5 .26345 L .53689 .26679 L closepath p F P
.505 .664 .505 r
s
.507 .716 .555 r
.573 .27253 m .53675 .26505 L .53689 .26679 L p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .53675 .73495 L .53689 .73321 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48265 .74128 L .49008 .74195 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .47605 .74028 L .48265 .74128 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .47058 .73899 L .47605 .74028 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .46649 .73747 L .47058 .73899 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .46392 .73581 L .46649 .73747 L closepath p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .46298 .73408 L .46392 .73581 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .53499 .73666 L .53675 .73495 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .53165 .73825 L .53499 .73666 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .52684 .73967 L .53165 .73825 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .52077 .74082 L .52684 .73967 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .51372 .74166 L .52077 .74082 L closepath p F P
.505 .664 .505 r
s
.136 .148 .112 r
.5 .73655 m .506 .74214 L .51372 .74166 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49799 .74224 L .506 .74214 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49008 .74195 L .49799 .74224 L closepath p F P
.505 .664 .505 r
s
.5 .709 .543 r
.53499 .26334 m .5 .26345 L .53675 .26505 L closepath p F P
.505 .664 .505 r
s
.498 .705 .534 r
.46298 .26592 m .5 .26345 L .46392 .26419 L closepath p F P
.505 .664 .505 r
s
.489 .695 .534 r
.53165 .26175 m .5 .26345 L .53499 .26334 L closepath p F P
.505 .664 .505 r
s
.487 .692 .525 r
.46392 .26419 m .5 .26345 L .46649 .26253 L closepath p F P
.505 .664 .505 r
s
.478 .682 .524 r
.52684 .26033 m .5 .26345 L .53165 .26175 L closepath p F P
.505 .664 .505 r
s
.477 .68 .517 r
.46649 .26253 m .5 .26345 L .47058 .26101 L closepath p F P
.505 .664 .505 r
s
.469 .671 .515 r
.52077 .25918 m .5 .26345 L .52684 .26033 L closepath p F P
.505 .664 .505 r
s
.468 .669 .509 r
.47058 .26101 m .5 .26345 L .47605 .25972 L closepath p F P
.505 .664 .505 r
s
.461 .661 .508 r
.51372 .25834 m .5 .26345 L .52077 .25918 L closepath p F P
.505 .664 .505 r
s
.461 .66 .504 r
.47605 .25972 m .5 .26345 L .48265 .25872 L closepath p F P
.505 .664 .505 r
s
.456 .655 .503 r
.506 .25786 m .5 .26345 L .51372 .25834 L closepath p F P
.505 .664 .505 r
s
.456 .654 .5 r
.48265 .25872 m .5 .26345 L .49008 .25805 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49799 .25776 m .5 .26345 L .506 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49008 .25805 m .5 .26345 L .49799 .25776 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.42808 .72914 m .46392 .73581 L .46298 .73408 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.46298 .73408 m .42673 .72581 L .42808 .72914 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.42673 .27419 m .46298 .26592 L .46392 .26419 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.46392 .26419 m .42808 .27086 L .42673 .27419 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.39217 .28809 m .42673 .27419 L .42808 .27086 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.39342 .71655 m .42808 .72914 L .42673 .72581 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.42673 .72581 m .39217 .71191 L .39342 .71655 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.36089 .69823 m .39342 .71655 L .39217 .71191 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.39217 .71191 m .36017 .69272 L .36089 .69823 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.42808 .27086 m .39342 .28345 L .39217 .28809 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.36017 .30728 m .39217 .28809 L .39342 .28345 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.573 .72747 m .53675 .73495 L .53499 .73666 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.53675 .26505 m .573 .27253 L .57001 .26922 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.57001 .26922 m .53499 .26334 L .53675 .26505 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.39342 .28345 m .36089 .30177 L .36017 .30728 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.33154 .33131 m .36017 .30728 L .36089 .30177 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.33142 .67453 m .36089 .69823 L .36017 .69272 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.36017 .69272 m .33154 .66869 L .33142 .67453 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.36089 .30177 m .33142 .32547 L .33154 .33131 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.30703 .35961 m .33154 .33131 L .33142 .32547 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.30591 .64599 m .33142 .67453 L .33154 .66869 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.33154 .66869 m .30703 .64039 L .30591 .64599 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.43272 .73238 m .46649 .73747 L .46392 .73581 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.46392 .73581 m .42808 .72914 L .43272 .73238 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.42808 .27086 m .46392 .26419 L .46649 .26253 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.33142 .32547 m .30591 .35401 L .30703 .35961 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.28726 .39146 m .30703 .35961 L .30591 .35401 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.28515 .61333 m .30591 .64599 L .30703 .64039 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.30703 .64039 m .28726 .60854 L .28515 .61333 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.30591 .35401 m .28515 .38667 L .28726 .39146 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.27276 .42606 m .28726 .39146 L .28515 .38667 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.26981 .57743 m .28515 .61333 L .28726 .60854 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.28726 .60854 m .27276 .57394 L .26981 .57743 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.60781 .71423 m .573 .72747 L .57001 .73078 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53499 .73666 m .57001 .73078 L .573 .72747 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.573 .27253 m .60781 .28577 L .60411 .28114 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.60411 .28114 m .57001 .26922 L .573 .27253 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.2604 .53929 m .26981 .57743 L .27276 .57394 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.27276 .57394 m .26391 .53744 L .2604 .53929 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.28515 .38667 m .26981 .42257 L .27276 .42606 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26391 .46256 m .27276 .42606 L .26981 .42257 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26981 .42257 m .2604 .46071 L .26391 .46256 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.26093 .5 m .26391 .46256 L .2604 .46071 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.25723 .5 m .2604 .53929 L .26391 .53744 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.26391 .53744 m .26093 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.2604 .46071 m .25723 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.57001 .73078 m .53499 .73666 L .53165 .73825 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.53499 .26334 m .57001 .26922 L .56374 .26608 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.56374 .26608 m .53165 .26175 L .53499 .26334 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.64026 .69546 m .60781 .71423 L .60411 .71886 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.57001 .73078 m .60411 .71886 L .60781 .71423 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.60781 .28577 m .64026 .30454 L .63633 .299 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.63633 .299 m .60411 .28114 L .60781 .28577 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.44056 .73538 m .47058 .73899 L .46649 .73747 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.46649 .73747 m .43272 .73238 L .44056 .73538 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.43272 .26762 m .46649 .26253 L .47058 .26101 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.46649 .26253 m .43272 .26762 L .42808 .27086 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.39961 .72113 m .43272 .73238 L .42808 .72914 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.42808 .72914 m .39342 .71655 L .39961 .72113 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.39342 .28345 m .42808 .27086 L .43272 .26762 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.53165 .73825 m .56374 .73392 L .57001 .73078 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.56374 .73392 m .53165 .73825 L .52684 .73967 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.53165 .26175 m .56374 .26608 L .55439 .26327 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.55439 .26327 m .52684 .26033 L .53165 .26175 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.66947 .67158 m .64026 .69546 L .63633 .701 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.60411 .71886 m .63633 .701 L .64026 .69546 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.64026 .30454 m .66947 .32842 L .6657 .32251 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.6657 .32251 m .63633 .299 L .64026 .30454 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.45134 .73796 m .47605 .74028 L .47058 .73899 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.47058 .73899 m .44056 .73538 L .45134 .73796 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.44056 .26462 m .47058 .26101 L .47605 .25972 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.47058 .26101 m .44056 .26462 L .43272 .26762 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.69462 .64316 m .66947 .67158 L .6657 .67749 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.63633 .701 m .6657 .67749 L .66947 .67158 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.66947 .32842 m .69462 .35684 L .69127 .35115 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.69127 .35115 m .6657 .32251 L .66947 .32842 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.52684 .73967 m .55439 .73673 L .56374 .73392 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.55439 .73673 m .52684 .73967 L .52077 .74082 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.52684 .26033 m .55439 .26327 L .5423 .26094 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.5423 .26094 m .52077 .25918 L .52684 .26033 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.60411 .71886 m .57001 .73078 L .56374 .73392 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.57001 .26922 m .60411 .28114 L .59543 .27668 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.59543 .27668 m .56374 .26608 L .57001 .26922 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.36811 .70373 m .39961 .72113 L .39342 .71655 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.39342 .71655 m .36089 .69823 L .36811 .70373 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.43272 .26762 m .39961 .27887 L .39342 .28345 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.36089 .30177 m .39342 .28345 L .39961 .27887 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.4646 .73999 m .48265 .74128 L .47605 .74028 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.47605 .74028 m .45134 .73796 L .4646 .73999 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.45134 .26204 m .47605 .25972 L .48265 .25872 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.47605 .25972 m .45134 .26204 L .44056 .26462 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.69462 .35684 m .71499 .38909 L .71217 .3842 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.71217 .3842 m .69127 .35115 L .69462 .35684 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.71499 .61091 m .69462 .64316 L .69127 .64885 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.6657 .67749 m .69127 .64885 L .69462 .64316 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.52077 .74082 m .5423 .73906 L .55439 .73673 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.5423 .73906 m .52077 .74082 L .51372 .74166 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52077 .25918 m .5423 .26094 L .52803 .25924 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52803 .25924 m .51372 .25834 L .52077 .25918 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.69127 .64885 m .71217 .6158 L .71499 .61091 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.72998 .57566 m .71499 .61091 L .71217 .6158 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.71499 .38909 m .72998 .42434 L .72767 .42076 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.72767 .42076 m .71217 .3842 L .71499 .38909 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.4797 .74135 m .49008 .74195 L .48265 .74128 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.48265 .74128 m .4646 .73999 L .4797 .74135 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.4646 .26001 m .48265 .25872 L .49008 .25805 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.48265 .25872 m .4646 .26001 L .45134 .26204 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.41074 .72541 m .44056 .73538 L .43272 .73238 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.43272 .73238 m .39961 .72113 L .41074 .72541 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.39961 .27887 m .43272 .26762 L .44056 .26462 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.51372 .74166 m .52803 .74076 L .5423 .73906 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.52803 .74076 m .51372 .74166 L .506 .74214 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51372 .25834 m .52803 .25924 L .51229 .25826 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51229 .25826 m .506 .25786 L .51372 .25834 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.73916 .53835 m .72998 .57566 L .72767 .57924 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.71217 .6158 m .72767 .57924 L .72998 .57566 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.72998 .42434 m .73916 .46165 L .7372 .45976 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.7372 .45976 m .72767 .42076 L .72998 .42434 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49589 .74194 m .49799 .74224 L .49008 .74195 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49008 .74195 m .4797 .74135 L .49589 .74194 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.49008 .25805 m .4797 .25865 L .4646 .26001 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.4797 .25865 m .49008 .25805 L .49799 .25776 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.33923 .68043 m .36811 .70373 L .36089 .69823 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.36089 .69823 m .33142 .67453 L .33923 .68043 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.39961 .27887 m .36811 .29627 L .36089 .30177 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33142 .32547 m .36089 .30177 L .36811 .29627 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.73916 .46165 m .74225 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.74042 .5 m .7372 .45976 L .73916 .46165 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.74225 .5 m .73916 .53835 L .7372 .54024 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.72767 .57924 m .7372 .54024 L .73916 .53835 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.506 .74214 m .51229 .74174 L .52803 .74076 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.51229 .74174 m .506 .74214 L .49799 .74224 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.506 .25786 m .51229 .25826 L .49589 .25806 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49589 .25806 m .49799 .25776 L .506 .25786 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.49799 .74224 m .49589 .74194 L .51229 .74174 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.49799 .25776 m .49589 .25806 L .4797 .25865 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.7372 .54024 m .74042 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.56374 .73392 m .59543 .72332 L .60411 .71886 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.63633 .701 m .60411 .71886 L .59543 .72332 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.60411 .28114 m .63633 .299 L .62576 .29361 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.62576 .29361 m .59543 .27668 L .60411 .28114 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.59543 .72332 m .56374 .73392 L .55439 .73673 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.56374 .26608 m .59543 .27668 L .58191 .27264 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.58191 .27264 m .55439 .26327 L .56374 .26608 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.31395 .65171 m .33923 .68043 L .33142 .67453 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.33142 .67453 m .30591 .64599 L .31395 .65171 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36811 .29627 m .33923 .31957 L .33142 .32547 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.30591 .35401 m .33142 .32547 L .33923 .31957 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.42652 .72914 m .45134 .73796 L .44056 .73538 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.44056 .73538 m .41074 .72541 L .42652 .72914 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.44056 .26462 m .41074 .27459 L .39961 .27887 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.41074 .27459 m .44056 .26462 L .45134 .26204 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.38203 .70894 m .41074 .72541 L .39961 .72113 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.39961 .72113 m .36811 .70373 L .38203 .70894 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.36811 .29627 m .39961 .27887 L .41074 .27459 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.33923 .31957 m .31395 .34829 L .30591 .35401 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.28515 .38667 m .30591 .35401 L .31395 .34829 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.29319 .61827 m .31395 .65171 L .30591 .64599 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.30591 .64599 m .28515 .61333 L .29319 .61827 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.6657 .67749 m .63633 .701 L .62576 .70639 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.59543 .72332 m .62576 .70639 L .63633 .701 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.63633 .299 m .6657 .32251 L .65374 .31669 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.65374 .31669 m .62576 .29361 L .63633 .299 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.55439 .73673 m .58191 .72736 L .59543 .72332 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.58191 .72736 m .55439 .73673 L .5423 .73906 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.55439 .26327 m .58191 .27264 L .56403 .26926 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.56403 .26926 m .5423 .26094 L .55439 .26327 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.27773 .58105 m .29319 .61827 L .28515 .61333 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.28515 .61333 m .26981 .57743 L .27773 .58105 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.31395 .34829 m .29319 .38173 L .28515 .38667 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.26981 .42257 m .28515 .38667 L .29319 .38173 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.44631 .73211 m .4646 .73999 L .45134 .73796 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.45134 .73796 m .42652 .72914 L .44631 .73211 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.42652 .27086 m .45134 .26204 L .4646 .26001 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.45134 .26204 m .42652 .27086 L .41074 .27459 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.2682 .5412 m .27773 .58105 L .26981 .57743 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.26981 .57743 m .2604 .53929 L .2682 .5412 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.29319 .38173 m .27773 .41895 L .26981 .42257 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.2604 .46071 m .26981 .42257 L .27773 .41895 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.62576 .70639 m .59543 .72332 L .58191 .72736 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.59543 .27668 m .62576 .29361 L .60857 .28866 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60857 .28866 m .58191 .27264 L .59543 .27668 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.6657 .32251 m .69127 .35115 L .67836 .34548 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.67836 .34548 m .65374 .31669 L .6657 .32251 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.69127 .64885 m .6657 .67749 L .65374 .68331 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.62576 .70639 m .65374 .68331 L .6657 .67749 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.27773 .41895 m .2682 .4588 L .2604 .46071 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.25723 .5 m .2604 .46071 L .2682 .4588 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.26498 .5 m .2682 .5412 L .2604 .53929 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.2604 .53929 m .25723 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.2682 .4588 m .26498 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.5423 .73906 m .56403 .73074 L .58191 .72736 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.56403 .73074 m .5423 .73906 L .52803 .74076 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.5423 .26094 m .56403 .26926 L .54259 .26676 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.54259 .26676 m .52803 .25924 L .5423 .26094 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.35538 .68609 m .38203 .70894 L .36811 .70373 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.36811 .70373 m .33923 .68043 L .35538 .68609 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.41074 .27459 m .38203 .29106 L .36811 .29627 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.33923 .31957 m .36811 .29627 L .38203 .29106 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27765 .59897 m
.28743 .61964 L
s
.26731 .57713 m
.27663 .59683 L
s
.27663 .59683 m
.27765 .59897 L
s
.5 Mabswid
.452 .65 .505 r
.46913 .7341 m .4797 .74135 L .4646 .73999 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.4646 .73999 m .44631 .73211 L .46913 .7341 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.44631 .26789 m .4646 .26001 L .4797 .25865 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.4646 .26001 m .44631 .26789 L .42652 .27086 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.40236 .71354 m .42652 .72914 L .41074 .72541 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.41074 .72541 m .38203 .70894 L .40236 .71354 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.38203 .29106 m .41074 .27459 L .42652 .27086 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.52803 .74076 m .54259 .73324 L .56403 .73074 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.54259 .73324 m .52803 .74076 L .51229 .74174 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.52803 .25924 m .54259 .26676 L .51871 .26531 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.51871 .26531 m .51229 .25826 L .52803 .25924 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69127 .35115 m .71217 .3842 L .69868 .37929 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69868 .37929 m .67836 .34548 L .69127 .35115 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.71217 .6158 m .69127 .64885 L .67836 .65452 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.65374 .68331 m .67836 .65452 L .69127 .64885 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27355 .59286 m
.27792 .59509 L
s
.5 Mabswid
.47 .672 .517 r
.49373 .73498 m .49589 .74194 L .4797 .74135 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.4797 .74135 m .46913 .7341 L .49373 .73498 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.4797 .25865 m .46913 .2659 L .44631 .26789 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.46913 .2659 m .4797 .25865 L .49589 .25806 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.51229 .74174 m .51871 .73469 L .54259 .73324 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.51871 .73469 m .51229 .74174 L .49589 .74194 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.51229 .25826 m .51871 .26531 L .49373 .26502 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.49373 .26502 m .49589 .25806 L .51229 .25826 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.49589 .74194 m .49373 .73498 L .51871 .73469 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.49589 .25806 m .49373 .26502 L .46913 .2659 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71217 .3842 m .72767 .42076 L .71386 .41715 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71386 .41715 m .69868 .37929 L .71217 .3842 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.72767 .57924 m .71217 .6158 L .69868 .62071 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.67836 .65452 m .69868 .62071 L .71217 .6158 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.65374 .68331 m .62576 .70639 L .60857 .71134 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.58191 .72736 m .60857 .71134 L .62576 .70639 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.62576 .29361 m .65374 .31669 L .63344 .31129 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.63344 .31129 m .60857 .28866 L .62576 .29361 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.60857 .71134 m .58191 .72736 L .56403 .73074 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58191 .27264 m .60857 .28866 L .58528 .28448 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58528 .28448 m .56403 .26926 L .58191 .27264 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.38203 .29106 m .35538 .31391 L .33923 .31957 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.31395 .34829 m .33923 .31957 L .35538 .31391 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33181 .65724 m .35538 .68609 L .33923 .68043 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33923 .68043 m .31395 .65171 L .33181 .65724 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28139 .60153 m
.28743 .61964 L
s
.28015 .5978 m
.28139 .60153 L
s
.5 Mabswid
.254 .308 .211 r
.72767 .42076 m .7372 .45976 L .72324 .45784 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72324 .45784 m .71386 .41715 L .72767 .42076 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.7372 .54024 m .72767 .57924 L .71386 .58285 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.69868 .62071 m .71386 .58285 L .72767 .57924 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42835 .71723 m .44631 .73211 L .42652 .72914 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42652 .72914 m .40236 .71354 L .42835 .71723 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.40236 .28646 m .42652 .27086 L .44631 .26789 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.42652 .27086 m .40236 .28646 L .38203 .29106 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.7372 .45976 m .74042 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.72642 .5 m .72324 .45784 L .7372 .45976 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.74042 .5 m .7372 .54024 L .72324 .54216 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.71386 .58285 m .72324 .54216 L .7372 .54024 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.72324 .54216 m .72642 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.35538 .31391 m .33181 .34276 L .31395 .34829 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.29319 .38173 m .31395 .34829 L .33181 .34276 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31228 .62308 m .33181 .65724 L .31395 .65171 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31395 .65171 m .29319 .61827 L .31228 .62308 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.37971 .69114 m .40236 .71354 L .38203 .70894 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.38203 .70894 m .35538 .68609 L .37971 .69114 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.35538 .31391 m .38203 .29106 L .40236 .28646 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.56403 .73074 m .58528 .71552 L .60857 .71134 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.58528 .71552 m .56403 .73074 L .54259 .73324 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.56403 .26926 m .58528 .28448 L .55693 .28136 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.55693 .28136 m .54259 .26676 L .56403 .26926 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.67836 .65452 m .65374 .68331 L .63344 .68871 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.60857 .71134 m .63344 .68871 L .65374 .68331 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65374 .31669 m .67836 .34548 L .65555 .34018 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65555 .34018 m .63344 .31129 L .65374 .31669 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29763 .58461 m .31228 .62308 L .29319 .61827 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29319 .61827 m .27773 .58105 L .29763 .58461 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27427 .58018 m
.28015 .5978 L
s
.5 Mabswid
.558 .777 .597 r
.45868 .71973 m .46913 .7341 L .44631 .73211 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.44631 .73211 m .42835 .71723 L .45868 .71973 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.42835 .28277 m .44631 .26789 L .46913 .2659 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.44631 .26789 m .42835 .28277 L .40236 .28646 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.33181 .34276 m .31228 .37692 L .29319 .38173 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.27773 .41895 m .29319 .38173 L .31228 .37692 L p F P
.505 .664 .505 r
s
.519 .718 .524 r
.63344 .68871 m .60857 .71134 L .58528 .71552 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60857 .28866 m .63344 .31129 L .60529 .30668 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60529 .30668 m .58528 .28448 L .60857 .28866 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.54259 .73324 m .55693 .71864 L .58528 .71552 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.55693 .71864 m .54259 .73324 L .51871 .73469 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.54259 .26676 m .55693 .28136 L .52506 .27954 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.52506 .27954 m .51871 .26531 L .54259 .26676 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.28856 .54309 m .29763 .58461 L .27773 .58105 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.27773 .58105 m .2682 .5412 L .28856 .54309 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.31228 .37692 m .29763 .41539 L .27773 .41895 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.2682 .4588 m .27773 .41895 L .29763 .41539 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.4916 .72084 m .49373 .73498 L .46913 .7341 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.46913 .7341 m .45868 .71973 L .4916 .72084 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.46913 .2659 m .45868 .28027 L .42835 .28277 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.45868 .28027 m .46913 .2659 L .49373 .26502 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67836 .34548 m .69868 .37929 L .67394 .37466 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67394 .37466 m .65555 .34018 L .67836 .34548 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.69868 .62071 m .67836 .65452 L .65555 .65982 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.63344 .68871 m .65555 .65982 L .67836 .65452 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27734 .58095 m
.28155 .59181 L
s
.28155 .59181 m
.2888 .61055 L
s
.5 Mabswid
.563 .768 .6 r
.35949 .66222 m .37971 .69114 L .35538 .68609 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35538 .68609 m .33181 .65724 L .35949 .66222 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.40236 .28646 m .37971 .30886 L .35538 .31391 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.33181 .34276 m .35538 .31391 L .37971 .30886 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.51871 .73469 m .52506 .72046 L .55693 .71864 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.52506 .72046 m .51871 .73469 L .49373 .73498 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.51871 .26531 m .52506 .27954 L .4916 .27916 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.4916 .27916 m .49373 .26502 L .51871 .26531 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.29763 .41539 m .28856 .45691 L .2682 .4588 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.26498 .5 m .2682 .4588 L .28856 .45691 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.28548 .5 m .28856 .54309 L .2682 .5412 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.2682 .5412 m .26498 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.49373 .73498 m .4916 .72084 L .52506 .72046 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.49373 .26502 m .4916 .27916 L .45868 .28027 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.28856 .45691 m .28548 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28372 .59874 m
.28708 .60504 L
s
.5 Mabswid
.586 .805 .621 r
.41137 .69522 m .42835 .71723 L .40236 .71354 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.40236 .71354 m .37971 .69114 L .41137 .69522 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.37971 .30886 m .40236 .28646 L .42835 .28277 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28708 .60504 m
.29054 .6094 L
s
.29054 .6094 m
.29329 .61178 L
s
.5 Mabswid
.471 .627 .436 r
.71386 .58285 m .69868 .62071 L .67394 .62534 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.65555 .65982 m .67394 .62534 L .69868 .62071 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.69868 .37929 m .71386 .41715 L .68778 .41371 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.68778 .41371 m .67394 .37466 L .69868 .37929 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29329 .61178 m
.29636 .61251 L
s
.5 Mabswid
.519 .718 .524 r
.58528 .71552 m .60529 .69332 L .63344 .68871 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.60529 .69332 m .58528 .71552 L .55693 .71864 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.58528 .28448 m .60529 .30668 L .57052 .30321 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.57052 .30321 m .55693 .28136 L .58528 .28448 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.65555 .65982 m .63344 .68871 L .60529 .69332 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.63344 .31129 m .65555 .34018 L .62323 .33561 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.62323 .33561 m .60529 .30668 L .63344 .31129 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.37971 .30886 m .35949 .33778 L .33181 .34276 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.31228 .37692 m .33181 .34276 L .35949 .33778 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.34259 .62745 m .35949 .66222 L .33181 .65724 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.33181 .65724 m .31228 .62308 L .34259 .62745 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.71386 .41715 m .72324 .45784 L .69638 .45601 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.69638 .45601 m .68778 .41371 L .71386 .41715 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.72324 .54216 m .71386 .58285 L .68778 .58629 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.67394 .62534 m .68778 .58629 L .71386 .58285 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.44875 .698 m .45868 .71973 L .42835 .71723 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.42835 .71723 m .41137 .69522 L .44875 .698 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.41137 .30478 m .42835 .28277 L .45868 .28027 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.42835 .28277 m .41137 .30478 L .37971 .30886 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.72324 .45784 m .72642 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.6993 .5 m .69638 .45601 L .72324 .45784 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.72642 .5 m .72324 .54216 L .69638 .54399 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.68778 .58629 m .69638 .54399 L .72324 .54216 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.69638 .54399 m .6993 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.55693 .71864 m .57052 .69679 L .60529 .69332 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.57052 .69679 m .55693 .71864 L .52506 .72046 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.55693 .28136 m .57052 .30321 L .5311 .30117 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.5311 .30117 m .52506 .27954 L .55693 .28136 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.35949 .33778 m .37971 .30886 L .41137 .30478 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.39609 .66628 m .41137 .69522 L .37971 .69114 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.37971 .69114 m .35949 .66222 L .39609 .66628 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.32983 .58786 m .34259 .62745 L .31228 .62308 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.31228 .62308 m .29763 .58461 L .32983 .58786 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.35949 .33778 m .34259 .37255 L .31228 .37692 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.29763 .41539 m .31228 .37692 L .34259 .37255 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29565 .59731 m
.29724 .60163 L
s
.29724 .60163 m
.30094 .60806 L
s
.5 Mabswid
.274 .303 .218 r
.45868 .28027 m .44875 .302 L .41137 .30478 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.44875 .302 m .45868 .28027 L .4916 .27916 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.48957 .69924 m .4916 .72084 L .45868 .71973 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.45868 .71973 m .44875 .698 L .48957 .69924 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30094 .60806 m
.30519 .61248 L
s
.29461 .59073 m
.29565 .59731 L
s
.5 Mabswid
.357 .424 .289 r
.65555 .34018 m .67394 .37466 L .63828 .37064 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.63828 .37064 m .62323 .33561 L .65555 .34018 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.67394 .62534 m .65555 .65982 L .62323 .66439 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.60529 .69332 m .62323 .66439 L .65555 .65982 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30519 .61248 m
.30874 .61489 L
s
.5 Mabswid
.612 .833 .618 r
.52506 .72046 m .5311 .69883 L .57052 .69679 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.5311 .69883 m .52506 .72046 L .4916 .72084 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.52506 .27954 m .5311 .30117 L .48957 .30076 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.48957 .30076 m .4916 .27916 L .52506 .27954 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29461 .59073 m
.29581 .58638 L
s
.5 Mabswid
.629 .854 .639 r
.4916 .72084 m .48957 .69924 L .5311 .69883 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.4916 .27916 m .48957 .30076 L .44875 .302 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.60529 .30668 m .62323 .33561 L .58279 .33214 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.58279 .33214 m .57052 .30321 L .60529 .30668 L p F P
.505 .664 .505 r
s
.605 .814 .594 r
.62323 .66439 m .60529 .69332 L .57052 .69679 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30874 .61489 m
.31308 .61558 L
s
.5 Mabswid
.565 .74 .573 r
.32189 .54482 m .32983 .58786 L .29763 .58461 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.29763 .58461 m .28856 .54309 L .32189 .54482 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.34259 .37255 m .32983 .41214 L .29763 .41539 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.28856 .45691 m .29763 .41539 L .32983 .41214 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29581 .58638 m
.29792 .5843 L
s
.31308 .61558 m
.31536 .61408 L
s
.5 Mabswid
.465 .584 .45 r
.32983 .41214 m .32189 .45518 L .28856 .45691 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.28548 .5 m .28856 .45691 L .32189 .45518 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.3192 .5 m .32189 .54482 L .28856 .54309 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.28856 .54309 m .28548 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29792 .5843 m
.30244 .58484 L
s
.5 Mabswid
.329 .382 .284 r
.41137 .30478 m .39609 .33372 L .35949 .33778 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.34259 .37255 m .35949 .33778 L .39609 .33372 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.38325 .63104 m .39609 .66628 L .35949 .66222 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.35949 .66222 m .34259 .62745 L .38325 .63104 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.32189 .45518 m .3192 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.68778 .58629 m .67394 .62534 L .63828 .62936 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.62323 .66439 m .63828 .62936 L .67394 .62534 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.67394 .37466 m .68778 .41371 L .64966 .41072 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.64966 .41072 m .63828 .37064 L .67394 .37466 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.43977 .66907 m .44875 .698 L .41137 .69522 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.41137 .69522 m .39609 .66628 L .43977 .66907 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.39609 .33372 m .41137 .30478 L .44875 .302 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31536 .61408 m
.31701 .61049 L
s
.30244 .58484 m
.30633 .58766 L
s
.30633 .58766 m
.31106 .59284 L
s
.5 Mabswid
.605 .814 .594 r
.57052 .69679 m .58279 .66786 L .62323 .66439 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.58279 .66786 m .57052 .69679 L .5311 .69883 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.57052 .30321 m .58279 .33214 L .53658 .3301 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.53658 .3301 m .5311 .30117 L .57052 .30321 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.69638 .54399 m .68778 .58629 L .64966 .58928 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.63828 .62936 m .64966 .58928 L .68778 .58629 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.68778 .41371 m .69638 .45601 L .65676 .45441 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.65676 .45441 m .64966 .41072 L .68778 .41371 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66407 .63078 m
.67433 .60327 L
s
.32167 .58671 m
.32832 .60632 L
s
.5 Mabswid
.402 .484 .33 r
.62323 .33561 m .63828 .37064 L .59314 .36757 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.59314 .36757 m .58279 .33214 L .62323 .33561 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.63828 .62936 m .62323 .66439 L .58279 .66786 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.48773 .67031 m .48957 .69924 L .44875 .698 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.44875 .698 m .43977 .66907 L .48773 .67031 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.44875 .302 m .43977 .33093 L .39609 .33372 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.43977 .33093 m .44875 .302 L .48957 .30076 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.39609 .33372 m .38325 .36896 L .34259 .37255 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.32983 .41214 m .34259 .37255 L .38325 .36896 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.3735 .59054 m .38325 .63104 L .34259 .62745 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.34259 .62745 m .32983 .58786 L .3735 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32832 .60632 m
.32992 .61103 L
s
.32992 .61103 m
.33665 .63087 L
s
.5 Mabswid
.636 .852 .628 r
.5311 .69883 m .53658 .6699 L .58279 .66786 L p F P
.505 .664 .505 r
s
.651 .872 .648 r
.53658 .6699 m .5311 .69883 L .48957 .69924 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.5311 .30117 m .53658 .3301 L .48773 .32969 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.48773 .32969 m .48957 .30076 L .5311 .30117 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.69638 .45601 m .6993 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.65918 .5 m .65676 .45441 L .69638 .45601 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.6993 .5 m .69638 .54399 L .65676 .54559 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.64966 .58928 m .65676 .54559 L .69638 .54399 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32857 .60986 m
.33643 .61663 L
s
.5 Mabswid
.651 .872 .648 r
.48957 .69924 m .48773 .67031 L .53658 .6699 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.48957 .30076 m .48773 .32969 L .43977 .33093 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.65676 .54559 m .65918 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67778 .59162 m
.68034 .58899 L
s
.6791 .58665 m
.68034 .58899 L
s
.33643 .61663 m
.34108 .61902 L
s
.67651 .58932 m
.67778 .59162 L
s
.5 Mabswid
.449 .547 .402 r
.38325 .36896 m .39609 .33372 L .43977 .33093 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.43218 .63351 m .43977 .66907 L .39609 .66628 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.39609 .66628 m .38325 .63104 L .43218 .63351 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67651 .58932 m
.6791 .58665 L
s
.34108 .61902 m
.3472 .61961 L
s
.5 Mabswid
.611 .797 .605 r
.36741 .54626 m .3735 .59054 L .32983 .58786 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.32983 .58786 m .32189 .54482 L .36741 .54626 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.38325 .36896 m .3735 .40946 L .32983 .41214 L p F P
.505 .664 .505 r
s
.522 .657 .495 r
.32189 .45518 m .32983 .41214 L .3735 .40946 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3472 .61961 m
.35077 .61799 L
s
.5 Mabswid
.605 .795 .573 r
.64966 .58928 m .63828 .62936 L .59314 .63243 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.58279 .66786 m .59314 .63243 L .63828 .62936 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.63828 .37064 m .64966 .41072 L .60101 .40842 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.60101 .40842 m .59314 .36757 L .63828 .37064 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65222 .61772 m
.65565 .61342 L
s
.64512 .62029 m
.65222 .61772 L
s
.5 Mabswid
.442 .537 .376 r
.58279 .33214 m .59314 .36757 L .54122 .36576 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.54122 .36576 m .53658 .3301 L .58279 .33214 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.59314 .63243 m .58279 .66786 L .53658 .6699 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35077 .61799 m
.351 .61193 L
s
.63843 .62083 m
.64512 .62029 L
s
.5 Mabswid
.522 .657 .495 r
.3735 .40946 m .36741 .45374 L .32189 .45518 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.3192 .5 m .32189 .45518 L .36741 .45374 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.36534 .5 m .36741 .54626 L .32189 .54482 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.32189 .54482 m .3192 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66022 .59779 m
.66085 .59539 L
s
.65679 .60263 m
.66022 .59779 L
s
.65178 .60525 m
.65679 .60263 L
s
.6599 .5906 m
.66085 .59539 L
s
.34489 .58841 m
.351 .61193 L
s
.5 Mabswid
.559 .714 .54 r
.36741 .45374 m .36534 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37356 .63455 m
.37644 .63647 L
s
.37356 .63455 m
.37528 .63296 L
s
.37644 .63647 m
.37819 .6349 L
s
.5 Mabswid
.449 .547 .402 r
.43977 .33093 m .43218 .36649 L .38325 .36896 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.43218 .36649 m .43977 .33093 L .48773 .32969 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.48617 .63462 m .48773 .67031 L .43977 .66907 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.43977 .66907 m .43218 .63351 L .48617 .63462 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37528 .63296 m
.37819 .6349 L
s
.5 Mabswid
.645 .848 .637 r
.42641 .59239 m .43218 .63351 L .38325 .63104 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.38325 .63104 m .3735 .59054 L .42641 .59239 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.3735 .40946 m .38325 .36896 L .43218 .36649 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.65676 .54559 m .64966 .58928 L .60101 .59158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65373 .5885 m
.6599 .5906 L
s
.5 Mabswid
.605 .795 .573 r
.59314 .63243 m .60101 .59158 L .64966 .58928 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63209 .61933 m
.63843 .62083 L
s
.63975 .60832 m
.65178 .60525 L
s
.5 Mabswid
.505 .634 .445 r
.64966 .41072 m .65676 .45441 L .60593 .45318 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.60593 .45318 m .60101 .40842 L .64966 .41072 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.53658 .6699 m .54122 .63424 L .59314 .63243 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.53658 .3301 m .54122 .36576 L .48617 .36538 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.48617 .36538 m .48773 .32969 L .53658 .3301 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.54122 .63424 m .53658 .6699 L .48773 .67031 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63087 .61533 m
.63209 .61933 L
s
.64669 .58892 m
.65373 .5885 L
s
.63442 .61086 m
.63975 .60832 L
s
.36411 .58951 m
.36996 .61387 L
s
.36996 .61387 m
.37181 .62158 L
s
.5 Mabswid
.654 .866 .64 r
.48773 .67031 m .48617 .63462 L .54122 .63424 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.48773 .32969 m .48617 .36538 L .43218 .36649 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63087 .61533 m
.63442 .61086 L
s
.5 Mabswid
.541 .688 .487 r
.65676 .45441 m .65918 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.6076 .5 m .60593 .45318 L .65676 .45441 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.65918 .5 m .65676 .54559 L .60593 .54682 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.60101 .59158 m .60593 .54682 L .65676 .54559 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63886 .5919 m
.64669 .58892 L
s
.5 Mabswid
.496 .615 .436 r
.59314 .36757 m .60101 .40842 L .54475 .40706 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.54475 .40706 m .54122 .36576 L .59314 .36757 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.60101 .59158 m .59314 .63243 L .54122 .63424 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63532 .59705 m
.63886 .5919 L
s
.5 Mabswid
.569 .732 .521 r
.60593 .54682 m .6076 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60986 .62071 m
.61293 .6185 L
s
.61293 .6185 m
.6165 .61409 L
s
.60419 .62303 m
.60986 .62071 L
s
.6165 .61409 m
.61751 .60966 L
s
.59627 .62342 m
.60419 .62303 L
s
.5 Mabswid
.631 .821 .615 r
.42279 .54725 m .42641 .59239 L .3735 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.39057 .61743 m
.39166 .62281 L
s
.5 Mabswid
.631 .821 .615 r
.3735 .59054 m .36741 .54626 L .42279 .54725 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38509 .59046 m
.39057 .61743 L
s
.5 Mabswid
.505 .628 .464 r
.43218 .36649 m .42641 .40761 L .3735 .40946 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.36741 .45374 m .3735 .40946 L .42641 .40761 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38972 .61442 m
.39903 .62117 L
s
.39903 .62117 m
.4048 .62347 L
s
.5913 .62161 m
.59627 .62342 L
s
.4048 .62347 m
.41293 .62383 L
s
.5 Mabswid
.651 .854 .635 r
.48498 .59322 m .48617 .63462 L .43218 .63351 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.43218 .63351 m .42641 .59239 L .48498 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.42641 .40761 m .43218 .36649 L .48617 .36538 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61556 .59302 m
.61997 .59784 L
s
.41293 .62383 m
.41806 .62199 L
s
.61052 .59064 m
.61556 .59302 L
s
.41806 .62199 m
.41979 .61569 L
s
.5 Mabswid
.632 .829 .604 r
.54122 .63424 m .54475 .59294 L .60101 .59158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.56089 .63804 m
.56394 .61427 L
s
.58659 .61762 m
.5913 .62161 L
s
.58491 .61108 m
.61751 .60966 L
s
.5 Mabswid
.646 .847 .624 r
.54475 .59294 m .54122 .63424 L .48617 .63462 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.54122 .36576 m .54475 .40706 L .48498 .40678 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.48498 .40678 m .48617 .36538 L .54122 .36576 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.42641 .40761 m .42279 .45275 L .36741 .45374 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.36534 .5 m .36741 .45374 L .42279 .45275 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.42155 .5 m .42279 .54725 L .36741 .54626 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.36741 .54626 m .36534 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.58491 .61108 m
.58659 .61762 L
s
.5 Mabswid
.538 .677 .483 r
.60101 .40842 m .60593 .45318 L .54696 .45245 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.54696 .45245 m .54475 .40706 L .60101 .40842 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.60593 .54682 m .60101 .59158 L .54475 .59294 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60214 .59094 m
.61052 .59064 L
s
.42933 .62239 m
.43535 .62462 L
s
.41979 .61569 m
.42933 .62239 L
s
.5 Mabswid
.646 .847 .624 r
.48617 .63462 m .48498 .59322 L .54475 .59294 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.48617 .36538 m .48498 .40678 L .42641 .40761 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.41638 .59152 m
.41979 .61569 L
s
.5 Mabswid
.583 .744 .554 r
.42279 .45275 m .42155 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43535 .62462 m
.44401 .62486 L
s
.58491 .61108 m
.58564 .60643 L
s
.44401 .62486 m
.4496 .62294 L
s
.59607 .59375 m
.60214 .59094 L
s
.58564 .60643 m
.58959 .59904 L
s
.55134 .62497 m
.55742 .62277 L
s
.55742 .62277 m
.56379 .61837 L
s
.54253 .62516 m
.55134 .62497 L
s
.58959 .59904 m
.59607 .59375 L
s
.4496 .62294 m
.4519 .61656 L
s
.53677 .6232 m
.54253 .62516 L
s
.53108 .61903 m
.53677 .6232 L
s
.48244 .62342 m
.48854 .62553 L
s
.48854 .62553 m
.49759 .62556 L
s
.49759 .62556 m
.50364 .62349 L
s
.5 Mabswid
.636 .827 .612 r
.48424 .5477 m .48498 .59322 L .42641 .59239 L p F P
.505 .664 .505 r
s
.636 .827 .612 r
.42641 .59239 m .42279 .54725 L .48424 .5477 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44984 .59223 m
.4519 .61656 L
s
.5 Mabswid
.558 .704 .516 r
.42279 .45275 m .42641 .40761 L .48498 .40678 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4762 .61911 m
.48244 .62342 L
s
.50364 .62349 m
.5067 .62137 L
s
.52843 .61236 m
.53108 .61903 L
s
.5 Mabswid
.571 .727 .522 r
.60593 .45318 m .6076 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.54772 .5 m .54696 .45245 L .60593 .45318 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.6076 .5 m .60593 .54682 L .54696 .54755 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.54475 .59294 m .54696 .54755 L .60593 .54682 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.56394 .61427 m
.56681 .59193 L
s
.5067 .62137 m
.50983 .61701 L
s
.4728 .61237 m
.4762 .61911 L
s
.56045 .59469 m
.56601 .59969 L
s
.50983 .61701 m
.50991 .6125 L
s
.52843 .61236 m
.52867 .60767 L
s
.47257 .60768 m
.4728 .61237 L
s
.4728 .61237 m
.50991 .6125 L
s
.5 Mabswid
.597 .768 .555 r
.54696 .54755 m .54772 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.55451 .59216 m
.56045 .59469 L
s
.52867 .60767 m
.53217 .60026 L
s
.47257 .60768 m
.47536 .60034 L
s
.5 Mabswid
.554 .699 .506 r
.54475 .40706 m .54696 .45245 L .48424 .4523 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.48424 .4523 m .48498 .40678 L .54475 .40706 L p F P
.505 .664 .505 r
s
.632 .82 .601 r
.54696 .54755 m .54475 .59294 L .48498 .59322 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.53217 .60026 m
.53872 .59504 L
s
.47536 .60034 m
.48151 .59522 L
s
.5 Mabswid
.632 .82 .601 r
.48498 .59322 m .48424 .5477 L .54696 .54755 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.54516 .59231 m
.55451 .59216 L
s
.5 Mabswid
.558 .704 .516 r
.48498 .40678 m .48424 .4523 L .42279 .45275 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.53872 .59504 m
.54516 .59231 L
s
.50383 .59527 m
.51013 .60042 L
s
.5 Mabswid
.59 .753 .554 r
.42155 .5 m .42279 .45275 L .48424 .4523 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.48398 .5 m .48424 .5477 L .42279 .54725 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.42279 .54725 m .42155 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.48151 .59522 m
.48783 .5926 L
s
.49744 .59262 m
.50383 .59527 L
s
.48783 .5926 m
.49744 .59262 L
s
.5 Mabswid
.59 .753 .554 r
.48424 .4523 m .48398 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.54696 .45245 m .54772 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.48398 .5 m .48424 .4523 L .54696 .45245 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.54772 .5 m .54696 .54755 L .48424 .5477 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.48424 .5477 m .48398 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003U0;3PiPl0PJV10`0T9ad0
0`21ZH409BPN02DX7P0602DX7P03086YP@0T9ad092LM00P0PJV1j02`h>H10?ooo`00h02`h>H6086Y
P@L08B@K0P21ZH4702@W7@03086YP@0U:1h09BPN00L09BPN00<0PJV102@W7@0T9ad01@0T9ad2086Y
P@03020S6`21ZH40PJV100@0PJV1hP2`h>H10?ooo`00g@2`h>H3086YP@806ahG0P21ZH47024T6`80
PJV12@0T9ad00`21ZH409BPN02DX7P0802DX7P03086YP@0T9ad092LM00H092LM0P21ZH44020S6`L0
PJV1g02`h>H10?ooo`00fP2`h>H4086YP@806ahG0P21ZH43024T6b<0PJV1100T9ad2086YP@D082<K
0P21ZH400`0J7QL0PJV1086YP@03086YPMP0/>3V0@3oool00=H0/>3V1@21ZH400`0K7QL0PJV1086Y
P@07086YP@@0<S<W00<0PJV103Hg:P0f=bX02P0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f
=bX0=SLZ0080=SLZ3021ZH401@0P8a/0PJV1086YP@21ZH406QhG0080PJV100<04QHA086YP@2`h>H0
e@2`h>H10?ooo`00e02`h>H00`21ZH404aLA086YP@05086YP@0302/]8P21ZH40<S<W00T0<S<W00<0
PJV103Hg:P0f=bX02`0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0
PJV1038c9`0b<bL00P0b<bL<086YPM<0/>3V0@3oool00=40/>3V00<0PJV101<G4@21ZH400`21ZH45
02/]8P03086YP@0b<bL0<S<W00P0<S<W00<0PJV103Hg:P0f=bX0300f=bX00`21ZH40=cP[03Lh:`0;
03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0PJV1038c9`0b<bL01`0b<bL9086YPM00/>3V0@3oool0
0<h0/>3V1P21ZH4702/]8P03086YP@0b<bL0<S<W00T0<S<W00<0PJV103Hg:P0f=bX02`0f=bX00`21
ZH40=cP[03Lh:`0<03Lh:`03086YP@0f=bX0=SLZ00X0=SLZ00<0PJV1038c9`0b<bL0200b<bL01021
ZH40:RdR02X]8P0Z;B85086YPLh0/>3V0@3oool00</0/>3V1021ZH400`0Q91/0PJV1086YP@0702/]
8P80PJV12`0b<bL00`21ZH40=SLZ03Hg:P0<03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg
:P0f=bX02P0f=bX00`21ZH40<S<W038c9`08038c9`80PJV1100Z;B85086YPL/0/>3V0@3oool00<T0
/>3V0`21ZH43024T6`03086YP@0[;B80:bdR00H0:bdR00<0PJV1038c9`0b<bL02P0b<bL00`21ZH40
=SLZ03Hg:P0=03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg:P0f=bX02`0f=bX00`21ZH40
<S<W038c9`09038c9`80PJV1100Z;B82086YP@03020S6P21ZH40PJV10<T0/>3V0@3oool00<L0/>3V
0`21ZH43024T6`80PJV1200[;B800`21ZH40<S<W038c9`07038c9bd0PJV11P0f=bX00`21ZH40<S<W
038c9`0:038c9`03086YP@0Z;B80:RdR00<0:RdR00<0PJV1020S6P0P8aX00P21ZH770;3PiP40oooo
00350;3PiP<0PJV10`0Q91/2086YP@T0:bdR00<0PJV1038c9`0b<bL02021ZH4304I==`03086YP@1<
ESd0C5Hm00h0C5Hm00<0PJV104mI?P1?FCh03P1?FCh00`21ZH40CEHm04eF?@0504eF?@l0PJV11@0b
<bL2086YP@@0:RdR0P21ZH42020S6P80PJV1a@2`h>H10?ooo`00``2`h>H00`21ZH4051PB086YP@03
024T6`80PJV1100[;B8:086YP@X0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI?P0?
04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL01016CCL9086YP@@0:RdR00@0PJV1
020S6P0P8aX082<J0P21ZH730;3PiP40oooo00310;3PiP04086YP@0D6180PJV1086YP@808B@K2021
ZH4503Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL03016CCL5086YP@0302X]8P21
ZH40PJV100<082<J0P21ZH710;3PiP40oooo002o0;3PiP05086YP@0D6180PJV1086YP@0Q91/01021
ZH4<03Xn;P03086YP@16CCL0ATdg00/0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00d0CEHm00<0PJV104I==`16CCL03016CCL01021ZH40>Sd]03Xm
;@0j?Bd5086YP@<082<J0P21ZH6o0;3PiP40oooo002m0;3PiP03086YP@0D6180PJV100@0PJV10P0/
;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd0401<
ESd00`21ZH40CeTn04mI?P0?04mI?P03086YP@1=ESd0CEHm00h0CEHm00<0PJV104I==`16CCL02`16
CCL00`21ZH40>Sd]03Xm;@0503Xm;@@0PJV10P0P8aX2086YPKd0/>3V0@3oool00;/0/>3V00<0PJV1
01@H4P21ZH400P21ZH4502`_8`03086YP@0j?Rh0>Sh^00X0>Sh^00<0PJV104I==`16CCL03016CCL0
0`21ZH40C5Hm04aF?@0@04aF?@03086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03@1=ESd0
0`21ZH40ATdg04I==`0<04I==`03086YP@0j?Bd0>Sd]00H0>Sd]00<0PJV102`^8`21ZH401@21ZH6k
0;3PiP40oooo002i0;3PiPD0PJV11P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg
00d0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI?P0A04mI?P03086YP@1=ESd0CEHm
00h0CEHm00<0PJV104I==`16CCL03016CCL00`21ZH40>Sd]03Xm;@0603Xm;@03086YP@0/;R<0;2hS
0080;2hS0`21ZH6j0;3PiP40oooo002g0;3PiP80PJV10`0M8AT00`21ZH40;2lS02`_8`0402`_8`03
086YP@0j?Rh0>Sh^00/0>Sh^00<0PJV104I==`16CCL03016CCL00`21ZH40C5Hm04aF?@0A04aF?@03
086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03P1=ESd00`21ZH40ATdg04I==`0=04I==`03
086YP@0j?Bd0>Sd]00H0>Sd]0P21ZH4502`^8`80PJV1^02`h>H10?ooo`00]P2`h>H01021ZH407B4I
01dQ6@0M8AT2086YP@H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh00`21ZH40ATdg04I==`0=04I==`03
086YP@1<ESd0C5Hm0140C5Hm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40CEHm04eF?@0?04eF?@03
086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0
PJV1]P2`h>H10?ooo`00]@2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV100P0;2lS00<0PJV103Xn;P0j
?Rh02P0j?Rh00`21ZH40ATdg04I==`0=04I==`03086YP@1<ESd0C5Hm0180C5Hm00<0PJV104mI?P1?
FCh04P1?FCh00`21ZH40CEHm04eF?@0?04eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j
?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0PJV1]@2`h>H10?ooo`00/`2`h>H2086YP@<07B4I
00<0PJV102`_8`0/;b<01P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00X0ATdg
>021ZH4804eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd0200j?Bd00`21ZH40;2hS
02`^8`0402`^8`<0PJV1/`2`h>H10?ooo`00/P2`h>H00`21ZH407B4I01dQ6@0201dQ6@03086YP@0/
;b<0;2lS00H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh01021ZH40ATdg04I==`16CCL9086YP@@0Gg1B
00<0PJV106AgE@1TMeD04P1TMeD00`21ZH40HgIC06=fD`0B06=fD`03086YP@1NKd`0GVm<00L0GVm<
3P21ZH4;04I==`03086YP@0j?Bd0>Sd]00P0>Sd]00<0PJV102`^8`0/;R<0100/;R<00`21ZH4071lH
086YP@2b0;3PiP40oooo002a0;3PiP03086YP@0M8AT07B4I00807B4I00<0PJV102`_8`0/;b<01P0/
;b<00`21ZH40>Sh^03Xn;P0803Xn;PP0PJV1301OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1S
MU<0HgIC0180HgIC00<0PJV105i_C01NKd`0401NKd`00`21ZH40F6M705QWA`0205QWA`T0PJV10`16
CCL00`21ZH40>Sd]03Xm;@0803Xm;@80PJV11@0/;R<00`21ZH4071lH086YP@2a0;3PiP40oooo002`
0;3PiP04086YP@0M8AT07B4I01dQ6@80PJV1200/;b<01021ZH40>Sh^03Xn;P0j?Rh8086YP@80E658
00<0PJV105m`DP1OL5803`1OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC0180HgIC
00<0PJV105i_C01NKd`04@1NKd`00`21ZH40F6M705QWA`0:05QWA`P0PJV1200j?Bd00`21ZH40;2hS
02`^8`0302`^8`04086YP@0L7aP0PJV1086YPJl0/>3V0@3oool00:l0/>3V00D0PJV101dQ6@0M8AT0
7B4I086YP@0702`_8`L0PJV12P1DHDP00`21ZH40Gg1B05m`DP0?05m`DP03086YP@1TMeD0I7ME01<0
I7ME00<0PJV106=fD`1SMU<04`1SMU<00`21ZH40GVm<05i_C00@05i_C003086YP@1HIdL0F6M700l0
F6M700<0PJV104eG?@1=Ecd01`21ZH4203Xm;@03086YP@0/;R<0;2hS00<0;2hS00@0PJV101`O600L
7aP0PJV1[P2`h>H10?ooo`00[P2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV10080;2lS1P21ZH400`10
AcL0PJV105AQB00=05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21
ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21
ZH40CELm04eG?@0704eG?@D0PJV1100/;R<2086YP@0301`O6021ZH40/>3V0:`0/>3V0@3oool00:`0
/>3V0P21ZH4201dQ6@D0PJV11`10AcL00`21ZH40E65805AQB00<05AQB003086YP@1OL580Gg1B00l0
Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140
GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@@0PJV10`0/;R<01021ZH40
71lH086YP@21ZH6[0;3PiP40oooo002[0;3PiP03086YP@0M8AT07B4I00<0PJV12P10AcL00`21ZH40
E65805AQB00<05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40
HgIC06=fD`0D06=fD`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21ZH40
CELm04eG?@0;04eG?@03086YP@0i?Rh0>Ch^00D0PJV10P0L7aP00`21ZH40/>3V0;3PiP2X0;3PiP40
oooo002Z0;3PiP@0PJV100<09b/Q086YP@10AcL02@10AcL00`21ZH40E65805AQB00=05AQB003086Y
P@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgIC06=fD`0D06=fD`03086Y
P@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@03086Y
P@0i?Rh0>Ch^00@0>Ch^0`21ZH400`0L7aP0PJV10;3PiP2X0;3PiP40oooo002Y0;3PiP80PJV1100W
:b400`21ZH40@4Lg0417=`070417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`DP1OL5804@1O
L5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC01@0HgIC00<0PJV105i_C01NKd`04P1N
Kd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn;P0i?Rh01@0i
?Rh5086YPJL0/>3V0@3oool00:L0/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00P0@4Lg00<0PJV1
05AQB01DHDP0301DHDP00`21ZH40Gg1B05m`DP0A05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV1
06=fD`1SMU<0501SMU<00`21ZH40GVm<05i_C00C05i_C003086YP@1HIdL0F6M700l0F6M700<0PJV1
04eG?@1=Ecd02`1=Ecd00`21ZH40>Ch^03Tn;P0503Tn;P03086YP@0T9ad092LM0080PJV1YP2`h>H1
0?ooo`00YP2`h>H2086YP@D09b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQ
B003086YP@1OL580Gg1B0140Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0E06=f
D`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL0401HIdL00`21ZH40CELm04eG?@0;04eG
?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2U0;3PiP40oooo002U0;3P
iP80PJV11@0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`
DP1OL5804P1OL5800`21ZH40I7ME06AgE@0D06AgE@03086YP@1SMU<0HgIC01D0HgIC00<0PJV105i_
C01NKd`04`1NKd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn
;P0i?Rh01@0i?Rh00`21ZH4092LM02@W7@0202@W7@03086YP@2`h>H0/>3V0:80/>3V0@3oool00:@0
/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00T0@4Lg00<0PJV105AQB01DHDP03@1DHDP00`21ZH40
Gg1B05m`DP0B05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=fD`1SMU<05@1SMU<00`21ZH40
GVm<05i_C00C05i_C003086YP@1HIdL0F6M70100F6M700<0PJV104eG?@1=Ecd02`1=Ecd00`21ZH40
>Ch^03Tn;P0503Tn;P05086YP@0T9ad092LM02@W7@21ZH40Y02`h>H10?ooo`00X`2`h>H2086YP@H0
9b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQB003086YP@1OL580Gg1B0180
Gg1B00<0PJV106AgE@1TMeD02P1TMeD_086YP@/0GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40
CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2S0;3P
iP40oooo002R0;3PiP80PJV11P0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800h0
E65800<0PJV105m`DP1OL580201OL58G086YP@/0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40
LHUP0769H0090769H100PJV13P1HIdL00`21ZH40CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0
>Ch^00D0PJV102@W7@0T9ad092LM086YP@2R0;3PiP40oooo002Q0;3PiP80PJV11P0W:b400`21ZH40
@4Lg0417=`080417=`03086YP@1DHDP0E65800X0E6584021ZH4:07:<IP03086YP@1fTFP0MY5X01D0
MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D0080
IW]D2P21ZH4405QWA`03086YP@1=Ecd0CELm00d0CELm00<0PJV103Tn;P0i?Rh01@0i?Rh01@21ZH40
92LM02@W7@0T9ad0PJV10:40/>3V0@3oool00:00/>3V00<0PJV1010D4021ZH401@0W:b400`21ZH40
@4Lg0417=`090417=`04086YP@1DHDP0E65805AQB0T0PJV1101YOel00`21ZH40LXaV07:<IP0C07:<
IP03086YP@1fTFP0MY5X01D0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00E0769
H003086YP@1VNe@0IW]D00/0IW]D2P21ZH4:04eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00D0PJV102@W
7@0T9ad092LM086YP@2P0;3PiP40oooo002O0;3PiP03086YP@0@5100PJV100D09b/Q00<0PJV10417
=`10AcL01`10AcL7086YP@`0JGmO00<0PJV107:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00F07JA
J003086YP@1fT6H0MY1V01H0MY1V00<0PJV10769H01aRF00501aRF000`21ZH40IW]D06IkE00@06Ik
E003086YP@1KK4T0Ffa90080Ffa92021ZH4304eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00@0PJV102@W
7@0T9ad0PJV1X02`h>H10?ooo`00WP2`h>H00`21ZH4041@@086YP@0602L[8@03086YP@10AcL0@4Lg
00<0@4Lg1021ZH400`1GIdl0PJV106UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JA
J01fTFP05P1fTFP00`21ZH40MY1V07J@IP0F07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106Ik
E01VNe@04@1VNe@00`21ZH40Ffa905]/B@0905]/B@H0PJV11P0i?Rh01@21ZH4092LM02@W7@0T9ad0
PJV109l0/>3V0@3oool009h0/>3V00<041@@086YP@0W:b401@0W:b400`21ZH40@4Lg086YP@04086Y
P@D0EfM?00<0PJV106UoG`1YOel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X
01H0MY5X00<0PJV107J@IP1fT6H05P1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D
0140IW]D00<0PJV105]/B@1KK4T03P1KK4T5086YP@<0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2N
0;3PiP40oooo002M0;3PiP03010D4021ZH409b/Q00<09b/Q1@21ZH4905MWC`03086YP@1YOel0JGmO
00l0JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V
01H0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00A06IkE003086YP@1KK4T0Ffa9
00d0Ffa900<0PJV104QD>`18E3/00P18E3/5086YP@<092LM00<0PJV10;3PiP2`h>H0V`2`h>H10?oo
o`00W02`h>H00`0@5100PJV102L[8@04086YP@0303Po=021ZH40EfM?00/0EfM?00<0PJV106UoG`1Y
Oel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X01L0MY5X00<0PJV107J@IP1f
T6H05P1fT6H00`21ZH40LHUP0769H00E0769H003086YP@1VNe@0IW]D0140IW]D00<0PJV105]/B@1K
K4T03P1KK4T00`21ZH40B5@k04QD>`0504QD>`80PJV10`0T9ad00`21ZH40/>3V0;3PiP2J0;3PiP40
oooo002K0;3PiP04010D4021ZH40PJV1086YP@D0>3ld00<0PJV105MWC`1GIdl02@1GIdl00`21ZH40
JGmO06UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40
MY1V07J@IP0G07J@IP03086YP@1aRF00LHUP01D0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40
Ffa905]/B@0=05]/B@03086YP@18E3/0B5@k00L0B5@k0P21ZH400`0T9ad0PJV10;3PiP2K0;3PiP40
oooo002J0;3PiP03010D4021ZH40>3ld00H0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO
06UoG`0?06UoG`03086YP@1bS6H0LXaV01@0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40MY1V
07J@IP0H07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40Ffa9
05]/B@0>05]/B@03086YP@18E3/0B5@k00H0B5@k00<0PJV102/^8`21ZH400P21ZH6K0;3PiP40oooo
002I0;3PiP<0PJV11`0h?c@00`21ZH40EfM?05MWC`0905MWC`03086YP@1YOel0JGmO0100JGmO00<0
PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0
PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900d0Ffa900<0
PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02086YPIX0/>3V0@3oool009P0/>3V00<0PJV1
01TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV1
07:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0PJV1
0769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV1
04QD>`18E3/01P18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V09L0/>3V0@3oool0
09L0/>3V00@0PJV101TN6@0I7QT0PJV11P0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109T0/>3V0@3o
ool009L0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0
Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109P0/>3V0@3o
ool009H0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0
/>3V09D0/>3V0@3oool009D0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C
06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[
;R<0PJV109L0/>3V0@3oool009D0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00D
06IkE003086YP@1KK4T0Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02
02/^8`03086YP@2`h>H0/>3V09@0/>3V0@3oool009@0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@0
0`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H03`1bS6I9
086YP@`0LHUP00<0PJV106IkE01VNe@04`1VNe@00`21ZH40Ffa905]/B@0>05]/B@03086YP@18E3/0
B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP03086YP@0I7QT0PJV100L0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO06UoG`0A06Uo
G`03086YP@1bS6H0LXaV00@0LXaV3021ZH45086PMP03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108>S
M@23XgD06@23XgD00`21ZH40OYe_07jMK`0:07jMKaP0PJV12`1VNe@00`21ZH40Ffa905]/B@0=05]/
B@03086YP@18E3/0B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3P
iP40oooo002C0;3PiP04086YP@0I7QT06AhI086YP@H0>3ld00<0PJV105MWC`1GIdl02`1GIdl00`21
ZH40JGmO06UoG`0706UoGa40PJV14@21X7H00`21ZH40Q:Ah08BTN00H08BTN003086YP@23XgD0Pj=e
01T0Pj=e00<0PJV107jMK`1nWFl05P1nWFl00`21ZH40MI5T07FAI00907FAI100PJV1301KK4T00`21
ZH40B5@k04QD>`0704QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3PiP2`h>H0TP2`h>H10?oo
o`00TP2`h>H01021ZH406AhI01TN6@21ZH4703Po=003086YP@1GIdl0EfM?00P0EfM?3@21ZH4:07VF
L003086YP@21X7H0PJ1f01D0PJ1f00<0PJV108BTN024Y7P06024Y7P00`21ZH40Pj=e08>SM@0I08>S
M@03086YP@1nWFl0OYe_01H0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0206El
D`T0PJV10`1KK4T00`21ZH40B5@k04QD>`0804QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3P
iP2`h>H0T@2`h>H10?ooo`00TP2`h>H00`21ZH406AhI086YP@0703Po=003086YP@1GIdl0EfM?00@0
EfM?1@21ZH4206R0H`03086YP@1iUW00NII`0140NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40
Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40
MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00X0IGaC1P21ZH4804QD>`03086YP@0[;R<0:bhS00<0
:bhS00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00T@2`h>H01021ZH406AhI01TN6@21ZH4703Po=003
086YP@1GIdl0PJV100@0PJV11P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0
PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01L0
OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0PJV100<0
PJV11@18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V0900/>3V0@3oool00900/>3V
00@0PJV101TN6@0I7QT0PJV11@0h?c@5086YP@/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40
PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40
OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40
E6E505AUA@0205AUA@@0PJV100<0B5@k086YP@0[;R<0100[;R<00`21ZH40/>3V0;3PiP2?0;3PiP40
oooo002@0;3PiP03086YP@0I7QT06AhI0080>3ld1021ZH4204]KB@03086YP@1XP6<0J81S00/0J81S
00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T
00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0605AUA@@0PJV1100[;R<00`21ZH40/>3V
0;3PiP2>0;3PiP40oooo002?0;3PiP03086YP@0I7QT06AhI00<0PJV11@1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40MI5T07FA
I00E07FAI003086YP@1UO5<0IGaC00h0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]086Y
P@04086YPI00/>3V0@3oool008l0/>3V00@06AhI086YP@21ZH40PJV11`1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FA
I00D07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0
;@0203M0;@80PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@0302@/9`21ZH40Be]900L0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2f?0;3PiP40oooo002>0;3PiP04086YP@0T;2L092`W086YP@L0Be]900<0PJV1
06R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV1
03M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3PiP04086YP@0T;2L092`W
086YP@P0Be]900<0PJV106R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0
PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0
OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0
E6E500P0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3P
iP04086YP@0T;2L092`W086YP@L0Be]900<0PJV106R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B
07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J
08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?
06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2;
0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1XP6<0301XP6<0
0`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P0
0`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV107FAI01eTF@05@1eTF@0
0`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d0
0`21ZH40/>3V0;3PiP2;0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00C07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002;0;3PiP05086YP@0T;2L092`W
02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0<06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1
086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003086YP@23XgD0Pj=e01X0Pj=e00<0PJV1
07jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV1
05AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08X0/>3V0@3oool0
08/0/>3V00@0PJV102@/9`0T;2L0PJV1201;FdT00`21ZH40J81S06R0H`0<06R0H`03086YP@1iUW00
NII`0180NII`00<0PJV1086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003086YP@23XgD0
Pj=e01X0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0
IGaC0100IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@0403M0;@03086YP@2`h>H0
/>3V08T0/>3V0@3oool008X0/>3V00D0PJV102@/9`0T;2L092`W086YP@0804]KB@03086YP@1XP6<0
J81S00/0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086PMP0F086PMP03086YP@24Y7P0
Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0H07jMK`03086YP@1eTF@0
MI5T01H0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0
=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H01021ZH4092`W02@/9`21ZH48
04]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086PMP0F
086PMP03086YP@24Y7P0Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0I
07jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@09
05AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H01021
ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW004P1iUW00
0`21ZH40PJ1f086PMP0G086PMP03086YP@24Y7P0Q:Ah00d0Q:Ah7@21ZH4>08>SM@03086YP@1nWFl0
OYe_01T0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0@06ElD`03086YP@1DIDD0
E6E500P0E6E500<0PJV103M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP280;3PiP40oooo00290;3P
iP05086YP@0T;2L092`W02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0=06R0H`03086YP@1iUW00
NII`0180NII`00<0PJV1086PMP21X7H02`21X7HL086YP@h0S[B400<0PJV108fbP@2=/X40302=/X4g
086YP@`0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0
=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R02`h>H10?ooo`00R@2`h>H01021ZH4092`W02@/9`21ZH48
04]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW002@1iUW0H086YP@`0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek01T0RJek00<0PJV1
086RL@21XW402P21XW4A086YP@d0IGaC00<0PJV105AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@04
03M0;@03086YP@2`h>H0/>3V08L0/>3V0@3oool008P0/>3V00D0PJV102@/9`0T;2L092`W086YP@08
04]KB@03086YP@1XP6<0J81S00T0J81S3`21ZH4:08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek01T0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0207:?H@X0PJV1101UO5<00`21ZH40E6E505AUA@09
05AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0Q`2`h>H10?ooo`00R02`h>H01021
ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S0080J81S2021ZH4307NEL`03086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06@29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ00`0LXmQ2021ZH4805AUA@03086YP@0g@2d0=d0]00@0=d0]00<0PJV10;3PiP2`h>H0QP2`h>H1
0?ooo`00Q`2`h>H01@21ZH4092`W02@/9`0T;2L0PJV100H0Be]91`21ZH4;07NEL`03086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0E086RL@03086YP@1bSf40
LXmQ0100LXmQ00@0PJV105ecC@1MLdd0GG==1P21ZH4305AUA@03086YP@0g@2d0=d0]00<0=d0]00<0
PJV10;3PiP2`h>H0QP2`h>H10?ooo`00Q`2`h>H01021ZH4092`W02@/9`21ZH4204]KB@D0PJV10P1K
LU/00`21ZH40MiEc07NEL`0<07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<0602<
/H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV108V]N`29[G/06P29
[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ00l0LXmQ00<0PJV105ecC@1MLdd01`1M
Ldd7086YP@<0=d0]00<0PJV10;3PiP2`h>H0Q@2`h>H10?ooo`00QP2`h>H00`21ZH4092`W02@/9`04
086YP@H0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0
S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0
RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0
GG==00T0GG==00@0PJV1045>=P11CSH0@Dhf1021ZH670;3PiP40oooo00260;3PiP<0PJV100<0;SPc
086YP@1KLU/01`1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV1
08baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV1
08V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0100LXmQ00<0PJV1
05ecC@1MLdd02@1MLdd00`21ZH40@Dhf045>=P04045>=P80PJV1QP2`h>H10?ooo`00QP2`h>H01021
ZH40;SPc02hh<`21ZH4905]bF`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h04`25Z7h0
0`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X406P2=/X40
0`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf40
0`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0@Dhf0P21ZH660;3PiP40oooo00250;3P
iP05086YP@0^>3<0;SPc02hh<`21ZH402@1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P03086YP@2`h>H0
/>3V08@0/>3V0@3oool008D0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0
MiEc00h0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0
S[B401`0S[B400<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40
PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0
@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc02hh<`0^>3<0
PJV100P0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0
S;6301L0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0K08fbP@03086YP@29[G/0
RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0
GG==00T0GG==00<0PJV1045>=P11CSH01011CSH2086YPHD0/>3V0@3oool008D0/>3V00@0PJV102hh
<`0^>3<0PJV12@1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV1
08baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV1
08V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0E086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV1
05ecC@1MLdd02@1MLdd00`21ZH40@Dhf045>=P04045>=P80PJV1Q@2`h>H10?ooo`00Q02`h>H01@21
ZH40;SPc02hh<`0^>3<0PJV100T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C
08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L
08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@
07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH00`11CSH2086YPHD0/>3V0@3oool0
08@0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV1
08FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0H08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV1
08fbP@2=/X40702=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV1
07:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV1
0;3PiP2`h>H0P`2`h>H10?ooo`00Q02`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV1
07NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1
045>=P11CSH01011CSH00`21ZH40/>3V0;3PiP230;3PiP40oooo00240;3PiP04086YP@0^>3<0;SPc
086YP@T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0
S;6301P0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0
RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0
GG==00X0GG==00<0PJV1045>=P11CSH01011CSH2086YPH@0/>3V0@3oool008<0/>3V00D0PJV102hh
<`0^>3<0;SPc086YP@0905]bF`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h05025Z7h0
0`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=/X40
0`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf404@1bSf40
0`21ZH40GG==05ecC@0905ecC@03086YP@11CSH0@Dhf00@0@Dhf0P21ZH640;3PiP40oooo00230;3P
iP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0
QJQn01@0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40
SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ0140LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P03045>=P80PJV1Q02`h>H1
0?ooo`00P`2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV107NEL`1gUG<03P1gUG<0
0`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@0
0`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW40
0`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH01011CSH0
0`21ZH40/>3V0;3PiP220;3PiP40oooo00230;3PiP04086YP@0^>3<0;SPc086YP@T0Fg9K00<0PJV1
07NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV1
08jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01/0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1
045>=P11CSH01011CSH2086YPH<0/>3V0@3oool00880/>3V00D0PJV102hh<`0^>3<0;SPc086YP@09
05]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0H
08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=/X400`21ZH40RJek08V]N`0K
08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:
05ecC@03086YP@11CSH0@Dhf00@0@Dhf0P21ZH630;3PiP40oooo00220;3PiP05086YP@0^>3<0;SPc
02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0QJQn01@0QJQn00<0PJV1
08baP`2</H<02`2</H=J086YP@l0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A
07:?H@03086YP@1MLdd0GG==00T0GG==00<0PJV1045>=P11CSH01011CSH2086YPH<0/>3V0@3oool0
0880/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV1
08FXOP25Z7h02@25Z7hI086YP@d0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L
09JoR`03086YP@2B^XD0T[Z500`0T[Z5<P21ZH4:07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1
045>=P11CSH00`11CSH2086YPH<0/>3V0@3oool00880/>3V0`0^>3<00`21ZH40Fg9K05]bF`0305]b
Fb40PJV12`2?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109Jo
R`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bN
K@1lWVd01`1lWVdA086YP@H0GG==00<0PJV1045>=P11CSH01011CSH00`21ZH40/>3V0;3PiP210;3P
iP40oooo00210;3PiP03086YP@0^>3<0;SPc00L0PJV1101XQ6X00`21ZH40PZIo08:VO`0>08:VO`03
086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03
086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003
086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@0101UOe@:086YP@<0@Dhf0P21ZH620;3PiP40
oooo00210;3PiP<0PJV100<0>da2086YP@1XQ6X0201XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086Y
P@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086Y
P@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086Y
P@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@01021ZH40AeXl04MJ?017FS`5086YPH80
/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0
AeXl0P21ZH620;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40
AeXl04MJ?00404MJ?003086YP@0M91X0/>3V0840/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl00<0PJV101dT6P2`h>H0P@2`h>H10?ooo`00
P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`00`21ZH40
7B@J0;3PiP210;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40
AeXl04MJ?00304MJ?003086YP@0M91X0/>3V0840/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00210;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00
P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40
/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0806R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd0401lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0
AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40
AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00
P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40
/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00<0
AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40
AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH00/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH600;3PiP40oooo00200;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00
P02`h>Kc086YPH00/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH600;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
6@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH00/>3V0@3oool00800/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
7@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH600;3PiP40oooo
00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0304aR@@03086Y
P@0R;Ah0/>3V0800/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086Y
P@1<HT40C69100@0C69100<0PJV1028]7P2`h>H0P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00800/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
7@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo
00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1
P@2`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH40/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00d0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04024ZgL00`21ZH40KXeO06j=G`0;06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00840/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo
00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0304aR@@80PJV1
PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH80/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH620;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH80/>3V0@3oool00840/>3V0P21
ZH4204ELC`03086YP@1aTgH0LI=f00L0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2
T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9
T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[
M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00@0PJV104aR@@1<HT40C6911@21ZH620;3PiP40oooo
00210;3PiP03086YP@1=J5T0PJV101@0PJV1202:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2L
bIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2H
a8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^
SEl0KXeO00@0KXeO2P21ZH4304iX@`80PJV1PP2`h>H10?ooo`00PP2`h>H01021ZH40CFQI04eXF@21
ZH4907RNOP03086YP@2@_I80T;fB00H0T;fB5021ZH4;09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0
PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0
PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0808B[Ma00PJV11P1dV6P00`21ZH40CVQ304iX
@`0404iX@`03086YP@2`h>H0/>3V0840/>3V0@3oool00880/>3V00D0PJV104eXF@1=J5T0CFQI086Y
P@0807RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X02@2Lc9XI086YP@d0W<VF00<0
PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>00d0V<B><P21
ZH4908ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<00`1>J4<00`21ZH4093<R0;3P
iP220;3PiP40oooo00220;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092m
TP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd02`2QdYeK086YP@h0WLfD00<0
PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0M9QX00<0
PJV104iX@`1>J4<0101>J4<2086YPH<0/>3V0@3oool00880/>3V00D0PJV104eXF@1=J5T0CFQI086Y
P@0907RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7B
W@0H0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=
U00K09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BH
J00:07BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH630;3PiP40oooo00230;3PiP04086YP@1=J5T0
CFQI086YP@T0N9in00<0PJV1092mTP2@_I803P2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2Q
dYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2M
cI@0WLfD01/0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1d
V6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<2086YPH<0/>3V0@3oool008<0/>3V00D0PJV1
04eXF@1=J5T0CFQI086YP@0807RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X0502L
c9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702Q
dIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:
]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0PP2`
h>H10?ooo`00P`2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@
_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702R
di`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2G
a8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<00`1>
J4<2086YPH@0/>3V0@3oool008<0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@
_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2R
di`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2G
a8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>
J4<0CVQ300@0CVQ30P21ZH640;3PiP40oooo00240;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0
PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0
PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0
PJV104iX@`1>J4<0101>J4<2086YPH@0/>3V0@3oool008@0/>3V00D0PJV104eXF@1=J5T0CFQI086Y
P@0807RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7B
W@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=
U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BH
J00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q02`h>H0
1@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<
VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7A
V@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08Zd
O`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V0;3P
iP230;3PiP40oooo00240;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092m
TP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L0:;C
W00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4
S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX
@`0304iX@`80PJV1Q@2`h>H10?ooo`00Q@2`h>H01021ZH40CFQI04eXF@21ZH4907RNOP03086YP@2@
_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2R
di`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2G
a8`0UlB<01D0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>
J4<0CVQ300@0CVQ30P21ZH650;3PiP40oooo00250;3PiP05086YP@1=J5T0CFQI04eXF@21ZH40201h
WWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd05`2Q
dYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01/0XM6I00<0PJV109g=U02McI@06P2M
cI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1d
V6P00`21ZH40CVQ304iX@`0404iX@`80PJV1Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40CFQI04eXF@1=
J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2Q
dYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2M
cI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1d
V6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V0;3PiP240;3PiP40oooo0025
0;3PiP050000001=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2L
c9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2Q
dIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:
]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`
h>H0/>3V08@0/>3V0@3oool008D0/>3V00D00000086YP@1=J5T0CFQI086YP@0907RNOP03086YP@2@
_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2R
di`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2G
a8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>
J4<0CVQ300<0CVQ30P21ZH660;3PiP40oooo00250;3PiP80000000@0PJV10000001=J5T00000201h
WWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2Q
dYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2M
cI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02@1d
V6P00`21ZH40CVQ304iX@`0404iX@`80PJV1QP2`h>H10?ooo`00QP2`h>H600000003086YP@1hWWh0
N9in00D0N9in00<0PJV1092mTP2@_I80302@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0
XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0
WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0
M9QX00T0M9QX00@0PJV104iX@`1>J4<0CVQ31021ZH670;3PiP40oooo00260;3PiPH0000000<0NjJ4
086YP@21ZH400`21ZH4207RNOP030000002@_I80000000`0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X0
0`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT0
0`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l03`2:]7l0
0`21ZH40M9QX07BHJ00707BHJ0L0PJV10`1CLD/00`21ZH40/>3V0;3PiP250;3PiP40oooo00270;3P
iPD000001P1kYX@00`21ZH40000000000003000000P0T;fB00D00000092mTP2@_I80T;fB086YP@0E
09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J
0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05@2Ga8`00`21ZH40R[Ao08ZdO`0;
08ZdO`030000002:]7l0R[Ao0080R[Ao00@0PJV107BHJ01dV6P0M9QX1P21ZH4307RPK`03086YP@1C
LD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0QP2`h>H10?ooo`00Q`2`h>H6000000D0NjJ41`000006
086YP@<000000P2@_I800`21ZH40W<bJ09c<VP0509c<VP030000002Lc9X0W<bJ00/0W<bJ00<0PJV1
0:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV1
09g=U02McI@06@2McI@00`21ZH40UlB<09O4S00D09O4S0050000002Ga8`0PJV108ZdO`0000002P2:
]7l3000000L0PJV1201hX6l00`21ZH40Dg5;05=aB`0405=aB`03086YP@2`h>H0/>3V08H0/>3V0@3o
ool008P0/>3V1@00000507^VQ080000000<0NjJ4086YP@2Ca9P00`00000609?4V08000002@21ZH43
00000003086YP@2Lc9X0W<bJ00@0W<bJ00<0000009c<VP2Lc9X00P2Lc9X00`21ZH40XM:M0:7BW@0G
0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00I
09g=U003086YP@000000UlB<0080UlB<00<0000009O4S02Ga8`03@2Ga8`:000000L0PJV110000002
08jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP27
0;3PiP40oooo00280;3PiPD000001@1kYX@20000000407^VQ021ZH40TlBH09?4V0@00000102Ca9P2
00000080TlBH00<0PJV109oBX02OdZ001@2OdZ020000000309oBX021ZH40PJV100<0PJV10`000009
086YP@8000001@21ZH4=0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10000002QdIT00`2QdIT0
0`000000XM6I0:7AV@0D0:7AV@03086YP@000000WLfD0080WLfD00<0000009g=U02McI@04`2McI@:
000000@0UlB<1P21ZH4=000000D0S[b51000000208jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV1
05=aB`1CLD/0101CLD/00`21ZH40/>3V0;3PiP270;3PiP40oooo00270;3PiPL00000101kYX@20000
000307^VQ021ZH40TlBH0080TlBH1000000309?4V0<000000P2Ca9P00`21ZH40Wm:P09oBX00409oB
X08000001`2OdZ02000000<0Wm:P00<0PJV10:GIX`2UfJ<00`2UfJ<2000000D0YMVS1`21ZH420000
0100PJV10P0000000`21ZH40X]>L0:;CW00<0:;CW0T000001`2QdIT;086YP@`0000000<0PJV10000
000000003P21ZH4<000000<0PJV11@2Jbi84000000<0V/^B00@0PJV108jlQ@2>_8D0S[b50P000007
08jlQ@<000000P2>_8D00`21ZH40N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV1
0;3PiP2`h>H0R02`h>H10?ooo`00R02`h>H6000000@0NjJ40P00000207^VQ003086YP@2Ca9P0TlBH
0080TlBH00<0000009?4V02Ca9P00`2Ca9P200000080TlBH00<0PJV109oBX02OdZ00102OdZ020000
00L0Wm:P0P00000309oBX003086YP@2UfJ<0YMVS00<0YMVS0P00000=0:GIX`8000000`2UfJ<00`21
ZH40Y]ZR0:KJXP090:KJXP80000000<0Y]ZR086YP@21ZH402`21ZH4<000000D0PJV12P2Uf9l@0000
00`0XMBJ100000000`21ZH40V/^B09[;TP0509[;TP800000202Jbi82000000@0V/^B00<0PJV108jl
Q@2>_8D00P2>_8D2000000P0S[b500D0000008jlQ@2>_8D0S[b5086YP@0:07RPK`03086YP@1CLD/0
Dg5;00@0Dg5;00<0PJV10;3PiP2`h>H0R02`h>H10?ooo`00R@2`h>H300000003055aH0000000NjJ4
00<0NjJ40P00000207^VQ003086YP@2Ca9P0TlBH00P0TlBH0P00000209?4V003086YP@2OdZ00Wm:P
00@0Wm:P0`00000609oBX0800000102OdZ000`21ZH40YMVS0:GIX`020:GIX`8000003@2UfJ<20000
00<0YMVS00<0PJV10:KJXP2VfZ802@2VfZ82000000`0Y]ZR100000000`21ZH40YMRO0:GHW`040:GH
W`@000003@2Uf9l300000080YMRO00<0PJV10:7DVP2Qe9X01@2Qe9X4000000/0XMBJ100000000`2Q
e9X0PJV109[;TP0709[;TP8000001`2Jbi800`000000V/^B09[;TP0309[;TP03086YP@2>_8D0S[b5
0080S[b50P00000;08jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21
ZH40/>3V0;3PiP290;3PiP40oooo00290;3PiPH000000`1kYX@2000000<0NjJ400<0PJV109?4V02C
a9P01`2Ca9P200000080TlBH00<0PJV109oBX02OdZ001@2OdZ02000000H0Wm:P0`00000309oBX003
086YP@2UfJ<0YMVS0080YMVS0P00000=0:GIX`8000000`2UfJ<00`21ZH40Y]ZR0:KJXP090:KJXP80
00002`2VfZ84000000030:KJXP21ZH40YMRO00L0YMRO1000000:0:GHW`<000000`2Uf9l00`21ZH40
XMBJ0:7DVP060:7DVP<000002P2Qe9X300000080XMBJ00<0PJV109[;TP2Jbi80202Jbi800`000000
V/^B09[;TP0509[;TP030000002Jbi80V/^B00<0V/^B00<0PJV108jlQ@2>_8D00P2>_8D3000000X0
S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08T0
/>3V0@3oool008T0/>3V1P00000307^VQ0<000000P1kYX@00`21ZH40TlBH09?4V00709?4V0<00000
0P2Ca9P00`21ZH40Wm:P09oBX00409oBX08000001`2OdZ02000000<0Wm:P00<0PJV10:GIX`2UfJ<0
0P2UfJ<2000000d0YMVS0P0000040:GIX`03086YP@2VfZ80Y]ZR00P0Y]ZR0P00000:0:KJXP<00000
0`2VfZ800`21ZH40YMRO0:GHW`070:GHW`@00000202Uf9l3000000@0YMRO00<0PJV10:7DVP2Qe9X0
1`2Qe9X3000000T0XMBJ0P0000030:7DVP03086YP@2Jbi80V/^B00P0V/^B00<0000009[;TP2Jbi80
2P2Jbi800`21ZH40S[b508jlQ@0208jlQ@<000002`2>_8D00`21ZH40N:1_07RPK`0807RPK`03086Y
P@1CLD/0Dg5;00@0Dg5;00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00R`2`h>H5000000@0NjJ400@0
000007^VQ01kYX@0PJV12P2Ca9P200000080TlBH00<0PJV109oBX02OdZ00102OdZ02000000L0Wm:P
0P00000309oBX003086YP@2UfJ<0YMVS0080YMVS0P00000=0:GIX`800000102UfJ<00`21ZH40Y]ZR
0:KJXP080:KJXP8000002P2VfZ82000000@0Y]ZR00<0PJV10:GHW`2Uf9l02@2Uf9l00`000000YMRO
0:GHW`070:GHW`8000001@2Uf9l00`21ZH40XMBJ0:7DVP070:7DVP8000002P2Qe9X00`000000XMBJ
0:7DVP020:7DVP03086YP@2Jbi80V/^B01D0V/^B00@0PJV108jlQ@2>_8D0S[b50`00000708jlQ@05
0000002>_8D0S[b508jlQ@21ZH402`1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V
08X0/>3V0@3oool008/0/>3V1P00000307^VQ08000000P1kYX@00`21ZH40TlBH09?4V00709?4V080
00000P2Ca9P00`21ZH40Wm:P09oBX00409oBX0<000001P2OdZ02000000@0Wm:P00@0PJV10:GIX`2U
fJ<0YMVS0P00000=0:GIX`800000102UfJ<00`21ZH40Y]ZR0:KJXP080:KJXP8000002P2VfZ800`00
0000Y]ZR0:KJXP030:KJXP03086YP@2Uf9l0YMRO01<0YMRO00<000000:GHW`2Uf9l0102Uf9l00`21
ZH40XMBJ0:7DVP070:7DVP8000002@2Qe9X2000000@0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21
ZH40S[b508jlQ@03000000L0S[b50`00000208jlQ@03086YP@1hX6l0N:1_00P0N:1_00<0PJV105=a
B`1CLD/0101CLD/00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002<0;3PiP80000000<0DG5P00000000
0000101kYX@20000000307^VQ021ZH40TlBH00P0TlBH0`00000209?4V003086YP@2OdZ00Wm:P00@0
Wm:P0P00000609oBX0<000000`2OdZ000`21ZH40YMVS0:GIX`020:GIX`8000003@2UfJ<2000000<0
YMVS00<0PJV10:KJXP2VfZ80202VfZ82000000T0Y]ZR0P0000050:KJXP03086YP@2Uf9l0YMRO0180
YMRO0P0000060:GHW`03086YP@2Qe9X0XMBJ00L0XMBJ0P0000090:7DVP030000002Qe9X0XMBJ00<0
XMBJ00<0PJV109[;TP2Jbi804P2Jbi88000000P0S[b50P00000208jlQ@03086YP@1hX6l0N:1_00T0
N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP2;0;3PiP40oooo002<0;3PiPD00000
101kYX@300000003086YP@2Ca9P0TlBH00<0TlBH00<0000009?4V02Ca9P00P2Ca9P200000080TlBH
00<0PJV109oBX02OdZ00102OdZ02000000L0Wm:P0P00000309oBX003086YP@2UfJ<0YMVS0080YMVS
0P00000=0:GIX`8000000`2UfJ<00`21ZH40Y]ZR0:KJXP080:KJXP800000202VfZ82000000H0Y]ZR
00<0PJV10:GHW`2Uf9l04@2Uf9l2000000L0YMRO00<0PJV10:7DVP2Qe9X01`2Qe9X2000000P0XMBJ
0P0000040:7DVP03086YP@2Jbi80V/^B00P0V/^B00<0000009[;TP2Jbi801@2Jbi8:000000T0S[b5
0P00000208jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V
0;3PiP2;0;3PiP40oooo002<0;3PiPL000000`1kYX@300000003086YP@2Ca9P0TlBH0080TlBH00@0
000009?4V02Ca9P0TlBH100000000`2Ca9P0PJV109oBX00509oBX08000001`2OdZ02000000<0Wm:P
00<0PJV10:GIX`2UfJ<00P2UfJ<2000000d0YMVS0P0000030:GIX`03086YP@2VfZ80Y]ZR00P0Y]ZR
0P0000080:KJXP8000001P2VfZ800`21ZH40YMRO0:GHW`0A0:GHW`8000001`2Uf9l00`21ZH40XMBJ
0:7DVP070:7DVP8000001`2Qe9XC000000H0V/^B1@0000000`2Jbi80PJV108jlQ@0;08jlQ@<00000
0P2>_8D00`21ZH40N:1_07RPK`0807RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0
S02`h>H10?ooo`00S@2`h>H200000003055aH00000000000008000000`1kYX@400000080TlBH0P00
000409?4V0@0000000<0TlBH086YP@2OdZ00102OdZ03000000H0Wm:P0P00000409oBX004086YP@2U
fJ<0YMVS0:GIX`8000003@2UfJ<2000000<0YMVS00<0PJV10:KJXP2VfZ80202VfZ82000000P0Y]ZR
5@0000070:GHW`8000001`2Uf9l00`21ZH40XMBJ0:7DVP070:7DVP8000001`2Qe9XC000000H0V/^B
0P00000409[;TP03086YP@2>_8D0S[b500<0S[b500<0000008jlQ@2>_8D0102>_8D200000080S[b5
00<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08`0/>3V
0@3oool008d0/>3V0`000000101ALF00000000000000000407^VQ0L000001@2Ca9P400000003086Y
P@2OdZ00Wm:P00<0Wm:P0P00000709oBX0<000000`2OdZ001021ZH40YMVS0:GIX`2UfJ<4000000/0
YMVS0P0000040:GIX`03086YP@2VfZ80Y]ZR00L0Y]ZR0P0000080:KJXQD000001`2Uf9l3000000D0
YMRO00<0PJV10:7DVP2Qe9X0202Qe9X2000000P0XMBJ0P0000040:7DVP03086YP@2Jbi80V/^B00H0
V/^B0`00000509[;TP800000102Jbi800`21ZH40S[b508jlQ@0308jlQ@<00000102>_8D300000080
S[b500<0PJV107RPK`1hX6l0201hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08d0
/>3V0@3oool008h0/>3V0P0000000`21ZH40DG5P086YP@0707^VQ0@000001P2Ca9P7000000<0Wm:P
0P00000809oBX08000000`2OdZ001021ZH40YMVS0:GIX`2UfJ<5000000X0YMVS100000020:GIX`03
086YP@2VfZ80Y]ZR00L0Y]ZR0`0000090:KJXP800000102VfZ800`21ZH40YMRO0:GHW`080:GHW`80
00002@2Uf9l2000000@0YMRO00<0PJV10:7DVP2Qe9X01`2Qe9X2000000T0XMBJ0P0000040:7DVP03
086YP@2Jbi80V/^B00D0V/^B0`00000609[;TP030000002Jbi80V/^B00<0V/^B00<0PJV108jlQ@2>
_8D00P2>_8D3000000D0S[b50P00000308jlQ@03086YP@1hX6l0N:1_00P0N:1_00<0PJV105=aB`1C
LD/00P1CLD/2086YPHl0/>3V0@3oool008h0/>3V0P0000000`1CMF<0PJV1086YP@02086YP@D0NjJ4
00<0PJV109?4V0000000202Ca9P<000000L0Wm:P0P00000309oBX004086YP@2UfJ<0YMVS0:GIX`80
000000<0YMVS0000000000000P0000080:GIX`D0000000<0YMVS086YP@2VfZ80202VfZ83000000T0
Y]ZR0`0000030:KJXP03086YP@2Uf9l0YMRO00P0YMRO0P0000090:GHW`<000000`2Uf9l00`21ZH40
XMBJ0:7DVP060:7DVP@00000202Qe9X300000080XMBJ00<0PJV109[;TP2Jbi801@2Jbi83000000L0
V/^B0P00000409[;TP03086YP@000000000000@000001P2>_8D200000080S[b500<0PJV107RPK`1h
X6l0201hX6l00`21ZH40Dg5;086YP@03086YP@0305AfD02`h>H0/>3V08h0/>3V0@3oool008h0/>3V
0`00000205=eH`03086YP@1kZ8H0PJV100<0PJV10P1kYX@00`21ZH40TlBH09?4V00709?4V0800000
0P2Ca9P00`21ZH40000000000004000000P0Wm:P0P00000409oBX004086YP@2UfJ<0YMVS0:GIX`80
000000<0YMVS0000000000000P0000070:GIX`80000000<0YMVS0000000000000P0000090:KJXP80
00002`2VfZ8300000080Y]ZR00<0PJV10:GHW`2Uf9l01`2Uf9l2000000/0YMRO0`0000020:GHW`03
086YP@2Qe9X0XMBJ00D0XMBJ1000000:0:7DVP@0000000<0PJV109[;TP2Jbi800P2Jbi85000000P0
V/^B3000000608jlQ@<000000P2>_8D00`21ZH40N:1_07RPK`0707RPK`<0PJV1101DMU000`21ZH40
/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP0500000021ZH40DgES05=eH`21ZH401@1kZ8H5086YP@L0
TlBH0P00000209?4V005086YP@2OdZ00Wm:P09oBX00000002P2OdZ03000000<0Wm:P00<0PJV10:GI
X`2UfJ<00P2UfJ<010000000YMVS0:GIX`2UfJ<3000000@0YMVS100000020:GIX`H000000`2VfZ85
000000`0Y]ZR0`0000000`2VfZ80PJV10:GHW`070:GHW`<00000302Uf9l5000000@0XMBJ1`00000;
0:7DVP`000002@2Jbi88000000X0S[b50P00000308jlQ@03086YP@1hX6l0N:1_00<0N:1_1@21ZH45
05AfD003086YP@2`h>H0/>3V08l0/>3V0@3oool00940/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H0
0`21ZH40U<NK086YP@04086YP@80TlBH0`0000000`2Ca9P0PJV109oBX00>09oBX0030000002OdZ00
Wm:P0080Wm:P00<0PJV10:GIX`2UfJ<00P2UfJ<00`000000YMVS0:GIX`020:GIX`T000001@2UfJ<;
000000h0Y]ZR1@0000040:GHW`D000003P2Uf9l<000000030:7DVP000000000000d0XMBJ1`00000A
09[;TP03086YP@2>_8D0S[b500T0S[b50`00000208jlQ@03086YP@1hX6l0N:1_00@0PJV1101iY7<0
0`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V0900/>3V0@3oool00980/>3V00<0PJV105=e
H`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0409C7V`<0PJV10P00000209?4V003086YP@2OdZ00Wm:P
0140Wm:P00<0PJV10:GIX`2UfJ<01`2UfJ<7000000L0YMVS00<0PJV10:KJXP0000001@00000B0:KJ
XP`000004@2Uf9l7000000<0XMBJ0P00000?0:7DVP8000005@2Jbi800`21ZH40S[b508jlQ@0908jl
Q@8000001P21ZH4707VTL`03086YP@1DMU00E7I@00<0E7I@00<0PJV10;3PiP2`h>H0T02`h>H10?oo
o`00TP2`h>H01021ZH40DgES05=eH`21ZH4707^XQP03086YP@2Dai/0U<NK00H0U<NK0P00000=086Y
P@X0Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJXP0H0:KJXPL000005@2Uf9l00`21
ZH40XMBJ0:7DVP060:7DVP8000003P2Qe9X00`21ZH40V/^B09[;TP0D09[;TP03086YP@2>_8D0S[b5
0080S[b52021ZH4200000080Skn900<0PJV107VTL`1iY7<0201iY7<00`21ZH40E7I@05AfD00205Af
D003086YP@2`h>H0/>3V0940/>3V0@3oool009<0/>3V00@0PJV105=eH`1CMF<0PJV11P1kZ8H00`21
ZH40U<NK09C7V`0609C7V`<000000P2Dai/00`21ZH40XMJT0:7FY0070:7FY0H0PJV100<00000086Y
P@21ZH401`21ZH4B0:GIX`03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21
ZH40XMBJ0:7DVP060:7DVP8000003P2Qe9X00`21ZH40V/^B09[;TP0909[;TQ00PJV11`2?_hT30000
0080Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V
0980/>3V0@3oool009@0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0609C7V`05
0000002Dai/0U<NK09C7V`21ZH403P2QeZ@300000080XMJT00<0PJV10:KMY`2VgJL00`2VgJL<086Y
P@H0YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ
00H0XMBJ0P0000020:7DVQP0PJV12`2Ld9H00`21ZH40Skn908noR@0:08noR@040000002?_hT0Skn9
086YP@T0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP04086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00:
0:7FY0D000000P2QeZ@00`21ZH40Y]fW0:KMY`0>0:KMYdH0PJV10P000002086YP@`0XmVN00<0PJV1
09c@UP2Ld9H04`2Ld9H00`21ZH40Skn908noR@0>08noR@03086YP@1iY7<0NJAc00L0NJAc00<0PJV1
05AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C0;3PiP40oooo002E0;3PiP03086YP@1CMF<0PJV1
00L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00;0:7FY0<000000`2QeZ@00`21
ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0Z=nV01P0Z=nV00<0PJV10:OMX`2WgJ<06@2WgJ<00`21
ZH40XmVN0:?IWP060:?IWP8000003@2SfIh00`21ZH40W=2F09c@UP0D09c@UP03086YP@2?_hT0Skn9
00d0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V
09@0/>3V0@3oool009D0/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H00`21ZH40U<NK09C7V`0:09C7
V`03086YP@2QeZ@0XMJT00/0XMJT00<000000:7FY02QeZ@00P2QeZ@00`21ZH40Y]fW0:KMY`0D0:KM
Y`03086YP@2XgjH0Z=nV01P0Z=nV00<0PJV10:OMX`2WgJ<06@2WgJ<00`21ZH40XmVN0:?IWP050:?I
WP8000003P2SfIh00`21ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VT
L`1iY7<01`1iY7<01@21ZH40E7I@05AfD01DMU00PJV109L0/>3V0@3oool009H0/>3V00<0PJV105=e
H`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0140XMJT00<0PJV10:KM
Y`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?I
WP2SfIh01P2SfIh2000000h0XmVN00<0PJV109c@UP2Ld9H04`2Ld9H00`21ZH40Skn908noR@0=08no
R@03086YP@1iY7<0NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2E0;3P
iP40oooo002G0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40
XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40
YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01H0XmVN00<0PJV109c@UP2Ld9H04P2Ld9H00`21ZH40
Skn908noR@0>08noR@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01DMU00E7I@086YP@2H0;3P
iP40oooo002G0;3PiP04086YP@1CMF<0DgES086YP@H0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21
ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21
ZH40YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04`2Ld9H00`21
ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01DMU00E7I@086YP@2I
0;3PiP40oooo002H0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21
ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21
ZH40YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04P2Ld9H00`21
ZH40Skn908noR@0>08noR@03086YP@1iY7<0NJAc00H0NJAc00<0PJV105AfD01DMU000P1DMU000`21
ZH40/>3V0;3PiP2G0;3PiP40oooo002I0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2D
ai/02@2Dai/00`21ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2X
gjH05P2XgjH00`21ZH40YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2L
d9H04P2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01D
MU00E7I@086YP@2J0;3PiP40oooo002J0;3PiP80PJV11`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03
086YP@2QeZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03
086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0B09c@UP03
086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01P1iY7<00`21ZH40E7I@05AfD002086YPI/0
/>3V0@3oool009/0/>3V1021ZH4507^XQP03086YP@2Dai/0U<NK00T0U<NK00<0PJV10:7FY02QeZ@0
402QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OMX`2WgJ<0
5`2WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT0
3@2?_hT00`21ZH40NJAc07VTL`0707VTL`@0PJV1W02`h>H10?ooo`00W02`h>H2086YP@0307JUQ021
ZH40PJV10080PJV100<0NjR6086YP@2Dai/02`2Dai/00`21ZH40XMJT0:7FY00?0:7FY003086YP@2V
gJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2S
fIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0>08noR@03086YP@1i
Y7<0NJAc00D0NJAc0`21ZH42059fDP03086YP@2`h>H0/>3V09X0/>3V0@3oool009d0/>3V0P21ZH44
07JUQ0D0PJV12@2Dai/00`21ZH40XMJT0:7FY00?0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV1
0:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV1
09c@UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc0080NJAc1@21ZH43
059fDP03086YP@2`h>H0/>3V09/0/>3V0@3oool009h0/>3V0P21ZH4607JUQ003086YP@2@a9T0PJV1
00<0PJV11P2Dai/00`21ZH40XMJT0:7FY00?0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SO
YP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0XmVN01@0XmVN00<0PJV109c@
UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0>08noR@D0PJV10`1eXW<01@21ZH40DWIB059fDP1BMU80
PJV109h0/>3V0@3oool009h0/>3V00<0PJV1051dHP21ZH401P1fYH@00`21ZH40T<BI0934V@020934
V@D0PJV100<0U<NK086YP@2QeZ@0402QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV
01H0Z=nV00<0PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2Ld9H0W=2F
0140W=2F00<0PJV108noR@2?_hT02@2?_hT6086YP@H0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2O
0;3PiP40oooo002O0;3PiP03086YP@1@M680PJV100D0MZF400<0PJV10934V@2@a9T01`2@a9T7086Y
P@`0XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS
01H0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0@09c@UP03086YP@2?_hT0Skn9
0080Skn92021ZH4308boRP03086YP@1eXW<0MJ9c00H0MJ9c00@0PJV1059fDP1BMU80PJV1X02`h>H1
0?ooo`00X02`h>H00`21ZH40D7AR086YP@0507JUQ003086YP@2@a9T0T<BI00T0T<BI00@0PJV109kF
Y02NeZ@0W]JT2@21ZH440:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05@2XgjH0
0`21ZH40YmfS0:OMX`0E0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H0302Ld9H9
086YP@X0S;n:00<0PJV107FRL`1eXW<01P1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:00/>3V0@3o
ool00:40/>3V0P21ZH4607JUQ003086YP@2@a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@02P2NeZ@?
086YP@/0Y]fW00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmfS0:OMX`0E0:OMX`03086YP@2SfIh0
XmVN01@0XmVN00<0PJV109c@UP2Ld9H00`2Ld9H:086YP@<0V]2H00<0PJV108boRP2<_hX03@2<_hX0
0`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80DWIB059fDP21ZH40X@2`h>H10?ooo`00XP2`h>H2
086YP@H0MZF400<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00>09kFY003086YP@2UgJP0
YMfX00L0YMfX5`21ZH4<0:SOYP03086YP@2WgJ<0YmfS01D0YmfS00<0PJV10:?IWP2SfIh02@2SfIhA
086YP@d0V]2H00<0PJV108boRP2<_hX0302<_hX00`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80
DWIB059fDP21ZH40XP2`h>H10?ooo`00X`2`h>H2086YP@H0MZF400<0PJV10934V@2@a9T0202@a9T0
0`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0180YMfX00<0PJV10:OPZ02Wh:P02@2Wh:P`
086YP@/0X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0<08boRP03086YP@1eXW<0
MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2S0;3PiP40oooo002T0;3PiP80PJV11@1fYH@0
0`21ZH40T<BI0934V@090934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP04P2UgJP0
0`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2VgjD0Y]nU01D0Y]nU00<0PJV10:;JX02RfZ004`2RfZ00
0`21ZH40V]2H09[@V00@09[@V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FRL`1eXW<01@1eXW<0
1@21ZH40DWIB059fDP1BMU80PJV10:@0/>3V0@3oool00:D0/>3V0P21ZH4507JUQ003086YP@2@a9T0
T<BI00P0T<BI00<0PJV109kFY02NeZ@03@2NeZ@00`21ZH40YMfX0:GMZ00B0:GMZ003086YP@2Wh:P0
Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD05@2VgjD00`21ZH40X]ZP0:;JX00C0:;JX003086YP@2Jd9P0
V]2H00l0V]2H00<0PJV108boRP2<_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FRL`03086YP@1BMU80
DWIB0080DWIB00<0PJV10;3PiP2`h>H0XP2`h>H10?ooo`00YP2`h>H2086YP@D0MZF400<0PJV10934
V@2@a9T0202@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0140YMfX00<0PJV10:OP
Z02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0E0:KOY@03086YP@2RfZ00X]ZP0180X]ZP00<0PJV109[@
V02Jd9P0402Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0MJ9c00D0MJ9c00D0PJV1059f
DP1BMU80DWIB086YP@2U0;3PiP40oooo002W0;3PiP80PJV11@1fYH@00`21ZH40T<BI0934V@080934
V@03086YP@2NeZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP04@2UgJP00`21ZH40Yn2X0:OPZ00D0:OP
Z003086YP@2VgjD0Y]nU01@0Y]nU00<0PJV10:;JX02RfZ004`2RfZ000`21ZH40V]2H09[@V00?09[@
V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FRL`1eXW<01@1eXW<00`21ZH40DWIB059fDP02086Y
PJH0/>3V0@3oool00:T0/>3V0P21ZH4407JUQ003086YP@2@a9T0T<BI00L0T<BI00<0PJV109kFY02N
eZ@03@2NeZ@00`21ZH40YMfX0:GMZ00A0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KOY@2V
gjD0502VgjD00`21ZH40X]ZP0:;JX00B0:;JX003086YP@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<
_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FRL`D0PJV1Y`2`h>H10?ooo`00ZP2`h>H3086YP@80MZF4
00<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0100YMfX
00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0D0:KOY@03086YP@2RfZ00X]ZP0180X]ZP
00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0:08boRP03086YP@1eXW<0MJ9c00@0MJ9c
0`21ZH4204eaD:T0/>3V0@3oool00:/0/>3V00<0PJV106fKO@21ZH400`21ZH4:0934V@03086YP@2N
eZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2V
gjD0Y]nU01@0Y]nU00<0PJV10:;JX02RfZ004P2RfZ000`21ZH40V]2H09[@V00>09[@V003086YP@2<
_hX0S;n:00/0S;n:00@0PJV107FRL`1eXW<0MJ9c1021ZH4204eaD003086YP@2`h>H0/>3V0:P0/>3V
0@3oool00:`0/>3V0P21ZH4206fKO@@0PJV1202@a9T00`21ZH40W]JT09kFY00<09kFY003086YP@2U
gJP0YMfX00l0YMfX00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0C0:KOY@03086YP@2R
fZ00X]ZP0140X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0:08boRPD0PJV10P1]
VVl01021ZH40CG5@04eaD021ZH6[0;3PiP40oooo002^0;3PiP06086YP@1]Vgd0KI]m06fKO@21ZH40
Q[ZB1P21ZH420934V@03086YP@2NeZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40
Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ004@2RfZ000`21ZH40
V]2H09[@V00>09[@V003086YP@2<_hX0S;n:00L0S;n:1@21ZH4406fJK`80PJV100<0CG5@086YP@2`
h>H0[02`h>H10?ooo`00[`2`h>H01@21ZH40KI]m06fKO@1]Vgd0PJV100H0Q[ZB1`21ZH4;09kFY003
086YP@2UgJP0YMfX00l0YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0C0:KOY@03
086YP@2RfZ00X]ZP0100X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP07086YP@80
Q;N600<0PJV106fJK`1]VVl00`1]VVl01021ZH40CG5@04eaD021ZH6^0;3PiP40oooo002`0;3PiP04
086YP@1]Vgd0KI]m06fKO@80PJV12026^Y800`21ZH40U/jN09K>WP08086YP@<0W]JT00<0PJV10:GM
Z02UgJP03`2UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU0180Y]nU00<0PJV10:;J
X02RfZ004@2RfZ000`21ZH40V]2H09[@V00:09[@V0P0PJV12024]hH00`21ZH40KIY_06fJK`0306fJ
K`04086YP@1=LE00PJV1086YPJl0/>3V0@3oool00;40/>3V00<0PJV106fKO@1]Vgd00P1]Vgd00`21
ZH40Q[ZB08JjTP0608JjTP03086YP@2FcYh0U/jN00L0U/jN2@21ZH4<0:GMZ003086YP@2Wh:P0Yn2X
01<0Yn2X00<0PJV10:KOY@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX00@0:;JX003086YP@2Jd9P0V]2H
0080V]2H2@21ZH4309?:U003086YP@24]hH0Q;N600P0Q;N60P21ZH4506fJK`03086YP@1=LE00PJV1
0;40/>3V0@3oool00;80/>3V00<0PJV106fKO@1]Vgd00P1]Vgd00`21ZH40Q[ZB08JjTP0608JjTP03
086YP@2FcYh0U/jN00/0U/jN00@0PJV109kHY02Nf:@0W]RT2@21ZH440:GMZ003086YP@2Wh:P0Yn2X
0180Yn2X00<0PJV10:KOY@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX0070:;JX0h0PJV12`2CbY@00`21
ZH40Q;N608BgQP0808BgQP03086YP@1]VVl0KIY_00@0KIY_00<0PJV104eaD021ZH40/P2`h>H10?oo
o`00/`2`h>H2086YP@<0KI]m00<0PJV108JjTP26^Y801P26^Y800`21ZH40U/jN09K>WP0:09K>WP03
086YP@2Nf:@0W]RT00X0W]RT>021ZH4809cEWP03086YP@2CbY@0TlZD00d0TlZD00<0PJV108BgQP24
]hH02024]hH00`21ZH40KIY_06fJK`0406fJK`<0PJV1/`2`h>H10?ooo`00]@2`h>H01@21ZH40KI]m
06fKO@1]Vgd0PJV100P0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00=09kHY003
086YP@2QfjD0XM^U0180XM^U00<0PJV10:7JX`2QfZ<04P2QfZ<00`21ZH40W=FN09cEWP0?09cEWP03
086YP@2CbY@0TlZD00d0TlZD00<0PJV108BgQP24]hH01`24]hH00`21ZH40KIY_06fJK`0306fJK`<0
PJV1]@2`h>H10?ooo`00]P2`h>H01021ZH40KI]m06fKO@1]Vgd2086YP@H0Q[ZB00<0PJV109K>WP2F
cYh02`2FcYh00`21ZH40W]RT09kHY00=09kHY003086YP@2QfjD0XM^U0140XM^U00<0PJV10:7JX`2Q
fZ<04@2QfZ<00`21ZH40W=FN09cEWP0?09cEWP03086YP@2CbY@0TlZD00d0TlZD00<0PJV108BgQP24
]hH01`24]hH00`21ZH40KIY_06fJK`0306fJK`<0PJV1]P2`h>H10?ooo`00]`2`h>H2086YP@<0KI]m
00<0PJV108JjTP26^Y801026^Y800`21ZH40U/jN09K>WP0;09K>WP03086YP@2Nf:@0W]RT00`0W]RT
00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086YP@2LeIh0W=FN00h0W=FN
00<0PJV109?:U02CbY@03@2CbY@00`21ZH40Q;N608BgQP0608BgQP80PJV11@1]VVl2086YPKP0/>3V
0@3oool00;P0/>3V1P21ZH4608JjTP03086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@03@2N
f:@00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2QfZ<0XMZS0140XMZS00<0PJV109cEWP2LeIh03P2L
eIh00`21ZH40TlZD09?:U00<09?:U003086YP@24]hH0Q;N600H0Q;N600<0PJV106fJK`1]VVl00P1]
VVl3086YPKX0/>3V0@3oool00;X0/>3V0P21ZH40101NRFl0PJV1086YP@21ZH4508JjTP03086YP@2F
cYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Q
fZ<0XMZS0140XMZS00<0PJV109cEWP2LeIh03@2LeIh00`21ZH40TlZD09?:U00<09?:U003086YP@24
]hH0Q;N600H0Q;N600<0PJV106fJK`21ZH401@21ZH6k0;3PiP40oooo002l0;3PiP80PJV100<0GXU_
086YP@21ZH400P21ZH4308JjTP03086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@0302Nf:@0
0`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2QfZ<0XMZS00l0XMZS00<0PJV109cEWP2LeIh03P2LeIh0
0`21ZH40TlZD09?:U00;09?:U003086YP@24]hH0Q;N600D0Q;N61021ZH4205n;IP80PJV1_@2`h>H1
0?ooo`00_P2`h>H2086YP@0305j9K`21ZH40PJV100D0PJV1302FcYh00`21ZH40W]RT09kHY00;09kH
Y003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<00`21ZH40W=FN09cEWP0=09cE
WP03086YP@2CbY@0TlZD00`0TlZD00@0PJV108BgQP24]hH0Q;N61@21ZH4305n;IP80PJV1_`2`h>H1
0?ooo`00`02`h>H2086YP@0305j9K`21ZH40PJV10080MJN42021ZH4509K>WP03086YP@2Nf:@0W]RT
00`0W]RT00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XMZS0:7JX`0?0:7JX`03086YP@2LeIh0W=FN
00`0W=FN00<0PJV109?:U02CbY@0302CbY@5086YP@0307FVN`21ZH40PJV100<0Gh]V0P21ZH710;3P
iP40oooo00320;3PiP80PJV100<0GXU_086YP@1eYh@00P1eYh@2086YP@@0QK^A2P21ZH4:09kHY003
086YP@2QfjD0XM^U00l0XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<00`21ZH40W=FN09cEWP0<09cEWP03
086YP@2CbY@0TlZD00@0TlZD2@21ZH4407FVN`04086YP@1ORfH0Gh]V05n;IP80PJV1``2`h>H10?oo
o`00a02`h>H4086YP@<0MJN40P21ZH4908FkT@03086YP@2>aYP0S/JH00P0PJV10`2Nf:@00`21ZH40
XM^U0:7KY@0>0:7KY@03086YP@2QfZ<0XMZS00h0XMZS00<0PJV109cEWP2LeIh01@2LeIh?086YP@D0
Q;V:0P21ZH4407FVN`80PJV10P1ORfH2086YPLD0/>3V0@3oool00<H0/>3V1021ZH4307FWQ003086Y
P@25^i40QK^A00L0QK^A00<0PJV108k6V02>aYP01`2>aYP]086YP@H0S/FC00<0PJV108BiRP24^HX0
2P24^HX00`21ZH40MJIk07FVN`0307FVN`03086YP@1ORfH0Gh]V00<0PJV1aP2`h>H10?ooo`00b@2`
h>H3086YP@80MJN40P21ZH4808FkT@03086YP@2>aYP0S/JH00X0S/JH00<0PJV109?<V`2Cc9/03@2C
c9/00`21ZH40T/^I09;;V@0=09;;V@03086YP@2>aI<0S/FC00/0S/FC00<0PJV108BiRP24^HX02@24
^HX2086YP@@0MJIk0P21ZH40101ORfH0PJV1086YP@21ZH780;3PiP40oooo003;0;3PiP<0PJV10P1e
Yh@2086YP@L0QK^A0P21ZH4;08k6V003086YP@2Cc9/0TlbK00`0TlbK00<0PJV109;;V@2BbiT03@2B
biT00`21ZH40S/FC08k5T`0:08k5T`03086YP@24^HX0Q;V:00P0Q;V:0P21ZH4407FVN`D0PJV1b`2`
h>H10?ooo`00cP2`h>H6086YP@L0QK^A00<0PJV108k6V02>aYP02@2>aYP00`21ZH40TlbK09?<V`0;
09?<V`03086YP@2BbiT0T/^I00`0T/^I00<0PJV108k5T`2>aI<02P2>aI<00`21ZH40Q;V:08BiRP08
08BiRP04086YP@1eYW/0MJIk07FVN`H0PJV1c@2`h>H10?ooo`00d@2`h>H6086YP@D0QK^A00<0PJV1
08k6V02>aYP0202>aYP00`21ZH40TlbK09?<V`0<09?<V`03086YP@2BbiT0T/^I00/0T/^I00<0PJV1
08k5T`2>aI<02@2>aI<00`21ZH40Q;V:08BiRP0708BiRPT0PJV1d02`h>H10?ooo`00d`2`h>H9086Y
P@0308FkT@21ZH40S/JH00T0S/JH00<0PJV109?<V`2Cc9/02`2Cc9/00`21ZH40T/^I09;;V@0:09;;
V@03086YP@2>aI<0S/FC00T0S/FC00<0PJV108BiRP24^HX00P24^HX<086YPM<0/>3V0@3oool00=H0
/>3V1@21ZH400`1ZVWT0PJV1086YP@06086YP@D0S/JH00<0PJV109?<V`2Cc9/02P2Cc9/00`21ZH40
T/^I09;;V@0:09;;V@03086YP@2>aI<0S/FC00<0S/FC2`21ZH4206^KM@80PJV100<0GHUW086YP@21
ZH400`21ZH7E0;3PiP40oooo003I0;3PiPD0PJV10P1ZVWT2086YP@80LjJ19@21ZH4307>VOP80PJV1
1@1[VgD2086YP@0305f9I`21ZH40PJV100<0PJV1f02`h>H10?ooo`00g@2`h>H3086YP@80JYYi0P21
ZH4707>VP@80PJV12@1h[8@00`21ZH40N:^307R[P`0807R[P`03086YP@1cYWh0LjIn00H0LjIn0P21
ZH4406^KM@L0PJV1g02`h>H10?ooo`00h02`h>H6086YP@L0LjJ10P21ZH4707R/Q003086YP@1hZh<0
N:^300L0N:^300<0PJV107>VOP1cYWh01@1cYWh2086YP@0306^KM@21ZH40PJV100D0PJV1h@2`h>H1
0?ooo`00i02`h>H?086YP@@0N:b400<0PJV107R[P`1hZh<01P1hZh<01021ZH40LjIn07>VOP1cYWh7
086YPNP0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.603 .774 .563 r
.4405 .46951 m .43989 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.47983 .5 m .48003 .46975 L .4405 .46951 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.48003 .53025 m .47983 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.48003 .46975 m .47983 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.47983 .5 m .48003 .53025 L .51997 .53025 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.51997 .53025 m .52017 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.52017 .5 m .51997 .46975 L .48003 .46975 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.51997 .46975 m .52017 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.52017 .5 m .51997 .53025 L .5595 .53049 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.5595 .53049 m .56011 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.44233 .43937 m .4405 .46951 L .48003 .46975 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.48003 .46975 m .48064 .43983 L .44233 .43937 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.43989 .5 m .4405 .53049 L .48003 .53025 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.48064 .56017 m .48003 .53025 L .4405 .53049 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.48064 .43983 m .48003 .46975 L .51997 .46975 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.48003 .53025 m .48064 .56017 L .51936 .56017 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.51936 .56017 m .51997 .53025 L .48003 .53025 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.51997 .46975 m .51936 .43983 L .48064 .43983 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.51936 .43983 m .51997 .46975 L .5595 .46951 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.56011 .5 m .5595 .46951 L .51997 .46975 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.51997 .53025 m .51936 .56017 L .55767 .56063 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.55767 .56063 m .5595 .53049 L .51997 .53025 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.49152 .43694 m
.49294 .43983 L
s
.54838 .46129 m
.54934 .46036 L
s
.55012 .46257 m
.55095 .46177 L
s
.54934 .46036 m
.55095 .46177 L
s
.49152 .43694 m
.49154 .4354 L
s
.5068 .4323 m
.50836 .4354 L
s
.49154 .4354 m
.4931 .4323 L
s
.5 Mabswid
.592 .761 .549 r
.40219 .46902 m .40117 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.43989 .5 m .4405 .46951 L .40219 .46902 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.4405 .53049 m .43989 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.5595 .46951 m .56011 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.56011 .5 m .5595 .53049 L .59781 .53098 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.59781 .53098 m .59883 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.44539 .40995 m .44233 .43937 L .48064 .43983 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.48064 .43983 m .48166 .41061 L .44539 .40995 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.4405 .53049 m .44233 .56063 L .48064 .56017 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.48166 .58939 m .48064 .56017 L .44233 .56063 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.48166 .41061 m .48064 .43983 L .51936 .43983 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.48064 .56017 m .48166 .58939 L .51834 .58939 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.51834 .58939 m .51936 .56017 L .48064 .56017 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.51936 .43983 m .51834 .41061 L .48166 .41061 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.51834 .41061 m .51936 .43983 L .55767 .43937 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.5475 .43034 m
.54762 .43202 L
s
.5 Mabswid
.626 .809 .598 r
.5595 .46951 m .55767 .43937 L .51936 .43983 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.51936 .56017 m .51834 .58939 L .55461 .59005 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.55461 .59005 m .55767 .56063 L .51936 .56017 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.40525 .43843 m .40219 .46902 L .4405 .46951 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.4405 .46951 m .44233 .43937 L .40525 .43843 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.40117 .5 m .40219 .53098 L .4405 .53049 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.44233 .56063 m .4405 .53049 L .40219 .53098 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.55767 .43937 m .5595 .46951 L .59781 .46902 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.59883 .5 m .59781 .46902 L .5595 .46951 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.5595 .53049 m .55767 .56063 L .59475 .56157 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.59475 .56157 m .59781 .53098 L .5595 .53049 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.41034 .40863 m .40525 .43843 L .44233 .43937 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.44233 .43937 m .44539 .40995 L .41034 .40863 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.40219 .53098 m .40525 .56157 L .44233 .56063 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.44539 .59005 m .44233 .56063 L .40525 .56157 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.44233 .56063 m .44539 .59005 L .48166 .58939 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.55767 .43937 m .55461 .40995 L .51834 .41061 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.55461 .40995 m .55767 .43937 L .59475 .43843 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.5602 .4393 m
.56038 .44137 L
s
.5 Mabswid
.625 .808 .601 r
.59781 .46902 m .59475 .43843 L .55767 .43937 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.55767 .56063 m .55461 .59005 L .58966 .59137 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.58966 .59137 m .59475 .56157 L .55767 .56063 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.44966 .38165 m .44539 .40995 L .48166 .41061 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.48166 .41061 m .48309 .38245 L .44966 .38165 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.48309 .61755 m .48166 .58939 L .44539 .59005 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.48309 .38245 m .48166 .41061 L .51834 .41061 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.48166 .58939 m .48309 .61755 L .51691 .61755 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.51691 .61755 m .51834 .58939 L .48166 .58939 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.51834 .41061 m .51691 .38245 L .48309 .38245 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.51691 .38245 m .51834 .41061 L .55461 .40995 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.51834 .58939 m .51691 .61755 L .55034 .61835 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.55034 .61835 m .55461 .59005 L .51834 .58939 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.36601 .46829 m .36459 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.40117 .5 m .40219 .46902 L .36601 .46829 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.40219 .53098 m .40117 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.59781 .46902 m .59883 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.59883 .5 m .59781 .53098 L .63399 .53171 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.63399 .53171 m .63541 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.3703 .43702 m .36601 .46829 L .40219 .46902 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.40219 .46902 m .40525 .43843 L .3703 .43702 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.36459 .5 m .36601 .53171 L .40219 .53098 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.40525 .56157 m .40219 .53098 L .36601 .53171 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.59475 .43843 m .59781 .46902 L .63399 .46829 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.63541 .5 m .63399 .46829 L .59781 .46902 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.59781 .53098 m .59475 .56157 L .6297 .56298 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.6297 .56298 m .63399 .53171 L .59781 .53098 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.41746 .38006 m .41034 .40863 L .44539 .40995 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.44539 .40995 m .44966 .38165 L .41746 .38006 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.40525 .56157 m .41034 .59137 L .44539 .59005 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.44966 .61835 m .44539 .59005 L .41034 .59137 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.44539 .59005 m .44966 .61835 L .48309 .61755 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.55461 .40995 m .55034 .38165 L .51691 .38245 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.55034 .38165 m .55461 .40995 L .58966 .40863 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.59475 .43843 m .58966 .40863 L .55461 .40995 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.55461 .59005 m .55034 .61835 L .58254 .61994 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.58254 .61994 m .58966 .59137 L .55461 .59005 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.36601 .53171 m .3703 .56298 L .40525 .56157 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.41034 .59137 m .40525 .56157 L .3703 .56298 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.37741 .40665 m .3703 .43702 L .40525 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.40525 .43843 m .41034 .40863 L .37741 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.58966 .40863 m .59475 .43843 L .6297 .43702 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.63399 .46829 m .6297 .43702 L .59475 .43843 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.59475 .56157 m .58966 .59137 L .62259 .59335 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.62259 .59335 m .6297 .56298 L .59475 .56157 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.45516 .35491 m .44966 .38165 L .48309 .38245 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.48309 .38245 m .48493 .35578 L .45516 .35491 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.48493 .64422 m .48309 .61755 L .44966 .61835 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.48493 .35578 m .48309 .38245 L .51691 .38245 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.48309 .61755 m .48493 .64422 L .51507 .64422 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.51507 .64422 m .51691 .61755 L .48309 .61755 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.51691 .38245 m .51507 .35578 L .48493 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.51507 .35578 m .51691 .38245 L .55034 .38165 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.51691 .61755 m .51507 .64422 L .54484 .64509 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.54484 .64509 m .55034 .61835 L .51691 .61755 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.38734 .37767 m .37741 .40665 L .41034 .40863 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.41034 .40863 m .41746 .38006 L .38734 .37767 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.3703 .56298 m .37741 .59335 L .41034 .59137 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.41746 .61994 m .41034 .59137 L .37741 .59335 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.41034 .59137 m .41746 .61994 L .44966 .61835 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.58966 .40863 m .58254 .38006 L .55034 .38165 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.58254 .38006 m .58966 .40863 L .62259 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.6297 .43702 m .62259 .40665 L .58966 .40863 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.58966 .59137 m .58254 .61994 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.61266 .62233 m .62259 .59335 L .58966 .59137 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.42658 .35317 m .41746 .38006 L .44966 .38165 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.44966 .38165 m .45516 .35491 L .42658 .35317 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.45516 .64509 m .44966 .61835 L .41746 .61994 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.44966 .61835 m .45516 .64509 L .48493 .64422 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.55034 .38165 m .54484 .35491 L .51507 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.54484 .35491 m .55034 .38165 L .58254 .38006 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.55034 .61835 m .54484 .64509 L .57342 .64683 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.57342 .64683 m .58254 .61994 L .55034 .61835 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.33301 .46731 m .33118 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.36459 .5 m .36601 .46829 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.36601 .53171 m .36459 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.63399 .46829 m .63541 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.63541 .5 m .63399 .53171 L .66699 .53269 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.66699 .53269 m .66882 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.33851 .43514 m .33301 .46731 L .36601 .46829 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.36601 .46829 m .3703 .43702 L .33851 .43514 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.33118 .5 m .33301 .53269 L .36601 .53171 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.3703 .56298 m .36601 .53171 L .33301 .53269 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.6297 .43702 m .63399 .46829 L .66699 .46731 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.66882 .5 m .66699 .46731 L .63399 .46829 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.63399 .53171 m .6297 .56298 L .66149 .56486 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.66149 .56486 m .66699 .53269 L .63399 .53171 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.34762 .40403 m .33851 .43514 L .3703 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.3703 .43702 m .37741 .40665 L .34762 .40403 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.33301 .53269 m .33851 .56486 L .3703 .56298 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.37741 .59335 m .3703 .56298 L .33851 .56486 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.62259 .40665 m .6297 .43702 L .66149 .43514 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.66699 .46731 m .66149 .43514 L .6297 .43702 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.6297 .56298 m .62259 .59335 L .65238 .59597 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.65238 .59597 m .66149 .56486 L .6297 .56298 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.46188 .3302 m .45516 .35491 L .48493 .35578 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.48493 .35578 m .48717 .33107 L .46188 .3302 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.48717 .33107 m .48493 .35578 L .51507 .35578 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.48717 .66893 m .48493 .64422 L .45516 .64509 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.51507 .35578 m .51283 .33107 L .48717 .33107 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.48493 .64422 m .48717 .66893 L .51283 .66893 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.51283 .66893 m .51507 .64422 L .48493 .64422 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.51283 .33107 m .51507 .35578 L .54484 .35491 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.51507 .64422 m .51283 .66893 L .53812 .6698 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.53812 .6698 m .54484 .64509 L .51507 .64422 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.40002 .35058 m .38734 .37767 L .41746 .38006 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.41746 .38006 m .42658 .35317 L .40002 .35058 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.37741 .59335 m .38734 .62233 L .41746 .61994 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.42658 .64683 m .41746 .61994 L .38734 .62233 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.41746 .61994 m .42658 .64683 L .45516 .64509 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.58254 .38006 m .57342 .35317 L .54484 .35491 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.57342 .35317 m .58254 .38006 L .61266 .37767 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.62259 .40665 m .61266 .37767 L .58254 .38006 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.58254 .61994 m .57342 .64683 L .59998 .64942 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.59998 .64942 m .61266 .62233 L .58254 .61994 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.43769 .32847 m .42658 .35317 L .45516 .35491 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.45516 .35491 m .46188 .3302 L .43769 .32847 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.46188 .6698 m .45516 .64509 L .42658 .64683 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.45516 .64509 m .46188 .6698 L .48717 .66893 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.54484 .35491 m .53812 .3302 L .51283 .33107 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.53812 .3302 m .54484 .35491 L .57342 .35317 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.54484 .64509 m .53812 .6698 L .56231 .67153 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.56231 .67153 m .57342 .64683 L .54484 .64509 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.36027 .37452 m .34762 .40403 L .37741 .40665 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.37741 .40665 m .38734 .37767 L .36027 .37452 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.33851 .56486 m .34762 .59597 L .37741 .59335 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.38734 .62233 m .37741 .59335 L .34762 .59597 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.61266 .37767 m .62259 .40665 L .65238 .40403 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.66149 .43514 m .65238 .40403 L .62259 .40665 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.62259 .59335 m .61266 .62233 L .63973 .62548 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.63973 .62548 m .65238 .59597 L .62259 .59335 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.41536 .32591 m .40002 .35058 L .42658 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.42658 .35317 m .43769 .32847 L .41536 .32591 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.38734 .62233 m .40002 .64942 L .42658 .64683 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.43769 .67153 m .42658 .64683 L .40002 .64942 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.42658 .64683 m .43769 .67153 L .46188 .6698 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.57342 .35317 m .56231 .32847 L .53812 .3302 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.56231 .32847 m .57342 .35317 L .59998 .35058 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.61266 .37767 m .59998 .35058 L .57342 .35317 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.57342 .64683 m .56231 .67153 L .58464 .67409 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.58464 .67409 m .59998 .64942 L .57342 .64683 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.37636 .34717 m .36027 .37452 L .38734 .37767 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.38734 .37767 m .40002 .35058 L .37636 .34717 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.34762 .59597 m .36027 .62548 L .38734 .62233 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.40002 .64942 m .38734 .62233 L .36027 .62548 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.59998 .35058 m .61266 .37767 L .63973 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.65238 .40403 m .63973 .37452 L .61266 .37767 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.61266 .62233 m .59998 .64942 L .62364 .65283 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.62364 .65283 m .63973 .62548 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.30442 .46609 m .30218 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.33118 .5 m .33301 .46731 L .30442 .46609 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.33301 .53269 m .33118 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.66699 .46731 m .66882 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.66882 .5 m .66699 .53269 L .69558 .53391 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.69558 .53391 m .69782 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.46978 .30806 m .46188 .3302 L .48717 .33107 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.48717 .33107 m .48982 .30885 L .46978 .30806 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.48982 .30885 m .48717 .33107 L .51283 .33107 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.48982 .69115 m .48717 .66893 L .46188 .6698 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.51283 .33107 m .51018 .30885 L .48982 .30885 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.48717 .66893 m .48982 .69115 L .51018 .69115 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.51018 .69115 m .51283 .66893 L .48717 .66893 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.51018 .30885 m .51283 .33107 L .53812 .3302 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.51283 .66893 m .51018 .69115 L .53022 .69194 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.53022 .69194 m .53812 .6698 L .51283 .66893 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.31108 .43281 m .30442 .46609 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.33301 .46731 m .33851 .43514 L .31108 .43281 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.30218 .5 m .30442 .53391 L .33301 .53269 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.33851 .56486 m .33301 .53269 L .30442 .53391 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.66149 .43514 m .66699 .46731 L .69558 .46609 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.69782 .5 m .69558 .46609 L .66699 .46731 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.66699 .53269 m .66149 .56486 L .68892 .56719 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.68892 .56719 m .69558 .53391 L .66699 .53269 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6609 .43311 m
.66091 .43036 L
s
.5 Mabswid
.548 .718 .508 r
.3221 .40078 m .31108 .43281 L .33851 .43514 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.33851 .43514 m .34762 .40403 L .3221 .40078 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.30442 .53391 m .31108 .56719 L .33851 .56486 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.34762 .59597 m .33851 .56486 L .31108 .56719 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.45071 .30652 m .43769 .32847 L .46188 .3302 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.46188 .3302 m .46978 .30806 L .45071 .30652 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.46978 .69194 m .46188 .6698 L .43769 .67153 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.46188 .6698 m .46978 .69194 L .48982 .69115 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.53812 .3302 m .53022 .30806 L .51018 .30885 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.53022 .30806 m .53812 .3302 L .56231 .32847 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.53812 .6698 m .53022 .69194 L .54929 .69348 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.54929 .69348 m .56231 .67153 L .53812 .6698 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.65238 .40403 m .66149 .43514 L .68892 .43281 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.69558 .46609 m .68892 .43281 L .66149 .43514 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.66149 .56486 m .65238 .59597 L .6779 .59922 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.6779 .59922 m .68892 .56719 L .66149 .56486 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.3957 .32256 m .37636 .34717 L .40002 .35058 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.40002 .35058 m .41536 .32591 L .3957 .32256 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.36027 .62548 m .37636 .65283 L .40002 .64942 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.41536 .67409 m .40002 .64942 L .37636 .65283 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.40002 .64942 m .41536 .67409 L .43769 .67153 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.59998 .35058 m .58464 .32591 L .56231 .32847 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.58464 .32591 m .59998 .35058 L .62364 .34717 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.63973 .37452 m .62364 .34717 L .59998 .35058 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.59998 .64942 m .58464 .67409 L .6043 .67744 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.6043 .67744 m .62364 .65283 L .59998 .64942 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.33733 .37063 m .3221 .40078 L .34762 .40403 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.34762 .40403 m .36027 .37452 L .33733 .37063 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.31108 .56719 m .3221 .59922 L .34762 .59597 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.36027 .62548 m .34762 .59597 L .3221 .59922 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.63973 .37452 m .65238 .40403 L .6779 .40078 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.68892 .43281 m .6779 .40078 L .65238 .40403 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.65238 .59597 m .63973 .62548 L .66267 .62937 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.66267 .62937 m .6779 .59922 L .65238 .59597 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43326 .30424 m .41536 .32591 L .43769 .32847 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43769 .32847 m .45071 .30652 L .43326 .30424 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.45071 .69348 m .43769 .67153 L .41536 .67409 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.43769 .67153 m .45071 .69348 L .46978 .69194 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.56231 .32847 m .54929 .30652 L .53022 .30806 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.54929 .30652 m .56231 .32847 L .58464 .32591 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56231 .67153 m .54929 .69348 L .56674 .69576 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56674 .69576 m .58464 .67409 L .56231 .67153 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.35657 .34299 m .33733 .37063 L .36027 .37452 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.36027 .37452 m .37636 .34717 L .35657 .34299 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.3221 .59922 m .33733 .62937 L .36027 .62548 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.37636 .65283 m .36027 .62548 L .33733 .62937 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.62364 .34717 m .63973 .37452 L .66267 .37063 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.6779 .40078 m .66267 .37063 L .63973 .37452 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.63973 .62548 m .62364 .65283 L .64343 .65701 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.64343 .65701 m .66267 .62937 L .63973 .62548 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.47883 .28911 m .46978 .30806 L .48982 .30885 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.48982 .30885 m .49286 .28971 L .47883 .28911 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.49286 .28971 m .48982 .30885 L .51018 .30885 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.49286 .71029 m .48982 .69115 L .46978 .69194 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.48982 .69115 m .49286 .71029 L .50714 .71029 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.50714 .71029 m .51018 .69115 L .48982 .69115 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.51018 .30885 m .50714 .28971 L .49286 .28971 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50714 .28971 m .51018 .30885 L .53022 .30806 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.51018 .69115 m .50714 .71029 L .52117 .71089 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.52117 .71089 m .53022 .69194 L .51018 .69115 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41809 .30128 m .3957 .32256 L .41536 .32591 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41536 .32591 m .43326 .30424 L .41809 .30128 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.37636 .65283 m .3957 .67744 L .41536 .67409 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.43326 .69576 m .41536 .67409 L .3957 .67744 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.41536 .67409 m .43326 .69576 L .45071 .69348 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.58464 .32591 m .56674 .30424 L .54929 .30652 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.56674 .30424 m .58464 .32591 L .6043 .32256 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.62364 .34717 m .6043 .32256 L .58464 .32591 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58464 .67409 m .56674 .69576 L .58191 .69872 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58191 .69872 m .6043 .67744 L .58464 .67409 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46555 .28792 m .45071 .30652 L .46978 .30806 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46978 .30806 m .47883 .28911 L .46555 .28792 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.47883 .71089 m .46978 .69194 L .45071 .69348 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.46978 .69194 m .47883 .71089 L .49286 .71029 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.53022 .30806 m .52117 .28911 L .50714 .28971 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.52117 .28911 m .53022 .30806 L .54929 .30652 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53022 .69194 m .52117 .71089 L .53445 .71208 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53445 .71208 m .54929 .69348 L .53022 .69194 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37952 .31849 m .35657 .34299 L .37636 .34717 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37636 .34717 m .3957 .32256 L .37952 .31849 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.33733 .62937 m .35657 .65701 L .37636 .65283 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.3957 .67744 m .37636 .65283 L .35657 .65701 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.6043 .32256 m .62364 .34717 L .64343 .34299 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.66267 .37063 m .64343 .34299 L .62364 .34717 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62364 .65283 m .6043 .67744 L .62048 .68151 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62048 .68151 m .64343 .65701 L .62364 .65283 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.28166 .46465 m .27906 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.30218 .5 m .30442 .46609 L .28166 .46465 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.30442 .53391 m .30218 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.69558 .46609 m .69782 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.69782 .5 m .69558 .53391 L .71834 .53535 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.71834 .53535 m .72094 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.28941 .43004 m .28166 .46465 L .30442 .46609 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.30442 .46609 m .31108 .43281 L .28941 .43004 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.27906 .5 m .28166 .53535 L .30442 .53391 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.31108 .56719 m .30442 .53391 L .28166 .53535 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.68892 .43281 m .69558 .46609 L .71834 .46465 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.72094 .5 m .71834 .46465 L .69558 .46609 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.69558 .53391 m .68892 .56719 L .71059 .56996 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.71059 .56996 m .71834 .53535 L .69558 .53391 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45351 .28618 m .43326 .30424 L .45071 .30652 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45071 .30652 m .46555 .28792 L .45351 .28618 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.46555 .71208 m .45071 .69348 L .43326 .69576 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.45071 .69348 m .46555 .71208 L .47883 .71089 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.54929 .30652 m .53445 .28792 L .52117 .28911 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.53445 .28792 m .54929 .30652 L .56674 .30424 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54929 .69348 m .53445 .71208 L .54649 .71382 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54649 .71382 m .56674 .69576 L .54929 .69348 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.30216 .39695 m .28941 .43004 L .31108 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.31108 .43281 m .3221 .40078 L .30216 .39695 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.28166 .53535 m .28941 .56996 L .31108 .56719 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.3221 .59922 m .31108 .56719 L .28941 .56996 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.6779 .40078 m .68892 .43281 L .71059 .43004 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.71834 .46465 m .71059 .43004 L .68892 .43281 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.68892 .56719 m .6779 .59922 L .69784 .60305 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.69784 .60305 m .71059 .56996 L .68892 .56719 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3197 .36608 m .30216 .39695 L .3221 .40078 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3221 .40078 m .33733 .37063 L .3197 .36608 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.28941 .56996 m .30216 .60305 L .3221 .59922 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.33733 .62937 m .3221 .59922 L .30216 .60305 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.66267 .37063 m .6779 .40078 L .69784 .39695 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.71059 .43004 m .69784 .39695 L .6779 .40078 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6779 .59922 m .66267 .62937 L .6803 .63392 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6803 .63392 m .69784 .60305 L .6779 .59922 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.40584 .29772 m .37952 .31849 L .3957 .32256 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.3957 .32256 m .41809 .30128 L .40584 .29772 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.35657 .65701 m .37952 .68151 L .3957 .67744 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.41809 .69872 m .3957 .67744 L .37952 .68151 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.3957 .67744 m .41809 .69872 L .43326 .69576 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.6043 .32256 m .58191 .30128 L .56674 .30424 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.58191 .30128 m .6043 .32256 L .62048 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.64343 .34299 m .62048 .31849 L .6043 .32256 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.6043 .67744 m .58191 .69872 L .59416 .70228 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.59416 .70228 m .62048 .68151 L .6043 .67744 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.44321 .28394 m .41809 .30128 L .43326 .30424 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.43326 .30424 m .45351 .28618 L .44321 .28394 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.45351 .71382 m .43326 .69576 L .41809 .69872 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.43326 .69576 m .45351 .71382 L .46555 .71208 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.56674 .30424 m .54649 .28618 L .53445 .28792 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.54649 .28618 m .56674 .30424 L .58191 .30128 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.56674 .69576 m .54649 .71382 L .55679 .71606 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.55679 .71606 m .58191 .69872 L .56674 .69576 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.34168 .33814 m .3197 .36608 L .33733 .37063 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.33733 .37063 m .35657 .34299 L .34168 .33814 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.30216 .60305 m .3197 .63392 L .33733 .62937 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.35657 .65701 m .33733 .62937 L .3197 .63392 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.64343 .34299 m .66267 .37063 L .6803 .36608 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.69784 .39695 m .6803 .36608 L .66267 .37063 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.66267 .62937 m .64343 .65701 L .65832 .66186 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.65832 .66186 m .6803 .63392 L .66267 .62937 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.48894 .274 m .47883 .28911 L .49286 .28971 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.49286 .28971 m .49626 .27434 L .48894 .274 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.49626 .27434 m .49286 .28971 L .50714 .28971 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.50714 .28971 m .50374 .27434 L .49626 .27434 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50374 .27434 m .50714 .28971 L .52117 .28911 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.49626 .72566 m .49286 .71029 L .47883 .71089 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.49286 .71029 m .49626 .72566 L .50374 .72566 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.50374 .72566 m .50714 .71029 L .49286 .71029 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.50714 .71029 m .50374 .72566 L .51106 .726 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.51106 .726 m .52117 .71089 L .50714 .71029 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.48205 .27334 m .46555 .28792 L .47883 .28911 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.47883 .28911 m .48894 .274 L .48205 .27334 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.48894 .726 m .47883 .71089 L .46555 .71208 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.47883 .71089 m .48894 .726 L .49626 .72566 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.52117 .28911 m .51106 .274 L .50374 .27434 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.51106 .274 m .52117 .28911 L .53445 .28792 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.52117 .71089 m .51106 .726 L .51795 .72666 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.51795 .72666 m .53445 .71208 L .52117 .71089 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.36767 .3138 m .34168 .33814 L .35657 .34299 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.35657 .34299 m .37952 .31849 L .36767 .3138 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.3197 .63392 m .34168 .66186 L .35657 .65701 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.37952 .68151 m .35657 .65701 L .34168 .66186 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.62048 .31849 m .64343 .34299 L .65832 .33814 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.6803 .36608 m .65832 .33814 L .64343 .34299 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.64343 .65701 m .62048 .68151 L .63233 .6862 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.63233 .6862 m .65832 .66186 L .64343 .65701 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.47588 .27237 m .45351 .28618 L .46555 .28792 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.46555 .28792 m .48205 .27334 L .47588 .27237 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.48205 .72666 m .46555 .71208 L .45351 .71382 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.46555 .71208 m .48205 .72666 L .48894 .726 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.53445 .28792 m .51795 .27334 L .51106 .274 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.51795 .27334 m .53445 .28792 L .54649 .28618 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.53445 .71208 m .51795 .72666 L .52412 .72763 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.52412 .72763 m .54649 .71382 L .53445 .71208 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.43508 .28127 m .40584 .29772 L .41809 .30128 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.41809 .30128 m .44321 .28394 L .43508 .28127 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.37952 .68151 m .40584 .70228 L .41809 .69872 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.44321 .71606 m .41809 .69872 L .40584 .70228 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.41809 .69872 m .44321 .71606 L .45351 .71382 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.58191 .30128 m .55679 .28394 L .54649 .28618 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.55679 .28394 m .58191 .30128 L .59416 .29772 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.62048 .31849 m .59416 .29772 L .58191 .30128 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.58191 .69872 m .55679 .71606 L .56492 .71873 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.56492 .71873 m .59416 .70228 L .58191 .69872 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.39716 .29366 m .36767 .3138 L .37952 .31849 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.37952 .31849 m .40584 .29772 L .39716 .29366 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.34168 .66186 m .36767 .6862 L .37952 .68151 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.40584 .70228 m .37952 .68151 L .36767 .6862 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.59416 .29772 m .62048 .31849 L .63233 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.65832 .33814 m .63233 .3138 L .62048 .31849 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.62048 .68151 m .59416 .70228 L .60284 .70634 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.60284 .70634 m .63233 .6862 L .62048 .68151 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.47068 .27114 m .44321 .28394 L .45351 .28618 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.45351 .28618 m .47588 .27237 L .47068 .27114 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.47588 .72763 m .45351 .71382 L .44321 .71606 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.45351 .71382 m .47588 .72763 L .48205 .72666 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.54649 .28618 m .52412 .27237 L .51795 .27334 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.52412 .27237 m .54649 .28618 L .55679 .28394 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.54649 .71382 m .52412 .72763 L .52932 .72886 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.52932 .72886 m .55679 .71606 L .54649 .71382 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.26636 .46299 m .26345 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.27906 .5 m .28166 .46465 L .26636 .46299 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.28166 .53535 m .27906 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.71834 .46465 m .72094 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.72094 .5 m .71834 .53535 L .73364 .53701 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.73364 .53701 m .73655 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.27502 .4269 m .26636 .46299 L .28166 .46465 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.28166 .46465 m .28941 .43004 L .27502 .4269 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.26345 .5 m .26636 .53701 L .28166 .53535 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.28941 .56996 m .28166 .53535 L .26636 .53701 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.71059 .43004 m .71834 .46465 L .73364 .46299 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.73655 .5 m .73364 .46299 L .71834 .46465 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.71834 .53535 m .71059 .56996 L .72498 .5731 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.72498 .5731 m .73364 .53701 L .71834 .53535 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28923 .39261 m .27502 .4269 L .28941 .43004 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28941 .43004 m .30216 .39695 L .28923 .39261 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.26636 .53701 m .27502 .5731 L .28941 .56996 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.30216 .60305 m .28941 .56996 L .27502 .5731 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.69784 .39695 m .71059 .43004 L .72498 .4269 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.73364 .46299 m .72498 .4269 L .71059 .43004 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71059 .56996 m .69784 .60305 L .71077 .60739 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71077 .60739 m .72498 .5731 L .71059 .56996 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30862 .36096 m .28923 .39261 L .30216 .39695 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30216 .39695 m .3197 .36608 L .30862 .36096 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.27502 .5731 m .28923 .60739 L .30216 .60305 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.3197 .63392 m .30216 .60305 L .28923 .60739 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.6803 .36608 m .69784 .39695 L .71077 .39261 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.72498 .4269 m .71077 .39261 L .69784 .39695 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69784 .60305 m .6803 .63392 L .69138 .63904 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69138 .63904 m .71077 .60739 L .69784 .60305 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.42953 .27826 m .39716 .29366 L .40584 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.40584 .29772 m .43508 .28127 L .42953 .27826 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.36767 .6862 m .39716 .70634 L .40584 .70228 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.43508 .71873 m .40584 .70228 L .39716 .70634 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.40584 .70228 m .43508 .71873 L .44321 .71606 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.59416 .29772 m .56492 .28127 L .55679 .28394 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.56492 .28127 m .59416 .29772 L .60284 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.63233 .3138 m .60284 .29366 L .59416 .29772 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.59416 .70228 m .56492 .71873 L .57047 .72174 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.57047 .72174 m .60284 .70634 L .59416 .70228 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.46668 .26969 m .43508 .28127 L .44321 .28394 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.44321 .28394 m .47068 .27114 L .46668 .26969 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.47068 .72886 m .44321 .71606 L .43508 .71873 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.44321 .71606 m .47068 .72886 L .47588 .72763 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.55679 .28394 m .52932 .27114 L .52412 .27237 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.52932 .27114 m .55679 .28394 L .56492 .28127 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.55679 .71606 m .52932 .72886 L .53332 .73031 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.53332 .73031 m .56492 .71873 L .55679 .71606 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.33273 .33273 m .30862 .36096 L .3197 .36608 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.3197 .36608 m .34168 .33814 L .33273 .33273 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.28923 .60739 m .30862 .63904 L .3197 .63392 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.34168 .66186 m .3197 .63392 L .30862 .63904 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.65832 .33814 m .6803 .36608 L .69138 .36096 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.71077 .39261 m .69138 .36096 L .6803 .36608 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.6803 .63392 m .65832 .66186 L .66727 .66727 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.66727 .66727 m .69138 .63904 L .6803 .63392 L p F P
.505 .664 .505 r
s
.554 .773 .585 r
.49626 .27434 m .5 .26345 L .48894 .274 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50374 .27434 m .5 .26345 L .49626 .27434 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.51106 .274 m .5 .26345 L .50374 .27434 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49626 .72566 L .48894 .726 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50374 .72566 L .49626 .72566 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .51106 .726 L .50374 .72566 L closepath p F P
.505 .664 .505 r
s
.551 .769 .581 r
.48894 .274 m .5 .26345 L .48205 .27334 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48894 .726 L .48205 .72666 L closepath p F P
.505 .664 .505 r
s
.554 .773 .586 r
.51795 .27334 m .5 .26345 L .51106 .274 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .51795 .72666 L .51106 .726 L closepath p F P
.505 .664 .505 r
s
.47 .648 .464 r
.36096 .30862 m .33273 .33273 L .34168 .33814 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.34168 .33814 m .36767 .3138 L .36096 .30862 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.30862 .63904 m .33273 .66727 L .34168 .66186 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.36767 .6862 m .34168 .66186 L .33273 .66727 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.63233 .3138 m .65832 .33814 L .66727 .33273 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.69138 .36096 m .66727 .33273 L .65832 .33814 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.65832 .66186 m .63233 .6862 L .63904 .69138 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.63904 .69138 m .66727 .66727 L .65832 .66186 L p F P
.505 .664 .505 r
s
.546 .763 .576 r
.48205 .27334 m .5 .26345 L .47588 .27237 L closepath p F P
.505 .664 .505 r
s
.198 .204 .155 r
.5 .73655 m .48205 .72666 L .47588 .72763 L closepath p F P
.505 .664 .505 r
s
.55 .768 .584 r
.52412 .27237 m .5 .26345 L .51795 .27334 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .52412 .72763 L .51795 .72666 L closepath p F P
.505 .664 .505 r
s
.537 .749 .559 r
.46407 .26807 m .42953 .27826 L .43508 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.43508 .28127 m .46668 .26969 L .46407 .26807 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.39716 .70634 m .42953 .72174 L .43508 .71873 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.46668 .73031 m .43508 .71873 L .42953 .72174 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.43508 .71873 m .46668 .73031 L .47068 .72886 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.56492 .28127 m .53332 .26969 L .52932 .27114 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.53332 .26969 m .56492 .28127 L .57047 .27826 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.60284 .29366 m .57047 .27826 L .56492 .28127 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.56492 .71873 m .53332 .73031 L .53593 .73193 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.53593 .73193 m .57047 .72174 L .56492 .71873 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.39261 .28923 m .36096 .30862 L .36767 .3138 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.36767 .3138 m .39716 .29366 L .39261 .28923 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.33273 .66727 m .36096 .69138 L .36767 .6862 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.39716 .70634 m .36767 .6862 L .36096 .69138 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.60284 .29366 m .63233 .3138 L .63904 .30862 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.66727 .33273 m .63904 .30862 L .63233 .3138 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.63233 .6862 m .60284 .70634 L .60739 .71077 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.60739 .71077 m .63904 .69138 L .63233 .6862 L p F P
.505 .664 .505 r
s
.539 .755 .57 r
.47588 .27237 m .5 .26345 L .47068 .27114 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .47588 .72763 L .47068 .72886 L closepath p F P
.505 .664 .505 r
s
.545 .762 .58 r
.52932 .27114 m .5 .26345 L .52412 .27237 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .52932 .72886 L .52412 .72763 L closepath p F P
.505 .664 .505 r
s
.501 .701 .516 r
.4269 .27502 m .39261 .28923 L .39716 .29366 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.39716 .29366 m .42953 .27826 L .4269 .27502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.36096 .69138 m .39261 .71077 L .39716 .70634 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42953 .72174 m .39716 .70634 L .39261 .71077 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.57047 .27826 m .60284 .29366 L .60739 .28923 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.63904 .30862 m .60739 .28923 L .60284 .29366 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.60284 .70634 m .57047 .72174 L .5731 .72498 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.5731 .72498 m .60739 .71077 L .60284 .70634 L p F P
.505 .664 .505 r
s
.531 .745 .563 r
.47068 .27114 m .5 .26345 L .46668 .26969 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .47068 .72886 L .46668 .73031 L closepath p F P
.505 .664 .505 r
s
.537 .753 .575 r
.53332 .26969 m .5 .26345 L .52932 .27114 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .53332 .73031 L .52932 .72886 L closepath p F P
.505 .664 .505 r
s
.509 .716 .534 r
.46299 .26636 m .4269 .27502 L .42953 .27826 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.42953 .27826 m .46407 .26807 L .46299 .26636 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.39261 .71077 m .4269 .72498 L .42953 .72174 L p F P
.505 .664 .505 r
s
.187 .194 .147 r
.46407 .73193 m .42953 .72174 L .4269 .72498 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.42953 .72174 m .46407 .73193 L .46668 .73031 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.57047 .27826 m .53593 .26807 L .53332 .26969 L p F P
.505 .664 .505 r
s
.53 .744 .575 r
.53593 .26807 m .57047 .27826 L .5731 .27502 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.60739 .28923 m .5731 .27502 L .57047 .27826 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57047 .72174 m .53593 .73193 L .53701 .73364 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.53701 .73364 m .5731 .72498 L .57047 .72174 L p F P
.505 .664 .505 r
s
.522 .734 .555 r
.46668 .26969 m .5 .26345 L .46407 .26807 L closepath p F P
.505 .664 .505 r
s
.183 .191 .145 r
.5 .73655 m .46668 .73031 L .46407 .73193 L closepath p F P
.505 .664 .505 r
s
.529 .743 .568 r
.53593 .26807 m .5 .26345 L .53332 .26969 L closepath p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .53593 .73193 L .53332 .73031 L closepath p F P
.505 .664 .505 r
s
.512 .722 .546 r
.46407 .26807 m .5 .26345 L .46299 .26636 L closepath p F P
.505 .664 .505 r
s
.187 .194 .147 r
.4269 .72498 m .46299 .73364 L .46407 .73193 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.5 .73655 m .46407 .73193 L .46299 .73364 L closepath p F P
.505 .664 .505 r
s
.519 .731 .56 r
.53701 .26636 m .5 .26345 L .53593 .26807 L closepath p F P
.505 .664 .505 r
s
.53 .744 .575 r
.5731 .27502 m .53701 .26636 L .53593 .26807 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .53701 .73364 L .53593 .73193 L closepath p F P
.505 .664 .505 r
s
.159 .19 .168 r
.72498 .5731 m .71077 .60739 L .71523 .61211 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.71077 .60739 m .69138 .63904 L .69463 .64457 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.69463 .64457 m .71523 .61211 L .71077 .60739 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.72498 .4269 m .73364 .46299 L .73972 .46118 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.73364 .46299 m .73655 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.74286 .5 m .73972 .46118 L .73364 .46299 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73655 .5 m .73364 .53701 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73364 .53701 m .72498 .5731 L .73041 .57654 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73041 .57654 m .73972 .53882 L .73364 .53701 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.69138 .36096 m .71077 .39261 L .71523 .38789 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.71077 .39261 m .72498 .4269 L .73041 .42346 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.73041 .42346 m .71523 .38789 L .71077 .39261 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.71523 .61211 m .73041 .57654 L .72498 .5731 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73972 .53882 m .74286 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.73972 .46118 m .73041 .42346 L .72498 .4269 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.66727 .33273 m .69138 .36096 L .69463 .35543 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.71523 .38789 m .69463 .35543 L .69138 .36096 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.69138 .63904 m .66727 .66727 L .66927 .67305 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.66927 .67305 m .69463 .64457 L .69138 .63904 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.66727 .66727 m .63904 .69138 L .63989 .69684 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.63989 .69684 m .66927 .67305 L .66727 .66727 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.63904 .30862 m .66727 .33273 L .66927 .32695 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.69463 .35543 m .66927 .32695 L .66727 .33273 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.60739 .28923 m .63904 .30862 L .63989 .30316 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.66927 .32695 m .63989 .30316 L .63904 .30862 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.36011 .30316 m .33073 .32695 L .33273 .33273 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.33273 .33273 m .36096 .30862 L .36011 .30316 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.30862 .36096 m .33273 .33273 L .33073 .32695 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.30537 .64457 m .33073 .67305 L .33273 .66727 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.33273 .66727 m .30862 .63904 L .30537 .64457 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.36096 .69138 m .33273 .66727 L .33073 .67305 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.63904 .69138 m .60739 .71077 L .60735 .71539 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.60739 .71077 m .5731 .72498 L .57256 .72831 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.57256 .72831 m .60735 .71539 L .60739 .71077 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.5731 .27502 m .60739 .28923 L .60735 .28461 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.63989 .30316 m .60735 .28461 L .60739 .28923 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.28477 .38789 m .26959 .42346 L .27502 .4269 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.27502 .4269 m .28923 .39261 L .28477 .38789 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26636 .46299 m .27502 .4269 L .26959 .42346 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26028 .46118 m .25714 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26345 .5 m .26636 .46299 L .26028 .46118 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.26636 .53701 m .26345 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.26028 .53882 m .26959 .57654 L .27502 .5731 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.27502 .5731 m .26636 .53701 L .26028 .53882 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.28923 .60739 m .27502 .5731 L .26959 .57654 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.60735 .71539 m .63989 .69684 L .63904 .69138 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.5731 .72498 m .53701 .73364 L .53647 .73538 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.53647 .73538 m .57256 .72831 L .5731 .72498 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.39265 .28461 m .36011 .30316 L .36096 .30862 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.36096 .30862 m .39261 .28923 L .39265 .28461 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .53647 .73538 L .53701 .73364 L closepath p F P
.505 .664 .505 r
s
.162 .172 .13 r
.39265 .71539 m .42744 .72831 L .4269 .72498 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.4269 .72498 m .39261 .71077 L .39265 .71539 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.46299 .73364 m .4269 .72498 L .42744 .72831 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.42744 .27169 m .39265 .28461 L .39261 .28923 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.39261 .28923 m .4269 .27502 L .42744 .27169 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.53701 .26636 m .5731 .27502 L .57256 .27169 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.60735 .28461 m .57256 .27169 L .5731 .27502 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.33073 .67305 m .36011 .69684 L .36096 .69138 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.39261 .71077 m .36096 .69138 L .36011 .69684 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.30537 .35543 m .28477 .38789 L .28923 .39261 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.28923 .39261 m .30862 .36096 L .30537 .35543 L p F P
.505 .664 .505 r
s
.508 .719 .551 r
.53647 .26462 m .5 .26345 L .53701 .26636 L closepath p F P
.505 .664 .505 r
s
.499 .706 .548 r
.57256 .27169 m .53647 .26462 L .53701 .26636 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26959 .42346 m .26028 .46118 L .26636 .46299 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.25714 .5 m .26028 .53882 L .26636 .53701 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.36011 .69684 m .39265 .71539 L .39261 .71077 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.42744 .72831 m .46353 .73538 L .46299 .73364 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .46299 .73364 L .46353 .73538 L closepath p F P
.505 .664 .505 r
s
.158 .178 .131 r
.26959 .57654 m .28477 .61211 L .28923 .60739 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.30862 .63904 m .28923 .60739 L .28477 .61211 L p F P
.505 .664 .505 r
s
.501 .709 .537 r
.46299 .26636 m .5 .26345 L .46353 .26462 L closepath p F P
.505 .664 .505 r
s
.477 .676 .506 r
.4269 .27502 m .46299 .26636 L .46353 .26462 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.46353 .26462 m .42744 .27169 L .4269 .27502 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.5 .73655 m .47457 .73998 L .48091 .74106 L closepath p F P
.505 .664 .505 r
s
.149 .159 .121 r
.5 .73655 m .46942 .73863 L .47457 .73998 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .4657 .73707 L .46942 .73863 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .46353 .73538 L .4657 .73707 L closepath p F P
.505 .664 .505 r
s
.159 .169 .128 r
.5 .73655 m .5343 .73707 L .53647 .73538 L closepath p F P
.505 .664 .505 r
s
.152 .162 .124 r
.5 .73655 m .53058 .73863 L .5343 .73707 L closepath p F P
.505 .664 .505 r
s
.147 .157 .119 r
.5 .73655 m .52543 .73998 L .53058 .73863 L closepath p F P
.505 .664 .505 r
s
.142 .152 .116 r
.5 .73655 m .51909 .74106 L .52543 .73998 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .51184 .74182 L .51909 .74106 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50401 .7422 L .51184 .74182 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49599 .7422 L .50401 .7422 L closepath p F P
.505 .664 .505 r
s
.137 .148 .112 r
.5 .73655 m .48816 .74182 L .49599 .7422 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48091 .74106 L .48816 .74182 L closepath p F P
.505 .664 .505 r
s
.33 .466 .323 r
.33073 .32695 m .30537 .35543 L .30862 .36096 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.28477 .61211 m .30537 .64457 L .30862 .63904 L p F P
.505 .664 .505 r
s
.497 .705 .541 r
.5343 .26293 m .5 .26345 L .53647 .26462 L closepath p F P
.505 .664 .505 r
s
.486 .692 .531 r
.53058 .26137 m .5 .26345 L .5343 .26293 L closepath p F P
.505 .664 .505 r
s
.49 .696 .528 r
.46353 .26462 m .5 .26345 L .4657 .26293 L closepath p F P
.505 .664 .505 r
s
.48 .683 .519 r
.4657 .26293 m .5 .26345 L .46942 .26137 L closepath p F P
.505 .664 .505 r
s
.476 .679 .522 r
.52543 .26002 m .5 .26345 L .53058 .26137 L closepath p F P
.505 .664 .505 r
s
.467 .668 .513 r
.51909 .25894 m .5 .26345 L .52543 .26002 L closepath p F P
.505 .664 .505 r
s
.47 .672 .511 r
.46942 .26137 m .5 .26345 L .47457 .26002 L closepath p F P
.505 .664 .505 r
s
.462 .662 .505 r
.47457 .26002 m .5 .26345 L .48091 .25894 L closepath p F P
.505 .664 .505 r
s
.46 .659 .507 r
.51184 .25818 m .5 .26345 L .51909 .25894 L closepath p F P
.505 .664 .505 r
s
.455 .653 .502 r
.50401 .2578 m .5 .26345 L .51184 .25818 L closepath p F P
.505 .664 .505 r
s
.457 .655 .501 r
.48091 .25894 m .5 .26345 L .48816 .25818 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49599 .2578 m .5 .26345 L .50401 .2578 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.48816 .25818 m .5 .26345 L .49599 .2578 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28401 .61032 m
.28503 .61334 L
s
.5 Mabswid
.133 .145 .11 r
.57256 .72831 m .53647 .73538 L .5343 .73707 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.53647 .26462 m .57256 .27169 L .56874 .26841 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.56874 .26841 m .5343 .26293 L .53647 .26462 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.43126 .73159 m .4657 .73707 L .46353 .73538 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.46353 .73538 m .42744 .72831 L .43126 .73159 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.42744 .27169 m .46353 .26462 L .4657 .26293 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27252 .58983 m
.27455 .58817 L
s
.5 Mabswid
.133 .145 .11 r
.5343 .73707 m .56874 .73159 L .57256 .72831 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.56874 .73159 m .5343 .73707 L .53058 .73863 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.5343 .26293 m .56874 .26841 L .56168 .26534 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.56168 .26534 m .53058 .26137 L .5343 .26293 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.43832 .73466 m .46942 .73863 L .4657 .73707 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.4657 .73707 m .43126 .73159 L .43832 .73466 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.43126 .26841 m .4657 .26293 L .46942 .26137 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.4657 .26293 m .43126 .26841 L .42744 .27169 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.60735 .71539 m .57256 .72831 L .56874 .73159 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.57256 .27169 m .60735 .28461 L .60241 .28 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.60241 .28 m .56874 .26841 L .57256 .27169 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.39759 .72 m .43126 .73159 L .42744 .72831 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.42744 .72831 m .39265 .71539 L .39759 .72 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.39265 .28461 m .42744 .27169 L .43126 .26841 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.53058 .73863 m .56168 .73466 L .56874 .73159 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.56168 .73466 m .53058 .73863 L .52543 .73998 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.53058 .26137 m .56168 .26534 L .55161 .26264 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.55161 .26264 m .52543 .26002 L .53058 .26137 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.44839 .73736 m .47457 .73998 L .46942 .73863 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.46942 .73863 m .43832 .73466 L .44839 .73736 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.43832 .26534 m .46942 .26137 L .47457 .26002 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.46942 .26137 m .43832 .26534 L .43126 .26841 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.63989 .69684 m .60735 .71539 L .60241 .72 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56874 .73159 m .60241 .72 L .60735 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.36568 .70237 m .39759 .72 L .39265 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.39265 .71539 m .36011 .69684 L .36568 .70237 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.60735 .28461 m .63989 .30316 L .63432 .29763 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.63432 .29763 m .60241 .28 L .60735 .28461 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.43126 .26841 m .39759 .28 L .39265 .28461 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.36011 .30316 m .39265 .28461 L .39759 .28 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27493 .59244 m
.27665 .59601 L
s
.27665 .59601 m
.28503 .61334 L
s
.5 Mabswid
.091 .106 .08 r
.52543 .73998 m .55161 .73736 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.55161 .73736 m .52543 .73998 L .51909 .74106 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.52543 .26002 m .55161 .26264 L .53892 .26046 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.53892 .26046 m .51909 .25894 L .52543 .26002 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.46108 .73954 m .48091 .74106 L .47457 .73998 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.47457 .73998 m .44839 .73736 L .46108 .73954 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.44839 .26264 m .47457 .26002 L .48091 .25894 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.47457 .26002 m .44839 .26264 L .43832 .26534 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.66927 .67305 m .63989 .69684 L .63432 .70237 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.60241 .72 m .63432 .70237 L .63989 .69684 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.63989 .30316 m .66927 .32695 L .66349 .32103 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.66349 .32103 m .63432 .29763 L .63989 .30316 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.33651 .67897 m .36568 .70237 L .36011 .69684 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.36011 .69684 m .33073 .67305 L .33651 .67897 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.39759 .28 m .36568 .29763 L .36011 .30316 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.33073 .32695 m .36011 .30316 L .36568 .29763 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.60241 .72 m .56874 .73159 L .56168 .73466 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.56874 .26841 m .60241 .28 L .59249 .27562 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.59249 .27562 m .56168 .26534 L .56874 .26841 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.40751 .72438 m .43832 .73466 L .43126 .73159 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.43126 .73159 m .39759 .72 L .40751 .72438 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.39759 .28 m .43126 .26841 L .43832 .26534 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.47579 .74108 m .48816 .74182 L .48091 .74106 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.48091 .74106 m .46108 .73954 L .47579 .74108 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.51909 .74106 m .53892 .73954 L .55161 .73736 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.53892 .73954 m .51909 .74106 L .51184 .74182 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.48091 .25894 m .46108 .26046 L .44839 .26264 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.46108 .26046 m .48091 .25894 L .48816 .25818 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.51909 .25894 m .53892 .26046 L .52421 .25892 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.52421 .25892 m .51184 .25818 L .51909 .25894 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.66927 .32695 m .69463 .35543 L .68896 .34972 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.68896 .34972 m .66349 .32103 L .66927 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63432 .70237 m .66349 .67897 L .66927 .67305 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.69463 .64457 m .66927 .67305 L .66349 .67897 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.36568 .29763 m .33651 .32103 L .33073 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.30537 .35543 m .33073 .32695 L .33651 .32103 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.31104 .65028 m .33651 .67897 L .33073 .67305 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.33073 .67305 m .30537 .64457 L .31104 .65028 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.51184 .74182 m .52421 .74108 L .53892 .73954 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.52421 .74108 m .51184 .74182 L .50401 .7422 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.49179 .74187 m .49599 .7422 L .48816 .74182 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.48816 .74182 m .47579 .74108 L .49179 .74187 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.51184 .25818 m .52421 .25892 L .50821 .25813 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.50821 .25813 m .50401 .2578 L .51184 .25818 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.48816 .25818 m .47579 .25892 L .46108 .26046 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.47579 .25892 m .48816 .25818 L .49599 .2578 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.50821 .74187 m .50401 .7422 L .49599 .7422 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.49599 .7422 m .49179 .74187 L .50821 .74187 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.50401 .7422 m .50821 .74187 L .52421 .74108 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49179 .25813 m .49599 .2578 L .50401 .2578 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.49599 .2578 m .49179 .25813 L .47579 .25892 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50401 .2578 m .50821 .25813 L .49179 .25813 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.69463 .35543 m .71523 .38789 L .70983 .38297 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.70983 .38297 m .68896 .34972 L .69463 .35543 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.71523 .61211 m .69463 .64457 L .68896 .65028 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.66349 .67897 m .68896 .65028 L .69463 .64457 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33651 .32103 m .31104 .34972 L .30537 .35543 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.28477 .38789 m .30537 .35543 L .31104 .34972 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.29017 .61703 m .31104 .65028 L .30537 .64457 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.30537 .64457 m .28477 .61211 L .29017 .61703 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.56168 .73466 m .59249 .72438 L .60241 .72 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.59249 .72438 m .56168 .73466 L .55161 .73736 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.56168 .26534 m .59249 .27562 L .57783 .27173 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.57783 .27173 m .55161 .26264 L .56168 .26534 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.42217 .72827 m .44839 .73736 L .43832 .73466 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.43832 .73466 m .40751 .72438 L .42217 .72827 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.43832 .26534 m .40751 .27562 L .39759 .28 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.40751 .27562 m .43832 .26534 L .44839 .26264 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.63432 .70237 m .60241 .72 L .59249 .72438 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.60241 .28 m .63432 .29763 L .62207 .29232 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.62207 .29232 m .59249 .27562 L .60241 .28 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.37793 .70768 m .40751 .72438 L .39759 .72 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.39759 .72 m .36568 .70237 L .37793 .70768 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.36568 .29763 m .39759 .28 L .40751 .27562 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.71523 .38789 m .73041 .42346 L .72534 .41986 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.72534 .41986 m .70983 .38297 L .71523 .38789 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.73041 .57654 m .71523 .61211 L .70983 .61703 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.68896 .65028 m .70983 .61703 L .71523 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.27466 .58014 m .29017 .61703 L .28477 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.28477 .61211 m .26959 .57654 L .27466 .58014 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26682 .57566 m
.27493 .59244 L
s
.5 Mabswid
.066 .086 .069 r
.31104 .34972 m .29017 .38297 L .28477 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.26959 .42346 m .28477 .38789 L .29017 .38297 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73041 .42346 m .73972 .46118 L .73489 .45928 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73489 .45928 m .72534 .41986 L .73041 .42346 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.73972 .53882 m .73041 .57654 L .72534 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.70983 .61703 m .72534 .58014 L .73041 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26511 .54072 m .27466 .58014 L .26959 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26959 .57654 m .26028 .53882 L .26511 .54072 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.29017 .38297 m .27466 .41986 L .26959 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.26028 .46118 m .26959 .42346 L .27466 .41986 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73972 .46118 m .74286 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73811 .5 m .73489 .45928 L .73972 .46118 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.74286 .5 m .73972 .53882 L .73489 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.72534 .58014 m .73489 .54072 L .73972 .53882 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.27466 .41986 m .26511 .45928 L .26028 .46118 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.25714 .5 m .26028 .46118 L .26511 .45928 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26189 .5 m .26511 .54072 L .26028 .53882 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26028 .53882 m .25714 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.73489 .54072 m .73811 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.26511 .45928 m .26189 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26684 .57641 m
.27555 .59805 L
s
.27555 .59805 m
.27821 .60466 L
s
.27316 .59335 m
.27576 .59938 L
s
.5 Mabswid
.316 .475 .357 r
.55161 .73736 m .57783 .72827 L .59249 .72438 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.57783 .72827 m .55161 .73736 L .53892 .73954 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55161 .26264 m .57783 .27173 L .55897 .26855 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55897 .26855 m .53892 .26046 L .55161 .26264 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44103 .73145 m .46108 .73954 L .44839 .73736 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44839 .73736 m .42217 .72827 L .44103 .73145 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.42217 .27173 m .44839 .26264 L .46108 .26046 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.44839 .26264 m .42217 .27173 L .40751 .27562 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27576 .59938 m
.27774 .60358 L
s
.5 Mabswid
.337 .488 .349 r
.66349 .67897 m .63432 .70237 L .62207 .70768 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.59249 .72438 m .62207 .70768 L .63432 .70237 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.63432 .29763 m .66349 .32103 L .64944 .31528 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.64944 .31528 m .62207 .29232 L .63432 .29763 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.35056 .68472 m .37793 .70768 L .36568 .70237 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.36568 .70237 m .33651 .67897 L .35056 .68472 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.40751 .27562 m .37793 .29232 L .36568 .29763 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.33651 .32103 m .36568 .29763 L .37793 .29232 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27774 .60358 m
.27901 .60589 L
s
.5 Mabswid
.398 .573 .422 r
.62207 .70768 m .59249 .72438 L .57783 .72827 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.59249 .27562 m .62207 .29232 L .60329 .28753 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.60329 .28753 m .57783 .27173 L .59249 .27562 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.39671 .71247 m .42217 .72827 L .40751 .72438 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.40751 .72438 m .37793 .70768 L .39671 .71247 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.37793 .29232 m .40751 .27562 L .42217 .27173 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.4632 .7337 m .47579 .74108 L .46108 .73954 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.46108 .73954 m .44103 .73145 L .4632 .7337 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.46108 .26046 m .44103 .26855 L .42217 .27173 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.53892 .73954 m .55897 .73145 L .57783 .72827 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.55897 .73145 m .53892 .73954 L .52421 .74108 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.44103 .26855 m .46108 .26046 L .47579 .25892 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.53892 .26046 m .55897 .26855 L .5368 .2663 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.5368 .2663 m .52421 .25892 L .53892 .26046 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27901 .60589 m
.27985 .60663 L
s
.5 Mabswid
.363 .512 .359 r
.68896 .65028 m .66349 .67897 L .64944 .68472 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.62207 .70768 m .64944 .68472 L .66349 .67897 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.66349 .32103 m .68896 .34972 L .67359 .34411 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.67359 .34411 m .64944 .31528 L .66349 .32103 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.32641 .65589 m .35056 .68472 L .33651 .67897 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.33651 .67897 m .31104 .65028 L .32641 .65589 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.37793 .29232 m .35056 .31528 L .33651 .32103 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.31104 .34972 m .33651 .32103 L .35056 .31528 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.52421 .74108 m .5368 .7337 L .55897 .73145 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.5368 .7337 m .52421 .74108 L .50821 .74187 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.48749 .73487 m .49179 .74187 L .47579 .74108 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.47579 .74108 m .4632 .7337 L .48749 .73487 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.52421 .25892 m .5368 .2663 L .51251 .26513 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.51251 .26513 m .50821 .25813 L .52421 .25892 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.4632 .2663 m .47579 .25892 L .49179 .25813 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.47579 .25892 m .4632 .2663 L .44103 .26855 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.50821 .74187 m .51251 .73487 L .5368 .7337 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.51251 .73487 m .50821 .74187 L .49179 .74187 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.49179 .74187 m .48749 .73487 L .51251 .73487 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.48749 .26513 m .49179 .25813 L .50821 .25813 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.49179 .25813 m .48749 .26513 L .4632 .2663 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.50821 .25813 m .51251 .26513 L .48749 .26513 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.68896 .34972 m .70983 .38297 L .69356 .3781 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.69356 .3781 m .67359 .34411 L .68896 .34972 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.70983 .61703 m .68896 .65028 L .67359 .65589 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.64944 .68472 m .67359 .65589 L .68896 .65028 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.35056 .31528 m .32641 .34411 L .31104 .34972 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.29017 .38297 m .31104 .34972 L .32641 .34411 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.30644 .6219 m .32641 .65589 L .31104 .65028 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.31104 .65028 m .29017 .61703 L .30644 .6219 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.57783 .72827 m .60329 .71247 L .62207 .70768 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.60329 .71247 m .57783 .72827 L .55897 .73145 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57783 .27173 m .60329 .28753 L .57862 .28359 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57862 .28359 m .55897 .26855 L .57783 .27173 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42138 .71641 m .44103 .73145 L .42217 .72827 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42217 .72827 m .39671 .71247 L .42138 .71641 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.39671 .28753 m .42217 .27173 L .44103 .26855 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.42217 .27173 m .39671 .28753 L .37793 .29232 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.64944 .68472 m .62207 .70768 L .60329 .71247 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.62207 .29232 m .64944 .31528 L .6271 .31005 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.6271 .31005 m .60329 .28753 L .62207 .29232 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.3729 .68995 m .39671 .71247 L .37793 .70768 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.37793 .70768 m .35056 .68472 L .3729 .68995 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.35056 .31528 m .37793 .29232 L .39671 .28753 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27506 .59216 m
.27672 .59629 L
s
.27672 .59629 m
.27975 .60247 L
s
.5 Mabswid
.368 .497 .336 r
.72534 .58014 m .70983 .61703 L .69356 .6219 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.67359 .65589 m .69356 .6219 L .70983 .61703 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.70983 .38297 m .72534 .41986 L .7085 .41626 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.7085 .41626 m .69356 .3781 L .70983 .38297 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.2915 .58374 m .30644 .6219 L .29017 .61703 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.29017 .61703 m .27466 .58014 L .2915 .58374 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27975 .60247 m
.28254 .60676 L
s
.27312 .5859 m
.27506 .59216 L
s
.5 Mabswid
.188 .21 .176 r
.32641 .34411 m .30644 .3781 L .29017 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.27466 .41986 m .29017 .38297 L .30644 .3781 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27263 .58178 m
.27312 .5859 L
s
.28254 .60676 m
.28461 .60912 L
s
.5 Mabswid
.351 .464 .307 r
.73489 .54072 m .72534 .58014 L .7085 .58374 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.69356 .6219 m .7085 .58374 L .72534 .58014 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.72534 .41986 m .73489 .45928 L .71775 .45737 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.71775 .45737 m .7085 .41626 L .72534 .41986 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.28225 .54263 m .2915 .58374 L .27466 .58014 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.27466 .58014 m .26511 .54072 L .28225 .54263 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.30644 .3781 m .2915 .41626 L .27466 .41986 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.26511 .45928 m .27466 .41986 L .2915 .41626 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27263 .58178 m
.27307 .57984 L
s
.28461 .60912 m
.28665 .60986 L
s
.5 Mabswid
.16 .17 .129 r
.44103 .26855 m .42138 .28359 L .39671 .28753 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.45078 .71923 m .4632 .7337 L .44103 .73145 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.44103 .73145 m .42138 .71641 L .45078 .71923 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.42138 .28359 m .44103 .26855 L .4632 .2663 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.55897 .73145 m .57862 .71641 L .60329 .71247 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.57862 .71641 m .55897 .73145 L .5368 .7337 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.55897 .26855 m .57862 .28359 L .54922 .28077 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.54922 .28077 m .5368 .2663 L .55897 .26855 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.73489 .45928 m .73811 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.72088 .5 m .71775 .45737 L .73489 .45928 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.73811 .5 m .73489 .54072 L .71775 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.7085 .58374 m .71775 .54263 L .73489 .54072 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.2915 .41626 m .28225 .45737 L .26511 .45928 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.26189 .5 m .26511 .45928 L .28225 .45737 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.27912 .5 m .28225 .54263 L .26511 .54072 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.26511 .54072 m .26189 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.71775 .54263 m .72088 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.28225 .45737 m .27912 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27307 .57984 m
.27514 .58041 L
s
.5 Mabswid
.487 .668 .478 r
.67359 .65589 m .64944 .68472 L .6271 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.60329 .71247 m .6271 .68995 L .64944 .68472 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64944 .31528 m .67359 .34411 L .64832 .33895 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64832 .33895 m .6271 .31005 L .64944 .31528 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35168 .66105 m .3729 .68995 L .35056 .68472 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35056 .68472 m .32641 .65589 L .35168 .66105 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.39671 .28753 m .3729 .31005 L .35056 .31528 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.32641 .34411 m .35056 .31528 L .3729 .31005 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28665 .60986 m
.2873 .60847 L
s
.5 Mabswid
.53 .739 .551 r
.5368 .7337 m .54922 .71923 L .57862 .71641 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.54922 .71923 m .5368 .7337 L .51251 .73487 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.48324 .7207 m .48749 .73487 L .4632 .7337 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.4632 .7337 m .45078 .71923 L .48324 .7207 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.45078 .28077 m .4632 .2663 L .48749 .26513 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.4632 .2663 m .45078 .28077 L .42138 .28359 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5368 .2663 m .54922 .28077 L .51676 .2793 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.51676 .2793 m .51251 .26513 L .5368 .2663 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.6271 .68995 m .60329 .71247 L .57862 .71641 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.60329 .28753 m .6271 .31005 L .59716 .30569 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.59716 .30569 m .57862 .28359 L .60329 .28753 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.40284 .69431 m .42138 .71641 L .39671 .71247 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.39671 .71247 m .3729 .68995 L .40284 .69431 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.3729 .31005 m .39671 .28753 L .42138 .28359 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28725 .60508 m
.2873 .60847 L
s
.27514 .58041 m
.27744 .58315 L
s
.5 Mabswid
.576 .797 .602 r
.51676 .7207 m .51251 .73487 L .48749 .73487 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.48749 .73487 m .48324 .7207 L .51676 .7207 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.51251 .73487 m .51676 .7207 L .54922 .71923 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.51251 .26513 m .51676 .2793 L .48324 .2793 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.48324 .2793 m .48749 .26513 L .51251 .26513 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.48749 .26513 m .48324 .2793 L .45078 .28077 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27744 .58315 m
.28068 .58816 L
s
.5 Mabswid
.307 .358 .248 r
.67359 .34411 m .69356 .3781 L .66602 .37358 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.66602 .37358 m .64832 .33895 L .67359 .34411 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.69356 .6219 m .67359 .65589 L .64832 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.6271 .68995 m .64832 .66105 L .67359 .65589 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.3729 .31005 m .35168 .33895 L .32641 .34411 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.30644 .3781 m .32641 .34411 L .35168 .33895 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.33398 .62642 m .35168 .66105 L .32641 .65589 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.32641 .65589 m .30644 .6219 L .33398 .62642 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29479 .60587 m
.30255 .62502 L
s
.29295 .60133 m
.29479 .60587 L
s
.5 Mabswid
.213 .223 .167 r
.42138 .28359 m .40284 .30569 L .3729 .31005 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.43899 .69745 m .45078 .71923 L .42138 .71641 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.42138 .71641 m .40284 .69431 L .43899 .69745 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.57862 .71641 m .59716 .69431 L .6271 .68995 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.59716 .69431 m .57862 .71641 L .54922 .71923 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.40284 .30569 m .42138 .28359 L .45078 .28077 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.57862 .28359 m .59716 .30569 L .56101 .30255 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.56101 .30255 m .54922 .28077 L .57862 .28359 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.7085 .58374 m .69356 .6219 L .66602 .62642 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.64832 .66105 m .66602 .62642 L .69356 .6219 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.69356 .3781 m .7085 .41626 L .67935 .41291 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.67935 .41291 m .66602 .37358 L .69356 .3781 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.32065 .58709 m .33398 .62642 L .30644 .6219 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.30644 .6219 m .2915 .58374 L .32065 .58709 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29323 .60471 m
.29914 .61136 L
s
.28532 .5825 m
.29295 .60133 L
s
.5 Mabswid
.315 .371 .289 r
.35168 .33895 m .33398 .37358 L .30644 .3781 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.2915 .41626 m .30644 .3781 L .33398 .37358 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.6271 .31005 m .64832 .33895 L .61381 .33462 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.61381 .33462 m .59716 .30569 L .6271 .31005 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.64832 .66105 m .6271 .68995 L .59716 .69431 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.38619 .66538 m .40284 .69431 L .3729 .68995 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.3729 .68995 m .35168 .66105 L .38619 .66538 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.35168 .33895 m .3729 .31005 L .40284 .30569 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29914 .61136 m
.30239 .61376 L
s
.30239 .61376 m
.30627 .61447 L
s
.5 Mabswid
.588 .803 .592 r
.54922 .71923 m .56101 .69745 L .59716 .69431 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.56101 .69745 m .54922 .71923 L .51676 .7207 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.71775 .54263 m .7085 .58374 L .67935 .58709 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.66602 .62642 m .67935 .58709 L .7085 .58374 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.47919 .69909 m .48324 .7207 L .45078 .71923 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.45078 .71923 m .43899 .69745 L .47919 .69909 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.7085 .41626 m .71775 .45737 L .68764 .45559 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.68764 .45559 m .67935 .41291 L .7085 .41626 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.54922 .28077 m .56101 .30255 L .52081 .30091 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.52081 .30091 m .51676 .2793 L .54922 .28077 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.43899 .30255 m .45078 .28077 L .48324 .2793 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.45078 .28077 m .43899 .30255 L .40284 .30569 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.31236 .54441 m .32065 .58709 L .2915 .58374 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.2915 .58374 m .28225 .54263 L .31236 .54441 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.33398 .37358 m .32065 .41291 L .2915 .41626 L p F P
.505 .664 .505 r
s
.444 .557 .432 r
.28225 .45737 m .2915 .41626 L .32065 .41291 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30627 .61447 m
.30821 .61299 L
s
.5 Mabswid
.423 .536 .361 r
.71775 .45737 m .72088 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.69045 .5 m .68764 .45559 L .71775 .45737 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.72088 .5 m .71775 .54263 L .68764 .54441 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.67935 .58709 m .68764 .54441 L .71775 .54263 L p F P
.505 .664 .505 r
s
.444 .557 .432 r
.32065 .41291 m .31236 .45559 L .28225 .45737 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.27912 .5 m .28225 .45737 L .31236 .45559 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.30955 .5 m .31236 .54441 L .28225 .54263 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.28225 .54263 m .27912 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.52081 .69909 m .51676 .7207 L .48324 .7207 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.48324 .7207 m .47919 .69909 L .52081 .69909 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.51676 .7207 m .52081 .69909 L .56101 .69745 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.47919 .30091 m .48324 .2793 L .51676 .2793 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.48324 .2793 m .47919 .30091 L .43899 .30255 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.51676 .2793 m .52081 .30091 L .47919 .30091 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.68764 .54441 m .69045 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.31236 .45559 m .30955 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30725 .60718 m
.30821 .61299 L
s
.5 Mabswid
.369 .44 .3 r
.64832 .33895 m .66602 .37358 L .6278 .36977 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.6278 .36977 m .61381 .33462 L .64832 .33895 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.66602 .62642 m .64832 .66105 L .61381 .66538 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.59716 .69431 m .61381 .66538 L .64832 .66105 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.40284 .30569 m .38619 .33462 L .35168 .33895 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.33398 .37358 m .35168 .33895 L .38619 .33462 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.3722 .63023 m .38619 .66538 L .35168 .66105 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.35168 .66105 m .33398 .62642 L .3722 .63023 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29969 .58452 m
.30725 .60718 L
s
.5 Mabswid
.641 .862 .655 r
.42833 .66851 m .43899 .69745 L .40284 .69431 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.40284 .69431 m .38619 .66538 L .42833 .66851 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.61381 .66538 m .59716 .69431 L .56101 .69745 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.38619 .33462 m .40284 .30569 L .43899 .30255 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.59716 .30569 m .61381 .33462 L .57167 .33149 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.57167 .33149 m .56101 .30255 L .59716 .30569 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32673 .62953 m
.32914 .63147 L
s
.32673 .62953 m
.32759 .62804 L
s
.32914 .63147 m
.33004 .63 L
s
.32759 .62804 m
.33004 .63 L
s
.31278 .58591 m
.32052 .60948 L
s
.5 Mabswid
.572 .753 .538 r
.67935 .58709 m .66602 .62642 L .6278 .63023 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.61381 .66538 m .6278 .63023 L .66602 .62642 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.66602 .37358 m .67935 .41291 L .63839 .41007 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.63839 .41007 m .6278 .36977 L .66602 .37358 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.38619 .33462 m .3722 .36977 L .33398 .37358 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.32065 .41291 m .33398 .37358 L .3722 .36977 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.36161 .58993 m .3722 .63023 L .33398 .62642 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.33398 .62642 m .32065 .58709 L .36161 .58993 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32052 .60948 m
.32298 .61696 L
s
.5 Mabswid
.614 .826 .604 r
.56101 .69745 m .57167 .66851 L .61381 .66538 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.57167 .66851 m .56101 .69745 L .52081 .69909 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.47552 .67016 m .47919 .69909 L .43899 .69745 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.43899 .69745 m .42833 .66851 L .47552 .67016 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.56101 .30255 m .57167 .33149 L .52448 .32984 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.52448 .32984 m .52081 .30091 L .56101 .30255 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.42833 .33149 m .43899 .30255 L .47919 .30091 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.43899 .30255 m .42833 .33149 L .38619 .33462 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.3722 .36977 m .38619 .33462 L .42833 .33149 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.41933 .63301 m .42833 .66851 L .38619 .66538 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.38619 .66538 m .3722 .63023 L .41933 .63301 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.61381 .33462 m .6278 .36977 L .58067 .36699 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.58067 .36699 m .57167 .33149 L .61381 .33462 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.6278 .63023 m .61381 .66538 L .57167 .66851 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.52081 .69909 m .52448 .67016 L .57167 .66851 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.52448 .67016 m .52081 .69909 L .47919 .69909 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.47919 .69909 m .47552 .67016 L .52448 .67016 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.52081 .30091 m .52448 .32984 L .47552 .32984 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.47552 .32984 m .47919 .30091 L .52081 .30091 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.47919 .30091 m .47552 .32984 L .42833 .33149 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.68764 .54441 m .67935 .58709 L .63839 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.6278 .63023 m .63839 .58993 L .67935 .58709 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.67935 .41291 m .68764 .45559 L .64501 .45407 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.64501 .45407 m .63839 .41007 L .67935 .41291 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.35499 .54593 m .36161 .58993 L .32065 .58709 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.32065 .58709 m .31236 .54441 L .35499 .54593 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.3722 .36977 m .36161 .41007 L .32065 .41291 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.31236 .45559 m .32065 .41291 L .36161 .41007 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32803 .58723 m
.33595 .61342 L
s
.33595 .61342 m
.33753 .61866 L
s
.33471 .61048 m
.34281 .61726 L
s
.5 Mabswid
.504 .64 .446 r
.68764 .45559 m .69045 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.64726 .5 m .64501 .45407 L .68764 .45559 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.69045 .5 m .68764 .54441 L .64501 .54593 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.63839 .58993 m .64501 .54593 L .68764 .54441 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.36161 .41007 m .35499 .45407 L .31236 .45559 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.30955 .5 m .31236 .45559 L .35499 .45407 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.35274 .5 m .35499 .54593 L .31236 .54441 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.31236 .54441 m .30955 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34281 .61726 m
.34761 .61965 L
s
.5 Mabswid
.534 .688 .483 r
.64501 .54593 m .64726 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.35499 .45407 m .35274 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34761 .61965 m
.35401 .62021 L
s
.35401 .62021 m
.35779 .61857 L
s
.5 Mabswid
.462 .564 .41 r
.41933 .36699 m .42833 .33149 L .47552 .32984 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.47241 .63448 m .47552 .67016 L .42833 .66851 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.42833 .66851 m .41933 .63301 L .47241 .63448 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.42833 .33149 m .41933 .36699 L .3722 .36977 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.57167 .66851 m .58067 .63301 L .6278 .63023 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.57167 .33149 m .58067 .36699 L .52759 .36552 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.52759 .36552 m .52448 .32984 L .57167 .33149 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.58067 .63301 m .57167 .66851 L .52448 .67016 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.36161 .41007 m .3722 .36977 L .41933 .36699 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.41249 .59201 m .41933 .63301 L .3722 .63023 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.3722 .63023 m .36161 .58993 L .41249 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.63839 .58993 m .6278 .63023 L .58067 .63301 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.6278 .36977 m .63839 .41007 L .58751 .40799 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.58751 .40799 m .58067 .36699 L .6278 .36977 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35779 .61857 m
.3582 .61248 L
s
.3582 .61248 m
.36697 .61926 L
s
.35236 .58887 m
.3582 .61248 L
s
.36697 .61926 m
.37229 .62162 L
s
.37229 .62162 m
.37957 .62209 L
s
.5 Mabswid
.645 .854 .627 r
.52448 .67016 m .52759 .63448 L .58067 .63301 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.52448 .32984 m .52759 .36552 L .47241 .36552 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.47241 .36552 m .47552 .32984 L .52448 .32984 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.52759 .63448 m .52448 .67016 L .47552 .67016 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.47552 .67016 m .47241 .63448 L .52759 .63448 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.47552 .32984 m .47241 .36552 L .41933 .36699 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37957 .62209 m
.38402 .62037 L
s
.5 Mabswid
.5 .621 .46 r
.41933 .36699 m .41249 .40799 L .36161 .41007 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.35499 .45407 m .36161 .41007 L .41249 .40799 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.4082 .54705 m .41249 .59201 L .36161 .58993 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.36161 .58993 m .35499 .54593 L .4082 .54705 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.63839 .41007 m .64501 .45407 L .5918 .45295 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.5918 .45295 m .58751 .40799 L .63839 .41007 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.64501 .54593 m .63839 .58993 L .58751 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.58067 .63301 m .58751 .59201 L .63839 .58993 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61373 .63548 m
.62111 .60722 L
s
.38402 .62037 m
.38504 .61417 L
s
.38023 .59026 m
.38504 .61417 L
s
.5 Mabswid
.637 .835 .61 r
.58751 .59201 m .58067 .63301 L .52759 .63448 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.47004 .59312 m .47241 .63448 L .41933 .63301 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.41933 .63301 m .41249 .59201 L .47004 .59312 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.58067 .36699 m .58751 .40799 L .52996 .40688 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.52996 .40688 m .52759 .36552 L .58067 .36699 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.41249 .40799 m .41933 .36699 L .47241 .36552 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.41249 .40799 m .4082 .45295 L .35499 .45407 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.35274 .5 m .35499 .45407 L .4082 .45295 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.40674 .5 m .4082 .54705 L .35499 .54593 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.35499 .54593 m .35274 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.64501 .45407 m .64726 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.59326 .5 m .5918 .45295 L .64501 .45407 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.64726 .5 m .64501 .54593 L .5918 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.58751 .59201 m .5918 .54705 L .64501 .54593 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6236 .59519 m
.62669 .59252 L
s
.62456 .59005 m
.62669 .59252 L
s
.62144 .59276 m
.6236 .59519 L
s
.58598 .62387 m
.59455 .62147 L
s
.59455 .62147 m
.59811 .61714 L
s
.62144 .59276 m
.62456 .59005 L
s
.5 Mabswid
.579 .739 .552 r
.4082 .45295 m .40674 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.5918 .54705 m .59326 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.57767 .62419 m
.58598 .62387 L
s
.40279 .61061 m
.40678 .61735 L
s
.40678 .61735 m
.41308 .6218 L
s
.41308 .6218 m
.41899 .62407 L
s
.41899 .62407 m
.42739 .62437 L
s
.40196 .60598 m
.40279 .61061 L
s
.40279 .61061 m
.43713 .61174 L
s
.40196 .60598 m
.40356 .5988 L
s
.42739 .62437 m
.43276 .62249 L
s
.59749 .606 m
.60109 .60109 L
s
.5915 .60856 m
.59749 .606 L
s
.5 Mabswid
.648 .85 .627 r
.52996 .59312 m .52759 .63448 L .47241 .63448 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.47241 .63448 m .47004 .59312 L .52996 .59312 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.52759 .63448 m .52996 .59312 L .58751 .59201 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.56953 .62242 m
.57767 .62419 L
s
.5 Mabswid
.516 .642 .463 r
.52759 .36552 m .52996 .40688 L .47004 .40688 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.47004 .40688 m .47241 .36552 L .52759 .36552 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.47241 .36552 m .47004 .40688 L .41249 .40799 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60109 .60109 m
.6015 .59862 L
s
.5769 .61135 m
.5915 .60856 L
s
.59949 .59364 m
.6015 .59862 L
s
.56727 .61827 m
.56953 .62242 L
s
.43276 .62249 m
.43534 .62048 L
s
.40356 .5988 m
.40853 .5939 L
s
.43534 .62048 m
.43768 .61624 L
s
.56727 .61827 m
.57078 .61379 L
s
.57078 .61379 m
.5769 .61135 L
s
.5 Mabswid
.543 .684 .49 r
.58751 .40799 m .5918 .45295 L .53144 .45236 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.53144 .45236 m .52996 .40688 L .58751 .40799 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.5918 .54705 m .58751 .59201 L .52996 .59312 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59124 .5913 m
.59949 .59364 L
s
.5 Mabswid
.557 .703 .516 r
.4082 .45295 m .41249 .40799 L .47004 .40688 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.46856 .54764 m .47004 .59312 L .41249 .59201 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.41249 .59201 m .4082 .54705 L .46856 .54764 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43713 .61174 m
.43768 .61624 L
s
.40853 .5939 m
.41402 .59145 L
s
.52827 .62539 m
.5372 .62526 L
s
.5372 .62526 m
.54331 .62308 L
s
.54331 .62308 m
.54648 .62092 L
s
.54648 .62092 m
.54989 .61652 L
s
.58244 .59155 m
.59124 .5913 L
s
.46502 .62323 m
.47114 .62538 L
s
.47114 .62538 m
.48012 .62548 L
s
.52238 .62338 m
.52827 .62539 L
s
.45869 .61887 m
.46502 .62323 L
s
.48012 .62548 m
.48607 .62345 L
s
.54989 .61652 m
.55033 .61202 L
s
.4551 .61212 m
.45869 .61887 L
s
.5165 .61917 m
.52238 .62338 L
s
.41402 .59145 m
.42292 .59169 L
s
.48607 .62345 m
.49205 .61921 L
s
.57319 .59441 m
.58244 .59155 L
s
.51363 .61248 m
.55033 .61202 L
s
.56962 .59961 m
.57319 .59441 L
s
.45471 .60744 m
.4551 .61212 L
s
.51363 .61248 m
.5165 .61917 L
s
.42292 .59169 m
.42922 .59447 L
s
.42922 .59447 m
.43579 .59973 L
s
.45471 .60744 m
.45724 .60013 L
s
.51363 .61248 m
.51375 .60779 L
s
.54561 .59495 m
.55141 .59999 L
s
.5 Mabswid
.576 .733 .528 r
.5918 .45295 m .59326 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.53195 .5 m .53144 .45236 L .5918 .45295 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.59326 .5 m .5918 .54705 L .53144 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.52996 .59312 m .53144 .54764 L .5918 .54705 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.47004 .40688 m .46856 .45236 L .4082 .45295 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.40674 .5 m .4082 .45295 L .46856 .45236 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.46805 .5 m .46856 .54764 L .4082 .54705 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.4082 .54705 m .40674 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45724 .60013 m
.46316 .59506 L
s
.51375 .60779 m
.51708 .60039 L
s
.5 Mabswid
.634 .823 .605 r
.53144 .54764 m .52996 .59312 L .47004 .59312 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49205 .61651 m
.49241 .63898 L
s
.5 Mabswid
.634 .823 .605 r
.47004 .59312 m .46856 .54764 L .53144 .54764 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49167 .59261 m
.49205 .61651 L
s
.5 Mabswid
.556 .701 .509 r
.46856 .45236 m .47004 .40688 L .52996 .40688 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.52996 .40688 m .53144 .45236 L .46856 .45236 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.5395 .59238 m
.54561 .59495 L
s
.5 Mabswid
.602 .774 .561 r
.53144 .54764 m .53195 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.46856 .45236 m .46805 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.46316 .59506 m
.46935 .59248 L
s
.51708 .60039 m
.52357 .59519 L
s
.48533 .59524 m
.49177 .60043 L
s
.53002 .59248 m
.5395 .59238 L
s
.52357 .59519 m
.53002 .59248 L
s
.46935 .59248 m
.47889 .59255 L
s
.47889 .59255 m
.48533 .59524 L
s
.5 Mabswid
.588 .75 .547 r
.53144 .45236 m .53195 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.46805 .5 m .46856 .45236 L .53144 .45236 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.53195 .5 m .53144 .54764 L .46856 .54764 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.46856 .54764 m .46805 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?40/>3V4@21ZH7a0;3PiP40oooo003U0;3PiPd0PJV10P0S9Qd0
0`21ZH409BPN02DX7P0602DX7P04086YP@0T9ah092LN02@W7Pd0PJV1i@2`h>H10?ooo`00h@2`h>H2
086YP@0301TM5P21ZH40PJV100D07b8J0P21ZH4702<V7@03086YP@0U:1h09BPN00L09BPN00<0PJV1
02@W7P0T9ah01@0T9ah2086YP@D08B@K1@21ZH7Q0;3PiP40oooo003M0;3PiP<0PJV10P0I7AH2086Y
P@D07b8J0P21ZH4802<V7@03086YP@0U:1h09BPN00P09BPN00<0PJV102@W7P0T9ah01`0T9ah2086Y
P@D08B@K0P21ZH400`0L7aP0PJV1086YP@02086YPMd0/>3V0@3oool00=T0/>3V0`21ZH4401TM5P80
PJV10`0O8QXY086YP@<08B@K0P21ZH4201`O60D0PJV1f@2`h>H10?ooo`00eP2`h>H3086YP@D06AdF
1`21ZH400`0`<RH0PJV103Df:@0;03Df:@03086YP@0g>2/0=cP[00T0=cP[00<0PJV103Hh:P0f>2X0
2P0f>2X00`21ZH40<c@X086YP@06086YP@<071lH1@21ZH7F0;3PiP40oooo003C0;3PiP<0PJV10P0I
7AH7086YP@H0<38V00<0PJV103Df:@0e=RT02P0e=RT00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103<d:00c=2P0100c=2P7086YP@0301`O6021ZH40PJV10080PJV1d`2`
h>H10?ooo`00d02`h>H8086YP@80:2/Q0P21ZH48030b9P03086YP@0e=RT0=CHY00/0=CHY00<0PJV1
03Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0c=2P0<c@X00H0<c@X0P21ZH42
02d_8`P0PJV1d02`h>H10?ooo`00c@2`h>H5086YP@L0:2/Q00<0PJV1030b9P0`<RH01`0`<RH00`21
ZH40=CHY03Df:@0<03Df:@03086YP@0g>2/0=cP[00/0=cP[00<0PJV103Hh:P0f>2X02`0f>2X00`21
ZH40<c@X03<d:00803<d:003086YP@0];b<0;BlS00D0;BlS1@21ZH7=0;3PiP40oooo003:0;3PiP<0
PJV100<07R4I086YP@21ZH40200X:b400`21ZH40<38V030b9P08030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X00<0PJV102d_8`0];b<01P0];b<2086YP@0402<V7021ZH40PJV1086YPLX0/>3V0@3oool00<P0
/>3V0`21ZH4201hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH4:030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X0P21ZH4802d_8`03086YP@0S9Q`08bHL00<0PJV1b02`h>H10?ooo`00aP2`h>H3086YP@807R4I
0P21ZH4802P[8@03086YP@0`<RH0<38V00T0<38V00<0PJV103Df:@0e=RT01@0e=RTQ086YP@L0=SPZ
00<0PJV103<d:00c=2P02@0c=2P00`21ZH40;BlS02d_8`0602d_8`80PJV10P0S9Q`3086YPLH0/>3V
0@3oool00<@0/>3V0`21ZH4301hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH45030b9Pl0PJV1201;
E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>Ech0CULn00H0CULn3`21ZH4503<d:080PJV1200]
;b<01021ZH408bHL02<V700S9Q`3086YPL@0/>3V0@3oool00<80/>3V0`21ZH4301hQ6@80PJV11@0X
:b4;086YP@D0@dXe00<0PJV104]D?01;E3`03`1;E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>
Ech0CULn00h0CULn00<0PJV104Q@>@18D3T01018D3T;086YP@D0;BlS0P21ZH4302<V70<0PJV1`P2`
h>H10?ooo`00`02`h>H3086YP@<07R4I0P21ZH400`0X:b40PJV1086YP@04086YP@80=STZ00<0PJV1
04=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00>04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV1
04iG?P1>Ech03P1>Ech00`21ZH40B50i04Q@>@0;04Q@>@03086YP@0m@S00?D8`00H0PJV100<0;BlS
086YP@21ZH400`0S9Q`3086YPL00/>3V0@3oool00;l0/>3V0P21ZH4201hQ6@H0PJV11`0f>BX00`21
ZH40@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21
ZH40CULn04iG?P0>04iG?P03086YP@18D3T0B50i00`0B50i00<0PJV103e2<00m@S001@0m@S06086Y
P@808bHL0P21ZH6o0;3PiP40oooo002m0;3PiPH0PJV100<0:B/Q086YP@0f>BX02P0f>BX00`21ZH40
@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21ZH40
CULn04iG?P0?04iG?P03086YP@18D3T0B50i00/0B50i00<0PJV103e2<00m@S002@0m@S000`21ZH40
;c4U086YP@05086YPKd0/>3V0@3oool00;/0/>3V1021ZH4402T[8@03086YP@0f>BX0=STZ00T0=STZ
00<0PJV104=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn00l0CUTn
00<0PJV104iG?P1>Ech03`1>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m@S00?D8`00T0?D8`
00<0PJV102la9@0_<BD00P0_<BD4086YPK/0/>3V0@3oool00;T0/>3V0`21ZH4602T[8@03086YP@0f
>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>
FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m
@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD3086YPKT0/>3V0@3oool00;L0/>3V1021ZH46
02T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00A
04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0=
04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086YPKL0/>3V0@3oool0
0;H0/>3V1021ZH4602T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03@13BSD00`21
ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn0140CUTn00<0PJV104iG?P1>Ech0401>Ech00`21
ZH40B50i04Q@>@0=04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086Y
PKH0/>3V0@3oool00;D0/>3V00<0PJV101TM5P21ZH401`0Y:b400`21ZH40=STZ03Hi:P0903Hi:P03
086YP@13BSD0@dXe00d0@dXe00<0PJV104]D?01;E3`04@1;E3`00`21ZH40CUTn04iI?P0A04iI?P03
086YP@1>Ech0CULn0100CULn00<0PJV104Q@>@18D3T03P18D3T00`21ZH40?D8`03e2<00903e2<003
086YP@0_<BD0;c4U00D0;c4U00<0PJV1020S6`21ZH40]@2`h>H10?ooo`00/`2`h>H2086YP@0301TM
5P21ZH40:B/Q00H0:B/Q00<0PJV103Hi:P0f>BX02P0f>BX00`21ZH40@dXe04=:=@0904=:=DD0PJV1
2`18D3T00`21ZH40?D8`03e2<00:03e2<003086YP@0_<BD0;c4U00D0;c4U00@0PJV1020S6`21ZH40
PJV1/`2`h>H10?ooo`00/P2`h>H01021ZH406AdF01TM5P21ZH4702T[8@03086YP@0f>BX0=STZ00X0
=STZ00@0PJV104=:=@13BSD0@dXe2@21ZH4405e]D003086YP@1SMU@0HgID0140HgID00<0PJV106Ag
E01TMe@04@1TMe@00`21ZH40H75>061aCP0A061aCP03086YP@1JJDP0FVU80080FVU82@21ZH4304Q@
>@03086YP@0m@S00?D8`00X0?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S6`21ZH6b
0;3PiP40oooo002a0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0PJV103Hi:P0f>BX01`0f>BX8
086YP@`0GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0
H75>0180H75>00<0PJV105YYB01JJDP02P1JJDP8086YP@T0?D8`00<0PJV102la9@0_<BD01@0_<BD0
1021ZH4082<K020S6`21ZH6a0;3PiP40oooo002`0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0
PJV103Hi:P0f>BX02021ZH42051LA@03086YP@1MKE00GFe@00l0GFe@00<0PJV106=fE01SMU@04P1S
MU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP03`1J
JDP00`21ZH40D5a0051L@008086YP@80?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S
6`21ZH6`0;3PiP40oooo002^0;3PiP80PJV100<06AdF086YP@21ZH401P0Y:b45086YP@X0D5a500<0
PJV105e]D01MKE003P1MKE000`21ZH40HgID06=fE00B06=fE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1061aCP1PLDh04P1PLDh00`21ZH40FVU805YYB00>05YYB003086YP@1@G400D5a000P0D5a01@21
ZH4602la9@80PJV100<082<K086YP@21ZH40[P2`h>H10?ooo`00[@2`h>H01021ZH406AdF01TM5P21
ZH4402T[8@D0PJV13@1@G4D00`21ZH40GFe@05e]D00?05e]D003086YP@1SMU@0HgID0180HgID00<0
PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0B061aCP03086YP@1JJDP0FVU800l0FVU800<0
PJV1051L@01@G4002`1@G405086YP@@0;c4U00@0PJV1020S6`0P8a/0PJV1[@2`h>H10?ooo`00[02`
h>H01@21ZH406AdF01TM5P21ZH40:B/Q00@0PJV1100i?c400`21ZH40D5a5051LA@0:051LA@03086Y
P@1MKE00GFe@0100GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00C06AgE003086Y
P@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP0401JJDP00`21ZH40D5a0051L@00:051L@003086Y
P@0oAS80?dHb0080?dHb1021ZH401@0_<BD0PJV1020S6`0P8a/0PJV10:`0/>3V0@3oool00:/0/>3V
00<0PJV101TM5P21ZH400`21ZH4703To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00
3`1MKE000`21ZH40HgID06=fE00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh0
4`1PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS80
1@0oAS84086YP@03020S6`21ZH40/>3V0:X0/>3V0@3oool00:T0/>3V00<0PJV101TM5P21ZH400P21
ZH4903To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00401MKE000`21ZH40HgID06=f
E00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh04`1PLDh00`21ZH40FVU805YY
B00@05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS801`0oAS85086YPJT0/>3V0@3o
ool00:P0/>3V0`21ZH400`0Q91`0PJV103To<@0803To<@03086YP@1@G4D0D5a500/0D5a500<0PJV1
05e]D01MKE00401MKE000`21ZH40HgID06=fE00D06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1
061aCP1PLDh0501PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000`0D5a000<0PJV1
03m6<P0oAS801`0oAS800`21ZH40:B/Q086YP@02086YPJP0/>3V0@3oool00:L0/>3V0P21ZH42024T
7003086YP@0i?c40>Cla00P0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00@05e]
D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0D061a
CP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6
<P03086YP@0Y:b40:B/Q0080PJV1Y`2`h>H10?ooo`00YP2`h>H00`21ZH408B@L024T7002024T7003
086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00A05e]D003
086YP@1SMU@0HgID01<0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>061aCP0C061aCP03
086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0703m6<P03
086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y@2`h>H00`21ZH408B@L
024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@
05e]D00@05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>
061aCP0D061aCP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G400301@G4000`21ZH40?dHb
03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00Y02`
h>H00`21ZH408B@L024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1T
Me@00`21ZH40H75>061aCP0D061aCP03086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G400301@
G4000`21ZH40?dHb03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0XP2`
h>H10?ooo`00Y02`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla00<0PJV1051LA@1@G4D02`1@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID00X0HgID;`21ZH4<061aCP03086YP@1J
JDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6<P05086YP@0Y
:b40:B/Q02T[8@21ZH40Y02`h>H10?ooo`00X`2`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla
00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@05e]D00705e]D1L0PJV12`1fT6P00`21ZH40MY1W
07J@I`0E07J@I`03086YP@1bRf80LX]R00T0LX]R5`21ZH4905YYB003086YP@1@G400D5a000`0D5a0
00<0PJV103m6<P0oAS80200oAS801@21ZH40:B/Q02T[8@0Y:b40PJV10:<0/>3V0@3oool00:80/>3V
00D0PJV1024T700Q91`08B@L086YP@0:03To<@03086YP@1@G4D0D5a500X0D5a53@21ZH4:0769I@03
086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03
086YP@1YOeP0JGmH00P0JGmH3@21ZH4<051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[8@0Y
:b40:B/Q086YP@2R0;3PiP40oooo002Q0;3PiP05086YP@0Q91`08B@L024T7021ZH402P0i?c400`21
ZH40D5a5051LA@05051LA@H0PJV10P1UNU`00`21ZH40LHUU0769I@0B0769I@03086YP@1fT6P0MY1X
01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03086YP@1YOeP0JGmH
0180JGmH00<0PJV105i`C01NL4`01P21ZH47051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[
8@0Y:b40:B/Q086YP@2Q0;3PiP40oooo002P0;3PiP03086YP@0Q91`08B@L00808B@L00<0PJV103To
<@0i?c40200i?c400`21ZH40D5a5086YP@05086YP@L0IGYL00<0PJV10769I@1aRFD04P1aRFD00`21
ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01D0MY1W00<0PJV107:;HP1bRf805P1bRf800`21
ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00D0GW1<1P21ZH400`1@G400PJV103m6<P0903m6
<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00W`2`h>H00`21ZH40
8B@L024T7002024T7003086YP@0i?c40>Cla00D0>Cla1P21ZH4=06EjG003086YP@1aRFD0LHUU0180
LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01D0
LX]R00<0PJV106UoF01YOeP04P1YOeP00`21ZH40GW1<05i`C00;05i`C0H0PJV11`0oAS800`21ZH40
:B/Q02T[8@0202T[8@03086YP@2`h>H0/>3V09d0/>3V0@3oool009h0/>3V00<0PJV1024T700Q91`0
0P0Q91`00`21ZH40>Cla03To<@06086YP@80D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU
0769I@0C0769I@03086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R
07:;HP0E07:;HP03086YP@1YOeP0JGmH01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o
04iK?`06086YP@80?dHb00<0PJV102T[8@0Y:b400P0Y:b400`21ZH40/>3V0;3PiP2L0;3PiP40oooo
002N0;3PiP03086YP@0Q91`08B@L00D0PJV1201@GTT00`21ZH40IGYL06EjG00=06EjG003086YP@1a
RFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1b
Rf80LX]R01D0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`C00=05i`C003086YP@1>
Fcl0CU/o00H0CU/o1@21ZH4202T[8@03086YP@2`h>H0/>3V09`0/>3V0@3oool009d0/>3V00<0PJV1
024T7021ZH400P21ZH4;051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD04P1aRFD0
0`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf80
0`21ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl3
086YP@0302T[8@21ZH40/>3V09`0/>3V0@3oool009`0/>3V0`21ZH42030e;@03086YP@1@GTT0D5i9
00T0D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU0769I@0C0769I@03086YP@1fT6P0MY1X
01H0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH
01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY
00<0PJV1W02`h>H10?ooo`00V`2`h>H2086YP@<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00@0PJV103@i:@0d>BT0=3TY0P21ZH6K0;3P
iP40oooo002J0;3PiP03086YP@0`=Bd0<3D]00<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00=06EjG003086YP@1aRFD0LHUU01@0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00<0PJV103@i:@0d>BT00`0d>BT00`21ZH40
/>3V0;3PiP2H0;3PiP40oooo002I0;3PiP80PJV1100`=Bd00`21ZH40D5i9051NB@09051NB@03086Y
P@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086Y
P@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086Y
P@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl00`21ZH40=3TY03@i:@0203@i:@80PJV1
V@2`h>H10?ooo`00V02`h>H2086YP@@0<3D]00<0PJV1051NB@1@GTT02P1@GTT00`21ZH40IGYL06Ej
G00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05`1fT6P00`21ZH40MY1W07J@
I`0G07J@I`03086YP@1bRf80LX]R01L0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`
C00>05i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i:@0d>BT00P0d>BT2086YPIP0/>3V0@3o
ool009L0/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03P1UNU`0
0`21ZH40LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L0
0`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03P1NL4`0
0`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6G0;3PiP40oooo002G0;3P
iP80PJV1100`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769
I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;
HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK
?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i:@03086YP@0I71H0/>3V09H0/>3V0@3oool009H0
/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40
LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L00`21ZH40
LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03`1NL4`00`21ZH40
CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6F0;3PiP40oooo002E0;3PiP80PJV1
1@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0
501aRFD00`21ZH40MY1X07J@J00G07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;HP1bRf80
5`1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl0
2P1>Fcl00`21ZH40=3TY03@i:@0303@i:@03086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V0P21
ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40LHUU0769
I@0D0769I@03086YP@1fT6P0MY1X00/0MY1X=@21ZH4=07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0
PJV105i`C01NL4`03`1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21
ZH6E0;3PiP40oooo002D0;3PiP80PJV11@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0
IGYL00h0IGYL00<0PJV10769I@1aRFD02P1aRFDI086YP@`0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H0
0`21ZH40P9ma082OL@0:082OLAT0PJV1301YOeP00`21ZH40GW1<05i`C00>05i`C003086YP@1>Fcl0
CU/o00X0CU/o00<0PJV103@i:@0d>BT00`0d>BT2086YPI@0/>3V0@3oool009@0/>3V0P21ZH44030e
;@03086YP@1@GTT0D5i900X0D5i900<0PJV106EjG01UNU`02`1UNU`A086YP@/0Oiie00<0PJV108BT
N024Y7P05`24Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01L0P9ma00<0PJV107RE
J01hUFP02@1hUFPA086YP@d0GW1<00<0PJV104iK?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i
:@80PJV1U02`h>H10?ooo`00T`2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT02P1@GTT01021ZH40
IGYL06EjG01UNU`:086YP@@0MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00G08BT
N003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg405`20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0080JX9H2P21ZH4305i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i
:@0d>BT00`0d>BT2086YPI<0/>3V0@3oool00980/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900L0
D5i92021ZH4=07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06024Y7P00`21ZH40
Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP0501hUFP00`21ZH40
JX9H06Z2F00<06Z2F0P0PJV12@1>Fcl00`21ZH40=3TY03@i:@0303@i:@80PJV1TP2`h>H10?ooo`00
TP2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT01`21ZH4306=iGP03086YP@1fTFh0MY5^00l0MY5^
00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H00l0JX9H
00@0PJV105Y/B@1JK4T0FVa91`21ZH4204iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6B0;3PiP40
oooo002A0;3PiP80PJV1100`=Bd5086YP@T0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie
07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma
082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa9
05Y/B@0705Y/B@D0PJV1100d>BT2086YPI40/>3V0@3oool00900/>3V0P21ZH43030e;@80PJV100<0
@Ti1086YP@1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0
PJV108BTN024Y7P06024Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0
PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900X0FVa900@0
PJV1041;=021ZH40PJV10`0d>BT00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002@0;3PiP03086YP@0`
=Bd0PJV10080PJV10P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^00l0MY5^00<0
PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0
PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0
PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=005086YPI00/>3V0@3oool008l0/>3V0`21ZH45
049>@@03086YP@1SNEh0HgUN00X0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E
07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma082OL@0I
082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP03`1ZPUP00`21ZH40FVa905Y/B@0;
05Y/B@03086YP@10Bc@0@4/d00<0@4/d0`21ZH6?0;3PiP40oooo002?0;3PiP80PJV11P12CT400`21
ZH40HgUN06=iGP0:06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21
ZH40Q:Ah08BTN00I08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21
ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02P1JK4T00`21
ZH40@4/d041;=004041;=080PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@H0@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024
Y7P06024Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01h
UFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010
Bc@01010Bc@2086YPHh0/>3V0@3oool008h0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0PJV101`P602`h>H0S@2`h>H10?ooo`00S@2`h>H2086YP@H0@Ti100<0PJV106=iGP1SNEh02`1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06024
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010
Bc@2086YPHd0/>3V0@3oool008d0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV1
07JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV1
08BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV1
06Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d0P21ZH6=
0;3PiP40oooo002<0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21
ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06@24Y7P00`21
ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05@1hUFP00`21
ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@00`21
ZH40720H086YP@2<0;3PiP40oooo002<0;3PiP80PJV11P12CT400`21ZH40HgUN06=iGP0;06=iGP03
086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00I08BTN003
086YP@24Y7H0Q:Af01/0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21ZH40N9EX07REJ00E07REJ003
086YP@1ZPUP0JX9H0140JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080
PJV1S02`h>H10?ooo`00R`2`h>H00`21ZH406b<O086YP@06049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01H0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0PJV101`P6021ZH40R`2`h>H10?ooo`00R`2`h>H2086YP@L0@Ti100<0PJV106=iGP1SNEh02`1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06@24
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010
Bc@00`21ZH40720H086YP@2;0;3PiP40oooo002:0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV1
06=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0A07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01X0P9ma00<0PJV1
07REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900`0FVa900<0PJV1
041;=010Bc@01010Bc@00`21ZH40720H086YP@2:0;3PiP40oooo002:0;3PiP03086YP@0K8al0PJV1
00H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie
01H0Oiie00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma
01X0P9ma00<0PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00A06Z2F003086YP@1JK4T0FVa9
00/0FVa900<0PJV1041;=010Bc@01010Bc@00`21ZH40720H086YP@2:0;3PiP40oooo002:0;3PiP03
01/S7`21ZH40@Ti100D0@Ti100<0PJV106=iGP1SNEh0301SNEh00`21ZH40MY5^07JAKP0@07JAKP03
086YP@1oWWD0Oiie00X0OiieL@21ZH4<07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1J
K4T0301JK4T00`21ZH40@4/d041;=004041;=080PJV1RP2`h>H10?ooo`00R@2`h>H00`21ZH406b<O
086YP@06049>@@03086YP@1SNEh0HgUN00`0HgUN00<0PJV107JAKP1fTFh0301fTFhA086YP@`0Rjn2
00<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm
00<0PJV108>UM023YG@02P23YG@A086YP@h0JX9H00<0PJV105Y/B@1JK4T0301JK4T00`21ZH40@4/d
041;=004041;=003086YP@0L81P0PJV108T0/>3V0@3oool008T0/>3V0P0K8al00`21ZH40@Ti1049>
@@04049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh00`1fTFh:086YP@@0PZAl00<0
PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80S[>201/0S[>200<0
PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV0080MiAV2P21
ZH4506Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@00`21ZH40720H086Y
P@290;3PiP40oooo00280;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh01@1SNEh=
086YP@h0PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80
S[>201/0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0
MiAV00`0MiAV3@21ZH4705Y/B@03086YP@10Bc@0@4/d00@0@4/d00<0PJV101`P6021ZH40R02`h>H1
0?ooo`00R02`h>H201/S7`03086YP@12CT40@Ti100<0@Ti12@21ZH47076>KP03086YP@22Y7`0PZAl
0140PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80S[>2
01/0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV
0140MiAV00<0PJV1069jD@1RNU401@1RNU49086YP@D0@4/d00<0PJV101`P6021ZH40R02`h>H10?oo
o`00Q`2`h>H00`21ZH406b<O086YP@02049>@@@0PJV100<0DFEC086YP@1aSVh03@1aSVh00`21ZH40
PZAl08:TO00@08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40
S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40
MiAV07NDIP0@07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?021ZH400`21ZH42041;=003
086YP@0L81P0PJV108L0/>3V0@3oool008L0/>3V0P0K8al3086YP@D0DFEC00<0PJV1076>KP1aSVh0
2`1aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@0
6`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@0
5P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`0
0`19FC`3086YP@0301`P6021ZH40/>3V08H0/>3V0@3oool008H0/>3V1021ZH46055UD`03086YP@1a
SVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21ZH40Rjn208^_PP0F08^_PP03086YP@2>
/h@0S[>401/0S[>400<0PJV108jcPP2>/h806`2>/h800`21ZH40Rjmm08^_O@0K08^_O@03086YP@23
YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04@1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@19
FC`0BETl00@0BETl1021ZH660;3PiP40oooo00260;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1
076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV1
08jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV1
08>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV1
04UI?019FC`01019FC`01021ZH408RLM028W7@21ZH660;3PiP40oooo00260;3PiP03086YP@0U;R/0
PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80
Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0
Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40
HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM028W7@260;3PiP40oooo00250;3P
iP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:TO00B
08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K
08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0B
07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM028W7@21
ZH650;3PiP40oooo00250;3PiP04086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1aSVh0301a
SVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06P2>
/h@00`21ZH40S[>208jcPP0L08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23
YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019
FC`01021ZH408RLM028W7@21ZH650;3PiP40oooo00250;3PiP03086YP@0U;R/0PJV100L0DFEC00<0
PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201L0Rjn200<0
PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0
PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0
PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH650;3PiP40oooo00250;3PiP03086YP@0U
;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;
[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;
[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1R
NU40HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM086YP@250;3PiP40oooo0024
0;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:T
O00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jc
PP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07ND
IP0B07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM028W
7@21ZH640;3PiP40oooo00240;3PiP04086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1aSVh0
301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@0
6P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@0
5`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`0
1019FC`01021ZH408RLM028W7@21ZH640;3PiP40oooo00240;3PiP03086YP@0U;R/0PJV100L0DFEC
00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn2
00<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm
00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA
00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH640;3PiP40oooo00240;3PiP03086Y
P@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086Y
P@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086Y
P@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086Y
P@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM086YP@240;3PiP40oooo
00230;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl
08:TO00C08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>2
08jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV
07NDIP0C07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM
028W7@21ZH630;3PiP40oooo00230;3PiP04086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1a
SVh0301aSVh00`21ZH40PZAl08:TO00C08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>
/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023
YG@05P23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019
FC`01019FC`01021ZH408RLM028W7@21ZH630;3PiP40oooo00230;3PiP03086YP@0U;R/0PJV100L0
DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0
Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0
Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0
HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH630;3PiP40oooo00230;3PiP03
086YP@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003
086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03
086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03
086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM086YP@230;3PiP40
oooo00220;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40
PZAl08:TO00C08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@03@2>/h@m086YP@l0
Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00/0
HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM028W7@21ZH620;3PiP40oooo00220;3PiP04
086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00908:T
O3@0PJV13P2F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^700`0Tk^7=021ZH4;07ND
IP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH62
0;3PiP40oooo00220;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh01@1aSVhC086Y
P@X0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<
01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b
00P0PJ=b4`21ZH47069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV1PP2`h>H1
0?ooo`00PP2`h>H202D^:`03086YP@1AIE<0DFEC0080DFEC2`21ZH4707fON`03086YP@2</hP0S;>8
01<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<
01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b
01<0PJ=b00<0PJV106b9G01/RE`01@1/RE`;086YP@@0BETl00<0PJV1028W7@21ZH40PP2`h>H10?oo
o`00P@2`h>H00`21ZH409Bh[086YP@05086YP@<0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40
S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40
U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40
PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00@0PJV1051U@`1@ID<0D6E31P21ZH400`0R
9ad0PJV10;3PiP200;3PiP40oooo00210;3PiP80PJV100<0;CXf086YP@1NNF801P1NNF800`21ZH40
OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40
U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40
S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40
D6E3051U@`05051U@`04086YP@0X<b<0PJV1086YPH40/>3V0@3oool00840/>3V00@0PJV102dj=P0]
>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109Bm
S@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>k
Q`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9
G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool0
0840/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0
:3<S086YPH40/>3V0@3oool00840/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fO
N`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0
SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bc
O`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U
@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201N
NF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D
_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C
^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/
RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00<0
PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0
PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0
PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0
PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10840/>3V0@3o
ool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0
PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fO
N`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0
SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bc
O`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U
@`03086YP@0X<b<0PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40
OImk07fON`0;07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40
U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40
S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b0180PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40
D6E3051U@`06051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40
1`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd0
5`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0
702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0
301/RE`00`21ZH40D6E3051U@`05051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00800/>3V00@0
PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00
/>3V0@3oool00800/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03
086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03
086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03
086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04
086YP@0X<b<0:3<S086YPH00/>3V0@3oool00800/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21
ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21
ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21
ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21
ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3oool00800/>3V00@0PJV102dj
=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV1
09BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV1
09>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV1
06b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3o
ool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0
:3<S086YPH00/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<
07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L
09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G
08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06
051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21
ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21
ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21
ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21
ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj=P21
ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D
_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C
^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/
RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V
00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V
0@3oool00800/>3Vl`21ZH600;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV1
08F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV1
09g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV1
09>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV1
05A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV1
00P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF
01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?
01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW
00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3PiP03
086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03
086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03
086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03
086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40
oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA
09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC
09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k
08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X
086YP@200;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025
[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702M
biH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C
_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1D
KDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^
00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF
00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?
00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW
00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086Y
P@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03
086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03
086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03
086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3P
iP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21
ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21
ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21
ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021
ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV1
08F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV1
09g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV1
09>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV1
05A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00210;3PiP03086YP@0hBT<0
PJV100L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0
VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0
V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0
M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3P
iP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH02`25[HH00`21ZH40U;nA09BoT@0C09Bo
T@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:
T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0B08R`
N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@210;3P
iP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40
U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40
W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40
R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40
;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH0
3025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0
6`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL0
5`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL0
1P1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0
PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0
PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0
PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0
PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0
PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0
VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0
V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0
M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo0021
0;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09Bo
T@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:
T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`
N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk
:021ZH610;3PiP40oooo00210;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH0
3025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0
6`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL0
5`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL0
1@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP04086YP@0hBT<0>4Y3086YP@L0
J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0
VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0
V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0
M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP80
PJV100<0>4Y3086YP@1XR6h01P1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0
U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0
W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0
R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0PJV1086Y
PH40/>3V0@3oool00840/>3V00<0PJV103mGC@21ZH401021ZH4406R8KP03086YP@25[HH0QJf600`0
QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0
WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0
Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e70080
E6e71@21ZH400`0`@R/0PJV10;3PiP200;3PiP40oooo00220;3PiP03086YP@0oEdd0PJV100<0Ki=g
3021ZH4708F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F
09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj7
09>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL01@1dUVL<086YP@<0FGI>
00<0PJV10312:`0`@R/0PP2`h>H10?ooo`00PP2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<
]hl0S;N?00D0S;N?4P21ZH4;09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2M
biH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C
_XL00`21ZH40R;1k08R`N`0908R`Na80PJV11`1kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`
@R/0<48[086YPH80/>3V0@3oool00880/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?
08bgS`0<08bgS`03086YP@2JbIT0V/VI00P0V/VI=021ZH4?09g;UP03086YP@2LbY<0W<ZC01d0W<ZC
00<0PJV109[6S`2JaXl03@2JaXld086YP@X0S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>
05UfCP0405UfCP04086YP@0`@R/0<48[086YPH80/>3V0@3oool00880/>3V00@0PJV103mGC@0oEdd0
PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bgS`03086YP@2JbIT0V/VI01<0V/VI00<0PJV10:3AW@2P
dId05`2PdId00`21ZH40X]>M0:;CW@0<0:;CWCl0PJV13P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03
086YP@2>^H<0S[V301<0S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505UfCP04
086YP@0`@R/0<48[086YPH80/>3V0@3oool008<0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21ZH40
S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40
X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40
VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40
FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108<0/>3V0@3oool008<0/>3V00<0PJV103mGC@21ZH40
1`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId0
5`2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH0
6`2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0
301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH<0/>3V0@3oool008<0/>3V
00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI01<0
V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0
X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V301<0
S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086Y
PH<0/>3V0@3oool008<0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bg
S`03086YP@2JbIT0V/VI01<0V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;C
W@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7
S`03086YP@2>^H<0S[V301<0S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505Uf
CP04086YP@0`@R/0<48[086YPH<0/>3V0@3oool008@0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21
ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21
ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21
ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21
ZH40FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108@0/>3V0@3oool008@0/>3V00<0PJV103mGC@21
ZH401`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2P
dId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2O
cYH06P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1k
XFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH@0/>3V0@3oool008@0
/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI
0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J
01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V3
0180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[
086YPH@0/>3V0@3oool008@0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;
08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J
0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0G
09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP05
05UfCP04086YP@0`@R/0<48[086YPH@0/>3V0@3oool008D0/>3V00<0PJV103mGC@21ZH401`1_TgL0
0`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05`2PdId0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH0
0`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl0301kXFl0
0`21ZH40FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108D0/>3V0@3oool008D0/>3V00<0PJV103mG
C@21ZH401`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3A
W@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>
UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^Q
K`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPHD0/>3V0@3oool0
08D0/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0
V/VI0180V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0
X]:J01`0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0
S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0
<48[086YPHD0/>3V0@3oool008D0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bg
S`0;08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;C
W@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7
S`0F09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05Uf
CP0505UfCP04086YP@0`@R/0<48[086YPHD0/>3V0@3oool008D0/>3V00@00000086YP@0oEdd0PJV1
1`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId0
5P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH0
6`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl0
301kXFl00`21ZH40FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108H0/>3V0@3oool008@0/>3V0`00
00000`0oEdd0PJV106nCM`0606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2J
bIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX06`2R
dYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>
^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1
QP2`h>H10?ooo`00Q@2`h>H200000080PJV100<0000006nCM`1_TgL0101_TgL00`21ZH40S;N?08bg
S`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;C
W@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7
S`0F09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05Uf
CP0405UfCP@0PJV1QP2`h>H10?ooo`00Q@2`h>H6000000<0Ki=g00@0000006nCM`1_TgL0PJV13@2<
]hl00`21ZH40V/VI09[9V@0A09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2R
did00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2I
ahl00`21ZH40S[V308jiP`0A08jiP`03086YP@1kXFl0Nj5_00/0Nj5_00<0PJV105UfCP1IMTh0101I
MTh2086YP@030315;021ZH40/>3V08H0/>3V0@3oool008D0/>3V1`0000001P21ZH40000000000000
0000Ki=g086YP@<0S;N?00<0000008bgS`2<]hl0202<]hl00`21ZH40V/VI09[9V@0@09[9V@03086Y
P@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086Y
P@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0@08jiP`03086Y
P@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh01021ZH40101NOeH0PJV10315;021ZH670;3PiP40
oooo00260;3PiP<0000000<0AF5D0000000000000P1bVgd2000000@0PJV10`000002086YP@<0S;N?
00D0000008bgS`2<]hl0S;N?086YP@0C09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2R
did06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2I
ahl05P2Iahl00`21ZH40S[V308jiP`0A08jiP`03086YP@1kXFl0Nj5_00D0Nj5_2P21ZH4405ioEP03
086YP@0`AB`0PJV108P0/>3V0@3oool008H0/>3V100000001021ZH4000000000001bVgd200000003
07:KO@21ZH40SkjD0080SkjD0P00000208nnU080PJV10`000005086YP@0300000021ZH40V/VI00T0
V/VI00<0000009[9V@2JbIT00P2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01X0
X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01H0
VLN?00<0PJV108jiP`2>^H<03@2>^H<<086YP@L0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40
<4D/086YP@280;3PiP40oooo00260;3PiP@0000000@0AF5D086YP@000000LY]m0`000000101bVgd0
PJV108nnU02?_Y@2000000D0SkjD0P00000208nnU003086YP@2Md9l00000008000002@21ZH430000
00<0V/VI00<0PJV10:3AW@2PdId01P2PdId00`000000X=6M0:3AW@0=0:3AW@03086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?
00l0VLN?00<0000009W7S`2Iahl0102Iahl00`21ZH40S[V308jiP`0308jiP`X0PJV1102B`8T00`21
ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40R@2`h>H10?oo
o`00QP2`h>H40000000304EQE021ZH4000000080LY]m0P000000101bVgd0PJV108nnU02?_Y@30000
00@0SkjD0P00000308nnU004086YP@2Md9l00000000000X0WM2O0P00000;086YP@<000000P21ZH4<
0:3AW@03086YP@000000X]>M00<0X]>M00<000000:;CW@2Rdid0502Rdid01@000000X]:J0:;BVP2R
dYX0000001T0X]:J00<0000009o>UP2OcYH00P2OcYH00`000000WljF09o>UP0B09o>UP050000002O
cYH0WljF086YP@0000002`2Iahl4086YP@<000002`21ZH4=09;0R@03086YP@1oZ7H0OjQf00`0OjQf
00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@290;3PiP40oooo00270;3PiP@0000000@0
PJV107:KO@1bVgd0LY]m0`0000001021ZH40SkjD08nnU02?_Y@2000000@0SkjD0P00000308nnU004
086YP@2Md9l00000000000X0WM2O0P00000309g@W`03086YP@2Tf:80Y=RR00H0Y=RR0P0000020:CH
XPX0PJV13000000@086YP@X000000`21ZH42000000l0PJV13000000=086YP@h000001P21ZH4309g>
U@D00000102McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00`0OjQf00<0PJV105io
EP1NOeH0101NOeH2086YPHX0/>3V0@3oool008L0/>3V100000000`15HE@0PJV107:KO@0207:KO@80
000000@0LY]m086YP@2?_Y@0SkjD0P00000408nnU0<000000P2?_Y@00`21ZH40WM2O000000020000
00T0WM2O0P00000309g@W`03086YP@2Tf:80Y=RR00H0Y=RR0P00000;0:CHXPh000003P2VfZ8=0000
00030:GIX0000000000000h0YMVP3P00000;0:?EW0l000002P2McYD3000000@0WLjE00<0PJV109;0
R@2B`8T04@2B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315
;021ZH40RP2`h>H10?ooo`00R02`h>H400000004086YP@1bVgd0LY]m07:KO@80000000@0LY]m086Y
P@2?_Y@0SkjD0`00000408nnU08000000P2?_Y@00`21ZH40WM2O09g@W`02000000T0WM2O0`000003
09g@W`03086YP@2Tf:80Y=RR00D0Y=RR0P00000:0:CHXP<0000000<0Y=RR086YP@2VfZ801`2VfZ83
000000`0Y]ZR0`0000020:KJXP03086YP@2UfJ00YMVP00<0YMVP1P00000=0:GIX0<000000P2UfJ00
0`21ZH40XmFL0:?EW0050:?EW0<000002P2SeI`2000000H0XmFL00<0PJV109g>U@2McYD00`2McYD2
000000X0WLjE00<0000009g>U@2McYD00`2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0
OjQf00`0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@2:0;3PiP40oooo00280;3P
iP@0000000@0PJV107:KO@1bVgd0LY]m0`000000101bVgd0PJV108nnU02?_Y@2000000@0SkjD0P00
000308nnU004086YP@2Md9l00000000000X0WM2O0P00000309g@W`03086YP@2Tf:80Y=RR00D0Y=RR
0`0000080:CHXP<000000`2Tf:800`21ZH40Y]ZR0:KJXP060:KJXP<000002P2VfZ83000000<0Y]ZR
00<0PJV10:GIX02UfJ001@2UfJ04000000`0YMVP0`0000030:GIX003086YP@2SeI`0XmFL00H0XmFL
0`0000080:?EW08000001P2SeI`00`21ZH40WLjE09g>U@0409g>U@<000003`2McYD00`21ZH40T/29
09;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/
086YP@2;0;3PiP40oooo00280;3PiP@0000000<0AF5D086YP@1bVgd00P1bVgd20000000407:KO@21
ZH40SkjD08nnU0<000000`2?_Y@2000000<0SkjD00@0PJV109g@W`00000000002P2Md9l2000000<0
WM2O00<0PJV10:CHXP2Tf:801P2Tf:82000000P0Y=RR0P0000040:CHXP03086YP@2VfZ80Y]ZR00L0
Y]ZR0`0000080:KJXP<00000102VfZ800`21ZH40YMVP0:GIX0060:GIX0@000002P2UfJ03000000@0
YMVP00<0PJV10:?EW02SeI`01`2SeI`3000000L0XmFL00<000000:?EW02SeI`01@2SeI`00`21ZH40
WLjE09g>U@0309g>U@<00000402McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0
OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@2;0;3PiP40oooo00290;3PiP@00000
00@0PJV107:KO@1bVgd0LY]m0`0000001021ZH40SkjD08nnU02?_Y@2000000<0SkjD0`00000208nn
U003086YP@2Md9l00000008000002@2Md9l2000000<0WM2O00<0PJV10:CHXP2Tf:801P2Tf:820000
00P0Y=RR0P0000040:CHXP03086YP@2VfZ80Y]ZR00P0Y]ZR00<000000:KJXP2VfZ801`2VfZ820000
00D0Y]ZR00<0PJV10:GIX02UfJ001`2UfJ02000000/0YMVP0P0000050:GIX003086YP@2SeI`0XmFL
00P0XmFL00<000000:?EW02SeI`01P2SeI`00`000000XmFL0:?EW0050:?EW003086YP@2McYD0WLjE
00<0WLjE0P00000@09g>U@03086YP@2B`8T0T/290140T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21
ZH40GWmF05ioEP0405ioEP80PJV1S02`h>H10?ooo`00R@2`h>H40000000304EQE000000000000080
LY]m0P000000101bVgd0PJV108nnU02?_Y@2000000@0SkjD0P00000308nnU004086YP@2Md9l00000
000000T0WM2O0`00000309g@W`03086YP@2Tf:80Y=RR00D0Y=RR0P0000080:CHXP800000102Tf:80
0`21ZH40Y]ZR0:KJXP0B0:KJXP030000002VfZ80Y]ZR00@0Y]ZR00<0PJV10:GIX02UfJ001`2UfJ02
000000/0YMVP00<000000:GIX02UfJ00102UfJ000`21ZH40XmFL0:?EW00I0:?EW003086YP@2McYD0
WLjE00<0WLjE0P00000@09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H02`1oZ7H0
0`21ZH40GWmF05ioEP0405ioEP03086YP@0`AB`0PJV108`0/>3V0@3oool008T0/>3V1`00000207:K
O@<0000000<0PJV108nnU02?_Y@00`00000308nnU08000000`2?_Y@01021ZH40WM2O00000000000:
09g@W`8000000`2Md9l00`21ZH40Y=RR0:CHXP050:CHXP<000001P2Tf:83000000@0Y=RR00<0PJV1
0:KJXP2VfZ804@2VfZ82000000H0Y]ZR00<0PJV10:GIX02UfJ001`2UfJ02000000X0YMVP0P000006
0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD01@00000@09g>U@03086YP@2B`8T0
T/290100T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1S@2`h>H1
0?ooo`00R@2`h>H7000000<0LY]m0P0000000`21ZH40SkjD08nnU002000000@0SkjD0P00000308nn
U003086YP@2Md9l00000008000002@2Md9l2000000<0WM2O00<0PJV10:CHXP2Tf:801P2Tf:820000
00H0Y=RR0P0000060:CHXP03086YP@2VfZ80Y]ZR0100Y]ZR00<000000:KJXP2VfZ801@2VfZ800`21
ZH40YMVP0:GIX0070:GIX08000002@2UfJ02000000L0YMVP00<0PJV10:?EW02SeI`0602SeI`80000
00T0WLjE0P00000609g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21
ZH40GWmF05ioEP0405ioEP80PJV1S@2`h>H10?ooo`00S@2`h>H400000080LY]m0`0000001021ZH40
SkjD00000000000408nnU0<000000`2?_Y@00`21ZH40WM2O00000002000000P0WM2O0P00000309g@
W`03086YP@2Tf:80Y=RR00H0Y=RR0P0000060:CHXQ<00000202VfZ82000000H0Y]ZR00<0PJV10:GI
X02UfJ001`2UfJ02000000T0YMVP0P0000070:GIX003086YP@2SeI`0XmFL01@0XmFL2@00000<09g>
U@8000001@2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105io
EP1NOeH0101NOeH2086YPHh0/>3V0@3oool008d0/>3V0`00000307:KO@@0000000@0SkjD00000000
00000000102?_Y@2000000<0SkjD00<0PJV109g@W`0000000`00000709g@W`<000000`2Md9l00`21
ZH40Y=RR0:CHXP050:CHXP8000001P2Tf:8D000000L0Y]ZR0`0000050:KJXP03086YP@2UfJ00YMVP
00L0YMVP0P0000090:GIX1@000002@2SeI`700000003086YP@2McYD0WLjE00h0WLjE0P00000509g>
U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40GWmF05ioEP0405io
EP80PJV1SP2`h>H10?ooo`00SP2`h>H00`000000PJV1086YP@0307:KO@H000001P2?_Y@200000080
SkjD00<0PJV109g@W`0000001000000609g@W`@000000P2Md9l00`21ZH40Y=RR0:CHXP050:CHXP<0
00001`2Tf:800`000000Y=RR0:CHXP030:CHXP03086YP@2VfZ80Y]ZR00L0Y]ZR0P0000080:KJXP80
00001P2VfZ800`21ZH40YMVP0:GIX0060:GIX08000002@2UfJ0D000000P0XmFL1@0000030:?EW003
086YP@2McYD0WLjE00@0WLjE00<0000009g>U@2McYD01`2McYD2000000D0WLjE00<0PJV109;0R@2B
`8T0402B`8T00`21ZH40OjQf07nXMP0:07nXMP03086YP@1NOeH0GWmF00@0GWmF0P21ZH6?0;3PiP40
oooo002>0;3PiP0400000021ZH40PJV1086YP@80LY]m1@00000808nnU0040000002?_Y@0SkjD086Y
P@80WM2O1@00000509g@W`H0000000<0PJV10:CHXP2Tf:801@2Tf:82000000P0Y=RR0P0000040:CH
XP03086YP@2VfZ80Y]ZR00L0Y]ZR0P0000080:KJXP8000001P2VfZ800`21ZH40YMVP0:GIX0060:GI
X08000002P2UfJ02000000D0YMVP00<0PJV10:?EW02SeI`01`2SeI`3000000L0XmFL0P0000060:?E
W003086YP@2McYD0WLjE00@0WLjE00<0000009g>U@2McYD01`2McYD2000000D0WLjE00<0PJV109;0
R@2B`8T03`2B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00<0GWmF0`21ZH6?0;3P
iP40oooo002@0;3PiP@0PJV10`0000000`21ZH40SkjD08nnU00708nnU0050000002?_Y@0SkjD08nn
U021ZH400P2Md9l00`000000WM2O0000000300000080WM2O200000070:CHXP800000202Tf:840000
00<0Y=RR00<0PJV10:KJXP2VfZ801P2VfZ82000000P0Y]ZR100000040:KJXP03086YP@2UfJ00YMVP
00H0YMVP0`0000090:GIX0<00000102UfJ000`21ZH40XmFL0:?EW0060:?EW0<00000202SeI`00`00
0000XmFL0:?EW0040:?EW003086YP@2McYD0WLjE00@0WLjE0P00000809g>U@8000001@2McYD00`21
ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00@0PJV105ioEP1NOeH0GWmF0P21ZH40
0`1OPeX0PJV10;3PiP2?0;3PiP40oooo002@0;3PiP80PJV10P1bWGl01@21ZH4000000000001bVgd0
PJV100`0SkjD00@0PJV109g@W`2Md9l000000P2Md9l8000000<0WM2O100000030:CHXP@000002@2T
f:85000000030:CHXP21ZH40Y]ZR00D0Y]ZR100000090:KJXPD000000P2VfZ800`21ZH40YMVP0:GI
X0050:GIX0<000002`2UfJ03000000<0YMVP00<0PJV10:?EW02SeI`01@2SeI`3000000T0XmFL0P00
00050:?EW003086YP@2McYD0WLjE00<0WLjE0P00000909g>U@8000001@2McYD00`21ZH40T/2909;0
R@0@09;0R@03086YP@1oZ7H0OjQf00X0OjQf00<0PJV105ioEP21ZH400P21ZH4205n3FP03086YP@2`
h>H0/>3V08l0/>3V0@3oool00940/>3V0P21ZH4207:MO`8000001@21ZH4908nnU003086YP@2Md9l0
WM2O00@0WM2O1@00000609g@W`T00000302Tf:86000000<0Y]ZR1@00000<0:KJXP@0000000<0Y]ZR
086YP@2UfJ001@2UfJ04000000`0YMVP0`0000020:GIX003086YP@2SeI`0XmFL00<0XmFL1000000:
0:?EW0D000000P2SeI`00`21ZH40WLjE00000004000000X0WLjE0P00000509g>U@03086YP@2B`8T0
T/290100T/2900<0PJV107nXMP1oZ7H01`1oZ7H5086YP@@0Gh=J0P21ZH6A0;3PiP40oooo002B0;3P
iP80PJV100H0LYeo000000000000000007:MO`21ZH4208o1U`L0PJV10`2?_Y@00`21ZH40WM2O09g@
W`0?09g@W`H00000402Tf:8:00000100Y]ZR100000030:GIX0L000003@2UfJ05000000@0XmFL1000
000<0:?EW0d000002P2McYD2000000D0WLjE00<0PJV109;0R@2B`8T03`2B`8T01021ZH40OjQf07nX
MP1oZ7H7086YP@80Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPI80/>3V0@3oool00980/>3V0P21
ZH4207:MO`040000001bWGl0LYeo086YP@T0Sl6G00<00000086YP@21ZH401@21ZH4=09g@W`03086Y
P@2Tf:80Y=RR01D0Y=RR1P00000C0:KJXPX0000000<0YMVP0000000000003P2UfJ0:00000140XmFL
1P00000>09g>U@800000102McYD00`21ZH40T/2909;0R@0<09;0R@P0PJV12@1o[7X00`21ZH40Gh=J
05n3FP0305n3FP80PJV1TP2`h>H10?ooo`00T`2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL01@2?
`IL300000080Sl6G00@0PJV109kCXP2Ndj80W]>R2P21ZH4409g@W`03086YP@2Tf:80Y=RR01D0Y=RR
00<0PJV10:KJXP2VfZ805P2VfZ86000000@0YMVP0P00000@0:GIX0L00000502SeI`00`21ZH40WLjE
09g>U@0>09g>U@8000001@2McYD00`21ZH40T/2909;0R@0209;0R@X0PJV10`2Ca8d00`21ZH40Ojaj
07n/NP0:07n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6C0;3PiP40oooo002D0;3PiP80PJV1101b
WGl00`21ZH40Sl6G08o1U`0508o1U`@0000000<0Sl6G086YP@2Ndj80302Ndj8@086YP@`0Y=RR00<0
PJV10:KJXP2VfZ805`2VfZ800`21ZH40YMVP0:GIX0060:GIX08000004@2UfJ000`21ZH40XmFL0:?E
W00G0:?EW003086YP@2McYD0WLjE00X0WLjE1021ZH42000000X0PJV13@2Ca8d00`21ZH40Ojaj07n/
NP0:07n/NP03086YP@1OPeX0Gh=J0080Gh=J0P21ZH6D0;3PiP40oooo002D0;3PiP80PJV11@1bWGl0
0`21ZH40Sl6G08o1U`0408o1U`@000000P2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0
YMbV00T0YMbV6@21ZH4=0:KJXP03086YP@2UfJ00YMVP00H0YMVP0P00000A0:GIX003086YP@2SeI`0
XmFL00/0XmFL6@21ZH4409kBV@8000001@2NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0
Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPI@0/>3V0@3oool009D0/>3V0P21ZH4507:M
O`03086YP@2?`IL0Sl6G00@0Sl6G0P00000308o1U`03086YP@2Ndj80W]>R00l0W]>R00<0PJV10:GL
YP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0:0:SOYQH0PJV10P00000O086YP@`0YMZP00<0PJV109kB
V@2NdYT03P2NdYT2000000@0W]:I00<0PJV109?4S@2Ca8d03`2Ca8d00`21ZH40Ojaj07n/NP0907n/
NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6E0;3PiP40oooo002E0;3PiP80PJV11@1bWGl00`21ZH40
Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40
Z=nV0:SOYP0G0:SOYP03086YP@2WgZ@0YmjT00H0YmjT0P00000A0:ONY003086YP@2UfZ00YMZP01L0
YMZP00<0PJV109kBV@2NdYT03P2NdYT2000000@0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40
Ojaj07n/NP0:07n/NP03086YP@1OPeX0Gh=J00<0Gh=J00<0PJV10;3PiP2`h>H0U02`h>H10?ooo`00
UP2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0?09kCXP03086Y
P@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY0060:ONY0800000
4@2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I00h0W]:I0P00000409kBV@03086Y
P@2Ca8d0TlB=00l0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV1
UP2`h>H10?ooo`00U`2`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40W]>R09kC
XP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ON
Y0060:ONY08000004@2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01@0W]:I00<0
PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0:07n/NP03086YP@1OPeX0Gh=J0080Gh=J0P21
ZH6G0;3PiP40oooo002G0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80
W]>R00h0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0
YmjT01T0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0D09kBV@03086YP@2Ca8d0
TlB=00h0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV1U`2`h>H1
0?ooo`00V02`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40W]>R09kCXP0>09kC
XP03086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40YmjT0:ONY00G0:ON
Y003086YP@2UfZ00YMZP01L0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0>09?4
S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPIP0/>3V0@3oool009T0
/>3V0P21ZH4407:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803P2Ndj800`21ZH40
YMbV0:GLYP0D0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40
YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01@0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40
Ojaj07n/NP0907n/NP03086YP@1OPeX0Gh=J0080Gh=J0P21ZH6I0;3PiP40oooo002J0;3PiP03086Y
P@1bWGl0LYeo00<0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0=09kCXP03086Y
P@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086Y
P@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0>09?4S@03086Y
P@1o[7X0Ojaj00T0Ojaj00<0PJV105n3FP1OPeX00`1OPeX00`21ZH40/>3V0;3PiP2H0;3PiP40oooo
002K0;3PiP80PJV10`1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00h0W]>R00<0
PJV10:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0
PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0
PJV107n/NP1o[7X02@1o[7X01021ZH40Gh=J05n3FP1OPeX2086YPI/0/>3V0@3oool009`0/>3V0`21
ZH4207:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803@2Ndj800`21ZH40YMbV0:GL
YP0C0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJ
X00F0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d03@2Ca8d00`21ZH40Ojaj07n/
NP0907n/NP03086YP@1OPeX0Gh=J00<0PJV1W02`h>H10?ooo`00W@2`h>H00`21ZH40KYYm086YP@02
086YP@/0Sl6G00<0PJV109kCXP2Ndj803P2Ndj800`21ZH40YMbV0:GLYP0B0:GLYP03086YP@2XgjH0
Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0
W]:I0180W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0907n/NP<0PJV100<0G8=K
086YP@2`h>H0W02`h>H10?ooo`00WP2`h>H00`21ZH40KYYm06jJO@05086YP@P0Sl6G00<0PJV109kC
XP2Ndj803@2Ndj800`21ZH40YMbV0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:ON
Y02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4
S@2Ca8d03@2Ca8d00`21ZH40Ojaj07n/NP0607n/NPD0PJV10P1LPe/00`21ZH40/>3V0;3PiP2L0;3P
iP40oooo002N0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;_YD01P21ZH4208o1U`03
086YP@2Ndj80W]>R00d0W]>R00<0PJV10:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0E0:SOYP03
086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I09kBV@0C09kBV@03
086YP@2Ca8d0TlB=00d0TlB=00<0PJV107n/NP1o[7X01P21ZH4207b[NP03086YP@1LPe/0G8=K0080
G8=K00<0PJV10;3PiP2`h>H0W02`h>H10?ooo`00W`2`h>H00`21ZH40KYYm06jJO@0206jJO@03086Y
P@2;_YD0RkjE00D0RkjE1P21ZH4=09kCXP03086YP@2Ug:H0YMbV0180YMbV00<0PJV10:SOYP2XgjH0
5@2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT0
4P2NdYT00`21ZH40TlB=09?4S@0;09?4S@H0PJV11`1lZgX00`21ZH40G8=K05b3F`0205b3F`03086Y
P@2`h>H0/>3V09d0/>3V0@3oool00:00/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^n
U@0808^nU@03086YP@2KdZ80PJV100D0PJV11`2Ndj800`21ZH40YMbV0:GLYP0B0:GLYP03086YP@2X
gjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05@2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2N
dYT0W]:I0180W]:I00<0PJV109?4S@2Ca8d01@2Ca8d6086YP@030974SP21ZH40O:]j00T0O:]j00<0
PJV105b3F`1LPe/00P1LPe/00`21ZH40/>3V0;3PiP2N0;3PiP40oooo002Q0;3PiP05086YP@1^VWd0
KYYm06jJO@21ZH402P2;_YD00`21ZH40Vm:R09_BXP0509_BXPH0PJV10P2Ndj800`21ZH40YMbV0:GL
YP0B0:GLYP03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:ONY02WgZ@05@2WgZ@00`21ZH40YMZP0:GJ
X00E0:GJX003086YP@2NdYT0W]:I0180W]:I00<0PJV109?4S@2Ca8d01P21ZH470974SP03086YP@1l
ZgX0O:]j00P0O:]j00D0PJV105b3F`1LPe/0G8=K086YP@2Q0;3PiP40oooo002R0;3PiP05086YP@1^
VWd0KYYm06jJO@21ZH402P2;_YD00`21ZH40Vm:R09_BXP0:09_BXPd0PJV12P2Ug:H00`21ZH40Z=nV
0:SOYP0E0:SOYP03086YP@2WgZ@0YmjT01D0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I
09kBV@0809kBV@d0PJV1302Aa8h00`21ZH40O:]j07b[NP0807b[NP05086YP@1LPe/0G8=K05b3F`21
ZH40XP2`h>H10?ooo`00X`2`h>H01@21ZH40KYYm06jJO@1^VWd0PJV100X0RkjE00<0PJV109_BXP2K
dZ80302KdZ800`21ZH40Y=bW0:CLY`070:CLYaH0PJV1302XgjH00`21ZH40YmjT0:ONY00E0:ONY003
086YP@2UfZ00YMZP00X0YMZP5P21ZH4909gCVP03086YP@2Aa8h0TLB>00`0TLB>00<0PJV107b[NP1l
ZgX0201lZgX01@21ZH40G8=K05b3F`1LPe/0PJV10:<0/>3V0@3oool00:@0/>3V00D0PJV106jJO@1^
VWd0KYYm086YP@0:08^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L04@2Tg:L00`21
ZH40Yn2X0:OPZ0090:OPZ340PJV12`2Tfj800`21ZH40WM>J09gCVP0A09gCVP03086YP@2Aa8h0TLB>
00/0TLB>00<0PJV107b[NP1lZgX0201lZgX01@21ZH40G8=K05b3F`1LPe/0PJV10:@0/>3V0@3oool0
0:@0/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^nU@0708^nU@03086YP@2KdZ80Vm:R
00`0Vm:R00<0PJV10:CLY`2Tg:L04@2Tg:L00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2WgjH0YmnV
01D0YmnV00<0PJV10:CKXP2Tfj80502Tfj800`21ZH40WM>J09gCVP0A09gCVP03086YP@2Aa8h0TLB>
00`0TLB>00<0PJV107b[NP1lZgX01`1lZgX00`21ZH40G8=K05b3F`0205b3F`03086YP@2`h>H0/>3V
0:80/>3V0@3oool00:D0/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^nU@0708^nU@03
086YP@2KdZ80Vm:R00`0Vm:R00<0PJV10:CLY`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00D0:OPZ003
086YP@2WgjH0YmnV01D0YmnV00<0PJV10:CKXP2Tfj80502Tfj800`21ZH40WM>J09gCVP0@09gCVP03
086YP@2Aa8h0TLB>00`0TLB>00<0PJV107b[NP1lZgX01`1lZgX00`21ZH40G8=K05b3F`0205b3F`03
086YP@2`h>H0/>3V0:<0/>3V0@3oool00:H0/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE
08^nU@0708^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L04@2Tg:L00`21ZH40Yn2X
0:OPZ00C0:OPZ003086YP@2WgjH0YmnV01D0YmnV00<0PJV10:CKXP2Tfj804`2Tfj800`21ZH40WM>J
09gCVP0A09gCVP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[NP1lZgX01`1lZgX00`21ZH40G8=K
05b3F`0205b3F`03086YP@2`h>H0/>3V0:@0/>3V0@3oool00:L0/>3V0P21ZH4206jJO@03086YP@2;
_YD0RkjE00P0RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0@0:CLY`03086YP@2W
h:P0Yn2X01@0Yn2X00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2M
diX0WM>J0100WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0807b[NP03086YP@1L
Pe/0G8=K0080PJV1Y`2`h>H10?ooo`00Z02`h>H3086YP@0306jJO@21ZH40RkjE00P0RkjE00<0PJV1
09_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0@0:CLY`03086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV1
0:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J00l0WM>J00<0PJV1
0974SP2Aa8h0302Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0PJV10080PJV1Z02`h>H1
0?ooo`00Z@2`h>H5086YP@T0RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0@0:CL
Y`03086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0C0:CK
XP03086YP@2MdiX0WM>J0100WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0707b[
NP<0PJV100<0EWaI086YP@2`h>H0Z02`h>H10?ooo`00Z`2`h>H00`21ZH40II5f086YP@02086YP@P0
RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0?0:CLY`03086YP@2Wh:P0Yn2X01<0
Yn2X00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0C0:CKXP03086YP@2MdiX0WM>J00l0
WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0607b[NP<0PJV100<0EWaI086YP@2`
h>H0ZP2`h>H10?ooo`00[02`h>H00`21ZH40II5f06FAMP05086YP@D0RkjE00<0PJV109_BXP2KdZ80
2P2KdZ800`21ZH40Y=bW0:CLY`0@0:CLY`03086YP@2Wh:P0Yn2X0180Yn2X00<0PJV10:OOYP2WgjH0
4`2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086YP@2MdiX0WM>J0100WM>J00<0PJV10974SP2Aa8h0
2P2Aa8h00`21ZH40O:]j07b[NP0307b[NPD0PJV10P1FO5T00`21ZH40/>3V0;3PiP2Z0;3PiP40oooo
002]0;3PiP04086YP@1UTGH0II5f086YP@<0PKB>1021ZH400`2;_YD0PJV109_BXP0<09_BXP03086Y
P@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086Y
P@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40TLB>0974SP0;0974SP03086Y
P@1lZgX0PJV100<0PJV10`1dXgH01021ZH40EWaI05IlF@21ZH6]0;3PiP40oooo002^0;3PiP80PJV1
00<0II5f086YP@21ZH401@21]8h6086YP@X0Vm:R00<0PJV10:CLY`2Tg:L03P2Tg:L00`21ZH40Yn2X
0:OPZ00B0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj804P2Tfj800`21ZH40WM>J
09gCVP0>09gCVP03086YP@2Aa8h0TLB>00P0TLB>1P21ZH4507BSMP80PJV100<0EWaI086YP@21ZH40
[P2`h>H10?ooo`00/02`h>H01021ZH40II5f06FAMP21ZH47086dSP03086YP@2BbY`0T/ZL00P0PJV1
0P2KdZ800`21ZH40Y=bW0:CLY`0?0:CLY`03086YP@2Wh:P0Yn2X0180Yn2X00<0PJV10:OOYP2WgjH0
4@2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086YP@2MdiX0WM>J00l0WM>J00<0PJV10974SP2Aa8h0
2021ZH4208VmRP03086YP@1dXgH0M:=f00D0M:=f00@0PJV105IlF@1FO5T0PJV1/02`h>H10?ooo`00
/@2`h>H01021ZH40II5f06FAMP21ZH47086dSP03086YP@2BbY`0T/ZL00L0T/ZL2021ZH4<0:CLY`03
086YP@2Wh:P0Yn2X0180Yn2X00<0PJV10:OOYP2WgjH04@2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03
086YP@2MdiX0WM>J00X0WM>J2021ZH4908VmRP03086YP@1dXgH0M:=f00D0M:=f00@0PJV105IlF@1F
O5T0PJV1/@2`h>H10?ooo`00/P2`h>H01021ZH40II5f06FAMP21ZH47086dSP03086YP@2BbY`0T/ZL
00X0T/ZL00@0PJV109cFX`2LeZ<0W=JS2@21ZH440:CLY`03086YP@2Wh:P0Yn2X0140Yn2X00<0PJV1
0:OOYP2WgjH04@2WgjH00`21ZH40Y=^R0:CKXP0A0:CKXP03086YP@2MdiX0WM>J0080WM>J2@21ZH43
09K=U`03086YP@29_HX0RKf:00X0RKf:00<0PJV107BSMP1dXgH01@1dXgH01021ZH40EWaI05IlF@21
ZH6b0;3PiP40oooo002c0;3PiP80PJV100<0II5f086YP@21]8h01P21]8h00`21ZH40T/ZL09;:W00:
09;:W003086YP@2LeZ<0W=JS00T0W=JSA@21ZH4;09K=U`03086YP@29_HX0RKf:00X0RKf:00<0PJV1
07BSMP1dXgH01@1dXgH01021ZH40EWaI086YP@21ZH6c0;3PiP40oooo002e0;3PiP03086YP@1UTGH0
PJV100L0PKB>00<0PJV109;:W02BbY`02@2BbY`00`21ZH40W=JS09cFX`0=09cFX`03086YP@2QfjD0
XM^U0140XM^U00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40W]NO09kGW`0@09kGW`03086YP@2FcIL0
U/fG00h0U/fG00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f07BSMP0507BSMP03086YP@1FO5T0
PJV10;D0/>3V0@3oool00;H0/>3V00@0PJV106FAMP21ZH40PJV11P21]8h00`21ZH40T/ZL09;:W009
09;:W003086YP@2LeZ<0W=JS00d0W=JS00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40XM^T0:7KY00A
0:7KY003086YP@2Neil0W]NO0100W]NO00<0PJV109K=U`2FcIL03@2FcIL00`21ZH40RKf:08VmRP09
08VmRP03086YP@1dXgH0M:=f00@0M:=f0P21ZH400`1FO5T0PJV10;3PiP2e0;3PiP40oooo002g0;3P
iP80PJV100<0II5f086YP@21]8h01@21]8h00`21ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS
00`0W=JS00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO
0100W]NO00<0PJV109K=U`2FcIL03@2FcIL00`21ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f
00@0M:=f00@0PJV105IlF@21ZH40PJV1]`2`h>H10?ooo`00^@2`h>H3086YP@H0PKB>00<0PJV109;:
W02BbY`02@2BbY`00`21ZH40W=JS09cFX`0<09cFX`03086YP@2QfjD0XM^U0100XM^U00<0PJV10:7K
Y02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0@09kGW`03086YP@2FcIL0U/fG00`0U/fG00<0PJV108Vm
RP29_HX02@29_HX00`21ZH40M:=f07BSMP0407BSMP<0PJV1^@2`h>H10?ooo`00^`2`h>H4086YP@@0
PKB>00<0PJV109;:W02BbY`02@2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2QfjD0XM^U0100
XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0?09kGW`03086YP@2FcIL0U/fG00`0
U/fG00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f07BSMP0207BSMP@0PJV1^`2`h>H10?ooo`00
_@2`h>H6086YP@03086dSP21ZH40T/ZL00X0T/ZL00<0PJV109cFX`2LeZ<02`2LeZ<00`21ZH40XM^U
0:7KY@0?0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil03`2Neil00`21ZH40U/fG
09K=U`0;09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BSMP21ZH401@21ZH6m0;3PiP40oooo
002n0;3PiP<0PJV10P1`X7l6086YP@L0T/ZL00<0PJV109cFX`2LeZ<02`2LeZ<00`21ZH40XM^U0:7K
Y@0?0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil03P2Neil00`21ZH40U/fG09K=
U`0<09K=U`03086YP@29_HX0RKf:00D0RKf:1P21ZH4206FBK0<0PJV1_P2`h>H10?ooo`00`02`h>H3
086YP@<0L:1o0P21ZH400`22]hh0PJV1086YP@04086YP@80T/ZL00<0PJV109cFX`2LeZ<02`2LeZ<0
0`21ZH40XM^U0:7KY@0>0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil03P2Neil0
0`21ZH40U/fG09K=U`0;09K=U`03086YP@29_HX0RKf:00H0PJV100<0NJao086YP@21ZH400`1UTV`3
086YPL00/>3V0@3oool00<80/>3V0`21ZH43072PO`80PJV11@22]hh:086YP@H0W=JS00<0PJV10:7K
Y@2QfjD03`2QfjD00`21ZH40XM^T0:7KY00=0:7KY003086YP@2Neil0W]NO00h0W]NO00<0PJV109K=
U`2FcIL01@2FcIL:086YP@D0NJao0P21ZH4306FBK0<0PJV1`P2`h>H10?ooo`00a02`h>H3086YP@<0
L:1o00<0PJV108:gSP22]hh01P22]hh2086YP@@0SLBG4021ZH480:7KY@03086YP@2Qfj@0XM^T00d0
XM^T00<0PJV109kGW`2Neil01P2Neil@086YP@@0Qkf=0P21ZH4807V/O`04086YP@1UTV`0II9/06FB
K0<0PJV1a02`h>H10?ooo`00aP2`h>H3086YP@80L:1o0P21ZH4808:gSP03086YP@2=a9L0SLBG00T0
SLBG00<0PJV109;;VP2BbiX01@2BbiXQ086YP@L0SlNE00<0PJV108NmS@27_Hd02@27_Hd00`21ZH40
NJao07V/O`0607V/O`80PJV10P1UTV`3086YPLH0/>3V0@3oool00<P0/>3V0`21ZH42072PO`03086Y
P@22]hh0P[N>00H0P[N>00<0PJV108g4U`2=a9L02@2=a9L00`21ZH40T/^J09;;VP0<09;;VP03086Y
P@2Cc9X0TlbJ00d0TlbJ00<0PJV108o7U@2?aiD0302?aiD00`21ZH40Qkf=08NmS@0908NmS@03086Y
P@1i[7l0NJao00H0NJao00<0PJV106FBK01UTV`00`21ZH780;3PiP40oooo003:0;3PiP<0PJV100<0
L:1o086YP@21ZH401`22]hh2086YP@X0SLBG00<0PJV109;;VP2BbiX0302BbiX00`21ZH40TlbJ09?<
VP0;09?<VP03086YP@2?aiD0SlNE00`0SlNE00<0PJV108NmS@27_Hd02027_Hd2086YP@L0NJao0P21
ZH40101UTV`0PJV1086YP@21ZH7:0;3PiP40oooo003=0;3PiPD0PJV11`22]hh00`21ZH40SLBG08g4
U`0708g4U`03086YP@2BbiX0T/^J00`0T/^J00<0PJV109?<VP2Cc9X02`2Cc9X00`21ZH40SlNE08o7
U@0;08o7U@03086YP@27_Hd0Qkf=00P0Qkf=00<0PJV107V/O`1i[7l01@1i[7l5086YPLd0/>3V0@3o
ool00=00/>3V1`21ZH4308:gSP80PJV1202=a9L00`21ZH40T/^J09;;VP0;09;;VP03086YP@2Cc9X0
TlbJ00/0TlbJ00<0PJV108o7U@2?aiD02`2?aiD00`21ZH40Qkf=08NmS@0608NmS@80PJV10`1i[7l7
086YPM00/>3V0@3oool00=<0/>3V3021ZH4608g4U`03086YP@2BbiX0T/^J00X0T/^J00<0PJV109?<
VP2Cc9X02`2Cc9X00`21ZH40SlNE08o7U@0:08o7U@03086YP@27_Hd0Qkf=00@0Qkf=2021ZH40101Q
SV/0PJV1086YP@21ZH7C0;3PiP40oooo003F0;3PiPD0PJV10P1WUgL8086YP@0308g4U`21ZH40T/^J
00/0T/^J00<0PJV109?<VP2Cc9X02@2Cc9X00`21ZH40SlNE08o7U@0:08o7U@03086YP@27_Hd0PJV1
00L0PJV1101QSV/3086YPMH0/>3V0@3oool00=T0/>3V1@21ZH400`1WUgL0PJV1086YP@04076TObT0
PJV1101]WWL2086YP@80HHi[1021ZH7I0;3PiP40oooo003M0;3PiPH0PJV11@1aY7l2086YP@T0Mj^3
00<0PJV107R/P`1h[8<0201h[8<00`21ZH40MJQo07FXO`0807FXO`80PJV11@1]WWL2086YP@04066>
J`21ZH40PJV1086YPMd0/>3V0@3oool00>40/>3V1021ZH45076TO`80PJV1201gZh<00`21ZH40N:b3
07R/P`0707R/P`03086YP@1eZ7l0MJQo00H0MJQo0P21ZH4506fNM`@0PJV1h@2`h>H10?ooo`00i@2`
h>H<086YP@<0Mj^300<0PJV107R/P`1h[8<01P1h[8<00`21ZH40MJQo07FXO`0207FXO``0PJV1i@2`
h>H10?ooo`00l02`h>HC086YPO00/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.605 .777 .566 r
.4503 .46959 m .4498 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.605 .777 .566 r
.48991 .5 m .49001 .46977 L .4503 .46959 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.49001 .53023 m .48991 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.49001 .46977 m .48991 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.48991 .5 m .49001 .53023 L .52992 .53029 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.52992 .53029 m .53022 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.53022 .5 m .52992 .46971 L .49001 .46977 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.52992 .46971 m .53022 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.53022 .5 m .52992 .53029 L .56922 .53059 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.56922 .53059 m .56993 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.45183 .43953 m .4503 .46959 L .49001 .46977 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.49001 .46977 m .49032 .43988 L .45183 .43953 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.4498 .5 m .4503 .53041 L .49001 .53023 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.49032 .56012 m .49001 .53023 L .4503 .53041 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.49032 .43988 m .49001 .46977 L .52992 .46971 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.49001 .53023 m .49032 .56012 L .529 .56024 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.529 .56024 m .52992 .53029 L .49001 .53023 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.52992 .46971 m .529 .43976 L .49032 .43988 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.529 .43976 m .52992 .46971 L .56922 .46941 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.56993 .5 m .56922 .46941 L .52992 .46971 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.52992 .53029 m .529 .56024 L .56709 .56082 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.56709 .56082 m .56922 .53059 L .52992 .53029 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.41161 .46916 m .41069 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.4498 .5 m .4503 .46959 L .41161 .46916 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.4503 .53041 m .4498 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.41436 .43871 m .41161 .46916 L .4503 .46959 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.4503 .46959 m .45183 .43953 L .41436 .43871 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.41069 .5 m .41161 .53084 L .4503 .53041 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.45183 .56047 m .4503 .53041 L .41161 .53084 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.4503 .53041 m .45183 .56047 L .49032 .56012 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54394 .45077 m
.54696 .45169 L
s
.54058 .44731 m
.54155 .44901 L
s
.5 Mabswid
.631 .82 .6 r
.45437 .41018 m .45183 .43953 L .49032 .43988 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.49032 .43988 m .49082 .41067 L .45437 .41018 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.49082 .41067 m .49032 .43988 L .529 .43976 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.49082 .58933 m .49032 .56012 L .45183 .56047 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.49032 .56012 m .49082 .58933 L .52748 .58949 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.52748 .58949 m .529 .56024 L .49032 .56012 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54696 .45169 m
.55158 .45163 L
s
.5 Mabswid
.636 .827 .609 r
.529 .43976 m .52748 .41051 L .49082 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.52748 .41051 m .529 .43976 L .56709 .43918 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.56922 .46941 m .56709 .43918 L .529 .43976 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.529 .56024 m .52748 .58949 L .56352 .59032 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.56352 .59032 m .56709 .56082 L .529 .56024 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.56922 .46941 m .56993 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.56993 .5 m .56922 .53059 L .60709 .53114 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.60709 .53114 m .60821 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.56709 .43918 m .56922 .46941 L .60709 .46886 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.60821 .5 m .60709 .46886 L .56922 .46941 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.56922 .53059 m .56709 .56082 L .60373 .56188 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.60373 .56188 m .60709 .53114 L .56922 .53059 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.41894 .40902 m .41436 .43871 L .45183 .43953 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.45183 .43953 m .45437 .41018 L .41894 .40902 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.41161 .53084 m .41436 .56129 L .45183 .56047 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.45437 .58982 m .45183 .56047 L .41436 .56129 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.45183 .56047 m .45437 .58982 L .49082 .58933 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.37481 .46849 m .37348 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.41069 .5 m .41161 .46916 L .37481 .46849 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.41161 .53084 m .41069 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.45794 .38193 m .45437 .41018 L .49082 .41067 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.49082 .41067 m .49154 .38253 L .45794 .38193 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.49154 .38253 m .49082 .41067 L .52748 .41051 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.49154 .61747 m .49082 .58933 L .45437 .58982 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.49082 .58933 m .49154 .61747 L .52534 .61767 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.52534 .61767 m .52748 .58949 L .49082 .58933 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.56709 .43918 m .56352 .40968 L .52748 .41051 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.56352 .40968 m .56709 .43918 L .60373 .43812 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.56723 .43917 m
.56724 .43929 L
s
.5 Mabswid
.624 .807 .602 r
.60709 .46886 m .60373 .43812 L .56709 .43918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.56709 .56082 m .56352 .59032 L .59813 .5918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.59813 .5918 m .60373 .56188 L .56709 .56082 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.37878 .43741 m .37481 .46849 L .41161 .46916 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.41161 .46916 m .41436 .43871 L .37878 .43741 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.37348 .5 m .37481 .53151 L .41161 .53084 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.41436 .56129 m .41161 .53084 L .37481 .53151 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.52748 .41051 m .52534 .38233 L .49154 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.52534 .38233 m .52748 .41051 L .56352 .40968 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.52748 .58949 m .52534 .61767 L .55853 .61867 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.55853 .61867 m .56352 .59032 L .52748 .58949 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.42535 .38053 m .41894 .40902 L .45437 .41018 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.45437 .41018 m .45794 .38193 L .42535 .38053 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.41436 .56129 m .41894 .59098 L .45437 .58982 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.45794 .61807 m .45437 .58982 L .41894 .59098 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.45437 .58982 m .45794 .61807 L .49154 .61747 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.38539 .40721 m .37878 .43741 L .41436 .43871 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.41436 .43871 m .41894 .40902 L .38539 .40721 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.37481 .53151 m .37878 .56259 L .41436 .56129 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.41894 .59098 m .41436 .56129 L .37878 .56259 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.60709 .46886 m .60821 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.60821 .5 m .60709 .53114 L .64258 .53194 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.64258 .53194 m .64411 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.56352 .40968 m .55853 .38133 L .52534 .38233 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.55853 .38133 m .56352 .40968 L .59813 .4082 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.60373 .43812 m .59813 .4082 L .56352 .40968 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.56352 .59032 m .55853 .61867 L .59031 .62047 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.59031 .62047 m .59813 .5918 L .56352 .59032 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.60373 .43812 m .60709 .46886 L .64258 .46806 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.64411 .5 m .64258 .46806 L .60709 .46886 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.60709 .53114 m .60373 .56188 L .63799 .56341 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.63799 .56341 m .64258 .53194 L .60709 .53114 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.46253 .35521 m .45794 .38193 L .49154 .38253 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.49154 .38253 m .49246 .35586 L .46253 .35521 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.49246 .64414 m .49154 .61747 L .45794 .61807 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.49246 .35586 m .49154 .38253 L .52534 .38233 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.49154 .61747 m .49246 .64414 L .52258 .64436 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.52258 .64436 m .52534 .61767 L .49154 .61747 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.52534 .38233 m .52258 .35564 L .49246 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.52258 .35564 m .52534 .38233 L .55853 .38133 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.52534 .61767 m .52258 .64436 L .55212 .64545 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.55212 .64545 m .55853 .61867 L .52534 .61767 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.59813 .4082 m .60373 .43812 L .63799 .43659 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.60651 .43799 m
.60691 .44057 L
s
.5 Mabswid
.617 .799 .601 r
.64258 .46806 m .63799 .43659 L .60373 .43812 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.60373 .56188 m .59813 .5918 L .63037 .59394 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.63037 .59394 m .63799 .56341 L .60373 .56188 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.39462 .37834 m .38539 .40721 L .41894 .40902 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.41894 .40902 m .42535 .38053 L .39462 .37834 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.37878 .56259 m .38539 .59279 L .41894 .59098 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.42535 .61947 m .41894 .59098 L .38539 .59279 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.41894 .59098 m .42535 .61947 L .45794 .61807 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.43357 .35368 m .42535 .38053 L .45794 .38193 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.45794 .38193 m .46253 .35521 L .43357 .35368 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.46253 .64479 m .45794 .61807 L .42535 .61947 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.45794 .61807 m .46253 .64479 L .49246 .64414 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.3409 .46758 m .33917 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.37348 .5 m .37481 .46849 L .3409 .46758 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.37481 .53151 m .37348 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.3461 .43565 m .3409 .46758 L .37481 .46849 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.37481 .46849 m .37878 .43741 L .3461 .43565 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.33917 .5 m .3409 .53242 L .37481 .53151 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.37878 .56259 m .37481 .53151 L .3409 .53242 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.55853 .38133 m .55212 .35455 L .52258 .35564 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.55212 .35455 m .55853 .38133 L .59031 .37953 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.59813 .4082 m .59031 .37953 L .55853 .38133 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.55853 .61867 m .55212 .64545 L .58028 .6474 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.58028 .6474 m .59031 .62047 L .55853 .61867 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.59031 .37953 m .59813 .4082 L .63037 .40606 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.63799 .43659 m .63037 .40606 L .59813 .4082 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.59813 .5918 m .59031 .62047 L .61975 .62304 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.61975 .62304 m .63037 .59394 L .59813 .5918 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.35472 .40475 m .3461 .43565 L .37878 .43741 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.37878 .43741 m .38539 .40721 L .35472 .40475 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.3409 .53242 m .3461 .56435 L .37878 .56259 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.38539 .59279 m .37878 .56259 L .3461 .56435 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.40642 .3513 m .39462 .37834 L .42535 .38053 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.42535 .38053 m .43357 .35368 L .40642 .3513 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.38539 .59279 m .39462 .62166 L .42535 .61947 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.43357 .64632 m .42535 .61947 L .39462 .62166 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.42535 .61947 m .43357 .64632 L .46253 .64479 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.64258 .46806 m .64411 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.64411 .5 m .64258 .53194 L .6746 .53297 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.6746 .53297 m .67654 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.46813 .3305 m .46253 .35521 L .49246 .35586 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.49246 .35586 m .49358 .33115 L .46813 .3305 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.49358 .33115 m .49246 .35586 L .52258 .35564 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.49358 .66885 m .49246 .64414 L .46253 .64479 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.49246 .64414 m .49358 .66885 L .51922 .66907 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.51922 .66907 m .52258 .64436 L .49246 .64414 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.52258 .35564 m .51922 .33093 L .49358 .33115 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.51922 .33093 m .52258 .35564 L .55212 .35455 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.52258 .64436 m .51922 .66907 L .5443 .67015 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.5443 .67015 m .55212 .64545 L .52258 .64436 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.63799 .43659 m .64258 .46806 L .6746 .46703 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.67654 .5 m .6746 .46703 L .64258 .46806 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.64258 .53194 m .63799 .56341 L .66881 .5654 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.66881 .5654 m .6746 .53297 L .64258 .53194 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.3667 .37538 m .35472 .40475 L .38539 .40721 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.38539 .40721 m .39462 .37834 L .3667 .37538 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.3461 .56435 m .35472 .59525 L .38539 .59279 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.39462 .62166 m .38539 .59279 L .35472 .59525 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.63566 .42725 m
.6359 .42705 L
s
.5 Mabswid
.646 .857 .63 r
.44359 .32898 m .43357 .35368 L .46253 .35521 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.46253 .35521 m .46813 .3305 L .44359 .32898 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.46813 .6695 m .46253 .64479 L .43357 .64632 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.46253 .64479 m .46813 .6695 L .49358 .66885 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.59031 .37953 m .58028 .3526 L .55212 .35455 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.58028 .3526 m .59031 .37953 L .61975 .37696 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.63037 .40606 m .61975 .37696 L .59031 .37953 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.59031 .62047 m .58028 .6474 L .60621 .6502 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.60621 .6502 m .61975 .62304 L .59031 .62047 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.63037 .40606 m .63799 .43659 L .66881 .4346 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.6746 .46703 m .66881 .4346 L .63799 .43659 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.63799 .56341 m .63037 .59394 L .65921 .59672 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.65921 .59672 m .66881 .5654 L .63799 .56341 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.55212 .35455 m .5443 .32985 L .51922 .33093 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.5443 .32985 m .55212 .35455 L .58028 .3526 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.55212 .64545 m .5443 .67015 L .5681 .67209 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.5681 .67209 m .58028 .6474 L .55212 .64545 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.42073 .32662 m .40642 .3513 L .43357 .35368 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.43357 .35368 m .44359 .32898 L .42073 .32662 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.39462 .62166 m .40642 .6487 L .43357 .64632 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.44359 .67102 m .43357 .64632 L .40642 .6487 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.43357 .64632 m .44359 .67102 L .46813 .6695 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.61975 .37696 m .63037 .40606 L .65921 .40328 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.66881 .4346 m .65921 .40328 L .63037 .40606 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.63037 .59394 m .61975 .62304 L .64589 .62639 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.64589 .62639 m .65921 .59672 L .63037 .59394 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.31108 .46642 m .30894 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.33917 .5 m .3409 .46758 L .31108 .46642 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.3409 .53242 m .33917 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.38195 .34809 m .3667 .37538 L .39462 .37834 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.39462 .37834 m .40642 .3513 L .38195 .34809 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.35472 .59525 m .3667 .62462 L .39462 .62166 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.40642 .6487 m .39462 .62166 L .3667 .62462 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.31746 .43343 m .31108 .46642 L .3409 .46758 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.3409 .46758 m .3461 .43565 L .31746 .43343 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.30894 .5 m .31108 .53358 L .3409 .53242 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.3461 .56435 m .3409 .53242 L .31108 .53358 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.32801 .40165 m .31746 .43343 L .3461 .43565 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.3461 .43565 m .35472 .40475 L .32801 .40165 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.31108 .53358 m .31746 .56657 L .3461 .56435 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.35472 .59525 m .3461 .56435 L .31746 .56657 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.58028 .3526 m .5681 .32791 L .5443 .32985 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.5681 .32791 m .58028 .3526 L .60621 .3498 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.61975 .37696 m .60621 .3498 L .58028 .3526 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58028 .6474 m .5681 .67209 L .58983 .67486 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58983 .67486 m .60621 .6502 L .58028 .6474 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.47472 .30833 m .46813 .3305 L .49358 .33115 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.49358 .33115 m .4949 .30892 L .47472 .30833 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.4949 .30892 m .49358 .33115 L .51922 .33093 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.4949 .69108 m .49358 .66885 L .46813 .6695 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.49358 .66885 m .4949 .69108 L .51525 .69128 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.51525 .69128 m .51922 .66907 L .49358 .66885 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.51922 .33093 m .51525 .30872 L .4949 .30892 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.51525 .30872 m .51922 .33093 L .5443 .32985 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.51922 .66907 m .51525 .69128 L .5351 .69225 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.5351 .69225 m .5443 .67015 L .51922 .66907 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.60621 .3498 m .61975 .37696 L .64589 .37361 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.65921 .40328 m .64589 .37361 L .61975 .37696 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.61975 .62304 m .60621 .6502 L .62899 .65381 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.62899 .65381 m .64589 .62639 L .61975 .62304 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.45535 .30698 m .44359 .32898 L .46813 .3305 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.46813 .3305 m .47472 .30833 L .45535 .30698 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.47472 .69167 m .46813 .6695 L .44359 .67102 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.46813 .6695 m .47472 .69167 L .4949 .69108 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.34262 .37167 m .32801 .40165 L .35472 .40475 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.35472 .40475 m .3667 .37538 L .34262 .37167 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.31746 .56657 m .32801 .59835 L .35472 .59525 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.3667 .62462 m .35472 .59525 L .32801 .59835 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.3667 .62462 m .38195 .65191 L .40642 .6487 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.42073 .67338 m .40642 .6487 L .38195 .65191 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.40642 .6487 m .42073 .67338 L .44359 .67102 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40032 .32347 m .38195 .34809 L .40642 .3513 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40642 .3513 m .42073 .32662 L .40032 .32347 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.5443 .32985 m .5351 .30775 L .51525 .30872 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5351 .30775 m .5443 .32985 L .5681 .32791 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.5443 .67015 m .5351 .69225 L .55383 .69398 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.55383 .69398 m .5681 .67209 L .5443 .67015 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.6746 .46703 m .67654 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.67654 .5 m .6746 .53297 L .70188 .53425 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.70188 .53425 m .70421 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.66881 .4346 m .6746 .46703 L .70188 .46575 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.70421 .5 m .70188 .46575 L .6746 .46703 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.6746 .53297 m .66881 .5654 L .69493 .56784 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.69493 .56784 m .70188 .53425 L .6746 .53297 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.43743 .30488 m .42073 .32662 L .44359 .32898 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.44359 .32898 m .45535 .30698 L .43743 .30488 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.45535 .69302 m .44359 .67102 L .42073 .67338 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.44359 .67102 m .45535 .69302 L .47472 .69167 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.65921 .40328 m .66881 .4346 L .69493 .43216 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.70188 .46575 m .69493 .43216 L .66881 .4346 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.66881 .5654 m .65921 .59672 L .68346 .60013 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.68346 .60013 m .69493 .56784 L .66881 .5654 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3611 .34411 m .34262 .37167 L .3667 .37538 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3667 .37538 m .38195 .34809 L .3611 .34411 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.32801 .59835 m .34262 .62833 L .3667 .62462 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.38195 .65191 m .3667 .62462 L .34262 .62833 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.60621 .3498 m .58983 .32514 L .5681 .32791 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.58983 .32514 m .60621 .3498 L .62899 .34619 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.64589 .37361 m .62899 .34619 L .60621 .3498 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.60621 .6502 m .58983 .67486 L .6087 .6784 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.6087 .6784 m .62899 .65381 L .60621 .6502 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5681 .32791 m .55383 .30602 L .5351 .30775 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.55383 .30602 m .5681 .32791 L .58983 .32514 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.5681 .67209 m .55383 .69398 L .57077 .69644 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.57077 .69644 m .58983 .67486 L .5681 .67209 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.64589 .37361 m .65921 .40328 L .68346 .39987 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.69493 .43216 m .68346 .39987 L .65921 .40328 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.65921 .59672 m .64589 .62639 L .66762 .63045 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.66762 .63045 m .68346 .60013 L .65921 .59672 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42163 .30208 m .40032 .32347 L .42073 .32662 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42073 .32662 m .43743 .30488 L .42163 .30208 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.38195 .65191 m .40032 .67653 L .42073 .67338 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.43743 .69512 m .42073 .67338 L .40032 .67653 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.42073 .67338 m .43743 .69512 L .45535 .69302 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.28671 .46503 m .2842 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.30894 .5 m .31108 .46642 L .28671 .46503 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.31108 .53358 m .30894 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.48228 .28932 m .47472 .30833 L .4949 .30892 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.4949 .30892 m .49643 .28977 L .48228 .28932 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.49643 .28977 m .4949 .30892 L .51525 .30872 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.49643 .71023 m .4949 .69108 L .47472 .69167 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.4949 .69108 m .49643 .71023 L .51069 .71038 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51069 .71038 m .51525 .69128 L .4949 .69108 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.2942 .43077 m .28671 .46503 L .31108 .46642 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.31108 .46642 m .31746 .43343 L .2942 .43077 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.2842 .5 m .28671 .53497 L .31108 .53358 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.31746 .56657 m .31108 .53358 L .28671 .53497 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.51525 .30872 m .51069 .28962 L .49643 .28977 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.51069 .28962 m .51525 .30872 L .5351 .30775 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.51525 .69128 m .51069 .71038 L .52458 .71113 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.52458 .71113 m .5351 .69225 L .51525 .69128 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.34262 .62833 m .3611 .65589 L .38195 .65191 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.40032 .67653 m .38195 .65191 L .3611 .65589 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.3832 .31957 m .3611 .34411 L .38195 .34809 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.38195 .34809 m .40032 .32347 L .3832 .31957 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.62899 .34619 m .64589 .37361 L .66762 .36955 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.68346 .39987 m .66762 .36955 L .64589 .37361 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64589 .62639 m .62899 .65381 L .64765 .65816 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64765 .65816 m .66762 .63045 L .64589 .62639 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.46877 .28827 m .45535 .30698 L .47472 .30833 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.47472 .30833 m .48228 .28932 L .46877 .28827 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.48228 .71068 m .47472 .69167 L .45535 .69302 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47472 .69167 m .48228 .71068 L .49643 .71023 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.30655 .39796 m .2942 .43077 L .31746 .43343 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.31746 .43343 m .32801 .40165 L .30655 .39796 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.28671 .53497 m .2942 .56923 L .31746 .56657 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.32801 .59835 m .31746 .56657 L .2942 .56923 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.5351 .30775 m .52458 .28887 L .51069 .28962 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.52458 .28887 m .5351 .30775 L .55383 .30602 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5351 .69225 m .52458 .71113 L .5376 .71246 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5376 .71246 m .55383 .69398 L .5351 .69225 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.58983 .32514 m .57077 .30356 L .55383 .30602 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.57077 .30356 m .58983 .32514 L .6087 .3216 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.62899 .34619 m .6087 .3216 L .58983 .32514 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58983 .67486 m .57077 .69644 L .58528 .69956 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58528 .69956 m .6087 .6784 L .58983 .67486 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45638 .28667 m .43743 .30488 L .45535 .30698 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45535 .30698 m .46877 .28827 L .45638 .28667 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32354 .36727 m .30655 .39796 L .32801 .40165 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32801 .40165 m .34262 .37167 L .32354 .36727 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.2942 .56923 m .30655 .60204 L .32801 .59835 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.34262 .62833 m .32801 .59835 L .30655 .60204 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.46877 .71173 m .45535 .69302 L .43743 .69512 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.45535 .69302 m .46877 .71173 L .48228 .71068 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.6087 .3216 m .62899 .34619 L .64765 .34184 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.66762 .36955 m .64765 .34184 L .62899 .34619 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62899 .65381 m .6087 .6784 L .62388 .68263 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62388 .68263 m .64765 .65816 L .62899 .65381 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.55383 .30602 m .5376 .28754 L .52458 .28887 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.5376 .28754 m .55383 .30602 L .57077 .30356 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.55383 .69398 m .5376 .71246 L .54924 .71433 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.54924 .71433 m .57077 .69644 L .55383 .69398 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40859 .29866 m .3832 .31957 L .40032 .32347 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40032 .32347 m .42163 .30208 L .40859 .29866 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.3611 .65589 m .3832 .68043 L .40032 .67653 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.42163 .69792 m .40032 .67653 L .3832 .68043 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.40032 .67653 m .42163 .69792 L .43743 .69512 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34488 .33941 m .32354 .36727 L .34262 .37167 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34262 .37167 m .3611 .34411 L .34488 .33941 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.30655 .60204 m .32354 .63273 L .34262 .62833 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.3611 .65589 m .34262 .62833 L .32354 .63273 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69518 .4324 m
.69609 .43578 L
s
.69609 .43578 m
.6983 .44071 L
s
.5 Mabswid
.492 .637 .5 r
.70188 .46575 m .70421 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.70421 .5 m .70188 .53425 L .72294 .53575 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.72294 .53575 m .72562 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.69493 .43216 m .70188 .46575 L .72294 .46425 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69464 .42717 m
.69518 .4324 L
s
.5 Mabswid
.492 .637 .5 r
.72562 .5 m .72294 .46425 L .70188 .46575 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.70188 .53425 m .69493 .56784 L .71494 .57071 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.71494 .57071 m .72294 .53575 L .70188 .53425 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.4456 .28455 m .42163 .30208 L .43743 .30488 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.43743 .30488 m .45638 .28667 L .4456 .28455 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45638 .71333 m .43743 .69512 L .42163 .69792 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.43743 .69512 m .45638 .71333 L .46877 .71173 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.68346 .39987 m .69493 .43216 L .71494 .42929 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.72294 .46425 m .71494 .42929 L .69493 .43216 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.69493 .56784 m .68346 .60013 L .70178 .6041 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.70178 .6041 m .71494 .57071 L .69493 .56784 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.37018 .31502 m .34488 .33941 L .3611 .34411 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.3611 .34411 m .3832 .31957 L .37018 .31502 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.32354 .63273 m .34488 .66059 L .3611 .65589 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.3832 .68043 m .3611 .65589 L .34488 .66059 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.57077 .30356 m .54924 .28567 L .5376 .28754 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.54924 .28567 m .57077 .30356 L .58528 .30044 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.6087 .3216 m .58528 .30044 L .57077 .30356 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.57077 .69644 m .54924 .71433 L .55905 .71669 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.55905 .71669 m .58528 .69956 L .57077 .69644 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.58528 .30044 m .6087 .3216 L .62388 .31737 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.64765 .34184 m .62388 .31737 L .6087 .3216 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.6087 .6784 m .58528 .69956 L .59668 .70325 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.59668 .70325 m .62388 .68263 L .6087 .6784 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.66762 .36955 m .68346 .39987 L .70178 .3959 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.71494 .42929 m .70178 .3959 L .68346 .39987 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68346 .60013 m .66762 .63045 L .68373 .63515 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68373 .63515 m .70178 .6041 L .68346 .60013 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49074 .27412 m .48228 .28932 L .49643 .28977 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49643 .28977 m .49813 .27437 L .49074 .27412 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.49813 .27437 m .49643 .28977 L .51069 .28962 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49813 .72563 m .49643 .71023 L .48228 .71068 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49643 .71023 m .49813 .72563 L .50559 .72571 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.50559 .72571 m .51069 .71038 L .49643 .71023 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.51069 .28962 m .50559 .27429 L .49813 .27437 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.50559 .27429 m .51069 .28962 L .52458 .28887 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51069 .71038 m .50559 .72571 L .51284 .72613 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51284 .72613 m .52458 .71113 L .51069 .71038 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48372 .27353 m .46877 .28827 L .48228 .28932 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48228 .28932 m .49074 .27412 L .48372 .27353 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.49074 .72588 m .48228 .71068 L .46877 .71173 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.48228 .71068 m .49074 .72588 L .49813 .72563 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.64765 .34184 m .66762 .36955 L .68373 .36485 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.70178 .3959 m .68373 .36485 L .66762 .36955 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66762 .63045 m .64765 .65816 L .66116 .66317 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66116 .66317 m .68373 .63515 L .66762 .63045 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.52458 .28887 m .51284 .27387 L .50559 .27429 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.51284 .27387 m .52458 .28887 L .5376 .28754 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.52458 .71113 m .51284 .72613 L .51957 .72688 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.51957 .72688 m .5376 .71246 L .52458 .71113 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.43688 .28198 m .40859 .29866 L .42163 .30208 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.42163 .30208 m .4456 .28455 L .43688 .28198 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.3832 .68043 m .40859 .70134 L .42163 .69792 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.4456 .71545 m .42163 .69792 L .40859 .70134 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.42163 .69792 m .4456 .71545 L .45638 .71333 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.47734 .27264 m .45638 .28667 L .46877 .28827 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.46877 .28827 m .48372 .27353 L .47734 .27264 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.48372 .72647 m .46877 .71173 L .45638 .71333 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.46877 .71173 m .48372 .72647 L .49074 .72588 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.39896 .29471 m .37018 .31502 L .3832 .31957 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.3832 .31957 m .40859 .29866 L .39896 .29471 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.34488 .66059 m .37018 .68498 L .3832 .68043 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.40859 .70134 m .3832 .68043 L .37018 .68498 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.5376 .28754 m .51957 .27312 L .51284 .27387 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.51957 .27312 m .5376 .28754 L .54924 .28567 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.5376 .71246 m .51957 .72688 L .52552 .72791 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.52552 .72791 m .54924 .71433 L .5376 .71246 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.26939 .46342 m .26655 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.2842 .5 m .28671 .46503 L .26939 .46342 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.28671 .53497 m .2842 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.27785 .42772 m .26939 .46342 L .28671 .46503 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.28671 .46503 m .2942 .43077 L .27785 .42772 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.26655 .5 m .26939 .53658 L .28671 .53497 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.2942 .56923 m .28671 .53497 L .26939 .53658 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.62388 .31737 m .64765 .34184 L .66116 .33683 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.68373 .36485 m .66116 .33683 L .64765 .34184 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.64765 .65816 m .62388 .68263 L .63452 .68746 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.63452 .68746 m .66116 .66317 L .64765 .65816 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.58528 .30044 m .55905 .28331 L .54924 .28567 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.55905 .28331 m .58528 .30044 L .59668 .29675 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.62388 .31737 m .59668 .29675 L .58528 .30044 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.58528 .69956 m .55905 .71669 L .56657 .71945 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.56657 .71945 m .59668 .70325 L .58528 .69956 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.29173 .39373 m .27785 .42772 L .2942 .43077 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.2942 .43077 m .30655 .39796 L .29173 .39373 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.26939 .53658 m .27785 .57228 L .2942 .56923 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.30655 .60204 m .2942 .56923 L .27785 .57228 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.47187 .27147 m .4456 .28455 L .45638 .28667 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.45638 .28667 m .47734 .27264 L .47187 .27147 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.47734 .72736 m .45638 .71333 L .4456 .71545 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.45638 .71333 m .47734 .72736 L .48372 .72647 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72044 .45334 m
.72131 .4553 L
s
.5 Mabswid
.448 .603 .42 r
.31071 .36228 m .29173 .39373 L .30655 .39796 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.30655 .39796 m .32354 .36727 L .31071 .36228 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.27785 .57228 m .29173 .60627 L .30655 .60204 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.32354 .63273 m .30655 .60204 L .29173 .60627 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.54924 .28567 m .52552 .27209 L .51957 .27312 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.52552 .27209 m .54924 .28567 L .55905 .28331 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.54924 .71433 m .52552 .72791 L .53045 .7292 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.53045 .7292 m .55905 .71669 L .54924 .71433 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.59668 .29675 m .62388 .31737 L .63452 .31254 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.66116 .33683 m .63452 .31254 L .62388 .31737 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.62388 .68263 m .59668 .70325 L .60439 .70742 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.60439 .70742 m .63452 .68746 L .62388 .68263 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.33435 .33413 m .31071 .36228 L .32354 .36727 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.32354 .36727 m .34488 .33941 L .33435 .33413 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.29173 .60627 m .31071 .63772 L .32354 .63273 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.34488 .66059 m .32354 .63273 L .31071 .63772 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.43065 .27904 m .39896 .29471 L .40859 .29866 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.40859 .29866 m .43688 .28198 L .43065 .27904 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.37018 .68498 m .39896 .70529 L .40859 .70134 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.43688 .71802 m .40859 .70134 L .39896 .70529 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.40859 .70134 m .43688 .71802 L .4456 .71545 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.46755 .27007 m .43688 .28198 L .4456 .28455 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.4456 .28455 m .47187 .27147 L .46755 .27007 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.47187 .72853 m .4456 .71545 L .43688 .71802 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.4456 .71545 m .47187 .72853 L .47734 .72736 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28288 .58492 m
.283 .5849 L
s
.5 Mabswid
.489 .672 .482 r
.36211 .30995 m .33435 .33413 L .34488 .33941 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.34488 .33941 m .37018 .31502 L .36211 .30995 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.31071 .63772 m .33435 .66587 L .34488 .66059 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.37018 .68498 m .34488 .66059 L .33435 .66587 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.55905 .28331 m .53045 .2708 L .52552 .27209 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.53045 .2708 m .55905 .28331 L .56657 .28055 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.59668 .29675 m .56657 .28055 L .55905 .28331 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.55905 .71669 m .53045 .7292 L .53411 .7307 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.53411 .7307 m .56657 .71945 L .55905 .71669 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.56657 .28055 m .59668 .29675 L .60439 .29258 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.63452 .31254 m .60439 .29258 L .59668 .29675 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.59668 .70325 m .56657 .71945 L .57141 .72253 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.57141 .72253 m .60439 .70742 L .59668 .70325 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.72294 .46425 m .72562 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.72562 .5 m .72294 .53575 L .73609 .53744 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.73609 .53744 m .73907 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.555 .774 .585 r
.49813 .27437 m .5 .26345 L .49074 .27412 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50559 .27429 m .5 .26345 L .49813 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49813 .72563 L .49074 .72588 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50559 .72571 L .49813 .72563 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51284 .27387 m .5 .26345 L .50559 .27429 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .51284 .72613 L .50559 .72571 L closepath p F P
.505 .664 .505 r
s
.415 .55 .447 r
.71494 .42929 m .72294 .46425 L .73609 .46256 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.73907 .5 m .73609 .46256 L .72294 .46425 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72294 .53575 m .71494 .57071 L .72724 .57394 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72724 .57394 m .73609 .53744 L .72294 .53575 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.39333 .29036 m .36211 .30995 L .37018 .31502 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.37018 .31502 m .39896 .29471 L .39333 .29036 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.33435 .66587 m .36211 .69005 L .37018 .68498 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.39896 .70529 m .37018 .68498 L .36211 .69005 L p F P
.505 .664 .505 r
s
.552 .77 .582 r
.49074 .27412 m .5 .26345 L .48372 .27353 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .49074 .72588 L .48372 .72647 L closepath p F P
.505 .664 .505 r
s
.444 .597 .482 r
.70178 .3959 m .71494 .42929 L .72724 .42606 L p F P
.505 .664 .505 r
s
.415 .55 .447 r
.73609 .46256 m .72724 .42606 L .71494 .42929 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71494 .57071 m .70178 .6041 L .71274 .60854 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71274 .60854 m .72724 .57394 L .71494 .57071 L p F P
.505 .664 .505 r
s
.553 .772 .586 r
.51957 .27312 m .5 .26345 L .51284 .27387 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .51957 .72688 L .51284 .72613 L closepath p F P
.505 .664 .505 r
s
.544 .757 .564 r
.46458 .26849 m .43065 .27904 L .43688 .28198 L p F P
.505 .664 .505 r
s
.544 .757 .564 r
.43688 .28198 m .46755 .27007 L .46458 .26849 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.39896 .70529 m .43065 .72096 L .43688 .71802 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.46755 .72993 m .43688 .71802 L .43065 .72096 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.43688 .71802 m .46755 .72993 L .47187 .72853 L p F P
.505 .664 .505 r
s
.547 .764 .578 r
.48372 .27353 m .5 .26345 L .47734 .27264 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .48372 .72647 L .47734 .72736 L closepath p F P
.505 .664 .505 r
s
.469 .638 .513 r
.68373 .36485 m .70178 .3959 L .71274 .39146 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.72724 .42606 m .71274 .39146 L .70178 .3959 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.70178 .6041 m .68373 .63515 L .69297 .64039 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.69297 .64039 m .71274 .60854 L .70178 .6041 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27586 .57141 m
.28118 .58046 L
s
.5 Mabswid
.549 .767 .583 r
.52552 .27209 m .5 .26345 L .51957 .27312 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .52552 .72791 L .51957 .72688 L closepath p F P
.505 .664 .505 r
s
.491 .673 .537 r
.66116 .33683 m .68373 .36485 L .69297 .35961 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.71274 .39146 m .69297 .35961 L .68373 .36485 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.68373 .63515 m .66116 .66317 L .66846 .66869 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.66846 .66869 m .69297 .64039 L .68373 .63515 L p F P
.505 .664 .505 r
s
.541 .757 .572 r
.47734 .27264 m .5 .26345 L .47187 .27147 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .47734 .72736 L .47187 .72853 L closepath p F P
.505 .664 .505 r
s
.513 .715 .527 r
.42727 .27585 m .39333 .29036 L .39896 .29471 L p F P
.505 .664 .505 r
s
.513 .715 .527 r
.39896 .29471 m .43065 .27904 L .42727 .27585 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.36211 .69005 m .39333 .70964 L .39896 .70529 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.43065 .72096 m .39896 .70529 L .39333 .70964 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.56657 .28055 m .53411 .2693 L .53045 .2708 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.53411 .2693 m .56657 .28055 L .57141 .27747 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.60439 .29258 m .57141 .27747 L .56657 .28055 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.56657 .71945 m .53411 .7307 L .53635 .73235 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.53635 .73235 m .57141 .72253 L .56657 .71945 L p F P
.505 .664 .505 r
s
.543 .76 .579 r
.53045 .2708 m .5 .26345 L .52552 .27209 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .53045 .7292 L .52552 .72791 L closepath p F P
.505 .664 .505 r
s
.507 .701 .556 r
.63452 .31254 m .66116 .33683 L .66846 .33131 L p F P
.505 .664 .505 r
s
.491 .673 .537 r
.69297 .35961 m .66846 .33131 L .66116 .33683 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.66116 .66317 m .63452 .68746 L .63983 .69272 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.63983 .69272 m .66846 .66869 L .66116 .66317 L p F P
.505 .664 .505 r
s
.533 .748 .565 r
.47187 .27147 m .5 .26345 L .46755 .27007 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .47187 .72853 L .46755 .72993 L closepath p F P
.505 .664 .505 r
s
.518 .721 .567 r
.60439 .29258 m .63452 .31254 L .63983 .30728 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.66846 .33131 m .63983 .30728 L .63452 .31254 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.63452 .68746 m .60439 .70742 L .60783 .71191 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60783 .71191 m .63983 .69272 L .63452 .68746 L p F P
.505 .664 .505 r
s
.535 .751 .573 r
.53411 .2693 m .5 .26345 L .53045 .2708 L closepath p F P
.505 .664 .505 r
s
.184 .192 .146 r
.5 .73655 m .53411 .7307 L .53045 .7292 L closepath p F P
.505 .664 .505 r
s
.517 .725 .541 r
.46311 .26679 m .42727 .27585 L .43065 .27904 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.43065 .27904 m .46458 .26849 L .46311 .26679 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.39333 .70964 m .42727 .72415 L .43065 .72096 L p F P
.505 .664 .505 r
s
.191 .198 .151 r
.46458 .73151 m .43065 .72096 L .42727 .72415 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.43065 .72096 m .46458 .73151 L .46755 .72993 L p F P
.505 .664 .505 r
s
.524 .737 .557 r
.46755 .27007 m .5 .26345 L .46458 .26849 L closepath p F P
.505 .664 .505 r
s
.185 .192 .146 r
.5 .73655 m .46755 .72993 L .46458 .73151 L closepath p F P
.505 .664 .505 r
s
.524 .733 .572 r
.57141 .27747 m .60439 .29258 L .60783 .28809 L p F P
.505 .664 .505 r
s
.518 .721 .567 r
.63983 .30728 m .60783 .28809 L .60439 .29258 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60439 .70742 m .57141 .72253 L .57327 .72581 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57327 .72581 m .60783 .71191 L .60439 .70742 L p F P
.505 .664 .505 r
s
.526 .74 .566 r
.53635 .26765 m .5 .26345 L .53411 .2693 L closepath p F P
.505 .664 .505 r
s
.551 .768 .591 r
.57141 .27747 m .53635 .26765 L .53411 .2693 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .53635 .73235 L .53411 .7307 L closepath p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26084 .46165 m .25775 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26655 .5 m .26939 .46342 L .26084 .46165 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.26939 .53658 m .26655 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.27002 .42434 m .26084 .46165 L .26939 .46342 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.26939 .46342 m .27785 .42772 L .27002 .42434 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.25775 .5 m .26084 .53835 L .26939 .53658 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.27785 .57228 m .26939 .53658 L .26084 .53835 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.26084 .53835 m .27002 .57566 L .27785 .57228 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.29173 .60627 m .27785 .57228 L .27002 .57566 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.28501 .38909 m .27002 .42434 L .27785 .42772 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.27785 .42772 m .29173 .39373 L .28501 .38909 L p F P
.505 .664 .505 r
s
.523 .735 .568 r
.53635 .26765 m .57141 .27747 L .57327 .27419 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.60783 .28809 m .57327 .27419 L .57141 .27747 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57141 .72253 m .53635 .73235 L .53702 .73408 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.53702 .73408 m .57327 .72581 L .57141 .72253 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.30538 .35684 m .28501 .38909 L .29173 .39373 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.29173 .39373 m .31071 .36228 L .30538 .35684 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.27002 .57566 m .28501 .61091 L .29173 .60627 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.31071 .63772 m .29173 .60627 L .28501 .61091 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.33053 .32842 m .30538 .35684 L .31071 .36228 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.31071 .36228 m .33435 .33413 L .33053 .32842 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.28501 .61091 m .30538 .64316 L .31071 .63772 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.33435 .66587 m .31071 .63772 L .30538 .64316 L p F P
.505 .664 .505 r
s
.514 .725 .548 r
.46458 .26849 m .5 .26345 L .46311 .26679 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.42727 .72415 m .46311 .73321 L .46458 .73151 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .46458 .73151 L .46311 .73321 L closepath p F P
.505 .664 .505 r
s
.399 .562 .4 r
.35974 .30454 m .33053 .32842 L .33435 .33413 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.33435 .33413 m .36211 .30995 L .35974 .30454 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.30538 .64316 m .33053 .67158 L .33435 .66587 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.36211 .69005 m .33435 .66587 L .33053 .67158 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.39219 .28577 m .35974 .30454 L .36211 .30995 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.36211 .30995 m .39333 .29036 L .39219 .28577 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.33053 .67158 m .35974 .69546 L .36211 .69005 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39333 .70964 m .36211 .69005 L .35974 .69546 L p F P
.505 .664 .505 r
s
.516 .728 .557 r
.53702 .26592 m .5 .26345 L .53635 .26765 L closepath p F P
.505 .664 .505 r
s
.523 .735 .568 r
.57327 .27419 m .53702 .26592 L .53635 .26765 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .53702 .73408 L .53635 .73235 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.35974 .69546 m .39219 .71423 L .39333 .70964 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.42727 .72415 m .39333 .70964 L .39219 .71423 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.427 .27253 m .39219 .28577 L .39333 .29036 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.39333 .29036 m .42727 .27585 L .427 .27253 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.46325 .26505 m .427 .27253 L .42727 .27585 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.42727 .27585 m .46311 .26679 L .46325 .26505 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39219 .71423 m .427 .72747 L .42727 .72415 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.46311 .73321 m .42727 .72415 L .427 .72747 L p F P
.505 .664 .505 r
s
.504 .712 .539 r
.46311 .26679 m .5 .26345 L .46325 .26505 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.427 .72747 m .46325 .73495 L .46311 .73321 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .46311 .73321 L .46325 .73495 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .46835 .73825 L .47316 .73967 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .46501 .73666 L .46835 .73825 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .46325 .73495 L .46501 .73666 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .53608 .73581 L .53702 .73408 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .53351 .73747 L .53608 .73581 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .52942 .73899 L .53351 .73747 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .52395 .74028 L .52942 .73899 L closepath p F P
.505 .664 .505 r
s
.141 .151 .115 r
.5 .73655 m .51735 .74128 L .52395 .74028 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50992 .74195 L .51735 .74128 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50201 .74224 L .50992 .74195 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .494 .74214 L .50201 .74224 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .48628 .74166 L .494 .74214 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .47923 .74082 L .48628 .74166 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .47316 .73967 L .47923 .74082 L closepath p F P
.505 .664 .505 r
s
.506 .715 .548 r
.53608 .26419 m .5 .26345 L .53702 .26592 L closepath p F P
.505 .664 .505 r
s
.494 .702 .539 r
.53351 .26253 m .5 .26345 L .53608 .26419 L closepath p F P
.505 .664 .505 r
s
.493 .699 .53 r
.46325 .26505 m .5 .26345 L .46501 .26334 L closepath p F P
.505 .664 .505 r
s
.483 .689 .529 r
.52942 .26101 m .5 .26345 L .53351 .26253 L closepath p F P
.505 .664 .505 r
s
.482 .686 .521 r
.46501 .26334 m .5 .26345 L .46835 .26175 L closepath p F P
.505 .664 .505 r
s
.473 .676 .52 r
.52395 .25972 m .5 .26345 L .52942 .26101 L closepath p F P
.505 .664 .505 r
s
.472 .674 .513 r
.46835 .26175 m .5 .26345 L .47316 .26033 L closepath p F P
.505 .664 .505 r
s
.465 .666 .512 r
.51735 .25872 m .5 .26345 L .52395 .25972 L closepath p F P
.505 .664 .505 r
s
.464 .664 .506 r
.47316 .26033 m .5 .26345 L .47923 .25918 L closepath p F P
.505 .664 .505 r
s
.458 .658 .505 r
.50992 .25805 m .5 .26345 L .51735 .25872 L closepath p F P
.505 .664 .505 r
s
.458 .657 .502 r
.47923 .25918 m .5 .26345 L .48628 .25834 L closepath p F P
.505 .664 .505 r
s
.454 .652 .501 r
.50201 .25776 m .5 .26345 L .50992 .25805 L closepath p F P
.505 .664 .505 r
s
.454 .652 .499 r
.48628 .25834 m .5 .26345 L .494 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.494 .25786 m .5 .26345 L .50201 .25776 L closepath p F P
.505 .664 .505 r
s
.49 .695 .54 r
.53702 .26592 m .57327 .27419 L .57192 .27086 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.57192 .27086 m .53608 .26419 L .53702 .26592 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.57327 .72581 m .53702 .73408 L .53608 .73581 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.57327 .27419 m .60783 .28809 L .60658 .28345 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.60658 .28345 m .57192 .27086 L .57327 .27419 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.60783 .71191 m .57327 .72581 L .57192 .72914 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.53608 .73581 m .57192 .72914 L .57327 .72581 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.60783 .28809 m .63983 .30728 L .63911 .30177 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.63911 .30177 m .60658 .28345 L .60783 .28809 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.63983 .69272 m .60783 .71191 L .60658 .71655 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.57192 .72914 m .60658 .71655 L .60783 .71191 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.42999 .73078 m .46501 .73666 L .46325 .73495 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.46325 .73495 m .427 .72747 L .42999 .73078 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.427 .27253 m .46325 .26505 L .46501 .26334 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.63983 .30728 m .66846 .33131 L .66858 .32547 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.66858 .32547 m .63911 .30177 L .63983 .30728 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.66846 .66869 m .63983 .69272 L .63911 .69823 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.60658 .71655 m .63911 .69823 L .63983 .69272 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28027 .60086 m
.28064 .60063 L
s
.5 Mabswid
.369 .523 .433 r
.66846 .33131 m .69297 .35961 L .69409 .35401 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.69409 .35401 m .66858 .32547 L .66846 .33131 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.69297 .64039 m .66846 .66869 L .66858 .67453 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.63911 .69823 m .66858 .67453 L .66846 .66869 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.57192 .72914 m .53608 .73581 L .53351 .73747 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.53608 .26419 m .57192 .27086 L .56728 .26762 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.56728 .26762 m .53351 .26253 L .53608 .26419 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.69297 .35961 m .71274 .39146 L .71485 .38667 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.71485 .38667 m .69409 .35401 L .69297 .35961 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.71274 .60854 m .69297 .64039 L .69409 .64599 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.66858 .67453 m .69409 .64599 L .69297 .64039 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.71274 .39146 m .72724 .42606 L .73019 .42257 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.73019 .42257 m .71485 .38667 L .71274 .39146 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.72724 .57394 m .71274 .60854 L .71485 .61333 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.69409 .64599 m .71485 .61333 L .71274 .60854 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.46501 .26334 m .42999 .26922 L .427 .27253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.39219 .28577 m .427 .27253 L .42999 .26922 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.39589 .71886 m .42999 .73078 L .427 .72747 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.427 .72747 m .39219 .71423 L .39589 .71886 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.72724 .42606 m .73609 .46256 L .7396 .46071 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.7396 .46071 m .73019 .42257 L .72724 .42606 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73609 .53744 m .72724 .57394 L .73019 .57743 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.71485 .61333 m .73019 .57743 L .72724 .57394 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.73609 .46256 m .73907 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.74277 .5 m .7396 .46071 L .73609 .46256 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.73907 .5 m .73609 .53744 L .7396 .53929 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73019 .57743 m .7396 .53929 L .73609 .53744 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.7396 .53929 m .74277 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.43626 .73392 m .46835 .73825 L .46501 .73666 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.46501 .73666 m .42999 .73078 L .43626 .73392 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.42999 .26922 m .46501 .26334 L .46835 .26175 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.53351 .73747 m .56728 .73238 L .57192 .72914 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56728 .73238 m .53351 .73747 L .52942 .73899 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.53351 .26253 m .56728 .26762 L .55944 .26462 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.55944 .26462 m .52942 .26101 L .53351 .26253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.42999 .26922 m .39589 .28114 L .39219 .28577 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.35974 .30454 m .39219 .28577 L .39589 .28114 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.36367 .701 m .39589 .71886 L .39219 .71423 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.39219 .71423 m .35974 .69546 L .36367 .701 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.60658 .71655 m .57192 .72914 L .56728 .73238 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.57192 .27086 m .60658 .28345 L .60039 .27887 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.60039 .27887 m .56728 .26762 L .57192 .27086 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.44561 .73673 m .47316 .73967 L .46835 .73825 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.46835 .73825 m .43626 .73392 L .44561 .73673 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.43626 .26608 m .46835 .26175 L .47316 .26033 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.46835 .26175 m .43626 .26608 L .42999 .26922 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.3343 .67749 m .36367 .701 L .35974 .69546 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.35974 .69546 m .33053 .67158 L .3343 .67749 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.39589 .28114 m .36367 .299 L .35974 .30454 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.33053 .32842 m .35974 .30454 L .36367 .299 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.52942 .73899 m .55944 .73538 L .56728 .73238 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.55944 .73538 m .52942 .73899 L .52395 .74028 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.52942 .26101 m .55944 .26462 L .54866 .26204 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.54866 .26204 m .52395 .25972 L .52942 .26101 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.4577 .73906 m .47923 .74082 L .47316 .73967 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.47316 .73967 m .44561 .73673 L .4577 .73906 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.47316 .26033 m .44561 .26327 L .43626 .26608 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.44561 .26327 m .47316 .26033 L .47923 .25918 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.30873 .64885 m .3343 .67749 L .33053 .67158 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.33053 .67158 m .30538 .64316 L .30873 .64885 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.36367 .299 m .3343 .32251 L .33053 .32842 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.30538 .35684 m .33053 .32842 L .3343 .32251 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.40457 .72332 m .43626 .73392 L .42999 .73078 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.42999 .73078 m .39589 .71886 L .40457 .72332 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.39589 .28114 m .42999 .26922 L .43626 .26608 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2724 .58703 m
.27399 .59097 L
s
.27399 .59097 m
.27621 .59687 L
s
.5 Mabswid
.066 .083 .063 r
.63911 .69823 m .60658 .71655 L .60039 .72113 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.56728 .73238 m .60039 .72113 L .60658 .71655 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.60658 .28345 m .63911 .30177 L .63189 .29627 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.63189 .29627 m .60039 .27887 L .60658 .28345 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26986 .58107 m
.2724 .58703 L
s
.5 Mabswid
.086 .101 .077 r
.52395 .74028 m .54866 .73796 L .55944 .73538 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.54866 .73796 m .52395 .74028 L .51735 .74128 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.52395 .25972 m .54866 .26204 L .5354 .26001 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.5354 .26001 m .51735 .25872 L .52395 .25972 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.3343 .32251 m .30873 .35115 L .30538 .35684 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.28501 .38909 m .30538 .35684 L .30873 .35115 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.28783 .6158 m .30873 .64885 L .30538 .64316 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.30538 .64316 m .28501 .61091 L .28783 .6158 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47197 .74076 m .48628 .74166 L .47923 .74082 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47923 .74082 m .4577 .73906 L .47197 .74076 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.4577 .26094 m .47923 .25918 L .48628 .25834 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.47923 .25918 m .4577 .26094 L .44561 .26327 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.51735 .74128 m .5354 .73999 L .54866 .73796 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.5354 .73999 m .51735 .74128 L .50992 .74195 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.51735 .25872 m .5354 .26001 L .5203 .25865 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.5203 .25865 m .50992 .25805 L .51735 .25872 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.30873 .35115 m .28783 .3842 L .28501 .38909 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.27002 .42434 m .28501 .38909 L .28783 .3842 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.27233 .57924 m .28783 .6158 L .28501 .61091 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.28501 .61091 m .27002 .57566 L .27233 .57924 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27621 .59687 m
.27754 .60098 L
s
.5 Mabswid
.058 .075 .057 r
.60039 .72113 m .56728 .73238 L .55944 .73538 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.56728 .26762 m .60039 .27887 L .58926 .27459 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.58926 .27459 m .55944 .26462 L .56728 .26762 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27754 .60098 m
.27817 .60324 L
s
.5 Mabswid
.312 .474 .374 r
.48771 .74174 m .494 .74214 L .48628 .74166 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48628 .74166 m .47197 .74076 L .48771 .74174 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.48628 .25834 m .47197 .25924 L .4577 .26094 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.47197 .25924 m .48628 .25834 L .494 .25786 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.2628 .54024 m .27233 .57924 L .27002 .57566 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26797 .57716 m
.26986 .58107 L
s
.5 Mabswid
.204 .281 .258 r
.27002 .57566 m .26084 .53835 L .2628 .54024 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.28783 .3842 m .27233 .42076 L .27002 .42434 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.26084 .46165 m .27002 .42434 L .27233 .42076 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.50992 .74195 m .5203 .74135 L .5354 .73999 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.5203 .74135 m .50992 .74195 L .50201 .74224 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50992 .25805 m .5203 .25865 L .50411 .25806 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50411 .25806 m .50201 .25776 L .50992 .25805 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26697 .57532 m
.26797 .57716 L
s
.5 Mabswid
.076 .092 .07 r
.63911 .30177 m .66858 .32547 L .66077 .31957 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66077 .31957 m .63189 .29627 L .63911 .30177 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.60039 .72113 m .63189 .70373 L .63911 .69823 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.66858 .67453 m .63911 .69823 L .63189 .70373 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.50411 .74194 m .50201 .74224 L .494 .74214 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.494 .74214 m .48771 .74174 L .50411 .74194 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.48771 .25826 m .494 .25786 L .50201 .25776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.494 .25786 m .48771 .25826 L .47197 .25924 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.27233 .42076 m .2628 .45976 L .26084 .46165 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.25775 .5 m .26084 .46165 L .2628 .45976 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.25958 .5 m .2628 .54024 L .26084 .53835 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.26084 .53835 m .25775 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.50201 .74224 m .50411 .74194 L .5203 .74135 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.50201 .25776 m .50411 .25806 L .48771 .25826 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.2628 .45976 m .25958 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.37424 .70639 m .40457 .72332 L .39589 .71886 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.39589 .71886 m .36367 .701 L .37424 .70639 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.43626 .26608 m .40457 .27668 L .39589 .28114 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36367 .299 m .39589 .28114 L .40457 .27668 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27807 .60397 m
.27817 .60324 L
s
.5 Mabswid
.058 .075 .057 r
.40457 .27668 m .43626 .26608 L .44561 .26327 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.41809 .72736 m .44561 .73673 L .43626 .73392 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.43626 .73392 m .40457 .72332 L .41809 .72736 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26678 .57588 m
.26697 .57532 L
s
.5 Mabswid
.241 .356 .243 r
.69409 .64599 m .66858 .67453 L .66077 .68043 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.63189 .70373 m .66077 .68043 L .66858 .67453 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.66858 .32547 m .69409 .35401 L .68605 .34829 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.68605 .34829 m .66077 .31957 L .66858 .32547 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2773 .60266 m
.27807 .60397 L
s
.5 Mabswid
.058 .075 .057 r
.55944 .73538 m .58926 .72541 L .60039 .72113 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.58926 .72541 m .55944 .73538 L .54866 .73796 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.55944 .26462 m .58926 .27459 L .57348 .27086 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.57348 .27086 m .54866 .26204 L .55944 .26462 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26678 .57588 m
.26755 .5785 L
s
.5 Mabswid
.322 .477 .349 r
.63189 .70373 m .60039 .72113 L .58926 .72541 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.60039 .27887 m .63189 .29627 L .61797 .29106 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.61797 .29106 m .58926 .27459 L .60039 .27887 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.69409 .35401 m .71485 .38667 L .70681 .38173 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.70681 .38173 m .68605 .34829 L .69409 .35401 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.71485 .61333 m .69409 .64599 L .68605 .65171 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.66077 .68043 m .68605 .65171 L .69409 .64599 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.34626 .68331 m .37424 .70639 L .36367 .701 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.36367 .701 m .3343 .67749 L .34626 .68331 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.40457 .27668 m .37424 .29361 L .36367 .299 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.3343 .32251 m .36367 .299 L .37424 .29361 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27578 .59943 m
.2773 .60266 L
s
.5 Mabswid
.392 .574 .454 r
.43597 .73074 m .4577 .73906 L .44561 .73673 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.44561 .73673 m .41809 .72736 L .43597 .73074 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.44561 .26327 m .41809 .27264 L .40457 .27668 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.41809 .27264 m .44561 .26327 L .4577 .26094 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26755 .5785 m
.26924 .58327 L
s
.5 Mabswid
.231 .323 .206 r
.73019 .57743 m .71485 .61333 L .70681 .61827 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.68605 .65171 m .70681 .61827 L .71485 .61333 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.71485 .38667 m .73019 .42257 L .72227 .41895 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.72227 .41895 m .70681 .38173 L .71485 .38667 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.54866 .73796 m .57348 .72914 L .58926 .72541 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.57348 .72914 m .54866 .73796 L .5354 .73999 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.54866 .26204 m .57348 .27086 L .55369 .26789 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.55369 .26789 m .5354 .26001 L .54866 .26204 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.7396 .53929 m .73019 .57743 L .72227 .58105 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.70681 .61827 m .72227 .58105 L .73019 .57743 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.73019 .42257 m .7396 .46071 L .7318 .4588 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.7318 .4588 m .72227 .41895 L .73019 .42257 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.39143 .71134 m .41809 .72736 L .40457 .72332 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.40457 .72332 m .37424 .70639 L .39143 .71134 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.37424 .29361 m .40457 .27668 L .41809 .27264 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.32164 .65452 m .34626 .68331 L .3343 .67749 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.3343 .67749 m .30873 .64885 L .32164 .65452 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.37424 .29361 m .34626 .31669 L .3343 .32251 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.30873 .35115 m .3343 .32251 L .34626 .31669 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.7396 .46071 m .74277 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.73502 .5 m .7318 .4588 L .7396 .46071 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.74277 .5 m .7396 .53929 L .7318 .5412 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.72227 .58105 m .7318 .5412 L .7396 .53929 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.7318 .5412 m .73502 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.45741 .73324 m .47197 .74076 L .4577 .73906 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.4577 .73906 m .43597 .73074 L .45741 .73324 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.43597 .26926 m .4577 .26094 L .47197 .25924 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.4577 .26094 m .43597 .26926 L .41809 .27264 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.66077 .68043 m .63189 .70373 L .61797 .70894 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.58926 .72541 m .61797 .70894 L .63189 .70373 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.63189 .29627 m .66077 .31957 L .64462 .31391 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.64462 .31391 m .61797 .29106 L .63189 .29627 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.5354 .73999 m .55369 .73211 L .57348 .72914 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.55369 .73211 m .5354 .73999 L .5203 .74135 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5354 .26001 m .55369 .26789 L .53087 .2659 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.53087 .2659 m .5203 .25865 L .5354 .26001 L p F P
.505 .664 .505 r
s
.42 .601 .443 r
.61797 .70894 m .58926 .72541 L .57348 .72914 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.58926 .27459 m .61797 .29106 L .59764 .28646 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.59764 .28646 m .57348 .27086 L .58926 .27459 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.48129 .73469 m .48771 .74174 L .47197 .74076 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.47197 .74076 m .45741 .73324 L .48129 .73469 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.45741 .26676 m .47197 .25924 L .48771 .25826 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.47197 .25924 m .45741 .26676 L .43597 .26926 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.34626 .31669 m .32164 .34548 L .30873 .35115 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.28783 .3842 m .30873 .35115 L .32164 .34548 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30132 .62071 m .32164 .65452 L .30873 .64885 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30873 .64885 m .28783 .6158 L .30132 .62071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2684 .57796 m
.27619 .59595 L
s
.27619 .59595 m
.27808 .60029 L
s
.27808 .60029 m
.28604 .61868 L
s
.5 Mabswid
.438 .63 .477 r
.5203 .74135 m .53087 .7341 L .55369 .73211 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.53087 .7341 m .5203 .74135 L .50411 .74194 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.5203 .25865 m .53087 .2659 L .50627 .26502 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.50627 .26502 m .50411 .25806 L .5203 .25865 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.50627 .73498 m .50411 .74194 L .48771 .74174 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.48771 .74174 m .48129 .73469 L .50627 .73498 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.48129 .26531 m .48771 .25826 L .50411 .25806 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.48771 .25826 m .48129 .26531 L .45741 .26676 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.50411 .74194 m .50627 .73498 L .53087 .7341 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.50411 .25806 m .50627 .26502 L .48129 .26531 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28614 .58285 m .30132 .62071 L .28783 .6158 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28783 .6158 m .27233 .57924 L .28614 .58285 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27648 .59916 m
.28017 .60558 L
s
.5 Mabswid
.16 .182 .152 r
.32164 .34548 m .30132 .37929 L .28783 .3842 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.27233 .42076 m .28783 .3842 L .30132 .37929 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.36656 .68871 m .39143 .71134 L .37424 .70639 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.37424 .70639 m .34626 .68331 L .36656 .68871 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.41809 .27264 m .39143 .28866 L .37424 .29361 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.34626 .31669 m .37424 .29361 L .39143 .28866 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66077 .31957 m .68605 .34829 L .66819 .34276 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66819 .34276 m .64462 .31391 L .66077 .31957 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.68605 .65171 m .66077 .68043 L .64462 .68609 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.61797 .70894 m .64462 .68609 L .66077 .68043 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41472 .71552 m .43597 .73074 L .41809 .72736 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41809 .72736 m .39143 .71134 L .41472 .71552 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.39143 .28866 m .41809 .27264 L .43597 .26926 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28017 .60558 m
.28194 .60792 L
s
.5 Mabswid
.396 .528 .433 r
.27676 .54216 m .28614 .58285 L .27233 .57924 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27233 .57924 m .2628 .54024 L .27676 .54216 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.30132 .37929 m .28614 .41715 L .27233 .42076 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.2628 .45976 m .27233 .42076 L .28614 .41715 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28194 .60792 m
.28352 .60867 L
s
.5 Mabswid
.42 .601 .443 r
.57348 .72914 m .59764 .71354 L .61797 .70894 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.59764 .71354 m .57348 .72914 L .55369 .73211 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57348 .27086 m .59764 .28646 L .57165 .28277 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57165 .28277 m .55369 .26789 L .57348 .27086 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.28614 .41715 m .27676 .45784 L .2628 .45976 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.25958 .5 m .2628 .45976 L .27676 .45784 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.27358 .5 m .27676 .54216 L .2628 .54024 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.2628 .54024 m .25958 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.27676 .45784 m .27358 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68605 .34829 m .70681 .38173 L .68772 .37692 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68772 .37692 m .66819 .34276 L .68605 .34829 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.70681 .61827 m .68605 .65171 L .66819 .65724 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.64462 .68609 m .66819 .65724 L .68605 .65171 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.64462 .68609 m .61797 .70894 L .59764 .71354 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.61797 .29106 m .64462 .31391 L .62029 .30886 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.62029 .30886 m .59764 .28646 L .61797 .29106 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28352 .60867 m
.28387 .6073 L
s
.5 Mabswid
.542 .758 .585 r
.44307 .71864 m .45741 .73324 L .43597 .73074 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.43597 .73074 m .41472 .71552 L .44307 .71864 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.41472 .28448 m .43597 .26926 L .45741 .26676 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.43597 .26926 m .41472 .28448 L .39143 .28866 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34445 .65982 m .36656 .68871 L .34626 .68331 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34626 .68331 m .32164 .65452 L .34445 .65982 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.39143 .28866 m .36656 .31129 L .34626 .31669 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.32164 .34548 m .34626 .31669 L .36656 .31129 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28196 .60174 m
.28387 .6073 L
s
.5 Mabswid
.406 .546 .373 r
.72227 .58105 m .70681 .61827 L .68772 .62308 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.66819 .65724 m .68772 .62308 L .70681 .61827 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70681 .38173 m .72227 .41895 L .70237 .41539 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70237 .41539 m .68772 .37692 L .70681 .38173 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.55369 .73211 m .57165 .71723 L .59764 .71354 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.57165 .71723 m .55369 .73211 L .53087 .7341 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.55369 .26789 m .57165 .28277 L .54132 .28027 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.54132 .28027 m .53087 .2659 L .55369 .26789 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27386 .58007 m
.28196 .60174 L
s
.5 Mabswid
.559 .772 .601 r
.39471 .69332 m .41472 .71552 L .39143 .71134 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39143 .71134 m .36656 .68871 L .39471 .69332 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.36656 .31129 m .39143 .28866 L .41472 .28448 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.47494 .72046 m .48129 .73469 L .45741 .73324 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.45741 .73324 m .44307 .71864 L .47494 .72046 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.44307 .28136 m .45741 .26676 L .48129 .26531 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.45741 .26676 m .44307 .28136 L .41472 .28448 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.7318 .5412 m .72227 .58105 L .70237 .58461 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.68772 .62308 m .70237 .58461 L .72227 .58105 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.72227 .41895 m .7318 .4588 L .71144 .45691 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.71144 .45691 m .70237 .41539 L .72227 .41895 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.53087 .7341 m .54132 .71973 L .57165 .71723 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.54132 .71973 m .53087 .7341 L .50627 .73498 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.53087 .2659 m .54132 .28027 L .5084 .27916 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.5084 .27916 m .50627 .26502 L .53087 .2659 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.36656 .31129 m .34445 .34018 L .32164 .34548 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.30132 .37929 m .32164 .34548 L .34445 .34018 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32606 .62534 m .34445 .65982 L .32164 .65452 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32164 .65452 m .30132 .62071 L .32606 .62534 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.66819 .65724 m .64462 .68609 L .62029 .69114 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.59764 .71354 m .62029 .69114 L .64462 .68609 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64462 .31391 m .66819 .34276 L .64051 .33778 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64051 .33778 m .62029 .30886 L .64462 .31391 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.7318 .4588 m .73502 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.71452 .5 m .71144 .45691 L .7318 .4588 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.73502 .5 m .7318 .5412 L .71144 .54309 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.70237 .58461 m .71144 .54309 L .7318 .5412 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.5084 .72084 m .50627 .73498 L .48129 .73469 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.48129 .73469 m .47494 .72046 L .5084 .72084 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.47494 .27954 m .48129 .26531 L .50627 .26502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.48129 .26531 m .47494 .27954 L .44307 .28136 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.50627 .73498 m .5084 .72084 L .54132 .71973 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.50627 .26502 m .5084 .27916 L .47494 .27954 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29691 .6235 m
.29868 .62541 L
s
.29691 .6235 m
.29694 .62209 L
s
.5 Mabswid
.363 .469 .309 r
.71144 .54309 m .71452 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.62029 .69114 m .59764 .71354 L .57165 .71723 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.59764 .28646 m .62029 .30886 L .58863 .30478 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.58863 .30478 m .57165 .28277 L .59764 .28646 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29868 .62541 m
.29874 .62403 L
s
.29694 .62209 m
.29874 .62403 L
s
.28901 .60419 m
.29176 .61139 L
s
.5 Mabswid
.538 .718 .564 r
.31222 .58629 m .32606 .62534 L .30132 .62071 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.30132 .62071 m .28614 .58285 L .31222 .58629 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28037 .58159 m
.28901 .60419 L
s
.5 Mabswid
.287 .335 .264 r
.34445 .34018 m .32606 .37466 L .30132 .37929 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.28614 .41715 m .30132 .37929 L .32606 .37466 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.42948 .69679 m .44307 .71864 L .41472 .71552 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.41472 .71552 m .39471 .69332 L .42948 .69679 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.39471 .30668 m .41472 .28448 L .44307 .28136 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.41472 .28448 m .39471 .30668 L .36656 .31129 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.37677 .66439 m .39471 .69332 L .36656 .68871 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.36656 .68871 m .34445 .65982 L .37677 .66439 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.34445 .34018 m .36656 .31129 L .39471 .30668 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.66819 .34276 m .68772 .37692 L .65741 .37255 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.65741 .37255 m .64051 .33778 L .66819 .34276 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.68772 .62308 m .66819 .65724 L .64051 .66222 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.62029 .69114 m .64051 .66222 L .66819 .65724 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.30362 .54399 m .31222 .58629 L .28614 .58285 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.28614 .58285 m .27676 .54216 L .30362 .54399 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.32606 .37466 m .31222 .41371 L .28614 .41715 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.27676 .45784 m .28614 .41715 L .31222 .41371 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.57165 .71723 m .58863 .69522 L .62029 .69114 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.58863 .69522 m .57165 .71723 L .54132 .71973 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.57165 .28277 m .58863 .30478 L .55125 .302 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.55125 .302 m .54132 .28027 L .57165 .28277 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.31222 .41371 m .30362 .45601 L .27676 .45784 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.27358 .5 m .27676 .45784 L .30362 .45601 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.3007 .5 m .30362 .54399 L .27676 .54216 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.27676 .54216 m .27358 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28907 .58309 m
.29835 .60828 L
s
.29835 .60828 m
.30021 .61333 L
s
.5 Mabswid
.465 .594 .465 r
.30362 .45601 m .3007 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.4689 .69883 m .47494 .72046 L .44307 .71864 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.44307 .71864 m .42948 .69679 L .4689 .69883 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.42948 .30321 m .44307 .28136 L .47494 .27954 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.44307 .28136 m .42948 .30321 L .39471 .30668 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2969 .60544 m
.30308 .61211 L
s
.5 Mabswid
.581 .785 .571 r
.64051 .66222 m .62029 .69114 L .58863 .69522 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.62029 .30886 m .64051 .33778 L .60391 .33372 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.60391 .33372 m .58863 .30478 L .62029 .30886 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.70237 .58461 m .68772 .62308 L .65741 .62745 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.64051 .66222 m .65741 .62745 L .68772 .62308 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.68772 .37692 m .70237 .41539 L .67017 .41214 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.67017 .41214 m .65741 .37255 L .68772 .37692 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.54132 .71973 m .55125 .698 L .58863 .69522 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.55125 .698 m .54132 .71973 L .5084 .72084 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.54132 .28027 m .55125 .302 L .51043 .30076 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.51043 .30076 m .5084 .27916 L .54132 .28027 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30308 .61211 m
.30654 .61451 L
s
.5 Mabswid
.296 .338 .255 r
.39471 .30668 m .37677 .33561 L .34445 .34018 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.32606 .37466 m .34445 .34018 L .37677 .33561 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.36172 .62936 m .37677 .66439 L .34445 .65982 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.34445 .65982 m .32606 .62534 L .36172 .62936 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.51043 .69924 m .5084 .72084 L .47494 .72046 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.47494 .72046 m .4689 .69883 L .51043 .69924 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.4689 .30117 m .47494 .27954 L .5084 .27916 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.47494 .27954 m .4689 .30117 L .42948 .30321 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30654 .61451 m
.31073 .61521 L
s
.5 Mabswid
.622 .846 .63 r
.5084 .72084 m .51043 .69924 L .55125 .698 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.5084 .27916 m .51043 .30076 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.37677 .33561 m .39471 .30668 L .42948 .30321 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.41721 .66786 m .42948 .69679 L .39471 .69332 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.39471 .69332 m .37677 .66439 L .41721 .66786 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.70237 .41539 m .71144 .45691 L .67811 .45518 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.67811 .45518 m .67017 .41214 L .70237 .41539 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.71144 .54309 m .70237 .58461 L .67017 .58786 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.65741 .62745 m .67017 .58786 L .70237 .58461 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31073 .61521 m
.31289 .61372 L
s
.5 Mabswid
.448 .568 .386 r
.71144 .45691 m .71452 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.6808 .5 m .67811 .45518 L .71144 .45691 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.71452 .5 m .71144 .54309 L .67811 .54482 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.67017 .58786 m .67811 .54482 L .71144 .54309 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.64051 .33778 m .65741 .37255 L .61675 .36896 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.61675 .36896 m .60391 .33372 L .64051 .33778 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.65741 .62745 m .64051 .66222 L .60391 .66628 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.58863 .69522 m .60391 .66628 L .64051 .66222 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.67811 .54482 m .6808 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.35034 .58928 m .36172 .62936 L .32606 .62534 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.32606 .62534 m .31222 .58629 L .35034 .58928 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31208 .60787 m
.31289 .61372 L
s
.5 Mabswid
.359 .421 .29 r
.58863 .30478 m .60391 .33372 L .56023 .33093 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.56023 .33093 m .55125 .302 L .58863 .30478 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.60391 .66628 m .58863 .69522 L .55125 .698 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.37677 .33561 m .36172 .37064 L .32606 .37466 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.31222 .41371 m .32606 .37466 L .36172 .37064 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31208 .60787 m
.31921 .61461 L
s
.30466 .58508 m
.31208 .60787 L
s
.31921 .61461 m
.32332 .61701 L
s
.5 Mabswid
.652 .874 .659 r
.46342 .6699 m .4689 .69883 L .42948 .69679 L p F P
.505 .664 .505 r
s
.652 .874 .659 r
.42948 .69679 m .41721 .66786 L .46342 .6699 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.41721 .33214 m .42948 .30321 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.42948 .30321 m .41721 .33214 L .37677 .33561 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32332 .61701 m
.32856 .61765 L
s
.5 Mabswid
.447 .551 .419 r
.36172 .37064 m .35034 .41072 L .31222 .41371 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.30362 .45601 m .31222 .41371 L .35034 .41072 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.34324 .54559 m .35034 .58928 L .31222 .58629 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.31222 .58629 m .30362 .54399 L .34324 .54559 L p F P
.505 .664 .505 r
s
.433 .526 .39 r
.36172 .37064 m .37677 .33561 L .41721 .33214 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.40686 .63243 m .41721 .66786 L .37677 .66439 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.37677 .66439 m .36172 .62936 L .40686 .63243 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.55125 .698 m .56023 .66907 L .60391 .66628 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.56023 .66907 m .55125 .698 L .51043 .69924 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.55125 .302 m .56023 .33093 L .51227 .32969 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.51227 .32969 m .51043 .30076 L .55125 .302 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32856 .61765 m
.33148 .6161 L
s
.5 Mabswid
.585 .769 .551 r
.67017 .58786 m .65741 .62745 L .61675 .63104 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.60391 .66628 m .61675 .63104 L .65741 .62745 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.65741 .37255 m .67017 .41214 L .6265 .40946 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.6265 .40946 m .61675 .36896 L .65741 .37255 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.51227 .67031 m .51043 .69924 L .4689 .69883 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.4689 .69883 m .46342 .6699 L .51227 .67031 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.46342 .3301 m .4689 .30117 L .51043 .30076 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.4689 .30117 m .46342 .3301 L .41721 .33214 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.35034 .41072 m .34324 .45441 L .30362 .45601 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.3007 .5 m .30362 .45601 L .34324 .45441 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.34082 .5 m .34324 .54559 L .30362 .54399 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.30362 .54399 m .3007 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33122 .61013 m
.33148 .6161 L
s
.5 Mabswid
.645 .864 .639 r
.51043 .69924 m .51227 .67031 L .56023 .66907 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.51043 .30076 m .51227 .32969 L .46342 .3301 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.34324 .45441 m .34082 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32441 .58694 m
.33122 .61013 L
s
.5 Mabswid
.425 .514 .356 r
.60391 .33372 m .61675 .36896 L .56782 .36649 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.56782 .36649 m .56023 .33093 L .60391 .33372 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.61675 .63104 m .60391 .66628 L .56023 .66907 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.67811 .54482 m .67017 .58786 L .6265 .59054 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.61675 .63104 m .6265 .59054 L .67017 .58786 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.67017 .41214 m .67811 .45518 L .63259 .45374 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.63259 .45374 m .6265 .40946 L .67017 .41214 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.39899 .59158 m .40686 .63243 L .36172 .62936 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.36172 .62936 m .35034 .58928 L .39899 .59158 L p F P
.505 .664 .505 r
s
.433 .526 .39 r
.41721 .33214 m .40686 .36757 L .36172 .37064 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.35034 .41072 m .36172 .37064 L .40686 .36757 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.40686 .36757 m .41721 .33214 L .46342 .3301 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.45878 .63424 m .46342 .6699 L .41721 .66786 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.41721 .66786 m .40686 .63243 L .45878 .63424 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34406 .60711 m
.34817 .61376 L
s
.34817 .61376 m
.3538 .61824 L
s
.34277 .6026 m
.34406 .60711 L
s
.34406 .60711 m
.37185 .60906 L
s
.3538 .61824 m
.35887 .62062 L
s
.5 Mabswid
.518 .658 .461 r
.67811 .45518 m .6808 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.63466 .5 m .63259 .45374 L .67811 .45518 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.6808 .5 m .67811 .54482 L .63259 .54626 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.6265 .59054 m .63259 .54626 L .67811 .54482 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34277 .6026 m
.34308 .59568 L
s
.35887 .62062 m
.3657 .62114 L
s
.5 Mabswid
.548 .705 .498 r
.63259 .54626 m .63466 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.56023 .66907 m .56782 .63351 L .61675 .63104 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.56023 .33093 m .56782 .36649 L .51383 .36538 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.51383 .36538 m .51227 .32969 L .56023 .33093 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.56782 .63351 m .56023 .66907 L .51227 .67031 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34308 .59568 m
.34639 .59102 L
s
.3657 .62114 m
.3698 .61946 L
s
.5 Mabswid
.621 .815 .591 r
.6265 .59054 m .61675 .63104 L .56782 .63351 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.61675 .36896 m .6265 .40946 L .57359 .40761 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.57359 .40761 m .56782 .36649 L .61675 .36896 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.40686 .36757 m .39899 .40842 L .35034 .41072 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.34324 .45441 m .35034 .41072 L .39899 .40842 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.39407 .54682 m .39899 .59158 L .35034 .58928 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.35034 .58928 m .34324 .54559 L .39407 .54682 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34639 .59102 m
.35046 .58876 L
s
.5 Mabswid
.465 .568 .408 r
.45878 .36576 m .46342 .3301 L .51227 .32969 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.51383 .63462 m .51227 .67031 L .46342 .6699 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.46342 .6699 m .45878 .63424 L .51383 .63462 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.46342 .3301 m .45878 .36576 L .40686 .36757 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3698 .61946 m
.37163 .61756 L
s
.5 Mabswid
.648 .859 .632 r
.51227 .67031 m .51383 .63462 L .56782 .63351 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.51227 .32969 m .51383 .36538 L .45878 .36576 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37163 .61756 m
.37295 .61347 L
s
.35046 .58876 m
.35766 .58917 L
s
.37185 .60906 m
.37295 .61347 L
s
.5 Mabswid
.538 .678 .507 r
.39899 .40842 m .39407 .45318 L .34324 .45441 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.34082 .5 m .34324 .45441 L .39407 .45318 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.3924 .5 m .39407 .54682 L .34324 .54559 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.34324 .54559 m .34082 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35766 .58917 m
.36313 .59201 L
s
.5 Mabswid
.65 .852 .637 r
.45525 .59294 m .45878 .63424 L .40686 .63243 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.40686 .63243 m .39899 .59158 L .45525 .59294 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.39899 .40842 m .40686 .36757 L .45878 .36576 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.36313 .59201 m
.36919 .59729 L
s
.5 Mabswid
.574 .732 .549 r
.39407 .45318 m .3924 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.63259 .54626 m .6265 .59054 L .57359 .59239 L p F P
.505 .664 .505 r
s
.621 .815 .591 r
.56782 .63351 m .57359 .59239 L .6265 .59054 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.6265 .40946 m .63259 .45374 L .57721 .45275 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.57721 .45275 m .57359 .40761 L .6265 .40946 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38718 .6099 m
.39124 .61663 L
s
.39124 .61663 m
.39744 .62109 L
s
.39744 .62109 m
.4032 .62339 L
s
.38622 .60529 m
.38718 .6099 L
s
.42109 .61382 m
.42484 .63753 L
s
.4032 .62339 m
.41129 .62376 L
s
.5 Mabswid
.641 .84 .615 r
.57359 .59239 m .56782 .63351 L .51383 .63462 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.56782 .36649 m .57359 .40761 L .51502 .40678 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.51502 .40678 m .51383 .36538 L .56782 .36649 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38622 .60529 m
.38751 .59817 L
s
.41129 .62376 m
.4164 .62193 L
s
.38751 .59817 m
.39211 .59333 L
s
.4164 .62193 m
.42127 .61791 L
s
.5 Mabswid
.558 .71 .507 r
.63259 .45374 m .63466 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.57845 .5 m .57721 .45275 L .63259 .45374 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.63466 .5 m .63259 .54626 L .57721 .54725 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.57359 .59239 m .57721 .54725 L .63259 .54626 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.45525 .40706 m .45878 .36576 L .51383 .36538 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.51502 .59322 m .51383 .63462 L .45878 .63424 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.45878 .63424 m .45525 .59294 L .51502 .59322 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.45878 .36576 m .45525 .40706 L .39899 .40842 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.39407 .45318 m .39899 .40842 L .45525 .40706 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.45304 .54755 m .45525 .59294 L .39899 .59158 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.39899 .59158 m .39407 .54682 L .45304 .54755 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.41756 .59155 m
.42109 .61382 L
s
.39211 .59333 m
.3973 .59092 L
s
.5 Mabswid
.641 .84 .615 r
.51383 .63462 m .51502 .59322 L .57359 .59239 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.5508 .63834 m
.55417 .60963 L
s
.5 Mabswid
.517 .644 .466 r
.51383 .36538 m .51502 .40678 L .45525 .40706 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.57721 .54725 m .57845 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3973 .59092 m
.40586 .59121 L
s
.44442 .61858 m
.45078 .62296 L
s
.45078 .62296 m
.45689 .62515 L
s
.45689 .62515 m
.46577 .6253 L
s
.44069 .61183 m
.44442 .61858 L
s
.40586 .59121 m
.41202 .59401 L
s
.46577 .6253 m
.4716 .62332 L
s
.41202 .59401 m
.41854 .59929 L
s
.50784 .62555 m
.51687 .6255 L
s
.51687 .6255 m
.52599 .62335 L
s
.4716 .62332 m
.47449 .62124 L
s
.44018 .60716 m
.44069 .61183 L
s
.44069 .61183 m
.47711 .61241 L
s
.52599 .62335 m
.52926 .61905 L
s
.49879 .62349 m
.50784 .62555 L
s
.5 Mabswid
.626 .813 .593 r
.57721 .54725 m .57359 .59239 L .51502 .59322 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.57359 .40761 m .57721 .45275 L .51576 .4523 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.51576 .4523 m .51502 .40678 L .57359 .40761 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.47449 .62124 m
.47731 .61693 L
s
.49572 .61922 m
.49879 .62349 L
s
.5 Mabswid
.555 .7 .516 r
.45525 .40706 m .45304 .45245 L .39407 .45318 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.3924 .5 m .39407 .45318 L .45304 .45245 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.45228 .5 m .45304 .54755 L .39407 .54682 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.39407 .54682 m .3924 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44018 .60716 m
.44247 .59987 L
s
.49572 .61922 m
.49877 .6148 L
s
.47711 .61241 m
.47731 .61693 L
s
.5 Mabswid
.588 .75 .555 r
.45304 .45245 m .45228 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44247 .59987 m
.44818 .59485 L
s
.49877 .6148 m
.50496 .61251 L
s
.50496 .61251 m
.52051 .61011 L
s
.52051 .61011 m
.52681 .60769 L
s
.55531 .59738 m
.55861 .59473 L
s
.55244 .59484 m
.55531 .59738 L
s
.55575 .59214 m
.55861 .59473 L
s
.5 Mabswid
.558 .703 .512 r
.45304 .45245 m .45525 .40706 L .51502 .40678 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.51576 .5477 m .51502 .59322 L .45525 .59294 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.45525 .59294 m .45304 .54755 L .51576 .5477 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.52681 .60769 m
.53016 .60279 L
s
.55244 .59484 m
.55575 .59214 L
s
.44818 .59485 m
.45422 .5923 L
s
.53016 .60279 m
.53029 .60028 L
s
.52737 .59516 m
.53029 .60028 L
s
.5 Mabswid
.626 .813 .593 r
.51502 .59322 m .51576 .5477 L .57721 .54725 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.51502 .40678 m .51576 .4523 L .45304 .45245 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4701 .59513 m
.47662 .60035 L
s
.45422 .5923 m
.46365 .59242 L
s
.49872 .59528 m
.49557 .60043 L
s
.46365 .59242 m
.4701 .59513 L
s
.5 Mabswid
.58 .739 .534 r
.57721 .45275 m .57845 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.51602 .5 m .51576 .4523 L .57721 .45275 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.57845 .5 m .57721 .54725 L .51576 .5477 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51792 .59257 m
.52737 .59516 L
s
.49872 .59528 m
.50833 .59261 L
s
.50833 .59261 m
.51792 .59257 L
s
.5 Mabswid
.606 .779 .566 r
.51576 .5477 m .51602 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.45228 .5 m .45304 .45245 L .51576 .4523 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.51602 .5 m .51576 .5477 L .45304 .54755 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.45304 .54755 m .45228 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.51576 .4523 m .51602 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>l0/>3V4P21ZH7b0;3PiP40oooo003X0;3PiPP0PJV10P0S9A`0
0`21ZH409BLN02DW7P0602DW7P04086YP@0U9ah09BLN02DW7Pl0PJV1i@2`h>H10?ooo`00hP2`h>H6
086YP@0301hQ6@21ZH40PJV100H08bDL00<0PJV102DW7P0U9ah01`0U9ah00`21ZH409BLN02DW7P06
02DW7P80PJV11`0R9A`6086YPN00/>3V0@3oool00=`0/>3V1`21ZH4401hQ6@80PJV1200S9A`00`21
ZH409BLN02DW7P0802DW7P03086YP@0U9ah09BLN00L09BLN0P21ZH47028U7080PJV10P0M8AT3086Y
PMd0/>3V0@3oool00=P0/>3V1@21ZH400`0G6a@0PJV1086YP@0501hQ6@80PJV1100S9A`S086YP@<0
8RDL0P21ZH4201dQ6@@0PJV1fP2`h>H10?ooo`00eP2`h>H4086YP@0301LK5021ZH40PJV100807R4I
3021ZH4403@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=3HX
03@f:00203@f:0T0PJV100<07B4I086YP@21ZH400`21ZH7F0;3PiP40oooo003C0;3PiP`0PJV1100_
<BD00`21ZH40=3HX03@f:00903@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02`0g
>2/00`21ZH40=3HX03@f:00803@f:003086YP@0^<2D0PJV100L0PJV1e02`h>H10?ooo`00d02`h>H9
086YP@T0;c4U00<0PJV103@f:00d=RP02@0d=RP00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0g>2/0
=cP[00`0=cP[00<0PJV103@f:00d=RP0200d=RP00`21ZH40;S0U02h`9@0302h`9@H0PJV1d@2`h>H1
0?ooo`00cP2`h>H5086YP@<09RTO00<0PJV102la9@0_<BD0200_<BD00`21ZH40=3HX03@f:00:03@f
:003086YP@0g>2/0=cP[00`0=cP[00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=3HX03@f:00903@f
:003086YP@0^<2D0;S0U00D0;S0U1P21ZH7>0;3PiP40oooo003;0;3PiPD0PJV1100V:Al2086YP@X0
;c4U00<0PJV103@f:00d=RP02P0d=RP00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0g>2/0=cP[00`0
=cP[00<0PJV103@f:00d=RP02@0d=RP2086YP@L0;S0U0P21ZH400`0V:1h0PJV1086YP@02086YPL/0
/>3V0@3oool00<T0/>3V0P21ZH400`0K7QL0PJV1086YP@0402HY7`80PJV12`0_<BD00`21ZH40=3HX
03@f:00;03@f:003086YP@0g>2/0=cP[00d0=cP[00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=3HX
03@f:00:03@f:003086YP@0^<2D0;S0U00H0;S0U00@0PJV102HX7P0V:1h09RPN0`21ZH790;3PiP40
oooo00370;3PiP80PJV10P0K7QL00`21ZH409RTO02HY7`0302HY7`03086YP@0_<BD0;c4U00X0;c4U
00<0PJV103@f:00d=RP0100d=RP]086YP@T0=3HX00<0PJV102h`9@0^<2D01P0^<2D2086YP@<09RPN
0`21ZH770;3PiP40oooo00350;3PiP80PJV10P0K7QL2086YP@@09RTO0P21ZH4502la9@l0PJV11`1:
DSX00`21ZH40CUPn04iH?P0>04iH?P03086YP@1>F3h0CUPn00h0CUPn00@0PJV104YB>`1:DS/0BU8k
2021ZH4203@f:003086YP@0^<2D0;S0U00L0;S0U0P21ZH4302HX7P<0PJV1a@2`h>H10?ooo`00``2`
h>H2086YP@<06ahG00<0PJV102HY7`0V:Al00P0V:Al9086YP@H0@DHc00<0PJV104YB>P1:DSX0301:
DSX00`21ZH40CUPn04iH?P0?04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0201:
DS/:086YP@@0;S0U0P21ZH4302HX7P<0PJV1``2`h>H10?ooo`00`@2`h>H2086YP@<06ahG0P21ZH40
0`0V:Al0PJV1086YP@03086YP@h0@DHc00<0PJV104YB>P1:DSX0301:DSX00`21ZH40CUPn04iH?P0?
04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`03
0456<`P0PJV10P0V:1h4086YPL40/>3V0@3oool00;l0/>3V0P21ZH4301/N5`D0PJV10`0b=2L00`21
ZH40@DHc0456<`0<0456<`03086YP@1:DSX0BU8j00d0BU8j00<0PJV104iH?P1>F3h03`1>F3h00`21
ZH40CUPn04iH?P0@04iH?P03086YP@1:DS/0BU8k00/0BU8k00<0PJV10456<`11AS<02P11AS<4086Y
P@0302HX7P21ZH40PJV10080PJV1_`2`h>H10?ooo`00_@2`h>H2086YP@806ahG1021ZH46038d9`03
086YP@11AS<0@DHc00`0@DHc00<0PJV104YB>P1:DSX03P1:DSX00`21ZH40CUPn04iH?P0?04iH?P03
086YP@1>F3h0CUPn0100CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`0:0456<`03
086YP@0b=2L0<S@W00L0PJV1_@2`h>H10?ooo`00^`2`h>H6086YP@0302DX7P21ZH40<S@W00L0<S@W
00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0=04YB>P03086YP@1>F3h0CUPn0140CUPn
00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0<04YB>`03086YP@11AS<0@DHc00X0@DHc
00<0PJV1038d9`0b=2L00`0b=2L5086YPK/0/>3V0@3oool00;X0/>3V0`21ZH4402DX7P03086YP@0b
=2L0<S@W00H0<S@W00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0>04YB>P03086YP@1>
F3h0CUPn0140CUPn00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0=04YB>`03086YP@11
AS<0@DHc00X0@DHc00<0PJV1038d9`0b=2L0100b=2L5086YPKT0/>3V0@3oool00;P0/>3V0P21ZH45
02DX7P80PJV1200b=2L00`21ZH40@DHc0456<`0=0456<`03086YP@1:DSX0BU8j00h0BU8j00<0PJV1
04iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A04iH?P03086YP@1:DS/0BU8k00`0BU8k00<0PJV1
0456<`11AS<02`11AS<00`21ZH40<S@W038d9`04038d9`04086YP@0T9ah092LN02@W7P80PJV1]`2`
h>H10?ooo`00]P2`h>H3086YP@D09BPN00<0PJV1038d9`0b=2L01`0b=2L00`21ZH40@DHc0456<`0=
0456<`03086YP@1:DSX0BU8j00l0BU8j00<0PJV104iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A
04iH?P03086YP@1:DS/0BU8k00d0BU8k00<0PJV10456<`11AS<02P11AS<00`21ZH40<S@W038d9`05
038d9`80PJV10`0T9ah00`21ZH40/>3V0;3PiP2d0;3PiP40oooo002e0;3PiP<0PJV11@0U:1h00`21
ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc00d0@DHc00<0PJV104YB>P1:DSX03`1:DSX00`21
ZH40CUPn04iH?P0B04iH?P03086YP@1>F3h0CUPn0180CUPn00<0PJV104YB>`1:DS/03@1:DS/00`21
ZH40@DHc0456<`0:0456<`03086YP@0b=2L0<S@W00H0<S@W00D0PJV102@W7P0T9ah092LN086YP@2e
0;3PiP40oooo002c0;3PiP<0PJV11P0U:1h00`21ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc
00h0@DHc00<0PJV104YB>P1:DSX01P1:DSXh086YP@`0BU8k00<0PJV10456<`11AS<02P11AS<00`21
ZH40<S@W038d9`06038d9`04086YP@0T9ah092LN02@W7P80PJV1/`2`h>H10?ooo`00/P2`h>H00`21
ZH4051PB086YP@0602DX7P03086YP@0b=2L0<S@W00P0<S@W00<0PJV10456<`11AS<02@11AS<>086Y
P@T0HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00B065cD003086YP@1KJdX0Ff]:
0080Ff]:2@21ZH4304YB>`03086YP@11AS<0@DHc00/0@DHc00<0PJV1038d9`0b=2L01P0b=2L00`21
ZH4092LN02@W7P0202@W7P03086YP@2`h>H0/>3V0;00/>3V0@3oool00;40/>3V00<0PJV101@H4P21
ZH401@0U:1h2086YP@X0<S@W00@0PJV10456<`11AS<0@DHc2@21ZH4405YZCP03086YP@1RM5@0HWAD
0100HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:
00X0Ff]:2021ZH4:0456<`03086YP@0b=2L0<S@W00H0<S@W00<0PJV102@W7P0T9ah00P0T9ah00`21
ZH40/>3V0;3PiP2_0;3PiP40oooo002_0;3PiP04086YP@0D618051PB086YP@D09BPN00<0PJV1038d
9`0b=2L01P0b=2L8086YP@`0FVY>00<0PJV1069dE01RM5@04@1RM5@00`21ZH40I7MD06AgE00B06Ag
E003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX03`1KJdX00`21ZH40Df1305=P@`08086Y
P@<0@DHc00<0PJV1038d9`0b=2L01P0b=2L2086YP@<092LN00<0PJV10;3PiP2`h>H0[P2`h>H10?oo
o`00[P2`h>H01021ZH4051PB01@H4P21ZH4502DX7P03086YP@0b=2L0<S@W00L0PJV10P1;ET400`21
ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0100HWAD00<0PJV106AgE01TMe@04`1TMe@00`21
ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:00l0Ff]:00<0PJV105=P@`1CH4<0201CH4<7086Y
P@L0<S@W00D0PJV102@W7P0T9ah092LN086YP@2_0;3PiP40oooo002]0;3PiP04086YP@0D6180PJV1
086YP@@09BPN1@21ZH4904]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1069dE01RM5@04@1RM5@0
0`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX0401KJdX0
0`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0PJV100D0PJV10P0b=2L01@21ZH4092LN02@W7P0T
9ah0PJV10:h0/>3V0@3oool00:/0/>3V00@0PJV101@H4P0D6180PJV10`0U:1h4086YP@`0BeI100<0
PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD069dE00A069dE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0?05][BP03086YP@1CH4<0Df1300`0Df1300<0
PJV104A<=P14C3H01@14C3H5086YP@8092LN0P21ZH6/0;3PiP40oooo002Z0;3PiP03086YP@0D6180
51PB00D0PJV10P0b=R/00`21ZH40BeI104]F@@0;04]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1
069dE01RM5@04P1RM5@00`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV1
05][BP1KJdX0401KJdX00`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0A4`f00P0A4`f0`21ZH42
02@W7P03086YP@2`h>H0/>3V0:T0/>3V0@3oool00:T0/>3V0P0D6183086YP@H0<SH[00<0PJV104]F
@@1;ET402P1;ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0180HWAD00<0PJV106Ag
E01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:0100Ff]:00<0PJV105=P
@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0PJV100<0PJV1ZP2`h>H10?oo
o`00Y`2`h>H5086YP@L0<SH[00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0?05YZCP03
086YP@1RM5@0HWAD0180HWAD00<0PJV106AgE01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003
086YP@1KJdX0Ff]:0140Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0704A<=P03
086YP@0];b@0;BlT0080;BlT0P21ZH6Y0;3PiP40oooo002V0;3PiP80PJV10P0K7aL00`21ZH40<SH[
038f:`05038f:`03086YP@1;ET40BeI100/0BeI100<0PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD
069dE00C069dE003086YP@1TMe@0I7MD01@0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:
05][BP0A05][BP03086YP@1CH4<0Df1300`0Df1300<0PJV104A<=P14C3H02014C3H00`21ZH40;BlT
02d_900302d_9080PJV1Y`2`h>H10?ooo`00Y@2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[
00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0@05YZCP03086YP@1RM5@0HWAD0180HWAD
00<0PJV106AgE01TMe@05@1TMe@00`21ZH40HG=@065cD00D065cD003086YP@1KJdX0Ff]:0140Ff]:
00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00<0;BlT
0P21ZH6V0;3PiP40oooo002T0;3PiP03086YP@0K7aL06alG00806alG00<0PJV1038f:`0b=R/0100b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00l0FVY>00<0PJV1069dE01RM5@04`1R
M5@00`21ZH40I7MD06AgE00E06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV105][BP1KJdX04P1K
JdX00`21ZH40Df1305=P@`0=05=P@`03086YP@14C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0]
;b@2086YPJD0/>3V0@3oool00:@0/>3V00D0PJV101/O5`0K7aL06alG086YP@07038f:`03086YP@1;
ET40BeI100/0BeI100<0PJV105YZCP1JJTh0401JJTh00`21ZH40HWAD069dE00C069dE003086YP@1T
Me@0I7MD01D0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0B05][BP03086YP@1C
H4<0Df1300d0Df1300<0PJV104A<=P14C3H02@14C3H00`21ZH40;BlT02d_900302d_9080PJV1Y02`
h>H10?ooo`00X`2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[00<0PJV104]F@@1;ET40301;
ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD00T0HWAD;`21ZH4<065cD003086YP@1K
JdX0Ff]:0180Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0]
;b@0;BlT00@0;BlT0P21ZH6S0;3PiP40oooo002R0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00`0FVY>4021ZH4;07F?J003086YP@1g
TFP0Mi5X01D0Mi5X00<0PJV107B=I01dSF@02@1dSF@G086YP@X0Ff]:00<0PJV105=P@`1CH4<03P1C
H4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00@0;BlT0P21ZH6R0;3PiP40oooo002Q
0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b=R/00`21ZH40BeI104]F@@0=04]F@@03086YP@1J
JTh0FVY>0080FVY>2P21ZH4406j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05@1g
TFP00`21ZH40M8eT07B=I00E07B=I003086YP@1/Pe/0K8=K00P0K8=K4021ZH4<05=P@`03086YP@14
C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2Q0;3PiP40oooo002P
0;3PiP05086YP@0K7aL06alG01/O5`21ZH40200b=R/00`21ZH40BeI104]F@@0804]F@@X0PJV13@1^
QV<00`21ZH40MHmX07F?J00D07F?J003086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05@1d
SF@00`21ZH40K8=K06b3F`0C06b3F`03086YP@1QM4l0HGA?0080HGA?2@21ZH4305=P@`03086YP@14
C3H0A4`f00T0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2P0;3PiP40oooo002P
0;3PiP04086YP@0K7aL06alG086YP@P0<SH[00@0PJV104]F@@1;ET40BeI12021ZH44065dF003086Y
P@1^QV<0KXIS0100KXIS00<0PJV107F?J01eSfP0501eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01H0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0:065dC`L0PJV1
2@14C3H00`21ZH40;BlT02d_900302d_9003086YP@0I7AH0PJV109l0/>3V0@3oool009l0/>3V00D0
PJV101/O5`0K7aL06alG086YP@06038f:`H0PJV12`1QM5P00`21ZH40KXIS06j6H`0A06j6H`03086Y
P@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086Y
P@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df93086YP@03086YP@D0A4`f
00<0PJV102d_900];b@0100];b@2086YPIl0/>3V0@3oool009h0/>3V00D0PJV101/O5`0K7aL06alG
086YP@03038f:`D0PJV1401QM5P00`21ZH40KXIS06j6H`0A06j6H`03086YP@1eSfP0MHmX01@0MHmX
00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0K8=K01<0K8=K
00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df9305=R@`0305=R@`D0PJV100<0A4`f086YP@0];b@0
1@0];b@2086YPIh0/>3V0@3oool009d0/>3V00@0PJV101/O5`0K7aL06alG1@21ZH4404UE@`03086Y
P@1QM5P0HGAH00d0HGAH00<0PJV106j6H`1^QV<04@1^QV<00`21ZH40MHmX07F?J00E07F?J003086Y
P@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05P1dSF@00`21ZH40K8=K06b3F`0D06b3F`03086Y
P@1QM4l0HGA?00l0HGA?00<0PJV105=R@`1CHT<01`1CHT<5086YP@@0;BlT0P21ZH6M0;3PiP40oooo
002L0;3PiP04086YP@0K7aL06alG01/O5`80PJV11`19ED<00`21ZH40HGAH065dF00>065dF003086Y
P@1^QV<0KXIS0140KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01L0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0?065dC`03086Y
P@1CHT<0Df9300X0Df9300<0PJV103]3<021ZH400`21ZH400`0];b@0PJV1086YP@2L0;3PiP40oooo
002L0;3PiP04086YP@0K7aL0PJV1086YP@T0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS
06j6H`0B06j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05`1gTFP00`21ZH40M8eT
07B=I00G07B=I003086YP@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df93
05=R@`0905=R@`03086YP@0k@c00>d<`00<0>d<`1021ZH6K0;3PiP40oooo002K0;3PiP<0PJV100<0
:2hV086YP@19ED<01`19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0140KXIS00<0
PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01H0M8eT00<0
PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0?065dC`03086YP@1CHT<0Df9300X0Df9300<0
PJV103]3<00k@c001@0k@c02086YPIX0/>3V0@3oool009X0/>3V0P21ZH4202P^9P03086YP@19ED<0
BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0B06j6H`03086YP@1eSfP0
MHmX01D0MHmX00<0PJV107NAJ01gTFP0601gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0
K8=K01@0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df9305=R@`0905=R@`03086YP@0k@c00
>d<`00D0>d<`0`21ZH6I0;3PiP40oooo002I0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE
@`19ED<01P19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c001@0k@c000`21ZH407b8J086YP@2H0;3PiP40oooo002I0;3PiP05086YP@0X;RH0:2hV02P^
9P21ZH402@19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c00100k@c001021ZH407b8J01lR6P21ZH6G0;3PiP40oooo002H0;3PiP05086YP@0X;RH0:2hV
02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV1
07F?J01eSfP05P1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV1
06b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV1
03]3<00k@c001@0k@c000`21ZH407b8J086YP@2G0;3PiP40oooo002G0;3PiP03086YP@0X;RH0:2hV
0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01L0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002G0;3PiP05
086YP@0X;RH0:2hV02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002F0;3PiP03
086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003
086YP@1^QV<0KXIS01@0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003
086YP@1dSF@0M8eT01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03
086YP@1CHT<0Df9300X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2E0;3PiP40
oooo002E0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH
065dF00>065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?J01eSfP02P1eSfQ9086YPA40K8=K
00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086YP@0k@c00>d<`00D0>d<`
00@0PJV101lR6P0O8QX0PJV1U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^9P0302P^9P03086Y
P@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0906j6HaP0PJV1
3023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0PJV107^HJ`1kV6/0
0`1kV6/<086YP@H0K8=K00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086Y
P@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^
9P0202P^9P03086YP@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P02P1QM5P@086YP@/0OIad00<0
PJV108>SN023XgP05P23XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0
PJV107^HJ`1kV6/03`1kV6/A086YP@T0HGA?00<0PJV105=R@`1CHT<02`1CHT<00`21ZH40>d<`03]3
<00403]3<004086YP@0O8QX07b8J086YPI<0/>3V0@3oool009<0/>3V00<0PJV102P^9P0X;RH00P0X
;RH00`21ZH40BEE304UE@`0804UE@`04086YP@1QM5P0HGAH065dF0T0PJV1101bSF/00`21ZH40OIad
07fLM00D07fLM003086YP@23XgP0Pj=h01H0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c
086QL`0H086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d0201^R5d=086YP@X0Df93
00<0PJV103]3<00k@c001@0k@c001021ZH407b8J01lR6P21ZH6B0;3PiP40oooo002B0;3PiP03086Y
P@0X;RH0:2hV00<0:2hV00<0PJV104UE@`19ED<01P19ED<6086YP@`0LXe[00<0PJV107fLM01mW7@0
501mW7@00`21ZH40Pj=h08>SN00G08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<0
6@21XG<00`21ZH40NiQ[07^HJ`0D07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0
1@21ZH4605=R@`03086YP@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40TP2`h>H10?ooo`00TP2`
h>H00`21ZH40:2hV02P^9P0202P^9P03086YP@19ED<0BEE300<0BEE31021ZH400`1LL5P0PJV107:=
J`0?07:=J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BT
M`0I08BTM`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8
G@0B06j8G@03086YP@1NLTd0GW9=00@0GW9=1@21ZH400`1CHT<0PJV103]3<00603]3<004086YP@0O
8QX07b8J086YPI40/>3V0@3oool00940/>3V00<0PJV102P^9P0X;RH00`0X;RH00`21ZH40BEE3086Y
P@03086YP@@0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23
XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I086QL`03086YP@1k
V6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0905ibC@D0PJV11@0k
@c000`21ZH407b8J086YP@2A0;3PiP40oooo002@0;3PiP03086YP@0X;RH0:2hV0080:2hV1021ZH48
05a`F003086YP@1bSF/0LXe[00h0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00G
08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21XG<00`21ZH40NiQ[07^HJ`0E
07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21ZH40AeDj04ME>P04
086YP@0503]3<021ZH407b8J01lR6P21ZH40T02`h>H10?ooo`00T02`h>H00`0X;RH0PJV1086YP@02
086YP@0303M0=`21ZH40G71H00T0G71H00<0PJV107:=J`1bSF/03P1bSF/00`21ZH40OIad07fLM00E
07fLM003086YP@23XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I
086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0<
05ibC@03086YP@17ECX0AeDj00<0AeDj0`21ZH4201lR6P03086YP@2`h>H0/>3V08d0/>3V0@3oool0
08l0/>3V0P21ZH4403M0=`03086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21
ZH40OIad07fLM00D07fLM003086YP@23XgP0Pj=h01P0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21
ZH40PJ5c086QL`0I086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21
ZH40GW9=05ibC@0;05ibC@03086YP@17ECX0AeDj00D0AeDj1021ZH6?0;3PiP40oooo002?0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03
086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM086YP@21ZH6>0;3P
iP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40
LXe[07:=J`0>07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40
KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH40
92LM02@W7@0T9af>0;3PiP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05@1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03086YP@0g@3L0=d0g00<0
=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0
OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0
PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0
GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BTM`03
086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM02@W7@21ZH6<0;3P
iP40oooo002<0;3PiP03086YP@0g@3L0=d0g00@0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40
LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40
KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH40
92LM02@W7@21ZH6<0;3PiP40oooo002<0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05P1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17
ECX01@17ECX01@21ZH4092LM02@W7@0T9ad0PJV108/0/>3V0@3oool008/0/>3V00<0PJV103M0=`0g
@3L0100g@3L00`21ZH40G71H05a`F00805a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01m
W7@05P1mW7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21
XG<06P21XG<00`21ZH40NiQ[07^HJ`0G07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1N
LTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPH/0/>3V0@3oool008/0
/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00l0
LXe[00<0PJV107fLM01mW7@05P1mW7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0
Q:Ag00<0PJV1086QL`21XG<06`21XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0180
KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P05086YP@0T9ad092LM02@W
7@21ZH40RP2`h>H10?ooo`00R`2`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0
G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00E07fLM003086YP@23XgP0Pj=h01T0
Pj=h00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PJ5c086QL`0K086QL`03086YP@1kV6/0NiQ[01H0
NiQ[00<0PJV106j8G@1^R5d04`1^R5d00`21ZH40GW9=05ibC@0<05ibC@03086YP@17ECX0AeDj00H0
AeDj00@0PJV102@W7@0T9ad0PJV1RP2`h>H10?ooo`00RP2`h>H00`21ZH40=d0g03M0=`0403M0=`03
086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/0401bSF/00`21ZH40OIad07fLM00E07fLM003
086YP@23XgP0Pj=h01T0Pj=h00<0PJV108BTM`24Y7L03024Y7LM086YP@l0PJ5c00<0PJV107^HJ`1k
V6/05P1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6:0;3PiP40oooo002:0;3PiP03086YP@0g@3L0=d0g00<0
=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad00X0
OIad=`21ZH4>08jcP`03086YP@2</7h0S;1n00`0S;1n7021ZH4=07^HJ`03086YP@1^R5d0KXQM0180
KXQM00<0PJV105ibC@1NLTd03@1NLTd00`21ZH40AeDj04ME>P0504ME>P05086YP@0T9ad092LM02@W
7@21ZH40R@2`h>H10?ooo`00R@2`h>H00`21ZH40=d0g03M0=`0403M0=`03086YP@1LL5P0G71H00T0
G71H00<0PJV107:=J`1bSF/02`1bSF/A086YP@`0RJf100<0PJV108jcQ02>/h@06@2>/h@00`21ZH40
S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26Z7L02P26Z7LH086YP@/0
KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086Y
PHT0/>3V0@3oool008T0/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003
086YP@1bSF/0LXe[0080LXe[2P21ZH4407nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>
/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26
Z7L05`26Z7L00`21ZH40NiY[07^JJ`0807^JJ`l0PJV12`1NLTd00`21ZH40AeDj04ME>P0604ME>P05
086YP@0T9ad092LM02@W7@21ZH40R02`h>H10?ooo`00R02`h>H00`21ZH40=d0g03M0=`0403M0=`03
086YP@1LL5P0G71H00H0G71H2021ZH4>07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>
/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26
Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`04086YP@1WPEH0Ih5F06N1EPP0PJV1101NLTd00`21
ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPHP0/>3V0@3oool008P0/>3V00<0PJV103M0
=`0g@3L00`0g@3L01021ZH40G71H05a`F01LL5P6086YP@<0JhIY00<0PJV107nPNP1oX7X0401oX7X0
0`21ZH40RJf108V]P@0E08V]P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jcP`2>/h<06P2>/h<0
0`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/0
0`21ZH40Ih5F06N1EP0906N1EPL0PJV11P17ECX01@21ZH4092LM02@W7@0T9ad0PJV108L0/>3V0@3o
ool008L0/>3V00@0PJV103M0=`0g@3L0=d0g1`21ZH4906^6J@03086YP@1oX7X0Oj1j00l0Oj1j00<0
PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301X0S[>300<0
PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0
PJV106N1EP1WPEH0301WPEH00`21ZH40DF=3055S@`05086YP@80AeDj00@0PJV102@W7@0T9ad0PJV1
Q`2`h>H10?ooo`00Q`2`h>H4086YP@<0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21ZH40Oj1j07nP
NP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jc
P`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^J
J`0C07^JJ`03086YP@1WPEH0Ih5F00`0Ih5F00<0PJV1055S@`1AHd<01@1AHd<4086YP@8092LM00<0
PJV10;3PiP2`h>H0Q02`h>H10?ooo`00QP2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02@1[QVT0
0`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@0
0`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L0
0`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01P1AHd<0
0`21ZH40;CDU086YP@02086YPHH0/>3V0@3oool008H0/>3V0P21ZH4504MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg
01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300@0PJV102de9@0]=BD0;CDUQP2`h>H10?ooo`00QP2`h>H00`21ZH40AeQ904MHB@0404MH
B@03086YP@1[QVT0JhIY00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]
P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`OP0L08b`
OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1
EP03086YP@1AHd<0DF=300L0DF=300D0PJV102de9@0]=BD0;CDU086YP@250;3PiP40oooo00260;3P
iP03086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0J08jc
P`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0
PJV108D0/>3V0@3oool008D0/>3V0P21ZH4604MHB@03086YP@1[QVT0JhIY00T0JhIY00<0PJV107nP
NP1oX7X04@1oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>401T0S[>400<0PJV108jc
P`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^J
J`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300H0DF=300D0PJV102de
9@0]=BD0;CDU086YP@250;3PiP40oooo00250;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6
J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jc
Q003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G08JX
M`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S
@`04086YP@0]=BD0;CDU086YPHD0/>3V0@3oool008D0/>3V0P21ZH4504MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg
01P0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@240;3PiP40oooo00250;3PiP03086YP@17F4T0AeQ9
00@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf1
01H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n
01/0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F
00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108@0/>3V0@3oool0
08D0/>3V00<0PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j
0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>3
01`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[
01<0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU
02de9@21ZH40Q02`h>H10?ooo`00Q02`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21
ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21
ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021
ZH40;CDU02de9@21ZH640;3PiP40oooo00240;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6
J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jc
Q003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JX
M`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S
@`05086YP@0]=BD0;CDU02de9@21ZH40P`2`h>H10?ooo`00Q02`h>H2086YP@D0AeQ900<0PJV106^6
J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0A07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jc
Q02>/h@06P2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JX
M`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S
@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108<0/>3V0@3oool008@0/>3V00<0PJV104MH
B@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]
P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`
OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1
EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU02de9@21ZH40P`2`h>H1
0?ooo`00P`2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>308jcP`0L08jc
P`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021ZH40;CDU02de9@21ZH63
0;3PiP40oooo00230;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j
0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h<0S[>3
01`0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[
01<0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU
02de9@21ZH40PP2`h>H10?ooo`00P`2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21
ZH40Oj1j07nPNP0A07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@03@2>/hAJ086Y
P@d0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@220;3PiP40oooo00230;3PiP0301dV8`21ZH40AeQ9
00@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0807nPNS80PJV13P2F_hh00`21
ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H402`2>]H4I086Y
P@/0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU
02de9@21ZH40PP2`h>H10?ooo`00P`2`h>H00`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY
00@0JhIY4@21ZH4908V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21
ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21
ZH40Q:Qf08BXMP0908BXMR40PJV11@1AHd<01021ZH40;CDU02de9@21ZH620;3PiP40oooo00220;3P
iP80PJV10`17F4T:086YP@H0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:k
S003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09Bm
R003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:A
HP03086YP@1GKTT0Efi90080Efi91`21ZH4202de9@03086YP@2`h>H0/>3V07l0/>3V0@3oool00880
/>3V1@21ZH4305A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40
T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40
U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40
LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900<0PJV103=1;021ZH400P21ZH610;3PiP40
oooo00220;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn6
00<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<
00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf
00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021
ZH40P@2`h>H10?ooo`00PP2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10840/>3V0@3oool00880/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg
00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>
00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F1
00<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi9
00D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00220;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00PP2`h>H00`21ZH40E6]I
05A[F@0405A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<
09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f8
09BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R
07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40
oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn6
00<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<
00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf
00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021
ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10840/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg
00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01X0U[n>
00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F1
00<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi9
00D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0I08jeP@03086YP@24Z7H0Q:Qf01<0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I
00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<
00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f8
00<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R
00<0PJV105M^B@1GKTT01`1GKTT01021ZH40<d4/03=1;021ZH610;3PiP40oooo00210;3PiP80PJV1
1P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00
P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800
/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0
7@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0
<d4/086YP@200;3PiP40oooo00210;3PiP0302@_;@21ZH40E6]I00D0E6]I00<0PJV107NHM`1gV7L0
2P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
6@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00840/>3V00<0PJV105A[F@1DJeT0
101DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00
P02`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800
/>3V0@3oool00800/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0
7@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0
<d4/086YP@200;3PiP40oooo00200;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086Y
P@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086Y
P@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086Y
P@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086Y
P@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L0
2`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
6@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00800/>3Vl`21ZH600;3PiP40oooo
00200;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P02`h>H10?ooo`00P02`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bd
O`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9
<@0hBC40PJV10800/>3V0@3oool00800/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0
PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00200;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H00`21ZH40GW]U05ik
I@0405ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6
U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7
T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^N
K@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo
00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bd
O`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9
<@0hBC40PJV10800/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0
PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0
PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0
PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0
PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0
PJV105ahC`1LN4l01`1LN4l01021ZH40>4Ta03Q9<@21ZH610;3PiP40oooo00210;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01<0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00P@2`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06P2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V
0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta
086YP@210;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H00`21ZH40GW]U05ikI@0405ikI@03086YP@20
YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2M
bYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E
`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1L
N4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V
0@3oool00880/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta
086YP@210;3PiP40oooo00220;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H5086YP@<0GW]U00<0PJV1082VPP20YX802P20
YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2M
bYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E
`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1L
N4l00`21ZH40>4Ta03Q9<@02086YPH40/>3V0@3oool00880/>3V0P21ZH4306F7KPX0PJV11P20YX80
0`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH0
0`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X0
0`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00H0Nii]5@21ZH400`0kCc<0PJV10;3PiP20
0;3PiP40oooo00230;3PiP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X01026/8X@086Y
P@X0TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD
01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao
00T0S;Ao5021ZH48086XM@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?<`0kCc<0>dlcPP2`h>H1
0?ooo`00P`2`h>H2086YP@D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0709O6
Uc80PJV13`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0
RP2E`8X02`2E`8XI086YP@/0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00606>3
F005086YP@0kCc<0>dlc03]?<`21ZH40PP2`h>H10?ooo`00P`2`h>H2086YP@H0IHM^00<0PJV108J`
RP26/8X02@26/8X00`21ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid0302RdieK086YP@d0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086X
M@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@220;3PiP40oooo00230;3P
iP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?
W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@
U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086X
M@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40PP2`h>H1
0?ooo`00P`2`h>H2086YP@H0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]>K0:;CV`0L0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH63
0;3PiP40oooo00240;3PiP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21
ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21
ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21
ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21
ZH40>dlc03]?<`0kCc<0PJV108<0/>3V0@3oool008@0/>3V0P21ZH4506F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL04@2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA
01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@230;3PiP40oooo00240;3PiP80PJV11P1UQfh00`21
ZH40Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`00`21
ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21
ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21
ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40P`2`h>H10?ooo`00Q02`h>H2086Y
P@H0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe
00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH640;3PiP40oooo00250;3P
iP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;C
V`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0
PJV108@0/>3V0@3oool008D0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`
RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;C
W@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9
T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3
F005086YP@0kCc<0>dlc03]?<`21ZH40Q02`h>H10?ooo`00Q@2`h>H2086YP@D0IHM^00<0PJV108J`
RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9
T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3
F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108@0/>3V0@3oool008D0/>3V0P21ZH4606F7
KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?
W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@
U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086X
M@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?<`0kCc<0PJV1Q@2`h>H10?ooo`00Q@2`h>H2086Y
P@H0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06@2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe
00d0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108D0/>3V0@3oool0
08H0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG
0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K
01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf7
01<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc
03]?<`21ZH40Q@2`h>H10?ooo`00QP2`h>H00`21ZH40IHM^06F7KP0406F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA
01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@250;3PiP40oooo00230;3PiP<000000P21ZH4506F7
KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?
W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@
U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086X
M@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?<`0kCc<0PJV1QP2`h>H10?ooo`00P`2`h>H40000
0003086YP@000000IHM^00@0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0J0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01P1SPeP00`21ZH40>dlc03]?<`02086Y
PHH0/>3V0@3oool008@0/>3V1P0000001`21ZH40000006F7KP1UQfh0PJV108J`RP0000002@26/8X0
0`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI40
0`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00`0PJQe00<0PJV106>3F01SPeP01@1SPeP5
086YP@0303]B=021ZH40/>3V08D0/>3V0@3oool008D0/>3V0P0000001@21ZH4000000000001XSW@0
000000<0PJV10`00000608J`RP0400000026/8X0Q[2:086YPA40UlJG00<0PJV109o?W02Oci`05P2O
ci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L06`2P
d9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03021
Z7D00`21ZH40Hh=H06>3F005086YP@80Ih]O00@0PJV103]B=00kDS@0PJV1Q`2`h>H10?ooo`00Q@2`
h>H50000000606R>M0000000000006R>M021ZH40RKN@0P000005086YP@<0000000<0Q[2:086YP@2G
aYL0102GaYL00`000000UlJG09O6U`0:09O6U`03086YP@2Oci`0WlnL01D0WlnL00<0PJV10:;CW@2R
did06P2Rdid00`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2K
bI405`2KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00X0PJQe1P21ZH4606N;G`05
086YP@0kDS@0>e8d03]B=021ZH40Q`2`h>H10?ooo`00QP2`h>H50000000506R>M0000000J8id06R>
M021ZH400P00000608VgT08000001P21ZH43000000/0UlJG00D0000009o?W02Oci`0WlnL0000000D
09o?W003086YP@2Rdid0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K
0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@02
086XM@P0PJV10`25/7`00`21ZH40Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d086YPHP0/>3V0@3o
ool008L0/>3V100000001@1XSW@000000000001XSW@0PJV100<000001@29]i020000000308VgT021
ZH40VlfM00<0VlfM00<0PJV10000000000001`21ZH4209O6U`P000004@2Oci`200000003086YP@2R
did0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2K
bI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL02@2A_HL?086YP@X0QK1l00<0PJV106N;G`1WRel01P1W
Rel01@21ZH40>e8d03]B=00kDS@0PJV108P0/>3V0@3oool008L0/>3V1000000206R>M0040000001X
SW@0J8id086YP@8000001@29]i0200000080RKN@00<0PJV109_=W@2KcId00P2KcId2000000L0VlfM
00<0PJV10000000000002@000005086YP@T0WlnL1`00000G0:;CW@0300000021ZH40X]>K0080X]>K
00<000000:;CV`2Rdi/04`2Rdi/01@000000X]>K0:;CV`21ZH40000001<0X=2G00<000000:3@U`2P
d9L01P2Pd9L00`21ZH40VlVA09_9T@0;09_9TAP0PJV12P2Ea8d00`21ZH40QK1l08F`O00<08F`O003
086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV1R@2`h>H10?ooo`00R02`h>H400000005
06R>M0000000J8id06R>M021ZH400P00000508VgT0<0000000<0RKN@086YP@2KcId00`2KcId30000
00L0VlfM0P0000000`2KcId0PJV10:?FXP030:?FXP@00000102SeZ88086YP@/0000000<0PJV10000
000000003P21ZH4<000000L0PJV1202Rdi/>000000P0X=2G0`21ZH44000001D0PJV1302Nd9L00`21
ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00d0QK1l00<0PJV106N;G`1WRel01@1WRel01@21
ZH40>e8d03]B=00kDS@0PJV108T0/>3V0@3oool008P0/>3V100000000`1XSW@000000000000206R>
M08000001P29]i020000000308VgT021ZH40VlfM00@0VlfM0P00000709_=W@8000000P2KcId00`21
ZH40XmJR0:?FXP030:?FXP<000002P2SeZ8300000080XmJR00<0PJV10:KJX`2VfZ<01@0000000`2V
fZ<000000000000<0:KJX`h000001P2VfZ46086YPA4000001`21ZH420:CGW@H000001P2Teid00`21
ZH40W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=01<0ULB=00<0PJV108F`O025/7`03025/7`00`21
ZH40Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d086YPHX0/>3V0@3oool008P0/>3V1@000000101X
SW@0000006R>M01XSW@3000000D0RKN@0P00000208VgT003086YP@2KcId0VlfM0080VlfM0P000006
09_=W@<000000P2KcId00`21ZH40XmJR0:?FXP040:?FXP<00000202SeZ83000000<0XmJR00<0PJV1
0:KJX`2VfZ<00`2VfZ<5000000/0Y]ZS0`0000030:KJX`03086YP@2VfZ40Y]ZQ00@0Y]ZQ0`00000:
0:KJX@@000001@2VfZ400`21ZH40Y=NM0:CGW@040:CGW@8000002P2Teid4000000L0Y=NM00<0PJV1
09k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0C09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV1
06N;G`1WRel01P1WRel01021ZH40>e8d03]B=021ZH6:0;3PiP40oooo00290;3PiP@0000000D0J8id
000000000000J8id086YP@02000000D0RKN@0P00000208VgT003086YP@2KcId0VlfM0080VlfM0`00
000509_=W@8000000`2KcId00`21ZH40XmJR0:?FXP050:?FXP<000001P2SeZ83000000D0XmJR00<0
PJV10:KJX`2VfZ<00`2VfZ<4000000X0Y]ZS0`0000040:KJX`03086YP@2VfZ40Y]ZQ00D0Y]ZQ0`00
00090:KJX@8000001`2VfZ400`21ZH40Y=NM0:CGW@040:CGW@8000002`2Teid3000000L0Y=NM00<0
PJV109k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00`0QK1l00<0
PJV106N;G`1WRel01P1WRel01@21ZH40>e8d03]B=00kDS@0PJV108X0/>3V0@3oool008P0/>3V1@00
000206R>M0030000001XSW@0J8id008000001@29]i030000000308VgT021ZH40VlfM00@0VlfM0P00
000509_=W@8000000`2KcId00`21ZH40XmJR0:?FXP060:?FXP030000002SeZ80XmJR00D0XmJR0P00
00060:?FXP03086YP@2VfZ<0Y]ZS00@0Y]ZS0`0000090:KJX`<000001@2VfZ<00`21ZH40Y]ZQ0:KJ
X@060:KJX@<00000202VfZ400`000000Y]ZQ0:KJX@060:KJX@03086YP@2Teid0Y=NM00@0Y=NM0`00
000;0:CGW@030000002Teid0Y=NM00D0Y=NM00<0PJV109k@U`2Nd9L05`2Nd9L00`21ZH40ULB=09G4
S@0B09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01P1WRel01021ZH40>e8d03]B
=021ZH6;0;3PiP40oooo00290;3PiPD0000000@0J8id000000000000J8id0`00000508VgT0800000
0P29]i000`21ZH40VlfM09_=W@0209_=W@8000001@2KcId2000000@0VlfM00<0PJV10:?FXP2SeZ80
3@2SeZ82000000H0XmJR00<0PJV10:KJX`2VfZ<01@2VfZ<2000000T0Y]ZS0P0000060:KJX`03086Y
P@2VfZ40Y]ZQ00L0Y]ZQ00<000000:KJX@2VfZ401`2VfZ400`000000Y]ZQ0:KJX@060:KJX@03086Y
P@2Teid0Y=NM00@0Y=NM0P00000D0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d0
4`2Ea8d00`21ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00D0Ih]O00D0PJV103]B=00kDS@0
>e8d086YP@2;0;3PiP40oooo00280;3PiPH0000000D0J8id000000000000000006R>M002000000D0
RKN@0P00000208VgT003086YP@2KcId0VlfM0080VlfM0`00000409_=W@800000102KcId00`21ZH40
XmJR0:?FXP0=0:?FXP8000001P2SeZ800`21ZH40Y]ZS0:KJX`060:KJX`800000202VfZ<2000000H0
Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@040:CGW@800000502Teid00`21ZH40
W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=01<0ULB=00<0PJV108F`O025/7`02`25/7`00`21ZH40
Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d086YPH`0/>3V0@3oool008P0/>3V1P00000206R>M080
000000@0J8id00000000000000001029]i0200000080RKN@00<0PJV109_=W@2KcId00`2KcId20000
00@0VlfM400000050:?FXP<000001P2SeZ800`21ZH40Y]ZS0:KJX`060:KJX`8000001`2VfZ<30000
00H0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@030:CGW@8000005@2Teid00`21
ZH40W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`03025/7`00`21
ZH40Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d086YPH`0/>3V0@3oool008/0/>3V10000000101X
SW@000000000001XSW@4000000<0RKN@0`00000208VgT003086YP@2KcId0VlfM0080VlfM0P000004
09_=WA4000001@2SeZ82000000L0XmJR00<0PJV10:KJX`2VfZ<01@2VfZ<2000000L0Y]ZS0P000007
0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid01@00000E0:CGW@03086YP@2Nd9L0
W]2G01H0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00<08F`O003086YP@1WRel0
Ih]O00D0Ih]O00@0PJV103]B=00kDS@0PJV1S@2`h>H10?ooo`00R`2`h>H300000004086YP@1XSW@0
000000000080J8id1000000308VgT0@0000000<0PJV109_=W@2KcId00P2KcId3000000D0VlfM00<0
000009_=W@2KcId00P2KcId00`21ZH40XmJR0:?FXP050:?FXP8000001P2SeZ800`000000XmJR0:?F
XP050:?FXP03086YP@2VfZ<0Y]ZS00D0Y]ZS0P0000070:KJX`8000001`2VfZ<00`21ZH40Y]ZQ0:KJ
X@0E0:KJX@`00000302Teid2000000P0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40ULB=09G4
S@0C09G4S@03086YP@25/7`0QK1l00/0QK1l00<0PJV106N;G`1WRel01P1WRel01021ZH40>e8d03]B
=021ZH6=0;3PiP40oooo002<0;3PiP80000000<0PJV106R>M00000000P0000000`1XSW@000000000
000300000080RKN@1@0000001021ZH40VlfM09_=W@2KcId2000000H0VlfM0P00000309_=W@03086Y
P@2SeZ80XmJR00D0XmJR0P0000060:?FXP8000001P2SeZ800`21ZH40Y]ZS0:KJX`050:KJX`800000
1`2VfZ<E000000T0Y]ZQ3000000?0:CGW@800000202Teid00`21ZH40W]2G09k@U`0E09k@U`03086Y
P@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O06N;G`0506N;G`04086Y
P@0kDS@0>e8d086YPHh0/>3V0@3oool008d0/>3V00D000000;3PiP21ZH40J8id0000000206R>M0h0
00000P2KcId2000000H0VlfM0`00000309_=W@03086YP@2SeZ80XmJR00@0XmJR0`0000060:?FXP80
00001@2SeZ800`21ZH40Y]ZS0:KJX`060:KJX`8000001P2VfZ<E000000P0Y]ZQ1@0000040:KJX@03
086YP@2Teid0Y=NM0100Y=NM0P0000070:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2E
a8d04P2Ea8d00`21ZH40QK1l08F`O00;08F`O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00k
DS@0PJV1SP2`h>H10?ooo`00S@2`h>H200000080PJV1101XSW@00`000000RKN@0000000500000080
RKN@2000000609_=W@@0000000<0VlfM086YP@2SeZ801@2SeZ82000000L0XmJR0`0000040:?FXP03
086YP@2VfZ<0Y]ZS00H0Y]ZS0P0000080:KJX`8000001P2VfZ<00`21ZH40Y]ZQ0:KJX@060:KJX@<0
00001`2VfZ42000000L0Y]ZQ00<0PJV10:CGW@2Teid01@2Teid00`000000Y=NM0:CGW@080:CGW@80
00001`2Teid00`21ZH40W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025
/7`02`25/7`00`21ZH40Ih]O06N;G`0506N;G`04086YP@0kDS@0PJV1086YPHl0/>3V0@3oool008h0
/>3V00<000000;3PiP21ZH401021ZH400`1XSW@0PJV108VgT00908VgT0D00000202KcId6000000@0
XmJR0`0000080:?FXP@000000`2SeZ800`21ZH40Y]ZS0:KJX`030:KJX`@00000202VfZ<3000000D0
Y]ZS00<0PJV10:KJX@2VfZ401@2VfZ43000000L0Y]ZQ0`0000070:KJX@03086YP@2Teid0Y=NM00D0
Y=NM00<000000:CGW@2Teid0202Teid2000000L0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40
ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel00`1WRel4086YP@03
03eH>P21ZH40/>3V08h0/>3V0@3oool008h0/>3V00<000000;3PiP21ZH400`1YTGL010000000PJV1
086YP@21ZH4908VgT003086YP@2KcId0000000`0VlfM2P00000:0:?FXP@000000P2SeZ800`21ZH40
Y]ZS0:KJX`020:KJX`D000002@2VfZ<4000000<0Y]ZS00<0PJV10:KJX@2VfZ40102VfZ43000000T0
Y]ZQ0P0000070:KJX@03086YP@2Teid0Y=NM00@0Y=NM0P00000:0:CGW@8000001`2Teid00`21ZH40
W]2G09k@U`0E09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`02`25/7`00`21ZH40
Ih]O06N;G`04086YP@0506R?H`21ZH40?EPj03eH>P21ZH40T02`h>H10?ooo`00T@2`h>H00`21ZH40
JI5g000000020000000306VAM`21ZH40PJV100<0PJV11@29]i000`21ZH40VlfM09_=W@0>09_=W@L0
00003@2SeZ8400000003086YP@2VfZ<0Y]ZS00@0000000<0Y]ZS0000000000002P2VfZ<600000003
086YP@2VfZ40Y]ZQ00@0Y]ZQ0P00000:0:KJX@8000001`2VfZ400`21ZH40Y=NM0:CGW@030:CGW@80
00002`2Teid2000000L0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03
086YP@25/7`0QK1l00T0QK1l1@21ZH4506R?H`03086YP@0mF3X0?EPj0940/>3V0@3oool00980/>3V
00<0PJV10000000000000P0000000`21ZH40RKZB08VjTP0208VjTP@0PJV10P29]i000`21ZH40VlfM
09_=W@0>09_=W@03086YP@2SeZ80XmJR0140XmJR2@0000020:KJX`800000302VfZ<=000000X0Y]ZQ
1`0000020:KJX@03086YP@000000000000@000002`2Teid2000000P0Y=NM00<0PJV109k@U`2Nd9L0
5@2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00@0QK1l1@21ZH400`25/gl0PJV1
06R?H`0606R?H`04086YP@0mF3X0?EPj086YPI40/>3V0@3oool00980/>3V00<0PJV1000000000000
0P0000000`1YTGL0PJV108VjTP0608VjTPL0PJV1302KcId00`21ZH40XmJR0:?FXP0B0:?FXPH00000
102VfZ<2000000l0Y]ZS2@00000<0:KJX@l000002`2Teid2000000P0Y=NM00<0PJV109k@U`2Nd9L0
502Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00D0PJV11P25/gl00`21ZH40J8mS
06R?H`0506R?H`03086YP@0mF3X0PJV10980/>3V0@3oool009<0/>3V00<0PJV10000000000000P1Y
TGL00`21ZH40RKZB08VjTP0808VjTP04086YP@2Kd:00Vm2P09_@X0T0PJV1102KcId00`21ZH40XmJR
0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS00@0Y]ZS0P00000@0:KJX`05086YP@2VfZ40Y]ZQ0:KJX@00
00004`2VfZ4600000100Y=NM0P0000070:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2E
a8d0202Ea8d=086YP@X0QK=o00<0PJV106R?H`1XSf<01@1XSf<01021ZH40?EPj03eH>P21ZH6B0;3P
iP40oooo002D0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y801`29^Y800`21ZH40
Vm2P09_@X00:09_@X100PJV12`2SeZ800`21ZH40Y]ZS0:KJX`040:KJX`800000402VfZ<00`21ZH40
Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM00l0Y=NM0P0000070:CGW@03086YP@2Nd9L0W]2G0100
W]2G4021ZH4909O9T@03086YP@25/gl0QK=o00/0QK=o00<0PJV106R?H`1XSf<0101XSf<01021ZH40
?EPj03eH>P21ZH6C0;3PiP40oooo002D0;3PiP03086YP@1YTGL0JI5g00<0JI5g00<0PJV108VjTP29
^Y801`29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV00T0Y=ZV4P21ZH42000000@0
PJV1302VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM00l0Y=NM0P0000070:CGW@03
086YP@2Nd9L0W]2G00@0W]2G3021ZH450:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25
/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109@0/>3V0@3oool009D0/>3V
00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00h0Vm2P
00<0PJV10:CJYP2TfZH04`2TfZH00`21ZH40Z=jW0:SNY`040:SNY`800000102XgZLj086YP@800000
3P21ZH4@0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS
06R?H`0506R?H`04086YP@0mF3X0?EPj086YPI@0/>3V0@3oool009H0/>3V00<0PJV106VAM`1YTGL0
0P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH0
502TfZH00`21ZH40Z=jW0:SNY`030:SNY`800000402XgZL00`21ZH40Z=jU0:SNY@0I0:SNY@03086Y
P@2Ufj40YM^Q00l0YM^Q0P0000070:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI40
4@2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40
U@2`h>H10?ooo`00U`2`h>H01@21ZH40JI5g06VAM`1YTGL0PJV100T0RKZB00<0PJV109_@X02Kd:00
3P2Kd:000`21ZH40Y=ZV0:CJYP0C0:CJYP03086YP@2XgZL0Z=jW00<0Z=jW0P00000@0:SNY`03086Y
P@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2Ufj403`2Ufj42000000L0YM^Q00<0PJV10:3EV`2PeI/0
502PeI/00`21ZH40UlVA09O9T@0@09O9T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<0
1@1XSf<00`21ZH40?EPj086YP@2F0;3PiP40oooo002G0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0
PJV108VjTP29^Y801`29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV01<0Y=ZV00<0
PJV10:SNY`2XgZL0102XgZL2000000l0Z=jW00<0PJV10:SNY@2XgZD06@2XgZD00`21ZH40YM^Q0:GK
X@0>0:GKX@8000001`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA00<0
PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3o
ool009P0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0
PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0F0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0
PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0
PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109L0/>3V0@3o
ool009T0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0
PJV10:CJYP2TfZH04`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0
PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0
PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0406R?H`04086YP@0mF3X0?EPj086YPIL0/>3V
0@3oool009T0/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0608VjTP03086YP@2K
d:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2X
gZD0Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2G
bI40UlVA0100UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0m
F3X0PJV109P0/>3V0@3oool009X0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2K
d:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2X
gZD0Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2G
bI40UlVA0100UlVA00<0PJV108FcO`25/gl02@25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0m
F3X0PJV109T0/>3V0@3oool009/0/>3V0P21ZH4206VAM`03086YP@29^Y80RKZB00H0RKZB00<0PJV1
09_@X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV1
0:SNY@2XgZD0602XgZD00`21ZH40YM^Q0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV1
09O9T@2GbI403`2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS0P21ZH6J
0;3PiP40oooo002L0;3PiP@0PJV12@29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV
0180Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0G0:SNY@03086YP@2Ufj40YM^Q
01L0YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0@09O9T@03086YP@25/gl0QK=o
00T0QK=o00<0PJV106R?H`1XSf<00`1XSf<4086YPI/0/>3V0@3oool009`0/>3V00<0PJV106F?M@1U
SgD00`21ZH4708VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40
Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40
X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40
J8mS086YP@03086YP@0306F>I021ZH40PJV109`0/>3V0@3oool009d0/>3V00@0PJV106F?M@1USgD0
IHme1@21ZH4408VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40
Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40
X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl01`25/gl5086YP@@0
IHiT0P21ZH6M0;3PiP40oooo002N0;3PiP05086YP@1USgD0IHme06F?M@21ZH400`25]i05086YPA00
Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0
Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0
UlVA00<0PJV108FcO`25/gl01025/gl4086YP@0308:bP021ZH40IHiT00D0IHiT0P21ZH6N0;3PiP40
oooo002O0;3PiP05086YP@1USgD0IHme06F?M@21ZH401P25]i06086YP@/0Vm2P00<0PJV10:CJYP2T
fZH04@2TfZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2U
fj405P2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`21
ZH401021ZH4408:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6O0;3PiP40oooo002P0;3PiP04086Y
P@1USgD0IHme086YP@P0QKN@00@0PJV109S>W`2HcYl0V<jO2021ZH4409_@X003086YP@2TfZH0Y=ZV
0100Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q
01H0YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0:09O9T@L0PJV12@22/X000`21
ZH40IHiT06F>I00306F>I003086YP@0mFch0PJV109l0/>3V0@3oool00:00/>3V00D0PJV106F?M@1U
SgD0IHme086YP@0808FgT003086YP@2HcYl0V<jO00P0V<jO2@21ZH4>0:CJYP03086YP@2XgZL0Z=jW
01@0Z=jW00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0E0:GKX@03086YP@2PeI/0X=FK
01<0X=FK00<0PJV109O9T@2GbI400P2GbI49086YP@<0U<RB00<0PJV108:bP022/X002@22/X000`21
ZH40IHiT06F>I00306F>I003086YP@0mFch0PJV10:00/>3V0@3oool00:40/>3V00D0PJV106F?M@1U
SgD0IHme086YP@0708FgT003086YP@2HcYl0V<jO00d0V<jO00@0PJV10:;JYP2RfZH0X]ZV2P21ZH45
0:CJYP03086YP@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05@2XgZD00`21ZH40YM^Q0:GKX@0E
0:GKX@03086YP@2PeI/0X=FK00T0X=FK3`21ZH4<09C8TP03086YP@22/X00P[:000P0P[:000<0PJV1
06F>I01USV@00`1USV@00`21ZH40?E/n086YP@2Q0;3PiP40oooo002R0;3PiP05086YP@1USgD0IHme
06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0<09S>W`03086YP@2RfZH0X]ZV00/0X]ZV4@21ZH4;
0:SNY`03086YP@2XgZD0Z=jU01D0Z=jU00<0PJV10:GKX@2Ufj402P2Ufj4G086YP@T0WmJL00<0PJV1
09C8TP2Db9803P2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6R
0;3PiP40oooo002S0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0<
09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP02@2VgjP`086YP@/0YMfS00<0PJV1
09oFW02OeY`04P2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV1
06F>I01USV@0101USV@2086YPJ<0/>3V0@3oool00:@0/>3V00D0PJV106F?M@1USgD0IHme086YP@07
08FgT003086YP@2HcYl0V<jO00/0V<jO00<0PJV10:;JYP2RfZH0402RfZH00`21ZH40Y]nX0:KOZ00C
0:KOZ003086YP@2Wh:L0Yn2W01D0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00B
09oFW003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40IHiT06F>I003
06F>I080PJV1Y02`h>H10?ooo`00Y02`h>H00`21ZH40IHme06F?M@0206F?M@03086YP@25]i00QKN@
00@0QKN@00<0PJV109S>W`2HcYl0302HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX
01<0Y]nX00<0PJV10:OPY`2Wh:L05@2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL
0180WmJL00<0PJV109C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT
00<0IHiT0P21ZH6U0;3PiP40oooo002U0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21
ZH40V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV0100X]ZV00<0PJV10:KOZ02VgjP04P2VgjP00`21
ZH40Yn2W0:OPY`0E0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04@2OeY`00`21
ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1USV@2086Y
PJH0/>3V0@3oool00:H0/>3V0P21ZH4206F?M@03086YP@25]i00QKN@00D0QKN@00<0PJV109S>W`2H
cYl02`2HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0PJV10:OPY`2W
h:L0502Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0140WmJL00<0PJV109C8TP2D
b980302Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6W0;3PiP40
oooo002W0;3PiPD0PJV11`25]i000`21ZH40V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV00l0X]ZV
00<0PJV10:KOZ02VgjP04P2VgjP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2UgJ<0YMfS01<0YMfS
00<0PJV109oFW02OeY`04@2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000L0P[:0
00<0PJV106F>I01USV@00P1USV@2086YPJT0/>3V0@3oool00:T0/>3V00<0PJV105f6KP21ZH400P21
ZH4608FgT003086YP@2HcYl0V<jO00X0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KO
Z00B0:KOZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oF
W00@09oFW003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>
I003086YPJX0/>3V0@3oool00:X0/>3V00<0PJV105f6KP1MQVh01021ZH4308FgT003086YP@2HcYl0
V<jO00/0V<jO00<0PJV10:;JYP2RfZH03P2RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003086YP@2Wh:L0
Yn2W01<0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00@09oFW003086YP@2Db980
U<RB00`0U<RB00<0PJV108:bP022/X002022/X04086YP@0305j7H@21ZH40/>3V0:X0/>3V0@3oool0
0:/0/>3V0P21ZH40101MQVh0PJV107^/R@1k[8T5086YP@`0V<jO00<0PJV10:;JYP2RfZH03`2RfZH0
0`21ZH40Y]nX0:KOZ00A0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<0
0`21ZH40WmJL09oFW00?09oFW003086YP@2Db980U<RB00`0U<RB00<0PJV108:bP022/X001P22/X04
086YP@80GXMQ0P21ZH6/0;3PiP40oooo002]0;3PiP04086YP@1MQVh0PJV1086YP@@0Njb91@21ZH49
09S>W`03086YP@2RfZH0X]ZV00h0X]ZV00<0PJV10:KOZ02VgjP04@2VgjP00`21ZH40Yn2W0:OPY`0C
0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`0402OeY`00`21ZH40U<RB09C8TP0<
09C8TP03086YP@22/X00P[:000H0PJV100<0NZYk086YP@1NQf400P1NQf400`21ZH40/>3V0;3PiP2/
0;3PiP40oooo002^0;3PiP04086YP@1MQVh0GHI^086YP@D0Njb900<0PJV108o5V@2?aIT01`21ZH42
09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP0402VgjP00`21ZH40Yn2W0:OPY`0C
0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`03`2OeY`00`21ZH40U<RB09C8TP09
09C8TPL0PJV11P1jZW/01@21ZH40GXMQ05j7H@1NQf40PJV10:l0/>3V0@3oool00:l0/>3V0P21ZH40
0`1MQVh0PJV107^/R@0407^/R@03086YP@2?aIT0SlFI00H0SlFI2021ZH4<0:;JYP03086YP@2VgjP0
Y]nX0140Y]nX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0
WmJL00l0WmJL00@0PJV109C8TP2Db980U<RB2021ZH4208g2SP03086YP@1jZW/0NZYk00H0NZYk0P21
ZH4305j7H@03086YP@2`h>H0/>3V0:h0/>3V0@3oool00;40/>3V00<0PJV105f6KP21ZH401@1k[8T2
086YP@X0SlFI00@0PJV109[CXP2Jdj80V]>R2@21ZH440:;JYP03086YP@2VgjP0Y]nX0100Y]nX00<0
PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00X0WmJL2@21
ZH4908g2SP03086YP@1jZW/0NZYk00H0NZYk00<0PJV105j7H@1NQf400P1NQf400`21ZH40/>3V0;3P
iP2_0;3PiP40oooo002b0;3PiP03086YP@1MQVh0PJV100H0Njb900<0PJV108o5V@2?aIT0202?aIT0
0`21ZH40V]>R09[CXP0909[CXPh0PJV12@2VgjP00`21ZH40Yn2W0:OPY`0B0:OPY`03086YP@2UgJ<0
YMfS0180YMfS00<0PJV109oFW02OeY`00P2OeY`9086YP@<0V=2J00<0PJV108g2SP2=`Xh02`2=`Xh0
0`21ZH40NZYk07ZZN`0607ZZN`03086YP@1NQf40GXMQ0080GXMQ00<0PJV10;3PiP2`h>H0/02`h>H1
0?ooo`00/`2`h>H3086YP@H0Njb900<0PJV108o5V@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0>09[C
XP03086YP@2PfZD0X=ZU00H0X=ZU>021ZH4<09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZ
N`1jZW/01P1jZW/01021ZH40GXMQ05j7H@1NQf42086YPK<0/>3V0@3oool00;D0/>3V0`21ZH4507^/
R@03086YP@2?aIT0SlFI00L0SlFI00<0PJV109[CXP2Jdj803@2Jdj800`21ZH40X=ZU0:3JY@0?0:3J
Y@03086YP@2Qfj@0XM^T0180XM^T00<0PJV109oHX@2Of:404P2Of:400`21ZH40V=2J09S@VP0=09S@
VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01P1jZW/01@21ZH40GXMQ05j7H@1NQf40
PJV10;D0/>3V0@3oool00;H0/>3V0`21ZH4507^/R@03086YP@2?aIT0SlFI00L0SlFI00<0PJV109[C
XP2Jdj803@2Jdj800`21ZH40X=ZU0:3JY@0?0:3JY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109oH
X@2Of:404@2Of:400`21ZH40V=2J09S@VP0=09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZ
N`1jZW/01@1jZW/2086YP@<0GXMQ00<0PJV10;3PiP2`h>H0]02`h>H10?ooo`00^02`h>H2086YP@D0
Njb90P21ZH4808o5V@03086YP@2Jdj80V]>R00d0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40
XM^T0:7KY00A0:7KY003086YP@2Of:40WmRQ0140WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40
SL:>08g2SP0;08g2SP03086YP@1jZW/0NZYk00@0NZYk00@0PJV105j7H@1NQf40GXMQ0P21ZH6g0;3P
iP40oooo002j0;3PiP<0PJV1101k[8T00`21ZH40SlFI08o5V@0608o5V@03086YP@2Jdj80V]>R00`0
V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Of:40WmRQ0100
WmRQ00<0PJV109S@VP2Hd9X03@2Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0NZYk00@0
NZYk1P21ZH6h0;3PiP40oooo002k0;3PiPH0PJV100<0Njb9086YP@2?aIT01`2?aIT00`21ZH40V]>R
09[CXP0<09[CXP03086YP@2PfZD0X=ZU00d0X=ZU00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40WmRQ
09oHX@0@09oHX@03086YP@2Hd9X0V=2J00`0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk
07ZZN`0307ZZN`<0PJV100<0DWYI086YP@21ZH40^P2`h>H10?ooo`00_@2`h>H2086YP@80JYUj1021
ZH4608o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7K
Y00?0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2
SP0:08g2SP04086YP@1jZW/0NZYk07ZZN`@0PJV100<0DWYI086YP@21ZH40_02`h>H10?ooo`00_`2`
h>H2086YP@<0JYUj1@21ZH4308o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03@2P
fZD00`21ZH40XM^T0:7KY00?0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X02`2H
d9X00`21ZH40SL:>08g2SP0:08g2SPL0PJV100<0DWYI086YP@21ZH40_P2`h>H10?ooo`00`@2`h>H2
086YP@<0JYUj0P21ZH400`1n/X/0PJV1086YP@03086YP@h0V]>R00<0PJV10:3JY@2PfZD0302PfZD0
0`21ZH40XM^T0:7KY00?0:7KY003086YP@2Of:40WmRQ00l0WmRQ00<0PJV109S@VP2Hd9X0302Hd9X0
0`21ZH40SL:>08g2SP0308g2SPP0PJV10P1[VG42086YP@03059jF@21ZH40PJV10<00/>3V0@3oool0
0<<0/>3V0P21ZH4306ZINP03086YP@1n/X/0O[:;0080O[:;2@21ZH4609[CXP03086YP@2PfZD0X=ZU
00`0X=ZU00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40WmRQ09oHX@0?09oHX@03086YP@2Hd9X0V=2J
00P0V=2J2P21ZH4407faP`80PJV10`1[VG401021ZH40DWYI086YP@21ZH720;3PiP40oooo00350;3P
iP80PJV10P1ZVGX2086YP@@0O[:;0P21ZH4508[2U@l0PJV11`2PfZD00`21ZH40XM^T0:7KY00>0:7K
Y003086YP@2Of:40WmRQ00h0WmRQ00@0PJV109S@VP2Hd9X0V=2J2021ZH4208W0S`03086YP@1m/H<0
OK6300L0OK630P21ZH4306^IL@@0PJV1a02`h>H10?ooo`00aP2`h>H3086YP@80JYUj00<0PJV107jb
R`1n/X/00`1n/X/00`21ZH40R/:E08[2U@0:08[2U@03086YP@2AbYX0TLZJ00@0TLZJ;@21ZH4908W0
S`03086YP@1m/H<0OK6300L0OK6300@0PJV106^IL@1[VG40JiUa1021ZH760;3PiP40oooo00380;3P
iP<0PJV100<0JYUj086YP@21ZH40101n/X/2086YP@/0R/:E00<0PJV1097:VP2AbYX02`2AbYX00`21
ZH40TlbJ09?<VP0=09?<VP03086YP@2AbIL0TLVG00d0TLVG00<0PJV108W0S`29`8l02P29`8l00`21
ZH40OK6307faP`0607faP`80PJV10P1[VG43086YPLT0/>3V0@3oool00</0/>3V1@21ZH4407jbR`80
PJV12P2:`YD00`21ZH40TLZJ097:VP0:097:VP03086YP@2Cc9X0TlbJ00d0TlbJ00<0PJV10979U`2A
bIL0302AbIL00`21ZH40RL2?08W0S`0908W0S`80PJV11`1m/H<2086YP@80JiUa0`21ZH7;0;3PiP40
oooo003=0;3PiPH0PJV10`1n/X/00`21ZH40R/:E08[2U@0808[2U@03086YP@2AbYX0TLZJ00X0TLZJ
00<0PJV109?<VP2Cc9X0302Cc9X00`21ZH40TLVG0979U`0;0979U`03086YP@29`8l0RL2?00T0RL2?
00<0PJV107faP`1m/H<01@1m/H<6086YPLh0/>3V0@3oool00=00/>3V2@21ZH4908[2U@03086YP@2A
bYX0TLZJ00T0TLZJ00<0PJV109?<VP2Cc9X02`2Cc9X00`21ZH40TLVG0979U`0<0979U`03086YP@29
`8l0RL2?00P0RL2?00<0PJV107faP`1m/H<00`1m/H<6086YPM40/>3V0@3oool00=<0/>3V3021ZH44
08[2U@03086YP@2AbYX0TLZJ00T0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21ZH40TLVG0979U`0;
0979U`03086YP@29`8l0RL2?00P0RL2?00<0PJV107faP`21ZH402021ZH7C0;3PiP40oooo003E0;3P
iPD0PJV100D0I99d086YP@21ZH40PJV106nQO@0;086YP@D0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X0
0`21ZH40TLVG0979U`0:0979U`03086YP@29`8l0RL2?00<0RL2?2021ZH400`1TTfl0PJV1086YP@03
086YPMH0/>3V0@3oool00=P0/>3V1@21ZH400`1TTW@0PJV1086YP@0506nQO@80PJV10`1fZH<U086Y
P@80L:5j0P21ZH4206BCK`D0PJV1f@2`h>H10?ooo`00g02`h>H7086YP@@0Kj5m0P21ZH4807JYP`03
086YP@1h[8@0N:b400P0N:b400<0PJV107JYP@1fZH401`1fZH42086YP@L0L:5j0P21ZH4206BCK`<0
PJV1g@2`h>H10?ooo`00h@2`h>H7086YP@0306nQO@21ZH40PJV100H0MZV300<0PJV107R/Q01h[8@0
1`1h[8@00`21ZH40MZV107JYP@0607JYP@80PJV11`1`XGX6086YPN00/>3V0@3oool00>P0/>3V1`21
ZH4307JYP`03086YP@1h[8@0N:b400H0N:b400<0PJV107JYP@1fZH400P1fZH4?086YPN@0/>3V0@3o
ool00>l0/>3V4P21ZH7b0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.606 .779 .568 r
.46017 .46966 m .45976 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.5 .5 m .5 .46978 L .46017 .46966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.5 .53022 m .5 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.5 .46978 m .5 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.5 .5 m .5 .53022 L .53983 .53034 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.53983 .53034 m .54024 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.46139 .43966 m .46017 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.5 .46978 m .5 .43989 L .46139 .43966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.45976 .5 m .46017 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.5 .56011 m .5 .53022 L .46017 .53034 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.5 .43989 m .5 .46978 L .53983 .46966 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.54024 .5 m .53983 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.5 .53022 m .5 .56011 L .53861 .56034 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.53861 .56034 m .53983 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.42114 .46929 m .42033 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.45976 .5 m .46017 .46966 L .42114 .46929 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.46017 .53034 m .45976 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.53983 .46966 m .54024 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.54024 .5 m .53983 .53034 L .57886 .53071 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.57886 .53071 m .57967 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.42358 .43896 m .42114 .46929 L .46017 .46966 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.46017 .46966 m .46139 .43966 L .42358 .43896 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.42033 .5 m .42114 .53071 L .46017 .53034 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.46139 .56034 m .46017 .53034 L .42114 .53071 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.46017 .53034 m .46139 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.53983 .46966 m .53861 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.53861 .43966 m .53983 .46966 L .57886 .46929 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.57967 .5 m .57886 .46929 L .53983 .46966 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.53983 .53034 m .53861 .56034 L .57642 .56104 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.57642 .56104 m .57886 .53071 L .53983 .53034 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.46342 .41036 m .46139 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.5 .43989 m .5 .41069 L .46342 .41036 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.5 .41069 m .5 .43989 L .53861 .43966 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.5 .58931 m .5 .56011 L .46139 .56034 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.5 .56011 m .5 .58931 L .53658 .58964 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.53658 .58964 m .53861 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.42766 .40937 m .42358 .43896 L .46139 .43966 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.46139 .43966 m .46342 .41036 L .42766 .40937 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.42114 .53071 m .42358 .56104 L .46139 .56034 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.46342 .58964 m .46139 .56034 L .42358 .56104 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.46139 .56034 m .46342 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.53861 .43966 m .53658 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.53658 .41036 m .53861 .43966 L .57642 .43896 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.57886 .46929 m .57642 .43896 L .53861 .43966 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.53861 .56034 m .53658 .58964 L .57234 .59063 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.57234 .59063 m .57642 .56104 L .53861 .56034 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.38378 .46868 m .38255 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.42033 .5 m .42114 .46929 L .38378 .46868 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.42114 .53071 m .42033 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.57886 .46929 m .57967 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.57967 .5 m .57886 .53071 L .61622 .53132 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.61622 .53132 m .61745 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.38745 .43778 m .38378 .46868 L .42114 .46929 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.42114 .46929 m .42358 .43896 L .38745 .43778 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.38255 .5 m .38378 .53132 L .42114 .53071 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.42358 .56104 m .42114 .53071 L .38378 .53132 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.57642 .43896 m .57886 .46929 L .61622 .46868 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.61745 .5 m .61622 .46868 L .57886 .46929 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.57886 .53071 m .57642 .56104 L .61255 .56222 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.61255 .56222 m .61622 .53132 L .57886 .53071 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.46628 .38215 m .46342 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.5 .41069 m .5 .38255 L .46628 .38215 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.5 .38255 m .5 .41069 L .53658 .41036 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.5 .61745 m .5 .58931 L .46342 .58964 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.5 .58931 m .5 .61745 L .53372 .61785 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.53372 .61785 m .53658 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.43336 .38095 m .42766 .40937 L .46342 .41036 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.46342 .41036 m .46628 .38215 L .43336 .38095 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.42358 .56104 m .42766 .59063 L .46342 .58964 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.46628 .61785 m .46342 .58964 L .42766 .59063 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.46342 .58964 m .46628 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.53658 .41036 m .53372 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.53372 .38215 m .53658 .41036 L .57234 .40937 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.57642 .43896 m .57234 .40937 L .53658 .41036 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.53658 .58964 m .53372 .61785 L .56664 .61905 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.56664 .61905 m .57234 .59063 L .53658 .58964 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.39355 .40772 m .38745 .43778 L .42358 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.42358 .43896 m .42766 .40937 L .39355 .40772 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.38378 .53132 m .38745 .56222 L .42358 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.42766 .59063 m .42358 .56104 L .38745 .56222 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.57234 .40937 m .57642 .43896 L .61255 .43778 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.61622 .46868 m .61255 .43778 L .57642 .43896 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.57642 .56104 m .57234 .59063 L .60645 .59228 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.60645 .59228 m .61255 .56222 L .57642 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.38745 .56222 m .39355 .59228 L .42766 .59063 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.43336 .61905 m .42766 .59063 L .39355 .59228 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.42766 .59063 m .43336 .61905 L .46628 .61785 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.40208 .37896 m .39355 .40772 L .42766 .40937 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.42766 .40937 m .43336 .38095 L .40208 .37896 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.57234 .40937 m .56664 .38095 L .53372 .38215 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.56664 .38095 m .57234 .40937 L .60645 .40772 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.61255 .43778 m .60645 .40772 L .57234 .40937 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.57234 .59063 m .56664 .61905 L .59792 .62104 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.59792 .62104 m .60645 .59228 L .57234 .59063 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.34905 .46783 m .34741 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.38255 .5 m .38378 .46868 L .34905 .46783 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.38378 .53132 m .38255 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.46995 .35545 m .46628 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.5 .38255 m .5 .35589 L .46995 .35545 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.5 .64411 m .5 .61745 L .46628 .61785 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.5 .35589 m .5 .38255 L .53372 .38215 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.5 .61745 m .5 .64411 L .53005 .64455 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.53005 .64455 m .53372 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.61622 .46868 m .61745 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.61745 .5 m .61622 .53132 L .65095 .53217 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.65095 .53217 m .65259 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.35394 .43614 m .34905 .46783 L .38378 .46868 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.38378 .46868 m .38745 .43778 L .35394 .43614 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.34741 .5 m .34905 .53217 L .38378 .53132 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.38745 .56222 m .38378 .53132 L .34905 .53217 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.61255 .43778 m .61622 .46868 L .65095 .46783 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.65259 .5 m .65095 .46783 L .61622 .46868 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.61622 .53132 m .61255 .56222 L .64606 .56386 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.64606 .56386 m .65095 .53217 L .61622 .53132 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.44068 .35415 m .43336 .38095 L .46628 .38215 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.46628 .38215 m .46995 .35545 L .44068 .35415 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.46995 .64455 m .46628 .61785 L .43336 .61905 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.46628 .61785 m .46995 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.53372 .38215 m .53005 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.53005 .35545 m .53372 .38215 L .56664 .38095 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.53372 .61785 m .53005 .64455 L .55932 .64585 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.55932 .64585 m .56664 .61905 L .53372 .61785 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.36206 .40542 m .35394 .43614 L .38745 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.38745 .43778 m .39355 .40772 L .36206 .40542 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.34905 .53217 m .35394 .56386 L .38745 .56222 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.39355 .59228 m .38745 .56222 L .35394 .56386 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.60645 .40772 m .61255 .43778 L .64606 .43614 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.61307 .43776 m
.61314 .43824 L
s
.5 Mabswid
.614 .796 .599 r
.65095 .46783 m .64606 .43614 L .61255 .43778 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.61255 .56222 m .60645 .59228 L .63794 .59458 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.63794 .59458 m .64606 .56386 L .61255 .56222 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.41299 .35198 m .40208 .37896 L .43336 .38095 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.43336 .38095 m .44068 .35415 L .41299 .35198 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.39355 .59228 m .40208 .62104 L .43336 .61905 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.44068 .64585 m .43336 .61905 L .40208 .62104 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.43336 .61905 m .44068 .64585 L .46995 .64455 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.56664 .38095 m .55932 .35415 L .53005 .35545 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.55932 .35415 m .56664 .38095 L .59792 .37896 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.60645 .40772 m .59792 .37896 L .56664 .38095 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.56664 .61905 m .55932 .64585 L .58701 .64802 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.58701 .64802 m .59792 .62104 L .56664 .61905 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.37336 .37619 m .36206 .40542 L .39355 .40772 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.39355 .40772 m .40208 .37896 L .37336 .37619 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.35394 .56386 m .36206 .59458 L .39355 .59228 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.40208 .62104 m .39355 .59228 L .36206 .59458 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.59792 .37896 m .60645 .40772 L .63794 .40542 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.64606 .43614 m .63794 .40542 L .60645 .40772 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.60645 .59228 m .59792 .62104 L .62664 .62381 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.62664 .62381 m .63794 .59458 L .60645 .59228 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.47443 .33074 m .46995 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.5 .35589 m .5 .33118 L .47443 .33074 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.5 .33118 m .5 .35589 L .53005 .35545 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.5 .66882 m .5 .64411 L .46995 .64455 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.5 .64411 m .5 .66882 L .52557 .66926 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.52557 .66926 m .53005 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.4496 .32944 m .44068 .35415 L .46995 .35545 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.46995 .35545 m .47443 .33074 L .4496 .32944 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.47443 .66926 m .46995 .64455 L .44068 .64585 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.46995 .64455 m .47443 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.53005 .35545 m .52557 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.52557 .33074 m .53005 .35545 L .55932 .35415 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.53005 .64455 m .52557 .66926 L .5504 .67056 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.5504 .67056 m .55932 .64585 L .53005 .64455 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.31808 .46673 m .31604 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.34741 .5 m .34905 .46783 L .31808 .46673 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.34905 .53217 m .34741 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.65095 .46783 m .65259 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.65259 .5 m .65095 .53217 L .68192 .53327 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.68192 .53327 m .68396 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.32417 .43403 m .31808 .46673 L .34905 .46783 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.34905 .46783 m .35394 .43614 L .32417 .43403 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.31604 .5 m .31808 .53327 L .34905 .53217 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.35394 .56386 m .34905 .53217 L .31808 .53327 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.64606 .43614 m .65095 .46783 L .68192 .46673 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.68396 .5 m .68192 .46673 L .65095 .46783 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.65095 .53217 m .64606 .56386 L .67583 .56597 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.67583 .56597 m .68192 .53327 L .65095 .53217 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.38776 .34897 m .37336 .37619 L .40208 .37896 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.40208 .37896 m .41299 .35198 L .38776 .34897 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.36206 .59458 m .37336 .62381 L .40208 .62104 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.41299 .64802 m .40208 .62104 L .37336 .62381 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.40208 .62104 m .41299 .64802 L .44068 .64585 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.59792 .37896 m .58701 .35198 L .55932 .35415 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.58701 .35198 m .59792 .37896 L .62664 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.63794 .40542 m .62664 .37619 L .59792 .37896 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.59792 .62104 m .58701 .64802 L .61224 .65103 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.61224 .65103 m .62664 .62381 L .59792 .62104 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.42624 .32729 m .41299 .35198 L .44068 .35415 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.44068 .35415 m .4496 .32944 L .42624 .32729 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.4496 .67056 m .44068 .64585 L .41299 .64802 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.44068 .64585 m .4496 .67056 L .47443 .66926 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.55932 .35415 m .5504 .32944 L .52557 .33074 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.5504 .32944 m .55932 .35415 L .58701 .35198 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.55932 .64585 m .5504 .67056 L .57376 .67271 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.57376 .67271 m .58701 .64802 L .55932 .64585 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.33425 .40248 m .32417 .43403 L .35394 .43614 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.35394 .43614 m .36206 .40542 L .33425 .40248 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.31808 .53327 m .32417 .56597 L .35394 .56386 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.36206 .59458 m .35394 .56386 L .32417 .56597 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.63794 .40542 m .64606 .43614 L .67583 .43403 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.68192 .46673 m .67583 .43403 L .64606 .43614 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.64606 .56386 m .63794 .59458 L .66575 .59752 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.66575 .59752 m .67583 .56597 L .64606 .56386 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.34822 .37266 m .33425 .40248 L .36206 .40542 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.36206 .40542 m .37336 .37619 L .34822 .37266 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.32417 .56597 m .33425 .59752 L .36206 .59458 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.37336 .62381 m .36206 .59458 L .33425 .59752 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.62664 .37619 m .63794 .40542 L .66575 .40248 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.67583 .43403 m .66575 .40248 L .63794 .40542 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.63794 .59458 m .62664 .62381 L .65178 .62734 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.65178 .62734 m .66575 .59752 L .63794 .59458 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.47972 .30855 m .47443 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.5 .33118 m .5 .30894 L .47972 .30855 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.5 .30894 m .5 .33118 L .52557 .33074 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.5 .69106 m .5 .66882 L .47443 .66926 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.5 .66882 m .5 .69106 L .52028 .69145 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.52028 .69145 m .52557 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.46008 .30739 m .4496 .32944 L .47443 .33074 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.47443 .33074 m .47972 .30855 L .46008 .30739 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.47972 .69145 m .47443 .66926 L .4496 .67056 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.47443 .66926 m .47972 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.52557 .66926 m .52028 .69145 L .53992 .69261 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.53992 .69261 m .5504 .67056 L .52557 .66926 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.52557 .33074 m .52028 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.52028 .30855 m .52557 .33074 L .5504 .32944 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.40515 .32433 m .38776 .34897 L .41299 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.41299 .35198 m .42624 .32729 L .40515 .32433 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.37336 .62381 m .38776 .65103 L .41299 .64802 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.42624 .67271 m .41299 .64802 L .38776 .65103 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.41299 .64802 m .42624 .67271 L .4496 .67056 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.58701 .35198 m .57376 .32729 L .5504 .32944 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.57376 .32729 m .58701 .35198 L .61224 .34897 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.62664 .37619 m .61224 .34897 L .58701 .35198 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.58701 .64802 m .57376 .67271 L .59485 .67567 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.59485 .67567 m .61224 .65103 L .58701 .64802 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.36592 .34517 m .34822 .37266 L .37336 .37619 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.37336 .37619 m .38776 .34897 L .36592 .34517 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.33425 .59752 m .34822 .62734 L .37336 .62381 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.38776 .65103 m .37336 .62381 L .34822 .62734 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.61224 .34897 m .62664 .37619 L .65178 .37266 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.66575 .40248 m .65178 .37266 L .62664 .37619 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.62664 .62381 m .61224 .65103 L .63408 .65483 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.63408 .65483 m .65178 .62734 L .62664 .62381 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.44174 .30547 m .42624 .32729 L .4496 .32944 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.4496 .32944 m .46008 .30739 L .44174 .30547 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.46008 .69261 m .4496 .67056 L .42624 .67271 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.4496 .67056 m .46008 .69261 L .47972 .69145 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.5504 .32944 m .53992 .30739 L .52028 .30855 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.53992 .30739 m .5504 .32944 L .57376 .32729 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.5504 .67056 m .53992 .69261 L .55826 .69453 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.55826 .69453 m .57376 .67271 L .5504 .67056 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.67817 .44658 m
.67931 .44723 L
s
.5 Mabswid
.481 .618 .426 r
.29221 .4654 m .28979 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.31604 .5 m .31808 .46673 L .29221 .4654 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.31808 .53327 m .31604 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.68192 .46673 m .68396 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.68396 .5 m .68192 .53327 L .70779 .5346 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.70779 .5346 m .71021 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.67294 .42498 m
.67369 .42414 L
s
.5 Mabswid
.503 .654 .455 r
.29943 .43148 m .29221 .4654 L .31808 .46673 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.31808 .46673 m .32417 .43403 L .29943 .43148 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.28979 .5 m .29221 .5346 L .31808 .53327 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.32417 .56597 m .31808 .53327 L .29221 .5346 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.67583 .43403 m .68192 .46673 L .70779 .4654 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.71021 .5 m .70779 .4654 L .68192 .46673 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.68192 .53327 m .67583 .56597 L .70057 .56852 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.70057 .56852 m .70779 .5346 L .68192 .53327 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42535 .30284 m .40515 .32433 L .42624 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42624 .32729 m .44174 .30547 L .42535 .30284 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.38776 .65103 m .40515 .67567 L .42624 .67271 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.44174 .69453 m .42624 .67271 L .40515 .67567 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.42624 .67271 m .44174 .69453 L .46008 .69261 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.31135 .39893 m .29943 .43148 L .32417 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.32417 .43403 m .33425 .40248 L .31135 .39893 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.57376 .32729 m .55826 .30547 L .53992 .30739 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.55826 .30547 m .57376 .32729 L .59485 .32433 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.61224 .34897 m .59485 .32433 L .57376 .32729 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.29221 .5346 m .29943 .56852 L .32417 .56597 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.33425 .59752 m .32417 .56597 L .29943 .56852 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57376 .67271 m .55826 .69453 L .57465 .69716 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57465 .69716 m .59485 .67567 L .57376 .67271 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.66575 .40248 m .67583 .43403 L .70057 .43148 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.70779 .4654 m .70057 .43148 L .67583 .43403 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.67583 .56597 m .66575 .59752 L .68865 .60107 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.68865 .60107 m .70057 .56852 L .67583 .56597 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38713 .32061 m .36592 .34517 L .38776 .34897 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38776 .34897 m .40515 .32433 L .38713 .32061 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.34822 .62734 m .36592 .65483 L .38776 .65103 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.40515 .67567 m .38776 .65103 L .36592 .65483 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.59485 .32433 m .61224 .34897 L .63408 .34517 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.65178 .37266 m .63408 .34517 L .61224 .34897 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61224 .65103 m .59485 .67567 L .61287 .67939 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61287 .67939 m .63408 .65483 L .61224 .65103 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.48578 .28949 m .47972 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.5 .30894 m .5 .28979 L .48578 .28949 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.5 .28979 m .5 .30894 L .52028 .30855 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.5 .71021 m .5 .69106 L .47972 .69145 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.5 .69106 m .5 .71021 L .51422 .71051 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51422 .71051 m .52028 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.32778 .36843 m .31135 .39893 L .33425 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.33425 .40248 m .34822 .37266 L .32778 .36843 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.29943 .56852 m .31135 .60107 L .33425 .59752 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.34822 .62734 m .33425 .59752 L .31135 .60107 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.65178 .37266 m .66575 .40248 L .68865 .39893 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.70057 .43148 m .68865 .39893 L .66575 .40248 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.66575 .59752 m .65178 .62734 L .67222 .63157 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.67222 .63157 m .68865 .60107 L .66575 .59752 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47206 .28859 m .46008 .30739 L .47972 .30855 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47972 .30855 m .48578 .28949 L .47206 .28859 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.48578 .71051 m .47972 .69145 L .46008 .69261 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47972 .69145 m .48578 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.52028 .30855 m .51422 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.51422 .28949 m .52028 .30855 L .53992 .30739 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52028 .69145 m .51422 .71051 L .52794 .71141 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52794 .71141 m .53992 .69261 L .52028 .69145 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.45934 .28712 m .44174 .30547 L .46008 .30739 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.46008 .30739 m .47206 .28859 L .45934 .28712 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.47206 .71141 m .46008 .69261 L .44174 .69453 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.46008 .69261 m .47206 .71141 L .48578 .71051 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.53992 .30739 m .52794 .28859 L .51422 .28949 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.52794 .28859 m .53992 .30739 L .55826 .30547 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.53992 .69261 m .52794 .71141 L .54066 .71288 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.54066 .71288 m .55826 .69453 L .53992 .69261 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34844 .34065 m .32778 .36843 L .34822 .37266 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34822 .37266 m .36592 .34517 L .34844 .34065 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.31135 .60107 m .32778 .63157 L .34822 .62734 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.36592 .65483 m .34822 .62734 L .32778 .63157 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.63408 .34517 m .65178 .37266 L .67222 .36843 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.68865 .39893 m .67222 .36843 L .65178 .37266 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65178 .62734 m .63408 .65483 L .65156 .65935 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65156 .65935 m .67222 .63157 L .65178 .62734 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.41156 .29957 m .38713 .32061 L .40515 .32433 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.40515 .32433 m .42535 .30284 L .41156 .29957 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.36592 .65483 m .38713 .67939 L .40515 .67567 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.42535 .69716 m .40515 .67567 L .38713 .67939 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.40515 .67567 m .42535 .69716 L .44174 .69453 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.59485 .32433 m .57465 .30284 L .55826 .30547 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.57465 .30284 m .59485 .32433 L .61287 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.63408 .34517 m .61287 .32061 L .59485 .32433 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.59485 .67567 m .57465 .69716 L .58844 .70043 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.58844 .70043 m .61287 .67939 L .59485 .67567 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44812 .28512 m .42535 .30284 L .44174 .30547 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44174 .30547 m .45934 .28712 L .44812 .28512 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.45934 .71288 m .44174 .69453 L .42535 .69716 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.44174 .69453 m .45934 .71288 L .47206 .71141 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.55826 .30547 m .54066 .28712 L .52794 .28859 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.54066 .28712 m .55826 .30547 L .57465 .30284 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55826 .69453 m .54066 .71288 L .55188 .71488 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55188 .71488 m .57465 .69716 L .55826 .69453 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29823 .56767 m
.30027 .57081 L
s
.5 Mabswid
.562 .759 .548 r
.37301 .31621 m .34844 .34065 L .36592 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.36592 .34517 m .38713 .32061 L .37301 .31621 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.32778 .63157 m .34844 .65935 L .36592 .65483 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.38713 .67939 m .36592 .65483 L .34844 .65935 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.61287 .32061 m .63408 .34517 L .65156 .34065 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.67222 .36843 m .65156 .34065 L .63408 .34517 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.63408 .65483 m .61287 .67939 L .62699 .68379 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.62699 .68379 m .65156 .65935 L .63408 .65483 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.49256 .27421 m .48578 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.5 .28979 m .5 .27438 L .49256 .27421 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.5 .27438 m .5 .28979 L .51422 .28949 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.5 .72562 m .5 .71021 L .48578 .71051 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.5 .71021 m .5 .72562 L .50744 .72579 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.50744 .72579 m .51422 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.70779 .4654 m .71021 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.71021 .5 m .70779 .5346 L .72703 .53616 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.72703 .53616 m .7298 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.27297 .46384 m .2702 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.28979 .5 m .29221 .4654 L .27297 .46384 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.29221 .5346 m .28979 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.70057 .43148 m .70779 .4654 L .72703 .46384 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.7298 .5 m .72703 .46384 L .70779 .4654 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.70779 .5346 m .70057 .56852 L .7188 .57148 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.7188 .57148 m .72703 .53616 L .70779 .5346 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.2812 .42852 m .27297 .46384 L .29221 .4654 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.29221 .4654 m .29943 .43148 L .2812 .42852 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.2702 .5 m .27297 .53616 L .29221 .5346 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.29943 .56852 m .29221 .5346 L .27297 .53616 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.43884 .28266 m .41156 .29957 L .42535 .30284 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.42535 .30284 m .44812 .28512 L .43884 .28266 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.38713 .67939 m .41156 .70043 L .42535 .69716 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.44812 .71488 m .42535 .69716 L .41156 .70043 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.42535 .69716 m .44812 .71488 L .45934 .71288 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.57465 .30284 m .55188 .28512 L .54066 .28712 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.55188 .28512 m .57465 .30284 L .58844 .29957 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.61287 .32061 m .58844 .29957 L .57465 .30284 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.57465 .69716 m .55188 .71488 L .56116 .71734 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.56116 .71734 m .58844 .70043 L .57465 .69716 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48542 .27371 m .47206 .28859 L .48578 .28949 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48578 .28949 m .49256 .27421 L .48542 .27371 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51422 .28949 m .50744 .27421 L .5 .27438 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.50744 .27421 m .51422 .28949 L .52794 .28859 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.49256 .72579 m .48578 .71051 L .47206 .71141 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.48578 .71051 m .49256 .72579 L .5 .72562 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51422 .71051 m .50744 .72579 L .51458 .72629 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51458 .72629 m .52794 .71141 L .51422 .71051 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.40102 .29574 m .37301 .31621 L .38713 .32061 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.38713 .32061 m .41156 .29957 L .40102 .29574 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.34844 .65935 m .37301 .68379 L .38713 .67939 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.41156 .70043 m .38713 .67939 L .37301 .68379 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.58844 .29957 m .61287 .32061 L .62699 .31621 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.65156 .34065 m .62699 .31621 L .61287 .32061 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.61287 .67939 m .58844 .70043 L .59898 .70426 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.59898 .70426 m .62699 .68379 L .61287 .67939 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.68865 .39893 m .70057 .43148 L .7188 .42852 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.72703 .46384 m .7188 .42852 L .70057 .43148 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70057 .56852 m .68865 .60107 L .70527 .60517 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70527 .60517 m .7188 .57148 L .70057 .56852 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.27297 .53616 m .2812 .57148 L .29943 .56852 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.31135 .60107 m .29943 .56852 L .2812 .57148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29473 .39483 m .2812 .42852 L .29943 .43148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29943 .43148 m .31135 .39893 L .29473 .39483 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47886 .27289 m .45934 .28712 L .47206 .28859 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47206 .28859 m .48542 .27371 L .47886 .27289 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.48542 .72629 m .47206 .71141 L .45934 .71288 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.47206 .71141 m .48542 .72629 L .49256 .72579 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.52794 .28859 m .51458 .27371 L .50744 .27421 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.51458 .27371 m .52794 .28859 L .54066 .28712 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52794 .71141 m .51458 .72629 L .52114 .72711 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52114 .72711 m .54066 .71288 L .52794 .71141 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.67222 .36843 m .68865 .39893 L .70527 .39483 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.7188 .42852 m .70527 .39483 L .68865 .39893 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68865 .60107 m .67222 .63157 L .68674 .63642 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68674 .63642 m .70527 .60517 L .68865 .60107 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31326 .36358 m .29473 .39483 L .31135 .39893 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31135 .39893 m .32778 .36843 L .31326 .36358 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.2812 .57148 m .29473 .60517 L .31135 .60107 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.32778 .63157 m .31135 .60107 L .29473 .60517 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.47314 .27179 m .44812 .28512 L .45934 .28712 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.45934 .28712 m .47886 .27289 L .47314 .27179 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.47886 .72711 m .45934 .71288 L .44812 .71488 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.45934 .71288 m .47886 .72711 L .48542 .72629 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.54066 .28712 m .52114 .27289 L .51458 .27371 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.52114 .27289 m .54066 .28712 L .55188 .28512 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.54066 .71288 m .52114 .72711 L .52686 .72821 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.52686 .72821 m .55188 .71488 L .54066 .71288 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.65156 .34065 m .67222 .36843 L .68674 .36358 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.70527 .39483 m .68674 .36358 L .67222 .36843 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.67222 .63157 m .65156 .65935 L .6636 .6645 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.6636 .6645 m .68674 .63642 L .67222 .63157 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.3364 .3355 m .31326 .36358 L .32778 .36843 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.32778 .36843 m .34844 .34065 L .3364 .3355 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.29473 .60517 m .31326 .63642 L .32778 .63157 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.34844 .65935 m .32778 .63157 L .31326 .63642 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.43196 .2798 m .40102 .29574 L .41156 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.41156 .29957 m .43884 .28266 L .43196 .2798 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.37301 .68379 m .40102 .70426 L .41156 .70043 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.43884 .71734 m .41156 .70043 L .40102 .70426 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.41156 .70043 m .43884 .71734 L .44812 .71488 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.58844 .29957 m .56116 .28266 L .55188 .28512 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.56116 .28266 m .58844 .29957 L .59898 .29574 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.62699 .31621 m .59898 .29574 L .58844 .29957 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.58844 .70043 m .56116 .71734 L .56804 .7202 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.56804 .7202 m .59898 .70426 L .58844 .70043 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.62699 .31621 m .65156 .34065 L .6636 .3355 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.68674 .36358 m .6636 .3355 L .65156 .34065 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.65156 .65935 m .62699 .68379 L .63638 .68874 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.63638 .68874 m .6636 .6645 L .65156 .65935 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.36362 .31126 m .3364 .3355 L .34844 .34065 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.34844 .34065 m .37301 .31621 L .36362 .31126 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.31326 .63642 m .3364 .6645 L .34844 .65935 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.37301 .68379 m .34844 .65935 L .3364 .6645 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.46851 .27044 m .43884 .28266 L .44812 .28512 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.44812 .28512 m .47314 .27179 L .46851 .27044 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.47314 .72821 m .44812 .71488 L .43884 .71734 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.44812 .71488 m .47314 .72821 L .47886 .72711 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.55188 .28512 m .52686 .27179 L .52114 .27289 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.52686 .27179 m .55188 .28512 L .56116 .28266 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.55188 .71488 m .52686 .72821 L .53149 .72956 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.53149 .72956 m .56116 .71734 L .55188 .71488 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.59898 .29574 m .62699 .31621 L .63638 .31126 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.6636 .3355 m .63638 .31126 L .62699 .31621 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.62699 .68379 m .59898 .70426 L .60566 .70852 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.60566 .70852 m .63638 .68874 L .62699 .68379 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.39434 .29148 m .36362 .31126 L .37301 .31621 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.37301 .31621 m .40102 .29574 L .39434 .29148 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.3364 .6645 m .36362 .68874 L .37301 .68379 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.40102 .70426 m .37301 .68379 L .36362 .68874 L p F P
.505 .664 .505 r
s
.555 .774 .586 r
.5 .27438 m .5 .26345 L .49256 .27421 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50744 .27421 m .5 .26345 L .5 .27438 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .5 .72562 L .49256 .72579 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50744 .72579 L .5 .72562 L closepath p F P
.505 .664 .505 r
s
.55 .764 .57 r
.46519 .2689 m .43196 .2798 L .43884 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.43884 .28266 m .46851 .27044 L .46519 .2689 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.40102 .70426 m .43196 .7202 L .43884 .71734 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.46851 .72956 m .43884 .71734 L .43196 .7202 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.43884 .71734 m .46851 .72956 L .47314 .72821 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.56116 .28266 m .53149 .27044 L .52686 .27179 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.53149 .27044 m .56116 .28266 L .56804 .2798 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.59898 .29574 m .56804 .2798 L .56116 .28266 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.56116 .71734 m .53149 .72956 L .53481 .7311 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.53481 .7311 m .56804 .7202 L .56116 .71734 L p F P
.505 .664 .505 r
s
.553 .771 .583 r
.49256 .27421 m .5 .26345 L .48542 .27371 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51458 .27371 m .5 .26345 L .50744 .27421 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .49256 .72579 L .48542 .72629 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51458 .72629 L .50744 .72579 L closepath p F P
.505 .664 .505 r
s
.549 .766 .579 r
.48542 .27371 m .5 .26345 L .47886 .27289 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .48542 .72629 L .47886 .72711 L closepath p F P
.505 .664 .505 r
s
.552 .771 .585 r
.52114 .27289 m .5 .26345 L .51458 .27371 L closepath p F P
.505 .664 .505 r
s
.197 .204 .155 r
.5 .73655 m .52114 .72711 L .51458 .72629 L closepath p F P
.505 .664 .505 r
s
.557 .772 .598 r
.56804 .2798 m .59898 .29574 L .60566 .29148 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.63638 .31126 m .60566 .29148 L .59898 .29574 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.59898 .70426 m .56804 .7202 L .57217 .72334 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.57217 .72334 m .60566 .70852 L .59898 .70426 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.42783 .27666 m .39434 .29148 L .40102 .29574 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.40102 .29574 m .43196 .2798 L .42783 .27666 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.36362 .68874 m .39434 .70852 L .40102 .70426 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.43196 .7202 m .40102 .70426 L .39434 .70852 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28221 .57661 m
.28509 .58229 L
s
.28509 .58229 m
.28651 .58605 L
s
.28651 .58605 m
.2879 .59168 L
s
.5 Mabswid
.543 .759 .573 r
.47886 .27289 m .5 .26345 L .47314 .27179 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .47886 .72711 L .47314 .72821 L closepath p F P
.505 .664 .505 r
s
.548 .765 .582 r
.52686 .27179 m .5 .26345 L .52114 .27289 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .52686 .72821 L .52114 .72711 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72001 .42876 m
.72109 .43231 L
s
.72109 .43231 m
.7232 .43747 L
s
.71885 .42326 m
.72001 .42876 L
s
.5 Mabswid
.535 .75 .567 r
.47314 .27179 m .5 .26345 L .46851 .27044 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .47314 .72821 L .46851 .72956 L closepath p F P
.505 .664 .505 r
s
.541 .758 .578 r
.53149 .27044 m .5 .26345 L .52686 .27179 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .53149 .72956 L .52686 .72821 L closepath p F P
.505 .664 .505 r
s
.344 .45 .374 r
.72703 .46384 m .7298 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.7298 .5 m .72703 .53616 L .73794 .53789 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.73794 .53789 m .74098 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.26206 .46211 m .25902 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.2702 .5 m .27297 .46384 L .26206 .46211 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.27297 .53616 m .2702 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.7188 .42852 m .72703 .46384 L .73794 .46211 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.74098 .5 m .73794 .46211 L .72703 .46384 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72703 .53616 m .7188 .57148 L .72891 .57479 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72891 .57479 m .73794 .53789 L .72703 .53616 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27109 .42521 m .26206 .46211 L .27297 .46384 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27297 .46384 m .2812 .42852 L .27109 .42521 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.25902 .5 m .26206 .53789 L .27297 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.2812 .57148 m .27297 .53616 L .26206 .53789 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.70527 .39483 m .7188 .42852 L .72891 .42521 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.73794 .46211 m .72891 .42521 L .7188 .42852 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.7188 .57148 m .70527 .60517 L .71415 .60972 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.71415 .60972 m .72891 .57479 L .7188 .57148 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.26206 .53789 m .27109 .57479 L .2812 .57148 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.29473 .60517 m .2812 .57148 L .27109 .57479 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.28585 .39028 m .27109 .42521 L .2812 .42852 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.2812 .42852 m .29473 .39483 L .28585 .39028 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.56804 .2798 m .53481 .2689 L .53149 .27044 L p F P
.505 .664 .505 r
s
.544 .761 .586 r
.53481 .2689 m .56804 .2798 L .57217 .27666 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.60566 .29148 m .57217 .27666 L .56804 .2798 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.56804 .7202 m .53481 .7311 L .53667 .73278 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.53667 .73278 m .57217 .72334 L .56804 .7202 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.46333 .26722 m .42783 .27666 L .43196 .2798 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.43196 .2798 m .46519 .2689 L .46333 .26722 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.39434 .70852 m .42783 .72334 L .43196 .7202 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.46519 .7311 m .43196 .7202 L .42783 .72334 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.43196 .7202 m .46519 .7311 L .46851 .72956 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.68674 .36358 m .70527 .39483 L .71415 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.72891 .42521 m .71415 .39028 L .70527 .39483 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.70527 .60517 m .68674 .63642 L .69406 .64177 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.69406 .64177 m .71415 .60972 L .70527 .60517 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.30594 .35823 m .28585 .39028 L .29473 .39483 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.29473 .39483 m .31326 .36358 L .30594 .35823 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.27109 .57479 m .28585 .60972 L .29473 .60517 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.31326 .63642 m .29473 .60517 L .28585 .60972 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.6636 .3355 m .68674 .36358 L .69406 .35823 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.71415 .39028 m .69406 .35823 L .68674 .36358 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.68674 .63642 m .6636 .6645 L .66919 .67013 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.66919 .67013 m .69406 .64177 L .68674 .63642 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.33081 .32987 m .30594 .35823 L .31326 .36358 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.31326 .36358 m .3364 .3355 L .33081 .32987 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.28585 .60972 m .30594 .64177 L .31326 .63642 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.3364 .6645 m .31326 .63642 L .30594 .64177 L p F P
.505 .664 .505 r
s
.527 .74 .559 r
.46851 .27044 m .5 .26345 L .46519 .2689 L closepath p F P
.505 .664 .505 r
s
.533 .749 .571 r
.53481 .2689 m .5 .26345 L .53149 .27044 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .46851 .72956 L .46519 .7311 L closepath p F P
.505 .664 .505 r
s
.183 .19 .145 r
.5 .73655 m .53481 .7311 L .53149 .72956 L closepath p F P
.505 .664 .505 r
s
.485 .675 .538 r
.63638 .31126 m .6636 .3355 L .66919 .32987 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.69406 .35823 m .66919 .32987 L .6636 .3355 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.6636 .6645 m .63638 .68874 L .64024 .69409 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.64024 .69409 m .66919 .67013 L .6636 .6645 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.35976 .30591 m .33081 .32987 L .3364 .3355 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.3364 .3355 m .36362 .31126 L .35976 .30591 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.30594 .64177 m .33081 .67013 L .3364 .6645 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.36362 .68874 m .3364 .6645 L .33081 .67013 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.60566 .29148 m .63638 .31126 L .64024 .30591 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.66919 .32987 m .64024 .30591 L .63638 .31126 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.63638 .68874 m .60566 .70852 L .60797 .71307 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.60797 .71307 m .64024 .69409 L .63638 .68874 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.33081 .67013 m .35976 .69409 L .36362 .68874 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.39434 .70852 m .36362 .68874 L .35976 .69409 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.39203 .28693 m .35976 .30591 L .36362 .31126 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.36362 .31126 m .39434 .29148 L .39203 .28693 L p F P
.505 .664 .505 r
s
.524 .738 .564 r
.53667 .26722 m .5 .26345 L .53481 .2689 L closepath p F P
.505 .664 .505 r
s
.544 .761 .586 r
.57217 .27666 m .53667 .26722 L .53481 .2689 L p F P
.505 .664 .505 r
s
.517 .728 .55 r
.46519 .2689 m .5 .26345 L .46333 .26722 L closepath p F P
.505 .664 .505 r
s
.176 .185 .14 r
.5 .73655 m .53667 .73278 L .53481 .7311 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42783 .72334 m .46333 .73278 L .46519 .7311 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .46519 .7311 L .46333 .73278 L closepath p F P
.505 .664 .505 r
s
.511 .718 .561 r
.57217 .27666 m .60566 .29148 L .60797 .28693 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.64024 .30591 m .60797 .28693 L .60566 .29148 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.60566 .70852 m .57217 .72334 L .57324 .72664 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.57324 .72664 m .60797 .71307 L .60566 .70852 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.42676 .27336 m .39203 .28693 L .39434 .29148 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.39434 .29148 m .42783 .27666 L .42676 .27336 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.35976 .69409 m .39203 .71307 L .39434 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.42783 .72334 m .39434 .70852 L .39203 .71307 L p F P
.505 .664 .505 r
s
.515 .726 .562 r
.53667 .26722 m .57217 .27666 L .57324 .27336 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.60797 .28693 m .57324 .27336 L .57217 .27666 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.57217 .72334 m .53667 .73278 L .53694 .73451 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.53694 .73451 m .57324 .72664 L .57217 .72334 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.46306 .26549 m .42676 .27336 L .42783 .27666 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.42783 .27666 m .46333 .26722 L .46306 .26549 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.39203 .71307 m .42676 .72664 L .42783 .72334 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.46333 .73278 m .42783 .72334 L .42676 .72664 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .53694 .73451 L .53667 .73278 L closepath p F P
.505 .664 .505 r
s
.514 .725 .555 r
.53694 .26549 m .5 .26345 L .53667 .26722 L closepath p F P
.505 .664 .505 r
s
.515 .726 .562 r
.57324 .27336 m .53694 .26549 L .53667 .26722 L p F P
.505 .664 .505 r
s
.506 .715 .541 r
.46333 .26722 m .5 .26345 L .46306 .26549 L closepath p F P
.505 .664 .505 r
s
.177 .185 .14 r
.42676 .72664 m .46306 .73451 L .46333 .73278 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .46333 .73278 L .46306 .73451 L closepath p F P
.505 .664 .505 r
s
.159 .168 .128 r
.5 .73655 m .46442 .73624 L .46737 .73787 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .46306 .73451 L .46442 .73624 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .53558 .73624 L .53694 .73451 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .53263 .73787 L .53558 .73624 L closepath p F P
.505 .664 .505 r
s
.149 .16 .121 r
.5 .73655 m .52817 .73933 L .53263 .73787 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .73655 m .5224 .74056 L .52817 .73933 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .51556 .74148 L .5224 .74056 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50797 .74206 L .51556 .74148 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .5 .74225 L .50797 .74206 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49203 .74206 L .5 .74225 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .48444 .74148 L .49203 .74206 L closepath p F P
.505 .664 .505 r
s
.141 .152 .116 r
.5 .73655 m .4776 .74056 L .48444 .74148 L closepath p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .73655 m .47183 .73933 L .4776 .74056 L closepath p F P
.505 .664 .505 r
s
.152 .162 .123 r
.5 .73655 m .46737 .73787 L .47183 .73933 L closepath p F P
.505 .664 .505 r
s
.503 .712 .546 r
.53558 .26376 m .5 .26345 L .53694 .26549 L closepath p F P
.505 .664 .505 r
s
.492 .698 .536 r
.53263 .26213 m .5 .26345 L .53558 .26376 L closepath p F P
.505 .664 .505 r
s
.496 .702 .532 r
.46306 .26549 m .5 .26345 L .46442 .26376 L closepath p F P
.505 .664 .505 r
s
.481 .685 .526 r
.52817 .26067 m .5 .26345 L .53263 .26213 L closepath p F P
.505 .664 .505 r
s
.485 .689 .523 r
.46442 .26376 m .5 .26345 L .46737 .26213 L closepath p F P
.505 .664 .505 r
s
.471 .673 .518 r
.5224 .25944 m .5 .26345 L .52817 .26067 L closepath p F P
.505 .664 .505 r
s
.475 .677 .515 r
.46737 .26213 m .5 .26345 L .47183 .26067 L closepath p F P
.505 .664 .505 r
s
.463 .663 .51 r
.51556 .25852 m .5 .26345 L .5224 .25944 L closepath p F P
.505 .664 .505 r
s
.466 .667 .508 r
.47183 .26067 m .5 .26345 L .4776 .25944 L closepath p F P
.505 .664 .505 r
s
.457 .656 .504 r
.50797 .25794 m .5 .26345 L .51556 .25852 L closepath p F P
.505 .664 .505 r
s
.459 .658 .503 r
.4776 .25944 m .5 .26345 L .48444 .25852 L closepath p F P
.505 .664 .505 r
s
.453 .652 .5 r
.5 .25775 m .5 .26345 L .50797 .25794 L closepath p F P
.505 .664 .505 r
s
.455 .653 .499 r
.48444 .25852 m .5 .26345 L .49203 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49203 .25794 m .5 .26345 L .5 .25775 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73491 .44488 m
.73779 .45263 L
s
.73145 .43556 m
.73491 .44488 L
s
.5 Mabswid
.144 .155 .118 r
.57324 .72664 m .53694 .73451 L .53558 .73624 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.53694 .26549 m .57324 .27336 L .57106 .27003 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.57106 .27003 m .53558 .26376 L .53694 .26549 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.42894 .72997 m .46442 .73624 L .46306 .73451 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.46306 .73451 m .42676 .72664 L .42894 .72997 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.42676 .27336 m .46306 .26549 L .46442 .26376 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.57324 .27336 m .60797 .28693 L .6055 .28229 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.6055 .28229 m .57106 .27003 L .57324 .27336 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60797 .71307 m .57324 .72664 L .57106 .72997 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.53558 .73624 m .57106 .72997 L .57324 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.3945 .71771 m .42894 .72997 L .42676 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.42676 .72664 m .39203 .71307 L .3945 .71771 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.46442 .26376 m .42894 .27003 L .42676 .27336 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.39203 .28693 m .42676 .27336 L .42894 .27003 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.60797 .28693 m .64024 .30591 L .63793 .30038 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.63793 .30038 m .6055 .28229 L .60797 .28693 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.64024 .69409 m .60797 .71307 L .6055 .71771 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.57106 .72997 m .6055 .71771 L .60797 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.36207 .69962 m .3945 .71771 L .39203 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.39203 .71307 m .35976 .69409 L .36207 .69962 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.42894 .27003 m .3945 .28229 L .39203 .28693 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.35976 .30591 m .39203 .28693 L .3945 .28229 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.57106 .72997 m .53558 .73624 L .53263 .73787 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.53558 .26376 m .57106 .27003 L .56561 .26684 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.56561 .26684 m .53263 .26213 L .53558 .26376 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.43439 .73316 m .46737 .73787 L .46442 .73624 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.46442 .73624 m .42894 .72997 L .43439 .73316 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.42894 .27003 m .46442 .26376 L .46737 .26213 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.66919 .67013 m .64024 .69409 L .63793 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.6055 .71771 m .63793 .69962 L .64024 .69409 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.64024 .30591 m .66919 .32987 L .66739 .32399 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.66739 .32399 m .63793 .30038 L .64024 .30591 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.33261 .67601 m .36207 .69962 L .35976 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.35976 .69409 m .33081 .67013 L .33261 .67601 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.3945 .28229 m .36207 .30038 L .35976 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.33081 .32987 m .35976 .30591 L .36207 .30038 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27669 .59067 m
.27847 .59482 L
s
.27847 .59482 m
.286 .61242 L
s
.26936 .57354 m
.27669 .59067 L
s
.5 Mabswid
.332 .476 .399 r
.66919 .32987 m .69406 .35823 L .69297 .35258 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.69297 .35258 m .66739 .32399 L .66919 .32987 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.69406 .64177 m .66919 .67013 L .66739 .67601 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.63793 .69962 m .66739 .67601 L .66919 .67013 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.36207 .30038 m .33261 .32399 L .33081 .32987 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.30594 .35823 m .33081 .32987 L .33261 .32399 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.30703 .64742 m .33261 .67601 L .33081 .67013 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.33081 .67013 m .30594 .64177 L .30703 .64742 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73432 .43837 m
.73779 .45263 L
s
.5 Mabswid
.122 .135 .102 r
.53263 .73787 m .56561 .73316 L .57106 .72997 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.56561 .73316 m .53263 .73787 L .52817 .73933 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.53263 .26213 m .56561 .26684 L .557 .26393 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.557 .26393 m .52817 .26067 L .53263 .26213 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.443 .73607 m .47183 .73933 L .46737 .73787 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.46737 .73787 m .43439 .73316 L .443 .73607 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.46737 .26213 m .43439 .26684 L .42894 .27003 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.43439 .26684 m .46737 .26213 L .47183 .26067 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.69406 .35823 m .71415 .39028 L .71384 .38544 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.71384 .38544 m .69297 .35258 L .69406 .35823 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.71415 .60972 m .69406 .64177 L .69297 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66739 .67601 m .69297 .64742 L .69406 .64177 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.33261 .32399 m .30703 .35258 L .30594 .35823 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.28585 .39028 m .30594 .35823 L .30703 .35258 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.28616 .61456 m .30703 .64742 L .30594 .64177 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.30594 .64177 m .28585 .60972 L .28616 .61456 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.71415 .39028 m .72891 .42521 L .72928 .42167 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.72928 .42167 m .71384 .38544 L .71415 .39028 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.72891 .57479 m .71415 .60972 L .71384 .61456 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.69297 .64742 m .71384 .61456 L .71415 .60972 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.30703 .35258 m .28616 .38544 L .28585 .39028 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.27109 .42521 m .28585 .39028 L .28616 .38544 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.27072 .57833 m .28616 .61456 L .28585 .60972 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.28585 .60972 m .27109 .57479 L .27072 .57833 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27696 .59371 m
.27849 .59985 L
s
.5 Mabswid
.087 .102 .077 r
.6055 .71771 m .57106 .72997 L .56561 .73316 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.57106 .27003 m .6055 .28229 L .59806 .27776 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.59806 .27776 m .56561 .26684 L .57106 .27003 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.3945 .28229 m .42894 .27003 L .43439 .26684 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.40194 .72224 m .43439 .73316 L .42894 .72997 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.42894 .72997 m .3945 .71771 L .40194 .72224 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27849 .59985 m
.27885 .60209 L
s
.5 Mabswid
.201 .277 .255 r
.72891 .42521 m .73794 .46211 L .73877 .46024 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.73877 .46024 m .72928 .42167 L .72891 .42521 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73074 .42761 m
.73238 .42681 L
s
.73412 .43754 m
.73432 .43837 L
s
.7282 .41319 m
.73412 .43754 L
s
.5 Mabswid
.115 .151 .14 r
.73794 .53789 m .72891 .57479 L .72928 .57833 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.71384 .61456 m .72928 .57833 L .72891 .57479 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.28616 .38544 m .27072 .42167 L .27109 .42521 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.26206 .46211 m .27109 .42521 L .27072 .42167 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.26123 .53976 m .27072 .57833 L .27109 .57479 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.27109 .57479 m .26206 .53789 L .26123 .53976 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.73794 .46211 m .74098 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.74197 .5 m .73877 .46024 L .73794 .46211 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.74098 .5 m .73794 .53789 L .73877 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.72928 .57833 m .73877 .53976 L .73794 .53789 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.27072 .42167 m .26123 .46024 L .26206 .46211 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.25902 .5 m .26206 .46211 L .26123 .46024 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.25803 .5 m .26123 .53976 L .26206 .53789 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.26206 .53789 m .25902 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.73877 .53976 m .74197 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.26123 .46024 m .25803 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.52817 .73933 m .557 .73607 L .56561 .73316 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.557 .73607 m .52817 .73933 L .5224 .74056 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.45445 .73853 m .4776 .74056 L .47183 .73933 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.47183 .73933 m .443 .73607 L .45445 .73853 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.52817 .26067 m .557 .26393 L .54555 .26147 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.54555 .26147 m .5224 .25944 L .52817 .26067 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.443 .26393 m .47183 .26067 L .4776 .25944 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.47183 .26067 m .443 .26393 L .43439 .26684 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27835 .60281 m
.27885 .60209 L
s
.5 Mabswid
.082 .097 .074 r
.5224 .74056 m .54555 .73853 L .557 .73607 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.54555 .73853 m .5224 .74056 L .51556 .74148 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.46823 .7404 m .48444 .74148 L .4776 .74056 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.4776 .74056 m .45445 .73853 L .46823 .7404 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.5224 .25944 m .54555 .26147 L .53177 .2596 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.53177 .2596 m .51556 .25852 L .5224 .25944 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.45445 .26147 m .4776 .25944 L .48444 .25852 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.4776 .25944 m .45445 .26147 L .443 .26393 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63793 .69962 m .6055 .71771 L .59806 .72224 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.56561 .73316 m .59806 .72224 L .6055 .71771 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.6055 .28229 m .63793 .30038 L .62903 .29493 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.62903 .29493 m .59806 .27776 L .6055 .28229 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.37097 .70507 m .40194 .72224 L .3945 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.3945 .71771 m .36207 .69962 L .37097 .70507 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.43439 .26684 m .40194 .27776 L .3945 .28229 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.36207 .30038 m .3945 .28229 L .40194 .27776 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.51556 .74148 m .53177 .7404 L .54555 .73853 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.53177 .7404 m .51556 .74148 L .50797 .74206 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48368 .74157 m .49203 .74206 L .48444 .74148 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48444 .74148 m .46823 .7404 L .48368 .74157 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51556 .25852 m .53177 .2596 L .51632 .25843 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51632 .25843 m .50797 .25794 L .51556 .25852 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.46823 .2596 m .48444 .25852 L .49203 .25794 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.48444 .25852 m .46823 .2596 L .45445 .26147 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27732 .6015 m
.27835 .60281 L
s
.5 Mabswid
.056 .074 .056 r
.50797 .74206 m .51632 .74157 L .53177 .7404 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.51632 .74157 m .50797 .74206 L .5 .74225 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.5 .74197 m .5 .74225 L .49203 .74206 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.49203 .74206 m .48368 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50797 .25794 m .51632 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.5 .25803 m .5 .25775 L .50797 .25794 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.49203 .25794 m .48368 .25843 L .46823 .2596 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.48368 .25843 m .49203 .25794 L .5 .25775 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .56561 .73316 L .557 .73607 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.56561 .26684 m .59806 .27776 L .58573 .2736 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.58573 .2736 m .557 .26393 L .56561 .26684 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.41427 .7264 m .443 .73607 L .43439 .73316 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.43439 .73316 m .40194 .72224 L .41427 .7264 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.40194 .27776 m .43439 .26684 L .443 .26393 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.5 .74225 m .5 .74197 L .51632 .74157 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.5 .25775 m .5 .25803 L .48368 .25843 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27475 .59619 m
.27732 .6015 L
s
.26686 .57555 m
.27475 .59619 L
s
.5 Mabswid
.056 .074 .056 r
.59806 .72224 m .62903 .70507 L .63793 .69962 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.66739 .67601 m .63793 .69962 L .62903 .70507 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.63793 .30038 m .66739 .32399 L .65752 .31812 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.65752 .31812 m .62903 .29493 L .63793 .30038 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.34248 .68188 m .37097 .70507 L .36207 .69962 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.36207 .69962 m .33261 .67601 L .34248 .68188 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.40194 .27776 m .37097 .29493 L .36207 .30038 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.33261 .32399 m .36207 .30038 L .37097 .29493 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.557 .73607 m .58573 .7264 L .59806 .72224 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.58573 .7264 m .557 .73607 L .54555 .73853 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.557 .26393 m .58573 .2736 L .56887 .27003 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.56887 .27003 m .54555 .26147 L .557 .26393 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.43113 .72997 m .45445 .73853 L .443 .73607 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.443 .73607 m .41427 .7264 L .43113 .72997 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.443 .26393 m .41427 .2736 L .40194 .27776 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.41427 .2736 m .443 .26393 L .45445 .26147 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.66739 .32399 m .69297 .35258 L .68252 .34688 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.68252 .34688 m .65752 .31812 L .66739 .32399 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.69297 .64742 m .66739 .67601 L .65752 .68188 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.62903 .70507 m .65752 .68188 L .66739 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.31748 .65312 m .34248 .68188 L .33261 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.33261 .67601 m .30703 .64742 L .31748 .65312 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.37097 .29493 m .34248 .31812 L .33261 .32399 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.30703 .35258 m .33261 .32399 L .34248 .31812 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.62903 .70507 m .59806 .72224 L .58573 .7264 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.59806 .27776 m .62903 .29493 L .61347 .28984 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.61347 .28984 m .58573 .2736 L .59806 .27776 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.38653 .71016 m .41427 .7264 L .40194 .72224 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.40194 .72224 m .37097 .70507 L .38653 .71016 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.37097 .29493 m .40194 .27776 L .41427 .2736 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28565 .61898 m
.28459 .61712 L
s
.28459 .61712 m
.28389 .61577 L
s
.28498 .61766 m
.28565 .61898 L
s
.28389 .61577 m
.28498 .61766 L
s
.5 Mabswid
.146 .156 .119 r
.69297 .35258 m .71384 .38544 L .7031 .38051 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.7031 .38051 m .68252 .34688 L .69297 .35258 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.71384 .61456 m .69297 .64742 L .68252 .65312 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.65752 .68188 m .68252 .65312 L .69297 .64742 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.54555 .73853 m .56887 .72997 L .58573 .7264 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.56887 .72997 m .54555 .73853 L .53177 .7404 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54555 .26147 m .56887 .27003 L .54823 .2673 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54823 .2673 m .53177 .2596 L .54555 .26147 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45177 .7327 m .46823 .7404 L .45445 .73853 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45445 .73853 m .43113 .72997 L .45177 .7327 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.43113 .27003 m .45445 .26147 L .46823 .2596 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.45445 .26147 m .43113 .27003 L .41427 .2736 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.34248 .31812 m .31748 .34688 L .30703 .35258 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.28616 .38544 m .30703 .35258 L .31748 .34688 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.2969 .61949 m .31748 .65312 L .30703 .64742 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.30703 .64742 m .28616 .61456 L .2969 .61949 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27591 .59861 m
.27868 .60549 L
s
.26724 .57705 m
.27591 .59861 L
s
.5 Mabswid
.279 .384 .251 r
.72928 .57833 m .71384 .61456 L .7031 .61949 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.68252 .65312 m .7031 .61949 L .71384 .61456 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71384 .38544 m .72928 .42167 L .71844 .41804 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71844 .41804 m .7031 .38051 L .71384 .38544 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28156 .58196 m .2969 .61949 L .28616 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28616 .61456 m .27072 .57833 L .28156 .58196 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.31748 .34688 m .2969 .38051 L .28616 .38544 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.27072 .42167 m .28616 .38544 L .2969 .38051 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.53177 .7404 m .54823 .7327 L .56887 .72997 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.54823 .7327 m .53177 .7404 L .51632 .74157 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.47517 .73443 m .48368 .74157 L .46823 .7404 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.46823 .7404 m .45177 .7327 L .47517 .73443 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53177 .2596 m .54823 .2673 L .52483 .26557 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.52483 .26557 m .51632 .25843 L .53177 .2596 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.45177 .2673 m .46823 .2596 L .48368 .25843 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.46823 .2596 m .45177 .2673 L .43113 .27003 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.73877 .53976 m .72928 .57833 L .71844 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.7031 .61949 m .71844 .58196 L .72928 .57833 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.62903 .29493 m .65752 .31812 L .63928 .31258 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.63928 .31258 m .61347 .28984 L .62903 .29493 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72928 .42167 m .73877 .46024 L .72792 .45832 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72792 .45832 m .71844 .41804 L .72928 .42167 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.65752 .68188 m .62903 .70507 L .61347 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.58573 .7264 m .61347 .71016 L .62903 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.36072 .68742 m .38653 .71016 L .37097 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.37097 .70507 m .34248 .68188 L .36072 .68742 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.41427 .2736 m .38653 .28984 L .37097 .29493 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.34248 .31812 m .37097 .29493 L .38653 .28984 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.2969 .38051 m .28156 .41804 L .27072 .42167 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.26123 .46024 m .27072 .42167 L .28156 .41804 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27208 .54168 m .28156 .58196 L .27072 .57833 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27072 .57833 m .26123 .53976 L .27208 .54168 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.51632 .74157 m .52483 .73443 L .54823 .7327 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.52483 .73443 m .51632 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.5 .73502 m .5 .74197 L .48368 .74157 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.48368 .74157 m .47517 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.51632 .25843 m .52483 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .26498 m .5 .25803 L .51632 .25843 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.47517 .26557 m .48368 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.48368 .25843 m .47517 .26557 L .45177 .2673 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.61347 .71016 m .58573 .7264 L .56887 .72997 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.58573 .2736 m .61347 .28984 L .59163 .28544 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.59163 .28544 m .56887 .27003 L .58573 .2736 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.40837 .71456 m .43113 .72997 L .41427 .7264 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.41427 .7264 m .38653 .71016 L .40837 .71456 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.38653 .28984 m .41427 .2736 L .43113 .27003 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73877 .46024 m .74197 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73113 .5 m .72792 .45832 L .73877 .46024 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.74197 .5 m .73877 .53976 L .72792 .54168 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.71844 .58196 m .72792 .54168 L .73877 .53976 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.28156 .41804 m .27208 .45832 L .26123 .46024 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.25803 .5 m .26123 .46024 L .27208 .45832 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26887 .5 m .27208 .54168 L .26123 .53976 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26123 .53976 m .25803 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.72792 .54168 m .73113 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.5 .74197 m .5 .73502 L .52483 .73443 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .25803 m .5 .26498 L .47517 .26557 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.27208 .45832 m .26887 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26958 .57858 m
.27919 .60264 L
s
.27919 .60264 m
.28112 .60747 L
s
.27769 .59991 m
.28167 .60637 L
s
.5 Mabswid
.431 .598 .424 r
.68252 .65312 m .65752 .68188 L .63928 .68742 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.61347 .71016 m .63928 .68742 L .65752 .68188 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.65752 .31812 m .68252 .34688 L .66217 .34145 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.66217 .34145 m .63928 .31258 L .65752 .31812 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.33783 .65855 m .36072 .68742 L .34248 .68188 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.34248 .68188 m .31748 .65312 L .33783 .65855 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.38653 .28984 m .36072 .31258 L .34248 .31812 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.31748 .34688 m .34248 .31812 L .36072 .31258 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28167 .60637 m
.28364 .60872 L
s
.5 Mabswid
.44 .627 .463 r
.56887 .72997 m .59163 .71456 L .61347 .71016 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.59163 .71456 m .56887 .72997 L .54823 .7327 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56887 .27003 m .59163 .28544 L .56441 .28202 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56441 .28202 m .54823 .2673 L .56887 .27003 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43559 .71798 m .45177 .7327 L .43113 .72997 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43113 .72997 m .40837 .71456 L .43559 .71798 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.40837 .28544 m .43113 .27003 L .45177 .2673 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.43113 .27003 m .40837 .28544 L .38653 .28984 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28364 .60872 m
.28552 .60946 L
s
.5 Mabswid
.5 .694 .505 r
.63928 .68742 m .61347 .71016 L .59163 .71456 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61347 .28984 m .63928 .31258 L .61301 .30773 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61301 .30773 m .59163 .28544 L .61347 .28984 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38699 .69227 m .40837 .71456 L .38653 .71016 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38653 .71016 m .36072 .68742 L .38699 .69227 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.36072 .31258 m .38653 .28984 L .40837 .28544 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68252 .34688 m .7031 .38051 L .68118 .37577 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68118 .37577 m .66217 .34145 L .68252 .34688 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.7031 .61949 m .68252 .65312 L .66217 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.63928 .68742 m .66217 .65855 L .68252 .65312 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.36072 .31258 m .33783 .34145 L .31748 .34688 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.2969 .38051 m .31748 .34688 L .33783 .34145 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31882 .62423 m .33783 .65855 L .31748 .65312 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31748 .65312 m .2969 .61949 L .31882 .62423 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28552 .60946 m
.28608 .60808 L
s
.5 Mabswid
.506 .71 .527 r
.54823 .7327 m .56441 .71798 L .59163 .71456 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.56441 .71798 m .54823 .7327 L .52483 .73443 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.46675 .72014 m .47517 .73443 L .45177 .7327 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.45177 .7327 m .43559 .71798 L .46675 .72014 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.54823 .2673 m .56441 .28202 L .53325 .27986 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.53325 .27986 m .52483 .26557 L .54823 .2673 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.43559 .28202 m .45177 .2673 L .47517 .26557 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.45177 .2673 m .43559 .28202 L .40837 .28544 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28428 .60249 m
.28608 .60808 L
s
.5 Mabswid
.576 .798 .606 r
.5 .72088 m .5 .73502 L .47517 .73443 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.47517 .73443 m .46675 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.52483 .73443 m .53325 .72014 L .56441 .71798 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.53325 .72014 m .52483 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.52483 .26557 m .53325 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.5 .27912 m .5 .26498 L .52483 .26557 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.46675 .27986 m .47517 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.47517 .26557 m .46675 .27986 L .43559 .28202 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.71844 .58196 m .7031 .61949 L .68118 .62423 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.66217 .65855 m .68118 .62423 L .7031 .61949 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.7031 .38051 m .71844 .41804 L .69546 .41454 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.69546 .41454 m .68118 .37577 L .7031 .38051 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.30454 .58546 m .31882 .62423 L .2969 .61949 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.2969 .61949 m .28156 .58196 L .30454 .58546 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2762 .58068 m
.28428 .60249 L
s
.28428 .60249 m
.28929 .60906 L
s
.5 Mabswid
.256 .294 .236 r
.33783 .34145 m .31882 .37577 L .2969 .38051 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.28156 .41804 m .2969 .38051 L .31882 .37577 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.5 .73502 m .5 .72088 L .53325 .72014 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5 .26498 m .5 .27912 L .46675 .27986 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28929 .60906 m
.29195 .61144 L
s
.5 Mabswid
.285 .323 .229 r
.63928 .31258 m .66217 .34145 L .63214 .33666 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63214 .33666 m .61301 .30773 L .63928 .31258 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.66217 .65855 m .63928 .68742 L .61301 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.59163 .71456 m .61301 .69227 L .63928 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36786 .66334 m .38699 .69227 L .36072 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36072 .68742 m .33783 .65855 L .36786 .66334 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.40837 .28544 m .38699 .30773 L .36072 .31258 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.33783 .34145 m .36072 .31258 L .38699 .30773 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.72792 .54168 m .71844 .58196 L .69546 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.68118 .62423 m .69546 .58546 L .71844 .58196 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.71844 .41804 m .72792 .45832 L .70432 .45645 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.70432 .45645 m .69546 .41454 L .71844 .41804 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.61301 .69227 m .59163 .71456 L .56441 .71798 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.59163 .28544 m .61301 .30773 L .57974 .30395 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.57974 .30395 m .56441 .28202 L .59163 .28544 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.42026 .69605 m .43559 .71798 L .40837 .71456 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.40837 .71456 m .38699 .69227 L .42026 .69605 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.29568 .54355 m .30454 .58546 L .28156 .58196 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.28156 .58196 m .27208 .54168 L .29568 .54355 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.38699 .30773 m .40837 .28544 L .43559 .28202 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.31882 .37577 m .30454 .41454 L .28156 .41804 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.27208 .45832 m .28156 .41804 L .30454 .41454 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29195 .61144 m
.29489 .61217 L
s
.5 Mabswid
.368 .465 .307 r
.72792 .45832 m .73113 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.70732 .5 m .70432 .45645 L .72792 .45832 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.73113 .5 m .72792 .54168 L .70432 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.69546 .58546 m .70432 .54355 L .72792 .54168 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.30454 .41454 m .29568 .45645 L .27208 .45832 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.26887 .5 m .27208 .45832 L .29568 .45645 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.29268 .5 m .29568 .54355 L .27208 .54168 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.27208 .54168 m .26887 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.70432 .54355 m .70732 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.29568 .45645 m .29268 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29489 .61217 m
.29617 .61074 L
s
.29479 .60503 m
.29617 .61074 L
s
.28692 .58276 m
.29479 .60503 L
s
.5 Mabswid
.565 .775 .569 r
.56441 .71798 m .57974 .69605 L .61301 .69227 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.57974 .69605 m .56441 .71798 L .53325 .72014 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.56441 .28202 m .57974 .30395 L .54126 .30153 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.54126 .30153 m .53325 .27986 L .56441 .28202 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.45874 .69847 m .46675 .72014 L .43559 .71798 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.43559 .71798 m .42026 .69605 L .45874 .69847 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.42026 .30395 m .43559 .28202 L .46675 .27986 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.43559 .28202 m .42026 .30395 L .38699 .30773 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.66217 .34145 m .68118 .37577 L .64816 .37157 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.64816 .37157 m .63214 .33666 L .66217 .34145 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.68118 .62423 m .66217 .65855 L .63214 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.61301 .69227 m .63214 .66334 L .66217 .65855 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.38699 .30773 m .36786 .33666 L .33783 .34145 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.31882 .37577 m .33783 .34145 L .36786 .33666 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.35184 .62843 m .36786 .66334 L .33783 .65855 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.33783 .65855 m .31882 .62423 L .35184 .62843 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.63214 .66334 m .61301 .69227 L .57974 .69605 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.61301 .30773 m .63214 .33666 L .59355 .33289 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.59355 .33289 m .57974 .30395 L .61301 .30773 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.40645 .66711 m .42026 .69605 L .38699 .69227 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.38699 .69227 m .36786 .66334 L .40645 .66711 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.36786 .33666 m .38699 .30773 L .42026 .30395 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.53325 .72014 m .54126 .69847 L .57974 .69605 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.54126 .69847 m .53325 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.5 .6993 m .5 .72088 L .46675 .72014 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.46675 .72014 m .45874 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.53325 .27986 m .54126 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.5 .3007 m .5 .27912 L .53325 .27986 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45874 .30153 m .46675 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.46675 .27986 m .45874 .30153 L .42026 .30395 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.5 .72088 m .5 .6993 L .54126 .69847 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.5 .27912 m .5 .3007 L .45874 .30153 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30042 .59806 m
.30198 .60241 L
s
.5 Mabswid
.54 .713 .505 r
.69546 .58546 m .68118 .62423 L .64816 .62843 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.63214 .66334 m .64816 .62843 L .68118 .62423 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.68118 .37577 m .69546 .41454 L .66026 .41141 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.66026 .41141 m .64816 .37157 L .68118 .37577 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.33974 .58859 m .35184 .62843 L .31882 .62423 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.31882 .62423 m .30454 .58546 L .33974 .58859 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30198 .60241 m
.32092 .60489 L
s
.30198 .60241 m
.30576 .60887 L
s
.5 Mabswid
.362 .432 .329 r
.36786 .33666 m .35184 .37157 L .31882 .37577 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.30454 .41454 m .31882 .37577 L .35184 .37157 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30576 .60887 m
.31022 .61331 L
s
.29954 .59143 m
.30042 .59806 L
s
.31022 .61331 m
.31399 .61571 L
s
.29954 .59143 m
.30101 .58704 L
s
.31399 .61571 m
.31868 .61639 L
s
.5 Mabswid
.525 .685 .48 r
.70432 .54355 m .69546 .58546 L .66026 .58859 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.64816 .62843 m .66026 .58859 L .69546 .58546 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.69546 .41454 m .70432 .45645 L .6678 .45478 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.6678 .45478 m .66026 .41141 L .69546 .41454 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.35184 .37157 m .33974 .41141 L .30454 .41454 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.29568 .45645 m .30454 .41454 L .33974 .41141 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.3322 .54522 m .33974 .58859 L .30454 .58546 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.30454 .58546 m .29568 .54355 L .3322 .54522 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30101 .58704 m
.30339 .58494 L
s
.31868 .61639 m
.3212 .61487 L
s
.5 Mabswid
.594 .801 .583 r
.57974 .69605 m .59355 .66711 L .63214 .66334 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.59355 .66711 m .57974 .69605 L .54126 .69847 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.57974 .30395 m .59355 .33289 L .54851 .33047 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.54851 .33047 m .54126 .30153 L .57974 .30395 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.45149 .66953 m .45874 .69847 L .42026 .69605 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.42026 .69605 m .40645 .66711 L .45149 .66953 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.40645 .33289 m .42026 .30395 L .45874 .30153 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.42026 .30395 m .40645 .33289 L .36786 .33666 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30339 .58494 m
.30828 .58547 L
s
.5 Mabswid
.389 .466 .316 r
.63214 .33666 m .64816 .37157 L .60519 .36823 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.60519 .36823 m .59355 .33289 L .63214 .33666 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.64816 .62843 m .63214 .66334 L .59355 .66711 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.35184 .37157 m .36786 .33666 L .40645 .33289 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.39481 .63177 m .40645 .66711 L .36786 .66334 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.36786 .66334 m .35184 .62843 L .39481 .63177 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3212 .61487 m
.32214 .61308 L
s
.5 Mabswid
.469 .595 .409 r
.70432 .45645 m .70732 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.67037 .5 m .6678 .45478 L .70432 .45645 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.70732 .5 m .70432 .54355 L .6678 .54522 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.66026 .58859 m .6678 .54522 L .70432 .54355 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.33974 .41141 m .3322 .45478 L .29568 .45645 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.29268 .5 m .29568 .45645 L .3322 .45478 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.32963 .5 m .3322 .54522 L .29568 .54355 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.29568 .54355 m .29268 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.6678 .54522 m .67037 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.3322 .45478 m .32963 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32214 .61308 m
.32239 .60917 L
s
.30828 .58547 m
.3124 .5883 L
s
.32092 .60489 m
.32239 .60917 L
s
.3124 .5883 m
.31734 .5935 L
s
.5 Mabswid
.63 .845 .621 r
.54126 .69847 m .54851 .66953 L .59355 .66711 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.54851 .66953 m .54126 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.5 .67037 m .5 .6993 L .45874 .69847 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.45874 .69847 m .45149 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.54126 .30153 m .54851 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.5 .32963 m .5 .3007 L .54126 .30153 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.45149 .33047 m .45874 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.45874 .30153 m .45149 .33047 L .40645 .33289 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.5 .6993 m .5 .67037 L .54851 .66953 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.5 .3007 m .5 .32963 L .45149 .33047 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.66026 .58859 m .64816 .62843 L .60519 .63177 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.59355 .66711 m .60519 .63177 L .64816 .62843 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.64816 .37157 m .66026 .41141 L .61402 .40892 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.61402 .40892 m .60519 .36823 L .64816 .37157 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.38598 .59108 m .39481 .63177 L .35184 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.35184 .62843 m .33974 .58859 L .38598 .59108 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.40645 .33289 m .39481 .36823 L .35184 .37157 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.33974 .41141 m .35184 .37157 L .39481 .36823 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33214 .60605 m
.3362 .61266 L
s
.3362 .61266 m
.34159 .61715 L
s
.33077 .60158 m
.33214 .60605 L
s
.33077 .60158 m
.33077 .59472 L
s
.34159 .61715 m
.34637 .61953 L
s
.5 Mabswid
.434 .527 .367 r
.59355 .33289 m .60519 .36823 L .55465 .36608 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.55465 .36608 m .54851 .33047 L .59355 .33289 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.60519 .63177 m .59355 .66711 L .54851 .66953 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.39481 .36823 m .40645 .33289 L .45149 .33047 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.44535 .63392 m .45149 .66953 L .40645 .66711 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.40645 .66711 m .39481 .63177 L .44535 .63392 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34637 .61953 m
.35271 .6201 L
s
.33077 .59472 m
.33363 .59013 L
s
.35271 .6201 m
.35645 .61846 L
s
.35941 .6107 m
.36592 .63392 L
s
.5 Mabswid
.581 .756 .54 r
.6678 .54522 m .66026 .58859 L .61402 .59108 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.60519 .63177 m .61402 .59108 L .66026 .58859 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.66026 .41141 m .6678 .45478 L .61955 .45345 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.61955 .45345 m .61402 .40892 L .66026 .41141 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.39481 .36823 m .38598 .40892 L .33974 .41141 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.3322 .45478 m .33974 .41141 L .38598 .40892 L p F P
.505 .664 .505 r
s
.618 .805 .609 r
.38045 .54655 m .38598 .59108 L .33974 .58859 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35331 .58892 m
.35941 .6107 L
s
.5 Mabswid
.618 .805 .609 r
.33974 .58859 m .3322 .54522 L .38045 .54655 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33363 .59013 m
.33731 .58791 L
s
.35645 .61846 m
.35973 .61467 L
s
.33731 .58791 m
.34398 .58836 L
s
.5 Mabswid
.465 .568 .41 r
.44535 .36608 m .45149 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.5 .63466 m .5 .67037 L .45149 .66953 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.45149 .66953 m .44535 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.45149 .33047 m .44535 .36608 L .39481 .36823 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.54851 .66953 m .55465 .63392 L .60519 .63177 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.54851 .33047 m .55465 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.5 .36534 m .5 .32963 L .54851 .33047 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.55465 .63392 m .54851 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34398 .58836 m
.34915 .5912 L
s
.5 Mabswid
.53 .674 .475 r
.6678 .45478 m .67037 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.62143 .5 m .61955 .45345 L .6678 .45478 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.67037 .5 m .6678 .54522 L .61955 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.61402 .59108 m .61955 .54655 L .6678 .54522 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.38598 .40892 m .38045 .45345 L .3322 .45478 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.32963 .5 m .3322 .45478 L .38045 .45345 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.37857 .5 m .38045 .54655 L .3322 .54522 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.3322 .54522 m .32963 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34915 .5912 m
.35499 .59647 L
s
.5 Mabswid
.559 .719 .51 r
.61955 .54655 m .62143 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.5 .67037 m .5 .63466 L .55465 .63392 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.5 .32963 m .5 .36534 L .44535 .36608 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.38045 .45345 m .37857 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.61402 .59108 m .60519 .63177 L .55465 .63392 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.60519 .36823 m .61402 .40892 L .55932 .4073 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.55932 .4073 m .55465 .36608 L .60519 .36823 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.38598 .40892 m .39481 .36823 L .44535 .36608 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.44068 .5927 m .44535 .63392 L .39481 .63177 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.39481 .63177 m .38598 .59108 L .44068 .5927 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37485 .60924 m
.37895 .61595 L
s
.37895 .61595 m
.38503 .62043 L
s
.38503 .62043 m
.39064 .62275 L
s
.37379 .60466 m
.37485 .60924 L
s
.37485 .60924 m
.40666 .61077 L
s
.39064 .62275 m
.39843 .62316 L
s
.37379 .60466 m
.37481 .59758 L
s
.39843 .62316 m
.4033 .62137 L
s
.37481 .59758 m
.37909 .59279 L
s
.4033 .62137 m
.40557 .61941 L
s
.40557 .61941 m
.40747 .61523 L
s
.5 Mabswid
.612 .795 .575 r
.61955 .54655 m .61402 .59108 L .55932 .5927 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.55465 .63392 m .55932 .5927 L .61402 .59108 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.61402 .40892 m .61955 .45345 L .56224 .45258 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.56224 .45258 m .55932 .4073 L .61402 .40892 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.44535 .36608 m .44068 .4073 L .38598 .40892 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.38045 .45345 m .38598 .40892 L .44068 .4073 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.43776 .54742 m .44068 .5927 L .38598 .59108 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.38598 .59108 m .38045 .54655 L .43776 .54742 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37909 .59279 m
.384 .59042 L
s
.5 Mabswid
.644 .844 .62 r
.55932 .5927 m .55465 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.5 .59326 m .5 .63466 L .44535 .63392 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.44535 .63392 m .44068 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.55465 .36608 m .55932 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.5 .40674 m .5 .36534 L .55465 .36608 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.44068 .4073 m .44535 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.40666 .61077 m
.40747 .61523 L
s
.384 .59042 m
.39225 .59074 L
s
.42468 .61802 m
.42819 .62235 L
s
.42819 .62235 m
.43708 .62467 L
s
.39225 .59074 m
.39825 .59356 L
s
.5 Mabswid
.644 .844 .62 r
.5 .63466 m .5 .59326 L .55932 .5927 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.5 .36534 m .5 .40674 L .44068 .4073 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.48073 .61012 m
.48193 .63891 L
s
.42468 .61802 m
.4269 .61372 L
s
.43708 .62467 m
.44575 .62491 L
s
.39825 .59356 m
.40469 .59884 L
s
.44575 .62491 m
.45432 .62304 L
s
.4269 .61372 m
.43242 .61162 L
s
.5 Mabswid
.565 .719 .515 r
.61955 .45345 m .62143 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.56324 .5 m .56224 .45258 L .61955 .45345 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.62143 .5 m .61955 .54655 L .56224 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.55932 .5927 m .56224 .54742 L .61955 .54655 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.44068 .4073 m .43776 .45258 L .38045 .45345 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.37857 .5 m .38045 .45345 L .43776 .45258 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.43676 .5 m .43776 .54742 L .38045 .54655 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.38045 .54655 m .37857 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45432 .62304 m
.45689 .61884 L
s
.43242 .61162 m
.44704 .60966 L
s
.5 Mabswid
.591 .761 .548 r
.56224 .54742 m .56324 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.43776 .45258 m .43676 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.42206 .59939 m
.42442 .59435 L
s
.44704 .60966 m
.45288 .60741 L
s
.42442 .59435 m
.4332 .59193 L
s
.5 Mabswid
.629 .817 .597 r
.56224 .54742 m .55932 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.5 .54772 m .5 .59326 L .44068 .5927 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.44068 .5927 m .43776 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.55932 .4073 m .56224 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.5 .45228 m .5 .40674 L .55932 .4073 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.43776 .45258 m .44068 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45288 .60741 m
.45556 .6026 L
s
.4332 .59193 m
.4424 .59211 L
s
.45538 .6001 m
.45556 .6026 L
s
.4519 .59491 m
.45538 .6001 L
s
.4424 .59211 m
.4519 .59491 L
s
.5 Mabswid
.629 .817 .597 r
.5 .59326 m .5 .54772 L .56224 .54742 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.5 .40674 m .5 .45228 L .43776 .45258 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.48342 .59523 m
.48032 .59782 L
s
.48032 .59782 m
.47707 .59519 L
s
.47707 .59519 m
.48016 .59256 L
s
.48016 .59256 m
.48342 .59523 L
s
.5 Mabswid
.583 .743 .539 r
.56224 .45258 m .56324 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.5 .5 m .5 .45228 L .56224 .45258 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.56324 .5 m .56224 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.43676 .5 m .43776 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.5 .5 m .5 .54772 L .43776 .54742 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.43776 .54742 m .43676 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.5 .54772 m .5 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.5 .45228 m .5 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>h0/>3V5`21ZH7^0;3PiP40oooo003V0;3PiPP0PJV10P0R9A`0
0`21ZH4092LN02@W7P0602@W7P03086YP@0U:1h09BPN00H09BPN00<0PJV102<V7@0S9Qd02021ZH7V
0;3PiP40oooo003P0;3PiPH0PJV100<0720H086YP@21ZH401P0R9A`00`21ZH4092LN02@W7P0702@W
7P03086YP@0U:1h09BPN00L09BPN00<0PJV102<V7@0S9Qd0100S9Qd2086YP@0301lR6P21ZH40PJV1
00@0PJV1h02`h>H10?ooo`00g02`h>H5086YP@@0720H0P21ZH47028U7003086YP@0T9ah092LN00P0
92LN00<0PJV102DX7P0U:1h0200U:1h00`21ZH408bHM02<V7@0502<V7@80PJV1100O8QX5086YPM`0
/>3V0@3oool00=T0/>3V1@21ZH4501`P6080PJV10`0R9A`S086YP@<08bHM0P21ZH4501lR6PD0PJV1
f@2`h>H10?ooo`00eP2`h>H2086YP@0301DI4`21ZH40PJV10080720H2`21ZH4403<d:003086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@0203Df:@/0PJV100<0
7b8J086YP@21ZH401021ZH7F0;3PiP40oooo003C0;3PiPX0PJV10`0];b@00`21ZH40<c@X03<d:009
03<d:003086YP@0f>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@09
03Df:@04086YP@0`<RH0<38V030b9PX0PJV1d`2`h>H10?ooo`00d02`h>H7086YP@P0;BlT00<0PJV1
03<d:00c=2P02@0c=2P00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0g>2/0=cP[00/0=cP[00<0PJV1
03Df:@0e=RT02@0e=RT00`21ZH40<38V030b9P06030b9PL0PJV1d02`h>H10?ooo`00c@2`h>H4086Y
P@<092HM00<0PJV102d_900];b@01`0];b@00`21ZH40<c@X03<d:00903<d:003086YP@0f>2X0=SPZ
00`0=SPZ00<0PJV103Lh:`0g>2/0300g>2/00`21ZH40=CHY03Df:@0903Df:@03086YP@0`<RH0<38V
00L0<38V00@0PJV102P[800X:b00:2/P1021ZH7=0;3PiP40oooo003:0;3PiP@0PJV1100T9Qd2086Y
P@P0;BlT0P21ZH4;03<d:003086YP@0f>2X0=SPZ00d0=SPZ00<0PJV103Lh:`0g>2/03@0g>2/00`21
ZH40=CHY03Df:@0903Df:@80PJV1200`<RH2086YP@@0:2/P1021ZH7:0;3PiP40oooo00380;3PiP@0
PJV11@0T9Qd00`21ZH40;BlT02d_900702d_9003086YP@0c=2P0<c@X00/0<c@X00<0PJV103Hh:P0f
>2X03@0f>2X00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0e=RT0=CHY00/0=CHY00<0PJV1030b9P0`
<RH01`0`<RH00`21ZH40:2/P02P[800302P[80@0PJV1b02`h>H10?ooo`00aP2`h>H4086YP@D092HM
0P21ZH4902d_9003086YP@0c=2P0<c@X00@0<c@X<@21ZH4603Df:@03086YP@0`<RH0<38V00L0<38V
0P21ZH4502P[8080PJV100<07B0H086YP@2`h>H0a@2`h>H10?ooo`00a02`h>H2086YP@0301LK5021
ZH4092HM00D092HM00<0PJV102d_900];b@01@0];b@;086YP@L0B50i00<0PJV104eG?@1=Ecd03P1=
Ecd00`21ZH40CeTn04mI?P0>04mI?P03086YP@1<E3`0C5@l00D0C5@l2`21ZH47030b9P03086YP@0X
:b00:2/P00@0:2/P00@0PJV101dP6021ZH40PJV1a02`h>H10?ooo`00`P2`h>H2086YP@0301LK5021
ZH40PJV100D092HM0P21ZH400`0];b@0PJV1086YP@05086YP@80?D8`00<0PJV104Q@>@18D3T03018
D3T00`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<
E3`00`21ZH40@dXe04=:=@07086YP@03030b9P21ZH40PJV100D0:2/P0P21ZH400`0M81P0PJV1086Y
P@320;3PiP40oooo00300;3PiPD0PJV1100T9Qd6086YP@T0?D8`00<0PJV104Q@>@18D3T03018D3T0
0`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<E3`0
0`21ZH40@dXe04=:=@0704=:=@H0PJV1100X:b05086YPL00/>3V0@3oool00;h0/>3V2`21ZH400`0`
<BD0PJV103e2<00;03e2<003086YP@18D3T0B50i00d0B50i00<0PJV104eG?@1=Ecd03`1=Ecd00`21
ZH40CeTn04mI?P0?04mI?P03086YP@1<E3`0C5@l00d0C5@l00<0PJV104=:=@13BSD02P13BSD00`21
ZH40=SPZ086YP@0:086YPKh0/>3V0@3oool00;d0/>3V1P21ZH46030a9@03086YP@0m@S00?D8`00X0
?D8`00<0PJV104Q@>@18D3T03@18D3T00`21ZH40CELm04eG?@0@04eG?@03086YP@1?FCh0CeTn0100
CeTn00<0PJV104aD?01<E3`03@1<E3`00`21ZH40@dXe04=:=@0:04=:=@03086YP@0f>2X0=SPZ00@0
=SPZ1P21ZH6m0;3PiP40oooo002k0;3PiPD0PJV1200`<BD00`21ZH40?D8`03e2<00:03e2<003086Y
P@18D3T0B50i00h0B50i00<0PJV104eG?@1=Ecd0401=Ecd00`21ZH40CeTn04mI?P0@04mI?P03086Y
P@1<E3`0C5@l00h0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0603Hh:PD0PJV1
^`2`h>H10?ooo`00^@2`h>H4086YP@03028T7021ZH40<34U00L0<34U00<0PJV103e2<00m@S002`0m
@S000`21ZH40B50i04Q@>@0=04Q@>@03086YP@1=Ecd0CELm0140CELm00<0PJV104mI?P1?FCh04@1?
FCh00`21ZH40C5@l04aD?00=04aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f
>2X00`21ZH40:2/P086YP@03086YPKT0/>3V0@3oool00;L0/>3V1021ZH42028T7003086YP@0`<BD0
<34U00H0<34U00<0PJV103e2<00m@S002`0m@S000`21ZH40B50i04Q@>@0>04Q@>@03086YP@1=Ecd0
CELm0140CELm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40C5@l04aD?00>04aD?003086YP@13BSD0
@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f>2X2086YP@0302P[8021ZH40PJV10080PJV1]`2`h>H1
0?ooo`00]@2`h>H4086YP@<08R@L00<0PJV1030a9@0`<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2
<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=Ecd04@1=Ecd00`21ZH40CeTn04mI?P0A04mI
?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh
:P03086YP@0X:b00:2/P00@0PJV1]@2`h>H10?ooo`00]02`h>H3086YP@@08R@L00<0PJV1030a9@0`
<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=
Ecd04P1=Ecd00`21ZH40CeTn04mI?P0B04mI?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13
BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh:P04086YP@0X:b00:2/P02P[80<0PJV1]02`h>H10?oo
o`00/`2`h>H00`21ZH4041@?086YP@03028T7080PJV12@0`<BD00`21ZH40?D8`03e2<00;03e2<003
086YP@18D3T0B50i00H0B50i?@21ZH4804aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f
>2X0200f>2X01@21ZH40:2/P02P[800X:b00PJV1008061/D/`2`h>H10?ooo`00/@2`h>H4086YP@<0
8R@L00<0PJV1030a9@0`<BD0200`<BD00`21ZH40?D8`03e2<00803e2<0d0PJV12@1QLU<00`21ZH40
I7ME06AgE@0B06AgE@03086YP@1SME80HgEB0180HgEB00<0PJV105e]B`1MKD/01`1MKD/=086YP@X0
@dXe00<0PJV103Hh:P0f>2X0200f>2X01021ZH40:2/P02P[800X:b02086YP@0301PK5021ZH40/>3V
0;00/>3V0@3oool00;00/>3V00<0PJV1010D3`21ZH40100R91`00`21ZH40<34U030a9@08030a9@04
086YP@0m@S00?D8`03e2<0P0PJV10`1GIT/00`21ZH40HG9C065bD`0@065bD`03086YP@1TMeD0I7ME
0180I7ME00<0PJV106=eDP1SME804P1SME800`21ZH40GFe;05e]B`0@05e]B`04086YP@1FI4D0EVA5
05ITA@P0PJV10`13BSD00`21ZH40=SPZ03Hh:P0803Hh:P80PJV10`0X:b000`21ZH4061/D086YP@2`
0;3PiP40oooo002_0;3PiP03086YP@0@50l0PJV100@08R@L00<0PJV1030a9@0`<BD01@0`<BD8086Y
P@X0EfI;00<0PJV1065bD`1QLU<0401QLU<00`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB
01<0HgEB00<0PJV105e]B`1MKD/0401MKD/00`21ZH40EVA505ITA@0805ITA@P0PJV1200f>2X01`21
ZH40:2/P02P[800X:b00PJV101PK5021ZH40[`2`h>H10?ooo`00[P2`h>H3086YP@@08R@L00<0PJV1
030a9@0`<BD01P21ZH4204I??003086YP@1GIT/0EfI;00d0EfI;00<0PJV1065bD`1QLU<0401QLU<0
0`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB01<0HgEB00<0PJV105e]B`1MKD/0401MKD/0
0`21ZH40EVA505ITA@0=05ITA@03086YP@18DSX0B58j00L0PJV10P0f>2X01021ZH40:2/P02P[800X
:b03086YPJh0/>3V0@3oool00:`0/>3V0`21ZH44028T70D0PJV12016Cc`00`21ZH40EfI;05MVB`0<
05MVB`03086YP@1QLU<0HG9C0140HG9C00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgEB06=eDP0C
06=eDP03086YP@1MKD/0GFe;0140GFe;00<0PJV105ITA@1FI4D0301FI4D00`21ZH40B58j04QB>P07
04QB>PD0PJV10`0X:b03086YPJ`0/>3V0@3oool00:/0/>3V00<0PJV1010D3`21ZH400P0R91`4086Y
P@/0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01<0I7ME00<0PJV106=eDP1SME804`1SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00d0EVA500<0PJV104QB>P18DSX02P18DSX4086YP@0402P[8021ZH4061/D086YPJ/0/>3V0@3oool0
0:X0/>3V1P21ZH4202d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21
ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=eDP1SME804`1SME800`21
ZH40GFe;05e]B`0B05e]B`03086YP@1FI4D0EVA500d0EVA500<0PJV104QB>P18DSX02@18DSX01021
ZH40<cHX03<f:00c=RP5086YPJX0/>3V0@3oool00:T0/>3V0`21ZH4602d`9P03086YP@16Cc`0ATll
00P0ATll00<0PJV105MVB`1GIT/03P1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01@0I7ME00<0PJV106=eDP1SME80501SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00h0EVA500<0PJV104QB>P18DSX02@18DSX00`21ZH40<cHX03<f:00303<f:0<0PJV1Z@2`h>H10?oo
o`00Y`2`h>H3086YP@L0;C0V00<0PJV104I??016Cc`02@16Cc`00`21ZH40EfI;05MVB`0=05MVB`03
086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgEB06=eDP0D06=eDP03
086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03@1FI4D00`21ZH40B58j04QB>P0:04QB>P03
086YP@0c=RP0<cHX00@0<cHX0`21ZH6W0;3PiP40oooo002V0;3PiP<0PJV11`0]<2H00`21ZH40ATll
04I??00904I??003086YP@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04P1QLU<00`21ZH40I7ME
06AgE@0D06AgE@03086YP@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04P1MKD/00`21ZH40EVA5
05ITA@0>05ITA@03086YP@18DSX0B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP3086YPJH0/>3V
0@3oool00:D0/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H00`21ZH40ATll04I??00904I??003086Y
P@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04`1QLU<00`21ZH40I7ME06AgE@0D06AgE@03086Y
P@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04`1MKD/00`21ZH40EVA505ITA@0>05ITA@03086Y
P@18DSX0B58j00T0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6U0;3PiP40
oooo002T0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02P16Cc`00`21ZH40
EfI;05MVB`0>05MVB`03086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD05@1TMeD00`21ZH40
HgEB06=eDP0E06=eDP03086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03P1FI4D00`21ZH40
B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1Y02`h>H10?oo
o`00X`2`h>H01021ZH405QXC01HJ4`21ZH4702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MV
B`1GIT/03P1GIT/00`21ZH40HG9C065bD`0C065bD`03086YP@1TMeD0I7ME01D0I7ME00<0PJV106=e
DP1SME805@1SME800`21ZH40GFe;05e]B`0C05e]B`03086YP@1FI4D0EVA500h0EVA500<0PJV104QB
>P18DSX02P18DSX00`21ZH40<cHX03<f:00403<f:004086YP@0O8QX07b8J086YPJ<0/>3V0@3oool0
0:80/>3V00@0PJV101HJ4`0F6Q<0PJV11`0]<2H00`21ZH40ATll04I??00904I??003086YP@1GIT/0
EfI;00l0EfI;00<0PJV1065bD`1QLU<03P1QLU<k086YPA00GFe;00<0PJV105ITA@1FI4D03`1FI4D0
0`21ZH40B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1XP2`
h>H10?ooo`00XP2`h>H00`21ZH405QXC086YP@0702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV1
05MVB`1GIT/03`1GIT/00`21ZH40HG9C065bD`03065bD``0PJV11@1dSFL00`21ZH40Mi5X07NAJ00E
07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0PJV106n6G@1_QUd00`1_QUd<086YP@D0GFe;00<0PJV1
05ITA@1FI4D03`1FI4D00`21ZH40B58j04QB>P0904QB>P03086YP@0c=RP0<cHX00D0<cHX00<0PJV1
01lR6P21ZH40XP2`h>H10?ooo`00X@2`h>H01021ZH405QXC01HJ4`21ZH4602d`9P03086YP@16Cc`0
ATll00X0ATll00<0PJV105MVB`1GIT/01P1GIT/?086YPA40M8eW00<0PJV107NAJ01gTFP05@1gTFP0
0`21ZH40MHmU07F?I@0E07F?I@03086YP@1_QUd0KhIM00l0KhIM3`21ZH4805ITA@03086YP@18DSX0
B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6Q0;3PiP40oooo002P
0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02016Cc`<086YP@T0K8=Q00<0
PJV107B=I`1dSFL04`1dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0
PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00706=gD0`0PJV12P18DSX00`21ZH40<cHX03<f
:00403<f:004086YP@0O8QX07b8J086YPJ00/>3V0@3oool009l0/>3V00@0PJV101HJ4`0F6Q<0PJV1
1`0]<2H00`21ZH40ATll04I??00304I??0D0PJV10P1LKU@00`21ZH40K8=Q06b3H@0?06b3H@03086Y
P@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40MHmU07F?I@0F07F?I@03086Y
P@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe003`1SMe000`21ZH40EfM705MWA`05086YP@H0B58j
00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6O0;3PiP40oooo002N0;3PiP04086Y
P@0F6Q<05QXC086YP@L0;C0V00<0PJV104I??021ZH401021ZH4605a^E003086YP@1/Pf40K8=Q0100
K8=Q00<0PJV107B=I`1dSFL0501dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0
MHmU00<0PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00@06=gD003086YP@1GIdL0EfM700@0
EfM71@21ZH400`18DSX0PJV103<f:00603<f:004086YP@0O8QX07b8J086YPIh0/>3V0@3oool009d0
/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H4086YP@/0G6iD00<0PJV106b3H@1/Pf40401/Pf400`21
ZH40M8eW07B=I`0D07B=I`03086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107F?I@1eSfD05P1eSfD00`21
ZH40KhIM06n6G@0D06n6G@03086YP@1SMe00HgM@0100HgM@00<0PJV105MWA`1GIdL02@1GIdL4086Y
P@H0<cHX00@0PJV101lR6P0O8QX0PJV1W@2`h>H10?ooo`00W02`h>H01@21ZH405QXC01HJ4`0F6Q<0
PJV100<0;C0V1021ZH4=05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL0501dSFL0
0`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd0501_QUd0
0`21ZH40HgM@06=gD00A06=gD003086YP@1GIdL0EfM700/0EfM71021ZH4303<f:005086YP@0O8QX0
7b8J01lR6P21ZH40W02`h>H10?ooo`00W02`h>H301HJ4`D0PJV10`11Bc`00`21ZH40G6iD05a^E00;
05a^E003086YP@1/Pf40K8=Q0100K8=Q00<0PJV107B=I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00F
07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00@
06=gD003086YP@1GIdL0EfM700/0EfM700@0PJV1049<=P12C3H0@T`f1@21ZH4201lR6P03086YP@2`
h>H0/>3V09X0/>3V0@3oool009/0/>3V0P0F6Q<3086YP@H0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0F07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00@0@T`f0`21ZH400`0O8QX0PJV10;3PiP2J
0;3PiP40oooo002J0;3PiP0401HJ4`21ZH40PJV1086YP@P0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f1021ZH6J0;3PiP40oooo002I0;3P
iP80PJV10P0Q9R000`21ZH40@D/l045;?005045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3
H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086YP@1gTFP0Mi5X01L0Mi5X00<0PJV107F?
I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0E06n6G@03086YP@1SMe00HgM@0140HgM@00<0PJV105MW
A`1GIdL02`1GIdL00`21ZH40@T`f049<=P05049<=P03086YP@0U9ah09BLN0080PJV1V@2`h>H10?oo
o`00V02`h>H01@21ZH408BHP024V800Q9R00PJV100P0@D/l00<0PJV105a^E01LKU@02`1LKU@00`21
ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP00`21
ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe000`21
ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f00D0PJV102DW7P0U9ah09BLN086YP@2H
0;3PiP40oooo002H0;3PiP04086YP@0Q9R008BHP086YP@P0@D/l00<0PJV105a^E01LKU@0301LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0<05MWA`03086YP@12C3H0@T`f00D0@T`f00D0PJV102DW7P0U9ah09BLN086Y
P@2H0;3PiP40oooo002G0;3PiP05086YP@0Q9R008BHP024V8021ZH402011Bc`00`21ZH40G6iD05a^
E00;05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL05P1dSFL00`21ZH40Mi5X07NA
J00G07NAJ003086YP@1eSfD0MHmU01L0MHmU00<0PJV106n6G@1_QUd05P1_QUd00`21ZH40HgM@06=g
D00A06=gD003086YP@1GIdL0EfM700/0EfM700<0PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW
7P0U9ah0PJV109L0/>3V0@3oool009H0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086Y
P@1LKU@0G6iD00`0G6iD00<0PJV106b3H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086Y
P@1gTFP0Mi5X01P0Mi5X00<0PJV107F?I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0F06n6G@03086Y
P@1SMe00HgM@0140HgM@00<0PJV105MWA`1GIdL0301GIdL00`21ZH40@T`f049<=P06049<=P05086Y
P@0U9ah09BLN02DW7P21ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH408BHP024V800Q9R00PJV100P0
@D/l00<0PJV105a^E01LKU@02`1LKU@00`21ZH40K8=Q06b3H@0B06b3H@03086YP@1dSFL0M8eW01D0
M8eW00<0PJV107NAJ01gTFP0601gTFP00`21ZH40MHmU07F?I@0H07F?I@03086YP@1_QUd0KhIM01D0
KhIM00<0PJV106=gD01SMe004P1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0
@T`f00D0PJV102DW7P0U9ah09BLN086YP@2F0;3PiP40oooo002E0;3PiP05086YP@0Q9R008BHP024V
8021ZH402011Bc`00`21ZH40G6iD05a^E00<05a^E003086YP@1/Pf40K8=Q0180K8=Q00<0PJV107B=
I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1eSfD0MHmU01P0MHmU00<0PJV106n6
G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0EfM700`0EfM700<0PJV1049<
=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109D0/>3V0@3oool009@0/>3V00D0PJV1024V
800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf404P1/Pf40
0`21ZH40M8eW07B=I`0:07B=Idl0PJV1301_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0
EfM700/0EfM700<0PJV1049<=P12C3H01`12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3o
ool009@0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086YP@1LKU@0G6iD00`0G6iD00<0
PJV106b3H@1/Pf403@1/Pf4B086YP@`0PZ9g00<0PJV108BTM`24Y7L06024Y7L00`21ZH40PZ9d08:R
M00H08:RM003086YP@1mVfd0OI]]00X0OI]]4P21ZH4?06=gD003086YP@1GIdL0EfM700`0EfM700<0
PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3oool009<0/>3V00D0
PJV1024V800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf40
0`1/Pf4;086YP@D0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03086Y
P@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0307:=H@/0PJV1
1@1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00L0@T`f00D0PJV102DW7P0U9ah0
9BLN086YP@2C0;3PiP40oooo002C0;3PiP04086YP@0Q9R008BHP086YP@T0@D/l00<0PJV105a^E01L
KU@02@1LKU@9086YPA00NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03
086YP@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0>07:=H@T0
PJV12`1GIdL00`21ZH40@T`f049<=P06049<=P05086YP@0U9ah09BLN02DW7P21ZH40T`2`h>H10?oo
o`00TP2`h>H01@21ZH408BHP024V800Q9R00PJV100T0@D/l00@0PJV105a^E01LKU@0G6iD2021ZH43
06j7I`03086YP@1kVG80NiUb0180NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0I
08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0B
07:=H@04086YP@1RMe00HWM@069gD0P0PJV10`1GIdL00`21ZH40@T`f049<=P07049<=P05086YP@0U
9ah09BLN02DW7P21ZH40TP2`h>H10?ooo`00T@2`h>H01@21ZH408BHP024V800Q9R00PJV100L0@D/l
1`21ZH4:06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag
08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ
07:=H@0C07:=H@03086YP@1RMe00HWM@00P0HWM@1`21ZH47049<=P05086YP@0U9ah09BLN02DW7P21
ZH40T@2`h>H10?ooo`00T@2`h>H01P21ZH408BHP024V800Q9R00PJV1045;?0H0PJV10P1DIU400`21
ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21
ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00`0HWM@00<0PJV104iN@01>GT001P21ZH400`12
C3H0PJV102DW7P0202DW7P03086YP@2`h>H0/>3V08l0/>3V0@3oool00900/>3V00@0PJV1024V800Q
9R008BHP0`21ZH4705AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG804`1kVG800`21
ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21
ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21
ZH40CUi004iN@00504iN@0<0PJV10`0U9ah00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP03
086YP@0Q9R008BHP00<0PJV12@1DIU400`21ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0
NiUb00<0PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0
PZ9d00<0PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0B07:=H@03086YP@1RMe00HWM@00d0
HWM@00<0PJV104iN@01>GT001`1>GT03086YP@809BLN00<0PJV10;3PiP2`h>H0S@2`h>H10?ooo`00
S`2`h>H01@0Q9R00PJV1086YP@0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40
NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40
PZ9d08:RM00I08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF404`1bSF400`21ZH40
HWM@069gD00=069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@21ZH400P21ZH6?0;3PiP40
oooo002>0;3PiP80PJV10`0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00d0KXMW
00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag
00<0PJV108:RM022XW@06@22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ
00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@004086YP@0^=2D0;S@U02hd9@80
PJV1SP2`h>H10?ooo`00SP2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^
QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01H0PZ9g00<0PJV108BTM`24
Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01H0OI]]00<0PJV107:=H@1b
SF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^
=2D00P0^=2F>0;3PiP40oooo002=0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU40
1`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL0
5`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0PJV107fKK@1mVfd0
5`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00d0HWM@00<0PJV104iN@01>GT00
1`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V00D0
PJV102dd;P0]=2h0;C@^086YP@0:05AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG80
4`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022XW@0
6P22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe00
3@1RMe000`21ZH40CUi004iN@00804iN@005086YP@0^=2D0;S@U02hd9@21ZH40S@2`h>H10?ooo`00
S02`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L0
6P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF40
4`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^=2D0
0P0^=2D00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002<0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0
PJV105AVD@1DIU401`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0
PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0D07:=H@03086YP@1RMe00HWM@00d0HWM@00<0
PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08X0/>3V0@3o
ool008`0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0905AVD@03086YP@1^QfL0KXMW00h0KXMW00<0
PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0H08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0
PJV108:RM022XW@06P22XW@00`21ZH40OI]]07fKK@0H07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0
PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40
S02`h>H10?ooo`00R`2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0
PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0
PJV108BTM`24Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01P0OI]]00<0
PJV107:=H@1bSF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0
PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP05086YP@0]=2h0
;C@^02dd;P21ZH402P1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0K08BTM`03086YP@22XW@0PZ9d01/0PZ9d00<0
PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0
PJV104iN@01>GT00201>GT001@21ZH40;S@U02hd9@0^=2D0PJV108/0/>3V0@3oool008X0/>3V00<0
PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00h0KXMW00<0
PJV107^ILP1kVG80501kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01/0Q:Ag00<0
PJV108:RM022XW@06`22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01@0LXeQ00<0
PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40
R`2`h>H10?ooo`00RP2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0
PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0
PJV108BTM`24Y7L03@24Y7LM086YP@l0PZ9d00<0PJV107fKK@1mVfd0601mVfd00`21ZH40LXeQ07:=
H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd
9@0202hd9@03086YP@2`h>H0/>3V08P0/>3V0@3oool008X0/>3V00D0PJV102dd;P0]=2h0;C@^086Y
P@0905AVD@03086YP@1^QfL0KXMW00l0KXMW00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:R
M`0;08:RMad0PJV13P2>]8<00`21ZH40SK6008faP00<08faP1d0PJV13@1mVfd00`21ZH40LXeQ07:=
H@0C07:=H@03086YP@1RMe00HWM@00l0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd
9@0^=2D0PJV108X0/>3V0@3oool008T0/>3V00<0PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AV
D@0705AVD@03086YP@1^QfL0KXMW00h0KXMW00<0PJV107^ILP1kVG802@1kVG8I086YP@d0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i00/0Qj]i6@21
ZH4;07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd
9@0202hd9@03086YP@2`h>H0/>3V08L0/>3V0@3oool008T0/>3V00D0PJV102dd;P0]=2h0;C@^086Y
P@0905AVD@03086YP@1^QfL0KXMW00L0KXMW5021ZH4;08N[P003086YP@2=/X@0SK:401P0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0
PJV107jNKP1nWVh02@1nWVhD086YP@T0HWM@00<0PJV104iN@01>GT001`1>GT001`21ZH40;S@U02hd
9@0^=2D0PJV10;3PiP3oO`00Q`2`h>H10?ooo`00R@2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100L0
E6IA3021ZH4807^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@0602=/X@00`21ZH40
S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06027ZgT00`21ZH40
OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00H0KHQL3021ZH4704iN@005086YP@0^=2D0;S@U02hd
9@21ZH400`3oO`260;3PiP40oooo00280;3PiP05086YP@0]=2h0;C@^02dd;P21ZH400P1DIU46086Y
P@80I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:4
01P0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i
01P0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa8
00H0PJV10P1>GT001@21ZH40;S@U02hd9@0^=2D0PJV10080ogl0QP2`h>H10?ooo`00R02`h>H00`21
ZH40;C@^02dd;P04086YP@P0I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21ZH40Qj^008N[P00D08N[
P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08fa
P003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00>06f8
G003086YP@1GK4P0Efa800H0Efa81021ZH4202hd9@03086YP@3oO`00ogl008H0/>3V0@3oool008L0
/>3V00H0PJV102dd;P21ZH40PJV103]8?P21ZH4906AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV1
08N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301/0S[B300<0PJV1
08faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV1
06f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00705M/B007086YP@0g@Rh0PJV1086YP@0^=2D0PJV1
0?mo00260;3PiP40oooo00270;3PiP80PJV10P0kB3h00`21ZH40I7aR06AlHP0806AlHP03086YP@1k
VgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>
]8<0S[B301/0S[B300<0PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1n
WVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00705M/B004086YP@0g
@Rh0=d8^03M2;P80PJV10P3oO`250;3PiP40oooo00270;3PiP05086YP@0kB3h0>dPn03]8?P21ZH40
2P1TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@0
6@2=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT0
6@27ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0
201GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV10080ogl0Q@2`h>H10?ooo`00QP2`h>H00`21ZH40>dPn
03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^0
08N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK60
08faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL
06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40ogl0
0?mo00240;3PiP40oooo00260;3PiP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680201T
O6800`21ZH40Ni]g07^KM`0>07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=
/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06@27
ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@1]R5`0KHQL00h0KHQL00<0PJV105M/B01GK4P0201G
K4P00`21ZH40=d8^03M2;P0203M2;P03086YP@3oO`00/>3V08@0/>3V0@3oool008H0/>3V00D0PJV1
03]8?P0kB3h0>dPn086YP@0:06AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005@27
Zh000`21ZH40SK:408fbQ00H08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H006`2=
/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]
R5`00`21ZH40Efa805M/B00705M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10?mo003oO`00Q02`
h>H10?ooo`00QP2`h>H01@21ZH40>dPn03]8?P0kB3h0PJV100X0I7aR00<0PJV107^KM`1kVgL03`1k
VgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>
]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0PJV107jNKP1nWVh05@1n
WVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800D0PJV103M2;P0g@Rh0=d8^
086YP@020?mo08@0/>3V0@3oool008D0/>3V00<0PJV103]8?P0kB3h00P0kB3h00`21ZH40I7aR06Al
HP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fb
Q00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[
N@0I08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/
B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10?mo002`h>H0P`2`h>H10?ooo`00Q@2`h>H0
0`21ZH40>dPn03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL0
0`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<0
0`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh0
0`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh0
0`21ZH40ogl00;3PiP230;3PiP40oooo00250;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO680
0`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@0
0`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT0
0`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P0
0`21ZH40=d8^03M2;P0203M2;P03086YP@3oO`00ogl008<0/>3V0@3oool008D0/>3V00D0PJV103]8
?P0kB3h0>dPn086YP@0;06AlHP03086YP@1kVgL0Ni]g00h0Ni]g00<0PJV108N[P027Zh005@27Zh00
0`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H00
0`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03P1]R5`0
0`21ZH40Efa805M/B00905M/B005086YP@0g@Rh0=d8^03M2;P21ZH400P3oO`230;3PiP40oooo0024
0;3PiP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?
07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0L
08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E
07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P02
03M2;P03086YP@3oO`00/>3V0880/>3V0@3oool008@0/>3V00<0PJV103]8?P0kB3h00P0kB3h00`21
ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005@27Zh000`21
ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21
ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21
ZH40Efa805M/B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10?mo002`h>H0PP2`h>H10?oo
o`00Q02`h>H01@21ZH40>dPn03]8?P0kB3h0PJV100/0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21
ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21
ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21
ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21
ZH40ogl00?mo00220;3PiP40oooo00240;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21
ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06P2=/X@00`21
ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06P27ZgT00`21
ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P02@1GK4P01@21
ZH40=d8^03M2;P0g@Rh0PJV10080ogl0PP2`h>H10?ooo`00P`2`h>H00`21ZH40>dPn03]8?P0203]8
?P03086YP@1TO680I7aR00T0I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21ZH40Qj^008N[P00E08N[
P003086YP@2=/X@0SK:401X0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08fa
P003086YP@27ZgT0Qj]i01X0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00>06f8
G003086YP@1GK4P0Efa800T0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40ogl00;3PiP210;3P
iP40oooo00230;3PiP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40
Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@0302=/XAK086YP@h0
Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0
Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40ogl00?mo00210;3PiP40oooo00230;3PiP05086Y
P@0kB3h0>dPn03]8?P21ZH402`1TO6800`21ZH40Ni]g07^KM`0707^KMbl0PJV13P2F_hh00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<0302@^8<_086YP@T0
KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@3oO`00/>3V0840
/>3V0@3oool008<0/>3V100kB3h00`21ZH40I7aR06AlHP0406AlHPl0PJV12026Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj9
09FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00607RHJ0l0PJV11P1GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108<0/>3V0@3oool00880/>3V
00<0PJV103]8?P0kB3h02@21ZH45072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/0
5@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0
702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P0
3`1hV6P00`21ZH40GWM>05igCP0305igCPT0PJV10P0g@Rh00`21ZH40/>3V0;3PiP200;3PiP40oooo
00220;3PiP<0PJV10P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0
PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0PJV1PP2`
h>H10?ooo`00PP2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV1
08J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV1
09O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV1
08N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV1
03i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@18G4h0B5a>
0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;
01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj9
01`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX
00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V
0800/>3V0@3oool00880/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03
086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03
086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03
086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03
086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40B5a>
04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj9
09FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V
0;3PiP200;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`
Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F
_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@
^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1N
Mdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V0800/>3V0@3oool00840/>3V00<0PJV1
04QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1
096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV1
09FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV1
07RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV1
0;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03
086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03
086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06@2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03
086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03
086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003
086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma
072?L@08072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>
09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3
092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03P1hV6P00`21ZH40GWM>
05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`
h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G
`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0n
CS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1
072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV1
09JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1
092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV1
05igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool0
0840/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^3
00l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=
01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai
01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd
0080?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QLCP03
086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03
086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03
086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003
086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40
oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^3
08J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=
09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai
08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd
03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18
G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A
^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E
_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1h
V6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`
h>H10?ooo`00P02`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV1
08J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV1
09O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV1
08N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV1
03i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@18G4h0B5a>
00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;
01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj9
01d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX
00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003086YP@2`h>H0/>3V
07h0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03
086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03
086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03
086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03
086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40B5a>
04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj9
09FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V
0;3PiP1n0;3PiP40oooo00200;3Pi_<0PJV1P02`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03
059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?
082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n
0;3PiP40oooo00200;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21
ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21
ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21
ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21
ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV1059/F`1B
K5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02H
a9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2K
b9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20
YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`
h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H
00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@1B
K5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2H
a9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2K
b980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20
YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`
h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO009
07VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J
09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J
09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F009
06J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21
ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21
ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21
ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01i
WG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2L
bIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G
`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01V
PeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V
00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=
00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E
00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR2
00<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi
00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1i
WG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2L
bIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G
`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1V
PeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo0021
0;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`0201iWG`00`21ZH40S[R=08jhS@0?
08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M
09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E
08nhPP03086YP@20YG80P:Eb00h0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@03
04=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21
ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21
ZH40W<VF09c9UP0I09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb980702Kb9800`21
ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21
ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?oo
o`00P@2`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>
^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2M
biD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?
^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13
EcT00`13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0DVaK
00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD
00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB
00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb
00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07l0/>3V
0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>
^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2M
biD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?
^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13
EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02
059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?
082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP20
0;3PiP40oooo00220;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`00`21
ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21
ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21
ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21
ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV1059/F`1B
K5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02H
a9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2K
b980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20
YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`
h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H
00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP<0PJV10P1B
K5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2H
a9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702K
b9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20
YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0PJV1PP2`h>H10?ooo`00PP2`h>H0
0`21ZH40FGQT05UhI008086YP@H0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?
082ULP03086YP@1VPeP0IX=H00@0IX=H2021ZH4204EL?003086YP@2`h>H0/>3V0800/>3V0@3oool0
08<0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0507nXQ@l0PJV12@2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP07
082ULPl0PJV11@1/SV400`21ZH40AE`l04EL?00204EL?8<0/>3V0@3oool008<0/>3V00D0PJV105Uh
I01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00H0U<:E<021ZH4>09c9UP03086YP@2MbiD0
WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00<09O2S300PJV12026[gX0
0`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P@2`h>H1
0?ooo`00P`2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2
U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M00`0X]:MF`21ZH4>09c;
T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>
H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P@2`h>H10?ooo`00P`2`h>H00`21ZH40
FGQT05UhI00205UhI003086YP@1oZ8D0OjR500T0OjR500<0PJV109C2U@2D`YD03P2D`YD00`21ZH40
W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01X0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40
XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01X0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40
QZmj08J_NP0>08J_NP03086YP@1/SV40K8iQ00T0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40
/>3V0;3PiP210;3PiP40oooo00240;3PiP05086YP@1IN6@0FGQT05UhI021ZH402`1oZ8D00`21ZH40
U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06P2RdYd00`21ZH40
X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<06P2Lbi<00`21ZH40
U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV402@1/SV401@21ZH40
AE`l04EL?015G3`0PJV108@0/>3V0@3oool008@0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nX
Q@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;B
W@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;
T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>
H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00Q02`h>H00`21ZH40
FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40
W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40
XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40
QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40
/>3V0;3PiP220;3PiP40oooo00240;3PiP03086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0
201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd0
6@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<0
6@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40
201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0880/>3V0@3oool008D0/>3V00D0
PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00h0U<:E00<0PJV109k>V`2NcY/0
5@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0
702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX0
3P26[gX00`21ZH40K8iQ06b>H@0906b>H@05086YP@15G3`0AE`l04EL?021ZH40Q@2`h>H10?ooo`00
Q@2`h>H01@21ZH40FGQT05UhI01IN6@0PJV100/0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40
W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40
XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40
QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40
/>3V0;3PiP230;3PiP40oooo00250;3PiP03086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0
201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd0
6@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<0
6@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40
201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08<0/>3V0@3oool008D0/>3V00<0
PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0
PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0
PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:00<0
PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0
PJV10;3PiP2`h>H0P`2`h>H10?ooo`00QP2`h>H01@21ZH40FGQT05UhI01IN6@0PJV100X0OjR500<0
PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0
PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0
PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00D0
PJV104EL?015G3`0AE`l086YP@260;3PiP40oooo00260;3PiP05086YP@1IN6@0FGQT05UhI021ZH40
2P1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd0
602RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<0
6@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40
1`1/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08@0/>3V0@3oool008H0/>3V00<0
PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0U<:E00h0U<:E00<0
PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0
PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0
PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0
PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`h>H00`000000PJV105UhI00305UhI003086YP@1oZ8D0
OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0
X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0
W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40
K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP240;3PiP40oooo00240;3P
iP<0000000D0PJV105UhI01IN6@0FGQT086YP@0:07nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV1
09k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV1
0:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:00<0PJV1
08J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@05086YP@15G3`0AE`l04EL?021ZH40Q`2`
h>H10?ooo`00Q@2`h>H300000004086YP@000000FGQT086YP@X0OjR500<0PJV109C2U@2D`YD03`2D
`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2R
di`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D
`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00L0K8iQ00@0PJV104EL?015G3`0AE`l
0P21ZH670;3PiP40oooo00250;3PiPH0000000D0FGQT086YP@1oZ8D0OjR50000000607nXQ@03086Y
P@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086Y
P@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086Y
P@2D`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0706b>H@06086Y
P@15G3`0PJV1086YP@17HT00PJV1Q`2`h>H10?ooo`00Q@2`h>H6000000<0PJV10`00000607nXQ@03
0000002D`YD0U<:E00h0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03
086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03
086YP@2D`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0606b>H@@0
PJV10P17HT000`21ZH40/>3V0;3PiP260;3PiP40oooo00260;3PiPD0000000@0GH1[086YP@23[h/0
Pjn;0P000004086YP@0307nXQ@0000000000008000003`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03
086YP@2RdYd0X]:M01P0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003
086YP@2Lbi<0W<^C01P0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03
086YP@1/SV40K8iQ00H0PJV10P1`UVP01@21ZH40Af9004MR@017HT00PJV108P0/>3V0@3oool008H0
/>3V1P0000000`1MP6/0PJV108>_R`02000000@0Pjn;1`000004086YP@P0U<:E00@00000086YP@2N
cY/00000102NcY/00`000000W/jK09k>V`0=09k>V`03086YP@2RdYd0X]:M01P0X]:M00<0PJV10:;C
W02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0PJV109C1
RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0708J_NP/0PJV11`1`UVP01@21ZH40Af9004MR@017HT00
PJV108T0/>3V0@3oool008H0/>3V1P0000000`1MP6/0PJV108>_R`03000000<0Pjn;0P0000000`21
ZH40UlVK00000003000000<0UlVK1P21ZH4700000080PJV10`000003086YP@X0W/jK00D00000086Y
P@2RdYd0X]:M0000000G0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP0
0`21ZH40W<^C09c;T`0H09c;T`03086YP@2D`HX0U<6:00T0U<6:5@21ZH4808ZfP@03086YP@1`UVP0
L9IX00L0L9IX00D0PJV104MR@017HT00Af90086YP@290;3PiP40oooo00270;3PiPD000000P1MP6/0
1021ZH40Pjn;00000000000308>_R`80000000@0Pjn;086YP@2GbI/0UlVK0`00000709O9V`X00000
00<0XMBQ0000000000000`2Qe:48086YP@P000002@21ZH4=0:;BW@030000002Rdi`0X]>L0140X]>L
00<000000:;CW02Rdi`01`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C00/0W<^C
6@21ZH4;09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af90
04MR@00204MR@003086YP@2`h>H0/>3V08L0/>3V0@3oool008L0/>3V1P0000000`1MP6/0PJV108>_
R`0200000080Pjn;0`0000000`23[h/0PJV109O9V`0209O9V`<000001P2GbI/2000000<0UlVK00<0
PJV10:7DX@0000001@00000:0:7DX@/000001`2UfJ<5086YP@l000002021ZH440:;CW0<00000202R
di`00`21ZH40XM6H0:7AV00=0:7AV1`0PJV13@2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:
]X40R[J100l0R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017HT00PJV108X0/>3V
0@3oool008P0/>3V1@00000205f0J`05086YP@000000000000000023[h/00P00000308>_R`04086Y
P@2GbI/0UlVK09O9V`<00000102GbI/2000000@0UlVK00@0PJV10:7DX@2Qe:40XMBQ1000000:0:7D
X@8000000P2Qe:401021ZH40YMVS0:GIX`2UfJ<4000000X0YMVS400000080:KJXP<0PJV11@00000G
086YP@h0Y=RN00<0PJV10:3BV@2PdYT0602PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40
R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@00204MR@003086YP@2`h>H0
/>3V08P0/>3V0@3oool008P0/>3V1P0000000`1MP6/0PJV108>_R`020000000308>_R`0000000000
00<0Pjn;00<0PJV109O9V`2GbI/00P2GbI/00`000000UlVK09O9V`0309O9V`800000102GbI/00`21
ZH40XMBQ0:7DX@020:7DX@@00000202Qe:42000000@0XMBQ00<0PJV10:GIX`2UfJ<00P2UfJ<40000
00P0YMVS0P0000070:GIX`03086YP@2VfZ80Y]ZR00<0Y]ZR0P00000;0:KJXPD000001P2VfZ800`21
ZH40Y=RN0:CHWP0K0:CHWP03086YP@2PdYT0X=:I01L0X=:I00<0PJV109S8T02Hb900502Hb9000`21
ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0L9IX00D0PJV104MR@017HT00Af90086YP@2;
0;3PiP40oooo00280;3PiPH0000000<0GH1[086YP@23[h/01@00000408>_R`03086YP@2GbI/0UlVK
00L0UlVK0P00000409O9V`03086YP@2Qe:40XMBQ00@0XMBQ0P0000070:7DX@<00000102Qe:400`21
ZH40YMVS0:GIX`030:GIX`@000001`2UfJ<2000000L0YMVS00<0PJV10:KJXP2VfZ80102VfZ820000
00X0Y]ZR100000070:KJXP03086YP@2Tf9h0Y=RN01/0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21
ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP0201`UVP01@21
ZH40Af9004MR@017HT00PJV108/0/>3V0@3oool008T0/>3V1@00000205f0J`03086YP@23[h/00000
00@000000`23[h/00`21ZH40UlVK09O9V`0709O9V`8000001@2GbI/00`21ZH40XMBQ0:7DX@030:7D
X@8000001`2Qe:42000000D0XMBQ00<0PJV10:GIX`2UfJ<01@2UfJ<00`000000YMVS0:GIX`050:GI
X`<00000202UfJ<00`21ZH40Y]ZR0:KJXP030:KJXP8000002`2VfZ800`000000Y]ZR0:KJXP070:KJ
XP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT0602PdYT00`21ZH40V<R@09S8T00C09S8
T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@00204MR
@003086YP@2`h>H0/>3V08T0/>3V0@3oool008P0/>3V1`0000000`1MP6/0PJV108>_R`0200000003
08>_R`000000000000T00000102GbI/2000000D0UlVK00<0PJV10:7DX@2Qe:400`2Qe:43000000H0
XMBQ0P0000050:7DX@03086YP@2UfJ<0YMVS00h0YMVS00<000000:GIX`2UfJ<01`2UfJ<00`21ZH40
Y]ZR0:KJXP030:KJXP8000005@2VfZ800`21ZH40Y=RN0:CHWP0J0:CHWP03086YP@2PdYT0X=:I01P0
X=:I00<0PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0
L9IX00D0PJV104MR@017HT00Af90086YP@2<0;3PiP40oooo00280;3PiPP0000000<0GH1[086YP@00
00000P0000000`23[h/0000000000009000000<0UlVK0P00000509O9V`03086YP@2Qe:40XMBQ00@0
XMBQ0P0000050:7DX@<000001P2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR00<0
Y]ZR0P00000E0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40
V<R@09S8T00D09S8T003086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40
Af9004MR@00204MR@003086YP@2`h>H0/>3V08X0/>3V0@3oool008/0/>3V1P0000000`21ZH400000
0000000308>_R`8000000P23[h/01021ZH40UlVK09O9V`2GbI/2000000<0UlVK0P00000609O9V`03
086YP@2Qe:40XMBQ00<0XMBQ0P0000060:7DX@8000001P2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03
086YP@2VfZ80Y]ZR0080Y]ZR0P00000F0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2P
dYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`
UVP01`1`UVP00`21ZH40Af9004MR@00204MR@003086YP@2`h>H0/>3V08X0/>3V0@3oool008/0/>3V
2@00000408>_R`0500000023[h/0Pjn;08>_R`21ZH400P2GbI/2000000<0UlVK0`00000509O9V`03
086YP@2Qe:40XMBQ00<0XMBQ0P0000060:7DX@8000001P2Qe:400`21ZH40YMVS0:GIX`050:GIX`03
0000002UfJ<0YMVS00l0YMVS00<0PJV10:KJXP2VfZ801000000F0:KJXP03086YP@2Tf9h0Y=RN01X0
Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100d0
R[J100<0PJV1072FJ01`UVP0201`UVP01@21ZH40Af9004MR@017HT00PJV108d0/>3V0@3oool008`0
/>3V2000000408>_R`8000000P23[h/00`21ZH40UlVK09O9V`02000000D0UlVK0P00000409O9V`03
086YP@2Qe:40XMBQ00<0XMBQ0`0000050:7DXA400000302UfJ<;000000d0Y]ZR0P0000080:KJXP03
086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003
086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@00204MR@003
086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V0P0000000`1MP6/0000000000002000000D0Pjn;
0P0000001023[h/0PJV109O9V`2GbI/2000000D0UlVK0`00000409O9V`03086YP@2Qe:40XMBQ00<0
XMBQ0P0000050:7DXA8000002@2UfJ<;000000l0Y]ZR0P0000080:KJXP03086YP@2Tf9h0Y=RN01X0
Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100h0
R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017HT00PJV108h0/>3V0@3oool008d0
/>3V00<00000086YP@1MP6/01000000508>_R`@0000000<0PJV109O9V`0000000P00000509O9V`@0
00000P2GbI/00`21ZH40XMBQ0:7DX@020:7DX@<000001`2Qe:42000000D0XMBQ00<0PJV10:GIX`2U
fJ<0102UfJ<3000000L0YMVS100000050:GIX`03086YP@2VfZ80Y]ZR00l0Y]ZR0P0000080:KJXP03
086YP@2Tf9h0Y=RN01T0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003
086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@00204MR@003
086YP@2`h>H0/>3V08`0/>3V0@3oool008`0/>3V0`000002086YP@80GH1[00<0PJV108>_R`23[h/0
1023[h/7000000L0UlVK100000000`2GbI/0PJV10:7DX@020:7DX@@000001`2Qe:43000000@0XMBQ
00<0PJV10:GIX`2UfJ<0102UfJ<2000000L0YMVS0`0000070:GIX`03086YP@2VfZ80Y]ZR00<0Y]ZR
00<000000:KJXP2VfZ802@2VfZ82000000P0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40X=:I
0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403@2:]X400`21ZH40L9IX
072FJ007072FJ003086YP@17HT00Af900080PJV1S`2`h>H10?ooo`00S02`h>H300000006086YP@1N
Q6d0PJV1086YP@1MP6/0PJV11P23[h/5000000X0UlVK0`0000000`21ZH40XMBQ0:7DX@06000000L0
XMBQ100000020:7DX@03086YP@2UfJ<0YMVS00@0YMVS0P0000060:GIX`<00000202UfJ<00`21ZH40
Y]ZR0:KJXP030:KJXP030000002VfZ80Y]ZR00T0Y]ZR0P0000080:KJXP03086YP@2Tf9h0Y=RN01T0
Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00B09S8T003086YP@2:]X40R[J100d0
R[J100<0PJV1072FJ01`UVP01`1`UVP01P21ZH40Af90086YP@21ZH40BFM5086YPHl0/>3V0@3oool0
08`0/>3V0`000000102`h>H0PJV105j4K@1NQ6d4086YP@L0Pjn;00<0PJV109O9V`2GbI/02P2GbI/7
00000080XMBQ0P0000080:7DX@D0000000<0XMBQ086YP@2UfJ<00`2UfJ<3000000L0YMVS0`000007
0:GIX`03086YP@2VfZ80Y]ZR0080Y]ZR0P00000;0:KJXP800000202VfZ800`21ZH40Y=RN0:CHWP0I
0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0=
08ZfP@03086YP@1`UVP0L9IX00D0L9IX1021ZH4204UWA@03086YP@2`h>H0/>3V08h0/>3V0@3oool0
0940/>3V00H0PJV105j4K@1NQ6d0GXA]086YP@23/Hd6086YP@80Pjn;00<0PJV109O9V`2GbI/02@2G
bI/6000000<0XMBQ0P00000:0:7DX@/000002@2UfJ<700000080YMVS00<0PJV10000000000000`00
000<0:KJXP800000202VfZ800`21ZH40Y=RN0:CHWP0I0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0
PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0<08ZfP@03086YP@1`UVP0L9IX00H0PJV100<0
LIY/086YP@19IdD00P19IdD00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002A0;3PiP05086YP@1NQ6d0
GXA]05j4K@21ZH401`23/Hd6086YP@/0UlVK00<0PJV10:7DX@2Qe:400`2Qe:42000000/0XMBQ2@00
000;0:GIX`h00000302VfZ82000000P0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40X=:I0:3B
V@0F0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X402@2:]X46086YP@L0LIY/00D0
PJV104UWA@19IdD0BFM5086YP@2A0;3PiP40oooo002B0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH40
2@23/Hd00`21ZH40V<bN09S<WP08086YP@@0UlVK00<0PJV10:7DX@2Qe:400P2Qe:43000000d0XMBQ
00<0PJV10:GIX`2UfJ<04P2UfJ<600000100Y]ZR0P0000080:KJXP03086YP@2Tf9h0Y=RN01T0Y=RN
00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00B09S8T003086YP@2:]X40R[J10080R[J1
2021ZH4208^jQ@03086YP@1aVV`0LIY/00L0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2B0;3PiP40
oooo002C0;3PiP04086YP@1NQ6d0GXA]086YP@T0Pk6=00<0PJV109S<WP2Hc9h0202Hc9h:086YP@80
00003P2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR00h0Y]ZR0P0000080:KJXP03
086YP@2Tf9h0Y=RN01P0Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00>09S8T0X0
PJV12P2;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40T`2`h>H10?oo
o`00T`2`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100T0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21
ZH40XmVU0:?IY@030:?IY@8000002@21ZH450:7DX@03086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJ
XP2VfZ803P2VfZ82000000P0Y]ZR00<0PJV10:CHWP2Tf9h0602Tf9h00`21ZH40X=:I0:3BV@0F0:3B
V@03086YP@2Hb900V<R@00<0V<R@2`21ZH4509W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076J
K01aVV`01`1aVV`01@21ZH40BFM504UWA@19IdD0PJV109<0/>3V0@3oool009@0/>3V00D0PJV105j4
K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00`0V<bN00<0PJV10:?IY@2SfJD00P2SfJD2
000000T0XmVU4P21ZH4<0:GIX`03086YP@2VfZ80Y]ZR00h0Y]ZR0P0000080:KJXP03086YP@2Tf9h0
Y=RN01P0Y=RN00<0PJV10:3BV@2PdYT02P2PdYTB086YP@l0VLbD00<0PJV108^jQ@2;^XD0302;^XD0
0`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40U02`h>H10?ooo`00U02`h>H0
1@21ZH40GXA]05j4K@1NQ6d0PJV100T0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?I
Y@020:?IY@<000003@2SfJD00`21ZH40YmjW0:ONY`0:0:ONYad0PJV10P00000`086YP@`0X]NM00<0
PJV109W<U02Ic9@04P2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00L0LIY/00D0
PJV104UWA@19IdD0BFM5086YP@2D0;3PiP40oooo002E0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH40
2023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0XmVU0080XmVU00<000000:?IY@2SfJD0
3@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV00h0Z=nV0P0000080:SOYP03086Y
P@2Vg:80Y]bR01P0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00B09W<U003086Y
P@2;^XD0RkZ500`0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109D0
/>3V0@3oool009H0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00/0
V<bN00<0PJV10:?IY@2SfJD04P2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV00h0
Z=nV0P0000080:SOYP03086YP@2Vg:80Y]bR01P0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40
VLbD09W<U00B09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40
BFM504UWA@19IdD0PJV109H0/>3V0@3oool009H0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>a
S@03086YP@2Hc9h0V<bN00`0V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ON
Y`03086YP@2XgjH0Z=nV00l0Z=nV0P0000070:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;G
W@2Reid05P2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500`0RkZ500<0PJV1076J
K01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109H0/>3V0@3oool009L0/>3V00D0PJV105j4
K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0PJV10:?IY@2SfJD04@2SfJD0
0`21ZH40YmjW0:ONY`0F0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:KLXP2Vg:805`2Vg:80
0`21ZH40X]NM0:;GW@0F0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;^XD02`2;^XD0
0`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40U`2`h>H10?ooo`00V02`h>H0
1021ZH40GXA]05j4K@21ZH4808>aS@03086YP@2Hc9h0V<bN00`0V<bN00<0PJV10:?IY@2SfJD04@2S
fJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:KLXP2Vg:805`2V
g:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;^XD0302;
^XD00`21ZH40LIY/076JK005076JK005086YP@19IdD0BFM504UWA@21ZH40V02`h>H10?ooo`00V02`
h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU
0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR
0:KLXP0G0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ5
08^jQ@0;08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2H0;3PiP40
oooo002I0;3PiP80PJV10P1NQ6d00`21ZH40Pk6=08>aS@0508>aS@03086YP@2Hc9h0V<bN00/0V<bN
00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV
00<0PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0140VLbD
00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK005076JK003086YP@19IdD0BFM50080PJV1
V@2`h>H10?ooo`00VP2`h>H4086YP@P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?I
Y@0A0:?IY@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR0:KL
XP0G0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^j
Q@0;08^jQ@03086YP@1aVV`0LIY/00H0LIY/1021ZH6J0;3PiP40oooo002K0;3PiP03086YP@1KPV`0
PJV10080PJV11P23/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV1
0:ONY`2WgZL0502WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV1
0:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1
076JK01aVV`0101aVV`3086YP@0304QYB021ZH40/>3V09X0/>3V0@3oool009`0/>3V00<0PJV105^2
K01KPV`01021ZH4408>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0PJV10:?IY@2SfJD0402SfJD00`21
ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805P2Vg:800`21
ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0100VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21
ZH40LIY/076JK002076JK0@0PJV10P18JDP00`21ZH40/>3V0;3PiP2J0;3PiP40oooo002L0;3PiP05
086YP@1KPV`0Fh9/05^2K021ZH400P1n[X/5086YP@d0V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21
ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805P2Vg:800`21
ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;^XD02`2;^XD5086Y
P@80KYU/00D0PJV104QYB018JDP0B6U8086YP@2L0;3PiP40oooo002M0;3PiP04086YP@1KPV`0Fh9/
086YP@H0OZj;1021ZH4;09S<WP03086YP@2SfJD0XmVU0100XmVU00<0PJV10:ONY`2WgZL0502WgZL0
0`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV10:;GW@2Reid0502Reid0
0`21ZH40VLbD09W<U00@09W<U003086YP@2;^XD0RkZ500T0RkZ51021ZH4606jIK004086YP@18JDP0
B6U8086YPId0/>3V0@3oool009h0/>3V00@0PJV105^2K01KPV`0PJV11`1n[X/00`21ZH40U<ZM086Y
P@04086YP@H0V<bN00<0PJV10:?IY@2SfJD0402SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2X
gjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2I
c9@0VLbD0100VLbD00<0PJV108^jQ@2;^XD0102;^XD5086YP@0308RiQ@21ZH40KYU/00H0KYU/00@0
PJV104QYB018JDP0PJV1WP2`h>H10?ooo`00W`2`h>H01021ZH40Fh9/05^2K021ZH4707j^R`03086Y
P@2DbYd0U<ZM00<0U<ZM1@21ZH4209S<WP03086YP@2SfJD0XmVU00l0XmVU00<0PJV10:ONY`2WgZL0
502WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV10:;GW@2Reid0
502Reid00`21ZH40VLbD09W<U00?09W<U003086YP@2;^XD0RkZ500D0PJV11P28^HD00`21ZH40KYU/
06jIK00406jIK004086YP@18JDP0B6U8086YPIl0/>3V0@3oool00:00/>3V00@0PJV105^2K01KPV`0
PJV11P1n[X/00`21ZH40U<ZM09C:W@0809C:W@`0PJV12@2SfJD00`21ZH40YmjW0:ONY`0C0:ONY`03
086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805@2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03
086YP@2Ic9@0VLbD00L0VLbD3021ZH4:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018
JDP0PJV1X02`h>H10?ooo`00X@2`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2DbYd0U<ZM
00X0U<ZM00<0PJV10:3HY@2Pf:D01P2Pf:D?086YPA40YmjW00<0PJV10:SOYP2XgjH05@2XgjH00`21
ZH40Y]bR0:KLXP0E0:KLXP03086YP@2Reid0X]NM00l0X]NM3`21ZH4809S=U@03086YP@28^HD0R;V5
00X0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6Q0;3PiP40oooo002R0;3P
iP03086YP@1KPV`0PJV100L0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0?0:3H
Y@03086YP@2VgZP0Y]jX00<0Y]jX3021ZH450:ONY`03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:KL
XP2Vg:805@2Vg:800`21ZH40X]NM0:;GW@030:;GW@`0PJV11@2Qf9h00`21ZH40V<fE09S=U@0?09S=
U@03086YP@28^HD0R;V500T0R;V500<0PJV106jIK01^VF`01@1^VF`00`21ZH40B6U8086YP@2R0;3P
iP40oooo002R0;3PiP04086YP@1KPV`0Fh9/086YP@L0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21
ZH40X=RU0:3HY@0?0:3HY@03086YP@2VgZP0Y]jX00h0Y]jX>`21ZH4@0:7HWP03086YP@2HcID0V<fE
00l0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK00406jIK004086YP@18JDP0B6U8
086YPJ80/>3V0@3oool00:<0/>3V00@0PJV105^2K01KPV`0PJV11`1n[X/00`21ZH40U<ZM09C:W@09
09C:W@03086YP@2Pf:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04`2VgZP00`21ZH40Yn2W0:OPY`0E
0:OPY`03086YP@2VgZ@0Y]jT01D0Y]jT00<0PJV10:7HWP2Qf9h04`2Qf9h00`21ZH40V<fE09S=U@0>
09S=U@03086YP@28^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021
ZH6S0;3PiP40oooo002T0;3PiP04086YP@1KPV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2DbYd02P2D
bYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX0180Y]jX00<0PJV10:OPY`2Wh:L05@2W
h:L00`21ZH40Y]jT0:KNY00E0:KNY003086YP@2Qf9h0XMRN0180XMRN00<0PJV109S=U@2HcID03P2H
cID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1
Y02`h>H10?ooo`00Y@2`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2DbYd0U<ZM00T0U<ZM
00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00C0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W
00<0PJV10:KNY02VgZ@0502VgZ@00`21ZH40XMRN0:7HWP0C0:7HWP03086YP@2HcID0V<fE00h0V<fE
00<0PJV108RiQ@28^HD02@28^HD00`21ZH40KYU/06jIK00406jIK004086YP@18JDP0B6U8086YPJD0
/>3V0@3oool00:H0/>3V0`21ZH4707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D0
3P2Pf:D00`21ZH40Y]jX0:KNZ00B0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@0
502VgZ@00`21ZH40XMRN0:7HWP0B0:7HWP03086YP@2HcID0V<fE00h0V<fE00<0PJV108RiQ@28^HD0
2P28^HD00`21ZH40KYU/06jIK00406jIK0<0PJV1YP2`h>H10?ooo`00Y`2`h>H3086YP@L0OZj;00<0
PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0180Y]jX00<0
PJV10:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0XMRN0180XMRN00<0
PJV109S=U@2HcID03@2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/0`21
ZH6W0;3PiP40oooo002Y0;3PiP<0PJV11P1n[X/00`21ZH40U<ZM09C:W@0809C:W@03086YP@2Pf:D0
X=RU00h0X=RU00<0PJV10:KNZ02VgZP04@2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2VgZ@0
Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04@2Qf9h00`21ZH40V<fE09S=U@0>09S=U@03086YP@28^HD0
R;V500T0R;V500<0PJV106jIK01^VF`00`1^VF`3086YPJT0/>3V0@3oool00:X0/>3V1@21ZH4307j^
R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21ZH40Y]jX0:KNZ00A0:KN
Z003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7HWP0B0:7H
WP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD02@28^HD01021ZH40KYU/06jIK01^VF`5
086YPJX0/>3V0@3oool00:/0/>3V00@0PJV105AkIP21ZH40M:B31@21ZH4;09C:W@03086YP@2Pf:D0
X=RU00d0X=RU00<0PJV10:KNZ02VgZP04@2VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2VgZ@0
Y]jT01<0Y]jT00<0PJV10:7HWP2Qf9h04@2Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28^HD0
R;V500X0R;V51021ZH40101VTFP0PJV104AUB021ZH6[0;3PiP40oooo002/0;3PiP<0PJV1101dY8<5
086YP@P0U<ZM00<0PJV10:3HY@2Pf:D0302Pf:D00`21ZH40Y]jX0:KNZ00A0:KNZ003086YP@2Wh:L0
Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7HWP0A0:7HWP03086YP@2HcID0
V<fE00`0V<fE00<0PJV108RiQ@28^HD01`28^HD5086YP@<0IY5X0`21ZH6/0;3PiP40oooo002^0;3P
iP<0PJV1101dY8<00`21ZH40Rl2F08_0UP06086YP@80U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21
ZH40Y]jX0:KNZ00@0:KNZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21
ZH40XMRN0:7HWP0@0:7HWP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD01`21ZH4207na
P@04086YP@1VTFP0IY5X06JAJ0<0PJV1[P2`h>H10?ooo`00[`2`h>H00`21ZH40E7]V086YP@0407BT
P`03086YP@2;`9H0Rl2F00D0Rl2F1`21ZH4;0:3HY@03086YP@2VgZP0Y]jX0100Y]jX00<0PJV10:OP
Y`2Wh:L04`2Wh:L00`21ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0100XMRN00<0PJV109S=
U@2HcID02@2HcID7086YP@P0Ok6100L0PJV106JAJ01VTFP0IY5X086YP@14IDP0PJV10:l0/>3V0@3o
ool00;00/>3V00<0PJV105AkIP21ZH40101dY8<00`21ZH40Rl2F08_0UP0808_0UP03086YP@2HdJ00
V=6P00P0PJV1102Pf:D00`21ZH40Y]jX0:KNZ00@0:KNZ003086YP@2Wh:L0Yn2W0180Yn2W00<0PJV1
0:KNY02VgZ@04P2VgZ@00`21ZH40XMRN0:7HWP0@0:7HWP03086YP@2HcID0V<fE0080V<fE2021ZH42
0936T@03086YP@1o/H40Ok6100P0Ok610P21ZH4306JAJ003086YP@14IDP0PJV10;00/>3V0@3oool0
0;40/>3V1021ZH4307BTP`03086YP@2;`9H0Rl2F00P0Rl2F00<0PJV109SAX02HdJ001`2HdJ0>086Y
P@T0Y]jX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40Y]jT0:KNY00B0:KNY003086YP@2Qf9h0XMRN
00L0XMRN3P21ZH490936T@03086YP@1o/H40Ok6100P0Ok6100@0PJV106JAJ01VTFP0IY5X1021ZH6a
0;3PiP40oooo002c0;3PiP03086YP@1DNfH0PJV100<0M:B300<0PJV108_0UP2;`9H0202;`9H00`21
ZH40V=6P09SAX00;09SAX003086YP@2OfJD0WmVU00H0WmVU?@21ZH4809[BW003086YP@2@aY40T<JA
00/0T<JA00<0PJV107naP@1o/H40201o/H401`21ZH40IY5X06JAJ01VTFP0PJV104AUB021ZH40/`2`
h>H10?ooo`00]02`h>H3086YP@<0M:B30P21ZH4908_0UP03086YP@2HdJ00V=6P00X0V=6P00<0PJV1
09oIY@2OfJD03`2OfJD00`21ZH40XM^U0:7KY@0B0:7KY@03086YP@2PfJ80X=VR0180X=VR00<0PJV1
09[BW02JdY`03`2JdY`00`21ZH40T<JA0936T@0:0936T@03086YP@1o/H40Ok6100P0Ok6100@0PJV1
06JAJ01VTFP0IY5X0`21ZH6d0;3PiP40oooo002e0;3PiP@0PJV10`1dY8<00`21ZH40Rl2F08_0UP07
08_0UP03086YP@2HdJ00V=6P00X0V=6P00<0PJV109oIY@2OfJD03`2OfJD00`21ZH40XM^U0:7KY@0A
0:7KY@03086YP@2PfJ80X=VR0140X=VR00<0PJV109[BW02JdY`03`2JdY`00`21ZH40T<JA0936T@0:
0936T@03086YP@1o/H40Ok6100P0Ok6100<0PJV106JAJ01VTFP01021ZH6e0;3PiP40oooo002g0;3P
iP@0PJV10P1dY8<00`21ZH40Rl2F08_0UP0608_0UP03086YP@2HdJ00V=6P00/0V=6P00<0PJV109oI
Y@2OfJD03P2OfJD00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2PfJ80X=VR0140X=VR00<0PJV109[B
W02JdY`03P2JdY`00`21ZH40T<JA0936T@0;0936T@03086YP@1o/H40Ok6100H0Ok610P21ZH400`1V
TFP0PJV1086YP@02086YPKL0/>3V0@3oool00;T0/>3V1021ZH400`1dY8<0PJV108_0UP0708_0UP03
086YP@2HdJ00V=6P00/0V=6P00<0PJV109oIY@2OfJD03@2OfJD00`21ZH40XM^U0:7KY@0A0:7KY@03
086YP@2PfJ80X=VR0140X=VR00<0PJV109[BW02JdY`03@2JdY`00`21ZH40T<JA0936T@0;0936T@03
086YP@1o/H40Ok6100H0Ok6100<0PJV106JAJ021ZH400`21ZH6i0;3PiP40oooo002k0;3PiPD0PJV1
202;`9H00`21ZH40V=6P09SAX00:09SAX003086YP@2OfJD0WmVU00h0WmVU00<0PJV10:7KY@2QfjD0
402QfjD00`21ZH40X=VR0:3IXP0@0:3IXP03086YP@2JdY`0V]:L00h0V]:L00<0PJV10936T@2@aY40
2P2@aY400`21ZH40Ok6107naP@0607naP@D0PJV1^`2`h>H10?ooo`00_02`h>H7086YP@H0Rl2F00<0
PJV109SAX02HdJ002P2HdJ000`21ZH40WmVU09oIY@0=09oIY@03086YP@2QfjD0XM^U0100XM^U00<0
PJV10:3IXP2PfJ80402PfJ800`21ZH40V]:L09[BW00=09[BW003086YP@2@aY40T<JA00X0T<JA00<0
PJV107naP@1o/H40101o/H47086YPK`0/>3V0@3oool00;h0/>3V2`21ZH400`2;`9H0PJV109SAX00;
09SAX003086YP@2OfJD0WmVU00d0WmVU00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40X=VR0:3IXP0?
0:3IXP03086YP@2JdY`0V]:L00d0V]:L00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok61086YP@0:
086YPKh0/>3V0@3oool00<00/>3V1@21ZH4407Z]R0H0PJV12@2HdJ000`21ZH40WmVU09oIY@0<09oI
Y@03086YP@2QfjD0XM^U00l0XM^U00<0PJV10:3IXP2PfJ803`2PfJ800`21ZH40V]:L09[BW00<09[B
W003086YP@2@aY40T<JA00L0T<JA1P21ZH44072PMPD0PJV1`02`h>H10?ooo`00`P2`h>H2086YP@03
06BBM@21ZH40PJV100D0NZf80P21ZH400`28_Y<0PJV1086YP@05086YP@80V=6P00<0PJV109oIY@2O
fJD0302OfJD00`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2PfJ80X=VR00l0X=VR00<0PJV109[BW02J
dY`0302JdY`00`21ZH40T<JA0936T@07086YP@03086eQP21ZH40PJV100D0L:1f0P21ZH400`1IPUl0
PJV1086YP@320;3PiP40oooo00340;3PiP80PJV100<0I99e086YP@1j[HP01@1j[HP00`21ZH40R;jC
08RnT`0508RnT`/0PJV11`2OfJD00`21ZH40XM^U0:7KY@0>0:7KY@03086YP@2PfJ80X=VR00h0X=VR
00<0PJV109[BW02JdY`01@2JdY`;086YP@L0PKF600<0PJV1072PMP1`X7H0101`X7H01021ZH40FH9O
086YP@21ZH740;3PiP40oooo00350;3PiPD0PJV11@1j[HP2086YP@T0R;jC00<0PJV10938V@2@b9T0
102@b9Ta086YP@H0S<>A00<0PJV1086eQP21]HH01`21]HH2086YP@D0L:1f1@21ZH750;3PiP40oooo
00370;3PiPD0PJV11@1j[HP00`21ZH40R;jC08RnT`0708RnT`03086YP@2@b9T0T<RI00/0T<RI00<0
PJV109?<V`2Cc9/03@2Cc9/00`21ZH40T/ZH09;:V00=09;:V003086YP@2<`i40S<>A00/0S<>A00<0
PJV1086eQP21]HH01`21]HH00`21ZH40L:1f072PMP03072PMPD0PJV1a`2`h>H10?ooo`00bP2`h>H4
086YP@@0NZf80P21ZH4808RnT`03086YP@2@b9T0T<RI00X0T<RI00<0PJV109?<V`2Cc9/03@2Cc9/0
0`21ZH40T/ZH09;:V00=09;:V003086YP@2<`i40S<>A00X0S<>A00<0PJV1086eQP21]HH01P21]HH2
086YP@@0L:1f1021ZH7:0;3PiP40oooo003=0;3PiP@0PJV10`1j[HP00`21ZH40R;jC08RnT`0608Rn
T`80PJV12`2@b9T00`21ZH40TlbK09?<V`0<09?<V`03086YP@2BbYP0T/ZH00`0T/ZH00<0PJV108c3
T@2<`i402@2<`i42086YP@P0PKF600@0PJV1072PMP1`X7H0L:1f1021ZH7=0;3PiP40oooo003@0;3P
iPL0PJV12028_Y<00`21ZH40T<RI0938V@090938V@03086YP@2Cc9/0TlbK00/0TlbK00<0PJV109;:
V02BbYP02`2BbYP00`21ZH40S<>A08c3T@0908c3T@03086YP@21]HH0PKF600H0PKF61`21ZH7@0;3P
iP40oooo003C0;3PiPT0PJV11028_Y<00`21ZH40T<RI0938V@090938V@03086YP@2Cc9/0TlbK00X0
TlbK00<0PJV109;:V02BbYP02P2BbYP00`21ZH40S<>A08c3T@0908c3T@03086YP@21]HH0PKF60080
PKF62@21ZH7C0;3PiP40oooo003F0;3PiQ40PJV11@2@b9T00`21ZH40TlbK09?<V`0:09?<V`03086Y
P@2BbYP0T/ZH00X0T/ZH00<0PJV108c3T@2<`i400`2<`i4;086YP@0306RGLP21ZH40PJV100<0PJV1
eP2`h>H10?ooo`00f@2`h>H5086YP@@0KIil0P21ZH4307FXPRD0PJV10`1bY7`2086YP@@0J9Mb1@21
ZH7I0;3PiP40oooo003L0;3PiPD0PJV10`1]WW`2086YP@P0MJR200<0PJV107R/Q01h[8@0201h[8@0
0`21ZH40Mj^207N[PP0807N[PP03086YP@1bY7`0LZAl00H0LZAl0P21ZH4306RGLPD0PJV1g02`h>H1
0?ooo`00h02`h>H8086YP@L0MJR200<0PJV107R/Q01h[8@01`1h[8@00`21ZH40Mj^207N[PP0707N[
PP03086YP@1bY7`0LZAl00D0LZAl2021ZH7P0;3PiP40oooo003V0;3PiPL0PJV10`1eZ8800`21ZH40
N:b407R/Q00607R/Q003086YP@1gZh80Mj^200H0Mj^200@0PJV107:TO01bY7`0LZAl1`21ZH7V0;3P
iP40oooo003]0;3PiQT0PJV1k@2`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.608 .781 .571 r
.47008 .46971 m .46978 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.608 .781 .571 r
.51009 .5 m .50999 .46977 L .47008 .46971 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.50999 .53023 m .51009 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.50999 .46977 m .51009 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.51009 .5 m .50999 .53023 L .5497 .53041 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.5497 .53041 m .5502 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.43078 .46941 m .43007 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.46978 .5 m .47008 .46971 L .43078 .46941 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.47008 .53029 m .46978 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.46978 .5 m .47008 .53029 L .50999 .53023 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.471 .43976 m .47008 .46971 L .50999 .46977 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.50999 .46977 m .50968 .43988 L .471 .43976 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.50968 .56012 m .50999 .53023 L .47008 .53029 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.50968 .43988 m .50999 .46977 L .5497 .46959 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.5502 .5 m .5497 .46959 L .50999 .46977 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.50999 .53023 m .50968 .56012 L .54817 .56047 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.54817 .56047 m .5497 .53041 L .50999 .53023 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.43291 .43918 m .43078 .46941 L .47008 .46971 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.47008 .46971 m .471 .43976 L .43291 .43918 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.43007 .5 m .43078 .53059 L .47008 .53029 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.471 .56024 m .47008 .53029 L .43078 .53059 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.47008 .53029 m .471 .56024 L .50968 .56012 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.5497 .46959 m .5502 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.5502 .5 m .5497 .53041 L .58839 .53084 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.58839 .53084 m .58931 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.5497 .46959 m .54817 .43953 L .50968 .43988 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.54817 .43953 m .5497 .46959 L .58839 .46916 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.58931 .5 m .58839 .46916 L .5497 .46959 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.5497 .53041 m .54817 .56047 L .58564 .56129 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.58564 .56129 m .58839 .53084 L .5497 .53041 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.47252 .41051 m .471 .43976 L .50968 .43988 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.50968 .43988 m .50918 .41067 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.50918 .41067 m .50968 .43988 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.50918 .58933 m .50968 .56012 L .471 .56024 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.50968 .56012 m .50918 .58933 L .54563 .58982 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.54563 .58982 m .54817 .56047 L .50968 .56012 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.43648 .40968 m .43291 .43918 L .471 .43976 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.471 .43976 m .47252 .41051 L .43648 .40968 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.43078 .53059 m .43291 .56082 L .471 .56024 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.47252 .58949 m .471 .56024 L .43291 .56082 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.471 .56024 m .47252 .58949 L .50918 .58933 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.39291 .46886 m .39179 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.43007 .5 m .43078 .46941 L .39291 .46886 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.43078 .53059 m .43007 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.39627 .43812 m .39291 .46886 L .43078 .46941 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.43078 .46941 m .43291 .43918 L .39627 .43812 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.39179 .5 m .39291 .53114 L .43078 .53059 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.43291 .56082 m .43078 .53059 L .39291 .53114 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.54817 .43953 m .54563 .41018 L .50918 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.54563 .41018 m .54817 .43953 L .58564 .43871 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.58839 .46916 m .58564 .43871 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.54817 .56047 m .54563 .58982 L .58106 .59098 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.58106 .59098 m .58564 .56129 L .54817 .56047 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.58839 .46916 m .58931 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.58931 .5 m .58839 .53084 L .62519 .53151 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.62519 .53151 m .62652 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.47466 .38233 m .47252 .41051 L .50918 .41067 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.50918 .41067 m .50846 .38253 L .47466 .38233 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.50846 .38253 m .50918 .41067 L .54563 .41018 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.50846 .61747 m .50918 .58933 L .47252 .58949 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.50918 .58933 m .50846 .61747 L .54206 .61807 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.54206 .61807 m .54563 .58982 L .50918 .58933 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.39291 .53114 m .39627 .56188 L .43291 .56082 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.43648 .59032 m .43291 .56082 L .39627 .56188 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.43291 .56082 m .43648 .59032 L .47252 .58949 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.40187 .4082 m .39627 .43812 L .43291 .43918 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.43291 .43918 m .43648 .40968 L .40187 .4082 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.44147 .38133 m .43648 .40968 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.47252 .41051 m .47466 .38233 L .44147 .38133 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.47466 .61767 m .47252 .58949 L .43648 .59032 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.47252 .58949 m .47466 .61767 L .50846 .61747 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.58564 .43871 m .58839 .46916 L .62519 .46849 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.62652 .5 m .62519 .46849 L .58839 .46916 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.58839 .53084 m .58564 .56129 L .62122 .56259 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.62122 .56259 m .62519 .53151 L .58839 .53084 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.54563 .41018 m .54206 .38193 L .50846 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.54206 .38193 m .54563 .41018 L .58106 .40902 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.58564 .43871 m .58106 .40902 L .54563 .41018 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.54563 .58982 m .54206 .61807 L .57465 .61947 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.57465 .61947 m .58106 .59098 L .54563 .58982 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.58106 .40902 m .58564 .43871 L .62122 .43741 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.62519 .46849 m .62122 .43741 L .58564 .43871 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.58564 .56129 m .58106 .59098 L .61461 .59279 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.61461 .59279 m .62122 .56259 L .58564 .56129 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.35742 .46806 m .35589 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.39179 .5 m .39291 .46886 L .35742 .46806 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.39291 .53114 m .39179 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.40969 .37953 m .40187 .4082 L .43648 .40968 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.43648 .40968 m .44147 .38133 L .40969 .37953 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.39627 .56188 m .40187 .5918 L .43648 .59032 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.44147 .61867 m .43648 .59032 L .40187 .5918 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.43648 .59032 m .44147 .61867 L .47466 .61767 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.36201 .43659 m .35742 .46806 L .39291 .46886 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.39291 .46886 m .39627 .43812 L .36201 .43659 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.35589 .5 m .35742 .53194 L .39291 .53114 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.39627 .56188 m .39291 .53114 L .35742 .53194 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.47742 .35564 m .47466 .38233 L .50846 .38253 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.50846 .38253 m .50754 .35586 L .47742 .35564 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.50754 .64414 m .50846 .61747 L .47466 .61767 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.50754 .35586 m .50846 .38253 L .54206 .38193 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.50846 .61747 m .50754 .64414 L .53747 .64479 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.53747 .64479 m .54206 .61807 L .50846 .61747 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.44788 .35455 m .44147 .38133 L .47466 .38233 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.47466 .38233 m .47742 .35564 L .44788 .35455 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.47742 .64436 m .47466 .61767 L .44147 .61867 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.47466 .61767 m .47742 .64436 L .50754 .64414 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.36963 .40606 m .36201 .43659 L .39627 .43812 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.39627 .43812 m .40187 .4082 L .36963 .40606 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.35742 .53194 m .36201 .56341 L .39627 .56188 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.40187 .5918 m .39627 .56188 L .36201 .56341 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.58106 .40902 m .57465 .38053 L .54206 .38193 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.57465 .38053 m .58106 .40902 L .61461 .40721 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.62122 .43741 m .61461 .40721 L .58106 .40902 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.58106 .59098 m .57465 .61947 L .60538 .62166 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.60538 .62166 m .61461 .59279 L .58106 .59098 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.54206 .38193 m .53747 .35521 L .50754 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.53747 .35521 m .54206 .38193 L .57465 .38053 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.54206 .61807 m .53747 .64479 L .56643 .64632 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.56643 .64632 m .57465 .61947 L .54206 .61807 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.62519 .46849 m .62652 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.62652 .5 m .62519 .53151 L .6591 .53242 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.6591 .53242 m .66083 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.62122 .43741 m .62519 .46849 L .6591 .46758 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.66083 .5 m .6591 .46758 L .62519 .46849 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.62519 .53151 m .62122 .56259 L .6539 .56435 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.6539 .56435 m .6591 .53242 L .62519 .53151 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.41972 .3526 m .40969 .37953 L .44147 .38133 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.44147 .38133 m .44788 .35455 L .41972 .3526 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.40187 .5918 m .40969 .62047 L .44147 .61867 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.44788 .64545 m .44147 .61867 L .40969 .62047 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.44147 .61867 m .44788 .64545 L .47742 .64436 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.38025 .37696 m .36963 .40606 L .40187 .4082 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.40187 .4082 m .40969 .37953 L .38025 .37696 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.36201 .56341 m .36963 .59394 L .40187 .5918 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.40969 .62047 m .40187 .5918 L .36963 .59394 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.61982 .431 m
.62002 .43119 L
s
.5 Mabswid
.624 .816 .617 r
.61461 .40721 m .62122 .43741 L .6539 .43565 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.6591 .46758 m .6539 .43565 L .62122 .43741 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.62122 .56259 m .61461 .59279 L .64528 .59525 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.64528 .59525 m .6539 .56435 L .62122 .56259 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.57465 .38053 m .56643 .35368 L .53747 .35521 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.56643 .35368 m .57465 .38053 L .60538 .37834 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.61461 .40721 m .60538 .37834 L .57465 .38053 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.57465 .61947 m .56643 .64632 L .59358 .6487 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.59358 .6487 m .60538 .62166 L .57465 .61947 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.3254 .46703 m .32346 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.35589 .5 m .35742 .46806 L .3254 .46703 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.35742 .53194 m .35589 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.48078 .33093 m .47742 .35564 L .50754 .35586 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.50754 .35586 m .50642 .33115 L .48078 .33093 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.50642 .33115 m .50754 .35586 L .53747 .35521 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.50642 .66885 m .50754 .64414 L .47742 .64436 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.50754 .64414 m .50642 .66885 L .53187 .6695 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.53187 .6695 m .53747 .64479 L .50754 .64414 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.4557 .32985 m .44788 .35455 L .47742 .35564 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.47742 .35564 m .48078 .33093 L .4557 .32985 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.48078 .66907 m .47742 .64436 L .44788 .64545 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.47742 .64436 m .48078 .66907 L .50642 .66885 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.33119 .4346 m .3254 .46703 L .35742 .46806 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.35742 .46806 m .36201 .43659 L .33119 .4346 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.32346 .5 m .3254 .53297 L .35742 .53194 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.36201 .56341 m .35742 .53194 L .3254 .53297 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.60538 .37834 m .61461 .40721 L .64528 .40475 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.6539 .43565 m .64528 .40475 L .61461 .40721 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.61461 .59279 m .60538 .62166 L .6333 .62462 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.6333 .62462 m .64528 .59525 L .61461 .59279 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.53747 .35521 m .53187 .3305 L .50642 .33115 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.53187 .3305 m .53747 .35521 L .56643 .35368 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.53747 .64479 m .53187 .6695 L .55641 .67102 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.55641 .67102 m .56643 .64632 L .53747 .64479 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.39379 .3498 m .38025 .37696 L .40969 .37953 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.40969 .37953 m .41972 .3526 L .39379 .3498 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.36963 .59394 m .38025 .62304 L .40969 .62047 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.41972 .6474 m .40969 .62047 L .38025 .62304 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.40969 .62047 m .41972 .6474 L .44788 .64545 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.34079 .40328 m .33119 .4346 L .36201 .43659 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.36201 .43659 m .36963 .40606 L .34079 .40328 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.3254 .53297 m .33119 .5654 L .36201 .56341 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.36963 .59394 m .36201 .56341 L .33119 .5654 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.4319 .32791 m .41972 .3526 L .44788 .35455 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.44788 .35455 m .4557 .32985 L .4319 .32791 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.4557 .67015 m .44788 .64545 L .41972 .6474 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.44788 .64545 m .4557 .67015 L .48078 .66907 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.35411 .37361 m .34079 .40328 L .36963 .40606 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.36963 .40606 m .38025 .37696 L .35411 .37361 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.33119 .5654 m .34079 .59672 L .36963 .59394 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.38025 .62304 m .36963 .59394 L .34079 .59672 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.56643 .35368 m .55641 .32898 L .53187 .3305 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.55641 .32898 m .56643 .35368 L .59358 .3513 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.60538 .37834 m .59358 .3513 L .56643 .35368 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.56643 .64632 m .55641 .67102 L .57927 .67338 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.57927 .67338 m .59358 .6487 L .56643 .64632 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.6591 .46758 m .66083 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.66083 .5 m .6591 .53242 L .68892 .53358 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.68892 .53358 m .69106 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.59358 .3513 m .60538 .37834 L .6333 .37538 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.64528 .40475 m .6333 .37538 L .60538 .37834 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.60538 .62166 m .59358 .6487 L .61805 .65191 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.61805 .65191 m .6333 .62462 L .60538 .62166 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.6539 .43565 m .6591 .46758 L .68892 .46642 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.69106 .5 m .68892 .46642 L .6591 .46758 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.6591 .53242 m .6539 .56435 L .68254 .56657 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.68254 .56657 m .68892 .53358 L .6591 .53242 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.64528 .40475 m .6539 .43565 L .68254 .43343 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65479 .43559 m
.65501 .43663 L
s
.5 Mabswid
.589 .766 .585 r
.68892 .46642 m .68254 .43343 L .6539 .43565 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.6539 .56435 m .64528 .59525 L .67199 .59835 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.67199 .59835 m .68254 .56657 L .6539 .56435 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41017 .32514 m .39379 .3498 L .41972 .3526 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41972 .3526 m .4319 .32791 L .41017 .32514 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.38025 .62304 m .39379 .6502 L .41972 .6474 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.4319 .67209 m .41972 .6474 L .39379 .6502 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.41972 .6474 m .4319 .67209 L .4557 .67015 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.48475 .30872 m .48078 .33093 L .50642 .33115 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.50642 .33115 m .5051 .30892 L .48475 .30872 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.5051 .30892 m .50642 .33115 L .53187 .3305 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.5051 .69108 m .50642 .66885 L .48078 .66907 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.50642 .66885 m .5051 .69108 L .52528 .69167 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.52528 .69167 m .53187 .6695 L .50642 .66885 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.4649 .30775 m .4557 .32985 L .48078 .33093 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.48078 .33093 m .48475 .30872 L .4649 .30775 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.48475 .69128 m .48078 .66907 L .4557 .67015 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.48078 .66907 m .48475 .69128 L .5051 .69108 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.37101 .34619 m .35411 .37361 L .38025 .37696 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.38025 .37696 m .39379 .3498 L .37101 .34619 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.34079 .59672 m .35411 .62639 L .38025 .62304 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.39379 .6502 m .38025 .62304 L .35411 .62639 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.53187 .3305 m .52528 .30833 L .5051 .30892 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.52528 .30833 m .53187 .3305 L .55641 .32898 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.53187 .6695 m .52528 .69167 L .54465 .69302 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.54465 .69302 m .55641 .67102 L .53187 .6695 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.6333 .37538 m .64528 .40475 L .67199 .40165 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.68254 .43343 m .67199 .40165 L .64528 .40475 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.64528 .59525 m .6333 .62462 L .65738 .62833 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.65738 .62833 m .67199 .59835 L .64528 .59525 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.59358 .3513 m .57927 .32662 L .55641 .32898 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.57927 .32662 m .59358 .3513 L .61805 .34809 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.6333 .37538 m .61805 .34809 L .59358 .3513 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59358 .6487 m .57927 .67338 L .59968 .67653 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59968 .67653 m .61805 .65191 L .59358 .6487 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4649 .69225 m .4557 .67015 L .4319 .67209 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.4557 .67015 m .4649 .69225 L .48475 .69128 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.44617 .30602 m .4319 .32791 L .4557 .32985 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.4557 .32985 m .4649 .30775 L .44617 .30602 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.29812 .46575 m .29579 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.32346 .5 m .3254 .46703 L .29812 .46575 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.3254 .53297 m .32346 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.30507 .43216 m .29812 .46575 L .3254 .46703 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.3254 .46703 m .33119 .4346 L .30507 .43216 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.29579 .5 m .29812 .53425 L .3254 .53297 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.33119 .5654 m .3254 .53297 L .29812 .53425 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.55641 .32898 m .54465 .30698 L .52528 .30833 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.54465 .30698 m .55641 .32898 L .57927 .32662 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.55641 .67102 m .54465 .69302 L .56257 .69512 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.56257 .69512 m .57927 .67338 L .55641 .67102 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.29812 .53425 m .30507 .56784 L .33119 .5654 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.34079 .59672 m .33119 .5654 L .30507 .56784 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.31654 .39987 m .30507 .43216 L .33119 .4346 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.33119 .4346 m .34079 .40328 L .31654 .39987 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.61805 .34809 m .6333 .37538 L .65738 .37167 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.67199 .40165 m .65738 .37167 L .6333 .37538 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6333 .62462 m .61805 .65191 L .6389 .65589 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6389 .65589 m .65738 .62833 L .6333 .62462 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.3913 .3216 m .37101 .34619 L .39379 .3498 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.39379 .3498 m .41017 .32514 L .3913 .3216 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.35411 .62639 m .37101 .65381 L .39379 .6502 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.41017 .67486 m .39379 .6502 L .37101 .65381 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.39379 .6502 m .41017 .67486 L .4319 .67209 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.42923 .30356 m .41017 .32514 L .4319 .32791 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.4319 .32791 m .44617 .30602 L .42923 .30356 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.44617 .69398 m .4319 .67209 L .41017 .67486 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4319 .67209 m .44617 .69398 L .4649 .69225 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.33238 .36955 m .31654 .39987 L .34079 .40328 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.34079 .40328 m .35411 .37361 L .33238 .36955 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.30507 .56784 m .31654 .60013 L .34079 .59672 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.35411 .62639 m .34079 .59672 L .31654 .60013 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.57927 .32662 m .56257 .30488 L .54465 .30698 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.56257 .30488 m .57927 .32662 L .59968 .32347 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.61805 .34809 m .59968 .32347 L .57927 .32662 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57927 .67338 m .56257 .69512 L .57837 .69792 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57837 .69792 m .59968 .67653 L .57927 .67338 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.68892 .46642 m .69106 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.69106 .5 m .68892 .53358 L .71329 .53497 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.71329 .53497 m .7158 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.48931 .28962 m .48475 .30872 L .5051 .30892 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.5051 .30892 m .50357 .28977 L .48931 .28962 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50357 .28977 m .5051 .30892 L .52528 .30833 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.50357 .71023 m .5051 .69108 L .48475 .69128 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.5051 .69108 m .50357 .71023 L .51772 .71068 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.51772 .71068 m .52528 .69167 L .5051 .69108 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.47542 .28887 m .4649 .30775 L .48475 .30872 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.48475 .30872 m .48931 .28962 L .47542 .28887 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.48931 .71038 m .48475 .69128 L .4649 .69225 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.48475 .69128 m .48931 .71038 L .50357 .71023 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.68254 .43343 m .68892 .46642 L .71329 .46503 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.7158 .5 m .71329 .46503 L .68892 .46642 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.68892 .53358 m .68254 .56657 L .7058 .56923 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.7058 .56923 m .71329 .53497 L .68892 .53358 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.59968 .32347 m .61805 .34809 L .6389 .34411 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.65738 .37167 m .6389 .34411 L .61805 .34809 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.61805 .65191 m .59968 .67653 L .6168 .68043 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.6168 .68043 m .6389 .65589 L .61805 .65191 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35235 .34184 m .33238 .36955 L .35411 .37361 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35411 .37361 m .37101 .34619 L .35235 .34184 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.31654 .60013 m .33238 .63045 L .35411 .62639 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.37101 .65381 m .35411 .62639 L .33238 .63045 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.52528 .30833 m .51772 .28932 L .50357 .28977 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.51772 .28932 m .52528 .30833 L .54465 .30698 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.52528 .69167 m .51772 .71068 L .53123 .71173 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.53123 .71173 m .54465 .69302 L .52528 .69167 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.67199 .40165 m .68254 .43343 L .7058 .43077 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.71329 .46503 m .7058 .43077 L .68254 .43343 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.68254 .56657 m .67199 .59835 L .69345 .60204 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.69345 .60204 m .7058 .56923 L .68254 .56657 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4624 .28754 m .44617 .30602 L .4649 .30775 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4649 .30775 m .47542 .28887 L .4624 .28754 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.47542 .71113 m .4649 .69225 L .44617 .69398 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.4649 .69225 m .47542 .71113 L .48931 .71038 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41472 .30044 m .3913 .3216 L .41017 .32514 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41017 .32514 m .42923 .30356 L .41472 .30044 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.37101 .65381 m .3913 .6784 L .41017 .67486 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.42923 .69644 m .41017 .67486 L .3913 .6784 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.41017 .67486 m .42923 .69644 L .44617 .69398 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.54465 .30698 m .53123 .28827 L .51772 .28932 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.53123 .28827 m .54465 .30698 L .56257 .30488 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54465 .69302 m .53123 .71173 L .54362 .71333 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54362 .71333 m .56257 .69512 L .54465 .69302 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.65738 .37167 m .67199 .40165 L .69345 .39796 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.7058 .43077 m .69345 .39796 L .67199 .40165 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67199 .59835 m .65738 .62833 L .67646 .63273 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67646 .63273 m .69345 .60204 L .67199 .59835 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37612 .31737 m .35235 .34184 L .37101 .34619 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37101 .34619 m .3913 .3216 L .37612 .31737 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.33238 .63045 m .35235 .65816 L .37101 .65381 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.3913 .6784 m .37101 .65381 L .35235 .65816 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.45076 .28567 m .42923 .30356 L .44617 .30602 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.44617 .30602 m .4624 .28754 L .45076 .28567 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.4624 .71246 m .44617 .69398 L .42923 .69644 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.44617 .69398 m .4624 .71246 L .47542 .71113 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.59968 .32347 m .57837 .30208 L .56257 .30488 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.57837 .30208 m .59968 .32347 L .6168 .31957 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.6389 .34411 m .6168 .31957 L .59968 .32347 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59968 .67653 m .57837 .69792 L .59141 .70134 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59141 .70134 m .6168 .68043 L .59968 .67653 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.6389 .34411 m .65738 .37167 L .67646 .36727 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.69345 .39796 m .67646 .36727 L .65738 .37167 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65738 .62833 m .6389 .65589 L .65512 .66059 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65512 .66059 m .67646 .63273 L .65738 .62833 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31175 .58665 m
.31181 .58716 L
s
.30338 .56913 m
.30669 .57241 L
s
.5 Mabswid
.42 .541 .365 r
.27706 .46425 m .27438 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.29579 .5 m .29812 .46575 L .27706 .46425 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.29812 .53425 m .29579 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.28506 .42929 m .27706 .46425 L .29812 .46575 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.29812 .46575 m .30507 .43216 L .28506 .42929 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.27438 .5 m .27706 .53575 L .29812 .53425 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.30507 .56784 m .29812 .53425 L .27706 .53575 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.56257 .30488 m .54362 .28667 L .53123 .28827 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.54362 .28667 m .56257 .30488 L .57837 .30208 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.56257 .69512 m .54362 .71333 L .5544 .71545 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.5544 .71545 m .57837 .69792 L .56257 .69512 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.29822 .3959 m .28506 .42929 L .30507 .43216 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.30507 .43216 m .31654 .39987 L .29822 .3959 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.27706 .53575 m .28506 .57071 L .30507 .56784 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.31654 .60013 m .30507 .56784 L .28506 .57071 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.44095 .28331 m .41472 .30044 L .42923 .30356 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.42923 .30356 m .45076 .28567 L .44095 .28331 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.3913 .6784 m .41472 .69956 L .42923 .69644 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.45076 .71433 m .42923 .69644 L .41472 .69956 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.42923 .69644 m .45076 .71433 L .4624 .71246 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.6168 .31957 m .6389 .34411 L .65512 .33941 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.67646 .36727 m .65512 .33941 L .6389 .34411 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.6389 .65589 m .6168 .68043 L .62982 .68498 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.62982 .68498 m .65512 .66059 L .6389 .65589 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.40332 .29675 m .37612 .31737 L .3913 .3216 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.3913 .3216 m .41472 .30044 L .40332 .29675 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.35235 .65816 m .37612 .68263 L .3913 .6784 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.41472 .69956 m .3913 .6784 L .37612 .68263 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31627 .36485 m .29822 .3959 L .31654 .39987 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31654 .39987 m .33238 .36955 L .31627 .36485 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.28506 .57071 m .29822 .6041 L .31654 .60013 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.33238 .63045 m .31654 .60013 L .29822 .6041 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.49441 .27429 m .48931 .28962 L .50357 .28977 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.50357 .28977 m .50187 .27437 L .49441 .27429 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50187 .27437 m .50357 .28977 L .51772 .28932 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.50187 .72563 m .50357 .71023 L .48931 .71038 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50357 .71023 m .50187 .72563 L .50926 .72588 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50926 .72588 m .51772 .71068 L .50357 .71023 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48716 .27387 m .47542 .28887 L .48931 .28962 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48931 .28962 m .49441 .27429 L .48716 .27387 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.49441 .72571 m .48931 .71038 L .47542 .71113 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.48931 .71038 m .49441 .72571 L .50187 .72563 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51772 .28932 m .50926 .27412 L .50187 .27437 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.50926 .27412 m .51772 .28932 L .53123 .28827 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51772 .71068 m .50926 .72588 L .51628 .72647 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51628 .72647 m .53123 .71173 L .51772 .71068 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70846 .44296 m
.70855 .44307 L
s
.5 Mabswid
.51 .688 .488 r
.33884 .33683 m .31627 .36485 L .33238 .36955 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33238 .36955 m .35235 .34184 L .33884 .33683 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.29822 .6041 m .31627 .63515 L .33238 .63045 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.35235 .65816 m .33238 .63045 L .31627 .63515 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.48043 .27312 m .4624 .28754 L .47542 .28887 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.47542 .28887 m .48716 .27387 L .48043 .27312 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.48716 .72613 m .47542 .71113 L .4624 .71246 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.47542 .71113 m .48716 .72613 L .49441 .72571 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.57837 .30208 m .5544 .28455 L .54362 .28667 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.5544 .28455 m .57837 .30208 L .59141 .29866 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.6168 .31957 m .59141 .29866 L .57837 .30208 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.57837 .69792 m .5544 .71545 L .56312 .71802 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.56312 .71802 m .59141 .70134 L .57837 .69792 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70268 .42249 m
.70268 .42245 L
s
.70855 .44307 m
.71063 .44456 L
s
.5 Mabswid
.613 .839 .633 r
.53123 .28827 m .51628 .27353 L .50926 .27412 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.51628 .27353 m .53123 .28827 L .54362 .28667 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.53123 .71173 m .51628 .72647 L .52266 .72736 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.52266 .72736 m .54362 .71333 L .53123 .71173 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70268 .42245 m
.7037 .42044 L
s
.5 Mabswid
.594 .811 .626 r
.59141 .29866 m .6168 .31957 L .62982 .31502 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.65512 .33941 m .62982 .31502 L .6168 .31957 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.6168 .68043 m .59141 .70134 L .60104 .70529 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.60104 .70529 m .62982 .68498 L .6168 .68043 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.47448 .27209 m .45076 .28567 L .4624 .28754 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.4624 .28754 m .48043 .27312 L .47448 .27209 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.48043 .72688 m .4624 .71246 L .45076 .71433 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.4624 .71246 m .48043 .72688 L .48716 .72613 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.71329 .46503 m .7158 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.7158 .5 m .71329 .53497 L .73061 .53658 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.73061 .53658 m .73345 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.7058 .43077 m .71329 .46503 L .73061 .46342 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.73345 .5 m .73061 .46342 L .71329 .46503 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.71329 .53497 m .7058 .56923 L .72215 .57228 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.72215 .57228 m .73061 .53658 L .71329 .53497 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.36548 .31254 m .33884 .33683 L .35235 .34184 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.35235 .34184 m .37612 .31737 L .36548 .31254 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.31627 .63515 m .33884 .66317 L .35235 .65816 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.37612 .68263 m .35235 .65816 L .33884 .66317 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.43343 .28055 m .40332 .29675 L .41472 .30044 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.41472 .30044 m .44095 .28331 L .43343 .28055 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.37612 .68263 m .40332 .70325 L .41472 .69956 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.44095 .71669 m .41472 .69956 L .40332 .70325 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.41472 .69956 m .44095 .71669 L .45076 .71433 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.69345 .39796 m .7058 .43077 L .72215 .42772 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.73061 .46342 m .72215 .42772 L .7058 .43077 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.7058 .56923 m .69345 .60204 L .70827 .60627 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.70827 .60627 m .72215 .57228 L .7058 .56923 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.54362 .28667 m .52266 .27264 L .51628 .27353 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.52266 .27264 m .54362 .28667 L .5544 .28455 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.54362 .71333 m .52266 .72736 L .52813 .72853 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.52813 .72853 m .5544 .71545 L .54362 .71333 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.67646 .36727 m .69345 .39796 L .70827 .39373 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.72215 .42772 m .70827 .39373 L .69345 .39796 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.69345 .60204 m .67646 .63273 L .68929 .63772 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.68929 .63772 m .70827 .60627 L .69345 .60204 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.46955 .2708 m .44095 .28331 L .45076 .28567 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.45076 .28567 m .47448 .27209 L .46955 .2708 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.47448 .72791 m .45076 .71433 L .44095 .71669 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.45076 .71433 m .47448 .72791 L .48043 .72688 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.39561 .29258 m .36548 .31254 L .37612 .31737 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.37612 .31737 m .40332 .29675 L .39561 .29258 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.33884 .66317 m .36548 .68746 L .37612 .68263 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.40332 .70325 m .37612 .68263 L .36548 .68746 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.65512 .33941 m .67646 .36727 L .68929 .36228 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.70827 .39373 m .68929 .36228 L .67646 .36727 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.67646 .63273 m .65512 .66059 L .66565 .66587 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.66565 .66587 m .68929 .63772 L .67646 .63273 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.59141 .29866 m .56312 .28198 L .5544 .28455 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.56312 .28198 m .59141 .29866 L .60104 .29471 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.62982 .31502 m .60104 .29471 L .59141 .29866 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.59141 .70134 m .56312 .71802 L .56935 .72096 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.56935 .72096 m .60104 .70529 L .59141 .70134 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.5544 .28455 m .52813 .27147 L .52266 .27264 L p F P
.505 .664 .505 r
s
.582 .805 .615 r
.52813 .27147 m .5544 .28455 L .56312 .28198 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.5544 .71545 m .52813 .72853 L .53245 .72993 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.53245 .72993 m .56312 .71802 L .5544 .71545 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.62982 .31502 m .65512 .33941 L .66565 .33413 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.68929 .36228 m .66565 .33413 L .65512 .33941 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.65512 .66059 m .62982 .68498 L .63789 .69005 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.63789 .69005 m .66565 .66587 L .65512 .66059 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.46589 .2693 m .43343 .28055 L .44095 .28331 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.44095 .28331 m .46955 .2708 L .46589 .2693 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.40332 .70325 m .43343 .71945 L .44095 .71669 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.46955 .7292 m .44095 .71669 L .43343 .71945 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.44095 .71669 m .46955 .7292 L .47448 .72791 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.42859 .27747 m .39561 .29258 L .40332 .29675 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.40332 .29675 m .43343 .28055 L .42859 .27747 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.36548 .68746 m .39561 .70742 L .40332 .70325 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.43343 .71945 m .40332 .70325 L .39561 .70742 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.26391 .46256 m .26093 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.27438 .5 m .27706 .46425 L .26391 .46256 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.27706 .53575 m .27438 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.556 .775 .586 r
.50187 .27437 m .5 .26345 L .49441 .27429 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50926 .27412 m .5 .26345 L .50187 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50187 .72563 L .49441 .72571 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .50926 .72588 L .50187 .72563 L closepath p F P
.505 .664 .505 r
s
.554 .772 .584 r
.49441 .27429 m .5 .26345 L .48716 .27387 L closepath p F P
.505 .664 .505 r
s
.201 .208 .158 r
.5 .73655 m .49441 .72571 L .48716 .72613 L closepath p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27276 .42606 m .26391 .46256 L .27706 .46425 L p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27706 .46425 m .28506 .42929 L .27276 .42606 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.26093 .5 m .26391 .53744 L .27706 .53575 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.28506 .57071 m .27706 .53575 L .26391 .53744 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.60104 .29471 m .62982 .31502 L .63789 .30995 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.66565 .33413 m .63789 .30995 L .62982 .31502 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.62982 .68498 m .60104 .70529 L .60667 .70964 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.60667 .70964 m .63789 .69005 L .62982 .68498 L p F P
.505 .664 .505 r
s
.554 .773 .587 r
.51628 .27353 m .5 .26345 L .50926 .27412 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51628 .72647 L .50926 .72588 L closepath p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28726 .39146 m .27276 .42606 L .28506 .42929 L p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28506 .42929 m .29822 .3959 L .28726 .39146 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.26391 .53744 m .27276 .57394 L .28506 .57071 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.29822 .6041 m .28506 .57071 L .27276 .57394 L p F P
.505 .664 .505 r
s
.55 .767 .58 r
.48716 .27387 m .5 .26345 L .48043 .27312 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48716 .72613 L .48043 .72688 L closepath p F P
.505 .664 .505 r
s
.582 .805 .615 r
.56312 .28198 m .53245 .27007 L .52813 .27147 L p F P
.505 .664 .505 r
s
.563 .782 .6 r
.53245 .27007 m .56312 .28198 L .56935 .27904 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.60104 .29471 m .56935 .27904 L .56312 .28198 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.56312 .71802 m .53245 .72993 L .53542 .73151 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.53542 .73151 m .56935 .72096 L .56312 .71802 L p F P
.505 .664 .505 r
s
.551 .769 .585 r
.52266 .27264 m .5 .26345 L .51628 .27353 L closepath p F P
.505 .664 .505 r
s
.197 .203 .154 r
.5 .73655 m .52266 .72736 L .51628 .72647 L closepath p F P
.505 .664 .505 r
s
.393 .535 .368 r
.30703 .35961 m .28726 .39146 L .29822 .3959 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.29822 .3959 m .31627 .36485 L .30703 .35961 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.27276 .57394 m .28726 .60854 L .29822 .6041 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.31627 .63515 m .29822 .6041 L .28726 .60854 L p F P
.505 .664 .505 r
s
.544 .761 .575 r
.48043 .27312 m .5 .26345 L .47448 .27209 L closepath p F P
.505 .664 .505 r
s
.197 .203 .155 r
.5 .73655 m .48043 .72688 L .47448 .72791 L closepath p F P
.505 .664 .505 r
s
.422 .581 .408 r
.33154 .33131 m .30703 .35961 L .31627 .36485 L p F P
.505 .664 .505 r
s
.422 .581 .408 r
.31627 .36485 m .33884 .33683 L .33154 .33131 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.28726 .60854 m .30703 .64039 L .31627 .63515 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.33884 .66317 m .31627 .63515 L .30703 .64039 L p F P
.505 .664 .505 r
s
.546 .764 .581 r
.52813 .27147 m .5 .26345 L .52266 .27264 L closepath p F P
.505 .664 .505 r
s
.192 .199 .152 r
.5 .73655 m .52813 .72853 L .52266 .72736 L closepath p F P
.505 .664 .505 r
s
.547 .76 .59 r
.56935 .27904 m .60104 .29471 L .60667 .29036 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.63789 .30995 m .60667 .29036 L .60104 .29471 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.60104 .70529 m .56935 .72096 L .57273 .72415 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.57273 .72415 m .60667 .70964 L .60104 .70529 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.46365 .26765 m .42859 .27747 L .43343 .28055 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.43343 .28055 m .46589 .2693 L .46365 .26765 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.39561 .70742 m .42859 .72253 L .43343 .71945 L p F P
.505 .664 .505 r
s
.2 .206 .157 r
.46589 .7307 m .43343 .71945 L .42859 .72253 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.43343 .71945 m .46589 .7307 L .46955 .7292 L p F P
.505 .664 .505 r
s
.537 .753 .568 r
.47448 .27209 m .5 .26345 L .46955 .2708 L closepath p F P
.505 .664 .505 r
s
.193 .199 .152 r
.5 .73655 m .47448 .72791 L .46955 .7292 L closepath p F P
.505 .664 .505 r
s
.448 .622 .444 r
.36017 .30728 m .33154 .33131 L .33884 .33683 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.33884 .33683 m .36548 .31254 L .36017 .30728 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.30703 .64039 m .33154 .66869 L .33884 .66317 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.36548 .68746 m .33884 .66317 L .33154 .66869 L p F P
.505 .664 .505 r
s
.539 .756 .576 r
.53245 .27007 m .5 .26345 L .52813 .27147 L closepath p F P
.505 .664 .505 r
s
.187 .194 .148 r
.5 .73655 m .53245 .72993 L .52813 .72853 L closepath p F P
.505 .664 .505 r
s
.471 .657 .477 r
.39217 .28809 m .36017 .30728 L .36548 .31254 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.36548 .31254 m .39561 .29258 L .39217 .28809 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.33154 .66869 m .36017 .69272 L .36548 .68746 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.39561 .70742 m .36548 .68746 L .36017 .69272 L p F P
.505 .664 .505 r
s
.529 .742 .561 r
.46955 .2708 m .5 .26345 L .46589 .2693 L closepath p F P
.505 .664 .505 r
s
.187 .195 .148 r
.5 .73655 m .46955 .7292 L .46589 .7307 L closepath p F P
.505 .664 .505 r
s
.563 .782 .6 r
.56935 .27904 m .53542 .26849 L .53245 .27007 L p F P
.505 .664 .505 r
s
.538 .753 .58 r
.53542 .26849 m .56935 .27904 L .57273 .27585 L p F P
.505 .664 .505 r
s
.547 .76 .59 r
.60667 .29036 m .57273 .27585 L .56935 .27904 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.56935 .72096 m .53542 .73151 L .53689 .73321 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.53689 .73321 m .57273 .72415 L .56935 .72096 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72701 .44581 m
.72941 .4543 L
s
.71898 .4173 m
.72138 .42581 L
s
.72342 .43307 m
.72701 .44581 L
s
.5 Mabswid
.531 .746 .57 r
.53542 .26849 m .5 .26345 L .53245 .27007 L closepath p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .53542 .73151 L .53245 .72993 L closepath p F P
.505 .664 .505 r
s
.489 .686 .505 r
.42673 .27419 m .39217 .28809 L .39561 .29258 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.39561 .29258 m .42859 .27747 L .42673 .27419 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.36017 .69272 m .39217 .71191 L .39561 .70742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.42859 .72253 m .39561 .70742 L .39217 .71191 L p F P
.505 .664 .505 r
s
.52 .731 .553 r
.46589 .2693 m .5 .26345 L .46365 .26765 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.42859 .72253 m .46365 .73235 L .46589 .7307 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .46589 .7307 L .46365 .73235 L closepath p F P
.505 .664 .505 r
s
.301 .396 .336 r
.73061 .46342 m .73345 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73345 .5 m .73061 .53658 L .73916 .53835 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73916 .53835 m .74225 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.72215 .42772 m .73061 .46342 L .73916 .46165 L p F P
.505 .664 .505 r
s
.301 .396 .336 r
.74225 .5 m .73916 .46165 L .73061 .46342 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.73061 .53658 m .72215 .57228 L .72998 .57566 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.72998 .57566 m .73916 .53835 L .73061 .53658 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.70827 .39373 m .72215 .42772 L .72998 .42434 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.73916 .46165 m .72998 .42434 L .72215 .42772 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.72215 .57228 m .70827 .60627 L .71499 .61091 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.71499 .61091 m .72998 .57566 L .72215 .57228 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.46298 .26592 m .42673 .27419 L .42859 .27747 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.42859 .27747 m .46365 .26765 L .46298 .26592 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.39217 .71191 m .42673 .72581 L .42859 .72253 L p F P
.505 .664 .505 r
s
.182 .189 .144 r
.46365 .73235 m .42859 .72253 L .42673 .72581 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.68929 .36228 m .70827 .39373 L .71499 .38909 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.72998 .42434 m .71499 .38909 L .70827 .39373 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.70827 .60627 m .68929 .63772 L .69462 .64316 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.69462 .64316 m .71499 .61091 L .70827 .60627 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.66565 .33413 m .68929 .36228 L .69462 .35684 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.71499 .38909 m .69462 .35684 L .68929 .36228 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.68929 .63772 m .66565 .66587 L .66947 .67158 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.66947 .67158 m .69462 .64316 L .68929 .63772 L p F P
.505 .664 .505 r
s
.522 .735 .562 r
.53689 .26679 m .5 .26345 L .53542 .26849 L closepath p F P
.505 .664 .505 r
s
.538 .753 .58 r
.57273 .27585 m .53689 .26679 L .53542 .26849 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .53689 .73321 L .53542 .73151 L closepath p F P
.505 .664 .505 r
s
.461 .645 .517 r
.63789 .30995 m .66565 .33413 L .66947 .32842 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.69462 .35684 m .66947 .32842 L .66565 .33413 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.66565 .66587 m .63789 .69005 L .64026 .69546 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.64026 .69546 m .66947 .67158 L .66565 .66587 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.60667 .29036 m .63789 .30995 L .64026 .30454 L p F P
.505 .664 .505 r
s
.461 .645 .517 r
.66947 .32842 m .64026 .30454 L .63789 .30995 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.63789 .69005 m .60667 .70964 L .60781 .71423 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.60781 .71423 m .64026 .69546 L .63789 .69005 L p F P
.505 .664 .505 r
s
.509 .719 .544 r
.46365 .26765 m .5 .26345 L .46298 .26592 L closepath p F P
.505 .664 .505 r
s
.182 .189 .144 r
.42673 .72581 m .46298 .73408 L .46365 .73235 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .46365 .73235 L .46298 .73408 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.60667 .70964 m .57273 .72415 L .573 .72747 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.573 .72747 m .60781 .71423 L .60667 .70964 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.57273 .27585 m .60667 .29036 L .60781 .28577 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.64026 .30454 m .60781 .28577 L .60667 .29036 L p F P
.505 .664 .505 r
s
.507 .716 .555 r
.53689 .26679 m .57273 .27585 L .573 .27253 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.60781 .28577 m .573 .27253 L .57273 .27585 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.57273 .72415 m .53689 .73321 L .53675 .73495 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.53675 .73495 m .573 .72747 L .57273 .72415 L p F P
.505 .664 .505 r
s
.511 .722 .553 r
.53675 .26505 m .5 .26345 L .53689 .26679 L closepath p F P
.505 .664 .505 r
s
.507 .716 .555 r
.573 .27253 m .53675 .26505 L .53689 .26679 L p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .53675 .73495 L .53689 .73321 L closepath p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .46298 .73408 L .46392 .73581 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .53499 .73666 L .53675 .73495 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .53165 .73825 L .53499 .73666 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .52684 .73967 L .53165 .73825 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .52077 .74082 L .52684 .73967 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .51372 .74166 L .52077 .74082 L closepath p F P
.505 .664 .505 r
s
.136 .148 .112 r
.5 .73655 m .506 .74214 L .51372 .74166 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49799 .74224 L .506 .74214 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49008 .74195 L .49799 .74224 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48265 .74128 L .49008 .74195 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .47605 .74028 L .48265 .74128 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .47058 .73899 L .47605 .74028 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .46649 .73747 L .47058 .73899 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .46392 .73581 L .46649 .73747 L closepath p F P
.505 .664 .505 r
s
.5 .709 .543 r
.53499 .26334 m .5 .26345 L .53675 .26505 L closepath p F P
.505 .664 .505 r
s
.498 .705 .534 r
.46298 .26592 m .5 .26345 L .46392 .26419 L closepath p F P
.505 .664 .505 r
s
.489 .695 .534 r
.53165 .26175 m .5 .26345 L .53499 .26334 L closepath p F P
.505 .664 .505 r
s
.487 .692 .525 r
.46392 .26419 m .5 .26345 L .46649 .26253 L closepath p F P
.505 .664 .505 r
s
.478 .682 .524 r
.52684 .26033 m .5 .26345 L .53165 .26175 L closepath p F P
.505 .664 .505 r
s
.477 .68 .517 r
.46649 .26253 m .5 .26345 L .47058 .26101 L closepath p F P
.505 .664 .505 r
s
.469 .671 .515 r
.52077 .25918 m .5 .26345 L .52684 .26033 L closepath p F P
.505 .664 .505 r
s
.468 .669 .509 r
.47058 .26101 m .5 .26345 L .47605 .25972 L closepath p F P
.505 .664 .505 r
s
.461 .661 .508 r
.51372 .25834 m .5 .26345 L .52077 .25918 L closepath p F P
.505 .664 .505 r
s
.461 .66 .504 r
.47605 .25972 m .5 .26345 L .48265 .25872 L closepath p F P
.505 .664 .505 r
s
.456 .655 .503 r
.506 .25786 m .5 .26345 L .51372 .25834 L closepath p F P
.505 .664 .505 r
s
.456 .654 .5 r
.48265 .25872 m .5 .26345 L .49008 .25805 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49799 .25776 m .5 .26345 L .506 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49008 .25805 m .5 .26345 L .49799 .25776 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28822 .61096 m
.2886 .61274 L
s
.28696 .60966 m
.28822 .61096 L
s
.5 Mabswid
.161 .17 .129 r
.42808 .72914 m .46392 .73581 L .46298 .73408 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.46298 .73408 m .42673 .72581 L .42808 .72914 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.42673 .27419 m .46298 .26592 L .46392 .26419 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.46392 .26419 m .42808 .27086 L .42673 .27419 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.39217 .28809 m .42673 .27419 L .42808 .27086 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.39342 .71655 m .42808 .72914 L .42673 .72581 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.42673 .72581 m .39217 .71191 L .39342 .71655 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28736 .61146 m
.2886 .61274 L
s
.28696 .60966 m
.28736 .61146 L
s
.27952 .59322 m
.2821 .59979 L
s
.27147 .57268 m
.27952 .59322 L
s
.5 Mabswid
.431 .616 .455 r
.42808 .27086 m .39342 .28345 L .39217 .28809 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.36017 .30728 m .39217 .28809 L .39342 .28345 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.36089 .69823 m .39342 .71655 L .39217 .71191 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.39217 .71191 m .36017 .69272 L .36089 .69823 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.573 .72747 m .53675 .73495 L .53499 .73666 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.53675 .26505 m .573 .27253 L .57001 .26922 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.57001 .26922 m .53499 .26334 L .53675 .26505 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.33142 .67453 m .36089 .69823 L .36017 .69272 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.36017 .69272 m .33154 .66869 L .33142 .67453 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.39342 .28345 m .36089 .30177 L .36017 .30728 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.33154 .33131 m .36017 .30728 L .36089 .30177 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.36089 .30177 m .33142 .32547 L .33154 .33131 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.30703 .35961 m .33154 .33131 L .33142 .32547 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.30591 .64599 m .33142 .67453 L .33154 .66869 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.33154 .66869 m .30703 .64039 L .30591 .64599 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.43272 .73238 m .46649 .73747 L .46392 .73581 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.46392 .73581 m .42808 .72914 L .43272 .73238 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.42808 .27086 m .46392 .26419 L .46649 .26253 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.33142 .32547 m .30591 .35401 L .30703 .35961 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.28726 .39146 m .30703 .35961 L .30591 .35401 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.28515 .61333 m .30591 .64599 L .30703 .64039 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.30703 .64039 m .28726 .60854 L .28515 .61333 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73368 .43939 m
.73375 .43868 L
s
.5 Mabswid
.123 .136 .103 r
.26981 .57743 m .28515 .61333 L .28726 .60854 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.28726 .60854 m .27276 .57394 L .26981 .57743 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.30591 .35401 m .28515 .38667 L .28726 .39146 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.27276 .42606 m .28726 .39146 L .28515 .38667 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.60781 .71423 m .573 .72747 L .57001 .73078 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53499 .73666 m .57001 .73078 L .573 .72747 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.573 .27253 m .60781 .28577 L .60411 .28114 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.60411 .28114 m .57001 .26922 L .573 .27253 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.28515 .38667 m .26981 .42257 L .27276 .42606 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26391 .46256 m .27276 .42606 L .26981 .42257 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.2604 .53929 m .26981 .57743 L .27276 .57394 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.27276 .57394 m .26391 .53744 L .2604 .53929 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26981 .42257 m .2604 .46071 L .26391 .46256 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.26093 .5 m .26391 .46256 L .2604 .46071 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.25723 .5 m .2604 .53929 L .26391 .53744 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.26391 .53744 m .26093 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.2604 .46071 m .25723 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.57001 .73078 m .53499 .73666 L .53165 .73825 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.53499 .26334 m .57001 .26922 L .56374 .26608 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.56374 .26608 m .53165 .26175 L .53499 .26334 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72679 .41685 m
.72862 .4201 L
s
.73335 .43483 m
.73375 .43868 L
s
.5 Mabswid
.115 .128 .098 r
.44056 .73538 m .47058 .73899 L .46649 .73747 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.46649 .73747 m .43272 .73238 L .44056 .73538 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.43272 .26762 m .46649 .26253 L .47058 .26101 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.46649 .26253 m .43272 .26762 L .42808 .27086 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.60781 .28577 m .64026 .30454 L .63633 .299 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.63633 .299 m .60411 .28114 L .60781 .28577 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.64026 .69546 m .60781 .71423 L .60411 .71886 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.57001 .73078 m .60411 .71886 L .60781 .71423 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72862 .4201 m
.7308 .42553 L
s
.73199 .42922 m
.73335 .43483 L
s
.5 Mabswid
.114 .127 .097 r
.39961 .72113 m .43272 .73238 L .42808 .72914 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.42808 .72914 m .39342 .71655 L .39961 .72113 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.39342 .28345 m .42808 .27086 L .43272 .26762 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7308 .42553 m
.73199 .42922 L
s
.5 Mabswid
.117 .129 .098 r
.53165 .73825 m .56374 .73392 L .57001 .73078 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.56374 .73392 m .53165 .73825 L .52684 .73967 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.53165 .26175 m .56374 .26608 L .55439 .26327 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.55439 .26327 m .52684 .26033 L .53165 .26175 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.66947 .67158 m .64026 .69546 L .63633 .701 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.60411 .71886 m .63633 .701 L .64026 .69546 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.64026 .30454 m .66947 .32842 L .6657 .32251 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.6657 .32251 m .63633 .299 L .64026 .30454 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.45134 .73796 m .47605 .74028 L .47058 .73899 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.47058 .73899 m .44056 .73538 L .45134 .73796 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.44056 .26462 m .47058 .26101 L .47605 .25972 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.47058 .26101 m .44056 .26462 L .43272 .26762 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27742 .59704 m
.27926 .60166 L
s
.26828 .57411 m
.27742 .59704 L
s
.27599 .59442 m
.27779 .6006 L
s
.5 Mabswid
.096 .11 .084 r
.52684 .73967 m .55439 .73673 L .56374 .73392 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.55439 .73673 m .52684 .73967 L .52077 .74082 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.52684 .26033 m .55439 .26327 L .5423 .26094 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.5423 .26094 m .52077 .25918 L .52684 .26033 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.69462 .64316 m .66947 .67158 L .6657 .67749 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.63633 .701 m .6657 .67749 L .66947 .67158 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.66947 .32842 m .69462 .35684 L .69127 .35115 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.69127 .35115 m .6657 .32251 L .66947 .32842 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.60411 .71886 m .57001 .73078 L .56374 .73392 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.57001 .26922 m .60411 .28114 L .59543 .27668 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.59543 .27668 m .56374 .26608 L .57001 .26922 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.36811 .70373 m .39961 .72113 L .39342 .71655 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.39342 .71655 m .36089 .69823 L .36811 .70373 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.43272 .26762 m .39961 .27887 L .39342 .28345 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.36089 .30177 m .39342 .28345 L .39961 .27887 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.4646 .73999 m .48265 .74128 L .47605 .74028 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.47605 .74028 m .45134 .73796 L .4646 .73999 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.45134 .26204 m .47605 .25972 L .48265 .25872 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.47605 .25972 m .45134 .26204 L .44056 .26462 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.69462 .35684 m .71499 .38909 L .71217 .3842 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.71217 .3842 m .69127 .35115 L .69462 .35684 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.71499 .61091 m .69462 .64316 L .69127 .64885 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.6657 .67749 m .69127 .64885 L .69462 .64316 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27779 .6006 m
.27833 .60285 L
s
.5 Mabswid
.077 .093 .071 r
.52077 .74082 m .5423 .73906 L .55439 .73673 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.5423 .73906 m .52077 .74082 L .51372 .74166 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52077 .25918 m .5423 .26094 L .52803 .25924 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52803 .25924 m .51372 .25834 L .52077 .25918 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73043 .41878 m
.73225 .42457 L
s
.73225 .42457 m
.73346 .4283 L
s
.73346 .4283 m
.73529 .43374 L
s
.5 Mabswid
.062 .08 .061 r
.4797 .74135 m .49008 .74195 L .48265 .74128 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.48265 .74128 m .4646 .73999 L .4797 .74135 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.4646 .26001 m .48265 .25872 L .49008 .25805 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.48265 .25872 m .4646 .26001 L .45134 .26204 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.69127 .64885 m .71217 .6158 L .71499 .61091 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.72998 .57566 m .71499 .61091 L .71217 .6158 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.71499 .38909 m .72998 .42434 L .72767 .42076 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.72767 .42076 m .71217 .3842 L .71499 .38909 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.41074 .72541 m .44056 .73538 L .43272 .73238 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.43272 .73238 m .39961 .72113 L .41074 .72541 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.39961 .27887 m .43272 .26762 L .44056 .26462 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72925 .41467 m
.73043 .41878 L
s
.5 Mabswid
.063 .08 .061 r
.51372 .74166 m .52803 .74076 L .5423 .73906 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.52803 .74076 m .51372 .74166 L .506 .74214 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51372 .25834 m .52803 .25924 L .51229 .25826 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51229 .25826 m .506 .25786 L .51372 .25834 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2781 .60358 m
.27833 .60285 L
s
.5 Mabswid
.095 .11 .083 r
.72998 .42434 m .73916 .46165 L .7372 .45976 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.7372 .45976 m .72767 .42076 L .72998 .42434 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73529 .43374 m
.73658 .43718 L
s
.5 Mabswid
.144 .202 .133 r
.73916 .53835 m .72998 .57566 L .72767 .57924 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.71217 .6158 m .72767 .57924 L .72998 .57566 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49589 .74194 m .49799 .74224 L .49008 .74195 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49008 .74195 m .4797 .74135 L .49589 .74194 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.49008 .25805 m .4797 .25865 L .4646 .26001 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.4797 .25865 m .49008 .25805 L .49799 .25776 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.33923 .68043 m .36811 .70373 L .36089 .69823 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.36089 .69823 m .33142 .67453 L .33923 .68043 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.39961 .27887 m .36811 .29627 L .36089 .30177 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33142 .32547 m .36089 .30177 L .36811 .29627 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.506 .74214 m .51229 .74174 L .52803 .74076 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.51229 .74174 m .506 .74214 L .49799 .74224 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.506 .25786 m .51229 .25826 L .49589 .25806 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49589 .25806 m .49799 .25776 L .506 .25786 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.73916 .46165 m .74225 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.74042 .5 m .7372 .45976 L .73916 .46165 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.74225 .5 m .73916 .53835 L .7372 .54024 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.72767 .57924 m .7372 .54024 L .73916 .53835 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.49799 .74224 m .49589 .74194 L .51229 .74174 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.49799 .25776 m .49589 .25806 L .4797 .25865 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.7372 .54024 m .74042 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72868 .41245 m
.72925 .41467 L
s
.73658 .43718 m
.73726 .43878 L
s
.5 Mabswid
.077 .093 .071 r
.56374 .73392 m .59543 .72332 L .60411 .71886 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.63633 .701 m .60411 .71886 L .59543 .72332 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.60411 .28114 m .63633 .299 L .62576 .29361 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.62576 .29361 m .59543 .27668 L .60411 .28114 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.59543 .72332 m .56374 .73392 L .55439 .73673 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.56374 .26608 m .59543 .27668 L .58191 .27264 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.58191 .27264 m .55439 .26327 L .56374 .26608 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72868 .41245 m
.7288 .41197 L
s
0 0 0 r
.27723 .60227 m
.2781 .60358 L
s
1 .5 0 r
.73726 .43878 m
.73744 .43844 L
s
.5 Mabswid
.316 .457 .385 r
.31395 .65171 m .33923 .68043 L .33142 .67453 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.33142 .67453 m .30591 .64599 L .31395 .65171 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36811 .29627 m .33923 .31957 L .33142 .32547 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.30591 .35401 m .33142 .32547 L .33923 .31957 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.42652 .72914 m .45134 .73796 L .44056 .73538 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.44056 .73538 m .41074 .72541 L .42652 .72914 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.44056 .26462 m .41074 .27459 L .39961 .27887 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.41074 .27459 m .44056 .26462 L .45134 .26204 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7288 .41197 m
.72954 .41358 L
s
0 0 0 r
.27474 .59692 m
.27723 .60227 L
s
1 .5 0 r
.73697 .43635 m
.73744 .43844 L
s
.5 Mabswid
.369 .539 .437 r
.38203 .70894 m .41074 .72541 L .39961 .72113 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.39961 .72113 m .36811 .70373 L .38203 .70894 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.36811 .29627 m .39961 .27887 L .41074 .27459 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.33923 .31957 m .31395 .34829 L .30591 .35401 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.28515 .38667 m .30591 .35401 L .31395 .34829 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.29319 .61827 m .31395 .65171 L .30591 .64599 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.30591 .64599 m .28515 .61333 L .29319 .61827 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.6657 .67749 m .63633 .701 L .62576 .70639 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.59543 .72332 m .62576 .70639 L .63633 .701 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.63633 .299 m .6657 .32251 L .65374 .31669 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.65374 .31669 m .62576 .29361 L .63633 .299 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26678 .57615 m
.27474 .59692 L
s
1 .5 0 r
.72954 .41358 m
.73092 .41713 L
s
.73588 .43236 m
.73697 .43635 L
s
.5 Mabswid
.298 .451 .339 r
.55439 .73673 m .58191 .72736 L .59543 .72332 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.58191 .72736 m .55439 .73673 L .5423 .73906 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.55439 .26327 m .58191 .27264 L .56403 .26926 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.56403 .26926 m .5423 .26094 L .55439 .26327 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72288 .39768 m
.73743 .43797 L
s
.5 Mabswid
.32 .443 .376 r
.27773 .58105 m .29319 .61827 L .28515 .61333 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.28515 .61333 m .26981 .57743 L .27773 .58105 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27474 .59692 m
.27753 .60324 L
s
.5 Mabswid
.099 .12 .098 r
.31395 .34829 m .29319 .38173 L .28515 .38667 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.26981 .42257 m .28515 .38667 L .29319 .38173 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27753 .60324 m
.27871 .60554 L
s
.5 Mabswid
.417 .605 .476 r
.44631 .73211 m .4646 .73999 L .45134 .73796 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.45134 .73796 m .42652 .72914 L .44631 .73211 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.42652 .27086 m .45134 .26204 L .4646 .26001 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.45134 .26204 m .42652 .27086 L .41074 .27459 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.2682 .5412 m .27773 .58105 L .26981 .57743 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.26981 .57743 m .2604 .53929 L .2682 .5412 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.29319 .38173 m .27773 .41895 L .26981 .42257 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.2604 .46071 m .26981 .42257 L .27773 .41895 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.62576 .70639 m .59543 .72332 L .58191 .72736 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.59543 .27668 m .62576 .29361 L .60857 .28866 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60857 .28866 m .58191 .27264 L .59543 .27668 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.6657 .32251 m .69127 .35115 L .67836 .34548 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.67836 .34548 m .65374 .31669 L .6657 .32251 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.69127 .64885 m .6657 .67749 L .65374 .68331 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.62576 .70639 m .65374 .68331 L .6657 .67749 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.27773 .41895 m .2682 .4588 L .2604 .46071 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.25723 .5 m .2604 .46071 L .2682 .4588 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.26498 .5 m .2682 .5412 L .2604 .53929 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.2604 .53929 m .25723 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72839 .41068 m
.73662 .4415 L
s
.73662 .4415 m
.73881 .44969 L
s
0 0 0 r
.27871 .60554 m
.27942 .60628 L
s
.5 Mabswid
.233 .297 .261 r
.2682 .4588 m .26498 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.5423 .73906 m .56403 .73074 L .58191 .72736 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.56403 .73074 m .5423 .73906 L .52803 .74076 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.5423 .26094 m .56403 .26926 L .54259 .26676 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.54259 .26676 m .52803 .25924 L .5423 .26094 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.35538 .68609 m .38203 .70894 L .36811 .70373 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.36811 .70373 m .33923 .68043 L .35538 .68609 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.41074 .27459 m .38203 .29106 L .36811 .29627 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.33923 .31957 m .36811 .29627 L .38203 .29106 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.46913 .7341 m .4797 .74135 L .4646 .73999 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.4646 .73999 m .44631 .73211 L .46913 .7341 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.44631 .26789 m .4646 .26001 L .4797 .25865 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.4646 .26001 m .44631 .26789 L .42652 .27086 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.40236 .71354 m .42652 .72914 L .41074 .72541 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.41074 .72541 m .38203 .70894 L .40236 .71354 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.38203 .29106 m .41074 .27459 L .42652 .27086 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27918 .60494 m
.27942 .60628 L
s
.5 Mabswid
.418 .606 .458 r
.52803 .74076 m .54259 .73324 L .56403 .73074 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.54259 .73324 m .52803 .74076 L .51229 .74174 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.52803 .25924 m .54259 .26676 L .51871 .26531 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.51871 .26531 m .51229 .25826 L .52803 .25924 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69127 .35115 m .71217 .3842 L .69868 .37929 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69868 .37929 m .67836 .34548 L .69127 .35115 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.71217 .6158 m .69127 .64885 L .67836 .65452 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.65374 .68331 m .67836 .65452 L .69127 .64885 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.49373 .73498 m .49589 .74194 L .4797 .74135 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.4797 .74135 m .46913 .7341 L .49373 .73498 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.46913 .2659 m .4797 .25865 L .49589 .25806 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.4797 .25865 m .46913 .2659 L .44631 .26789 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.51229 .74174 m .51871 .73469 L .54259 .73324 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.51871 .73469 m .51229 .74174 L .49589 .74194 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.51229 .25826 m .51871 .26531 L .49373 .26502 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.49373 .26502 m .49589 .25806 L .51229 .25826 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27697 .59949 m
.27918 .60494 L
s
.5 Mabswid
.47 .671 .513 r
.49589 .74194 m .49373 .73498 L .51871 .73469 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.49589 .25806 m .49373 .26502 L .46913 .2659 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26888 .57823 m
.27697 .59949 L
s
.5 Mabswid
.217 .251 .178 r
.71217 .3842 m .72767 .42076 L .71386 .41715 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71386 .41715 m .69868 .37929 L .71217 .3842 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.72767 .57924 m .71217 .6158 L .69868 .62071 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.67836 .65452 m .69868 .62071 L .71217 .6158 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.65374 .68331 m .62576 .70639 L .60857 .71134 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.58191 .72736 m .60857 .71134 L .62576 .70639 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.62576 .29361 m .65374 .31669 L .63344 .31129 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.63344 .31129 m .60857 .28866 L .62576 .29361 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.60857 .71134 m .58191 .72736 L .56403 .73074 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58191 .27264 m .60857 .28866 L .58528 .28448 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58528 .28448 m .56403 .26926 L .58191 .27264 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.38203 .29106 m .35538 .31391 L .33923 .31957 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.31395 .34829 m .33923 .31957 L .35538 .31391 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33181 .65724 m .35538 .68609 L .33923 .68043 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33923 .68043 m .31395 .65171 L .33181 .65724 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72767 .42076 m .7372 .45976 L .72324 .45784 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73355 .43461 m
.73881 .44969 L
s
.73324 .43373 m
.73355 .43461 L
s
.73032 .42239 m
.73284 .42381 L
s
.5 Mabswid
.254 .308 .211 r
.72324 .45784 m .71386 .41715 L .72767 .42076 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7243 .40808 m
.73324 .43373 L
s
.5 Mabswid
.307 .409 .265 r
.7372 .54024 m .72767 .57924 L .71386 .58285 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.69868 .62071 m .71386 .58285 L .72767 .57924 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42835 .71723 m .44631 .73211 L .42652 .72914 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42652 .72914 m .40236 .71354 L .42835 .71723 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.40236 .28646 m .42652 .27086 L .44631 .26789 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.42652 .27086 m .40236 .28646 L .38203 .29106 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.7372 .45976 m .74042 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.72642 .5 m .72324 .45784 L .7372 .45976 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.74042 .5 m .7372 .54024 L .72324 .54216 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.71386 .58285 m .72324 .54216 L .7372 .54024 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.72324 .54216 m .72642 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.35538 .31391 m .33181 .34276 L .31395 .34829 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.29319 .38173 m .31395 .34829 L .33181 .34276 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31228 .62308 m .33181 .65724 L .31395 .65171 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31395 .65171 m .29319 .61827 L .31228 .62308 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.37971 .69114 m .40236 .71354 L .38203 .70894 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.38203 .70894 m .35538 .68609 L .37971 .69114 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.35538 .31391 m .38203 .29106 L .40236 .28646 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.56403 .73074 m .58528 .71552 L .60857 .71134 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.58528 .71552 m .56403 .73074 L .54259 .73324 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.56403 .26926 m .58528 .28448 L .55693 .28136 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.55693 .28136 m .54259 .26676 L .56403 .26926 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65374 .31669 m .67836 .34548 L .65555 .34018 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65555 .34018 m .63344 .31129 L .65374 .31669 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.67836 .65452 m .65374 .68331 L .63344 .68871 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.60857 .71134 m .63344 .68871 L .65374 .68331 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27698 .59295 m
.27863 .59711 L
s
.27863 .59711 m
.28178 .60333 L
s
.27516 .58664 m
.27698 .59295 L
s
.2749 .58249 m
.27516 .58664 L
s
.5 Mabswid
.558 .777 .597 r
.45868 .71973 m .46913 .7341 L .44631 .73211 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.44631 .73211 m .42835 .71723 L .45868 .71973 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29763 .58461 m .31228 .62308 L .29319 .61827 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29319 .61827 m .27773 .58105 L .29763 .58461 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28178 .60333 m
.2848 .60764 L
s
.27863 .59711 m
.28806 .59982 L
s
.5 Mabswid
.196 .203 .154 r
.42835 .28277 m .44631 .26789 L .46913 .2659 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.44631 .26789 m .42835 .28277 L .40236 .28646 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.33181 .34276 m .31228 .37692 L .29319 .38173 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.27773 .41895 m .29319 .38173 L .31228 .37692 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2848 .60764 m
.28709 .61001 L
s
.5 Mabswid
.227 .24 .178 r
.60857 .28866 m .63344 .31129 L .60529 .30668 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60529 .30668 m .58528 .28448 L .60857 .28866 L p F P
.505 .664 .505 r
s
.519 .718 .524 r
.63344 .68871 m .60857 .71134 L .58528 .71552 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.54259 .73324 m .55693 .71864 L .58528 .71552 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.55693 .71864 m .54259 .73324 L .51871 .73469 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.54259 .26676 m .55693 .28136 L .52506 .27954 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.52506 .27954 m .51871 .26531 L .54259 .26676 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28709 .61001 m
.28947 .61075 L
s
.5 Mabswid
.47 .621 .496 r
.28856 .54309 m .29763 .58461 L .27773 .58105 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.27773 .58105 m .2682 .5412 L .28856 .54309 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2749 .58249 m
.27558 .58053 L
s
.5 Mabswid
.296 .356 .288 r
.31228 .37692 m .29763 .41539 L .27773 .41895 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.2682 .4588 m .27773 .41895 L .29763 .41539 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.4916 .72084 m .49373 .73498 L .46913 .7341 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.46913 .7341 m .45868 .71973 L .4916 .72084 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.45868 .28027 m .46913 .2659 L .49373 .26502 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.46913 .2659 m .45868 .28027 L .42835 .28277 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67836 .34548 m .69868 .37929 L .67394 .37466 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67394 .37466 m .65555 .34018 L .67836 .34548 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.69868 .62071 m .67836 .65452 L .65555 .65982 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.63344 .68871 m .65555 .65982 L .67836 .65452 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35949 .66222 m .37971 .69114 L .35538 .68609 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35538 .68609 m .33181 .65724 L .35949 .66222 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.40236 .28646 m .37971 .30886 L .35538 .31391 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.33181 .34276 m .35538 .31391 L .37971 .30886 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27558 .58053 m
.27801 .5811 L
s
.5 Mabswid
.555 .772 .578 r
.51871 .73469 m .52506 .72046 L .55693 .71864 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.52506 .72046 m .51871 .73469 L .49373 .73498 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.51871 .26531 m .52506 .27954 L .4916 .27916 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.4916 .27916 m .49373 .26502 L .51871 .26531 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.29763 .41539 m .28856 .45691 L .2682 .4588 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.26498 .5 m .2682 .4588 L .28856 .45691 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.28548 .5 m .28856 .54309 L .2682 .5412 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.2682 .5412 m .26498 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28947 .61075 m
.29036 .60935 L
s
.5 Mabswid
.574 .795 .599 r
.49373 .73498 m .4916 .72084 L .52506 .72046 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.49373 .26502 m .4916 .27916 L .45868 .28027 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.28856 .45691 m .28548 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.41137 .69522 m .42835 .71723 L .40236 .71354 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.40236 .71354 m .37971 .69114 L .41137 .69522 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.37971 .30886 m .40236 .28646 L .42835 .28277 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29036 .60935 m
.29044 .60766 L
s
.27801 .5811 m
.28056 .58386 L
s
.28971 .60393 m
.29044 .60766 L
s
.5 Mabswid
.331 .398 .271 r
.69868 .37929 m .71386 .41715 L .68778 .41371 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.68778 .41371 m .67394 .37466 L .69868 .37929 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.71386 .58285 m .69868 .62071 L .67394 .62534 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.65555 .65982 m .67394 .62534 L .69868 .62071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28056 .58386 m
.28403 .58889 L
s
.5 Mabswid
.519 .718 .524 r
.58528 .71552 m .60529 .69332 L .63344 .68871 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.60529 .69332 m .58528 .71552 L .55693 .71864 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.58528 .28448 m .60529 .30668 L .57052 .30321 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.57052 .30321 m .55693 .28136 L .58528 .28448 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28806 .59982 m
.28971 .60393 L
s
.5 Mabswid
.55 .747 .54 r
.65555 .65982 m .63344 .68871 L .60529 .69332 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.63344 .31129 m .65555 .34018 L .62323 .33561 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.62323 .33561 m .60529 .30668 L .63344 .31129 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.37971 .30886 m .35949 .33778 L .33181 .34276 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.31228 .37692 m .33181 .34276 L .35949 .33778 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.34259 .62745 m .35949 .66222 L .33181 .65724 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.33181 .65724 m .31228 .62308 L .34259 .62745 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.72324 .54216 m .71386 .58285 L .68778 .58629 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.67394 .62534 m .68778 .58629 L .71386 .58285 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.71386 .41715 m .72324 .45784 L .69638 .45601 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.69638 .45601 m .68778 .41371 L .71386 .41715 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.44875 .698 m .45868 .71973 L .42835 .71723 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.42835 .71723 m .41137 .69522 L .44875 .698 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.41137 .30478 m .42835 .28277 L .45868 .28027 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.42835 .28277 m .41137 .30478 L .37971 .30886 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.72324 .45784 m .72642 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.6993 .5 m .69638 .45601 L .72324 .45784 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.72642 .5 m .72324 .54216 L .69638 .54399 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.68778 .58629 m .69638 .54399 L .72324 .54216 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.69638 .54399 m .6993 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29295 .59685 m
.29456 .60115 L
s
.29456 .60115 m
.2982 .60756 L
s
.5 Mabswid
.577 .79 .582 r
.55693 .71864 m .57052 .69679 L .60529 .69332 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.57052 .69679 m .55693 .71864 L .52506 .72046 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.55693 .28136 m .57052 .30321 L .5311 .30117 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.5311 .30117 m .52506 .27954 L .55693 .28136 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.39609 .66628 m .41137 .69522 L .37971 .69114 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.37971 .69114 m .35949 .66222 L .39609 .66628 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.35949 .33778 m .37971 .30886 L .41137 .30478 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29182 .5903 m
.29295 .59685 L
s
.5 Mabswid
.34 .404 .31 r
.35949 .33778 m .34259 .37255 L .31228 .37692 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.29763 .41539 m .31228 .37692 L .34259 .37255 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.32983 .58786 m .34259 .62745 L .31228 .62308 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.31228 .62308 m .29763 .58461 L .32983 .58786 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2982 .60756 m
.30232 .61197 L
s
.30232 .61197 m
.30574 .61437 L
s
.29182 .5903 m
.29285 .58596 L
s
.5 Mabswid
.631 .858 .647 r
.48957 .69924 m .4916 .72084 L .45868 .71973 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.45868 .71973 m .44875 .698 L .48957 .69924 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.44875 .302 m .45868 .28027 L .4916 .27916 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.45868 .28027 m .44875 .302 L .41137 .30478 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.65555 .34018 m .67394 .37466 L .63828 .37064 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.63828 .37064 m .62323 .33561 L .65555 .34018 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.67394 .62534 m .65555 .65982 L .62323 .66439 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.60529 .69332 m .62323 .66439 L .65555 .65982 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30574 .61437 m
.30987 .61507 L
s
.5 Mabswid
.612 .833 .618 r
.52506 .72046 m .5311 .69883 L .57052 .69679 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.5311 .69883 m .52506 .72046 L .4916 .72084 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.52506 .27954 m .5311 .30117 L .48957 .30076 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.48957 .30076 m .4916 .27916 L .52506 .27954 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.4916 .72084 m .48957 .69924 L .5311 .69883 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.4916 .27916 m .48957 .30076 L .44875 .302 L p F P
.505 .664 .505 r
s
.605 .814 .594 r
.62323 .66439 m .60529 .69332 L .57052 .69679 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.60529 .30668 m .62323 .33561 L .58279 .33214 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.58279 .33214 m .57052 .30321 L .60529 .30668 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.34259 .37255 m .32983 .41214 L .29763 .41539 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.28856 .45691 m .29763 .41539 L .32983 .41214 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.32189 .54482 m .32983 .58786 L .29763 .58461 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.29763 .58461 m .28856 .54309 L .32189 .54482 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29285 .58596 m
.2948 .5839 L
s
.30987 .61507 m
.31199 .61358 L
s
.2948 .5839 m
.2991 .58444 L
s
.31307 .60619 m
.32139 .62871 L
s
.30531 .58515 m
.31307 .60619 L
s
.31199 .61358 m
.31348 .61002 L
s
.5 Mabswid
.465 .584 .45 r
.32983 .41214 m .32189 .45518 L .28856 .45691 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.28548 .5 m .28856 .45691 L .32189 .45518 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.3192 .5 m .32189 .54482 L .28856 .54309 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.28856 .54309 m .28548 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.41137 .30478 m .39609 .33372 L .35949 .33778 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.34259 .37255 m .35949 .33778 L .39609 .33372 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.38325 .63104 m .39609 .66628 L .35949 .66222 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.35949 .66222 m .34259 .62745 L .38325 .63104 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2991 .58444 m
.30284 .58726 L
s
.5 Mabswid
.508 .649 .5 r
.32189 .45518 m .3192 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.68778 .58629 m .67394 .62534 L .63828 .62936 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.62323 .66439 m .63828 .62936 L .67394 .62534 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.67394 .37466 m .68778 .41371 L .64966 .41072 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.64966 .41072 m .63828 .37064 L .67394 .37466 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.43977 .66907 m .44875 .698 L .41137 .69522 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.41137 .69522 m .39609 .66628 L .43977 .66907 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.39609 .33372 m .41137 .30478 L .44875 .302 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30284 .58726 m
.30744 .59243 L
s
.5 Mabswid
.605 .814 .594 r
.57052 .69679 m .58279 .66786 L .62323 .66439 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.58279 .66786 m .57052 .69679 L .5311 .69883 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.57052 .30321 m .58279 .33214 L .53658 .3301 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.53658 .3301 m .5311 .30117 L .57052 .30321 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.69638 .54399 m .68778 .58629 L .64966 .58928 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.63828 .62936 m .64966 .58928 L .68778 .58629 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.68778 .41371 m .69638 .45601 L .65676 .45441 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.65676 .45441 m .64966 .41072 L .68778 .41371 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.62323 .33561 m .63828 .37064 L .59314 .36757 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.59314 .36757 m .58279 .33214 L .62323 .33561 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.63828 .62936 m .62323 .66439 L .58279 .66786 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.48773 .67031 m .48957 .69924 L .44875 .698 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.44875 .698 m .43977 .66907 L .48773 .67031 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.43977 .33093 m .44875 .302 L .48957 .30076 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.44875 .302 m .43977 .33093 L .39609 .33372 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.39609 .33372 m .38325 .36896 L .34259 .37255 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.32983 .41214 m .34259 .37255 L .38325 .36896 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.3735 .59054 m .38325 .63104 L .34259 .62745 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.34259 .62745 m .32983 .58786 L .3735 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32307 .60513 m
.32707 .6117 L
s
.32707 .6117 m
.33223 .61618 L
s
.32163 .60069 m
.32307 .60513 L
s
.32307 .60513 m
.34709 .60736 L
s
.5 Mabswid
.488 .619 .429 r
.69638 .45601 m .6993 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.65918 .5 m .65676 .45441 L .69638 .45601 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.6993 .5 m .69638 .54399 L .65676 .54559 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.64966 .58928 m .65676 .54559 L .69638 .54399 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.5311 .69883 m .53658 .6699 L .58279 .66786 L p F P
.505 .664 .505 r
s
.651 .872 .648 r
.53658 .6699 m .5311 .69883 L .48957 .69924 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.5311 .30117 m .53658 .3301 L .48773 .32969 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.48773 .32969 m .48957 .30076 L .5311 .30117 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32139 .59389 m
.32163 .60069 L
s
.33223 .61618 m
.33676 .61857 L
s
.5 Mabswid
.651 .872 .648 r
.48957 .69924 m .48773 .67031 L .53658 .6699 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.48957 .30076 m .48773 .32969 L .43977 .33093 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.65676 .54559 m .65918 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33676 .61857 m
.34268 .61918 L
s
.32139 .59389 m
.32388 .58935 L
s
.5 Mabswid
.449 .547 .402 r
.38325 .36896 m .39609 .33372 L .43977 .33093 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.43218 .63351 m .43977 .66907 L .39609 .66628 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.39609 .66628 m .38325 .63104 L .43218 .63351 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34268 .61918 m
.34611 .61757 L
s
.5 Mabswid
.473 .586 .441 r
.38325 .36896 m .3735 .40946 L .32983 .41214 L p F P
.505 .664 .505 r
s
.522 .657 .495 r
.32189 .45518 m .32983 .41214 L .3735 .40946 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.36741 .54626 m .3735 .59054 L .32983 .58786 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.32983 .58786 m .32189 .54482 L .36741 .54626 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32388 .58935 m
.32721 .58717 L
s
.34611 .61757 m
.34754 .61572 L
s
.32721 .58717 m
.33343 .58764 L
s
.5 Mabswid
.605 .795 .573 r
.64966 .58928 m .63828 .62936 L .59314 .63243 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.58279 .66786 m .59314 .63243 L .63828 .62936 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.63828 .37064 m .64966 .41072 L .60101 .40842 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.60101 .40842 m .59314 .36757 L .63828 .37064 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34754 .61572 m
.34838 .61171 L
s
.5 Mabswid
.442 .537 .376 r
.58279 .33214 m .59314 .36757 L .54122 .36576 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.54122 .36576 m .53658 .3301 L .58279 .33214 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.59314 .63243 m .58279 .66786 L .53658 .6699 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34709 .60736 m
.34838 .61171 L
s
.33343 .58764 m
.33835 .59048 L
s
.5 Mabswid
.522 .657 .495 r
.3735 .40946 m .36741 .45374 L .32189 .45518 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.3192 .5 m .32189 .45518 L .36741 .45374 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.36534 .5 m .36741 .54626 L .32189 .54482 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.32189 .54482 m .3192 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33835 .59048 m
.34397 .59574 L
s
.5 Mabswid
.559 .714 .54 r
.36741 .45374 m .36534 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.43218 .36649 m .43977 .33093 L .48773 .32969 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.48617 .63462 m .48773 .67031 L .43977 .66907 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.43977 .66907 m .43218 .63351 L .48617 .63462 L p F P
.505 .664 .505 r
s
.449 .547 .402 r
.43977 .33093 m .43218 .36649 L .38325 .36896 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.42641 .59239 m .43218 .63351 L .38325 .63104 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.38325 .63104 m .3735 .59054 L .42641 .59239 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.3735 .40946 m .38325 .36896 L .43218 .36649 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3625 .61488 m
.36603 .61919 L
s
.36603 .61919 m
.37372 .62171 L
s
.3625 .61488 m
.36368 .61073 L
s
.5 Mabswid
.591 .768 .55 r
.65676 .54559 m .64966 .58928 L .60101 .59158 L p F P
.505 .664 .505 r
s
.605 .795 .573 r
.59314 .63243 m .60101 .59158 L .64966 .58928 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.64966 .41072 m .65676 .45441 L .60593 .45318 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.60593 .45318 m .60101 .40842 L .64966 .41072 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.53658 .6699 m .54122 .63424 L .59314 .63243 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.53658 .3301 m .54122 .36576 L .48617 .36538 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.48617 .36538 m .48773 .32969 L .53658 .3301 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.54122 .63424 m .53658 .6699 L .48773 .67031 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.36368 .61073 m
.36792 .60882 L
s
.37372 .62171 m
.38105 .62219 L
s
.5 Mabswid
.654 .866 .64 r
.48773 .67031 m .48617 .63462 L .54122 .63424 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.48773 .32969 m .48617 .36538 L .43218 .36649 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35785 .59665 m
.35918 .59179 L
s
.36792 .60882 m
.37992 .60727 L
s
.38105 .62219 m
.38809 .6206 L
s
.5 Mabswid
.541 .688 .487 r
.65676 .45441 m .65918 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.6076 .5 m .60593 .45318 L .65676 .45441 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.65918 .5 m .65676 .54559 L .60593 .54682 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.60101 .59158 m .60593 .54682 L .65676 .54559 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35918 .59179 m
.36613 .58961 L
s
.5 Mabswid
.632 .829 .604 r
.60101 .59158 m .59314 .63243 L .54122 .63424 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.59314 .36757 m .60101 .40842 L .54475 .40706 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.54475 .40706 m .54122 .36576 L .59314 .36757 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38809 .6206 m
.38968 .61655 L
s
.5 Mabswid
.569 .732 .521 r
.60593 .54682 m .6076 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.40963 .6086 m
.4152 .63711 L
s
.37992 .60727 m
.38464 .60522 L
s
.5 Mabswid
.631 .821 .615 r
.42279 .54725 m .42641 .59239 L .3735 .59054 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.3735 .59054 m .36741 .54626 L .42279 .54725 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.36613 .58961 m
.37387 .58998 L
s
.5 Mabswid
.505 .628 .464 r
.43218 .36649 m .42641 .40761 L .3735 .40946 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.36741 .45374 m .3735 .40946 L .42641 .40761 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.38464 .60522 m
.38635 .60056 L
s
.5 Mabswid
.651 .854 .635 r
.48498 .59322 m .48617 .63462 L .43218 .63351 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.43218 .63351 m .42641 .59239 L .48498 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.42641 .40761 m .43218 .36649 L .48617 .36538 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37387 .58998 m
.38229 .59293 L
s
.38589 .5981 m
.38635 .60056 L
s
.38229 .59293 m
.38589 .5981 L
s
.5 Mabswid
.632 .829 .604 r
.54122 .63424 m .54475 .59294 L .60101 .59158 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.54475 .59294 m .54122 .63424 L .48617 .63462 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.54122 .36576 m .54475 .40706 L .48498 .40678 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.48498 .40678 m .48617 .36538 L .54122 .36576 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.42641 .40761 m .42279 .45275 L .36741 .45374 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.36534 .5 m .36741 .45374 L .42279 .45275 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.42155 .5 m .42279 .54725 L .36741 .54626 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.36741 .54626 m .36534 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.60593 .54682 m .60101 .59158 L .54475 .59294 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.60101 .40842 m .60593 .45318 L .54696 .45245 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.54696 .45245 m .54475 .40706 L .60101 .40842 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.48617 .63462 m .48498 .59322 L .54475 .59294 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.48617 .36538 m .48498 .40678 L .42641 .40761 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.42279 .45275 m .42155 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4045 .59377 m
.40702 .59124 L
s
.4045 .59377 m
.40774 .59644 L
s
.40774 .59644 m
.41027 .59396 L
s
.40702 .59124 m
.41027 .59396 L
s
.5 Mabswid
.636 .827 .612 r
.48424 .5477 m .48498 .59322 L .42641 .59239 L p F P
.505 .664 .505 r
s
.636 .827 .612 r
.42641 .59239 m .42279 .54725 L .48424 .5477 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.42279 .45275 m .42641 .40761 L .48498 .40678 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.60593 .45318 m .6076 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.54772 .5 m .54696 .45245 L .60593 .45318 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.6076 .5 m .60593 .54682 L .54696 .54755 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.54475 .59294 m .54696 .54755 L .60593 .54682 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.54696 .54755 m .54772 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.54475 .40706 m .54696 .45245 L .48424 .4523 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.48424 .4523 m .48498 .40678 L .54475 .40706 L p F P
.505 .664 .505 r
s
.632 .82 .601 r
.54696 .54755 m .54475 .59294 L .48498 .59322 L p F P
.505 .664 .505 r
s
.632 .82 .601 r
.48498 .59322 m .48424 .5477 L .54696 .54755 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.48498 .40678 m .48424 .4523 L .42279 .45275 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.42155 .5 m .42279 .45275 L .48424 .4523 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.48398 .5 m .48424 .5477 L .42279 .54725 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.42279 .54725 m .42155 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.48424 .4523 m .48398 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.54696 .45245 m .54772 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.48398 .5 m .48424 .4523 L .54696 .45245 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.54772 .5 m .54696 .54755 L .48424 .5477 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.48424 .5477 m .48398 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003U0;3PiPl0PJV10`0T9ad0
0`21ZH409BPN02DX7P0602DX7P03086YP@0T9ad092LM00P0PJV1j02`h>H10?ooo`00h02`h>H6086Y
P@L08B@K0P21ZH4702@W7@03086YP@0U:1h09BPN00L09BPN00<0PJV102@W7@0T9ad01@0T9ad2086Y
P@03020S6`21ZH40PJV100@0PJV1hP2`h>H10?ooo`00g@2`h>H3086YP@806ahG0P21ZH47024T6`80
PJV12@0T9ad00`21ZH409BPN02DX7P0802DX7P03086YP@0T9ad092LM00H092LM0P21ZH44020S6`L0
PJV1g02`h>H10?ooo`00fP2`h>H4086YP@806ahG0P21ZH43024T6b<0PJV1100T9ad2086YP@D082<K
0P21ZH400`0J7QL0PJV1086YP@03086YPMP0/>3V0@3oool00=H0/>3V1@21ZH400`0K7QL0PJV1086Y
P@07086YP@@0<S<W00<0PJV103Hg:P0f=bX02P0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f
=bX0=SLZ0080=SLZ3021ZH401@0P8a/0PJV1086YP@21ZH406QhG0080PJV100<04QHA086YP@2`h>H0
e@2`h>H10?ooo`00e02`h>H00`21ZH404aLA086YP@05086YP@0302/]8P21ZH40<S<W00T0<S<W00<0
PJV103Hg:P0f=bX02`0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0
PJV1038c9`0b<bL00P0b<bL<086YPM<0/>3V0@3oool00=40/>3V00<0PJV101<G4@21ZH400`21ZH45
02/]8P03086YP@0b<bL0<S<W00P0<S<W00<0PJV103Hg:P0f=bX0300f=bX00`21ZH40=cP[03Lh:`0;
03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0PJV1038c9`0b<bL01`0b<bL9086YPM00/>3V0@3oool0
0<h0/>3V1P21ZH4702/]8P03086YP@0b<bL0<S<W00T0<S<W00<0PJV103Hg:P0f=bX02`0f=bX00`21
ZH40=cP[03Lh:`0<03Lh:`03086YP@0f=bX0=SLZ00X0=SLZ00<0PJV1038c9`0b<bL0200b<bL01021
ZH40:RdR02X]8P0Z;B85086YPLh0/>3V0@3oool00</0/>3V1021ZH400`0Q91/0PJV1086YP@0702/]
8P80PJV12`0b<bL00`21ZH40=SLZ03Hg:P0<03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg
:P0f=bX02P0f=bX00`21ZH40<S<W038c9`08038c9`80PJV1100Z;B85086YPL/0/>3V0@3oool00<T0
/>3V0`21ZH43024T6`03086YP@0[;B80:bdR00H0:bdR00<0PJV1038c9`0b<bL02P0b<bL00`21ZH40
=SLZ03Hg:P0=03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg:P0f=bX02`0f=bX00`21ZH40
<S<W038c9`09038c9`80PJV1100Z;B82086YP@03020S6P21ZH40PJV10<T0/>3V0@3oool00<L0/>3V
0`21ZH43024T6`80PJV1200[;B800`21ZH40<S<W038c9`07038c9bd0PJV11P0f=bX00`21ZH40<S<W
038c9`0:038c9`03086YP@0Z;B80:RdR00<0:RdR00<0PJV1020S6P0P8aX00P21ZH770;3PiP40oooo
00350;3PiP<0PJV10`0Q91/2086YP@T0:bdR00<0PJV1038c9`0b<bL02021ZH4304I==`03086YP@1<
ESd0C5Hm00h0C5Hm00<0PJV104mI?P1?FCh03P1?FCh00`21ZH40CEHm04eF?@0504eF?@l0PJV11@0b
<bL2086YP@@0:RdR0P21ZH42020S6P80PJV1a@2`h>H10?ooo`00``2`h>H00`21ZH4051PB086YP@03
024T6`80PJV1100[;B8:086YP@X0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI?P0?
04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL01016CCL9086YP@@0:RdR00@0PJV1
020S6P0P8aX082<J0P21ZH730;3PiP40oooo00310;3PiP04086YP@0D6180PJV1086YP@808B@K2021
ZH4503Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL03016CCL5086YP@0302X]8P21
ZH40PJV100<082<J0P21ZH710;3PiP40oooo002o0;3PiP05086YP@0D6180PJV1086YP@0Q91/01021
ZH4<03Xn;P03086YP@16CCL0ATdg00/0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00d0CEHm00<0PJV104I==`16CCL03016CCL01021ZH40>Sd]03Xm
;@0j?Bd5086YP@<082<J0P21ZH6o0;3PiP40oooo002m0;3PiP03086YP@0D6180PJV100@0PJV10P0/
;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd0401<
ESd00`21ZH40CeTn04mI?P0?04mI?P03086YP@1=ESd0CEHm00h0CEHm00<0PJV104I==`16CCL02`16
CCL00`21ZH40>Sd]03Xm;@0503Xm;@@0PJV10P0P8aX2086YPKd0/>3V0@3oool00;/0/>3V00<0PJV1
01@H4P21ZH400P21ZH4502`_8`03086YP@0j?Rh0>Sh^00X0>Sh^00<0PJV104I==`16CCL03016CCL0
0`21ZH40C5Hm04aF?@0@04aF?@03086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03@1=ESd0
0`21ZH40ATdg04I==`0<04I==`03086YP@0j?Bd0>Sd]00H0>Sd]00<0PJV102`^8`21ZH401@21ZH6k
0;3PiP40oooo002i0;3PiPD0PJV11P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg
00d0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI?P0A04mI?P03086YP@1=ESd0CEHm
00h0CEHm00<0PJV104I==`16CCL03016CCL00`21ZH40>Sd]03Xm;@0603Xm;@03086YP@0/;R<0;2hS
0080;2hS0`21ZH6j0;3PiP40oooo002g0;3PiP80PJV10`0M8AT00`21ZH40;2lS02`_8`0402`_8`03
086YP@0j?Rh0>Sh^00/0>Sh^00<0PJV104I==`16CCL03016CCL00`21ZH40C5Hm04aF?@0A04aF?@03
086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03P1=ESd00`21ZH40ATdg04I==`0=04I==`03
086YP@0j?Bd0>Sd]00H0>Sd]0P21ZH4502`^8`80PJV1^02`h>H10?ooo`00]P2`h>H01021ZH407B4I
01dQ6@0M8AT2086YP@H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh00`21ZH40ATdg04I==`0=04I==`03
086YP@1<ESd0C5Hm0140C5Hm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40CEHm04eF?@0?04eF?@03
086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0
PJV1]P2`h>H10?ooo`00]@2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV100P0;2lS00<0PJV103Xn;P0j
?Rh02P0j?Rh00`21ZH40ATdg04I==`0=04I==`03086YP@1<ESd0C5Hm0180C5Hm00<0PJV104mI?P1?
FCh04P1?FCh00`21ZH40CEHm04eF?@0?04eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j
?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0PJV1]@2`h>H10?ooo`00/`2`h>H2086YP@<07B4I
00<0PJV102`_8`0/;b<01P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00X0ATdg
>021ZH4804eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd0200j?Bd00`21ZH40;2hS
02`^8`0402`^8`<0PJV1/`2`h>H10?ooo`00/P2`h>H00`21ZH407B4I01dQ6@0201dQ6@03086YP@0/
;b<0;2lS00H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh01021ZH40ATdg04I==`16CCL9086YP@@0Gg1B
00<0PJV106AgE@1TMeD04P1TMeD00`21ZH40HgIC06=fD`0B06=fD`03086YP@1NKd`0GVm<00L0GVm<
3P21ZH4;04I==`03086YP@0j?Bd0>Sd]00P0>Sd]00<0PJV102`^8`0/;R<0100/;R<00`21ZH4071lH
086YP@2b0;3PiP40oooo002a0;3PiP03086YP@0M8AT07B4I00807B4I00<0PJV102`_8`0/;b<01P0/
;b<00`21ZH40>Sh^03Xn;P0803Xn;PP0PJV1301OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1S
MU<0HgIC0180HgIC00<0PJV105i_C01NKd`0401NKd`00`21ZH40F6M705QWA`0205QWA`T0PJV10`16
CCL00`21ZH40>Sd]03Xm;@0803Xm;@80PJV11@0/;R<00`21ZH4071lH086YP@2a0;3PiP40oooo002`
0;3PiP04086YP@0M8AT07B4I01dQ6@80PJV1200/;b<01021ZH40>Sh^03Xn;P0j?Rh8086YP@80E658
00<0PJV105m`DP1OL5803`1OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC0180HgIC
00<0PJV105i_C01NKd`04@1NKd`00`21ZH40F6M705QWA`0:05QWA`P0PJV1200j?Bd00`21ZH40;2hS
02`^8`0302`^8`04086YP@0L7aP0PJV1086YPJl0/>3V0@3oool00:l0/>3V00D0PJV101dQ6@0M8AT0
7B4I086YP@0702`_8`L0PJV12P1DHDP00`21ZH40Gg1B05m`DP0?05m`DP03086YP@1TMeD0I7ME01<0
I7ME00<0PJV106=fD`1SMU<04`1SMU<00`21ZH40GVm<05i_C00@05i_C003086YP@1HIdL0F6M700l0
F6M700<0PJV104eG?@1=Ecd01`21ZH4203Xm;@03086YP@0/;R<0;2hS00<0;2hS00@0PJV101`O600L
7aP0PJV1[P2`h>H10?ooo`00[P2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV10080;2lS1P21ZH400`10
AcL0PJV105AQB00=05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21
ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21
ZH40CELm04eG?@0704eG?@D0PJV1100/;R<2086YP@0301`O6021ZH40/>3V0:`0/>3V0@3oool00:`0
/>3V0P21ZH4201dQ6@D0PJV11`10AcL00`21ZH40E65805AQB00<05AQB003086YP@1OL580Gg1B00l0
Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140
GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@@0PJV10`0/;R<01021ZH40
71lH086YP@21ZH6[0;3PiP40oooo002[0;3PiP03086YP@0M8AT07B4I00<0PJV12P10AcL00`21ZH40
E65805AQB00<05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40
HgIC06=fD`0D06=fD`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21ZH40
CELm04eG?@0;04eG?@03086YP@0i?Rh0>Ch^00D0PJV10P0L7aP00`21ZH40/>3V0;3PiP2X0;3PiP40
oooo002Z0;3PiP@0PJV100<09b/Q086YP@10AcL02@10AcL00`21ZH40E65805AQB00=05AQB003086Y
P@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgIC06=fD`0D06=fD`03086Y
P@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@03086Y
P@0i?Rh0>Ch^00@0>Ch^0`21ZH400`0L7aP0PJV10;3PiP2X0;3PiP40oooo002Y0;3PiP80PJV1100W
:b400`21ZH40@4Lg0417=`070417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`DP1OL5804@1O
L5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC01@0HgIC00<0PJV105i_C01NKd`04P1N
Kd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn;P0i?Rh01@0i
?Rh5086YPJL0/>3V0@3oool00:L0/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00P0@4Lg00<0PJV1
05AQB01DHDP0301DHDP00`21ZH40Gg1B05m`DP0A05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV1
06=fD`1SMU<0501SMU<00`21ZH40GVm<05i_C00C05i_C003086YP@1HIdL0F6M700l0F6M700<0PJV1
04eG?@1=Ecd02`1=Ecd00`21ZH40>Ch^03Tn;P0503Tn;P03086YP@0T9ad092LM0080PJV1YP2`h>H1
0?ooo`00YP2`h>H2086YP@D09b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQ
B003086YP@1OL580Gg1B0140Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0E06=f
D`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL0401HIdL00`21ZH40CELm04eG?@0;04eG
?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2U0;3PiP40oooo002U0;3P
iP80PJV11@0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`
DP1OL5804P1OL5800`21ZH40I7ME06AgE@0D06AgE@03086YP@1SMU<0HgIC01D0HgIC00<0PJV105i_
C01NKd`04`1NKd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn
;P0i?Rh01@0i?Rh00`21ZH4092LM02@W7@0202@W7@03086YP@2`h>H0/>3V0:80/>3V0@3oool00:@0
/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00T0@4Lg00<0PJV105AQB01DHDP03@1DHDP00`21ZH40
Gg1B05m`DP0B05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=fD`1SMU<05@1SMU<00`21ZH40
GVm<05i_C00C05i_C003086YP@1HIdL0F6M70100F6M700<0PJV104eG?@1=Ecd02`1=Ecd00`21ZH40
>Ch^03Tn;P0503Tn;P05086YP@0T9ad092LM02@W7@21ZH40Y02`h>H10?ooo`00X`2`h>H2086YP@H0
9b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQB003086YP@1OL580Gg1B0180
Gg1B00<0PJV106AgE@1TMeD02P1TMeD_086YP@/0GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40
CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2S0;3P
iP40oooo002R0;3PiP80PJV11P0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800h0
E65800<0PJV105m`DP1OL580201OL58G086YP@/0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40
LHUP0769H0090769H100PJV13P1HIdL00`21ZH40CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0
>Ch^00D0PJV102@W7@0T9ad092LM086YP@2R0;3PiP40oooo002Q0;3PiP80PJV11P0W:b400`21ZH40
@4Lg0417=`080417=`03086YP@1DHDP0E65800X0E6584021ZH4:07:<IP03086YP@1fTFP0MY5X01D0
MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D0080
IW]D2P21ZH4405QWA`03086YP@1=Ecd0CELm00d0CELm00<0PJV103Tn;P0i?Rh01@0i?Rh01@21ZH40
92LM02@W7@0T9ad0PJV10:40/>3V0@3oool00:00/>3V00<0PJV1010D4021ZH401@0W:b400`21ZH40
@4Lg0417=`090417=`04086YP@1DHDP0E65805AQB0T0PJV1101YOel00`21ZH40LXaV07:<IP0C07:<
IP03086YP@1fTFP0MY5X01D0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00E0769
H003086YP@1VNe@0IW]D00/0IW]D2P21ZH4:04eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00D0PJV102@W
7@0T9ad092LM086YP@2P0;3PiP40oooo002O0;3PiP03086YP@0@5100PJV100D09b/Q00<0PJV10417
=`10AcL01`10AcL7086YP@`0JGmO00<0PJV107:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00F07JA
J003086YP@1fT6H0MY1V01H0MY1V00<0PJV10769H01aRF00501aRF000`21ZH40IW]D06IkE00@06Ik
E003086YP@1KK4T0Ffa90080Ffa92021ZH4304eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00@0PJV102@W
7@0T9ad0PJV1X02`h>H10?ooo`00WP2`h>H00`21ZH4041@@086YP@0602L[8@03086YP@10AcL0@4Lg
00<0@4Lg1021ZH400`1GIdl0PJV106UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JA
J01fTFP05P1fTFP00`21ZH40MY1V07J@IP0F07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106Ik
E01VNe@04@1VNe@00`21ZH40Ffa905]/B@0905]/B@H0PJV11P0i?Rh01@21ZH4092LM02@W7@0T9ad0
PJV109l0/>3V0@3oool009h0/>3V00<041@@086YP@0W:b401@0W:b400`21ZH40@4Lg086YP@04086Y
P@D0EfM?00<0PJV106UoG`1YOel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X
01H0MY5X00<0PJV107J@IP1fT6H05P1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D
0140IW]D00<0PJV105]/B@1KK4T03P1KK4T5086YP@<0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2N
0;3PiP40oooo002M0;3PiP03010D4021ZH409b/Q00<09b/Q1@21ZH4905MWC`03086YP@1YOel0JGmO
00l0JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V
01H0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00A06IkE003086YP@1KK4T0Ffa9
00d0Ffa900<0PJV104QD>`18E3/00P18E3/5086YP@<092LM00<0PJV10;3PiP2`h>H0V`2`h>H10?oo
o`00W02`h>H00`0@5100PJV102L[8@04086YP@0303Po=021ZH40EfM?00/0EfM?00<0PJV106UoG`1Y
Oel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X01L0MY5X00<0PJV107J@IP1f
T6H05P1fT6H00`21ZH40LHUP0769H00E0769H003086YP@1VNe@0IW]D0140IW]D00<0PJV105]/B@1K
K4T03P1KK4T00`21ZH40B5@k04QD>`0504QD>`80PJV10`0T9ad00`21ZH40/>3V0;3PiP2J0;3PiP40
oooo002K0;3PiP04010D4021ZH40PJV1086YP@D0>3ld00<0PJV105MWC`1GIdl02@1GIdl00`21ZH40
JGmO06UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40
MY1V07J@IP0G07J@IP03086YP@1aRF00LHUP01D0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40
Ffa905]/B@0=05]/B@03086YP@18E3/0B5@k00L0B5@k0P21ZH400`0T9ad0PJV10;3PiP2K0;3PiP40
oooo002J0;3PiP03010D4021ZH40>3ld00H0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO
06UoG`0?06UoG`03086YP@1bS6H0LXaV01@0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40MY1V
07J@IP0H07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40Ffa9
05]/B@0>05]/B@03086YP@18E3/0B5@k00H0B5@k00<0PJV102/^8`21ZH400P21ZH6K0;3PiP40oooo
002I0;3PiP<0PJV11`0h?c@00`21ZH40EfM?05MWC`0905MWC`03086YP@1YOel0JGmO0100JGmO00<0
PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0
PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900d0Ffa900<0
PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02086YPIX0/>3V0@3oool009P0/>3V00<0PJV1
01TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV1
07:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0PJV1
0769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV1
04QD>`18E3/01P18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V09L0/>3V0@3oool0
09L0/>3V00@0PJV101TN6@0I7QT0PJV11P0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109T0/>3V0@3o
ool009L0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0
Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109P0/>3V0@3o
ool009H0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0
/>3V09D0/>3V0@3oool009D0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C
06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[
;R<0PJV109L0/>3V0@3oool009D0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00D
06IkE003086YP@1KK4T0Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02
02/^8`03086YP@2`h>H0/>3V09@0/>3V0@3oool009@0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@0
0`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H03`1bS6I9
086YP@`0LHUP00<0PJV106IkE01VNe@04`1VNe@00`21ZH40Ffa905]/B@0>05]/B@03086YP@18E3/0
B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP03086YP@0I7QT0PJV100L0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO06UoG`0A06Uo
G`03086YP@1bS6H0LXaV00@0LXaV3021ZH45086PMP03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108>S
M@23XgD06@23XgD00`21ZH40OYe_07jMK`0:07jMKaP0PJV12`1VNe@00`21ZH40Ffa905]/B@0=05]/
B@03086YP@18E3/0B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3P
iP40oooo002C0;3PiP04086YP@0I7QT06AhI086YP@H0>3ld00<0PJV105MWC`1GIdl02`1GIdl00`21
ZH40JGmO06UoG`0706UoGa40PJV14@21X7H00`21ZH40Q:Ah08BTN00H08BTN003086YP@23XgD0Pj=e
01T0Pj=e00<0PJV107jMK`1nWFl05P1nWFl00`21ZH40MI5T07FAI00907FAI100PJV1301KK4T00`21
ZH40B5@k04QD>`0704QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3PiP2`h>H0TP2`h>H10?oo
o`00TP2`h>H01021ZH406AhI01TN6@21ZH4703Po=003086YP@1GIdl0EfM?00P0EfM?3@21ZH4:07VF
L003086YP@21X7H0PJ1f01D0PJ1f00<0PJV108BTN024Y7P06024Y7P00`21ZH40Pj=e08>SM@0I08>S
M@03086YP@1nWFl0OYe_01H0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0206El
D`T0PJV10`1KK4T00`21ZH40B5@k04QD>`0804QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3P
iP2`h>H0T@2`h>H10?ooo`00TP2`h>H00`21ZH406AhI086YP@0703Po=003086YP@1GIdl0EfM?00@0
EfM?1@21ZH4206R0H`03086YP@1iUW00NII`0140NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40
Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40
MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00X0IGaC1P21ZH4804QD>`03086YP@0[;R<0:bhS00<0
:bhS00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00T@2`h>H01021ZH406AhI01TN6@21ZH4703Po=003
086YP@1GIdl0PJV100@0PJV11P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0
PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01L0
OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0PJV100<0
PJV11@18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V0900/>3V0@3oool00900/>3V
00@0PJV101TN6@0I7QT0PJV11@0h?c@5086YP@/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40
PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40
OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40
E6E505AUA@0205AUA@@0PJV100<0B5@k086YP@0[;R<0100[;R<00`21ZH40/>3V0;3PiP2?0;3PiP40
oooo002@0;3PiP03086YP@0I7QT06AhI0080>3ld1021ZH4204]KB@03086YP@1XP6<0J81S00/0J81S
00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T
00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0605AUA@@0PJV1100[;R<00`21ZH40/>3V
0;3PiP2>0;3PiP40oooo002?0;3PiP03086YP@0I7QT06AhI00<0PJV11@1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40MI5T07FA
I00E07FAI003086YP@1UO5<0IGaC00h0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]086Y
P@04086YPI00/>3V0@3oool008l0/>3V00@06AhI086YP@21ZH40PJV11`1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FA
I00D07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0
;@0203M0;@80PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@0302@/9`21ZH40Be]900L0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2f?0;3PiP40oooo002>0;3PiP04086YP@0T;2L092`W086YP@L0Be]900<0PJV1
06R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV1
03M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3PiP04086YP@0T;2L092`W
086YP@P0Be]900<0PJV106R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0
PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0
OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0
E6E500P0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3P
iP04086YP@0T;2L092`W086YP@L0Be]900<0PJV106R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B
07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J
08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?
06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2;
0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1XP6<0301XP6<0
0`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P0
0`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV107FAI01eTF@05@1eTF@0
0`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d0
0`21ZH40/>3V0;3PiP2;0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00C07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2d00`21ZH40/>3V0?mo002:0;3PiP40oooo002;0;3PiP05086YP@0T;2L092`W
02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0<06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1
086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003086YP@23XgD0Pj=e01X0Pj=e00<0PJV1
07jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV1
05AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@0303M0;@04086YP@3oO`00ogl00?mo08T0/>3V0@3o
ool008/0/>3V00@0PJV102@/9`0T;2L0PJV1201;FdT00`21ZH40J81S06R0H`0<06R0H`03086YP@1i
UW00NII`0180NII`00<0PJV1086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003086YP@23
XgD0Pj=e01X0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1U
O5<0IGaC0100IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@0403M0;@03086YP@3o
O`00ogl008T0/>3V0@3oool008X0/>3V00D0PJV102@/9`0T;2L092`W086YP@0804]KB@03086YP@1X
P6<0J81S00/0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086PMP0F086PMP03086YP@24
Y7P0Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0H07jMK`03086YP@1e
TF@0MI5T01H0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g
@2d0=d0]00<0=d0]00<0PJV10?mo003oO`00R@2`h>H10?ooo`00RP2`h>H01021ZH4092`W02@/9`21
ZH4804]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086P
MP0F086PMP03086YP@24Y7P0Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jM
K`0I07jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AU
A@0905AUA@03086YP@0g@2d0=d0]00<0=d0]00@0PJV10?mo003oO`00ogl0R02`h>H10?ooo`00RP2`
h>H01021ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW00
4P1iUW000`21ZH40PJ1f086PMP0G086PMP03086YP@24Y7P0Q:Ah00d0Q:Ah7@21ZH4>08>SM@03086Y
P@1nWFl0OYe_01T0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0@06ElD`03086Y
P@1DIDD0E6E500P0E6E500<0PJV103M0;@0g@2d0100g@2d00`21ZH40ogl00?mo00280;3PiP40oooo
00290;3PiP05086YP@0T;2L092`W02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0=06R0H`03086Y
P@1iUW00NII`0180NII`00<0PJV1086PMP21X7H02`21X7HL086YP@h0S[B400<0PJV108fbP@2=/X40
302=/X4g086YP@`0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086Y
P@0g@2d0=d0]00<0=d0]103oO`270;3PiP40oooo00290;3PiP04086YP@0T;2L092`W086YP@P0Be]9
00<0PJV106R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00907VFL1P0PJV1302</H<00`21ZH40S[B4
08jdQ00K08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV108V]N`29[G/06@29[G/00`21ZH40PJ9a
086RL@0:086RLA40PJV13@1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00@0=d0]
103oO`260;3PiP40oooo00280;3PiP05086YP@0T;2L092`W02@/9`21ZH40201;FdT00`21ZH40J81S
06R0H`0906R0H`l0PJV12P25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401/0S[B4
00<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0I08V]N`03086YP@21XW40PJ9a01H0PJ9a
00<0PJV107:?H@1bSf400P1bSf4:086YP@@0IGaC00<0PJV105AUA@1DIDD02@1DIDD00`21ZH40=d0]
03M0;@0303M0;@@0ogl0QP2`h>H10?ooo`00R02`h>H01021ZH4092`W02@/9`21ZH4804]KB@03086Y
P@1XP6<0J81S0080J81S2021ZH4307NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<0
5`2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV108V]N`29[G/0
6@29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ00`0LXmQ2021ZH4805AUA@03086Y
P@0g@2d0=d0]00<0=d0]1@3oO`250;3PiP40oooo00270;3PiP05086YP@0T;2L092`W02@/9`21ZH40
1P1;FdT7086YP@/0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G08baP`03086Y
P@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03086Y
P@21XW40PJ9a01D0PJ9a00<0PJV107:?H@1bSf40401bSf401021ZH40GG==05ecC@1MLdd6086YP@<0
E6E500<0PJV103M0;@0g@2d00`0g@2d30?mo08H0/>3V0@3oool008L0/>3V00@0PJV102@/9`0T;2L0
PJV10P1;FdT5086YP@80Fg9K00<0PJV107NEL`1gUG<0301gUG<00`21ZH40QJQn08FXOP0C08FXOP03
086YP@2</H<0S;6301P0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0J08fbP@03
086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0?07:?H@03
086YP@1MLdd0GG==00L0GG==1`21ZH4203M0;@@0ogl0Q@2`h>H10?ooo`00QP2`h>H00`21ZH4092`W
02@/9`04086YP@H0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086Y
P@2</H<0S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@03086Y
P@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086Y
P@1MLdd0GG==00T0GG==00@0PJV1045>=P11CSH0@Dhf0P21ZH440?mo08D0/>3V0@3oool008H0/>3V
0`21ZH400`0^>3<0PJV105]bF`0705]bF`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h0
4`25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40
6P2=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40
401bSf400`21ZH40GG==05ecC@0905ecC@03086YP@11CSH0@Dhf00<0@Dhf103oO`250;3PiP40oooo
00260;3PiP04086YP@0^>3<0;SPc086YP@T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn
08FXOP0C08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:1
08fbP@0J08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ
07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH00`11CSH40?mo08@0/>3V
0@3oool008D0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0905]bF`03086YP@1gUG<0MiEc00d0MiEc
00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B4
00<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a
00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0@Dhf
103oO`240;3PiP40oooo00250;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc
07NEL`0>07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B4
08jdQ00L08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a
086RL@0F086RL@03086YP@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf
045>=P03045>=P@0ogl0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K
00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0S;6301L0S;63
00<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0K08fbP@03086YP@29[G/0RJek01X0RJek
00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00T0GG==
00<0PJV1045>=P11CSH01011CSH30?mo08@0/>3V0@3oool008D0/>3V00@0PJV102hh<`0^>3<0PJV1
2@1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<0
602</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/0
6P29[G/00`21ZH40PJ9a086RL@0E086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV105ecC@1MLdd0
2@1MLdd00`21ZH40@Dhf045>=P04045>=P@0ogl0P`2`h>H10?ooo`00Q02`h>H01@21ZH40;SPc02hh
<`0^>3<0PJV100T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086Y
P@2</H<0S;6301P0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086Y
P@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086Y
P@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH00`11CSH40?mo08<0/>3V0@3oool008@0/>3V00D0
PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV108FXOP25Z7h0
4`25Z7h00`21ZH40S;6308baP`0H08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X40
702=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40
401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0@Dhf103oO`230;3PiP40oooo
00240;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086Y
P@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jdQ003086Y
P@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086Y
P@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P04086Y
P@3oO`00ogl00?mo0880/>3V0@3oool008@0/>3V00@0PJV102hh<`0^>3<0PJV12@1KLU/00`21ZH40
MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01@0QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40
S[B408jdQ00K08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40
PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40
@Dhf045>=P04045>=P03086YP@3oO`00ogl008<0/>3V0@3oool008<0/>3V00D0PJV102hh<`0^>3<0
;SPc086YP@0905]bF`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h05025Z7h00`21ZH40
S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=/X400`21ZH40
RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf404@1bSf400`21ZH40
GG==05ecC@0905ecC@03086YP@11CSH0@Dhf00@0@Dhf00@0PJV10?mo003oO`00ogl0PP2`h>H10?oo
o`00P`2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV107NEL`1gUG<03P1gUG<00`21
ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21
ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21
ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH00`11CSH2086Y
P@80ogl0PP2`h>H10?ooo`00P`2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV107NE
L`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV108jd
Q02>]8@0702>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086R
L@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>
=P11CSH01011CSH00`21ZH40ogl00?mo00220;3PiP40oooo00230;3PiP04086YP@0^>3<0;SPc086Y
P@T0Fg9K00<0PJV107NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;63
01P0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek
01/0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==
00X0GG==00<0PJV1045>=P11CSH01011CSH00`21ZH40ogl00?mo00220;3PiP40oooo00220;3PiP05
086YP@0^>3<0;SPc02hh<`21ZH402@1KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0QJQn
01<0QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:1
01`0SK:100<0PJV108V]N`29[G/06`29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ
0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P04086YP@3oO`00ogl0
0?mo0840/>3V0@3oool00880/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0
MiEc00h0MiEc00<0PJV108FXOP25Z7h05025Z7h00`21ZH40S;6308baP`0;08baPeX0PJV13`29[G/0
0`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV105ecC@1MLdd02@1MLdd0
0`21ZH40@Dhf045>=P04045>=P80PJV100<0ogl00;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H01@21
ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV107NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP09
08FXOQT0PJV13@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV1
09:jQ@2B^XD0302B^XDb086YP@X0LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P03
045>=P80PJV1P`2`h>H10?ooo`00PP2`h>H302hh<`03086YP@1KLU/0Fg9K00<0Fg9K8@21ZH4;08nf
RP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09Jo
R`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0707bN
KA40PJV11P1MLdd00`21ZH40@Dhf045>=P04045>=P03086YP@2`h>H0/>3V0840/>3V0@3oool00840
/>3V00<0PJV102hh<`0^>3<01`21ZH4406R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?
]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F
_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1l
WVd04@1lWVd00`21ZH40IGmD06EoE00406EoE0X0PJV10`11CSH2086YPH80/>3V0@3oool00840/>3V
0`21ZH400`0kC480PJV106R4JP0806R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0
502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0
702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd0
4@1lWVd00`21ZH40IGmD06EoE00:06EoE004086YP@17FS`0AeXl04MJ?0D0PJV1PP2`h>H10?ooo`00
P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH80
/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0
AeXl00<0PJV101dT6P2`h>H0P@2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0
IGmD00<0PJV104MJ?017FS`01017FS`00`21ZH407B@J0;3PiP210;3PiP40oooo00210;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?003086YP@0M91X0/>3V0840
/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00<0
AeXl00<0PJV101dT6P2`h>H0P@2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00210;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00
P@2`h>H01@21ZH40>da203]<@P0kC480PJV100P0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0@07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40
/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0
AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40
AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00
P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`00`17FS`2086YPH40
/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0
AeXl0P21ZH600;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40
AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH00/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH600;3PiP40oooo00200;3Pi_<0PJV1
P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH00/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH600;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
6@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH00/>3V0@3oool00800/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
7@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100<0C69100<0PJV1028]7P2`h>H0
P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40
101<HT400`21ZH408RdN0;3PiP200;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
6@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00800/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
7@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo
00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1
P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3@2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0@08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH40/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00840/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100<0C6910P21ZH620;3PiP40oooo
00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1
PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH80/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH620;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1PP2`h>H10?ooo`00P@2`h>H2086YP@80AEa?00<0
PJV1076CMP1aTgH01`1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0
PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0
PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0
PJV106j=G`1^SEl02P1^SEl01021ZH40C69104aR@@1<HT45086YPH80/>3V0@3oool00840/>3V00<0
PJV104eXF@21ZH405021ZH4808ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602L
bIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2H
a8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0101^
SEl:086YP@<0CVQ30P21ZH620;3PiP40oooo00220;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0
PJV1092mTP2@_I801P2@_I8D086YP@/0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;
UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096k
Q@0F096kQ@03086YP@24ZgL0Q:]g00P0Q:]g4021ZH4607BHJ003086YP@1>J4<0CVQ300@0CVQ300<0
PJV10;3PiP2`h>H0P@2`h>H10?ooo`00PP2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100P0N9in00<0
PJV1092mTP2@_I803P2@_I800`21ZH40W<bJ09c<VP0909c<VQT0PJV13@2LbIH00`21ZH40WL^F09g;
UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h03@2Ha8hb086YP@T0R[Ao00<0
PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0304iX@`03086YP@0T<b80/>3V0880/>3V0@3o
ool00880/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0
PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0;0:7BWE/0PJV13P2McI@00`21ZH40UlB<09O4
S00F09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40CVQ304iX
@`0404iX@`80PJV1P`2`h>H10?ooo`00PP2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0
PJV1092mTP2@_I803P2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0
PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01/0WLfD00<0
PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0
PJV104iX@`1>J4<0101>J4<2086YPH<0/>3V0@3oool008<0/>3V00@0PJV104eXF@1=J5T0PJV12@1h
WWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0602Q
dYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06`2M
cI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1d
V6P00`21ZH40CVQ304iX@`0404iX@`80PJV1P`2`h>H10?ooo`00P`2`h>H01@21ZH40CFQI04eXF@1=
J5T0PJV100P0N9in00<0PJV1092mTP2@_I803P2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2Q
dYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2M
cI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1d
V6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V0;3PiP220;3PiP40oooo0023
0;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2L
c9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2Q
dIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:
]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0304iX@`80PJV1Q02`
h>H10?ooo`00P`2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@
_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702R
di`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2G
a8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0M9QX00<0PJV104iX@`1>J4<0101>
J4<2086YPH@0/>3V0@3oool008@0/>3V00@0PJV104eXF@1=J5T0PJV12@1hWWh00`21ZH40T;fB092m
TP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L0:;C
W00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4
S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX
@`0404iX@`80PJV1Q02`h>H10?ooo`00Q02`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100P0N9in00<0
PJV1092mTP2@_I803P2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0
PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0
PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V0;3PiP230;3PiP40oooo00240;3PiP05086YP@1=J5T0
CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0
PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0
PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0
PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V08<0/>3V0@3o
ool008@0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0
PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0
PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0
PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300<0CVQ30P21
ZH650;3PiP40oooo00250;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0PJV1092mTP2@_I803@2@
_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`06`2R
di`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05@2G
a8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0M9QX00<0PJV104iX@`1>J4<0101>
J4<2086YPHD0/>3V0@3oool008D0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0807RNOP03086YP@2@
_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2R
di`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06`2QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2G
a8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>
J4<0CVQ300@0CVQ30P21ZH650;3PiP40oooo00250;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1h
WWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2Q
dYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2M
cI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1d
V6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V08@0/>3V0@3oool008D0/>3V00D0PJV1
04eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2L
c9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2Q
dIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:
]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0Q02`
h>H10?ooo`00Q02`h>H300000080CFQI00<0PJV107RNOP1hWWh01`1hWWh00`21ZH40T;fB092mTP0=
092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L
0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F
09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`03
04iX@`80PJV1QP2`h>H10?ooo`00Q@2`h>H300000080CFQI00<0000007RNOP1hWWh01P1hWWh00`21
ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21
ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21
ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21
ZH40CVQ304iX@`0404iX@`80PJV1QP2`h>H10?ooo`00Q@2`h>H700000003086YP@1hWWh0N9in00D0
N9in00<0PJV1092mTP2@_I80302@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0
XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01X0
WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00T0
M9QX00@0PJV104iX@`1>J4<0CVQ31021ZH670;3PiP40oooo00250;3PiPP000001@21ZH40101hWWh0
0000086YP@000002092mTP030000002@_I80T;fB00P0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21
ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21
ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l03`2:]7l00`21
ZH40M9QX07BHJ00707BHJ0L0PJV10`1CLD/00`21ZH40/>3V0;3PiP250;3PiP40oooo00260;3PiP@0
000000@0DG5P0000000000000000101kYX@8000000T0T;fB00<00000086YP@2Lc9X0502Lc9X00`21
ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21
ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01D0UlB<00<0PJV108ZdO`2:]7l0402:]7l01021
ZH40M9QX07BHJ01dV6P6086YP@<0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP26
0;3PiP40oooo00260;3PiPD0000000<0PJV10000000000000`1kYX@9000000H0PJV10P2@_I850000
01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I
01X0XM6I00<0PJV109g=U02McI@06@2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao
00`0R[Ao2021ZH4807RPK`03086YP@1CLD/0Dg5;00@0Dg5;00<0PJV10;3PiP2`h>H0QP2`h>H10?oo
o`00Q`2`h>H400000003055aH021ZH40000000<0NjJ40P00000207^VQ003086YP@00000000000080
00001P2Ca9P00`21ZH40000000000006000000H0PJV11`2Lc9X01@000000W<bJ09c<VP000000PJV1
01T0XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD
01T0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0208ZdO`X0PJV1102>_8D00`21
ZH40N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0Q`2`h>H10?oo
o`00Q`2`h>H400000003055aH021ZH4000000080NjJ40`00000207^VQ003086YP@2Ca9P0000000<0
00001@2Ca9P30000000309?4V021ZH40Wm:P00@000001@2OdZ04086YP@`000002021ZH440:7BW@03
0000002QdYd0XM:M00H0XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03
086YP@2McI@0WLfD01T0WLfD00<0PJV109O4S02Ga8`02P2Ga8`A086YP@d0S[b500<0PJV107RPK`1h
X6l02@1hX6l00`21ZH40Dg5;05=aB`0405=aB`03086YP@2`h>H0/>3V08L0/>3V0@3oool008L0/>3V
1@0000000`1ALF00PJV107^VQ00207^VQ08000000P1kYX@00`21ZH40TlBH09?4V003000000D0TlBH
0P00000309?4V003086YP@2OdZ00Wm:P00<000001`2OdZ0=000000P0YMVS0P21ZH44000001H0PJV1
3`2Rdi`00`21ZH40XM6I0:7AV@0<0:7AVCL0PJV1302Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086Y
P@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP280;3PiP40oooo
00280;3PiP@0000000<0DG5P086YP@1kYX@00P1kYX@2000000<0NjJ400<0PJV109?4V02Ca9P00P00
000409?4V0800000102Ca9P01021ZH40Wm:P09oBX02OdZ03000000H0Wm:P0P00000609oBX004086Y
P@2UfJ<0YMVS0:GIX`800000202UfJ<6000000H0YMVS00<0PJV10:KJXP2VfZ80302VfZ8N086YP@h0
YMRO00<0PJV10:7DVP2Qe9X06@2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b50100
S[b500<0PJV107RPK`1hX6l0201hX6l00`21ZH40Dg5;05=aB`0405=aB`03086YP@2`h>H0/>3V08P0
/>3V0@3oool008P0/>3V1P00000307^VQ0<000000P1kYX@00`21ZH40TlBH09?4V003000000<0TlBH
0P00000409?4V003086YP@2OdZ00Wm:P0080Wm:P0`00000509oBX0030000002OdZ00Wm:P00H0Wm:P
00@0PJV10:GIX`2UfJ<0YMVS0P0000080:GIX`@000001`2UfJ<00`21ZH40Y]ZR0:KJXP0K0:KJXP03
086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X06@2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03
086YP@2>_8D0S[b500l0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03
086YP@2`h>H0/>3V08T0/>3V0@3oool008T0/>3V1`0000000`1kYX@000000000000407^VQ003086Y
P@2Ca9P0TlBH008000000`2Ca9P2000000@0TlBH00<0PJV109oBX02OdZ000`2OdZ000`000000Wm:P
09oBX00409oBX0030000002OdZ00Wm:P00H0Wm:P00@0PJV10:GIX`2UfJ<0YMVS0P00000:0:GIX`03
0000002UfJ<0YMVS00H0YMVS00<0PJV10:KJXP2VfZ806`2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03
086YP@2Qe9X0XMBJ01P0XMBJ00<0PJV109[;TP2Jbi805P2Jbi800`21ZH40S[b508jlQ@0?08jlQ@03
086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP290;3PiP40
oooo00290;3PiPX00000101kYX@00`21ZH40TlBH09?4V00300000080TlBH0P00000509?4V003086Y
P@2OdZ00Wm:P0180Wm:P00@0PJV10:GIX`2UfJ<0YMVS0`00000C0:GIX`03086YP@2VfZ80Y]ZR01X0
Y]ZR00<0PJV10:GHW`2Uf9l06P2Uf9l00`21ZH40XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B01D0
V/^B00<0PJV108jlQ@2>_8D0402>_8D00`21ZH40N:1_07RPK`0807RPK`03086YP@1CLD/0Dg5;00@0
Dg5;00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00R@2`h>H400000080DG5P1@00000307^VQ004086Y
P@2Ca9P0TlBH09?4V08000000P2Ca9P3000000@0TlBH00<0PJV109oBX02OdZ004P2OdZ001021ZH40
YMVS0:GIX`2UfJ<2000001@0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GH
W`03086YP@2Qe9X0XMBJ01P0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0?08jl
Q@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP2:0;3P
iP40oooo00290;3PiPD0000000<0DG5P0000000000000P1kYX@00`000000NjJ407^VQ00207^VQ003
086YP@2Ca9P0TlBH008000000`2Ca9P7000001D0Wm:P00<0PJV10:GIX`2UfJ<00P00000D0:GIX`03
086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GHW`2Uf9l06P2Uf9l00`21ZH40XMBJ0:7DVP0H0:7DVP03
086YP@2Jbi80V/^B01D0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0807RPK`03
086YP@1CLD/0Dg5;00@0Dg5;00<0PJV10;3PiP2`h>H0RP2`h>H10?ooo`00R@2`h>H800000080NjJ4
0P00000307^VQ003086YP@2Ca9P0TlBH00<000000`2Ca9P<000000X0Wm:P00<0000009oBX02OdZ00
0P2OdZ000`21ZH40000000000002000001@0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO
0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ01P0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b5
08jlQ@0>08jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V
0;3PiP2;0;3PiP40oooo00290;3PiP<0000000<0/>3V0000000000000P00000207^VQ0<000000P1k
YX@01021ZH40TlBH09?4V02Ca9P2000000@0TlBH00<0000009?4V02Ca9P00P2Ca9P7000000L0Wm:P
2`00000<0:GIX`8000001`2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO01X0YMRO
00<0PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500l0S[b5
00<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08/0/>3V
0@3oool008d0/>3V00@0PJV100000000000000000`1kYX@300000080NjJ400<0PJV109?4V02Ca9P0
0P00000409?4V08000000`2Ca9P00`21ZH40Wm:P09oBX00209oBX08000001P2OdZ0:000000h0YMVS
0P0000070:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GHW`2Uf9l06P2Uf9l00`21ZH40XMBJ
0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01D0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_
07RPK`0807RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0S02`h>H10?ooo`00S@2`
h>H400000004086YP@1kYX@0NjJ407^VQ0@0000000<0PJV109?4V00000000`00000309?4V0<00000
0`2Ca9P01021ZH40Wm:P09oBX02OdZ02000000H0Wm:P0P00000709oBX003086YP@2UfJ<0YMVS00`0
YMVS0P0000070:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GHW`2Uf9l06P2Uf9l00`21ZH40
XMBJ0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01D0V/^B00<0PJV108jlQ@2>_8D03P2>_8D00`21ZH40
N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0S02`h>H10?ooo`00
SP2`h>H01021ZH40DG5P055aH021ZH4407^VQ0H0000000<0TlBH000000000000102Ca9P300000080
TlBH00@0PJV109oBX02OdZ00Wm:P0P00000509oBX0<000001`2OdZ000`21ZH40YMVS0:GIX`020:GI
X`030000002UfJ<0YMVS00L0YMVS0P0000080:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GH
W`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0PJV108jl
Q@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0807RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3P
iP2`h>H0S@2`h>H10?ooo`00S`2`h>H2086YP@03055aH021ZH40NjJ400<0NjJ41@0000000`2Ca9P0
00000000000509?4V0D000000`2OdZ03000000D0Wm:P0`00000609oBX003086YP@2UfJ<0YMVS0080
YMVS00<000000:GIX`2UfJ<01`2UfJ<2000000P0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40
YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01P0XMBJ00<0PJV109[;TP2Jbi80502Jbi800`21ZH40
S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00P0N:1_00<0PJV105=aB`1CLD/00P1CLD/2086YPHl0
/>3V0@3oool008l0/>3V00<0PJV105=eH`21ZH400`21ZH4507^VQ003086YP@2Ca9P0TlBH00<00000
1@2Ca9P9000000L0Wm:P1000000409oBX004086YP@2UfJ<0YMVS0:GIX`8000002P2UfJ<2000000L0
YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0
XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0>08jlQ@03086YP@1hX6l0N:1_00P0
N:1_00<0PJV105=aB`21ZH400`21ZH400`1DMU00/>3V0;3PiP2>0;3PiP40oooo002@0;3PiP05086Y
P@1CMF<0DgES086YP@1kZ8H01021ZH4207^VQ003086YP@2Ca9P0TlBH008000001`2Ca9P6000000T0
Wm:P1@00000309oBX0D000002P2UfJ<2000000L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40
YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi80502Jbi800`21ZH40
S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00L0N:1_0`21ZH4405AfD003086YP@2`h>H0/>3V08h0
/>3V0@3oool00900/>3V00@0PJV105=eH`1CMF<0PJV11@1kZ8H5086YP@<00000202Ca9P00`21ZH40
Wm:P09oBX00<09oBX0X000002`2UfJ<2000000L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40
YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi80502Jbi800`21ZH40
S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00<0N:1_1@21ZH4505AfD003086YP@2`h>H0/>3V08l0
/>3V0@3oool00940/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H00`21ZH40U<NK086YP@0200000080
PJV11P2Ca9P00`21ZH40Wm:P09oBX00=09oBX0H000003P2UfJ<2000000L0YMVS00<0PJV10:KJXP2V
fZ806@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2J
bi80502Jbi800`21ZH40S[b508jlQ@0>08jlQ@03086YP@1hX6l0N:1_00@0PJV1101iY7<00`21ZH40
E7I@05AfD00205AfD003086YP@2`h>H0/>3V0900/>3V0@3oool00980/>3V00<0PJV105=eH`21ZH40
1`1kZ8H00`21ZH40U<NK09C7V`0200000080U<NK1@21ZH4209?4V003086YP@2OdZ00Wm:P0140Wm:P
00<0PJV10:GIX`2UfJ<0302UfJ<2000000L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMRO
0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi80502Jbi800`21ZH40S[b5
08jlQ@0:08jlQ@L0PJV11`1iY7<00`21ZH40E7I@05AfD00305AfD003086YP@2`h>H0/>3V0900/>3V
0@3oool00980/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H00`21ZH40U<NK00000002000000H0U<NK
3@21ZH4:09oBX003086YP@2UfJ<0YMVS00`0YMVS0P0000070:GIX`03086YP@2VfZ80Y]ZR01P0Y]ZR
00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0F0:7DVP03086YP@2Jbi80V/^B01@0V/^B
00<0PJV108jlQ@2>_8D00P2>_8D9086YP@<0Skn900<0PJV107VTL`1iY7<0201iY7<00`21ZH40E7I@
05AfD00205AfD003086YP@2`h>H0/>3V0940/>3V0@3oool009<0/>3V00@0PJV105=eH`1CMF<0PJV1
1P1kZ8H01021ZH40U<NK09C7V`00000:09C7V`03086YP@2QeZ@0XMJT00L0XMJT4021ZH490:GIX`80
00001`2UfJ<00`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0PJV10:7DVP2Q
e9X05P2Qe9X00`21ZH40V/^B09[;TP0909[;TQ00PJV1302?_hT00`21ZH40NJAc07VTL`0707VTL`03
086YP@1DMU00E7I@0080E7I@00<0PJV10;3PiP2`h>H0TP2`h>H10?ooo`00U02`h>H00`21ZH40DgES
086YP@0707^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@04@2QeZ@00`21ZH40Y]fW
0:KMY`030:KMY`T0PJV10P0000000`21ZH40YMVS0:GIX`040:GIX`03086YP@2VfZ80Y]ZR01P0Y]ZR
00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0:0:7DVQP0PJV12`2Ld9H00`21ZH40Skn9
08noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V
0;3PiP2C0;3PiP40oooo002D0;3PiP04086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`2Dai/0
2P2Dai/00`21ZH40XMJT0:7FY00A0:7FY003086YP@2VgJL0Y]fW00/0Y]fW0P0000000`2VgJL0PJV1
086YP@18086YP@`0XmVN00<0PJV109c@UP2Ld9H04`2Ld9H00`21ZH40Skn908noR@0>08noR@03086Y
P@1iY7<0NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C0;3PiP40oooo
002E0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7F
Y00A0:7FY003086YP@2VgJL0Y]fW00/0Y]fW0P0000070:KMY`03086YP@2XgjH0Z=nV01P0Z=nV00<0
PJV10:OMX`2WgJ<06@2WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F01@0W=2F00<0
PJV108noR@2?_hT03@2?_hT00`21ZH40NJAc07VTL`0707VTL`03086YP@1DMU00E7I@0080E7I@00<0
PJV10;3PiP2`h>H0U02`h>H10?ooo`00U@2`h>H01021ZH40DgES05=eH`21ZH4707^XQP03086YP@2D
ai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@0402QeZ@00`21ZH40Y]fW0:KMY`0<0:KMY`8000001P2V
gJL00`21ZH40Z=nV0:SOYP0H0:SOYP03086YP@2WgJ<0YmfS01T0YmfS00<0PJV10:?IWP2SfIh05@2S
fIh00`21ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01`1i
Y7<01@21ZH40E7I@05AfD01DMU00PJV109L0/>3V0@3oool009H0/>3V00<0PJV105=eH`21ZH401`1k
Z8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0140XMJT00<0PJV10:KMY`2VgJL0502V
gJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05P2S
fIh00`21ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<01`1i
Y7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V09D0/>3V0@3oool009L0/>3V00<0PJV1
05=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV1
0:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV1
0:?IWP2SfIh05P2SfIh00`21ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV1
07VTL`1iY7<01`1iY7<01@21ZH40E7I@05AfD01DMU00PJV109P0/>3V0@3oool009L0/>3V00@0PJV1
05=eH`1CMF<0PJV11P1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0
PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0
PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900d0Skn900<0
PJV107VTL`1iY7<01`1iY7<01@21ZH40E7I@05AfD01DMU00PJV109T0/>3V0@3oool009P0/>3V00<0
PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0
PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0
PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900h0Skn900<0
PJV107VTL`1iY7<01P1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V09L0/>3V0@3o
ool009T0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0909C7V`03086YP@2QeZ@0
XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0
YmfS01P0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0
Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<01@21ZH40E7I@05AfD01DMU00PJV109X0/>3V0@3o
ool009X0/>3V0P21ZH4707^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@03`2QeZ@0
0`21ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<0
0`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT03P2?_hT0
0`21ZH40NJAc07VTL`0607VTL`03086YP@1DMU00E7I@0080PJV1V`2`h>H10?ooo`00V`2`h>H4086Y
P@D0NjR600<0PJV109C7V`2Dai/02@2Dai/00`21ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW
01<0Y]fW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0G0:OMX`03086YP@2SfIh0XmVN
01D0XmVN00<0PJV109c@UP2Ld9H04P2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc
00L0NJAc1021ZH6L0;3PiP40oooo002L0;3PiP80PJV100<0MZF4086YP@21ZH400P21ZH400`1kZ8H0
PJV109C7V`0;09C7V`03086YP@2QeZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40
Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01H0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40
W=2F09c@UP0A09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01@1iY7<3086YP@80
DWIB00<0PJV10;3PiP2`h>H0VP2`h>H10?ooo`00W@2`h>H2086YP@@0MZF41@21ZH4909C7V`03086Y
P@2QeZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086Y
P@2WgJ<0YmfS01H0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0A09c@UP03086Y
P@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<00P1iY7<5086YP@<0DWIB00<0PJV10;3PiP2`h>H0
V`2`h>H10?ooo`00WP2`h>H2086YP@H0MZF400<0PJV10934V@21ZH400`21ZH4609C7V`03086YP@2Q
eZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2W
gJ<0YmfS01H0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?
_hT0Skn900h0Skn91@21ZH4307FRL`05086YP@1BMU80DWIB059fDP21ZH40WP2`h>H10?ooo`00WP2`
h>H00`21ZH40D7AR086YP@0607JUQ003086YP@2@a9T0T<BI0080T<BI1@21ZH400`2Dai/0PJV10:7F
Y00@0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OM
X`0F0:OMX`03086YP@2SfIh0XmVN01@0XmVN00<0PJV109c@UP2Ld9H04@2Ld9H00`21ZH40Skn908no
R@0908noR@H0PJV11P1eXW<01@21ZH40DWIB059fDP1BMU80PJV109l0/>3V0@3oool009l0/>3V00<0
PJV1051dHP21ZH401@1fYH@00`21ZH40T<BI0934V@070934V@L0PJV1302QeZ@00`21ZH40Y]fW0:KM
Y`0C0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?I
WP0D0:?IWP03086YP@2Ld9H0W=2F0100W=2F00<0PJV108noR@2?_hT00P2?_hT8086YP@<0S;n:00<0
PJV107FRL`1eXW<01P1eXW<01021ZH40DWIB059fDP21ZH6P0;3PiP40oooo002P0;3PiP03086YP@1@
M680PJV100D0MZF400<0PJV10934V@2@a9T02@2@a9T01021ZH40W]JT09kFY02NeZ@9086YP@@0XMJT
00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgJ<0YmfS01D0YmfS
00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0<09c@UPT0PJV12P2<_hX00`21ZH40MJ9c
07FRL`0607FRL`05086YP@1BMU80DWIB059fDP21ZH40X02`h>H10?ooo`00X@2`h>H2086YP@H0MZF4
00<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00:09kFY0l0PJV12`2VgJL00`21ZH40Z=nV
0:SOYP0E0:SOYP03086YP@2WgJ<0YmfS01D0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F
09c@UP0309c@UPX0PJV10`2Jd9P00`21ZH40S;n:08boRP0=08boRP03086YP@1eXW<0MJ9c00D0MJ9c
00D0PJV1059fDP1BMU80DWIB086YP@2Q0;3PiP40oooo002R0;3PiP80PJV11P1fYH@00`21ZH40T<BI
0934V@080934V@03086YP@2NeZ@0W]JT00h0W]JT00<0PJV10:GMZ02UgJP01`2UgJPG086YP@`0Z=nV
00<0PJV10:OMX`2WgJ<05@2WgJ<00`21ZH40XmVN0:?IWP090:?IWQ40PJV13@2Jd9P00`21ZH40S;n:
08boRP0<08boRP03086YP@1eXW<0MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2R0;3PiP40
oooo002S0;3PiP80PJV11P1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT
00<0PJV10:GMZ02UgJP04P2UgJP00`21ZH40Yn2X0:OPZ0090:OPZ300PJV12`2RfZ000`21ZH40V]2H
09[@V00?09[@V003086YP@2<_hX0S;n:00`0S;n:00<0PJV107FRL`1eXW<01@1eXW<01@21ZH40DWIB
059fDP1BMU80PJV10:<0/>3V0@3oool00:@0/>3V0P21ZH4507JUQ003086YP@2@a9T0T<BI00T0T<BI
00<0PJV109kFY02NeZ@03@2NeZ@00`21ZH40YMfX0:GMZ00B0:GMZ003086YP@2Wh:P0Yn2X01@0Yn2X
00<0PJV10:KOY@2VgjD05@2VgjD00`21ZH40X]ZP0:;JX00C0:;JX003086YP@2Jd9P0V]2H0100V]2H
00<0PJV108boRP2<_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80DWIB059fDP21
ZH40Y02`h>H10?ooo`00Y@2`h>H2086YP@D0MZF400<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT
09kFY00=09kFY003086YP@2UgJP0YMfX0180YMfX00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40Y]nU
0:KOY@0E0:KOY@03086YP@2RfZ00X]ZP01<0X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:
08boRP0;08boRP03086YP@1eXW<0MJ9c00D0MJ9c00<0PJV1059fDP1BMU800P1BMU800`21ZH40/>3V
0;3PiP2R0;3PiP40oooo002V0;3PiP80PJV11@1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2N
eZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP04@2UgJP00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2V
gjD0Y]nU01D0Y]nU00<0PJV10:;JX02RfZ004P2RfZ000`21ZH40V]2H09[@V00@09[@V003086YP@2<
_hX0S;n:00/0S;n:00<0PJV107FRL`1eXW<01@1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:D0/>3V
0@3oool00:L0/>3V0P21ZH4507JUQ003086YP@2@a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@0302N
eZ@00`21ZH40YMfX0:GMZ00A0:GMZ003086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD0502V
gjD00`21ZH40X]ZP0:;JX00C0:;JX003086YP@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<_hX02`2<
_hX00`21ZH40MJ9c07FRL`0507FRL`03086YP@1BMU80DWIB0080PJV1YP2`h>H10?ooo`00Z@2`h>H2
086YP@@0MZF400<0PJV10934V@2@a9T01`2@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0
YMfX0140YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0D0:KOY@03086YP@2RfZ00
X]ZP0180X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0
MJ9c00D0MJ9c1@21ZH6W0;3PiP40oooo002Z0;3PiP<0PJV10P1fYH@00`21ZH40T<BI0934V@080934
V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40Yn2X0:OPZ00C0:OP
Z003086YP@2VgjD0Y]nU01@0Y]nU00<0PJV10:;JX02RfZ004P2RfZ000`21ZH40V]2H09[@V00?09[@
V003086YP@2<_hX0S;n:00X0S;n:00<0PJV107FRL`1eXW<0101eXW<3086YP@80CG5@Z@2`h>H10?oo
o`00Z`2`h>H00`21ZH40KI]m086YP@03086YP@X0T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40
YMfX0:GMZ00@0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD0502VgjD00`21ZH40
X]ZP0:;JX00B0:;JX003086YP@2Jd9P0V]2H00h0V]2H00<0PJV108boRP2<_hX02`2<_hX01021ZH40
MJ9c07FRL`1eXW<4086YP@80CG5@00<0PJV10;3PiP2`h>H0Z02`h>H10?ooo`00[02`h>H2086YP@80
KI]m1021ZH480934V@03086YP@2NeZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP03`2UgJP00`21ZH40
Yn2X0:OPZ00D0:OPZ003086YP@2VgjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ004@2RfZ000`21ZH40
V]2H09[@V00?09[@V003086YP@2<_hX0S;n:00X0S;n:1@21ZH4206fJK`04086YP@1=LE00CG5@086Y
PJ/0/>3V0@3oool00:h0/>3V00H0PJV106fKO@1]Vgd0KI]m086YP@26^Y86086YP@80T<BI00<0PJV1
09kFY02NeZ@0302NeZ@00`21ZH40YMfX0:GMZ00@0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV1
0:KOY@2VgjD04`2VgjD00`21ZH40X]ZP0:;JX00A0:;JX003086YP@2Jd9P0V]2H00h0V]2H00<0PJV1
08boRP2<_hX01`2<_hX5086YP@@0KIY_0P21ZH400`1=LE00PJV10;3PiP2/0;3PiP40oooo002_0;3P
iP05086YP@1]Vgd0KI]m06fKO@21ZH401P26^Y87086YP@/0W]JT00<0PJV10:GMZ02UgJP03`2UgJP0
0`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ00402RfZ00
0`21ZH40V]2H09[@V00?09[@V003086YP@2<_hX0S;n:00L0PJV10P24]hH00`21ZH40KIY_06fJK`03
06fJK`04086YP@1=LE00CG5@086YPJh0/>3V0@3oool00;00/>3V00@0PJV106fKO@1]Vgd0KI]m0P21
ZH4808JjTP03086YP@2FcYh0U/jN00P0PJV10`2NeZ@00`21ZH40YMfX0:GMZ00?0:GMZ003086YP@2W
h:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX00A0:;JX003086YP@2J
d9P0V]2H00X0V]2H2021ZH4808BgQP03086YP@1]VVl0KIY_00<0KIY_00@0PJV104eaD021ZH40PJV1
[`2`h>H10?ooo`00/@2`h>H00`21ZH40KI]m06fKO@0206fKO@03086YP@26^Y80Q[ZB00H0Q[ZB00<0
PJV109K>WP2FcYh01`2FcYh9086YP@`0YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KO
Y@0B0:KOY@03086YP@2RfZ00X]ZP0100X]ZP00<0PJV109[@V02Jd9P00P2Jd9P9086YP@<0TlZD00<0
PJV108BgQP24]hH02024]hH2086YP@D0KIY_00<0PJV104eaD021ZH40/@2`h>H10?ooo`00/P2`h>H0
0`21ZH40KI]m06fKO@0206fKO@03086YP@26^Y80Q[ZB00H0Q[ZB00<0PJV109K>WP2FcYh02`2FcYh0
1021ZH40W]RT09kHY02Nf:@9086YP@@0YMfX00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40Y]nU0:KO
Y@0B0:KOY@03086YP@2RfZ00X]ZP00L0X]ZP3P21ZH4;09?:U003086YP@24]hH0Q;N600P0Q;N600<0
PJV106fJK`1]VVl0101]VVl00`21ZH40CG5@086YP@2b0;3PiP40oooo002c0;3PiP80PJV10`1]Vgd0
0`21ZH40Q[ZB08JjTP0608JjTP03086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@02P2Nf:@h
086YP@P0W=FN00<0PJV109?:U02CbY@03@2CbY@00`21ZH40Q;N608BgQP0808BgQP03086YP@1]VVl0
KIY_00@0KIY_0`21ZH6c0;3PiP40oooo002e0;3PiP05086YP@1]Vgd0KI]m06fKO@21ZH402026^Y80
0`21ZH40U/jN09K>WP0:09K>WP03086YP@2Nf:@0W]RT00d0W]RT00<0PJV10:7KY@2QfjD04P2QfjD0
0`21ZH40XMZS0:7JX`0B0:7JX`03086YP@2LeIh0W=FN00l0W=FN00<0PJV109?:U02CbY@03@2CbY@0
0`21ZH40Q;N608BgQP0708BgQP03086YP@1]VVl0KIY_00<0KIY_0`21ZH6e0;3PiP40oooo002f0;3P
iP04086YP@1]Vgd0KI]m06fKO@80PJV11P26^Y800`21ZH40U/jN09K>WP0;09K>WP03086YP@2Nf:@0
W]RT00d0W]RT00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086YP@2LeIh0
W=FN00l0W=FN00<0PJV109?:U02CbY@03@2CbY@00`21ZH40Q;N608BgQP0708BgQP03086YP@1]VVl0
KIY_00<0KIY_0`21ZH6f0;3PiP40oooo002g0;3PiP80PJV10`1]Vgd00`21ZH40Q[ZB08JjTP0408Jj
TP03086YP@2FcYh0U/jN00/0U/jN00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0A0:7K
Y@03086YP@2QfZ<0XMZS0140XMZS00<0PJV109cEWP2LeIh03P2LeIh00`21ZH40TlZD09?:U00=09?:
U003086YP@24]hH0Q;N600H0Q;N60P21ZH4506fJK`80PJV1^02`h>H10?ooo`00^02`h>H6086YP@H0
Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00=09kHY003086YP@2QfjD0XM^U0100
XM^U00<0PJV10:7JX`2QfZ<04@2QfZ<00`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00`0
TlZD00<0PJV108BgQP24]hH01P24]hH00`21ZH40KIY_06fJK`0206fJK`<0PJV1^P2`h>H10?ooo`00
^P2`h>H2086YP@0405j9K`21ZH40PJV1086YP@D0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40
W]RT09kHY00<09kHY003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<04@2QfZ<00`21ZH40
W=FN09cEWP0=09cEWP03086YP@2CbY@0TlZD00`0TlZD00<0PJV108BgQP24]hH01P24]hH00`21ZH40
KIY_086YP@05086YPK/0/>3V0@3oool00;`0/>3V0P21ZH400`1NRFl0PJV1086YP@02086YP@<0Q[ZB
00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00<09kHY003086YP@2QfjD0XM^U0100XM^U
00<0PJV10:7JX`2QfZ<03`2QfZ<00`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00/0TlZD
00<0PJV108BgQP24]hH01@24]hH4086YP@80Gh]V0P21ZH6m0;3PiP40oooo002n0;3PiP80PJV100<0
GXU_086YP@21ZH401@21ZH4<09K>WP03086YP@2Nf:@0W]RT00/0W]RT00<0PJV10:7KY@2QfjD0402Q
fjD00`21ZH40XMZS0:7JX`0?0:7JX`03086YP@2LeIh0W=FN00d0W=FN00<0PJV109?:U02CbY@0302C
bY@01021ZH40Q;N608BgQP24]hH5086YP@<0Gh]V0P21ZH6o0;3PiP40oooo00300;3PiP80PJV100<0
GXU_086YP@21ZH400P1eYh@8086YP@D0U/jN00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7K
Y@0?0:7KY@03086YP@2QfZ<0XMZS00l0XMZS00<0PJV109cEWP2LeIh0302LeIh00`21ZH40TlZD09?:
U00<09?:U0D0PJV100<0MJIk086YP@21ZH400`1ORfH2086YPL40/>3V0@3oool00<80/>3V0P21ZH40
0`1NRFl0PJV107FWQ00207FWQ080PJV11025^i4:086YP@X0W]RT00<0PJV10:7KY@2QfjD03`2QfjD0
0`21ZH40XMZS0:7JX`0?0:7JX`03086YP@2LeIh0W=FN00`0W=FN00<0PJV109?:U02CbY@0102CbY@9
086YP@@0MJIk00@0PJV105n;IP1ORfH0Gh]V0P21ZH730;3PiP40oooo00340;3PiP@0PJV10`1eYh@2
086YP@T0QK^A00<0PJV108k6V02>aYP02021ZH4309kHY003086YP@2QfjD0XM^U00h0XM^U00<0PJV1
0:7JX`2QfZ<03P2QfZ<00`21ZH40W=FN09cEWP0509cEWPl0PJV11@24^HX2086YP@@0MJIk0P21ZH42
05n;IP80PJV1a@2`h>H10?ooo`00aP2`h>H4086YP@<0MJN400<0PJV108FkT@25^i401`25^i400`21
ZH40S/JH08k6V00708k6V2d0PJV11P2>aI<00`21ZH40Q;V:08BiRP0:08BiRP03086YP@1eYW/0MJIk
00<0MJIk00<0PJV105n;IP1ORfH00`21ZH760;3PiP40oooo00390;3PiP<0PJV10P1eYh@2086YP@P0
QK^A00<0PJV108k6V02>aYP02P2>aYP00`21ZH40TlbK09?<V`0=09?<V`03086YP@2BbiT0T/^I00d0
T/^I00<0PJV108k5T`2>aI<02`2>aI<00`21ZH40Q;V:08BiRP0908BiRP80PJV1101eYW/2086YP@04
05n;IP21ZH40PJV1086YPLP0/>3V0@3oool00</0/>3V0`21ZH4207FWQ080PJV11`25^i42086YP@/0
S/JH00<0PJV109?<V`2Cc9/0302Cc9/00`21ZH40T/^I09;;V@0=09;;V@03086YP@2>aI<0S/FC00X0
S/FC00<0PJV108BiRP24^HX02024^HX2086YP@@0MJIk1@21ZH7;0;3PiP40oooo003>0;3PiPH0PJV1
1`25^i400`21ZH40S/JH08k6V00908k6V003086YP@2Cc9/0TlbK00/0TlbK00<0PJV109;;V@2BbiT0
302BbiT00`21ZH40S/FC08k5T`0:08k5T`03086YP@24^HX0Q;V:00P0Q;V:00@0PJV107FVN`1eYW/0
MJIk1P21ZH7=0;3PiP40oooo003A0;3PiPH0PJV11@25^i400`21ZH40S/JH08k6V00808k6V003086Y
P@2Cc9/0TlbK00`0TlbK00<0PJV109;;V@2BbiT02`2BbiT00`21ZH40S/FC08k5T`0908k5T`03086Y
P@24^HX0Q;V:00L0Q;V:2@21ZH7@0;3PiP40oooo003C0;3PiPT0PJV100<0QK^A086YP@2>aYP02@2>
aYP00`21ZH40TlbK09?<V`0;09?<V`03086YP@2BbiT0T/^I00X0T/^I00<0PJV108k5T`2>aI<02@2>
aI<00`21ZH40Q;V:08BiRP0208BiRP`0PJV1d`2`h>H10?ooo`00eP2`h>H5086YP@0306ZJN@21ZH40
PJV100H0PJV11@2>aYP00`21ZH40TlbK09?<V`0:09?<V`03086YP@2BbiT0T/^I00X0T/^I00<0PJV1
08k5T`2>aI<00`2>aI<;086YP@80Ji]e0P21ZH400`1MRFL0PJV1086YP@03086YPMD0/>3V0@3oool0
0=T0/>3V1@21ZH4206ZJN@80PJV10P1cYX4U086YP@<0LjIn0P21ZH4506^KM@80PJV100<0GHUW086Y
P@21ZH400`21ZH7H0;3PiP40oooo003M0;3PiP<0PJV10P1ZVWT2086YP@L0LjJ10P21ZH4907R/Q003
086YP@1hZh<0N:^300P0N:^300<0PJV107>VOP1cYWh01P1cYWh2086YP@@0Ji]e1`21ZH7L0;3PiP40
oooo003P0;3PiPH0PJV11`1cYX42086YP@L0N:b400<0PJV107R[P`1hZh<01`1hZh<00`21ZH40LjIn
07>VOP0507>VOP80PJV100<0Ji]e086YP@21ZH401@21ZH7Q0;3PiP40oooo003T0;3PiPl0PJV1101h
[8@00`21ZH40N:^307R[P`0607R[P`04086YP@1cYWh0LjIn07>VOPL0PJV1j02`h>H10?ooo`00lP2`
h>HB086YPNl0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.603 .774 .563 r
.4405 .46951 m .43989 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.47983 .5 m .48003 .46975 L .4405 .46951 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.48003 .53025 m .47983 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.48003 .46975 m .47983 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.52017 .5 m .51997 .46975 L .48003 .46975 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.47983 .5 m .48003 .53025 L .51997 .53025 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.51997 .53025 m .52017 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.51997 .46975 m .52017 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.52017 .5 m .51997 .53025 L .5595 .53049 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.5595 .53049 m .56011 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.44233 .43937 m .4405 .46951 L .48003 .46975 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.48003 .46975 m .48064 .43983 L .44233 .43937 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.43989 .5 m .4405 .53049 L .48003 .53025 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.48064 .56017 m .48003 .53025 L .4405 .53049 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.48064 .43983 m .48003 .46975 L .51997 .46975 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.48003 .53025 m .48064 .56017 L .51936 .56017 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.51936 .56017 m .51997 .53025 L .48003 .53025 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.51997 .46975 m .51936 .43983 L .48064 .43983 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.51936 .43983 m .51997 .46975 L .5595 .46951 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.56011 .5 m .5595 .46951 L .51997 .46975 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.51997 .53025 m .51936 .56017 L .55767 .56063 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.55767 .56063 m .5595 .53049 L .51997 .53025 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.40219 .46902 m .40117 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.43989 .5 m .4405 .46951 L .40219 .46902 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.4405 .53049 m .43989 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.5595 .46951 m .56011 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.56011 .5 m .5595 .53049 L .59781 .53098 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.59781 .53098 m .59883 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.44539 .40995 m .44233 .43937 L .48064 .43983 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.48064 .43983 m .48166 .41061 L .44539 .40995 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.4405 .53049 m .44233 .56063 L .48064 .56017 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.48166 .58939 m .48064 .56017 L .44233 .56063 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.48166 .41061 m .48064 .43983 L .51936 .43983 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.51936 .43983 m .51834 .41061 L .48166 .41061 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.48064 .56017 m .48166 .58939 L .51834 .58939 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.51834 .58939 m .51936 .56017 L .48064 .56017 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.51834 .41061 m .51936 .43983 L .55767 .43937 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.5595 .46951 m .55767 .43937 L .51936 .43983 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.51936 .56017 m .51834 .58939 L .55461 .59005 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.55461 .59005 m .55767 .56063 L .51936 .56017 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.40525 .43843 m .40219 .46902 L .4405 .46951 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.4405 .46951 m .44233 .43937 L .40525 .43843 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.40117 .5 m .40219 .53098 L .4405 .53049 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.44233 .56063 m .4405 .53049 L .40219 .53098 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.55767 .43937 m .5595 .46951 L .59781 .46902 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.59883 .5 m .59781 .46902 L .5595 .46951 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.5595 .53049 m .55767 .56063 L .59475 .56157 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.59475 .56157 m .59781 .53098 L .5595 .53049 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.41034 .40863 m .40525 .43843 L .44233 .43937 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.44233 .43937 m .44539 .40995 L .41034 .40863 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.40219 .53098 m .40525 .56157 L .44233 .56063 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.44539 .59005 m .44233 .56063 L .40525 .56157 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.44233 .56063 m .44539 .59005 L .48166 .58939 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.55767 .43937 m .55461 .40995 L .51834 .41061 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.55461 .40995 m .55767 .43937 L .59475 .43843 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.59781 .46902 m .59475 .43843 L .55767 .43937 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.55767 .56063 m .55461 .59005 L .58966 .59137 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.58966 .59137 m .59475 .56157 L .55767 .56063 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.48309 .61755 m .48166 .58939 L .44539 .59005 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.48309 .38245 m .48166 .41061 L .51834 .41061 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.51834 .41061 m .51691 .38245 L .48309 .38245 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.48166 .58939 m .48309 .61755 L .51691 .61755 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.51691 .61755 m .51834 .58939 L .48166 .58939 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.51691 .38245 m .51834 .41061 L .55461 .40995 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.51834 .58939 m .51691 .61755 L .55034 .61835 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.55034 .61835 m .55461 .59005 L .51834 .58939 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.44966 .38165 m .44539 .40995 L .48166 .41061 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.48166 .41061 m .48309 .38245 L .44966 .38165 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.36601 .46829 m .36459 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.40117 .5 m .40219 .46902 L .36601 .46829 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.40219 .53098 m .40117 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.59781 .46902 m .59883 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.59883 .5 m .59781 .53098 L .63399 .53171 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.63399 .53171 m .63541 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.3703 .43702 m .36601 .46829 L .40219 .46902 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.40219 .46902 m .40525 .43843 L .3703 .43702 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.36459 .5 m .36601 .53171 L .40219 .53098 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.40525 .56157 m .40219 .53098 L .36601 .53171 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.59475 .43843 m .59781 .46902 L .63399 .46829 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.63541 .5 m .63399 .46829 L .59781 .46902 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.59781 .53098 m .59475 .56157 L .6297 .56298 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.6297 .56298 m .63399 .53171 L .59781 .53098 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.41746 .38006 m .41034 .40863 L .44539 .40995 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.44539 .40995 m .44966 .38165 L .41746 .38006 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.40525 .56157 m .41034 .59137 L .44539 .59005 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.44966 .61835 m .44539 .59005 L .41034 .59137 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.44539 .59005 m .44966 .61835 L .48309 .61755 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.55461 .40995 m .55034 .38165 L .51691 .38245 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.55034 .38165 m .55461 .40995 L .58966 .40863 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.59475 .43843 m .58966 .40863 L .55461 .40995 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.55461 .59005 m .55034 .61835 L .58254 .61994 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.58254 .61994 m .58966 .59137 L .55461 .59005 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.37741 .40665 m .3703 .43702 L .40525 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.40525 .43843 m .41034 .40863 L .37741 .40665 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.36601 .53171 m .3703 .56298 L .40525 .56157 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.41034 .59137 m .40525 .56157 L .3703 .56298 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.58966 .40863 m .59475 .43843 L .6297 .43702 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.63399 .46829 m .6297 .43702 L .59475 .43843 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.59475 .56157 m .58966 .59137 L .62259 .59335 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.62259 .59335 m .6297 .56298 L .59475 .56157 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.45516 .35491 m .44966 .38165 L .48309 .38245 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.48309 .38245 m .48493 .35578 L .45516 .35491 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.48493 .64422 m .48309 .61755 L .44966 .61835 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.48493 .35578 m .48309 .38245 L .51691 .38245 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.51691 .38245 m .51507 .35578 L .48493 .35578 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.48309 .61755 m .48493 .64422 L .51507 .64422 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.51507 .64422 m .51691 .61755 L .48309 .61755 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.51507 .35578 m .51691 .38245 L .55034 .38165 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.51691 .61755 m .51507 .64422 L .54484 .64509 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.54484 .64509 m .55034 .61835 L .51691 .61755 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.38734 .37767 m .37741 .40665 L .41034 .40863 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.41034 .40863 m .41746 .38006 L .38734 .37767 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.3703 .56298 m .37741 .59335 L .41034 .59137 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.41746 .61994 m .41034 .59137 L .37741 .59335 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.41034 .59137 m .41746 .61994 L .44966 .61835 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.58966 .40863 m .58254 .38006 L .55034 .38165 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.58254 .38006 m .58966 .40863 L .62259 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.6297 .43702 m .62259 .40665 L .58966 .40863 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.58966 .59137 m .58254 .61994 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.61266 .62233 m .62259 .59335 L .58966 .59137 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.42658 .35317 m .41746 .38006 L .44966 .38165 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.44966 .38165 m .45516 .35491 L .42658 .35317 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.45516 .64509 m .44966 .61835 L .41746 .61994 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.44966 .61835 m .45516 .64509 L .48493 .64422 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.55034 .38165 m .54484 .35491 L .51507 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.54484 .35491 m .55034 .38165 L .58254 .38006 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.55034 .61835 m .54484 .64509 L .57342 .64683 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.57342 .64683 m .58254 .61994 L .55034 .61835 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.33301 .46731 m .33118 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.36459 .5 m .36601 .46829 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.36601 .53171 m .36459 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.63399 .46829 m .63541 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.63541 .5 m .63399 .53171 L .66699 .53269 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.66699 .53269 m .66882 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.33851 .43514 m .33301 .46731 L .36601 .46829 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.36601 .46829 m .3703 .43702 L .33851 .43514 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.33118 .5 m .33301 .53269 L .36601 .53171 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.3703 .56298 m .36601 .53171 L .33301 .53269 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.6297 .43702 m .63399 .46829 L .66699 .46731 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.66882 .5 m .66699 .46731 L .63399 .46829 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.63399 .53171 m .6297 .56298 L .66149 .56486 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.66149 .56486 m .66699 .53269 L .63399 .53171 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.34762 .40403 m .33851 .43514 L .3703 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.3703 .43702 m .37741 .40665 L .34762 .40403 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.33301 .53269 m .33851 .56486 L .3703 .56298 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.37741 .59335 m .3703 .56298 L .33851 .56486 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.62259 .40665 m .6297 .43702 L .66149 .43514 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.66699 .46731 m .66149 .43514 L .6297 .43702 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.6297 .56298 m .62259 .59335 L .65238 .59597 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.65238 .59597 m .66149 .56486 L .6297 .56298 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.46188 .3302 m .45516 .35491 L .48493 .35578 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.48493 .35578 m .48717 .33107 L .46188 .3302 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.48717 .33107 m .48493 .35578 L .51507 .35578 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.48717 .66893 m .48493 .64422 L .45516 .64509 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.51507 .35578 m .51283 .33107 L .48717 .33107 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.48493 .64422 m .48717 .66893 L .51283 .66893 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.51283 .66893 m .51507 .64422 L .48493 .64422 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.51283 .33107 m .51507 .35578 L .54484 .35491 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.51507 .64422 m .51283 .66893 L .53812 .6698 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.53812 .6698 m .54484 .64509 L .51507 .64422 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.40002 .35058 m .38734 .37767 L .41746 .38006 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.41746 .38006 m .42658 .35317 L .40002 .35058 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.37741 .59335 m .38734 .62233 L .41746 .61994 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.42658 .64683 m .41746 .61994 L .38734 .62233 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.41746 .61994 m .42658 .64683 L .45516 .64509 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.58254 .38006 m .57342 .35317 L .54484 .35491 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.57342 .35317 m .58254 .38006 L .61266 .37767 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.62259 .40665 m .61266 .37767 L .58254 .38006 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.58254 .61994 m .57342 .64683 L .59998 .64942 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.59998 .64942 m .61266 .62233 L .58254 .61994 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.43769 .32847 m .42658 .35317 L .45516 .35491 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.45516 .35491 m .46188 .3302 L .43769 .32847 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.46188 .6698 m .45516 .64509 L .42658 .64683 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.45516 .64509 m .46188 .6698 L .48717 .66893 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.54484 .35491 m .53812 .3302 L .51283 .33107 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.53812 .3302 m .54484 .35491 L .57342 .35317 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.54484 .64509 m .53812 .6698 L .56231 .67153 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.56231 .67153 m .57342 .64683 L .54484 .64509 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.36027 .37452 m .34762 .40403 L .37741 .40665 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.37741 .40665 m .38734 .37767 L .36027 .37452 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.33851 .56486 m .34762 .59597 L .37741 .59335 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.38734 .62233 m .37741 .59335 L .34762 .59597 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.61266 .37767 m .62259 .40665 L .65238 .40403 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.66149 .43514 m .65238 .40403 L .62259 .40665 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.62259 .59335 m .61266 .62233 L .63973 .62548 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.63973 .62548 m .65238 .59597 L .62259 .59335 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.41536 .32591 m .40002 .35058 L .42658 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.42658 .35317 m .43769 .32847 L .41536 .32591 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.38734 .62233 m .40002 .64942 L .42658 .64683 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.43769 .67153 m .42658 .64683 L .40002 .64942 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.42658 .64683 m .43769 .67153 L .46188 .6698 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.57342 .35317 m .56231 .32847 L .53812 .3302 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.56231 .32847 m .57342 .35317 L .59998 .35058 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.61266 .37767 m .59998 .35058 L .57342 .35317 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.57342 .64683 m .56231 .67153 L .58464 .67409 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.58464 .67409 m .59998 .64942 L .57342 .64683 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.37636 .34717 m .36027 .37452 L .38734 .37767 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.38734 .37767 m .40002 .35058 L .37636 .34717 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.34762 .59597 m .36027 .62548 L .38734 .62233 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.40002 .64942 m .38734 .62233 L .36027 .62548 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.59998 .35058 m .61266 .37767 L .63973 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.65238 .40403 m .63973 .37452 L .61266 .37767 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.61266 .62233 m .59998 .64942 L .62364 .65283 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.62364 .65283 m .63973 .62548 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.30442 .46609 m .30218 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.33118 .5 m .33301 .46731 L .30442 .46609 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.33301 .53269 m .33118 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.66699 .46731 m .66882 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.66882 .5 m .66699 .53269 L .69558 .53391 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.69558 .53391 m .69782 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.46978 .30806 m .46188 .3302 L .48717 .33107 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.48717 .33107 m .48982 .30885 L .46978 .30806 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.48982 .30885 m .48717 .33107 L .51283 .33107 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.51283 .33107 m .51018 .30885 L .48982 .30885 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.51018 .30885 m .51283 .33107 L .53812 .3302 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.48982 .69115 m .48717 .66893 L .46188 .6698 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.48717 .66893 m .48982 .69115 L .51018 .69115 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.51018 .69115 m .51283 .66893 L .48717 .66893 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.51283 .66893 m .51018 .69115 L .53022 .69194 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.53022 .69194 m .53812 .6698 L .51283 .66893 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.31108 .43281 m .30442 .46609 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.33301 .46731 m .33851 .43514 L .31108 .43281 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.30218 .5 m .30442 .53391 L .33301 .53269 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.33851 .56486 m .33301 .53269 L .30442 .53391 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.66149 .43514 m .66699 .46731 L .69558 .46609 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.69782 .5 m .69558 .46609 L .66699 .46731 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.66699 .53269 m .66149 .56486 L .68892 .56719 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.68892 .56719 m .69558 .53391 L .66699 .53269 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3371 .56606 m
.33945 .56809 L
s
1 .5 0 r
.65929 .42761 m
.66042 .42871 L
s
.65901 .42667 m
.65955 .42539 L
s
.5 Mabswid
.642 .859 .634 r
.45071 .30652 m .43769 .32847 L .46188 .3302 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.46188 .3302 m .46978 .30806 L .45071 .30652 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.46978 .69194 m .46188 .6698 L .43769 .67153 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.46188 .6698 m .46978 .69194 L .48982 .69115 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.53812 .3302 m .53022 .30806 L .51018 .30885 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.53022 .30806 m .53812 .3302 L .56231 .32847 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.53812 .6698 m .53022 .69194 L .54929 .69348 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.54929 .69348 m .56231 .67153 L .53812 .6698 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.3221 .40078 m .31108 .43281 L .33851 .43514 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.33851 .43514 m .34762 .40403 L .3221 .40078 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.30442 .53391 m .31108 .56719 L .33851 .56486 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.34762 .59597 m .33851 .56486 L .31108 .56719 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.65238 .40403 m .66149 .43514 L .68892 .43281 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.69558 .46609 m .68892 .43281 L .66149 .43514 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.66149 .56486 m .65238 .59597 L .6779 .59922 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.6779 .59922 m .68892 .56719 L .66149 .56486 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.3957 .32256 m .37636 .34717 L .40002 .35058 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.40002 .35058 m .41536 .32591 L .3957 .32256 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.36027 .62548 m .37636 .65283 L .40002 .64942 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.41536 .67409 m .40002 .64942 L .37636 .65283 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.40002 .64942 m .41536 .67409 L .43769 .67153 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.59998 .35058 m .58464 .32591 L .56231 .32847 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.58464 .32591 m .59998 .35058 L .62364 .34717 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.63973 .37452 m .62364 .34717 L .59998 .35058 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.59998 .64942 m .58464 .67409 L .6043 .67744 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.6043 .67744 m .62364 .65283 L .59998 .64942 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.33733 .37063 m .3221 .40078 L .34762 .40403 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.34762 .40403 m .36027 .37452 L .33733 .37063 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.31108 .56719 m .3221 .59922 L .34762 .59597 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.36027 .62548 m .34762 .59597 L .3221 .59922 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.63973 .37452 m .65238 .40403 L .6779 .40078 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.68892 .43281 m .6779 .40078 L .65238 .40403 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.65238 .59597 m .63973 .62548 L .66267 .62937 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.66267 .62937 m .6779 .59922 L .65238 .59597 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43326 .30424 m .41536 .32591 L .43769 .32847 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43769 .32847 m .45071 .30652 L .43326 .30424 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.45071 .69348 m .43769 .67153 L .41536 .67409 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.43769 .67153 m .45071 .69348 L .46978 .69194 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.56231 .32847 m .54929 .30652 L .53022 .30806 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.54929 .30652 m .56231 .32847 L .58464 .32591 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56231 .67153 m .54929 .69348 L .56674 .69576 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56674 .69576 m .58464 .67409 L .56231 .67153 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.35657 .34299 m .33733 .37063 L .36027 .37452 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.36027 .37452 m .37636 .34717 L .35657 .34299 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.3221 .59922 m .33733 .62937 L .36027 .62548 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.37636 .65283 m .36027 .62548 L .33733 .62937 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.62364 .34717 m .63973 .37452 L .66267 .37063 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.6779 .40078 m .66267 .37063 L .63973 .37452 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.63973 .62548 m .62364 .65283 L .64343 .65701 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.64343 .65701 m .66267 .62937 L .63973 .62548 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.47883 .28911 m .46978 .30806 L .48982 .30885 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.48982 .30885 m .49286 .28971 L .47883 .28911 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.49286 .28971 m .48982 .30885 L .51018 .30885 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.51018 .30885 m .50714 .28971 L .49286 .28971 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50714 .28971 m .51018 .30885 L .53022 .30806 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.49286 .71029 m .48982 .69115 L .46978 .69194 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.48982 .69115 m .49286 .71029 L .50714 .71029 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.50714 .71029 m .51018 .69115 L .48982 .69115 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.51018 .69115 m .50714 .71029 L .52117 .71089 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.52117 .71089 m .53022 .69194 L .51018 .69115 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41809 .30128 m .3957 .32256 L .41536 .32591 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41536 .32591 m .43326 .30424 L .41809 .30128 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.37636 .65283 m .3957 .67744 L .41536 .67409 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.43326 .69576 m .41536 .67409 L .3957 .67744 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.41536 .67409 m .43326 .69576 L .45071 .69348 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.58464 .32591 m .56674 .30424 L .54929 .30652 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.56674 .30424 m .58464 .32591 L .6043 .32256 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.62364 .34717 m .6043 .32256 L .58464 .32591 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58464 .67409 m .56674 .69576 L .58191 .69872 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58191 .69872 m .6043 .67744 L .58464 .67409 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46555 .28792 m .45071 .30652 L .46978 .30806 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46978 .30806 m .47883 .28911 L .46555 .28792 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.47883 .71089 m .46978 .69194 L .45071 .69348 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.46978 .69194 m .47883 .71089 L .49286 .71029 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.53022 .30806 m .52117 .28911 L .50714 .28971 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.52117 .28911 m .53022 .30806 L .54929 .30652 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53022 .69194 m .52117 .71089 L .53445 .71208 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53445 .71208 m .54929 .69348 L .53022 .69194 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37952 .31849 m .35657 .34299 L .37636 .34717 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37636 .34717 m .3957 .32256 L .37952 .31849 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.33733 .62937 m .35657 .65701 L .37636 .65283 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.3957 .67744 m .37636 .65283 L .35657 .65701 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.6043 .32256 m .62364 .34717 L .64343 .34299 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.66267 .37063 m .64343 .34299 L .62364 .34717 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62364 .65283 m .6043 .67744 L .62048 .68151 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62048 .68151 m .64343 .65701 L .62364 .65283 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.69558 .46609 m .69782 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.69782 .5 m .69558 .53391 L .71834 .53535 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.71834 .53535 m .72094 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.28166 .46465 m .27906 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.30218 .5 m .30442 .46609 L .28166 .46465 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.30442 .53391 m .30218 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.68892 .43281 m .69558 .46609 L .71834 .46465 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.72094 .5 m .71834 .46465 L .69558 .46609 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.69558 .53391 m .68892 .56719 L .71059 .56996 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.71059 .56996 m .71834 .53535 L .69558 .53391 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.28941 .43004 m .28166 .46465 L .30442 .46609 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.30442 .46609 m .31108 .43281 L .28941 .43004 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.27906 .5 m .28166 .53535 L .30442 .53391 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.31108 .56719 m .30442 .53391 L .28166 .53535 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45351 .28618 m .43326 .30424 L .45071 .30652 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45071 .30652 m .46555 .28792 L .45351 .28618 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.46555 .71208 m .45071 .69348 L .43326 .69576 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.45071 .69348 m .46555 .71208 L .47883 .71089 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.54929 .30652 m .53445 .28792 L .52117 .28911 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.53445 .28792 m .54929 .30652 L .56674 .30424 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54929 .69348 m .53445 .71208 L .54649 .71382 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54649 .71382 m .56674 .69576 L .54929 .69348 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.6779 .40078 m .68892 .43281 L .71059 .43004 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69016 .43265 m
.69072 .43476 L
s
.5 Mabswid
.534 .699 .545 r
.71834 .46465 m .71059 .43004 L .68892 .43281 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.68892 .56719 m .6779 .59922 L .69784 .60305 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.69784 .60305 m .71059 .56996 L .68892 .56719 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.30216 .39695 m .28941 .43004 L .31108 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.31108 .43281 m .3221 .40078 L .30216 .39695 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.28166 .53535 m .28941 .56996 L .31108 .56719 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.3221 .59922 m .31108 .56719 L .28941 .56996 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.66267 .37063 m .6779 .40078 L .69784 .39695 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.71059 .43004 m .69784 .39695 L .6779 .40078 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6779 .59922 m .66267 .62937 L .6803 .63392 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6803 .63392 m .69784 .60305 L .6779 .59922 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3197 .36608 m .30216 .39695 L .3221 .40078 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3221 .40078 m .33733 .37063 L .3197 .36608 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.28941 .56996 m .30216 .60305 L .3221 .59922 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.33733 .62937 m .3221 .59922 L .30216 .60305 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.40584 .29772 m .37952 .31849 L .3957 .32256 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.3957 .32256 m .41809 .30128 L .40584 .29772 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.35657 .65701 m .37952 .68151 L .3957 .67744 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.41809 .69872 m .3957 .67744 L .37952 .68151 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.3957 .67744 m .41809 .69872 L .43326 .69576 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.6043 .32256 m .58191 .30128 L .56674 .30424 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.58191 .30128 m .6043 .32256 L .62048 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.64343 .34299 m .62048 .31849 L .6043 .32256 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.6043 .67744 m .58191 .69872 L .59416 .70228 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.59416 .70228 m .62048 .68151 L .6043 .67744 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.44321 .28394 m .41809 .30128 L .43326 .30424 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.43326 .30424 m .45351 .28618 L .44321 .28394 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.45351 .71382 m .43326 .69576 L .41809 .69872 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.43326 .69576 m .45351 .71382 L .46555 .71208 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.56674 .30424 m .54649 .28618 L .53445 .28792 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.54649 .28618 m .56674 .30424 L .58191 .30128 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.56674 .69576 m .54649 .71382 L .55679 .71606 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.55679 .71606 m .58191 .69872 L .56674 .69576 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.64343 .34299 m .66267 .37063 L .6803 .36608 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.69784 .39695 m .6803 .36608 L .66267 .37063 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.66267 .62937 m .64343 .65701 L .65832 .66186 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.65832 .66186 m .6803 .63392 L .66267 .62937 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.34168 .33814 m .3197 .36608 L .33733 .37063 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.33733 .37063 m .35657 .34299 L .34168 .33814 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.30216 .60305 m .3197 .63392 L .33733 .62937 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.35657 .65701 m .33733 .62937 L .3197 .63392 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.48894 .274 m .47883 .28911 L .49286 .28971 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.49286 .28971 m .49626 .27434 L .48894 .274 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.49626 .27434 m .49286 .28971 L .50714 .28971 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.50714 .28971 m .50374 .27434 L .49626 .27434 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50374 .27434 m .50714 .28971 L .52117 .28911 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.49626 .72566 m .49286 .71029 L .47883 .71089 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.49286 .71029 m .49626 .72566 L .50374 .72566 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.50374 .72566 m .50714 .71029 L .49286 .71029 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.50714 .71029 m .50374 .72566 L .51106 .726 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.51106 .726 m .52117 .71089 L .50714 .71029 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.48205 .27334 m .46555 .28792 L .47883 .28911 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.47883 .28911 m .48894 .274 L .48205 .27334 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.48894 .726 m .47883 .71089 L .46555 .71208 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.47883 .71089 m .48894 .726 L .49626 .72566 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.52117 .28911 m .51106 .274 L .50374 .27434 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.51106 .274 m .52117 .28911 L .53445 .28792 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.52117 .71089 m .51106 .726 L .51795 .72666 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.51795 .72666 m .53445 .71208 L .52117 .71089 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.62048 .31849 m .64343 .34299 L .65832 .33814 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.6803 .36608 m .65832 .33814 L .64343 .34299 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.64343 .65701 m .62048 .68151 L .63233 .6862 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.63233 .6862 m .65832 .66186 L .64343 .65701 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.36767 .3138 m .34168 .33814 L .35657 .34299 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.35657 .34299 m .37952 .31849 L .36767 .3138 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.3197 .63392 m .34168 .66186 L .35657 .65701 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.37952 .68151 m .35657 .65701 L .34168 .66186 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.47588 .27237 m .45351 .28618 L .46555 .28792 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.46555 .28792 m .48205 .27334 L .47588 .27237 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.48205 .72666 m .46555 .71208 L .45351 .71382 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.46555 .71208 m .48205 .72666 L .48894 .726 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.53445 .28792 m .51795 .27334 L .51106 .274 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.51795 .27334 m .53445 .28792 L .54649 .28618 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.53445 .71208 m .51795 .72666 L .52412 .72763 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.52412 .72763 m .54649 .71382 L .53445 .71208 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.43508 .28127 m .40584 .29772 L .41809 .30128 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.41809 .30128 m .44321 .28394 L .43508 .28127 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.37952 .68151 m .40584 .70228 L .41809 .69872 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.44321 .71606 m .41809 .69872 L .40584 .70228 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.41809 .69872 m .44321 .71606 L .45351 .71382 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.58191 .30128 m .55679 .28394 L .54649 .28618 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.55679 .28394 m .58191 .30128 L .59416 .29772 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.62048 .31849 m .59416 .29772 L .58191 .30128 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.58191 .69872 m .55679 .71606 L .56492 .71873 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.56492 .71873 m .59416 .70228 L .58191 .69872 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.59416 .29772 m .62048 .31849 L .63233 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.65832 .33814 m .63233 .3138 L .62048 .31849 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.62048 .68151 m .59416 .70228 L .60284 .70634 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.60284 .70634 m .63233 .6862 L .62048 .68151 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.39716 .29366 m .36767 .3138 L .37952 .31849 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.37952 .31849 m .40584 .29772 L .39716 .29366 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.34168 .66186 m .36767 .6862 L .37952 .68151 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.40584 .70228 m .37952 .68151 L .36767 .6862 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.47068 .27114 m .44321 .28394 L .45351 .28618 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.45351 .28618 m .47588 .27237 L .47068 .27114 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.47588 .72763 m .45351 .71382 L .44321 .71606 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.45351 .71382 m .47588 .72763 L .48205 .72666 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.54649 .28618 m .52412 .27237 L .51795 .27334 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.52412 .27237 m .54649 .28618 L .55679 .28394 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.54649 .71382 m .52412 .72763 L .52932 .72886 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.52932 .72886 m .55679 .71606 L .54649 .71382 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30335 .60584 m
.30342 .60527 L
s
.30335 .60584 m
.30405 .60637 L
s
.5 Mabswid
.416 .541 .437 r
.71834 .46465 m .72094 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.72094 .5 m .71834 .53535 L .73364 .53701 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.73364 .53701 m .73655 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.26636 .46299 m .26345 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.27906 .5 m .28166 .46465 L .26636 .46299 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.28166 .53535 m .27906 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.71059 .43004 m .71834 .46465 L .73364 .46299 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.73655 .5 m .73364 .46299 L .71834 .46465 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.71834 .53535 m .71059 .56996 L .72498 .5731 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.72498 .5731 m .73364 .53701 L .71834 .53535 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.27502 .4269 m .26636 .46299 L .28166 .46465 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.28166 .46465 m .28941 .43004 L .27502 .4269 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.26345 .5 m .26636 .53701 L .28166 .53535 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.28941 .56996 m .28166 .53535 L .26636 .53701 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.69784 .39695 m .71059 .43004 L .72498 .4269 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.73364 .46299 m .72498 .4269 L .71059 .43004 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71059 .56996 m .69784 .60305 L .71077 .60739 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71077 .60739 m .72498 .5731 L .71059 .56996 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28923 .39261 m .27502 .4269 L .28941 .43004 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28941 .43004 m .30216 .39695 L .28923 .39261 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.26636 .53701 m .27502 .5731 L .28941 .56996 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.30216 .60305 m .28941 .56996 L .27502 .5731 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.6803 .36608 m .69784 .39695 L .71077 .39261 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.72498 .4269 m .71077 .39261 L .69784 .39695 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69784 .60305 m .6803 .63392 L .69138 .63904 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69138 .63904 m .71077 .60739 L .69784 .60305 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30862 .36096 m .28923 .39261 L .30216 .39695 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30216 .39695 m .3197 .36608 L .30862 .36096 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.27502 .5731 m .28923 .60739 L .30216 .60305 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.3197 .63392 m .30216 .60305 L .28923 .60739 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.59416 .29772 m .56492 .28127 L .55679 .28394 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.56492 .28127 m .59416 .29772 L .60284 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.63233 .3138 m .60284 .29366 L .59416 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.42953 .27826 m .39716 .29366 L .40584 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.40584 .29772 m .43508 .28127 L .42953 .27826 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.59416 .70228 m .56492 .71873 L .57047 .72174 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.57047 .72174 m .60284 .70634 L .59416 .70228 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.36767 .6862 m .39716 .70634 L .40584 .70228 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.43508 .71873 m .40584 .70228 L .39716 .70634 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.40584 .70228 m .43508 .71873 L .44321 .71606 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.46668 .26969 m .43508 .28127 L .44321 .28394 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.44321 .28394 m .47068 .27114 L .46668 .26969 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.47068 .72886 m .44321 .71606 L .43508 .71873 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.44321 .71606 m .47068 .72886 L .47588 .72763 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.55679 .28394 m .52932 .27114 L .52412 .27237 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.52932 .27114 m .55679 .28394 L .56492 .28127 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.55679 .71606 m .52932 .72886 L .53332 .73031 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.53332 .73031 m .56492 .71873 L .55679 .71606 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.65832 .33814 m .6803 .36608 L .69138 .36096 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.71077 .39261 m .69138 .36096 L .6803 .36608 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.6803 .63392 m .65832 .66186 L .66727 .66727 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.66727 .66727 m .69138 .63904 L .6803 .63392 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.33273 .33273 m .30862 .36096 L .3197 .36608 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.3197 .36608 m .34168 .33814 L .33273 .33273 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.28923 .60739 m .30862 .63904 L .3197 .63392 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.34168 .66186 m .3197 .63392 L .30862 .63904 L p F P
.505 .664 .505 r
s
.554 .773 .585 r
.49626 .27434 m .5 .26345 L .48894 .274 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50374 .27434 m .5 .26345 L .49626 .27434 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.51106 .274 m .5 .26345 L .50374 .27434 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49626 .72566 L .48894 .726 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50374 .72566 L .49626 .72566 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .51106 .726 L .50374 .72566 L closepath p F P
.505 .664 .505 r
s
.551 .769 .581 r
.48894 .274 m .5 .26345 L .48205 .27334 L closepath p F P
.505 .664 .505 r
s
.554 .773 .586 r
.51795 .27334 m .5 .26345 L .51106 .274 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48894 .726 L .48205 .72666 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .51795 .72666 L .51106 .726 L closepath p F P
.505 .664 .505 r
s
.527 .725 .572 r
.63233 .3138 m .65832 .33814 L .66727 .33273 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.69138 .36096 m .66727 .33273 L .65832 .33814 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.65832 .66186 m .63233 .6862 L .63904 .69138 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.63904 .69138 m .66727 .66727 L .65832 .66186 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.36096 .30862 m .33273 .33273 L .34168 .33814 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.34168 .33814 m .36767 .3138 L .36096 .30862 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.30862 .63904 m .33273 .66727 L .34168 .66186 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.36767 .6862 m .34168 .66186 L .33273 .66727 L p F P
.505 .664 .505 r
s
.546 .763 .576 r
.48205 .27334 m .5 .26345 L .47588 .27237 L closepath p F P
.505 .664 .505 r
s
.198 .204 .155 r
.5 .73655 m .48205 .72666 L .47588 .72763 L closepath p F P
.505 .664 .505 r
s
.55 .768 .584 r
.52412 .27237 m .5 .26345 L .51795 .27334 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .52412 .72763 L .51795 .72666 L closepath p F P
.505 .664 .505 r
s
.578 .8 .612 r
.56492 .28127 m .53332 .26969 L .52932 .27114 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.53332 .26969 m .56492 .28127 L .57047 .27826 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.60284 .29366 m .57047 .27826 L .56492 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.46407 .26807 m .42953 .27826 L .43508 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.43508 .28127 m .46668 .26969 L .46407 .26807 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.56492 .71873 m .53332 .73031 L .53593 .73193 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.53593 .73193 m .57047 .72174 L .56492 .71873 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.39716 .70634 m .42953 .72174 L .43508 .71873 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.46668 .73031 m .43508 .71873 L .42953 .72174 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.43508 .71873 m .46668 .73031 L .47068 .72886 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.60284 .29366 m .63233 .3138 L .63904 .30862 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.66727 .33273 m .63904 .30862 L .63233 .3138 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.63233 .6862 m .60284 .70634 L .60739 .71077 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.60739 .71077 m .63904 .69138 L .63233 .6862 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.39261 .28923 m .36096 .30862 L .36767 .3138 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.36767 .3138 m .39716 .29366 L .39261 .28923 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.33273 .66727 m .36096 .69138 L .36767 .6862 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.39716 .70634 m .36767 .6862 L .36096 .69138 L p F P
.505 .664 .505 r
s
.539 .755 .57 r
.47588 .27237 m .5 .26345 L .47068 .27114 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .47588 .72763 L .47068 .72886 L closepath p F P
.505 .664 .505 r
s
.545 .762 .58 r
.52932 .27114 m .5 .26345 L .52412 .27237 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .52932 .72886 L .52412 .72763 L closepath p F P
.505 .664 .505 r
s
.535 .747 .581 r
.57047 .27826 m .60284 .29366 L .60739 .28923 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.63904 .30862 m .60739 .28923 L .60284 .29366 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.60284 .70634 m .57047 .72174 L .5731 .72498 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.5731 .72498 m .60739 .71077 L .60284 .70634 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.4269 .27502 m .39261 .28923 L .39716 .29366 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.39716 .29366 m .42953 .27826 L .4269 .27502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.36096 .69138 m .39261 .71077 L .39716 .70634 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42953 .72174 m .39716 .70634 L .39261 .71077 L p F P
.505 .664 .505 r
s
.531 .745 .563 r
.47068 .27114 m .5 .26345 L .46668 .26969 L closepath p F P
.505 .664 .505 r
s
.537 .753 .575 r
.53332 .26969 m .5 .26345 L .52932 .27114 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .47068 .72886 L .46668 .73031 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .53332 .73031 L .52932 .72886 L closepath p F P
.505 .664 .505 r
s
.557 .776 .596 r
.57047 .27826 m .53593 .26807 L .53332 .26969 L p F P
.505 .664 .505 r
s
.53 .744 .575 r
.53593 .26807 m .57047 .27826 L .5731 .27502 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.60739 .28923 m .5731 .27502 L .57047 .27826 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57047 .72174 m .53593 .73193 L .53701 .73364 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.53701 .73364 m .5731 .72498 L .57047 .72174 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.46299 .26636 m .4269 .27502 L .42953 .27826 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.42953 .27826 m .46407 .26807 L .46299 .26636 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.39261 .71077 m .4269 .72498 L .42953 .72174 L p F P
.505 .664 .505 r
s
.187 .194 .147 r
.46407 .73193 m .42953 .72174 L .4269 .72498 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.42953 .72174 m .46407 .73193 L .46668 .73031 L p F P
.505 .664 .505 r
s
.529 .743 .568 r
.53593 .26807 m .5 .26345 L .53332 .26969 L closepath p F P
.505 .664 .505 r
s
.522 .734 .555 r
.46668 .26969 m .5 .26345 L .46407 .26807 L closepath p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .53593 .73193 L .53332 .73031 L closepath p F P
.505 .664 .505 r
s
.183 .191 .145 r
.5 .73655 m .46668 .73031 L .46407 .73193 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28435 .59675 m
.28499 .59716 L
s
1 .5 0 r
.72644 .43301 m
.72781 .43651 L
s
.72331 .42211 m
.72374 .42392 L
s
0 0 0 r
.28145 .59163 m
.28435 .59675 L
s
1 .5 0 r
.72781 .43651 m
.72973 .43983 L
s
.72291 .41817 m
.72331 .42211 L
s
.5 Mabswid
.519 .731 .56 r
.53701 .26636 m .5 .26345 L .53593 .26807 L closepath p F P
.505 .664 .505 r
s
.53 .744 .575 r
.5731 .27502 m .53701 .26636 L .53593 .26807 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .53701 .73364 L .53593 .73193 L closepath p F P
.505 .664 .505 r
s
.512 .722 .546 r
.46407 .26807 m .5 .26345 L .46299 .26636 L closepath p F P
.505 .664 .505 r
s
.187 .194 .147 r
.4269 .72498 m .46299 .73364 L .46407 .73193 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.5 .73655 m .46407 .73193 L .46299 .73364 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27417 .57185 m
.28145 .59163 L
s
1 .5 0 r
.72973 .43983 m
.73109 .44138 L
s
.72291 .41817 m
.72307 .41603 L
s
.5 Mabswid
.166 .175 .133 r
.5 .73655 m .53647 .73538 L .53701 .73364 L closepath p F P
.505 .664 .505 r
s
.159 .169 .128 r
.5 .73655 m .5343 .73707 L .53647 .73538 L closepath p F P
.505 .664 .505 r
s
.152 .162 .124 r
.5 .73655 m .53058 .73863 L .5343 .73707 L closepath p F P
.505 .664 .505 r
s
.147 .157 .119 r
.5 .73655 m .52543 .73998 L .53058 .73863 L closepath p F P
.505 .664 .505 r
s
.142 .152 .116 r
.5 .73655 m .51909 .74106 L .52543 .73998 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .51184 .74182 L .51909 .74106 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50401 .7422 L .51184 .74182 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49599 .7422 L .50401 .7422 L closepath p F P
.505 .664 .505 r
s
.137 .148 .112 r
.5 .73655 m .48816 .74182 L .49599 .7422 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48091 .74106 L .48816 .74182 L closepath p F P
.505 .664 .505 r
s
.144 .154 .117 r
.5 .73655 m .47457 .73998 L .48091 .74106 L closepath p F P
.505 .664 .505 r
s
.149 .159 .121 r
.5 .73655 m .46942 .73863 L .47457 .73998 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .4657 .73707 L .46942 .73863 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .46353 .73538 L .4657 .73707 L closepath p F P
.505 .664 .505 r
s
.501 .709 .537 r
.46299 .26636 m .5 .26345 L .46353 .26462 L closepath p F P
.505 .664 .505 r
s
.477 .676 .506 r
.46353 .26462 m .42744 .27169 L .4269 .27502 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.4269 .27502 m .46299 .26636 L .46353 .26462 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.42744 .27169 m .39265 .28461 L .39261 .28923 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.39261 .28923 m .4269 .27502 L .42744 .27169 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.39265 .28461 m .36011 .30316 L .36096 .30862 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.36096 .30862 m .39261 .28923 L .39265 .28461 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.36011 .30316 m .33073 .32695 L .33273 .33273 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.33273 .33273 m .36096 .30862 L .36011 .30316 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.33073 .32695 m .30537 .35543 L .30862 .36096 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.30862 .36096 m .33273 .33273 L .33073 .32695 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.30537 .35543 m .28477 .38789 L .28923 .39261 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.28923 .39261 m .30862 .36096 L .30537 .35543 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.28477 .38789 m .26959 .42346 L .27502 .4269 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.27502 .4269 m .28923 .39261 L .28477 .38789 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26959 .42346 m .26028 .46118 L .26636 .46299 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26636 .46299 m .27502 .4269 L .26959 .42346 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26028 .46118 m .25714 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26345 .5 m .26636 .46299 L .26028 .46118 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.25714 .5 m .26028 .53882 L .26636 .53701 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.26636 .53701 m .26345 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.26028 .53882 m .26959 .57654 L .27502 .5731 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.27502 .5731 m .26636 .53701 L .26028 .53882 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.26959 .57654 m .28477 .61211 L .28923 .60739 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28145 .59163 m
.28196 .59598 L
s
.5 Mabswid
.158 .178 .131 r
.28923 .60739 m .27502 .5731 L .26959 .57654 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.28477 .61211 m .30537 .64457 L .30862 .63904 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.30862 .63904 m .28923 .60739 L .28477 .61211 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.30537 .64457 m .33073 .67305 L .33273 .66727 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.33273 .66727 m .30862 .63904 L .30537 .64457 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.33073 .67305 m .36011 .69684 L .36096 .69138 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.36096 .69138 m .33273 .66727 L .33073 .67305 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.36011 .69684 m .39265 .71539 L .39261 .71077 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.39261 .71077 m .36096 .69138 L .36011 .69684 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.39265 .71539 m .42744 .72831 L .4269 .72498 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.4269 .72498 m .39261 .71077 L .39265 .71539 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.42744 .72831 m .46353 .73538 L .46299 .73364 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.46299 .73364 m .4269 .72498 L .42744 .72831 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .46299 .73364 L .46353 .73538 L closepath p F P
.505 .664 .505 r
s
.508 .719 .551 r
.53647 .26462 m .5 .26345 L .53701 .26636 L closepath p F P
.505 .664 .505 r
s
.497 .705 .541 r
.5343 .26293 m .5 .26345 L .53647 .26462 L closepath p F P
.505 .664 .505 r
s
.49 .696 .528 r
.46353 .26462 m .5 .26345 L .4657 .26293 L closepath p F P
.505 .664 .505 r
s
.486 .692 .531 r
.53058 .26137 m .5 .26345 L .5343 .26293 L closepath p F P
.505 .664 .505 r
s
.48 .683 .519 r
.4657 .26293 m .5 .26345 L .46942 .26137 L closepath p F P
.505 .664 .505 r
s
.476 .679 .522 r
.52543 .26002 m .5 .26345 L .53058 .26137 L closepath p F P
.505 .664 .505 r
s
.155 .165 .126 r
.5731 .72498 m .53701 .73364 L .53647 .73538 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.53701 .26636 m .5731 .27502 L .57256 .27169 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.57256 .27169 m .53647 .26462 L .53701 .26636 L p F P
.505 .664 .505 r
s
.47 .672 .511 r
.46942 .26137 m .5 .26345 L .47457 .26002 L closepath p F P
.505 .664 .505 r
s
.467 .668 .513 r
.51909 .25894 m .5 .26345 L .52543 .26002 L closepath p F P
.505 .664 .505 r
s
.46 .659 .507 r
.51184 .25818 m .5 .26345 L .51909 .25894 L closepath p F P
.505 .664 .505 r
s
.462 .662 .505 r
.47457 .26002 m .5 .26345 L .48091 .25894 L closepath p F P
.505 .664 .505 r
s
.455 .653 .502 r
.50401 .2578 m .5 .26345 L .51184 .25818 L closepath p F P
.505 .664 .505 r
s
.457 .655 .501 r
.48091 .25894 m .5 .26345 L .48816 .25818 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49599 .2578 m .5 .26345 L .50401 .2578 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.48816 .25818 m .5 .26345 L .49599 .2578 L closepath p F P
.505 .664 .505 r
s
.145 .155 .118 r
.60739 .71077 m .5731 .72498 L .57256 .72831 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.53647 .73538 m .57256 .72831 L .5731 .72498 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.5731 .27502 m .60739 .28923 L .60735 .28461 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.60735 .28461 m .57256 .27169 L .5731 .27502 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.63904 .69138 m .60739 .71077 L .60735 .71539 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.57256 .72831 m .60735 .71539 L .60739 .71077 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.60739 .28923 m .63904 .30862 L .63989 .30316 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.63989 .30316 m .60735 .28461 L .60739 .28923 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.66727 .66727 m .63904 .69138 L .63989 .69684 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.60735 .71539 m .63989 .69684 L .63904 .69138 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.63904 .30862 m .66727 .33273 L .66927 .32695 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.66927 .32695 m .63989 .30316 L .63904 .30862 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.69138 .63904 m .66727 .66727 L .66927 .67305 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.63989 .69684 m .66927 .67305 L .66727 .66727 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.66727 .33273 m .69138 .36096 L .69463 .35543 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.69463 .35543 m .66927 .32695 L .66727 .33273 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.69138 .36096 m .71077 .39261 L .71523 .38789 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.71523 .38789 m .69463 .35543 L .69138 .36096 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.71077 .60739 m .69138 .63904 L .69463 .64457 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.66927 .67305 m .69463 .64457 L .69138 .63904 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.72498 .5731 m .71077 .60739 L .71523 .61211 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.69463 .64457 m .71523 .61211 L .71077 .60739 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.71077 .39261 m .72498 .4269 L .73041 .42346 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.73041 .42346 m .71523 .38789 L .71077 .39261 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.72498 .4269 m .73364 .46299 L .73972 .46118 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.73972 .46118 m .73041 .42346 L .72498 .4269 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73364 .53701 m .72498 .5731 L .73041 .57654 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.71523 .61211 m .73041 .57654 L .72498 .5731 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.73364 .46299 m .73655 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.74286 .5 m .73972 .46118 L .73364 .46299 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73655 .5 m .73364 .53701 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73041 .57654 m .73972 .53882 L .73364 .53701 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73972 .53882 m .74286 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.43126 .73159 m .4657 .73707 L .46353 .73538 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.46353 .73538 m .42744 .72831 L .43126 .73159 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.42744 .27169 m .46353 .26462 L .4657 .26293 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.57256 .72831 m .53647 .73538 L .5343 .73707 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.53647 .26462 m .57256 .27169 L .56874 .26841 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.56874 .26841 m .5343 .26293 L .53647 .26462 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27925 .59924 m
.2793 .59928 L
s
.5 Mabswid
.121 .133 .101 r
.43832 .73466 m .46942 .73863 L .4657 .73707 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.4657 .73707 m .43126 .73159 L .43832 .73466 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.5343 .73707 m .56874 .73159 L .57256 .72831 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.56874 .73159 m .5343 .73707 L .53058 .73863 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.43126 .26841 m .4657 .26293 L .46942 .26137 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.4657 .26293 m .43126 .26841 L .42744 .27169 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.5343 .26293 m .56874 .26841 L .56168 .26534 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.56168 .26534 m .53058 .26137 L .5343 .26293 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.39759 .72 m .43126 .73159 L .42744 .72831 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.42744 .72831 m .39265 .71539 L .39759 .72 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.39265 .28461 m .42744 .27169 L .43126 .26841 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.60735 .71539 m .57256 .72831 L .56874 .73159 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.57256 .27169 m .60735 .28461 L .60241 .28 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.60241 .28 m .56874 .26841 L .57256 .27169 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2765 .59402 m
.27925 .59924 L
s
.26885 .57379 m
.26901 .5742 L
s
.27227 .58283 m
.2765 .59402 L
s
.5 Mabswid
.099 .113 .086 r
.44839 .73736 m .47457 .73998 L .46942 .73863 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.46942 .73863 m .43832 .73466 L .44839 .73736 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.53058 .73863 m .56168 .73466 L .56874 .73159 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.56168 .73466 m .53058 .73863 L .52543 .73998 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.43832 .26534 m .46942 .26137 L .47457 .26002 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.46942 .26137 m .43832 .26534 L .43126 .26841 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.53058 .26137 m .56168 .26534 L .55161 .26264 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.55161 .26264 m .52543 .26002 L .53058 .26137 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.36568 .70237 m .39759 .72 L .39265 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.39265 .71539 m .36011 .69684 L .36568 .70237 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.43126 .26841 m .39759 .28 L .39265 .28461 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.36011 .30316 m .39265 .28461 L .39759 .28 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.63989 .69684 m .60735 .71539 L .60241 .72 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56874 .73159 m .60241 .72 L .60735 .71539 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.60735 .28461 m .63989 .30316 L .63432 .29763 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.63432 .29763 m .60241 .28 L .60735 .28461 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73797 .44893 m
.73894 .45223 L
s
.72761 .41375 m
.73797 .44893 L
s
.5 Mabswid
.08 .096 .073 r
.46108 .73954 m .48091 .74106 L .47457 .73998 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.47457 .73998 m .44839 .73736 L .46108 .73954 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.52543 .73998 m .55161 .73736 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.55161 .73736 m .52543 .73998 L .51909 .74106 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.44839 .26264 m .47457 .26002 L .48091 .25894 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.47457 .26002 m .44839 .26264 L .43832 .26534 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.52543 .26002 m .55161 .26264 L .53892 .26046 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.53892 .26046 m .51909 .25894 L .52543 .26002 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.33651 .67897 m .36568 .70237 L .36011 .69684 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.36011 .69684 m .33073 .67305 L .33651 .67897 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.39759 .28 m .36568 .29763 L .36011 .30316 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.33073 .32695 m .36011 .30316 L .36568 .29763 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.66927 .67305 m .63989 .69684 L .63432 .70237 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.60241 .72 m .63432 .70237 L .63989 .69684 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.63989 .30316 m .66927 .32695 L .66349 .32103 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.66349 .32103 m .63432 .29763 L .63989 .30316 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.40751 .72438 m .43832 .73466 L .43126 .73159 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.43126 .73159 m .39759 .72 L .40751 .72438 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.39759 .28 m .43126 .26841 L .43832 .26534 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.60241 .72 m .56874 .73159 L .56168 .73466 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.56874 .26841 m .60241 .28 L .59249 .27562 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.59249 .27562 m .56168 .26534 L .56874 .26841 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.51909 .74106 m .53892 .73954 L .55161 .73736 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.53892 .73954 m .51909 .74106 L .51184 .74182 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.47579 .74108 m .48816 .74182 L .48091 .74106 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.48091 .74106 m .46108 .73954 L .47579 .74108 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.51909 .25894 m .53892 .26046 L .52421 .25892 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.52421 .25892 m .51184 .25818 L .51909 .25894 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.46108 .26046 m .48091 .25894 L .48816 .25818 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.48091 .25894 m .46108 .26046 L .44839 .26264 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.36568 .29763 m .33651 .32103 L .33073 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.30537 .35543 m .33073 .32695 L .33651 .32103 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.31104 .65028 m .33651 .67897 L .33073 .67305 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.33073 .67305 m .30537 .64457 L .31104 .65028 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63432 .70237 m .66349 .67897 L .66927 .67305 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.69463 .64457 m .66927 .67305 L .66349 .67897 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.66927 .32695 m .69463 .35543 L .68896 .34972 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.68896 .34972 m .66349 .32103 L .66927 .32695 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.51184 .74182 m .52421 .74108 L .53892 .73954 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.52421 .74108 m .51184 .74182 L .50401 .7422 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.49179 .74187 m .49599 .7422 L .48816 .74182 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.48816 .74182 m .47579 .74108 L .49179 .74187 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.51184 .25818 m .52421 .25892 L .50821 .25813 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.50821 .25813 m .50401 .2578 L .51184 .25818 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.48816 .25818 m .47579 .25892 L .46108 .26046 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.47579 .25892 m .48816 .25818 L .49599 .2578 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27174 .58779 m
.27335 .59176 L
s
.27335 .59176 m
.2757 .5977 L
s
.26927 .58178 m
.27174 .58779 L
s
.5 Mabswid
.309 .469 .366 r
.50401 .7422 m .50821 .74187 L .52421 .74108 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.50821 .74187 m .50401 .7422 L .49599 .7422 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.49599 .7422 m .49179 .74187 L .50821 .74187 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50401 .2578 m .50821 .25813 L .49179 .25813 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49179 .25813 m .49599 .2578 L .50401 .2578 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.49599 .2578 m .49179 .25813 L .47579 .25892 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2757 .5977 m
.27724 .60184 L
s
.26927 .58178 m
.26758 .57785 L
s
.5 Mabswid
.056 .074 .056 r
.33651 .32103 m .31104 .34972 L .30537 .35543 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.28477 .38789 m .30537 .35543 L .31104 .34972 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.29017 .61703 m .31104 .65028 L .30537 .64457 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.30537 .64457 m .28477 .61211 L .29017 .61703 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.69463 .35543 m .71523 .38789 L .70983 .38297 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.70983 .38297 m .68896 .34972 L .69463 .35543 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.71523 .61211 m .69463 .64457 L .68896 .65028 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.66349 .67897 m .68896 .65028 L .69463 .64457 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73756 .44253 m
.74022 .4515 L
s
.72866 .41249 m
.73756 .44253 L
s
.5 Mabswid
.346 .515 .414 r
.42217 .72827 m .44839 .73736 L .43832 .73466 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.43832 .73466 m .40751 .72438 L .42217 .72827 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.56168 .73466 m .59249 .72438 L .60241 .72 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.59249 .72438 m .56168 .73466 L .55161 .73736 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.43832 .26534 m .40751 .27562 L .39759 .28 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.40751 .27562 m .43832 .26534 L .44839 .26264 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.56168 .26534 m .59249 .27562 L .57783 .27173 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.57783 .27173 m .55161 .26264 L .56168 .26534 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.37793 .70768 m .40751 .72438 L .39759 .72 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.39759 .72 m .36568 .70237 L .37793 .70768 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.36568 .29763 m .39759 .28 L .40751 .27562 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.63432 .70237 m .60241 .72 L .59249 .72438 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.60241 .28 m .63432 .29763 L .62207 .29232 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.62207 .29232 m .59249 .27562 L .60241 .28 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.27466 .58014 m .29017 .61703 L .28477 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.28477 .61211 m .26959 .57654 L .27466 .58014 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27724 .60184 m
.27808 .60412 L
s
.27335 .59176 m
.27388 .59443 L
s
.5 Mabswid
.066 .086 .069 r
.31104 .34972 m .29017 .38297 L .28477 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.26959 .42346 m .28477 .38789 L .29017 .38297 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.73041 .57654 m .71523 .61211 L .70983 .61703 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.68896 .65028 m .70983 .61703 L .71523 .61211 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.71523 .38789 m .73041 .42346 L .72534 .41986 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.72534 .41986 m .70983 .38297 L .71523 .38789 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26511 .54072 m .27466 .58014 L .26959 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26959 .57654 m .26028 .53882 L .26511 .54072 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26677 .576 m
.26758 .57785 L
s
.5 Mabswid
.108 .138 .122 r
.29017 .38297 m .27466 .41986 L .26959 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.26028 .46118 m .26959 .42346 L .27466 .41986 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.73972 .53882 m .73041 .57654 L .72534 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.70983 .61703 m .72534 .58014 L .73041 .57654 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73041 .42346 m .73972 .46118 L .73489 .45928 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73489 .45928 m .72534 .41986 L .73041 .42346 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27808 .60412 m
.27829 .60485 L
s
.5 Mabswid
.145 .182 .168 r
.27466 .41986 m .26511 .45928 L .26028 .46118 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.25714 .5 m .26028 .46118 L .26511 .45928 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26189 .5 m .26511 .54072 L .26028 .53882 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26028 .53882 m .25714 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73972 .46118 m .74286 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73811 .5 m .73489 .45928 L .73972 .46118 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.74286 .5 m .73972 .53882 L .73489 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.72534 .58014 m .73489 .54072 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.26511 .45928 m .26189 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.73489 .54072 m .73811 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26677 .576 m
.2669 .57656 L
s
1 .5 0 r
.73293 .42292 m
.73417 .42673 L
s
.73088 .41701 m
.73293 .42292 L
s
.73417 .42673 m
.73585 .43227 L
s
.5 Mabswid
.405 .59 .466 r
.44103 .73145 m .46108 .73954 L .44839 .73736 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44839 .73736 m .42217 .72827 L .44103 .73145 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.55161 .73736 m .57783 .72827 L .59249 .72438 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.57783 .72827 m .55161 .73736 L .53892 .73954 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.42217 .27173 m .44839 .26264 L .46108 .26046 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.44839 .26264 m .42217 .27173 L .40751 .27562 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55161 .26264 m .57783 .27173 L .55897 .26855 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55897 .26855 m .53892 .26046 L .55161 .26264 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27771 .60353 m
.27829 .60485 L
s
1 .5 0 r
.72928 .41283 m
.73088 .41701 L
s
.73585 .43227 m
.73677 .43578 L
s
.5 Mabswid
.396 .568 .462 r
.35056 .68472 m .37793 .70768 L .36568 .70237 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.36568 .70237 m .33651 .67897 L .35056 .68472 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.40751 .27562 m .37793 .29232 L .36568 .29763 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.33651 .32103 m .36568 .29763 L .37793 .29232 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.66349 .67897 m .63432 .70237 L .62207 .70768 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.59249 .72438 m .62207 .70768 L .63432 .70237 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.63432 .29763 m .66349 .32103 L .64944 .31528 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.64944 .31528 m .62207 .29232 L .63432 .29763 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2669 .57656 m
.2679 .5792 L
s
1 .5 0 r
.7283 .41057 m
.72928 .41283 L
s
0 0 0 r
.27704 .60192 m
.27771 .60353 L
s
1 .5 0 r
.73677 .43578 m
.73707 .43742 L
s
0 0 0 r
.2679 .5792 m
.26982 .58401 L
s
.27555 .59836 m
.27704 .60192 L
s
1 .5 0 r
.72784 .41008 m
.7283 .41057 L
s
.5 Mabswid
.438 .628 .499 r
.39671 .71247 m .42217 .72827 L .40751 .72438 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.40751 .72438 m .37793 .70768 L .39671 .71247 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.62207 .70768 m .59249 .72438 L .57783 .72827 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.37793 .29232 m .40751 .27562 L .42217 .27173 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.59249 .27562 m .62207 .29232 L .60329 .28753 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.60329 .28753 m .57783 .27173 L .59249 .27562 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.53892 .73954 m .55897 .73145 L .57783 .72827 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.55897 .73145 m .53892 .73954 L .52421 .74108 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.4632 .7337 m .47579 .74108 L .46108 .73954 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.46108 .73954 m .44103 .73145 L .4632 .7337 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.53892 .26046 m .55897 .26855 L .5368 .2663 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.5368 .2663 m .52421 .25892 L .53892 .26046 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.44103 .26855 m .46108 .26046 L .47579 .25892 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.46108 .26046 m .44103 .26855 L .42217 .27173 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73664 .43706 m
.73707 .43742 L
s
0 0 0 r
.27388 .59443 m
.27555 .59836 L
s
1 .5 0 r
.72784 .41008 m
.7282 .41172 L
s
.5 Mabswid
.431 .604 .49 r
.32641 .65589 m .35056 .68472 L .33651 .67897 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.33651 .67897 m .31104 .65028 L .32641 .65589 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.37793 .29232 m .35056 .31528 L .33651 .32103 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.31104 .34972 m .33651 .32103 L .35056 .31528 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.68896 .65028 m .66349 .67897 L .64944 .68472 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.62207 .70768 m .64944 .68472 L .66349 .67897 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.66349 .32103 m .68896 .34972 L .67359 .34411 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.67359 .34411 m .64944 .31528 L .66349 .32103 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.52421 .74108 m .5368 .7337 L .55897 .73145 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.5368 .7337 m .52421 .74108 L .50821 .74187 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.48749 .73487 m .49179 .74187 L .47579 .74108 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.47579 .74108 m .4632 .7337 L .48749 .73487 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.52421 .25892 m .5368 .2663 L .51251 .26513 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.51251 .26513 m .50821 .25813 L .52421 .25892 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.4632 .2663 m .47579 .25892 L .49179 .25813 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.47579 .25892 m .4632 .2663 L .44103 .26855 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73575 .43493 m
.73664 .43706 L
s
.7282 .41172 m
.72919 .41533 L
s
.5 Mabswid
.459 .657 .499 r
.50821 .74187 m .51251 .73487 L .5368 .7337 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.51251 .73487 m .50821 .74187 L .49179 .74187 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.49179 .74187 m .48749 .73487 L .51251 .73487 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.50821 .25813 m .51251 .26513 L .48749 .26513 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.48749 .26513 m .49179 .25813 L .50821 .25813 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.49179 .25813 m .48749 .26513 L .4632 .2663 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73423 .43086 m
.73575 .43493 L
s
.72919 .41533 m
.73097 .42105 L
s
.73223 .42494 m
.73423 .43086 L
s
.73097 .42105 m
.73223 .42494 L
s
.5 Mabswid
.131 .143 .11 r
.35056 .31528 m .32641 .34411 L .31104 .34972 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.29017 .38297 m .31104 .34972 L .32641 .34411 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.30644 .6219 m .32641 .65589 L .31104 .65028 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.31104 .65028 m .29017 .61703 L .30644 .6219 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.68896 .34972 m .70983 .38297 L .69356 .3781 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.69356 .3781 m .67359 .34411 L .68896 .34972 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.70983 .61703 m .68896 .65028 L .67359 .65589 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.64944 .68472 m .67359 .65589 L .68896 .65028 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27409 .59168 m
.27575 .59579 L
s
.27575 .59579 m
.27871 .60194 L
s
.27209 .58544 m
.27409 .59168 L
s
.5 Mabswid
.508 .715 .558 r
.42138 .71641 m .44103 .73145 L .42217 .72827 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42217 .72827 m .39671 .71247 L .42138 .71641 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.57783 .72827 m .60329 .71247 L .62207 .70768 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.60329 .71247 m .57783 .72827 L .55897 .73145 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.39671 .28753 m .42217 .27173 L .44103 .26855 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.42217 .27173 m .39671 .28753 L .37793 .29232 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57783 .27173 m .60329 .28753 L .57862 .28359 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57862 .28359 m .55897 .26855 L .57783 .27173 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27871 .60194 m
.28137 .60622 L
s
.5 Mabswid
.504 .704 .555 r
.3729 .68995 m .39671 .71247 L .37793 .70768 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.37793 .70768 m .35056 .68472 L .3729 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.64944 .68472 m .62207 .70768 L .60329 .71247 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.35056 .31528 m .37793 .29232 L .39671 .28753 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.62207 .29232 m .64944 .31528 L .6271 .31005 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.6271 .31005 m .60329 .28753 L .62207 .29232 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27145 .58135 m
.27209 .58544 L
s
.5 Mabswid
.188 .21 .176 r
.32641 .34411 m .30644 .3781 L .29017 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.27466 .41986 m .29017 .38297 L .30644 .3781 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.2915 .58374 m .30644 .6219 L .29017 .61703 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.29017 .61703 m .27466 .58014 L .2915 .58374 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28137 .60622 m
.2833 .60857 L
s
.5 Mabswid
.368 .497 .336 r
.72534 .58014 m .70983 .61703 L .69356 .6219 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.67359 .65589 m .69356 .6219 L .70983 .61703 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.70983 .38297 m .72534 .41986 L .7085 .41626 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.7085 .41626 m .69356 .3781 L .70983 .38297 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2833 .60857 m
.28512 .60931 L
s
1 .5 0 r
.72623 .41394 m
.72867 .42004 L
s
.72867 .42004 m
.72994 .42397 L
s
.72391 .40964 m
.72623 .41394 L
s
.5 Mabswid
.435 .578 .467 r
.28225 .54263 m .2915 .58374 L .27466 .58014 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.27466 .58014 m .26511 .54072 L .28225 .54263 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27145 .58135 m
.27175 .57942 L
s
.5 Mabswid
.258 .307 .254 r
.30644 .3781 m .2915 .41626 L .27466 .41986 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.26511 .45928 m .27466 .41986 L .2915 .41626 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.73489 .54072 m .72534 .58014 L .7085 .58374 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.69356 .6219 m .7085 .58374 L .72534 .58014 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.72534 .41986 m .73489 .45928 L .71775 .45737 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72994 .42397 m
.73128 .4297 L
s
.5 Mabswid
.287 .351 .238 r
.71775 .45737 m .7085 .41626 L .72534 .41986 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73128 .4297 m
.7315 .43334 L
s
0 0 0 r
.27175 .57942 m
.27359 .57999 L
s
.5 Mabswid
.476 .672 .498 r
.55897 .73145 m .57862 .71641 L .60329 .71247 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.57862 .71641 m .55897 .73145 L .5368 .7337 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.45078 .71923 m .4632 .7337 L .44103 .73145 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.44103 .73145 m .42138 .71641 L .45078 .71923 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.55897 .26855 m .57862 .28359 L .54922 .28077 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.54922 .28077 m .5368 .2663 L .55897 .26855 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.42138 .28359 m .44103 .26855 L .4632 .2663 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.44103 .26855 m .42138 .28359 L .39671 .28753 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72221 .4073 m
.72391 .40964 L
s
0 0 0 r
.28512 .60931 m
.28564 .60794 L
s
.5 Mabswid
.32 .398 .325 r
.2915 .41626 m .28225 .45737 L .26511 .45928 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.26189 .5 m .26511 .45928 L .28225 .45737 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.27912 .5 m .28225 .54263 L .26511 .54072 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.26511 .54072 m .26189 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.73489 .45928 m .73811 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.72088 .5 m .71775 .45737 L .73489 .45928 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.73811 .5 m .73489 .54072 L .71775 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.7085 .58374 m .71775 .54263 L .73489 .54072 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73107 .43505 m
.7315 .43334 L
s
.5 Mabswid
.37 .473 .384 r
.28225 .45737 m .27912 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.71775 .54263 m .72088 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72068 .40682 m
.72221 .4073 L
s
.5 Mabswid
.543 .744 .584 r
.35168 .66105 m .3729 .68995 L .35056 .68472 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35056 .68472 m .32641 .65589 L .35168 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.67359 .65589 m .64944 .68472 L .6271 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.60329 .71247 m .6271 .68995 L .64944 .68472 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.39671 .28753 m .3729 .31005 L .35056 .31528 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.32641 .34411 m .35056 .31528 L .3729 .31005 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64944 .31528 m .67359 .34411 L .64832 .33895 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64832 .33895 m .6271 .31005 L .64944 .31528 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27359 .57999 m
.27575 .58272 L
s
.28544 .60456 m
.28564 .60794 L
s
1 .5 0 r
.72952 .43469 m
.73107 .43505 L
s
0 0 0 r
.28499 .60092 m
.2941 .62259 L
s
.27652 .58076 m
.28499 .60092 L
s
1 .5 0 r
.72032 .40852 m
.72068 .40682 L
s
.5 Mabswid
.53 .739 .551 r
.5368 .7337 m .54922 .71923 L .57862 .71641 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.54922 .71923 m .5368 .7337 L .51251 .73487 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.48324 .7207 m .48749 .73487 L .4632 .7337 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.4632 .7337 m .45078 .71923 L .48324 .7207 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5368 .2663 m .54922 .28077 L .51676 .2793 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.51676 .2793 m .51251 .26513 L .5368 .2663 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.45078 .28077 m .4632 .2663 L .48749 .26513 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.4632 .2663 m .45078 .28077 L .42138 .28359 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.40284 .69431 m .42138 .71641 L .39671 .71247 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.39671 .71247 m .3729 .68995 L .40284 .69431 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.6271 .68995 m .60329 .71247 L .57862 .71641 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.3729 .31005 m .39671 .28753 L .42138 .28359 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.60329 .28753 m .6271 .31005 L .59716 .30569 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.59716 .30569 m .57862 .28359 L .60329 .28753 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27575 .58272 m
.27885 .58771 L
s
1 .5 0 r
.72032 .40852 m
.72059 .41225 L
s
.72789 .43249 m
.72952 .43469 L
s
.71248 .39188 m
.72719 .43421 L
s
.5 Mabswid
.562 .78 .585 r
.51251 .73487 m .51676 .7207 L .54922 .71923 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.51676 .7207 m .51251 .73487 L .48749 .73487 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.48749 .73487 m .48324 .7207 L .51676 .7207 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.51251 .26513 m .51676 .2793 L .48324 .2793 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.48324 .2793 m .48749 .26513 L .51251 .26513 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.48749 .26513 m .48324 .2793 L .45078 .28077 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72561 .42829 m
.72789 .43249 L
s
.5 Mabswid
.226 .247 .193 r
.3729 .31005 m .35168 .33895 L .32641 .34411 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.30644 .3781 m .32641 .34411 L .35168 .33895 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.33398 .62642 m .35168 .66105 L .32641 .65589 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.32641 .65589 m .30644 .6219 L .33398 .62642 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.67359 .34411 m .69356 .3781 L .66602 .37358 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.66602 .37358 m .64832 .33895 L .67359 .34411 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.69356 .6219 m .67359 .65589 L .64832 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.6271 .68995 m .64832 .66105 L .67359 .65589 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71577 .40552 m
.72014 .43801 L
s
.72014 .43801 m
.7213 .44667 L
s
0 0 0 r
.28763 .59582 m
.28926 .60009 L
s
.28926 .60009 m
.29278 .60645 L
s
.5 Mabswid
.536 .739 .541 r
.57862 .71641 m .59716 .69431 L .6271 .68995 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.57862 .28359 m .59716 .30569 L .56101 .30255 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.56101 .30255 m .54922 .28077 L .57862 .28359 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.59716 .69431 m .57862 .71641 L .54922 .71923 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.43899 .69745 m .45078 .71923 L .42138 .71641 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.42138 .71641 m .40284 .69431 L .43899 .69745 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.40284 .30569 m .42138 .28359 L .45078 .28077 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.42138 .28359 m .40284 .30569 L .3729 .31005 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2863 .58933 m
.28763 .59582 L
s
.5 Mabswid
.315 .371 .289 r
.35168 .33895 m .33398 .37358 L .30644 .3781 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.2915 .41626 m .30644 .3781 L .33398 .37358 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.32065 .58709 m .33398 .62642 L .30644 .6219 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.30644 .6219 m .2915 .58374 L .32065 .58709 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29278 .60645 m
.29661 .61084 L
s
.28926 .60009 m
.30395 .60271 L
s
.5 Mabswid
.352 .425 .288 r
.69356 .3781 m .7085 .41626 L .67935 .41291 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.67935 .41291 m .66602 .37358 L .69356 .3781 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.7085 .58374 m .69356 .6219 L .66602 .62642 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.64832 .66105 m .66602 .62642 L .69356 .6219 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29661 .61084 m
.29973 .61323 L
s
.2863 .58933 m
.28697 .58505 L
s
.5 Mabswid
.608 .823 .634 r
.38619 .66538 m .40284 .69431 L .3729 .68995 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.3729 .68995 m .35168 .66105 L .38619 .66538 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.6271 .31005 m .64832 .33895 L .61381 .33462 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.61381 .33462 m .59716 .30569 L .6271 .31005 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.64832 .66105 m .6271 .68995 L .59716 .69431 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.35168 .33895 m .3729 .31005 L .40284 .30569 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29973 .61323 m
.3034 .61395 L
s
.5 Mabswid
.588 .803 .592 r
.54922 .71923 m .56101 .69745 L .59716 .69431 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.56101 .69745 m .54922 .71923 L .51676 .7207 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.47919 .69909 m .48324 .7207 L .45078 .71923 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.45078 .71923 m .43899 .69745 L .47919 .69909 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.33398 .37358 m .32065 .41291 L .2915 .41626 L p F P
.505 .664 .505 r
s
.444 .557 .432 r
.28225 .45737 m .2915 .41626 L .32065 .41291 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.31236 .54441 m .32065 .58709 L .2915 .58374 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.2915 .58374 m .28225 .54263 L .31236 .54441 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28697 .58505 m
.28858 .58302 L
s
.5 Mabswid
.385 .477 .318 r
.7085 .41626 m .71775 .45737 L .68764 .45559 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70993 .41794 m
.71845 .41933 L
s
.5 Mabswid
.385 .477 .318 r
.68764 .45559 m .67935 .41291 L .7085 .41626 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.71775 .54263 m .7085 .58374 L .67935 .58709 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.66602 .62642 m .67935 .58709 L .7085 .58374 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.54922 .28077 m .56101 .30255 L .52081 .30091 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.52081 .30091 m .51676 .2793 L .54922 .28077 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.43899 .30255 m .45078 .28077 L .48324 .2793 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.45078 .28077 m .43899 .30255 L .40284 .30569 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70232 .40297 m
.714 .42987 L
s
.714 .42987 m
.7213 .44667 L
s
0 0 0 r
.3034 .61395 m
.30519 .61248 L
s
.28858 .58302 m
.29237 .58357 L
s
.30519 .61248 m
.30573 .61074 L
s
.5 Mabswid
.444 .557 .432 r
.32065 .41291 m .31236 .45559 L .28225 .45737 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.27912 .5 m .28225 .45737 L .31236 .45559 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.30955 .5 m .31236 .54441 L .28225 .54263 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.28225 .54263 m .27912 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.71775 .45737 m .72088 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.69045 .5 m .68764 .45559 L .71775 .45737 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.72088 .5 m .71775 .54263 L .68764 .54441 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.67935 .58709 m .68764 .54441 L .71775 .54263 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.51676 .7207 m .52081 .69909 L .56101 .69745 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.52081 .69909 m .51676 .7207 L .48324 .7207 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.48324 .7207 m .47919 .69909 L .52081 .69909 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.51676 .2793 m .52081 .30091 L .47919 .30091 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.47919 .30091 m .48324 .2793 L .51676 .2793 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.48324 .2793 m .47919 .30091 L .43899 .30255 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.68764 .54441 m .69045 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.31236 .45559 m .30955 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29237 .58357 m
.29581 .58638 L
s
.30553 .60691 m
.30573 .61074 L
s
.5 Mabswid
.314 .362 .27 r
.40284 .30569 m .38619 .33462 L .35168 .33895 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.33398 .37358 m .35168 .33895 L .38619 .33462 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.3722 .63023 m .38619 .66538 L .35168 .66105 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.35168 .66105 m .33398 .62642 L .3722 .63023 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.64832 .33895 m .66602 .37358 L .6278 .36977 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.6278 .36977 m .61381 .33462 L .64832 .33895 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.66602 .62642 m .64832 .66105 L .61381 .66538 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.59716 .69431 m .61381 .66538 L .64832 .66105 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30395 .60271 m
.30553 .60691 L
s
.29581 .58638 m
.30012 .59151 L
s
.5 Mabswid
.614 .826 .604 r
.61381 .66538 m .59716 .69431 L .56101 .69745 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.59716 .30569 m .61381 .33462 L .57167 .33149 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.57167 .33149 m .56101 .30255 L .59716 .30569 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.42833 .66851 m .43899 .69745 L .40284 .69431 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.40284 .69431 m .38619 .66538 L .42833 .66851 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.38619 .33462 m .40284 .30569 L .43899 .30255 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31539 .61028 m
.31549 .60631 L
s
.31539 .61028 m
.31855 .61452 L
s
.31549 .60631 m
.31812 .60457 L
s
.5 Mabswid
.616 .814 .622 r
.36161 .58993 m .3722 .63023 L .33398 .62642 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.33398 .62642 m .32065 .58709 L .36161 .58993 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31855 .61452 m
.32434 .61714 L
s
.5 Mabswid
.572 .753 .538 r
.67935 .58709 m .66602 .62642 L .6278 .63023 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.61381 .66538 m .6278 .63023 L .66602 .62642 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.38619 .33462 m .3722 .36977 L .33398 .37358 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.32065 .41291 m .33398 .37358 L .3722 .36977 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.66602 .37358 m .67935 .41291 L .63839 .41007 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.63839 .41007 m .6278 .36977 L .66602 .37358 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3094 .59265 m
.30965 .58801 L
s
.32434 .61714 m
.32965 .61778 L
s
.5 Mabswid
.614 .826 .604 r
.56101 .69745 m .57167 .66851 L .61381 .66538 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.57167 .66851 m .56101 .69745 L .52081 .69909 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.47552 .67016 m .47919 .69909 L .43899 .69745 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.43899 .69745 m .42833 .66851 L .47552 .67016 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.56101 .30255 m .57167 .33149 L .52448 .32984 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.52448 .32984 m .52081 .30091 L .56101 .30255 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.42833 .33149 m .43899 .30255 L .47919 .30091 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.43899 .30255 m .42833 .33149 L .38619 .33462 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.31812 .60457 m
.32643 .60335 L
s
.30965 .58801 m
.3142 .58605 L
s
.32965 .61778 m
.33451 .61643 L
s
.5 Mabswid
.414 .5 .344 r
.61381 .33462 m .6278 .36977 L .58067 .36699 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.58067 .36699 m .57167 .33149 L .61381 .33462 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.6278 .63023 m .61381 .66538 L .57167 .66851 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.3722 .36977 m .38619 .33462 L .42833 .33149 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.41933 .63301 m .42833 .66851 L .38619 .66538 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.38619 .66538 m .3722 .63023 L .41933 .63301 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.52081 .69909 m .52448 .67016 L .57167 .66851 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.52448 .67016 m .52081 .69909 L .47919 .69909 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.47919 .69909 m .47552 .67016 L .52448 .67016 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.52081 .30091 m .52448 .32984 L .47552 .32984 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.47552 .32984 m .47919 .30091 L .52081 .30091 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.47919 .30091 m .47552 .32984 L .42833 .33149 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.35499 .54593 m .36161 .58993 L .32065 .58709 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.32065 .58709 m .31236 .54441 L .35499 .54593 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3142 .58605 m
.31975 .58655 L
s
.5 Mabswid
.557 .725 .514 r
.68764 .54441 m .67935 .58709 L .63839 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.6278 .63023 m .63839 .58993 L .67935 .58709 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.3722 .36977 m .36161 .41007 L .32065 .41291 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.31236 .45559 m .32065 .41291 L .36161 .41007 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.67935 .41291 m .68764 .45559 L .64501 .45407 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.64501 .45407 m .63839 .41007 L .67935 .41291 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33451 .61643 m
.33502 .61254 L
s
.32643 .60335 m
.32958 .60147 L
s
.31975 .58655 m
.32625 .58955 L
s
.32958 .60147 m
.33022 .59701 L
s
.5 Mabswid
.511 .643 .487 r
.36161 .41007 m .35499 .45407 L .31236 .45559 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.30955 .5 m .31236 .45559 L .35499 .45407 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.35274 .5 m .35499 .54593 L .31236 .54441 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.31236 .54441 m .30955 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.68764 .45559 m .69045 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.64726 .5 m .64501 .45407 L .68764 .45559 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.69045 .5 m .68764 .54441 L .64501 .54593 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.63839 .58993 m .64501 .54593 L .68764 .54441 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32955 .59462 m
.33022 .59701 L
s
.32625 .58955 m
.32955 .59462 L
s
.34911 .60532 m
.35815 .63322 L
s
.5 Mabswid
.55 .702 .533 r
.35499 .45407 m .35274 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.64501 .54593 m .64726 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.57167 .66851 m .58067 .63301 L .6278 .63023 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.57167 .33149 m .58067 .36699 L .52759 .36552 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.52759 .36552 m .52448 .32984 L .57167 .33149 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.58067 .63301 m .57167 .66851 L .52448 .67016 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.41933 .36699 m .42833 .33149 L .47552 .32984 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.47241 .63448 m .47552 .67016 L .42833 .66851 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.42833 .66851 m .41933 .63301 L .47241 .63448 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.42833 .33149 m .41933 .36699 L .3722 .36977 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.63839 .58993 m .6278 .63023 L .58067 .63301 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.6278 .36977 m .63839 .41007 L .58751 .40799 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.58751 .40799 m .58067 .36699 L .6278 .36977 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.41249 .59201 m .41933 .63301 L .3722 .63023 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.3722 .63023 m .36161 .58993 L .41249 .59201 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.36161 .41007 m .3722 .36977 L .41933 .36699 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34321 .59081 m
.34489 .58841 L
s
.34321 .59081 m
.34606 .59347 L
s
.34606 .59347 m
.34777 .59111 L
s
.34489 .58841 m
.34777 .59111 L
s
.5 Mabswid
.645 .854 .627 r
.52448 .67016 m .52759 .63448 L .58067 .63301 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.52448 .32984 m .52759 .36552 L .47241 .36552 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.47241 .36552 m .47552 .32984 L .52448 .32984 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.52759 .63448 m .52448 .67016 L .47552 .67016 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.47552 .67016 m .47241 .63448 L .52759 .63448 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.47552 .32984 m .47241 .36552 L .41933 .36699 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.64501 .54593 m .63839 .58993 L .58751 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.58067 .63301 m .58751 .59201 L .63839 .58993 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.63839 .41007 m .64501 .45407 L .5918 .45295 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.5918 .45295 m .58751 .40799 L .63839 .41007 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.4082 .54705 m .41249 .59201 L .36161 .58993 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.36161 .58993 m .35499 .54593 L .4082 .54705 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.41933 .36699 m .41249 .40799 L .36161 .41007 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.35499 .45407 m .36161 .41007 L .41249 .40799 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.58751 .59201 m .58067 .63301 L .52759 .63448 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.47004 .59312 m .47241 .63448 L .41933 .63301 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.41933 .63301 m .41249 .59201 L .47004 .59312 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.58067 .36699 m .58751 .40799 L .52996 .40688 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.52996 .40688 m .52759 .36552 L .58067 .36699 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.41249 .40799 m .41933 .36699 L .47241 .36552 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.64501 .45407 m .64726 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.59326 .5 m .5918 .45295 L .64501 .45407 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.64726 .5 m .64501 .54593 L .5918 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.58751 .59201 m .5918 .54705 L .64501 .54593 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.41249 .40799 m .4082 .45295 L .35499 .45407 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.35274 .5 m .35499 .45407 L .4082 .45295 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.40674 .5 m .4082 .54705 L .35499 .54593 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.35499 .54593 m .35274 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.5918 .54705 m .59326 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.4082 .45295 m .40674 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.52759 .63448 m .52996 .59312 L .58751 .59201 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.52996 .59312 m .52759 .63448 L .47241 .63448 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.47241 .63448 m .47004 .59312 L .52996 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.52759 .36552 m .52996 .40688 L .47004 .40688 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.47004 .40688 m .47241 .36552 L .52759 .36552 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.47241 .36552 m .47004 .40688 L .41249 .40799 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.5918 .54705 m .58751 .59201 L .52996 .59312 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.46856 .54764 m .47004 .59312 L .41249 .59201 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.41249 .59201 m .4082 .54705 L .46856 .54764 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.58751 .40799 m .5918 .45295 L .53144 .45236 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.53144 .45236 m .52996 .40688 L .58751 .40799 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.4082 .45295 m .41249 .40799 L .47004 .40688 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.5918 .45295 m .59326 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.53195 .5 m .53144 .45236 L .5918 .45295 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.59326 .5 m .5918 .54705 L .53144 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.52996 .59312 m .53144 .54764 L .5918 .54705 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.47004 .40688 m .46856 .45236 L .4082 .45295 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.40674 .5 m .4082 .45295 L .46856 .45236 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.46805 .5 m .46856 .54764 L .4082 .54705 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.4082 .54705 m .40674 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.52996 .40688 m .53144 .45236 L .46856 .45236 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.46856 .45236 m .47004 .40688 L .52996 .40688 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.53144 .54764 m .52996 .59312 L .47004 .59312 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.47004 .59312 m .46856 .54764 L .53144 .54764 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.53144 .54764 m .53195 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.46856 .45236 m .46805 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.53144 .45236 m .53195 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.46805 .5 m .46856 .45236 L .53144 .45236 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.53195 .5 m .53144 .54764 L .46856 .54764 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.46856 .54764 m .46805 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?40/>3V4@21ZH7a0;3PiP40oooo003U0;3PiPd0PJV10P0S9Qd0
0`21ZH409BPN02DX7P0602DX7P04086YP@0T9ah092LN02@W7Pd0PJV1i@2`h>H10?ooo`00h@2`h>H2
086YP@0301TM5P21ZH40PJV100D07b8J0P21ZH4702<V7@03086YP@0U:1h09BPN00L09BPN00<0PJV1
02@W7P0T9ah01@0T9ah2086YP@D08B@K1@21ZH7Q0;3PiP40oooo003M0;3PiP<0PJV10P0I7AH2086Y
P@D07b8J0P21ZH4802<V7@03086YP@0U:1h09BPN00P09BPN00<0PJV102@W7P0T9ah01`0T9ah2086Y
P@D08B@K0P21ZH400`0L7aP0PJV1086YP@02086YPMd0/>3V0@3oool00=T0/>3V0`21ZH4401TM5P80
PJV10`0O8QXY086YP@<08B@K0P21ZH4201`O60D0PJV1f@2`h>H10?ooo`00eP2`h>H3086YP@D06AdF
1`21ZH400`0`<RH0PJV103Df:@0;03Df:@03086YP@0g>2/0=cP[00T0=cP[00<0PJV103Hh:P0f>2X0
2P0f>2X00`21ZH40<c@X086YP@06086YP@<071lH1@21ZH7F0;3PiP40oooo003C0;3PiP<0PJV10P0I
7AH7086YP@H0<38V00<0PJV103Df:@0e=RT02P0e=RT00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103<d:00c=2P0100c=2P7086YP@0301`O6021ZH40PJV10080PJV1d`2`
h>H10?ooo`00d02`h>H8086YP@80:2/Q0P21ZH48030b9P03086YP@0e=RT0=CHY00/0=CHY00<0PJV1
03Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0c=2P0<c@X00H0<c@X0P21ZH42
02d_8`P0PJV1d02`h>H10?ooo`00c@2`h>H5086YP@L0:2/Q00<0PJV1030b9P0`<RH01`0`<RH00`21
ZH40=CHY03Df:@0<03Df:@03086YP@0g>2/0=cP[00/0=cP[00<0PJV103Hh:P0f>2X02`0f>2X00`21
ZH40<c@X03<d:00803<d:003086YP@0];b<0;BlS00D0;BlS1@21ZH7=0;3PiP40oooo003:0;3PiP<0
PJV100<07R4I086YP@21ZH40200X:b400`21ZH40<38V030b9P08030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X00<0PJV102d_8`0];b<01P0];b<2086YP@0402<V7021ZH40PJV1086YPLX0/>3V0@3oool00<P0
/>3V0`21ZH4201hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH4:030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X0P21ZH4802d_8`03086YP@0S9Q`08bHL00<0PJV1b02`h>H10?ooo`00aP2`h>H3086YP@807R4I
0P21ZH4802P[8@03086YP@0`<RH0<38V00T0<38V00<0PJV103Df:@0e=RT01@0e=RTQ086YP@L0=SPZ
00<0PJV103<d:00c=2P02@0c=2P00`21ZH40;BlS02d_8`0602d_8`80PJV10P0S9Q`3086YPLH0/>3V
0@3oool00<@0/>3V0`21ZH4301hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH45030b9Pl0PJV1201;
E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>Ech0CULn00H0CULn3`21ZH4503<d:080PJV1200]
;b<01021ZH408bHL02<V700S9Q`3086YPL@0/>3V0@3oool00<80/>3V0`21ZH4301hQ6@80PJV11@0X
:b4;086YP@D0@dXe00<0PJV104]D?01;E3`03`1;E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>
Ech0CULn00h0CULn00<0PJV104Q@>@18D3T01018D3T;086YP@D0;BlS0P21ZH4302<V70<0PJV1`P2`
h>H10?ooo`00`02`h>H3086YP@<07R4I0P21ZH400`0X:b40PJV1086YP@04086YP@80=STZ00<0PJV1
04=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00>04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV1
04iG?P1>Ech03P1>Ech00`21ZH40B50i04Q@>@0;04Q@>@03086YP@0m@S00?D8`00H0PJV100<0;BlS
086YP@21ZH400`0S9Q`3086YPL00/>3V0@3oool00;l0/>3V0P21ZH4201hQ6@H0PJV11`0f>BX00`21
ZH40@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21
ZH40CULn04iG?P0>04iG?P03086YP@18D3T0B50i00`0B50i00<0PJV103e2<00m@S001@0m@S06086Y
P@808bHL0P21ZH6o0;3PiP40oooo002m0;3PiPH0PJV100<0:B/Q086YP@0f>BX02P0f>BX00`21ZH40
@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21ZH40
CULn04iG?P0?04iG?P03086YP@18D3T0B50i00/0B50i00<0PJV103e2<00m@S002@0m@S000`21ZH40
;c4U086YP@05086YPKd0/>3V0@3oool00;/0/>3V1021ZH4402T[8@03086YP@0f>BX0=STZ00T0=STZ
00<0PJV104=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn00l0CUTn
00<0PJV104iG?P1>Ech03`1>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m@S00?D8`00T0?D8`
00<0PJV102la9@0_<BD00P0_<BD4086YPK/0/>3V0@3oool00;T0/>3V0`21ZH4602T[8@03086YP@0f
>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>
FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m
@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD3086YPKT0/>3V0@3oool00;L0/>3V1021ZH46
02T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00A
04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0=
04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086YPKL0/>3V0@3oool0
0;H0/>3V1021ZH4602T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03@13BSD00`21
ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn0140CUTn00<0PJV104iG?P1>Ech0401>Ech00`21
ZH40B50i04Q@>@0=04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086Y
PKH0/>3V0@3oool00;D0/>3V00<0PJV101TM5P21ZH401`0Y:b400`21ZH40=STZ03Hi:P0903Hi:P03
086YP@13BSD0@dXe00d0@dXe00<0PJV104]D?01;E3`04@1;E3`00`21ZH40CUTn04iI?P0A04iI?P03
086YP@1>Ech0CULn0100CULn00<0PJV104Q@>@18D3T03P18D3T00`21ZH40?D8`03e2<00903e2<003
086YP@0_<BD0;c4U00D0;c4U00<0PJV1020S6`21ZH40]@2`h>H10?ooo`00/`2`h>H2086YP@0301TM
5P21ZH40:B/Q00H0:B/Q00<0PJV103Hi:P0f>BX02P0f>BX00`21ZH40@dXe04=:=@0904=:=DD0PJV1
2`18D3T00`21ZH40?D8`03e2<00:03e2<003086YP@0_<BD0;c4U00D0;c4U00@0PJV1020S6`21ZH40
PJV1/`2`h>H10?ooo`00/P2`h>H01021ZH406AdF01TM5P21ZH4702T[8@03086YP@0f>BX0=STZ00X0
=STZ00@0PJV104=:=@13BSD0@dXe2@21ZH4405e]D003086YP@1SMU@0HgID0140HgID00<0PJV106Ag
E01TMe@04@1TMe@00`21ZH40H75>061aCP0A061aCP03086YP@1JJDP0FVU80080FVU82@21ZH4304Q@
>@03086YP@0m@S00?D8`00X0?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S6`21ZH6b
0;3PiP40oooo002a0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0PJV103Hi:P0f>BX01`0f>BX8
086YP@`0GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0
H75>0180H75>00<0PJV105YYB01JJDP02P1JJDP8086YP@T0?D8`00<0PJV102la9@0_<BD01@0_<BD0
1021ZH4082<K020S6`21ZH6a0;3PiP40oooo002`0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0
PJV103Hi:P0f>BX02021ZH42051LA@03086YP@1MKE00GFe@00l0GFe@00<0PJV106=fE01SMU@04P1S
MU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP03`1J
JDP00`21ZH40D5a0051L@008086YP@80?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S
6`21ZH6`0;3PiP40oooo002^0;3PiP80PJV100<06AdF086YP@21ZH401P0Y:b45086YP@X0D5a500<0
PJV105e]D01MKE003P1MKE000`21ZH40HgID06=fE00B06=fE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1061aCP1PLDh04P1PLDh00`21ZH40FVU805YYB00>05YYB003086YP@1@G400D5a000P0D5a01@21
ZH4602la9@80PJV100<082<K086YP@21ZH40[P2`h>H10?ooo`00[@2`h>H01021ZH406AdF01TM5P21
ZH4402T[8@D0PJV13@1@G4D00`21ZH40GFe@05e]D00?05e]D003086YP@1SMU@0HgID0180HgID00<0
PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0B061aCP03086YP@1JJDP0FVU800l0FVU800<0
PJV1051L@01@G4002`1@G405086YP@@0;c4U00@0PJV1020S6`0P8a/0PJV1[@2`h>H10?ooo`00[02`
h>H01@21ZH406AdF01TM5P21ZH40:B/Q00@0PJV1100i?c400`21ZH40D5a5051LA@0:051LA@03086Y
P@1MKE00GFe@0100GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00C06AgE003086Y
P@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP0401JJDP00`21ZH40D5a0051L@00:051L@003086Y
P@0oAS80?dHb0080?dHb1021ZH401@0_<BD0PJV1020S6`0P8a/0PJV10:`0/>3V0@3oool00:/0/>3V
00<0PJV101TM5P21ZH400`21ZH4703To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00
3`1MKE000`21ZH40HgID06=fE00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh0
4`1PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS80
1@0oAS84086YP@03020S6`21ZH40/>3V0:X0/>3V0@3oool00:T0/>3V00<0PJV101TM5P21ZH400P21
ZH4903To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00401MKE000`21ZH40HgID06=f
E00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh04`1PLDh00`21ZH40FVU805YY
B00@05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS801`0oAS85086YPJT0/>3V0@3o
ool00:P0/>3V0`21ZH400`0Q91`0PJV103To<@0803To<@03086YP@1@G4D0D5a500/0D5a500<0PJV1
05e]D01MKE00401MKE000`21ZH40HgID06=fE00D06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1
061aCP1PLDh0501PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000`0D5a000<0PJV1
03m6<P0oAS801`0oAS800`21ZH40:B/Q086YP@02086YPJP0/>3V0@3oool00:L0/>3V0P21ZH42024T
7003086YP@0i?c40>Cla00P0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00@05e]
D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0D061a
CP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6
<P03086YP@0Y:b40:B/Q0080PJV1Y`2`h>H10?ooo`00YP2`h>H00`21ZH408B@L024T7002024T7003
086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00A05e]D003
086YP@1SMU@0HgID01<0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>061aCP0C061aCP03
086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0703m6<P03
086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y@2`h>H00`21ZH408B@L
024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@
05e]D00@05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>
061aCP0D061aCP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G400301@G4000`21ZH40?dHb
03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00Y02`
h>H00`21ZH408B@L024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1T
Me@00`21ZH40H75>061aCP0D061aCP03086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G400301@
G4000`21ZH40?dHb03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0XP2`
h>H10?ooo`00Y02`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla00<0PJV1051LA@1@G4D02`1@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID00X0HgID;`21ZH4<061aCP03086YP@1J
JDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6<P05086YP@0Y
:b40:B/Q02T[8@21ZH40Y02`h>H10?ooo`00X`2`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla
00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@05e]D00705e]D1L0PJV12`1fT6P00`21ZH40MY1W
07J@I`0E07J@I`03086YP@1bRf80LX]R00T0LX]R5`21ZH4905YYB003086YP@1@G400D5a000`0D5a0
00<0PJV103m6<P0oAS80200oAS801@21ZH40:B/Q02T[8@0Y:b40PJV10:<0/>3V0@3oool00:80/>3V
00D0PJV1024T700Q91`08B@L086YP@0:03To<@03086YP@1@G4D0D5a500X0D5a53@21ZH4:0769I@03
086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03
086YP@1YOeP0JGmH00P0JGmH3@21ZH4<051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[8@0Y
:b40:B/Q086YP@2R0;3PiP40oooo002Q0;3PiP05086YP@0Q91`08B@L024T7021ZH402P0i?c400`21
ZH40D5a5051LA@05051LA@H0PJV10P1UNU`00`21ZH40LHUU0769I@0B0769I@03086YP@1fT6P0MY1X
01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03086YP@1YOeP0JGmH
0180JGmH00<0PJV105i`C01NL4`01P21ZH47051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[
8@0Y:b40:B/Q086YP@2Q0;3PiP40oooo002P0;3PiP03086YP@0Q91`08B@L00808B@L00<0PJV103To
<@0i?c40200i?c400`21ZH40D5a5086YP@05086YP@L0IGYL00<0PJV10769I@1aRFD04P1aRFD00`21
ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01D0MY1W00<0PJV107:;HP1bRf805P1bRf800`21
ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00D0GW1<1P21ZH400`1@G400PJV103m6<P0903m6
<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00W`2`h>H00`21ZH40
8B@L024T7002024T7003086YP@0i?c40>Cla00D0>Cla1P21ZH4=06EjG003086YP@1aRFD0LHUU0180
LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01D0
LX]R00<0PJV106UoF01YOeP04P1YOeP00`21ZH40GW1<05i`C00;05i`C0H0PJV11`0oAS800`21ZH40
:B/Q02T[8@0202T[8@03086YP@2`h>H0/>3V09d0/>3V0@3oool009h0/>3V00<0PJV1024T700Q91`0
0P0Q91`00`21ZH40>Cla03To<@06086YP@80D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU
0769I@0C0769I@03086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R
07:;HP0E07:;HP03086YP@1YOeP0JGmH01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o
04iK?`06086YP@80?dHb00<0PJV102T[8@0Y:b400P0Y:b400`21ZH40/>3V0;3PiP2L0;3PiP40oooo
002N0;3PiP03086YP@0Q91`08B@L00D0PJV1201@GTT00`21ZH40IGYL06EjG00=06EjG003086YP@1a
RFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1b
Rf80LX]R01D0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`C00=05i`C003086YP@1>
Fcl0CU/o00H0CU/o1@21ZH4202T[8@03086YP@2`h>H0/>3V09`0/>3V0@3oool009d0/>3V00<0PJV1
024T7021ZH400P21ZH4;051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD04P1aRFD0
0`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf80
0`21ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl3
086YP@0302T[8@21ZH40/>3V09`0/>3V0@3oool009`0/>3V0`21ZH42030e;@03086YP@1@GTT0D5i9
00T0D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU0769I@0C0769I@03086YP@1fT6P0MY1X
01H0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH
01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY
00<0PJV1W02`h>H10?ooo`00V`2`h>H2086YP@<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00@0PJV103@i:@0d>BT0=3TY0P21ZH6K0;3P
iP40oooo002J0;3PiP03086YP@0`=Bd0<3D]00<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00=06EjG003086YP@1aRFD0LHUU01@0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00<0PJV103@i:@0d>BT00`0d>BT00`21ZH40
/>3V0;3PiP2H0;3PiP40oooo002I0;3PiP80PJV1100`=Bd00`21ZH40D5i9051NB@09051NB@03086Y
P@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086Y
P@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086Y
P@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl00`21ZH40=3TY03@i:@0203@i:@80PJV1
V@2`h>H10?ooo`00V02`h>H2086YP@@0<3D]00<0PJV1051NB@1@GTT02P1@GTT00`21ZH40IGYL06Ej
G00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05`1fT6P00`21ZH40MY1W07J@
I`0G07J@I`03086YP@1bRf80LX]R01L0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`
C00>05i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i:@0d>BT00P0d>BT2086YPIP0/>3V0@3o
ool009L0/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03P1UNU`0
0`21ZH40LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L0
0`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03P1NL4`0
0`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6G0;3PiP40oooo002G0;3P
iP80PJV1100`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769
I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;
HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK
?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i:@03086YP@0I71H0/>3V09H0/>3V0@3oool009H0
/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40
LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L00`21ZH40
LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03`1NL4`00`21ZH40
CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6F0;3PiP40oooo002E0;3PiP80PJV1
1@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0
501aRFD00`21ZH40MY1X07J@J00G07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;HP1bRf80
5`1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl0
2P1>Fcl00`21ZH40=3TY03@i:@0303@i:@03086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V0P21
ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40LHUU0769
I@0D0769I@03086YP@1fT6P0MY1X00/0MY1X=@21ZH4=07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0
PJV105i`C01NL4`03`1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21
ZH6E0;3PiP40oooo002D0;3PiP80PJV11@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0
IGYL00h0IGYL00<0PJV10769I@1aRFD02P1aRFDI086YP@`0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H0
0`21ZH40P9ma082OL@0:082OLAT0PJV1301YOeP00`21ZH40GW1<05i`C00>05i`C003086YP@1>Fcl0
CU/o00X0CU/o00<0PJV103@i:@0d>BT00`0d>BT2086YPI@0/>3V0@3oool009@0/>3V0P21ZH44030e
;@03086YP@1@GTT0D5i900X0D5i900<0PJV106EjG01UNU`02`1UNU`A086YP@/0Oiie00<0PJV108BT
N024Y7P05`24Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01L0P9ma00<0PJV107RE
J01hUFP02@1hUFPA086YP@d0GW1<00<0PJV104iK?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i
:@80PJV1U02`h>H10?ooo`00T`2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT02P1@GTT01021ZH40
IGYL06EjG01UNU`:086YP@@0MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00G08BT
N003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg405`20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0080JX9H2P21ZH4305i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i
:@0d>BT00`0d>BT2086YPI<0/>3V0@3oool00980/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900L0
D5i92021ZH4=07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06024Y7P00`21ZH40
Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP0501hUFP00`21ZH40
JX9H06Z2F00<06Z2F0P0PJV12@1>Fcl00`21ZH40=3TY03@i:@0303@i:@80PJV1TP2`h>H10?ooo`00
TP2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT01`21ZH4306=iGP03086YP@1fTFh0MY5^00l0MY5^
00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H00l0JX9H
00@0PJV105Y/B@1JK4T0FVa91`21ZH4204iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6B0;3PiP40
oooo002A0;3PiP80PJV1100`=Bd5086YP@T0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie
07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma
082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa9
05Y/B@0705Y/B@D0PJV1100d>BT2086YPI40/>3V0@3oool00900/>3V0P21ZH43030e;@80PJV100<0
@Ti1086YP@1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0
PJV108BTN024Y7P06024Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0
PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900X0FVa900@0
PJV1041;=021ZH40PJV10`0d>BT00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002@0;3PiP03086YP@0`
=Bd0PJV10080PJV10P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^00l0MY5^00<0
PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0
PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0
PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=005086YPI00/>3V0@3oool008l0/>3V0`21ZH45
049>@@03086YP@1SNEh0HgUN00X0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E
07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma082OL@0I
082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP03`1ZPUP00`21ZH40FVa905Y/B@0;
05Y/B@03086YP@10Bc@0@4/d00<0@4/d0`21ZH6?0;3PiP40oooo002?0;3PiP80PJV11P12CT400`21
ZH40HgUN06=iGP0:06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21
ZH40Q:Ah08BTN00I08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21
ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02P1JK4T00`21
ZH40@4/d041;=004041;=080PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@H0@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024
Y7P06024Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01h
UFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010
Bc@01010Bc@2086YPHh0/>3V0@3oool008h0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0ogl001`P602`h>H0S@2`h>H10?ooo`00S@2`h>H2086YP@H0@Ti100<0PJV106=iGP1SNEh02`1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06024
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@00P10
Bc@30?mo0003086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V0P21ZH46049>@@03086YP@1SNEh0
HgUN00/0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E07nNM@03086YP@24Y7P0
Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0
N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0
@4/d00<0@4/d0P3oO`000`21ZH40/>3V0;3PiP2;0;3PiP40oooo002<0;3PiP03086YP@0K8al0PJV1
00H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie
01D0Oiie00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma
01T0P9ma00<0PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa9
00/0FVa900<0PJV1041;=010Bc@00`10Bc@20?mo000301`P6021ZH40/>3V08/0/>3V0@3oool008`0
/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40
Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40
P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP04@1ZPUP00`21ZH40
FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d0080@4/d0`3oO`000`21ZH40/>3V0;3PiP2:0;3PiP40
oooo002;0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^
07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Q:Af
08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05P1hUFP00`21ZH40JX9H
06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@00`10Bc@20?mo000301`P
6021ZH40/>3V08X0/>3V0@3oool008/0/>3V0P21ZH47049>@@03086YP@1SNEh0HgUN00/0HgUN00<0
PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0
PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01H0N9EX00<0
PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@030?mo0010Bc@0@4/d00<0@4/d0P3o
O`000`0L81P0PJV10;3PiP2:0;3PiP40oooo002:0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV1
06=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0A07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01X0P9ma00<0PJV1
07REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0ogl0
086YP@10Bc@00`10Bc@30?mo000301`P6021ZH40/>3V08T0/>3V0@3oool008X0/>3V00<0PJV101/S
7`21ZH401P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nN
M@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00J08BTN003086YP@24Y7H0Q:Af01/0Q:Af00<0PJV1082O
L@20Wg406P20Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0140JX9H00<0PJV105Y/
B@1JK4T02P1JK4T20?mo00@0@4/d0`3oO`000`0L81P0ogl00;3PiP290;3PiP40oooo002:0;3PiP03
01/S7`21ZH40@Ti100D0@Ti100<0PJV106=iGP1SNEh0301SNEh00`21ZH40MY5^07JAKP0@07JAKP03
086YP@1oWWD0Oiie00X0OiieL@21ZH4<07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1J
K4T02`1JK4T00`3oO`00PJV1041;=003041;=0D0ogl0R@2`h>H10?ooo`00R@2`h>H00`21ZH406b<O
086YP@06049>@@03086YP@1SNEh0HgUN00`0HgUN00<0PJV107JAKP1fTFh0301fTFhA086YP@`0Rjn2
00<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm
00<0PJV108>UM023YG@02P23YG@A086YP@h0JX9H00<0PJV105Y/B@1JK4T02`1JK4T20?mo00@0@4/d
1`3oO`270;3PiP40oooo00290;3PiP806b<O00<0PJV1049>@@12CT401012CT400`21ZH40HgUN06=i
GP0;06=iGP03086YP@1fTFh0MY5^00<0MY5^2P21ZH4408:TO003086YP@2;[h80Rjn201H0Rjn200<0
PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0
PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0207NDIPX0PJV11@1ZPUP00`21ZH40FVa905Y/
B@0;05Y/B@030?mo0010Bc@0@4/d0080@4/d0`3oO`000`0L81P0ogl00?mo00020?mo08H0/>3V0@3o
ool008P0/>3V00<0PJV101/S7`21ZH401P12CT400`21ZH40HgUN06=iGP0506=iGPd0PJV13P22Y7`0
0`21ZH40Rjn208^_PP0F08^_PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h806`2>/h80
0`21ZH40Rjmm08^_O@0J08^_O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H0301gU6H=
086YP@H0FVa90P3oO`03041;=0<0ogl000<0PJV10?mo003oO`000P3oO`260;3PiP40oooo00280;3P
iP806b<O00<0PJV1049>@@12CT400`12CT49086YP@L0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21
ZH40Rjn208^_PP0F08^_PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h806`2>/h800`21
ZH40Rjmm08^_O@0J08^_O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04@1gU6H00`21
ZH40HWYA069jD@05069jD@L0PJV100@0ogl0086YP@10Bc@0@4/d103oO`00100L81P0ogl00?mo003o
O`260;3PiP40oooo00270;3PiP03086YP@0K8al0PJV10080@Ti11021ZH400`1AIE<0PJV1076>KP0=
076>KP03086YP@22Y7`0PZAl0100PZAl00<0PJV108^_PP2;[h805`2;[h800`21ZH40S[>408jcQ00J
08jcQ003086YP@2>/h80S[>201/0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00G
08>UM003086YP@1gU6H0MiAV0100MiAV00<0PJV1069jD@1RNU40301RNU480?mo0003086YP@3oO`00
ogl00080ogl0Q@2`h>H10?ooo`00Q`2`h>H201/S7`<0PJV11@1AIE<00`21ZH40LHi^076>KP0;076>
KP03086YP@22Y7`0PZAl0140PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00K08jc
Q003086YP@2>/h80S[>201/0S[>200<0PJV108^_O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00F08>U
M003086YP@1gU6H0MiAV0140MiAV00<0PJV1069jD@1RNU402`1RNU480?mo0003086YP@3oO`00ogl0
0080ogl0Q@2`h>H10?ooo`00QP2`h>H4086YP@H0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40
PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40
S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40
MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA00<0ogl004UI?019FC`01@3oO`001021ZH40
ogl00?mo003oO`250;3PiP40oooo00260;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1076>KP1a
SVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>
/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023
YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA0P3oO`0204UI?0@0
ogl000<08RLM0?mo003oO`000P3oO`240;3PiP40oooo00260;3PiP03086YP@0U;R/0PJV100L0DFEC
00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn2
00<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm
00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA
00@0PJV10?mo0019FC`0BETl2P3oO`230;3PiP40oooo00250;3PiP04086YP@0U;R/09Bh[086YP@L0
DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201H0
Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0
Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00/0
HWYA00@0PJV10?mo003oO`00BETl2P3oO`230;3PiP40oooo00250;3PiP04086YP@0U;R/09Bh[086Y
P@H0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn2
01H0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0L08jcPP03086YP@2;[gd0Rjmm
01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA
00`0HWYA1@3oO`000`19FC`0ogl00?mo00050?mo08<0/>3V0@3oool008D0/>3V00<0PJV102D^:`21
ZH401`1AIE<00`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl0140PZAl00<0PJV108^_PP2;
[h805`2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80S[>201d0S[>200<0PJV108^_O@2;
[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV0180MiAV00<0PJV1069jD@1R
NU40301RNU400`21ZH40ogl00?mo00020?mo000304UI?03oO`00ogl000H0ogl0PP2`h>H10?ooo`00
Q@2`h>H00`21ZH409Bh[086YP@07055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`0
4@22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h80
7@2>/h800`21ZH40Rjmm08^_O@0J08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H0
4@1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@3oO`00ogl00080ogl000<0BETl0?mo003oO`00
1@3oO`230;3PiP40oooo00240;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh0
2`1aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@0
6P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@0
5`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV10?mo003oO`00
0P3oO`0204UI?0L0ogl0PP2`h>H10?ooo`00Q02`h>H01021ZH409Bh[02D^:`21ZH46055UD`03086Y
P@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086Y
P@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h807@2>/h800`21ZH40Rjmm08^_O@0J08^_O@03086Y
P@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40HWYA069jD@0<069jD@04086Y
P@3oO`00ogl00?mo00<0BETl1P3oO`220;3PiP40oooo00240;3PiP03086YP@0U;R/0PJV100L0DFEC
00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn2
00<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm
00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA
00<0PJV10?mo003oO`000P3oO`0204UI?003086YP@0R9ad0ogl000<0ogl0PP2`h>H10?ooo`00Q02`
h>H00`21ZH409Bh[086YP@07055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04P22
Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h807@2>
/h800`21ZH40Rjmm08^_O@0J08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04P1g
U6H00`21ZH40HWYA069jD@0<069jD@04086YP@19FC`0ogl00?mo00@0BETl00<0PJV1028W7@21ZH40
0`3oO`210;3PiP40oooo00230;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh0
2`1aSVh00`21ZH40PZAl08:TO00C08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@0
6`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@0
5P23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00/0HWYA00@0PJV104UI?03oO`00
ogl01019FC`01021ZH408RLM028W7@21ZH420?mo0840/>3V0@3oool008<0/>3V00@0PJV102D^:`0U
;R/0PJV11P1AIE<00`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl01<0PZAl00<0PJV108^_
PP2;[h805P2;[h800`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h80S[>201d0S[>200<0PJV108^_
O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV01<0MiAV00<0PJV1069j
D@1RNU40301RNU401021ZH40ogl00?mo003oO`0304UI?004086YP@0R9ad08RLM086YP@80ogl0P@2`
h>H10?ooo`00P`2`h>H00`21ZH409Bh[086YP@07055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV1
08:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>401/0S[>400<0PJV1
08jcPP2>/h807@2>/h800`21ZH40Rjmm08^_O@0K08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV1
07NDIP1gU6H04P1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@3oO`00ogl000@0BETl00@0PJV1
028W7@0R9ad0PJV10P3oO`210;3PiP40oooo00230;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1
076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV1
08jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV1
08>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV1
04UI?019FC`01@19FC`00`21ZH408RLM086YP@020?mo0840/>3V0@3oool00880/>3V00@0PJV102D^
:`0U;R/0PJV11`1AIE<00`21ZH40LHi^076>KP0;076>KP03086YP@22Y7`0PZAl01<0PZAl00<0PJV1
08^_PP2;[h805`2;[h800`21ZH40S[>408jcQ00=08jcQ3d0PJV13`2;[gd00`21ZH40PjEd08>UM00G
08>UM003086YP@1gU6H0MiAV01<0MiAV00<0PJV1069jD@1RNU402`1RNU400`21ZH40BETl04UI?005
04UI?005086YP@0R9ad08RLM086YP@3oO`00P@2`h>H10?ooo`00PP2`h>H01021ZH409Bh[02D^:`21
ZH46055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`02@22Y7`d086YP@h0U/2>00<0
PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0<09>kQc@0PJV12`1gU6H00`21ZH40HWYA069j
D@0<069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV10P3oO`200;3PiP40oooo
00220;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh01@1aSVhC086YP@X0S;>800<0
PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0
PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b00P0PJ=b4`21
ZH47069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV1PP2`h>H10?ooo`00PP2`
h>H202D^:`03086YP@1AIE<0DFEC0080DFEC2`21ZH4707fON`03086YP@2</hP0S;>801<0S;>800<0
PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0
PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0
PJV106b9G01/RE`01@1/RE`;086YP@@0BETl00<0PJV1028W7@21ZH40PP2`h>H10?ooo`00P@2`h>H0
0`21ZH409Bh[086YP@05086YP@<0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C
08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40U[n<09JoS00M
09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C
086SLP03086YP@1/RE`0K8UL00`0K8UL00@0PJV1051U@`1@ID<0D6E31P21ZH400`0R9ad0PJV10;3P
iP200;3PiP40oooo00210;3PiP80PJV100<0;CXf086YP@1NNF801P1NNF800`21ZH40OImk07fON`0<
07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K
09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G
08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05
051U@`04086YP@0X<b<0PJV1086YPH40/>3V0@3oool00840/>3V00@0PJV102dj=P0]>SH0PJV11`1N
NF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D
_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C
^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/
RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00@0
PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40
/>3V0@3oool00840/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03
086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03
086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03
086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04
086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40
OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40
U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40
S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40
D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00<0PJV102dj=P21
ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D
_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C
^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/
RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00840/>3V
00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10840/>3V
0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2<
/hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F
_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21
Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X
<b<0PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0;
07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L
09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G
08bcO`03086YP@21Xg80PJ=b0180PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06
051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH401`1NNF800`21
ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21
ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21
ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21
ZH40D6E3051U@`05051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00800/>3V00@0PJV102dj=P0]
>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109Bm
S@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>k
Q`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9
G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3oool0
0800/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0
:3<S086YPH00/>3V0@3oool00800/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fO
N`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0
SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bc
O`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U
@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3oool00800/>3V00@0PJV102dj=P0]>SH0PJV1
1`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd0
5`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0
702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0
301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3oool00800/>3V
00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00
/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086Y
P@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086Y
P@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086Y
P@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086Y
P@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fO
N`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0
SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bc
O`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U
@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF80
0`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd0
0`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL0
0`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`0
0`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj
=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109Bm
S@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>k
Q`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9
G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800
/>3Vl`21ZH600;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH0
3025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL0
5`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL0
1P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0
PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0
PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0
PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0
PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3PiP03086YP@0hBT<0
PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0
VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0
V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0
M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3P
iP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09Bo
T@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:
T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`
N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3P
iP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40
U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40
W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40
R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40
;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]
QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;
UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>n
Q`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]
A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3
086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0
VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0
V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0
M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo0020
0;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09Bo
T@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:
T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`
N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk
:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH0
3025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL0
5`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL0
1@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100L0J8Q^
00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF
00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?
00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW
00<0PJV105A]A`1DKDL01@1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0h
BT<0PJV100P0J8Q^00<0PJV108F]QP25[HH02`25[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2K
b9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2J
aXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0B08R`N`03086YP@1d
UVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo0021
0;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C
09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M
09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C
08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@21
0;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21
ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21
ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21
ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21
ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25
[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2M
biH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C
_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1D
KDL01P1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^
00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF
00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?
00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW
00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP04086Y
P@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03
086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03
086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03
086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3P
iP40oooo00210;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21
ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21
ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21
ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021
ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV1
08F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV1
09g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV1
09>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV1
05A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP80PJV100<0>4Y3
086YP@1XR6h01P1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV1
09_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV1
09[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV1
07BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0PJV1086YPH40/>3V0@3o
ool00840/>3V00<0PJV103mGC@21ZH401021ZH4406R8KP03086YP@25[HH0QJf600`0QJf600<0PJV1
09BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV1
09c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV1
08R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e70080E6e71@21ZH40
0`0`@R/0PJV10;3PiP200;3PiP40oooo00220;3PiP03086YP@0oEdd0PJV100<0Ki=g3021ZH4708F]
QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;
UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>n
Q`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL01@1dUVL<086YP@<0FGI>00<0PJV10312
:`0`@R/0PP2`h>H10?ooo`00PP2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0S;N?00D0
S;N?4P21ZH4;09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40
W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40
R;1k08R`N`0908R`Na80PJV11`1kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086Y
PH80/>3V0@3oool00880/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bg
S`03086YP@2JbIT0V/VI00P0V/VI=021ZH4?09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6
S`2JaXl03@2JaXld086YP@X0S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405Uf
CP04086YP@0`@R/0<48[086YPH80/>3V0@3oool00880/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL0
0`21ZH40S;N?08bgS`0;08bgS`03086YP@2JbIT0V/VI01<0V/VI00<0PJV10:3AW@2PdId05`2PdId0
0`21ZH40X]>M0:;CW@0<0:;CWCl0PJV13P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0
S[V301<0S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505UfCP04086YP@0`@R/0
<48[086YPH80/>3V0@3oool008<0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21ZH40S;N?08bgS`0<
08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0K
0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0G
09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP05
05UfCP03086YP@0`@R/0PJV108<0/>3V0@3oool008<0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21
ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21
ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21
ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21
ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH<0/>3V0@3oool008<0/>3V00@0PJV103mG
C@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI01<0V/VI00<0PJV1
0:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV1
09o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V301<0S[V300<0PJV1
07^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH<0/>3V0@3o
ool008<0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bgS`03086YP@2J
bIT0V/VI01<0V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2R
dYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>
^H<0S[V301<0S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505UfCP04086YP@0`
@R/0<48[086YPH<0/>3V0@3oool008@0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21ZH40S;N?08bg
S`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;C
W@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7
S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05Uf
CP0505UfCP03086YP@0`@R/0PJV108@0/>3V0@3oool008@0/>3V00<0PJV103mGC@21ZH401`1_TgL0
0`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH0
0`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl0
0`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH@0/>3V0@3oool008@0/>3V00@0PJV1
03mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0
PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0
PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0
PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH@0/>3V
0@3oool008@0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bgS`03086Y
P@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086Y
P@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086Y
P@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505UfCP04086Y
P@0`@R/0<48[086YPH@0/>3V0@3oool008D0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21ZH40S;N?
08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M
0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?
09W7S`0G09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>
05UfCP0505UfCP03086YP@0`@R/0PJV108D0/>3V0@3oool008D0/>3V00<0PJV103mGC@21ZH401`1_
TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05`2P
dId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2O
cYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301k
XFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPHD0/>3V0@3oool008D0/>3V00@0
PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI
00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01`0X]:J
00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30180S[V3
00<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPHD0
/>3V0@3oool008D0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bgS`03
086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03
086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03
086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505UfCP04
086YP@0`@R/0<48[086YPHD0/>3V0@3oool008@0/>3V0P0000000`21ZH40?eM=086YP@0706nCM`03
086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03
086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03
086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03
086YP@1IMTh0FGI>00D0FGI>00<0PJV10312:`21ZH40QP2`h>H10?ooo`00P`2`h>H300000003086Y
P@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A09[9V@03086Y
P@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086Y
P@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0A08jiP`03086Y
P@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh01021ZH40<48[0312:`21ZH660;3PiP40
oooo00230;3PiP<000000P21ZH42000000H0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI
09[9V@0A09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J
0:;BVP0K0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V3
08jiP`0A08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh4086YPHH0/>3V
0@3oool008@0/>3V1P0000000`21ZH40Ki=g06nCM`0306nCM`0300000021ZH40S;N?00`0S;N?00<0
PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0
PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0
PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00@0FGI>0P21
ZH400`0`AB`0PJV10;3PiP260;3PiP40oooo00240;3PiPL000001021ZH43000000h0S;N?00<0PJV1
09[9V@2JbIT0402JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV1
0:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV1
08jiP`2>^H<0402>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0PJV100@0GWmF
086YP@0`AB`0PJV1Q`2`h>H10?ooo`00QP2`h>H200000003086YP@000000000000<0LY]m1P000005
086YP@<0S;N?00D0000008bgS`2<]hl00000086YP@0C09[9V@03086YP@2PdId0X=6M01H0X=6M00<0
PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0
PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0A08jiP`03086YP@1kXFl0Nj5_00D0Nj5_2P21
ZH4405ioEP03086YP@0`AB`0PJV108P0/>3V0@3oool008H0/>3V0`0000000`15HE@0000000000002
07:KO@80000000<0LY]m0000000000000P00000408nnU003086YP@000000000000D000001021ZH47
09[9V@030000002JbIT0V/VI00D0V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0J
0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0F
09W7S`03086YP@2>^H<0S[V300d0S[V33021ZH4707nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV1
0315;021ZH40R02`h>H10?ooo`00QP2`h>H300000003086YP@15HE@000000080LY]m0P00000207:K
O@03086YP@000000000000@0SkjD2P00000209g@W`H0PJV10`0000000`21ZH40V/VI09[9V@0309[9
V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;B
VP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0308ji
P`X0PJV1102B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315
;021ZH40R@2`h>H10?ooo`00Q`2`h>H200000003086YP@15HE@0000000@000000P1bVgd01021ZH40
SkjD00000000000308nnU08000001@2?_Y@4000000H0WM2O1@00000B086YP@`0X=6M00<0PJV10:;C
W@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7
S`2Iahl02P2IahlB086YP@d0T/2900<0PJV107nXMP1oZ7H0301oZ7H00`21ZH40GWmF05ioEP0405io
EP03086YP@0`AB`0PJV108T0/>3V0@3oool008L0/>3V0`000002086YP@040000001bVgd000000000
0080LY]m00@0PJV108nnU02?_Y@000000`2?_Y@2000000H0SkjD00@0PJV100000000000000001P2M
d9l3000000H0WM2O00<0PJV10:CHXP2Tf:802P2Tf:9a086YP@`0WLjE00<0PJV109;0R@2B`8T0402B
`8T00`21ZH40OjQf07nXMP0<07nXMP03086YP@1NOeH0GWmF00@0GWmF0P21ZH6:0;3PiP40oooo0027
0;3PiP<0000000<0PJV104EQE00000000`00000307:KO@03086YP@2?_Y@0000000<0SkjD0P000006
08nnU003086YP@2Md9l00000008000001P2Md9l00`000000WM2O09g@W`0509g@W`03086YP@2Tf:80
Y=RR01H0Y=RR00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0
XmFL01X0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0A09;0R@03086YP@1oZ7H0
OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@2:0;3PiP40oooo00270;3P
iP<0000000<0PJV104EQE021ZH401000000207:KO@03086YP@2?_Y@0SkjD00/0SkjD00@0PJV109g@
W`00000000001`2Md9l00`000000WM2O09g@W`0609g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV1
0:KJXP2VfZ806P2VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL01X0XmFL00<0PJV1
09g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00`0OjQf00<0PJV1
05ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@2:0;3PiP40oooo00280;3PiP<000000P21ZH440000
00<0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH4000000000000@09g@W`03086YP@2Tf:80Y=RR
01H0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL
01T0XmFL00<0PJV109g>U@2McYD05P2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf
00/0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@2;0;3PiP40oooo00290;3PiP<0
000000<0AF5D0000000000002@00000:08nnU003086YP@00000000000100WM2O00<0PJV10:CHXP2T
f:805P2Tf:800`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02S
eI`06@2SeI`00`21ZH40WLjE09g>U@0F09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1o
Z7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP03086YP@0`AB`0PJV108/0/>3V0@3oool008T0/>3V
0`000002086YP@X000001P2?_Y@010000000SkjD08nnU02?_Y@4000000l0WM2O00<0PJV10:CHXP2T
f:805P2Tf:800`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02S
eI`06@2SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/290140T/2900<0PJV107nXMP1o
Z7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1S02`h>H10?ooo`00R02`h>H80000000307:K
O@00000000000080LY]m00@0PJV108nnU00000000000102?_Y@8000000T0WM2O00<0000009g@W`2M
d9l01@2Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02U
fJ006`2UfJ000`21ZH40XmFL0:?EW00I0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B
`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021
ZH40S02`h>H10?ooo`00R02`h>H<0000000307:KO@21ZH40SkjD008000000`2?_Y@700000003086Y
P@2Md9l0WM2O00L0WM2O0`00000609g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80
6@2VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD0
5@2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0
101NOeH2086YPHd0/>3V0@3oool008`0/>3V1@0000001P1bVgd00000000000000000PJV108nnU080
00000`2?_Y@2000000D0SkjD00<0PJV109g@W`2Md9l0202Md9l2000000H0WM2O00<0PJV10:CHXP2T
f:805P2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02S
eI`0602SeI`00`21ZH40WLjE09g>U@0F09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1o
Z7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1S@2`h>H10?ooo`00S@2`h>H400000080LY]m
0`0000000`21ZH4000000000000308nnU08000001P2?_Y@01021ZH40WM2O09g@W`00000609g@W`80
00001P2Md9l00`21ZH40Y=RR0:CHXP0F0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02U
fJ006`2UfJ000`21ZH40XmFL0:?EW00H0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B
`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF0P21ZH6>0;3PiP40
oooo002=0;3PiPD000000P1bVgd600000080SkjD0`00000508nnU004086YP@2Md9l0WM2O000000H0
WM2O0`00000609g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40
YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL01P0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40
T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH2086YPHh0
/>3V0@3oool008l0/>3V00<0PJV10000000000000`1bVgd4000000@0SkjD1@00000208nnU004086Y
P@2Md9l00000000000L0WM2O0P00000609g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2V
fZ806@2VfZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2M
cYD05@2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00X0OjQf00<0PJV105ioEP1N
OeH0101NOeH2086YPHl0/>3V0@3oool008l0/>3V00@0PJV10000000000000000101bVgd00`000000
SkjD08nnU00408nnU0X000001`2Md9l2000000H0WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40
Y]ZR0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`06@2SeI`00`21ZH40
WLjE09g>U@0E09g>U@03086YP@2B`8T0T/2900l0T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40
GWmF05ioEP0305ioEP<0PJV1S`2`h>H10?ooo`00T02`h>H01021ZH40000000000021ZH4307:KO@03
086YP@2?_Y@0SkjD00L0SkjD1P00000809g@W`8000001P2Md9l00`21ZH40Y=RR0:CHXP0F0:CHXP03
086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?EW003
086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP04
086YP@1NOeH0GWmF05ioEP80PJV100<0Gh=J086YP@2`h>H0S`2`h>H10?ooo`00T02`h>H01021ZH40
00000000001bWGl3086YP@0307:KO@21ZH40SkjD00X0SkjD00<00000086YP@2Md9l0202Md9l30000
00H0WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP
01T0YMVP00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/29
0100T/2900<0PJV107nXMP1oZ7H02P1oZ7H00`21ZH40GWmF086YP@02086YP@80Gh=J00<0PJV10;3P
iP2`h>H0S`2`h>H10?ooo`00T@2`h>H3000000<0LYeo1@21ZH4908nnU003086YP@2Md9l0WM2O00P0
WM2O0P00000609g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40
YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01P0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40
T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00L0OjQf1@21ZH4405n3FP80PJV1T@2`h>H10?ooo`00
TP2`h>H00`000000PJV107:MO`0407:MO`03086YP@2?`IL0Sl6G00L0PJV10`2?_Y@00`21ZH40WM2O
09g@W`0709g@W`8000001P2Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR
00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?EW003086YP@2McYD0WLjE01D0WLjE
00<0PJV109;0R@2B`8T03`2B`8T01021ZH40OjQf07nXMP1oZ7H7086YP@80Ojaj00<0PJV105n3FP1O
PeX00`1OPeX2086YPI80/>3V0@3oool00980/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00L0Sl6G
2021ZH4509g@W`<000001@2Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR
00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?EW003086YP@2McYD0WLjE01@0WLjE
00<0PJV109;0R@2B`8T0302B`8T8086YP@T0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPI80/>3V
0@3oool009<0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00X0Sl6G00@0PJV109kCXP2Ndj80W]>R
1P21ZH4200000080PJV1102Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01L0Y]ZR
00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00G0:?EW003086YP@2McYD0WLjE01D0WLjE
00<0PJV109;0R@2B`8T00P2B`8T:086YP@<0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40Gh=J
05n3FP0305n3FP80PJV1T`2`h>H10?ooo`00U02`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?
`IL00`21ZH40W]>R09kCXP0709kCXP8000000P2Ndj8@086YP@`0Y=RR00<0PJV10:KJXP2VfZ805`2V
fZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01L0XmFL00<0PJV109g>U@2McYD02P2M
cYD@086YP@d0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0205n3FP80PJV1U02`
h>H10?ooo`00U02`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40W]>R09kCXP06
09kCXP<000001@2Ndj800`21ZH40YMbV0:GLYP090:GLYQT0PJV13@2VfZ800`21ZH40YMVP0:GIX00I
0:GIX003086YP@2SeI`0XmFL00/0XmFL6@21ZH4;09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV1
07n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV1U02`h>H10?ooo`00U@2`h>H2086Y
P@D0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0709kCXP030000002Ndj80W]>R
00D0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0:0:SOYSL0PJV1302UfZ000`21
ZH40W]:I09kBV@0D09kBV@03086YP@2Ca8d0TlB=00l0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21
ZH40Gh=J05n3FP0305n3FP80PJV1U@2`h>H10?ooo`00U@2`h>H2086YP@D0LYeo00<0PJV108o1U`2?
`IL02P2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2X
gjH05`2XgjH00`21ZH40YmjT0:ONY00I0:ONY003086YP@2UfZ00YMZP01L0YMZP00<0PJV109kBV@2N
dYT0502NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1O
PeX00`1OPeX00`21ZH40/>3V0;3PiP2D0;3PiP40oooo002F0;3PiP80PJV11@1bWGl00`21ZH40Sl6G
08o1U`0908o1U`03086YP@2Ndj80W]>R00l0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV
0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01T0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I
09kBV@0D09kBV@03086YP@2Ca8d0TlB=00l0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J
05n3FP0305n3FP80PJV1UP2`h>H10?ooo`00U`2`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?
`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2X
gjH00`21ZH40YmjT0:ONY00I0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT0502N
dYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00P1O
PeX2086YPIL0/>3V0@3oool009L0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV1
09kCXP2Ndj803P2Ndj800`21ZH40YMbV0:GLYP0D0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV1
0:ONY02WgZ@06@2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01@0W]:I00<0PJV1
09?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0907n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6G
0;3PiP40oooo002H0;3PiP80PJV1101bWGl00`21ZH40Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R
00h0W]>R00<0PJV10:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgZ@0YmjT
01L0YmjT00<0PJV10:GJX02UfZ005`2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=
00h0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0205n3FP80PJV1V02`h>H10?oo
o`00V@2`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0>09kCXP03
086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003
086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT0502NdYT00`21ZH40TlB=09?4S@0>09?4S@03
086YP@1o[7X0Ojaj00T0Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPIT0/>3V0@3oool009X0/>3V
00<0PJV107:MO`1bWGl00`1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00d0W]>R
00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT
00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00h0TlB=
00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3FP03086YP@2`h>H0/>3V09P0/>3V
0@3oool009/0/>3V0P21ZH4307:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803P2N
dj800`21ZH40YMbV0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2W
gZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d03P2C
a8d00`21ZH40Ojaj07n/NP0907n/NP04086YP@1OPeX0Gh=J05n3FP80PJV1V`2`h>H10?ooo`00W02`
h>H3086YP@80LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0=09kCXP03086YP@2U
g:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2U
fZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0=09?4S@03086YP@1o
[7X0Ojaj00T0Ojaj00<0PJV105n3FP1OPeX00`21ZH6L0;3PiP40oooo002M0;3PiP03086YP@1^VWd0
PJV10080PJV12`2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV0180YMbV00<0PJV1
0:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV1
09kBV@2NdYT04P2NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00T0Ojaj0`21ZH40
0`1LPe/0PJV10;3PiP2L0;3PiP40oooo002N0;3PiP03086YP@1^VWd0KYYm00D0PJV1202?`IL00`21
ZH40W]>R09kCXP0=09kCXP03086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05@2XgjH00`21
ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21
ZH40TlB=09?4S@0=09?4S@03086YP@1o[7X0Ojaj00H0Ojaj1@21ZH4205b3F`03086YP@2`h>H0/>3V
09`0/>3V0@3oool009h0/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^nU@06086YP@80
Sl6G00<0PJV109kCXP2Ndj803@2Ndj800`21ZH40YMbV0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01D0
Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I01<0
W]:I00<0PJV109?4S@2Ca8d03@2Ca8d00`21ZH40Ojaj07n/NP06086YP@80O:]j00<0PJV105b3F`1L
Pe/00P1LPe/00`21ZH40/>3V0;3PiP2L0;3PiP40oooo002O0;3PiP03086YP@1^VWd0KYYm0080KYYm
00<0PJV108^nU@2;_YD01@2;_YD6086YP@d0W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV
0:SOYP0E0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I
09kBV@0B09kBV@03086YP@2Ca8d0TlB=00/0TlB=1P21ZH4707b[NP03086YP@1LPe/0G8=K0080G8=K
00<0PJV10;3PiP2`h>H0W@2`h>H10?ooo`00X02`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;
_YD0RkjE00P0RkjE00<0PJV109_BXP21ZH401@21ZH4709kCXP03086YP@2Ug:H0YMbV0180YMbV00<0
PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0
PJV109kBV@2NdYT04P2NdYT00`21ZH40TlB=09?4S@0509?4S@H0PJV100<0TLB>086YP@1lZgX02@1l
ZgX00`21ZH40G8=K05b3F`0205b3F`03086YP@2`h>H0/>3V09h0/>3V0@3oool00:40/>3V00D0PJV1
06jJO@1^VWd0KYYm086YP@0:08^nU@03086YP@2KdZ80Vm:R00D0Vm:R1P21ZH4209kCXP03086YP@2U
g:H0YMbV0180YMbV00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2U
fZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT04P2NdYT00`21ZH40TlB=09?4S@06086YP@L0TLB>00<0
PJV107b[NP1lZgX0201lZgX01@21ZH40G8=K05b3F`1LPe/0PJV10:40/>3V0@3oool00:80/>3V00D0
PJV106jJO@1^VWd0KYYm086YP@0:08^nU@03086YP@2KdZ80Vm:R00X0Vm:R3@21ZH4:0:GLYP03086Y
P@2XgjH0Z=nV01D0Z=nV00<0PJV10:ONY02WgZ@05@2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086Y
P@2NdYT0W]:I00P0W]:I3@21ZH4<0974SP03086YP@1lZgX0O:]j00P0O:]j00D0PJV105b3F`1LPe/0
G8=K086YP@2R0;3PiP40oooo002S0;3PiP05086YP@1^VWd0KYYm06jJO@21ZH402P2;_YD00`21ZH40
Vm:R09_BXP0<09_BXP03086YP@2Tg:L0Y=bW00L0Y=bW5P21ZH4<0:SOYP03086YP@2WgZ@0YmjT01D0
YmjT00<0PJV10:GJX02UfZ002P2UfZ0F086YP@T0WM>J00<0PJV10974SP2Aa8h0302Aa8h00`21ZH40
O:]j07b[NP0807b[NP05086YP@1LPe/0G8=K05b3F`21ZH40X`2`h>H10?ooo`00Y02`h>H01@21ZH40
KYYm06jJO@1^VWd0PJV100X0RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0A0:CL
Y`03086YP@2Wh:P0Yn2X00T0Yn2X<@21ZH4;0:CKXP03086YP@2MdiX0WM>J0140WM>J00<0PJV10974
SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0807b[NP05086YP@1LPe/0G8=K05b3F`21ZH40Y02`h>H1
0?ooo`00Y02`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0RkjE00<0PJV109_B
XP2KdZ80302KdZ800`21ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:OO
YP2WgjH05@2WgjH00`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J0140WM>J00<0PJV10974
SP2Aa8h0302Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3P
iP2`h>H0XP2`h>H10?ooo`00Y@2`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0
RkjE00<0PJV109_BXP2KdZ80302KdZ800`21ZH40Y=bW0:CLY`0@0:CLY`03086YP@2Wh:P0Yn2X01@0
Yn2X00<0PJV10:OOYP2WgjH05@2WgjH00`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J0100
WM>J00<0PJV10974SP2Aa8h0302Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080
G8=K00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00YP2`h>H00`21ZH40KYYm06jJO@0206jJO@03086Y
P@2;_YD0RkjE00L0RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0A0:CLY`03086Y
P@2Wh:P0Yn2X01<0Yn2X00<0PJV10:OOYP2WgjH05@2WgjH00`21ZH40Y=^R0:CKXP0C0:CKXP03086Y
P@2MdiX0WM>J0140WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0707b[NP03086Y
P@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y`2`h>H2086YP@80KYYm00<0
PJV108^nU@2;_YD0202;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0
PJV10:OPZ02Wh:P0502Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0
PJV109gCVP2MdiX0402MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00P0O:]j00<0
PJV105b3F`1LPe/00P21ZH6W0;3PiP40oooo002X0;3PiP<0PJV100<0KYYm086YP@2;_YD0202;_YD0
0`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P0502Wh:P0
0`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX03`2MdiX0
0`21ZH40TLB>0974SP0<0974SP03086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`21ZH400P21ZH6X
0;3PiP40oooo002Y0;3PiPD0PJV12@2;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW
0100Y=bW00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R
01<0Y=^R00<0PJV109gCVP2MdiX0402MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j
00L0O:]j0`21ZH400`1FO5T0PJV10;3PiP2X0;3PiP40oooo002[0;3PiP03086YP@1UTGH0PJV10080
PJV1202;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02W
h:P04`2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R00<0PJV109gCVP2M
diX03`2MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00H0O:]j0`21ZH400`1FO5T0
PJV10;3PiP2Z0;3PiP40oooo002/0;3PiP03086YP@1UTGH0II5f00D0PJV11@2;_YD00`21ZH40Vm:R
09_BXP0:09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV
0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX0402MdiX00`21ZH40TLB>
0974SP0:0974SP03086YP@1lZgX0O:]j00<0O:]j1@21ZH4205IlF@03086YP@2`h>H0/>3V0:X0/>3V
0@3oool00:d0/>3V00@0PJV106FAMP1UTGH0PJV10`21]8h4086YP@0308^nU@21ZH40Vm:R00`0Vm:R
00<0PJV10:CLY`2Tg:L03`2Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2WgjH0YmnV01<0YmnV
00<0PJV10:CKXP2Tfj804P2Tfj800`21ZH40WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00/0TLB>
00<0PJV107b[NP21ZH400`21ZH4307BSMP04086YP@1FO5T0EWaI086YPJd0/>3V0@3oool00:h0/>3V
0P21ZH400`1UTGH0PJV1086YP@05086dSPH0PJV12P2KdZ800`21ZH40Y=bW0:CLY`0>0:CLY`03086Y
P@2Wh:P0Yn2X0180Yn2X00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086Y
P@2MdiX0WM>J00h0WM>J00<0PJV10974SP2Aa8h0202Aa8h6086YP@D0M:=f0P21ZH400`1FO5T0PJV1
086YP@2^0;3PiP40oooo002`0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`0
2021ZH4209_BXP03086YP@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV
0:OOYP0A0:OOYP03086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40TLB>
0974SP08086YP@80RKf:00<0PJV107BSMP1dXgH01@1dXgH01021ZH40EWaI05IlF@21ZH6`0;3PiP40
oooo002a0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`01`2BbY`8086YP@`0
Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0A0:OOYP03086YP@2Tfj80Y=^R0180
Y=^R00<0PJV109gCVP2MdiX02P2MdiX8086YP@T0RKf:00<0PJV107BSMP1dXgH01@1dXgH01021ZH40
EWaI05IlF@21ZH6a0;3PiP40oooo002b0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:
W02BbY`02P2BbY`01021ZH40W=JS09cFX`2LeZ<9086YP@@0Y=bW00<0PJV10:OPZ02Wh:P04@2Wh:P0
0`21ZH40YmnV0:OOYP0A0:OOYP03086YP@2Tfj80Y=^R0140Y=^R00<0PJV109gCVP2MdiX00P2MdiX9
086YP@<0U/fG00<0PJV108VmRP29_HX02P29_HX00`21ZH40M:=f07BSMP0507BSMP04086YP@1FO5T0
EWaI086YPK80/>3V0@3oool00;<0/>3V0P21ZH400`1UTGH0PJV1086dSP06086dSP03086YP@2BbY`0
T/ZL00X0T/ZL00<0PJV109cFX`2LeZ<02@2LeZ=5086YP@/0U/fG00<0PJV108VmRP29_HX02P29_HX0
0`21ZH40M:=f07BSMP0507BSMP04086YP@1FO5T0PJV1086YPK<0/>3V0@3oool00;D0/>3V00<0PJV1
06FAMP21ZH401`21]8h00`21ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00d0W=JS00<0PJV1
0:7KY@2QfjD04@2QfjD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Neil0W]NO0100W]NO00<0PJV1
09K=U`2FcIL03P2FcIL00`21ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f00D0M:=f00<0PJV1
05IlF@21ZH40]@2`h>H10?ooo`00]P2`h>H01021ZH40II5f086YP@21ZH46086dSP03086YP@2BbY`0
T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<03@2LeZ<00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Qfj@0
XM^T0140XM^T00<0PJV109kGW`2Neil0402Neil00`21ZH40U/fG09K=U`0=09K=U`03086YP@29_HX0
RKf:00T0RKf:00<0PJV107BSMP1dXgH0101dXgH2086YP@0305IlF@21ZH40/>3V0;D0/>3V0@3oool0
0;L0/>3V0P21ZH400`1UTGH0PJV1086dSP05086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cF
X`2LeZ<0302LeZ<00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kG
W`2Neil0402Neil00`21ZH40U/fG09K=U`0=09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BS
MP1dXgH0101dXgH01021ZH40EWaI086YP@21ZH6g0;3PiP40oooo002i0;3PiP<0PJV11P21]8h00`21
ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00`0W=JS00<0PJV10:7KY@2QfjD0402QfjD00`21
ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO0100W]NO00<0PJV109K=U`2FcIL0302FcIL00`21
ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f00@0M:=f0`21ZH6i0;3PiP40oooo002k0;3PiP@0
PJV11021]8h00`21ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00/0W=JS00<0PJV10:7KY@2Q
fjD0402QfjD00`21ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO00l0W]NO00<0PJV109K=U`2F
cIL0302FcIL00`21ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f0080M:=f1021ZH6k0;3PiP40
oooo002m0;3PiPH0PJV100<0PKB>086YP@2BbY`02P2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086Y
P@2QfjD0XM^U00l0XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0?09kGW`03086Y
P@2FcIL0U/fG00/0U/fG00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f086YP@05086YPKd0/>3V
0@3oool00;h0/>3V0`21ZH42072PO`H0PJV11`2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2Q
fjD0XM^U00l0XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0>09kGW`03086YP@2F
cIL0U/fG00`0U/fG00<0PJV108VmRP29_HX01@29_HX6086YP@80II9/0`21ZH6n0;3PiP40oooo0030
0;3PiP<0PJV10`1`X7l2086YP@0308:gSP21ZH40PJV100@0PJV10P2BbY`00`21ZH40W=JS09cFX`0;
09cFX`03086YP@2QfjD0XM^U00h0XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0>
09kGW`03086YP@2FcIL0U/fG00/0U/fG00<0PJV108VmRP29_HX01P21ZH400`1i[7l0PJV1086YP@03
06FBK0<0PJV1`02`h>H10?ooo`00`P2`h>H3086YP@<0L:1o0P21ZH4508:gSPX0PJV11P2LeZ<00`21
ZH40XM^U0:7KY@0?0:7KY@03086YP@2Qfj@0XM^T00d0XM^T00<0PJV109kGW`2Neil03P2Neil00`21
ZH40U/fG09K=U`0509K=U`X0PJV11@1i[7l2086YP@<0II9/0`21ZH720;3PiP40oooo00340;3PiP<0
PJV10`1`X7l00`21ZH40P[N>08:gSP0608:gSP80PJV1102=a9L@086YP@P0XM^U00<0PJV10:7KY02Q
fj@03@2Qfj@00`21ZH40W]NO09kGW`0609kGWa00PJV11027_Hd2086YP@P0NJao00@0PJV106FBK01U
TV`0II9/0`21ZH740;3PiP40oooo00360;3PiP<0PJV10P1`X7l2086YP@P0P[N>00<0PJV108g4U`2=
a9L02@2=a9L00`21ZH40T/^J09;;VP0509;;VR40PJV11`2?aiD00`21ZH40Qkf=08NmS@0908NmS@03
086YP@1i[7l0NJao00H0NJao0P21ZH4206FBK0<0PJV1aP2`h>H10?ooo`00b02`h>H3086YP@80L:1o
00<0PJV108:gSP22]hh01P22]hh00`21ZH40SLBG08g4U`0908g4U`03086YP@2BbiX0T/^J00`0T/^J
00<0PJV109?<VP2Cc9X03@2Cc9X00`21ZH40SlNE08o7U@0<08o7U@03086YP@27_Hd0Qkf=00T0Qkf=
00<0PJV107V/O`1i[7l01P1i[7l00`21ZH40II9/06FBK003086YPLP0/>3V0@3oool00<X0/>3V0`21
ZH400`1`X7l0PJV1086YP@0708:gSP80PJV12P2=a9L00`21ZH40T/^J09;;VP0<09;;VP03086YP@2C
c9X0TlbJ00/0TlbJ00<0PJV108o7U@2?aiD0302?aiD00`21ZH40Qkf=08NmS@0808NmS@80PJV11`1i
[7l2086YP@0406FBK021ZH40PJV1086YPLX0/>3V0@3oool00<d0/>3V1@21ZH4708:gSP03086YP@2=
a9L0SLBG00L0SLBG00<0PJV109;;VP2BbiX0302BbiX00`21ZH40TlbJ09?<VP0;09?<VP03086YP@2?
aiD0SlNE00/0SlNE00<0PJV108NmS@27_Hd02027_Hd00`21ZH40NJao07V/O`0507V/O`D0PJV1c@2`
h>H10?ooo`00d02`h>H7086YP@<0P[N>0P21ZH4808g4U`03086YP@2BbiX0T/^J00/0T/^J00<0PJV1
09?<VP2Cc9X02`2Cc9X00`21ZH40SlNE08o7U@0;08o7U@03086YP@27_Hd0Qkf=00H0Qkf=0P21ZH43
07V/O`L0PJV1d02`h>H10?ooo`00d`2`h>H<086YP@H0SLBG00<0PJV109;;VP2BbiX02P2BbiX00`21
ZH40TlbJ09?<VP0;09?<VP03086YP@2?aiD0SlNE00X0SlNE00<0PJV108NmS@27_Hd01027_Hd8086Y
P@04066>J`21ZH40PJV1086YPM<0/>3V0@3oool00=H0/>3V1@21ZH4206NGM`P0PJV100<0SLBG086Y
P@2BbiX02`2BbiX00`21ZH40TlbJ09?<VP0909?<VP03086YP@2?aiD0SlNE00X0SlNE00<0PJV108Nm
S@21ZH401`21ZH44066>J`<0PJV1eP2`h>H10?ooo`00f@2`h>H5086YP@0306NGM`21ZH40PJV100@0
LJAo:@21ZH4406fNM`80PJV10P1QSV/4086YPMT0/>3V0@3oool00=d0/>3V1P21ZH45076TO`80PJV1
2@1gZh<00`21ZH40N:b307R/P`0807R/P`03086YP@1eZ7l0MJQo00P0MJQo0P21ZH4506fNM`80PJV1
00@0HHi[086YP@21ZH40PJV1g@2`h>H10?ooo`00h@2`h>H4086YP@D0LJAo0P21ZH4807N[P`03086Y
P@1h[8<0N:b300L0N:b300<0PJV107FXO`1eZ7l01P1eZ7l2086YP@D0KIig1021ZH7Q0;3PiP40oooo
003U0;3PiP`0PJV10`1gZh<00`21ZH40N:b307R/P`0607R/P`03086YP@1eZ7l0MJQo0080MJQo3021
ZH7U0;3PiP40oooo003`0;3PiQ<0PJV1l02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.605 .777 .566 r
.4503 .46959 m .4498 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.605 .777 .566 r
.48991 .5 m .49001 .46977 L .4503 .46959 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.49001 .53023 m .48991 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.49001 .46977 m .48991 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.48991 .5 m .49001 .53023 L .52992 .53029 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.52992 .53029 m .53022 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.53022 .5 m .52992 .46971 L .49001 .46977 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.52992 .46971 m .53022 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.53022 .5 m .52992 .53029 L .56922 .53059 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.56922 .53059 m .56993 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.45183 .43953 m .4503 .46959 L .49001 .46977 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.49001 .46977 m .49032 .43988 L .45183 .43953 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.4498 .5 m .4503 .53041 L .49001 .53023 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.49032 .56012 m .49001 .53023 L .4503 .53041 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.49032 .43988 m .49001 .46977 L .52992 .46971 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.49001 .53023 m .49032 .56012 L .529 .56024 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.529 .56024 m .52992 .53029 L .49001 .53023 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.52992 .46971 m .529 .43976 L .49032 .43988 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.529 .43976 m .52992 .46971 L .56922 .46941 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.56993 .5 m .56922 .46941 L .52992 .46971 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.52992 .53029 m .529 .56024 L .56709 .56082 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.56709 .56082 m .56922 .53059 L .52992 .53029 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.41161 .46916 m .41069 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.4498 .5 m .4503 .46959 L .41161 .46916 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.4503 .53041 m .4498 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.41436 .43871 m .41161 .46916 L .4503 .46959 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.4503 .46959 m .45183 .43953 L .41436 .43871 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.41069 .5 m .41161 .53084 L .4503 .53041 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.45183 .56047 m .4503 .53041 L .41161 .53084 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.4503 .53041 m .45183 .56047 L .49032 .56012 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.45437 .41018 m .45183 .43953 L .49032 .43988 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.49032 .43988 m .49082 .41067 L .45437 .41018 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.49082 .41067 m .49032 .43988 L .529 .43976 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.49082 .58933 m .49032 .56012 L .45183 .56047 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.49032 .56012 m .49082 .58933 L .52748 .58949 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.52748 .58949 m .529 .56024 L .49032 .56012 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.529 .43976 m .52748 .41051 L .49082 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.52748 .41051 m .529 .43976 L .56709 .43918 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.56922 .46941 m .56709 .43918 L .529 .43976 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.529 .56024 m .52748 .58949 L .56352 .59032 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.56352 .59032 m .56709 .56082 L .529 .56024 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.56922 .46941 m .56993 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.56993 .5 m .56922 .53059 L .60709 .53114 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.60709 .53114 m .60821 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.56709 .43918 m .56922 .46941 L .60709 .46886 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.60821 .5 m .60709 .46886 L .56922 .46941 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.56922 .53059 m .56709 .56082 L .60373 .56188 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.60373 .56188 m .60709 .53114 L .56922 .53059 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.41894 .40902 m .41436 .43871 L .45183 .43953 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.45183 .43953 m .45437 .41018 L .41894 .40902 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.41161 .53084 m .41436 .56129 L .45183 .56047 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.45437 .58982 m .45183 .56047 L .41436 .56129 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.45183 .56047 m .45437 .58982 L .49082 .58933 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.37481 .46849 m .37348 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.41069 .5 m .41161 .46916 L .37481 .46849 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.41161 .53084 m .41069 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.45794 .38193 m .45437 .41018 L .49082 .41067 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.49082 .41067 m .49154 .38253 L .45794 .38193 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.49154 .61747 m .49082 .58933 L .45437 .58982 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.49154 .38253 m .49082 .41067 L .52748 .41051 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.49082 .58933 m .49154 .61747 L .52534 .61767 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.52534 .61767 m .52748 .58949 L .49082 .58933 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.56709 .43918 m .56352 .40968 L .52748 .41051 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.56352 .40968 m .56709 .43918 L .60373 .43812 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.60709 .46886 m .60373 .43812 L .56709 .43918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.56709 .56082 m .56352 .59032 L .59813 .5918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.59813 .5918 m .60373 .56188 L .56709 .56082 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.37878 .43741 m .37481 .46849 L .41161 .46916 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.41161 .46916 m .41436 .43871 L .37878 .43741 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.37348 .5 m .37481 .53151 L .41161 .53084 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.41436 .56129 m .41161 .53084 L .37481 .53151 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.52748 .41051 m .52534 .38233 L .49154 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.52534 .38233 m .52748 .41051 L .56352 .40968 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.52748 .58949 m .52534 .61767 L .55853 .61867 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.55853 .61867 m .56352 .59032 L .52748 .58949 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.42535 .38053 m .41894 .40902 L .45437 .41018 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.45437 .41018 m .45794 .38193 L .42535 .38053 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.41436 .56129 m .41894 .59098 L .45437 .58982 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.45794 .61807 m .45437 .58982 L .41894 .59098 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.45437 .58982 m .45794 .61807 L .49154 .61747 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.38539 .40721 m .37878 .43741 L .41436 .43871 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.41436 .43871 m .41894 .40902 L .38539 .40721 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.37481 .53151 m .37878 .56259 L .41436 .56129 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.41894 .59098 m .41436 .56129 L .37878 .56259 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.60709 .46886 m .60821 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.60821 .5 m .60709 .53114 L .64258 .53194 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.64258 .53194 m .64411 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.56352 .40968 m .55853 .38133 L .52534 .38233 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.55853 .38133 m .56352 .40968 L .59813 .4082 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.60373 .43812 m .59813 .4082 L .56352 .40968 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.56352 .59032 m .55853 .61867 L .59031 .62047 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.59031 .62047 m .59813 .5918 L .56352 .59032 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.60373 .43812 m .60709 .46886 L .64258 .46806 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.64411 .5 m .64258 .46806 L .60709 .46886 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.60709 .53114 m .60373 .56188 L .63799 .56341 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.63799 .56341 m .64258 .53194 L .60709 .53114 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.46253 .35521 m .45794 .38193 L .49154 .38253 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.49154 .38253 m .49246 .35586 L .46253 .35521 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.49246 .64414 m .49154 .61747 L .45794 .61807 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.49246 .35586 m .49154 .38253 L .52534 .38233 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.49154 .61747 m .49246 .64414 L .52258 .64436 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.52258 .64436 m .52534 .61767 L .49154 .61747 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.52534 .38233 m .52258 .35564 L .49246 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.52258 .35564 m .52534 .38233 L .55853 .38133 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.52534 .61767 m .52258 .64436 L .55212 .64545 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.55212 .64545 m .55853 .61867 L .52534 .61767 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.59813 .4082 m .60373 .43812 L .63799 .43659 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.64258 .46806 m .63799 .43659 L .60373 .43812 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.60373 .56188 m .59813 .5918 L .63037 .59394 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.63037 .59394 m .63799 .56341 L .60373 .56188 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.39462 .37834 m .38539 .40721 L .41894 .40902 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.41894 .40902 m .42535 .38053 L .39462 .37834 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.37878 .56259 m .38539 .59279 L .41894 .59098 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.42535 .61947 m .41894 .59098 L .38539 .59279 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.41894 .59098 m .42535 .61947 L .45794 .61807 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.43357 .35368 m .42535 .38053 L .45794 .38193 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.45794 .38193 m .46253 .35521 L .43357 .35368 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.46253 .64479 m .45794 .61807 L .42535 .61947 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.45794 .61807 m .46253 .64479 L .49246 .64414 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.3409 .46758 m .33917 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.37348 .5 m .37481 .46849 L .3409 .46758 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.37481 .53151 m .37348 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.3461 .43565 m .3409 .46758 L .37481 .46849 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.37481 .46849 m .37878 .43741 L .3461 .43565 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.33917 .5 m .3409 .53242 L .37481 .53151 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.37878 .56259 m .37481 .53151 L .3409 .53242 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.55853 .38133 m .55212 .35455 L .52258 .35564 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.55212 .35455 m .55853 .38133 L .59031 .37953 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.59813 .4082 m .59031 .37953 L .55853 .38133 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.55853 .61867 m .55212 .64545 L .58028 .6474 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.58028 .6474 m .59031 .62047 L .55853 .61867 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37768 .56372 m
.37932 .56505 L
s
.5 Mabswid
.641 .842 .634 r
.59031 .37953 m .59813 .4082 L .63037 .40606 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.63799 .43659 m .63037 .40606 L .59813 .4082 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.59813 .5918 m .59031 .62047 L .61975 .62304 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.61975 .62304 m .63037 .59394 L .59813 .5918 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.35472 .40475 m .3461 .43565 L .37878 .43741 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.37878 .43741 m .38539 .40721 L .35472 .40475 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.3409 .53242 m .3461 .56435 L .37878 .56259 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.38539 .59279 m .37878 .56259 L .3461 .56435 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.40642 .3513 m .39462 .37834 L .42535 .38053 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.42535 .38053 m .43357 .35368 L .40642 .3513 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.38539 .59279 m .39462 .62166 L .42535 .61947 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.43357 .64632 m .42535 .61947 L .39462 .62166 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.42535 .61947 m .43357 .64632 L .46253 .64479 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.64258 .46806 m .64411 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.64411 .5 m .64258 .53194 L .6746 .53297 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.6746 .53297 m .67654 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.46813 .3305 m .46253 .35521 L .49246 .35586 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.49246 .35586 m .49358 .33115 L .46813 .3305 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.49358 .33115 m .49246 .35586 L .52258 .35564 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.49358 .66885 m .49246 .64414 L .46253 .64479 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.49246 .64414 m .49358 .66885 L .51922 .66907 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.51922 .66907 m .52258 .64436 L .49246 .64414 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.52258 .35564 m .51922 .33093 L .49358 .33115 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.51922 .33093 m .52258 .35564 L .55212 .35455 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.52258 .64436 m .51922 .66907 L .5443 .67015 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.5443 .67015 m .55212 .64545 L .52258 .64436 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.63799 .43659 m .64258 .46806 L .6746 .46703 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.67654 .5 m .6746 .46703 L .64258 .46806 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.64258 .53194 m .63799 .56341 L .66881 .5654 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.66881 .5654 m .6746 .53297 L .64258 .53194 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.3667 .37538 m .35472 .40475 L .38539 .40721 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.38539 .40721 m .39462 .37834 L .3667 .37538 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.3461 .56435 m .35472 .59525 L .38539 .59279 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.39462 .62166 m .38539 .59279 L .35472 .59525 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.44359 .32898 m .43357 .35368 L .46253 .35521 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.46253 .35521 m .46813 .3305 L .44359 .32898 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.46813 .6695 m .46253 .64479 L .43357 .64632 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.46253 .64479 m .46813 .6695 L .49358 .66885 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.59031 .37953 m .58028 .3526 L .55212 .35455 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.58028 .3526 m .59031 .37953 L .61975 .37696 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.63037 .40606 m .61975 .37696 L .59031 .37953 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.59031 .62047 m .58028 .6474 L .60621 .6502 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.60621 .6502 m .61975 .62304 L .59031 .62047 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.63037 .40606 m .63799 .43659 L .66881 .4346 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.6746 .46703 m .66881 .4346 L .63799 .43659 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.63799 .56341 m .63037 .59394 L .65921 .59672 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.65921 .59672 m .66881 .5654 L .63799 .56341 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.55212 .35455 m .5443 .32985 L .51922 .33093 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.5443 .32985 m .55212 .35455 L .58028 .3526 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.55212 .64545 m .5443 .67015 L .5681 .67209 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.5681 .67209 m .58028 .6474 L .55212 .64545 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.42073 .32662 m .40642 .3513 L .43357 .35368 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.43357 .35368 m .44359 .32898 L .42073 .32662 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.39462 .62166 m .40642 .6487 L .43357 .64632 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.44359 .67102 m .43357 .64632 L .40642 .6487 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.43357 .64632 m .44359 .67102 L .46813 .6695 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.61975 .37696 m .63037 .40606 L .65921 .40328 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.66881 .4346 m .65921 .40328 L .63037 .40606 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.63037 .59394 m .61975 .62304 L .64589 .62639 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.64589 .62639 m .65921 .59672 L .63037 .59394 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.31108 .46642 m .30894 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.33917 .5 m .3409 .46758 L .31108 .46642 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.3409 .53242 m .33917 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.38195 .34809 m .3667 .37538 L .39462 .37834 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.39462 .37834 m .40642 .3513 L .38195 .34809 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.35472 .59525 m .3667 .62462 L .39462 .62166 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.40642 .6487 m .39462 .62166 L .3667 .62462 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.31746 .43343 m .31108 .46642 L .3409 .46758 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.3409 .46758 m .3461 .43565 L .31746 .43343 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.30894 .5 m .31108 .53358 L .3409 .53242 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.3461 .56435 m .3409 .53242 L .31108 .53358 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.32801 .40165 m .31746 .43343 L .3461 .43565 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.3461 .43565 m .35472 .40475 L .32801 .40165 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.31108 .53358 m .31746 .56657 L .3461 .56435 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.35472 .59525 m .3461 .56435 L .31746 .56657 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.58028 .3526 m .5681 .32791 L .5443 .32985 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.5681 .32791 m .58028 .3526 L .60621 .3498 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.61975 .37696 m .60621 .3498 L .58028 .3526 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58028 .6474 m .5681 .67209 L .58983 .67486 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58983 .67486 m .60621 .6502 L .58028 .6474 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.47472 .30833 m .46813 .3305 L .49358 .33115 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.49358 .33115 m .4949 .30892 L .47472 .30833 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.4949 .30892 m .49358 .33115 L .51922 .33093 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.4949 .69108 m .49358 .66885 L .46813 .6695 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.49358 .66885 m .4949 .69108 L .51525 .69128 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.51525 .69128 m .51922 .66907 L .49358 .66885 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.51922 .33093 m .51525 .30872 L .4949 .30892 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.51525 .30872 m .51922 .33093 L .5443 .32985 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.51922 .66907 m .51525 .69128 L .5351 .69225 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.5351 .69225 m .5443 .67015 L .51922 .66907 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.60621 .3498 m .61975 .37696 L .64589 .37361 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.65921 .40328 m .64589 .37361 L .61975 .37696 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.61975 .62304 m .60621 .6502 L .62899 .65381 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.62899 .65381 m .64589 .62639 L .61975 .62304 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.45535 .30698 m .44359 .32898 L .46813 .3305 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.46813 .3305 m .47472 .30833 L .45535 .30698 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.47472 .69167 m .46813 .6695 L .44359 .67102 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.46813 .6695 m .47472 .69167 L .4949 .69108 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.34262 .37167 m .32801 .40165 L .35472 .40475 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.35472 .40475 m .3667 .37538 L .34262 .37167 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.31746 .56657 m .32801 .59835 L .35472 .59525 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.3667 .62462 m .35472 .59525 L .32801 .59835 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40032 .32347 m .38195 .34809 L .40642 .3513 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40642 .3513 m .42073 .32662 L .40032 .32347 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.3667 .62462 m .38195 .65191 L .40642 .6487 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.42073 .67338 m .40642 .6487 L .38195 .65191 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.40642 .6487 m .42073 .67338 L .44359 .67102 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.5443 .32985 m .5351 .30775 L .51525 .30872 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5351 .30775 m .5443 .32985 L .5681 .32791 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.5443 .67015 m .5351 .69225 L .55383 .69398 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.55383 .69398 m .5681 .67209 L .5443 .67015 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.6746 .46703 m .67654 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.67654 .5 m .6746 .53297 L .70188 .53425 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.70188 .53425 m .70421 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.66881 .4346 m .6746 .46703 L .70188 .46575 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.70421 .5 m .70188 .46575 L .6746 .46703 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.6746 .53297 m .66881 .5654 L .69493 .56784 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.69493 .56784 m .70188 .53425 L .6746 .53297 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.43743 .30488 m .42073 .32662 L .44359 .32898 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.44359 .32898 m .45535 .30698 L .43743 .30488 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.45535 .69302 m .44359 .67102 L .42073 .67338 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.44359 .67102 m .45535 .69302 L .47472 .69167 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.65921 .40328 m .66881 .4346 L .69493 .43216 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.70188 .46575 m .69493 .43216 L .66881 .4346 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.66881 .5654 m .65921 .59672 L .68346 .60013 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.68346 .60013 m .69493 .56784 L .66881 .5654 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3611 .34411 m .34262 .37167 L .3667 .37538 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3667 .37538 m .38195 .34809 L .3611 .34411 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.32801 .59835 m .34262 .62833 L .3667 .62462 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.38195 .65191 m .3667 .62462 L .34262 .62833 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.60621 .3498 m .58983 .32514 L .5681 .32791 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.58983 .32514 m .60621 .3498 L .62899 .34619 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.64589 .37361 m .62899 .34619 L .60621 .3498 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.60621 .6502 m .58983 .67486 L .6087 .6784 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.6087 .6784 m .62899 .65381 L .60621 .6502 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5681 .32791 m .55383 .30602 L .5351 .30775 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.55383 .30602 m .5681 .32791 L .58983 .32514 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.5681 .67209 m .55383 .69398 L .57077 .69644 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.57077 .69644 m .58983 .67486 L .5681 .67209 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.64589 .37361 m .65921 .40328 L .68346 .39987 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.69493 .43216 m .68346 .39987 L .65921 .40328 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.65921 .59672 m .64589 .62639 L .66762 .63045 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.66762 .63045 m .68346 .60013 L .65921 .59672 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42163 .30208 m .40032 .32347 L .42073 .32662 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42073 .32662 m .43743 .30488 L .42163 .30208 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.38195 .65191 m .40032 .67653 L .42073 .67338 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.43743 .69512 m .42073 .67338 L .40032 .67653 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.42073 .67338 m .43743 .69512 L .45535 .69302 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.28671 .46503 m .2842 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.30894 .5 m .31108 .46642 L .28671 .46503 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.31108 .53358 m .30894 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.48228 .28932 m .47472 .30833 L .4949 .30892 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.4949 .30892 m .49643 .28977 L .48228 .28932 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.49643 .28977 m .4949 .30892 L .51525 .30872 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.49643 .71023 m .4949 .69108 L .47472 .69167 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.4949 .69108 m .49643 .71023 L .51069 .71038 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51069 .71038 m .51525 .69128 L .4949 .69108 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.51525 .30872 m .51069 .28962 L .49643 .28977 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.51069 .28962 m .51525 .30872 L .5351 .30775 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.51525 .69128 m .51069 .71038 L .52458 .71113 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.52458 .71113 m .5351 .69225 L .51525 .69128 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.2942 .43077 m .28671 .46503 L .31108 .46642 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.31108 .46642 m .31746 .43343 L .2942 .43077 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.2842 .5 m .28671 .53497 L .31108 .53358 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.31746 .56657 m .31108 .53358 L .28671 .53497 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.3832 .31957 m .3611 .34411 L .38195 .34809 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.38195 .34809 m .40032 .32347 L .3832 .31957 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.34262 .62833 m .3611 .65589 L .38195 .65191 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.40032 .67653 m .38195 .65191 L .3611 .65589 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.62899 .34619 m .64589 .37361 L .66762 .36955 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.68346 .39987 m .66762 .36955 L .64589 .37361 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64589 .62639 m .62899 .65381 L .64765 .65816 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64765 .65816 m .66762 .63045 L .64589 .62639 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.46877 .28827 m .45535 .30698 L .47472 .30833 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.47472 .30833 m .48228 .28932 L .46877 .28827 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.48228 .71068 m .47472 .69167 L .45535 .69302 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47472 .69167 m .48228 .71068 L .49643 .71023 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.30655 .39796 m .2942 .43077 L .31746 .43343 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.31746 .43343 m .32801 .40165 L .30655 .39796 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.28671 .53497 m .2942 .56923 L .31746 .56657 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.32801 .59835 m .31746 .56657 L .2942 .56923 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.5351 .30775 m .52458 .28887 L .51069 .28962 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.52458 .28887 m .5351 .30775 L .55383 .30602 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5351 .69225 m .52458 .71113 L .5376 .71246 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5376 .71246 m .55383 .69398 L .5351 .69225 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.58983 .32514 m .57077 .30356 L .55383 .30602 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.57077 .30356 m .58983 .32514 L .6087 .3216 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.62899 .34619 m .6087 .3216 L .58983 .32514 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58983 .67486 m .57077 .69644 L .58528 .69956 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58528 .69956 m .6087 .6784 L .58983 .67486 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45638 .28667 m .43743 .30488 L .45535 .30698 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45535 .30698 m .46877 .28827 L .45638 .28667 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.46877 .71173 m .45535 .69302 L .43743 .69512 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.45535 .69302 m .46877 .71173 L .48228 .71068 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32354 .36727 m .30655 .39796 L .32801 .40165 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32801 .40165 m .34262 .37167 L .32354 .36727 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.2942 .56923 m .30655 .60204 L .32801 .59835 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.34262 .62833 m .32801 .59835 L .30655 .60204 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.6087 .3216 m .62899 .34619 L .64765 .34184 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.66762 .36955 m .64765 .34184 L .62899 .34619 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62899 .65381 m .6087 .6784 L .62388 .68263 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62388 .68263 m .64765 .65816 L .62899 .65381 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.55383 .30602 m .5376 .28754 L .52458 .28887 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.5376 .28754 m .55383 .30602 L .57077 .30356 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.55383 .69398 m .5376 .71246 L .54924 .71433 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.54924 .71433 m .57077 .69644 L .55383 .69398 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40859 .29866 m .3832 .31957 L .40032 .32347 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40032 .32347 m .42163 .30208 L .40859 .29866 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.3611 .65589 m .3832 .68043 L .40032 .67653 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.42163 .69792 m .40032 .67653 L .3832 .68043 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.40032 .67653 m .42163 .69792 L .43743 .69512 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34488 .33941 m .32354 .36727 L .34262 .37167 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34262 .37167 m .3611 .34411 L .34488 .33941 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.30655 .60204 m .32354 .63273 L .34262 .62833 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.3611 .65589 m .34262 .62833 L .32354 .63273 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.70188 .46575 m .70421 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.70421 .5 m .70188 .53425 L .72294 .53575 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.72294 .53575 m .72562 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.69493 .43216 m .70188 .46575 L .72294 .46425 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.72562 .5 m .72294 .46425 L .70188 .46575 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.70188 .53425 m .69493 .56784 L .71494 .57071 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.71494 .57071 m .72294 .53575 L .70188 .53425 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69258 .42384 m
.69405 .42545 L
s
.69258 .42384 m
.69295 .42199 L
s
.5 Mabswid
.606 .825 .61 r
.4456 .28455 m .42163 .30208 L .43743 .30488 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.43743 .30488 m .45638 .28667 L .4456 .28455 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45638 .71333 m .43743 .69512 L .42163 .69792 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.43743 .69512 m .45638 .71333 L .46877 .71173 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.68346 .39987 m .69493 .43216 L .71494 .42929 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.72294 .46425 m .71494 .42929 L .69493 .43216 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.69493 .56784 m .68346 .60013 L .70178 .6041 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.70178 .6041 m .71494 .57071 L .69493 .56784 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.57077 .30356 m .54924 .28567 L .5376 .28754 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.54924 .28567 m .57077 .30356 L .58528 .30044 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.6087 .3216 m .58528 .30044 L .57077 .30356 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.57077 .69644 m .54924 .71433 L .55905 .71669 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.55905 .71669 m .58528 .69956 L .57077 .69644 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.37018 .31502 m .34488 .33941 L .3611 .34411 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.3611 .34411 m .3832 .31957 L .37018 .31502 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.32354 .63273 m .34488 .66059 L .3611 .65589 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.3832 .68043 m .3611 .65589 L .34488 .66059 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.58528 .30044 m .6087 .3216 L .62388 .31737 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.64765 .34184 m .62388 .31737 L .6087 .3216 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.6087 .6784 m .58528 .69956 L .59668 .70325 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.59668 .70325 m .62388 .68263 L .6087 .6784 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.66762 .36955 m .68346 .39987 L .70178 .3959 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.71494 .42929 m .70178 .3959 L .68346 .39987 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68346 .60013 m .66762 .63045 L .68373 .63515 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68373 .63515 m .70178 .6041 L .68346 .60013 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49074 .27412 m .48228 .28932 L .49643 .28977 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49643 .28977 m .49813 .27437 L .49074 .27412 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.49813 .27437 m .49643 .28977 L .51069 .28962 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49813 .72563 m .49643 .71023 L .48228 .71068 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49643 .71023 m .49813 .72563 L .50559 .72571 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.50559 .72571 m .51069 .71038 L .49643 .71023 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.51069 .28962 m .50559 .27429 L .49813 .27437 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.50559 .27429 m .51069 .28962 L .52458 .28887 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51069 .71038 m .50559 .72571 L .51284 .72613 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51284 .72613 m .52458 .71113 L .51069 .71038 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48372 .27353 m .46877 .28827 L .48228 .28932 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48228 .28932 m .49074 .27412 L .48372 .27353 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.49074 .72588 m .48228 .71068 L .46877 .71173 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.48228 .71068 m .49074 .72588 L .49813 .72563 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.64765 .34184 m .66762 .36955 L .68373 .36485 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.70178 .3959 m .68373 .36485 L .66762 .36955 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66762 .63045 m .64765 .65816 L .66116 .66317 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66116 .66317 m .68373 .63515 L .66762 .63045 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.52458 .28887 m .51284 .27387 L .50559 .27429 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.51284 .27387 m .52458 .28887 L .5376 .28754 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.52458 .71113 m .51284 .72613 L .51957 .72688 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.51957 .72688 m .5376 .71246 L .52458 .71113 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.43688 .28198 m .40859 .29866 L .42163 .30208 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.42163 .30208 m .4456 .28455 L .43688 .28198 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.3832 .68043 m .40859 .70134 L .42163 .69792 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.4456 .71545 m .42163 .69792 L .40859 .70134 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.42163 .69792 m .4456 .71545 L .45638 .71333 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.47734 .27264 m .45638 .28667 L .46877 .28827 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.46877 .28827 m .48372 .27353 L .47734 .27264 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.48372 .72647 m .46877 .71173 L .45638 .71333 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.46877 .71173 m .48372 .72647 L .49074 .72588 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.39896 .29471 m .37018 .31502 L .3832 .31957 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.3832 .31957 m .40859 .29866 L .39896 .29471 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.34488 .66059 m .37018 .68498 L .3832 .68043 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.40859 .70134 m .3832 .68043 L .37018 .68498 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.5376 .28754 m .51957 .27312 L .51284 .27387 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.51957 .27312 m .5376 .28754 L .54924 .28567 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.5376 .71246 m .51957 .72688 L .52552 .72791 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.52552 .72791 m .54924 .71433 L .5376 .71246 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.26939 .46342 m .26655 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.2842 .5 m .28671 .46503 L .26939 .46342 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.28671 .53497 m .2842 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.27785 .42772 m .26939 .46342 L .28671 .46503 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.28671 .46503 m .2942 .43077 L .27785 .42772 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.26655 .5 m .26939 .53658 L .28671 .53497 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.2942 .56923 m .28671 .53497 L .26939 .53658 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.62388 .31737 m .64765 .34184 L .66116 .33683 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.68373 .36485 m .66116 .33683 L .64765 .34184 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.64765 .65816 m .62388 .68263 L .63452 .68746 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.63452 .68746 m .66116 .66317 L .64765 .65816 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.58528 .30044 m .55905 .28331 L .54924 .28567 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.55905 .28331 m .58528 .30044 L .59668 .29675 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.62388 .31737 m .59668 .29675 L .58528 .30044 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.58528 .69956 m .55905 .71669 L .56657 .71945 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.56657 .71945 m .59668 .70325 L .58528 .69956 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.29173 .39373 m .27785 .42772 L .2942 .43077 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.2942 .43077 m .30655 .39796 L .29173 .39373 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.26939 .53658 m .27785 .57228 L .2942 .56923 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.30655 .60204 m .2942 .56923 L .27785 .57228 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.47187 .27147 m .4456 .28455 L .45638 .28667 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.45638 .28667 m .47734 .27264 L .47187 .27147 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.47734 .72736 m .45638 .71333 L .4456 .71545 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.45638 .71333 m .47734 .72736 L .48372 .72647 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.31071 .36228 m .29173 .39373 L .30655 .39796 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.30655 .39796 m .32354 .36727 L .31071 .36228 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.27785 .57228 m .29173 .60627 L .30655 .60204 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.32354 .63273 m .30655 .60204 L .29173 .60627 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.54924 .28567 m .52552 .27209 L .51957 .27312 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.52552 .27209 m .54924 .28567 L .55905 .28331 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.54924 .71433 m .52552 .72791 L .53045 .7292 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.53045 .7292 m .55905 .71669 L .54924 .71433 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.59668 .29675 m .62388 .31737 L .63452 .31254 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.66116 .33683 m .63452 .31254 L .62388 .31737 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.62388 .68263 m .59668 .70325 L .60439 .70742 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.60439 .70742 m .63452 .68746 L .62388 .68263 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.33435 .33413 m .31071 .36228 L .32354 .36727 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.32354 .36727 m .34488 .33941 L .33435 .33413 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.29173 .60627 m .31071 .63772 L .32354 .63273 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.34488 .66059 m .32354 .63273 L .31071 .63772 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.43065 .27904 m .39896 .29471 L .40859 .29866 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.40859 .29866 m .43688 .28198 L .43065 .27904 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.37018 .68498 m .39896 .70529 L .40859 .70134 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.43688 .71802 m .40859 .70134 L .39896 .70529 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.40859 .70134 m .43688 .71802 L .4456 .71545 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.46755 .27007 m .43688 .28198 L .4456 .28455 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.4456 .28455 m .47187 .27147 L .46755 .27007 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.47187 .72853 m .4456 .71545 L .43688 .71802 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.4456 .71545 m .47187 .72853 L .47734 .72736 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.36211 .30995 m .33435 .33413 L .34488 .33941 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.34488 .33941 m .37018 .31502 L .36211 .30995 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.31071 .63772 m .33435 .66587 L .34488 .66059 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.37018 .68498 m .34488 .66059 L .33435 .66587 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.55905 .28331 m .53045 .2708 L .52552 .27209 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.53045 .2708 m .55905 .28331 L .56657 .28055 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.59668 .29675 m .56657 .28055 L .55905 .28331 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.55905 .71669 m .53045 .7292 L .53411 .7307 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.53411 .7307 m .56657 .71945 L .55905 .71669 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.56657 .28055 m .59668 .29675 L .60439 .29258 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.63452 .31254 m .60439 .29258 L .59668 .29675 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.59668 .70325 m .56657 .71945 L .57141 .72253 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.57141 .72253 m .60439 .70742 L .59668 .70325 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.72294 .46425 m .72562 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.72562 .5 m .72294 .53575 L .73609 .53744 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.73609 .53744 m .73907 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.555 .774 .585 r
.49813 .27437 m .5 .26345 L .49074 .27412 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50559 .27429 m .5 .26345 L .49813 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49813 .72563 L .49074 .72588 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50559 .72571 L .49813 .72563 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51284 .27387 m .5 .26345 L .50559 .27429 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .51284 .72613 L .50559 .72571 L closepath p F P
.505 .664 .505 r
s
.415 .55 .447 r
.71494 .42929 m .72294 .46425 L .73609 .46256 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7134 .41865 m
.71812 .43429 L
s
.5 Mabswid
.382 .499 .408 r
.73907 .5 m .73609 .46256 L .72294 .46425 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72294 .53575 m .71494 .57071 L .72724 .57394 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72724 .57394 m .73609 .53744 L .72294 .53575 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.39333 .29036 m .36211 .30995 L .37018 .31502 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.37018 .31502 m .39896 .29471 L .39333 .29036 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.33435 .66587 m .36211 .69005 L .37018 .68498 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.39896 .70529 m .37018 .68498 L .36211 .69005 L p F P
.505 .664 .505 r
s
.552 .77 .582 r
.49074 .27412 m .5 .26345 L .48372 .27353 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .49074 .72588 L .48372 .72647 L closepath p F P
.505 .664 .505 r
s
.444 .597 .482 r
.70178 .3959 m .71494 .42929 L .72724 .42606 L p F P
.505 .664 .505 r
s
.415 .55 .447 r
.73609 .46256 m .72724 .42606 L .71494 .42929 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71494 .57071 m .70178 .6041 L .71274 .60854 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71274 .60854 m .72724 .57394 L .71494 .57071 L p F P
.505 .664 .505 r
s
.553 .772 .586 r
.51957 .27312 m .5 .26345 L .51284 .27387 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .51957 .72688 L .51284 .72613 L closepath p F P
.505 .664 .505 r
s
.544 .757 .564 r
.46458 .26849 m .43065 .27904 L .43688 .28198 L p F P
.505 .664 .505 r
s
.544 .757 .564 r
.43688 .28198 m .46755 .27007 L .46458 .26849 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.39896 .70529 m .43065 .72096 L .43688 .71802 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.46755 .72993 m .43688 .71802 L .43065 .72096 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.43688 .71802 m .46755 .72993 L .47187 .72853 L p F P
.505 .664 .505 r
s
.547 .764 .578 r
.48372 .27353 m .5 .26345 L .47734 .27264 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .48372 .72647 L .47734 .72736 L closepath p F P
.505 .664 .505 r
s
.469 .638 .513 r
.68373 .36485 m .70178 .3959 L .71274 .39146 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.72724 .42606 m .71274 .39146 L .70178 .3959 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.70178 .6041 m .68373 .63515 L .69297 .64039 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.69297 .64039 m .71274 .60854 L .70178 .6041 L p F P
.505 .664 .505 r
s
.549 .767 .583 r
.52552 .27209 m .5 .26345 L .51957 .27312 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .52552 .72791 L .51957 .72688 L closepath p F P
.505 .664 .505 r
s
.491 .673 .537 r
.66116 .33683 m .68373 .36485 L .69297 .35961 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.71274 .39146 m .69297 .35961 L .68373 .36485 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.68373 .63515 m .66116 .66317 L .66846 .66869 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.66846 .66869 m .69297 .64039 L .68373 .63515 L p F P
.505 .664 .505 r
s
.541 .757 .572 r
.47734 .27264 m .5 .26345 L .47187 .27147 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .47734 .72736 L .47187 .72853 L closepath p F P
.505 .664 .505 r
s
.513 .715 .527 r
.42727 .27585 m .39333 .29036 L .39896 .29471 L p F P
.505 .664 .505 r
s
.513 .715 .527 r
.39896 .29471 m .43065 .27904 L .42727 .27585 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.36211 .69005 m .39333 .70964 L .39896 .70529 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.43065 .72096 m .39896 .70529 L .39333 .70964 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.56657 .28055 m .53411 .2693 L .53045 .2708 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.53411 .2693 m .56657 .28055 L .57141 .27747 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.60439 .29258 m .57141 .27747 L .56657 .28055 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.56657 .71945 m .53411 .7307 L .53635 .73235 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.53635 .73235 m .57141 .72253 L .56657 .71945 L p F P
.505 .664 .505 r
s
.543 .76 .579 r
.53045 .2708 m .5 .26345 L .52552 .27209 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .53045 .7292 L .52552 .72791 L closepath p F P
.505 .664 .505 r
s
.178 .189 .147 r
.66116 .66317 m .63452 .68746 L .63983 .69272 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.63983 .69272 m .66846 .66869 L .66116 .66317 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.63452 .31254 m .66116 .33683 L .66846 .33131 L p F P
.505 .664 .505 r
s
.491 .673 .537 r
.69297 .35961 m .66846 .33131 L .66116 .33683 L p F P
.505 .664 .505 r
s
.533 .748 .565 r
.47187 .27147 m .5 .26345 L .46755 .27007 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .47187 .72853 L .46755 .72993 L closepath p F P
.505 .664 .505 r
s
.518 .721 .567 r
.60439 .29258 m .63452 .31254 L .63983 .30728 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.66846 .33131 m .63983 .30728 L .63452 .31254 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.63452 .68746 m .60439 .70742 L .60783 .71191 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60783 .71191 m .63983 .69272 L .63452 .68746 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27946 .57725 m
.28177 .58189 L
s
.28372 .58666 m
.28376 .58676 L
s
.28376 .58676 m
.28527 .59242 L
s
.5 Mabswid
.535 .751 .573 r
.53411 .2693 m .5 .26345 L .53045 .2708 L closepath p F P
.505 .664 .505 r
s
.184 .192 .146 r
.5 .73655 m .53411 .7307 L .53045 .7292 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27668 .57349 m
.27946 .57725 L
s
.5 Mabswid
.208 .214 .163 r
.43065 .72096 m .46458 .73151 L .46755 .72993 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.46311 .26679 m .42727 .27585 L .43065 .27904 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.43065 .27904 m .46458 .26849 L .46311 .26679 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.39333 .70964 m .42727 .72415 L .43065 .72096 L p F P
.505 .664 .505 r
s
.191 .198 .151 r
.46458 .73151 m .43065 .72096 L .42727 .72415 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28527 .59242 m
.28546 .59636 L
s
.5 Mabswid
.524 .737 .557 r
.46755 .27007 m .5 .26345 L .46458 .26849 L closepath p F P
.505 .664 .505 r
s
.185 .192 .146 r
.5 .73655 m .46755 .72993 L .46458 .73151 L closepath p F P
.505 .664 .505 r
s
.524 .733 .572 r
.57141 .27747 m .60439 .29258 L .60783 .28809 L p F P
.505 .664 .505 r
s
.518 .721 .567 r
.63983 .30728 m .60783 .28809 L .60439 .29258 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60439 .70742 m .57141 .72253 L .57327 .72581 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57327 .72581 m .60783 .71191 L .60439 .70742 L p F P
.505 .664 .505 r
s
.526 .74 .566 r
.53635 .26765 m .5 .26345 L .53411 .2693 L closepath p F P
.505 .664 .505 r
s
.551 .768 .591 r
.57141 .27747 m .53635 .26765 L .53411 .2693 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .53635 .73235 L .53411 .7307 L closepath p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26084 .46165 m .25775 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26655 .5 m .26939 .46342 L .26084 .46165 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.26939 .53658 m .26655 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.27002 .42434 m .26084 .46165 L .26939 .46342 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.26939 .46342 m .27785 .42772 L .27002 .42434 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.25775 .5 m .26084 .53835 L .26939 .53658 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.27785 .57228 m .26939 .53658 L .26084 .53835 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.26084 .53835 m .27002 .57566 L .27785 .57228 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27614 .57301 m
.27668 .57349 L
s
.5 Mabswid
.196 .226 .161 r
.29173 .60627 m .27785 .57228 L .27002 .57566 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.28501 .38909 m .27002 .42434 L .27785 .42772 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.27785 .42772 m .29173 .39373 L .28501 .38909 L p F P
.505 .664 .505 r
s
.523 .735 .568 r
.53635 .26765 m .57141 .27747 L .57327 .27419 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.60783 .28809 m .57327 .27419 L .57141 .27747 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57141 .72253 m .53635 .73235 L .53702 .73408 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.53702 .73408 m .57327 .72581 L .57141 .72253 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.30538 .35684 m .28501 .38909 L .29173 .39373 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.29173 .39373 m .31071 .36228 L .30538 .35684 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.27002 .57566 m .28501 .61091 L .29173 .60627 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.31071 .63772 m .29173 .60627 L .28501 .61091 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.33053 .32842 m .30538 .35684 L .31071 .36228 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.31071 .36228 m .33435 .33413 L .33053 .32842 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.28501 .61091 m .30538 .64316 L .31071 .63772 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.33435 .66587 m .31071 .63772 L .30538 .64316 L p F P
.505 .664 .505 r
s
.514 .725 .548 r
.46458 .26849 m .5 .26345 L .46311 .26679 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.42727 .72415 m .46311 .73321 L .46458 .73151 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .46458 .73151 L .46311 .73321 L closepath p F P
.505 .664 .505 r
s
.399 .562 .4 r
.35974 .30454 m .33053 .32842 L .33435 .33413 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.33435 .33413 m .36211 .30995 L .35974 .30454 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.30538 .64316 m .33053 .67158 L .33435 .66587 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.36211 .69005 m .33435 .66587 L .33053 .67158 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.39219 .28577 m .35974 .30454 L .36211 .30995 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.36211 .30995 m .39333 .29036 L .39219 .28577 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.33053 .67158 m .35974 .69546 L .36211 .69005 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39333 .70964 m .36211 .69005 L .35974 .69546 L p F P
.505 .664 .505 r
s
.516 .728 .557 r
.53702 .26592 m .5 .26345 L .53635 .26765 L closepath p F P
.505 .664 .505 r
s
.523 .735 .568 r
.57327 .27419 m .53702 .26592 L .53635 .26765 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .53702 .73408 L .53635 .73235 L closepath p F P
.505 .664 .505 r
s
.461 .653 .481 r
.427 .27253 m .39219 .28577 L .39333 .29036 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.39333 .29036 m .42727 .27585 L .427 .27253 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.35974 .69546 m .39219 .71423 L .39333 .70964 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.42727 .72415 m .39333 .70964 L .39219 .71423 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.46325 .26505 m .427 .27253 L .42727 .27585 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.42727 .27585 m .46311 .26679 L .46325 .26505 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39219 .71423 m .427 .72747 L .42727 .72415 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.46311 .73321 m .42727 .72415 L .427 .72747 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73409 .45431 m
.73452 .45521 L
s
.73377 .45299 m
.73384 .45178 L
s
.5 Mabswid
.504 .712 .539 r
.46311 .26679 m .5 .26345 L .46325 .26505 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.427 .72747 m .46325 .73495 L .46311 .73321 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .46311 .73321 L .46325 .73495 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73452 .45521 m
.73462 .45341 L
s
.73384 .45178 m
.73462 .45341 L
s
.72336 .41592 m
.72453 .41959 L
s
.7294 .43496 m
.73141 .4413 L
s
.5 Mabswid
.164 .173 .132 r
.5 .73655 m .53608 .73581 L .53702 .73408 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .53351 .73747 L .53608 .73581 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .52942 .73899 L .53351 .73747 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .52395 .74028 L .52942 .73899 L closepath p F P
.505 .664 .505 r
s
.141 .151 .115 r
.5 .73655 m .51735 .74128 L .52395 .74028 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50992 .74195 L .51735 .74128 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50201 .74224 L .50992 .74195 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .494 .74214 L .50201 .74224 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .48628 .74166 L .494 .74214 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .47923 .74082 L .48628 .74166 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .47316 .73967 L .47923 .74082 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .46835 .73825 L .47316 .73967 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .46501 .73666 L .46835 .73825 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .46325 .73495 L .46501 .73666 L closepath p F P
.505 .664 .505 r
s
.506 .715 .548 r
.53608 .26419 m .5 .26345 L .53702 .26592 L closepath p F P
.505 .664 .505 r
s
.494 .702 .539 r
.53351 .26253 m .5 .26345 L .53608 .26419 L closepath p F P
.505 .664 .505 r
s
.493 .699 .53 r
.46325 .26505 m .5 .26345 L .46501 .26334 L closepath p F P
.505 .664 .505 r
s
.483 .689 .529 r
.52942 .26101 m .5 .26345 L .53351 .26253 L closepath p F P
.505 .664 .505 r
s
.482 .686 .521 r
.46501 .26334 m .5 .26345 L .46835 .26175 L closepath p F P
.505 .664 .505 r
s
.473 .676 .52 r
.52395 .25972 m .5 .26345 L .52942 .26101 L closepath p F P
.505 .664 .505 r
s
.472 .674 .513 r
.46835 .26175 m .5 .26345 L .47316 .26033 L closepath p F P
.505 .664 .505 r
s
.465 .666 .512 r
.51735 .25872 m .5 .26345 L .52395 .25972 L closepath p F P
.505 .664 .505 r
s
.464 .664 .506 r
.47316 .26033 m .5 .26345 L .47923 .25918 L closepath p F P
.505 .664 .505 r
s
.458 .658 .505 r
.50992 .25805 m .5 .26345 L .51735 .25872 L closepath p F P
.505 .664 .505 r
s
.458 .657 .502 r
.47923 .25918 m .5 .26345 L .48628 .25834 L closepath p F P
.505 .664 .505 r
s
.454 .652 .501 r
.50201 .25776 m .5 .26345 L .50992 .25805 L closepath p F P
.505 .664 .505 r
s
.454 .652 .499 r
.48628 .25834 m .5 .26345 L .494 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.494 .25786 m .5 .26345 L .50201 .25776 L closepath p F P
.505 .664 .505 r
s
.15 .16 .122 r
.57327 .72581 m .53702 .73408 L .53608 .73581 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.53702 .26592 m .57327 .27419 L .57192 .27086 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.57192 .27086 m .53608 .26419 L .53702 .26592 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.60783 .71191 m .57327 .72581 L .57192 .72914 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.53608 .73581 m .57192 .72914 L .57327 .72581 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.57327 .27419 m .60783 .28809 L .60658 .28345 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.60658 .28345 m .57192 .27086 L .57327 .27419 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.63983 .69272 m .60783 .71191 L .60658 .71655 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.57192 .72914 m .60658 .71655 L .60783 .71191 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.60783 .28809 m .63983 .30728 L .63911 .30177 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.63911 .30177 m .60658 .28345 L .60783 .28809 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.42999 .73078 m .46501 .73666 L .46325 .73495 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.46325 .73495 m .427 .72747 L .42999 .73078 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.427 .27253 m .46325 .26505 L .46501 .26334 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.66846 .66869 m .63983 .69272 L .63911 .69823 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.60658 .71655 m .63911 .69823 L .63983 .69272 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.63983 .30728 m .66846 .33131 L .66858 .32547 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.66858 .32547 m .63911 .30177 L .63983 .30728 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.69297 .64039 m .66846 .66869 L .66858 .67453 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.63911 .69823 m .66858 .67453 L .66846 .66869 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.66846 .33131 m .69297 .35961 L .69409 .35401 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.69409 .35401 m .66858 .32547 L .66846 .33131 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.57192 .72914 m .53608 .73581 L .53351 .73747 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.53608 .26419 m .57192 .27086 L .56728 .26762 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.56728 .26762 m .53351 .26253 L .53608 .26419 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.69297 .35961 m .71274 .39146 L .71485 .38667 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.71485 .38667 m .69409 .35401 L .69297 .35961 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.71274 .60854 m .69297 .64039 L .69409 .64599 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.66858 .67453 m .69409 .64599 L .69297 .64039 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.71274 .39146 m .72724 .42606 L .73019 .42257 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.73019 .42257 m .71485 .38667 L .71274 .39146 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.72724 .57394 m .71274 .60854 L .71485 .61333 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.69409 .64599 m .71485 .61333 L .71274 .60854 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.39589 .71886 m .42999 .73078 L .427 .72747 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.427 .72747 m .39219 .71423 L .39589 .71886 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.46501 .26334 m .42999 .26922 L .427 .27253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.39219 .28577 m .427 .27253 L .42999 .26922 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.72724 .42606 m .73609 .46256 L .7396 .46071 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.7396 .46071 m .73019 .42257 L .72724 .42606 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73609 .53744 m .72724 .57394 L .73019 .57743 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.71485 .61333 m .73019 .57743 L .72724 .57394 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.73609 .46256 m .73907 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.74277 .5 m .7396 .46071 L .73609 .46256 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.73907 .5 m .73609 .53744 L .7396 .53929 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73019 .57743 m .7396 .53929 L .73609 .53744 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.7396 .53929 m .74277 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.43626 .73392 m .46835 .73825 L .46501 .73666 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.46501 .73666 m .42999 .73078 L .43626 .73392 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.42999 .26922 m .46501 .26334 L .46835 .26175 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73392 .4377 m
.7342 .43852 L
s
.7342 .43852 m
.73524 .44009 L
s
.5 Mabswid
.119 .131 .1 r
.36367 .701 m .39589 .71886 L .39219 .71423 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.39219 .71423 m .35974 .69546 L .36367 .701 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.42999 .26922 m .39589 .28114 L .39219 .28577 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.35974 .30454 m .39219 .28577 L .39589 .28114 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.53351 .73747 m .56728 .73238 L .57192 .72914 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56728 .73238 m .53351 .73747 L .52942 .73899 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.53351 .26253 m .56728 .26762 L .55944 .26462 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.55944 .26462 m .52942 .26101 L .53351 .26253 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.60658 .71655 m .57192 .72914 L .56728 .73238 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.57192 .27086 m .60658 .28345 L .60039 .27887 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.60039 .27887 m .56728 .26762 L .57192 .27086 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.44561 .73673 m .47316 .73967 L .46835 .73825 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.46835 .73825 m .43626 .73392 L .44561 .73673 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.43626 .26608 m .46835 .26175 L .47316 .26033 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.46835 .26175 m .43626 .26608 L .42999 .26922 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73524 .44009 m
.73597 .43976 L
s
.5 Mabswid
.104 .118 .09 r
.3343 .67749 m .36367 .701 L .35974 .69546 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.35974 .69546 m .33053 .67158 L .3343 .67749 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.39589 .28114 m .36367 .299 L .35974 .30454 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.33053 .32842 m .35974 .30454 L .36367 .299 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27297 .58657 m
.27455 .59049 L
s
.27455 .59049 m
.27669 .59637 L
s
.27039 .58064 m
.27297 .58657 L
s
.5 Mabswid
.106 .12 .091 r
.52942 .73899 m .55944 .73538 L .56728 .73238 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.55944 .73538 m .52942 .73899 L .52395 .74028 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.52942 .26101 m .55944 .26462 L .54866 .26204 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.54866 .26204 m .52395 .25972 L .52942 .26101 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27669 .59637 m
.2779 .60046 L
s
.2684 .57675 m
.27039 .58064 L
s
.5 Mabswid
.091 .106 .08 r
.30873 .64885 m .3343 .67749 L .33053 .67158 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.33053 .67158 m .30538 .64316 L .30873 .64885 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.36367 .299 m .3343 .32251 L .33053 .32842 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.30538 .35684 m .33053 .32842 L .3343 .32251 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.4577 .73906 m .47923 .74082 L .47316 .73967 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.47316 .73967 m .44561 .73673 L .4577 .73906 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.44561 .26327 m .47316 .26033 L .47923 .25918 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.47316 .26033 m .44561 .26327 L .43626 .26608 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73589 .43771 m
.73597 .43976 L
s
.5 Mabswid
.094 .108 .082 r
.40457 .72332 m .43626 .73392 L .42999 .73078 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.42999 .73078 m .39589 .71886 L .40457 .72332 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.39589 .28114 m .42999 .26922 L .43626 .26608 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.63911 .69823 m .60658 .71655 L .60039 .72113 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.56728 .73238 m .60039 .72113 L .60658 .71655 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.60658 .28345 m .63911 .30177 L .63189 .29627 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.63189 .29627 m .60039 .27887 L .60658 .28345 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.52395 .74028 m .54866 .73796 L .55944 .73538 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.54866 .73796 m .52395 .74028 L .51735 .74128 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.52395 .25972 m .54866 .26204 L .5354 .26001 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.5354 .26001 m .51735 .25872 L .52395 .25972 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73481 .43183 m
.73589 .43771 L
s
.5 Mabswid
.216 .323 .219 r
.3343 .32251 m .30873 .35115 L .30538 .35684 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.28501 .38909 m .30538 .35684 L .30873 .35115 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.28783 .6158 m .30873 .64885 L .30538 .64316 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.30538 .64316 m .28501 .61091 L .28783 .6158 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47197 .74076 m .48628 .74166 L .47923 .74082 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47923 .74082 m .4577 .73906 L .47197 .74076 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.4577 .26094 m .47923 .25918 L .48628 .25834 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.47923 .25918 m .4577 .26094 L .44561 .26327 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.30873 .35115 m .28783 .3842 L .28501 .38909 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.27002 .42434 m .28501 .38909 L .28783 .3842 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.27233 .57924 m .28783 .6158 L .28501 .61091 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.28501 .61091 m .27002 .57566 L .27233 .57924 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2779 .60046 m
.27841 .60271 L
s
.5 Mabswid
.07 .086 .066 r
.51735 .74128 m .5354 .73999 L .54866 .73796 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.5354 .73999 m .51735 .74128 L .50992 .74195 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.51735 .25872 m .5354 .26001 L .5203 .25865 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.5203 .25865 m .50992 .25805 L .51735 .25872 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.60039 .72113 m .56728 .73238 L .55944 .73538 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.56728 .26762 m .60039 .27887 L .58926 .27459 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.58926 .27459 m .55944 .26462 L .56728 .26762 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27812 .60344 m
.27841 .60271 L
s
1 .5 0 r
.72835 .41301 m
.73687 .43919 L
s
.5 Mabswid
.312 .474 .374 r
.48771 .74174 m .494 .74214 L .48628 .74166 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48628 .74166 m .47197 .74076 L .48771 .74174 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.48628 .25834 m .47197 .25924 L .4577 .26094 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.47197 .25924 m .48628 .25834 L .494 .25786 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.2628 .54024 m .27233 .57924 L .27002 .57566 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.27002 .57566 m .26084 .53835 L .2628 .54024 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26727 .57492 m
.2684 .57675 L
s
.5 Mabswid
.087 .114 .1 r
.28783 .3842 m .27233 .42076 L .27002 .42434 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.26084 .46165 m .27002 .42434 L .27233 .42076 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26689 .57547 m
.26727 .57492 L
s
.5 Mabswid
.058 .076 .058 r
.50992 .74195 m .5203 .74135 L .5354 .73999 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.5203 .74135 m .50992 .74195 L .50201 .74224 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50992 .25805 m .5203 .25865 L .50411 .25806 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50411 .25806 m .50201 .25776 L .50992 .25805 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.60039 .72113 m .63189 .70373 L .63911 .69823 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.66858 .67453 m .63911 .69823 L .63189 .70373 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.63911 .30177 m .66858 .32547 L .66077 .31957 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66077 .31957 m .63189 .29627 L .63911 .30177 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.27233 .42076 m .2628 .45976 L .26084 .46165 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.25775 .5 m .26084 .46165 L .2628 .45976 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.25958 .5 m .2628 .54024 L .26084 .53835 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.26084 .53835 m .25775 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.50411 .74194 m .50201 .74224 L .494 .74214 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.494 .74214 m .48771 .74174 L .50411 .74194 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.48771 .25826 m .494 .25786 L .50201 .25776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.494 .25786 m .48771 .25826 L .47197 .25924 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.50201 .74224 m .50411 .74194 L .5203 .74135 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.50201 .25776 m .50411 .25806 L .48771 .25826 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.2628 .45976 m .25958 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.37424 .70639 m .40457 .72332 L .39589 .71886 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.39589 .71886 m .36367 .701 L .37424 .70639 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.43626 .26608 m .40457 .27668 L .39589 .28114 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36367 .299 m .39589 .28114 L .40457 .27668 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.41809 .72736 m .44561 .73673 L .43626 .73392 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.43626 .73392 m .40457 .72332 L .41809 .72736 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.40457 .27668 m .43626 .26608 L .44561 .26327 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27723 .60213 m
.27812 .60344 L
s
.26689 .57547 m
.26753 .57808 L
s
.5 Mabswid
.241 .356 .243 r
.69409 .64599 m .66858 .67453 L .66077 .68043 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.63189 .70373 m .66077 .68043 L .66858 .67453 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.66858 .32547 m .69409 .35401 L .68605 .34829 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.68605 .34829 m .66077 .31957 L .66858 .32547 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27559 .59891 m
.27723 .60213 L
s
.5 Mabswid
.058 .075 .057 r
.55944 .73538 m .58926 .72541 L .60039 .72113 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.58926 .72541 m .55944 .73538 L .54866 .73796 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.55944 .26462 m .58926 .27459 L .57348 .27086 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.57348 .27086 m .54866 .26204 L .55944 .26462 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26753 .57808 m
.26908 .58283 L
s
1 .5 0 r
.73297 .42338 m
.7342 .42717 L
s
.73098 .41751 m
.73297 .42338 L
s
.7342 .42717 m
.73592 .43268 L
s
.5 Mabswid
.322 .477 .349 r
.63189 .70373 m .60039 .72113 L .58926 .72541 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.60039 .27887 m .63189 .29627 L .61797 .29106 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.61797 .29106 m .58926 .27459 L .60039 .27887 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26679 .57622 m
.27569 .59668 L
s
.27569 .59668 m
.28418 .61622 L
s
1 .5 0 r
.7295 .41335 m
.73098 .41751 L
s
.5 Mabswid
.123 .135 .103 r
.69409 .35401 m .71485 .38667 L .70681 .38173 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.70681 .38173 m .68605 .34829 L .69409 .35401 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.71485 .61333 m .69409 .64599 L .68605 .65171 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.66077 .68043 m .68605 .65171 L .69409 .64599 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.34626 .68331 m .37424 .70639 L .36367 .701 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.36367 .701 m .3343 .67749 L .34626 .68331 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.40457 .27668 m .37424 .29361 L .36367 .299 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.3343 .32251 m .36367 .299 L .37424 .29361 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73592 .43268 m
.73695 .43617 L
s
.5 Mabswid
.392 .574 .454 r
.43597 .73074 m .4577 .73906 L .44561 .73673 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.44561 .73673 m .41809 .72736 L .43597 .73074 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.41809 .27264 m .44561 .26327 L .4577 .26094 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.44561 .26327 m .41809 .27264 L .40457 .27668 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73695 .43617 m
.73736 .4378 L
s
.5 Mabswid
.231 .323 .206 r
.73019 .57743 m .71485 .61333 L .70681 .61827 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.68605 .65171 m .70681 .61827 L .71485 .61333 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.71485 .38667 m .73019 .42257 L .72227 .41895 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72864 .41109 m
.7295 .41335 L
s
.5 Mabswid
.142 .155 .117 r
.72227 .41895 m .70681 .38173 L .71485 .38667 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72834 .41061 m
.72864 .41109 L
s
.5 Mabswid
.334 .498 .374 r
.54866 .73796 m .57348 .72914 L .58926 .72541 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.57348 .72914 m .54866 .73796 L .5354 .73999 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.54866 .26204 m .57348 .27086 L .55369 .26789 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.55369 .26789 m .5354 .26001 L .54866 .26204 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.7396 .53929 m .73019 .57743 L .72227 .58105 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.70681 .61827 m .72227 .58105 L .73019 .57743 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.73019 .42257 m .7396 .46071 L .7318 .4588 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7371 .43745 m
.73736 .4378 L
s
.5 Mabswid
.176 .21 .148 r
.7318 .4588 m .72227 .41895 L .73019 .42257 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.39143 .71134 m .41809 .72736 L .40457 .72332 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.40457 .72332 m .37424 .70639 L .39143 .71134 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.37424 .29361 m .40457 .27668 L .41809 .27264 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.32164 .65452 m .34626 .68331 L .3343 .67749 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.3343 .67749 m .30873 .64885 L .32164 .65452 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.37424 .29361 m .34626 .31669 L .3343 .32251 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.30873 .35115 m .3343 .32251 L .34626 .31669 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.7396 .46071 m .74277 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.73502 .5 m .7318 .4588 L .7396 .46071 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.74277 .5 m .7396 .53929 L .7318 .5412 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.72227 .58105 m .7318 .5412 L .7396 .53929 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.7318 .5412 m .73502 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.45741 .73324 m .47197 .74076 L .4577 .73906 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.4577 .73906 m .43597 .73074 L .45741 .73324 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.43597 .26926 m .4577 .26094 L .47197 .25924 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.4577 .26094 m .43597 .26926 L .41809 .27264 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72834 .41061 m
.72881 .41224 L
s
.5 Mabswid
.37 .529 .38 r
.66077 .68043 m .63189 .70373 L .61797 .70894 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.58926 .72541 m .61797 .70894 L .63189 .70373 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.63189 .29627 m .66077 .31957 L .64462 .31391 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.64462 .31391 m .61797 .29106 L .63189 .29627 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73633 .43533 m
.7371 .43745 L
s
.72881 .41224 m
.72991 .41583 L
s
.5 Mabswid
.394 .575 .434 r
.5354 .73999 m .55369 .73211 L .57348 .72914 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.55369 .73211 m .5354 .73999 L .5203 .74135 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5354 .26001 m .55369 .26789 L .53087 .2659 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.53087 .2659 m .5203 .25865 L .5354 .26001 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73493 .43128 m
.73633 .43533 L
s
.5 Mabswid
.42 .601 .443 r
.61797 .70894 m .58926 .72541 L .57348 .72914 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.58926 .27459 m .61797 .29106 L .59764 .28646 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.59764 .28646 m .57348 .27086 L .58926 .27459 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27251 .59063 m
.27416 .5947 L
s
.27416 .5947 m
.27696 .6008 L
s
.27037 .58446 m
.27251 .59063 L
s
.5 Mabswid
.463 .664 .513 r
.48129 .73469 m .48771 .74174 L .47197 .74076 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.47197 .74076 m .45741 .73324 L .48129 .73469 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.45741 .26676 m .47197 .25924 L .48771 .25826 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.47197 .25924 m .45741 .26676 L .43597 .26926 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.34626 .31669 m .32164 .34548 L .30873 .35115 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.28783 .3842 m .30873 .35115 L .32164 .34548 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30132 .62071 m .32164 .65452 L .30873 .64885 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30873 .64885 m .28783 .6158 L .30132 .62071 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72991 .41583 m
.73174 .42152 L
s
0 0 0 r
.27696 .6008 m
.27932 .60504 L
s
1 .5 0 r
.733 .42539 m
.73493 .43128 L
s
.5 Mabswid
.438 .63 .477 r
.5203 .74135 m .53087 .7341 L .55369 .73211 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.53087 .7341 m .5203 .74135 L .50411 .74194 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.5203 .25865 m .53087 .2659 L .50627 .26502 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.50627 .26502 m .50411 .25806 L .5203 .25865 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26943 .58041 m
.27037 .58446 L
s
1 .5 0 r
.73174 .42152 m
.733 .42539 L
s
.5 Mabswid
.472 .674 .517 r
.50627 .73498 m .50411 .74194 L .48771 .74174 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.48771 .74174 m .48129 .73469 L .50627 .73498 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.48129 .26531 m .48771 .25826 L .50411 .25806 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.48771 .25826 m .48129 .26531 L .45741 .26676 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.50411 .74194 m .50627 .73498 L .53087 .7341 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.50411 .25806 m .50627 .26502 L .48129 .26531 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.32164 .34548 m .30132 .37929 L .28783 .3842 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.27233 .42076 m .28783 .3842 L .30132 .37929 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28614 .58285 m .30132 .62071 L .28783 .6158 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28783 .6158 m .27233 .57924 L .28614 .58285 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27932 .60504 m
.28095 .60738 L
s
.27416 .5947 m
.27949 .59743 L
s
.5 Mabswid
.481 .675 .536 r
.36656 .68871 m .39143 .71134 L .37424 .70639 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.37424 .70639 m .34626 .68331 L .36656 .68871 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.41809 .27264 m .39143 .28866 L .37424 .29361 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.34626 .31669 m .37424 .29361 L .39143 .28866 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41472 .71552 m .43597 .73074 L .41809 .72736 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41809 .72736 m .39143 .71134 L .41472 .71552 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.39143 .28866 m .41809 .27264 L .43597 .26926 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.68605 .65171 m .66077 .68043 L .64462 .68609 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.61797 .70894 m .64462 .68609 L .66077 .68043 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66077 .31957 m .68605 .34829 L .66819 .34276 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66819 .34276 m .64462 .31391 L .66077 .31957 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28095 .60738 m
.28233 .60812 L
s
.5 Mabswid
.216 .253 .216 r
.30132 .37929 m .28614 .41715 L .27233 .42076 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.2628 .45976 m .27233 .42076 L .28614 .41715 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27676 .54216 m .28614 .58285 L .27233 .57924 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27233 .57924 m .2628 .54024 L .27676 .54216 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26942 .5785 m
.26943 .58041 L
s
.26942 .5785 m
.27079 .57907 L
s
1 .5 0 r
.72559 .40866 m
.7365 .44577 L
s
.7365 .44577 m
.73752 .44926 L
s
.5 Mabswid
.42 .601 .443 r
.57348 .72914 m .59764 .71354 L .61797 .70894 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.59764 .71354 m .57348 .72914 L .55369 .73211 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57348 .27086 m .59764 .28646 L .57165 .28277 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57165 .28277 m .55369 .26789 L .57348 .27086 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.28614 .41715 m .27676 .45784 L .2628 .45976 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.25958 .5 m .2628 .45976 L .27676 .45784 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.27358 .5 m .27676 .54216 L .2628 .54024 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.2628 .54024 m .25958 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28233 .60812 m
.28254 .60676 L
s
.5 Mabswid
.329 .42 .348 r
.27676 .45784 m .27358 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68605 .34829 m .70681 .38173 L .68772 .37692 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68772 .37692 m .66819 .34276 L .68605 .34829 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.70681 .61827 m .68605 .65171 L .66819 .65724 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.64462 .68609 m .66819 .65724 L .68605 .65171 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.64462 .68609 m .61797 .70894 L .59764 .71354 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.61797 .29106 m .64462 .31391 L .62029 .30886 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.62029 .30886 m .59764 .28646 L .61797 .29106 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27079 .57907 m
.27263 .58178 L
s
.28227 .60511 m
.28254 .60676 L
s
.5 Mabswid
.542 .758 .585 r
.44307 .71864 m .45741 .73324 L .43597 .73074 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.43597 .73074 m .41472 .71552 L .44307 .71864 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.41472 .28448 m .43597 .26926 L .45741 .26676 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.43597 .26926 m .41472 .28448 L .39143 .28866 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34445 .65982 m .36656 .68871 L .34626 .68331 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34626 .68331 m .32164 .65452 L .34445 .65982 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.39143 .28866 m .36656 .31129 L .34626 .31669 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.32164 .34548 m .34626 .31669 L .36656 .31129 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28118 .60146 m
.28227 .60511 L
s
.27263 .58178 m
.27541 .58672 L
s
.27949 .59743 m
.28118 .60146 L
s
.5 Mabswid
.492 .692 .513 r
.55369 .73211 m .57165 .71723 L .59764 .71354 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.57165 .71723 m .55369 .73211 L .53087 .7341 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.55369 .26789 m .57165 .28277 L .54132 .28027 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.54132 .28027 m .53087 .2659 L .55369 .26789 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70681 .38173 m .72227 .41895 L .70237 .41539 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70237 .41539 m .68772 .37692 L .70681 .38173 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.72227 .58105 m .70681 .61827 L .68772 .62308 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.66819 .65724 m .68772 .62308 L .70681 .61827 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72234 .40735 m
.73153 .43901 L
s
.73153 .43901 m
.73428 .4485 L
s
.5 Mabswid
.559 .772 .601 r
.39471 .69332 m .41472 .71552 L .39143 .71134 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39143 .71134 m .36656 .68871 L .39471 .69332 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.36656 .31129 m .39143 .28866 L .41472 .28448 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.47494 .72046 m .48129 .73469 L .45741 .73324 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.45741 .73324 m .44307 .71864 L .47494 .72046 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.44307 .28136 m .45741 .26676 L .48129 .26531 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.45741 .26676 m .44307 .28136 L .41472 .28448 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.7318 .5412 m .72227 .58105 L .70237 .58461 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.68772 .62308 m .70237 .58461 L .72227 .58105 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.72227 .41895 m .7318 .4588 L .71144 .45691 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.71144 .45691 m .70237 .41539 L .72227 .41895 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.53087 .7341 m .54132 .71973 L .57165 .71723 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.54132 .71973 m .53087 .7341 L .50627 .73498 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.53087 .2659 m .54132 .28027 L .5084 .27916 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.5084 .27916 m .50627 .26502 L .53087 .2659 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.36656 .31129 m .34445 .34018 L .32164 .34548 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.30132 .37929 m .32164 .34548 L .34445 .34018 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32606 .62534 m .34445 .65982 L .32164 .65452 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32164 .65452 m .30132 .62071 L .32606 .62534 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.66819 .65724 m .64462 .68609 L .62029 .69114 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.59764 .71354 m .62029 .69114 L .64462 .68609 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64462 .31391 m .66819 .34276 L .64051 .33778 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64051 .33778 m .62029 .30886 L .64462 .31391 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.5084 .72084 m .50627 .73498 L .48129 .73469 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.48129 .73469 m .47494 .72046 L .5084 .72084 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.47494 .27954 m .48129 .26531 L .50627 .26502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.48129 .26531 m .47494 .27954 L .44307 .28136 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.7318 .4588 m .73502 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.71452 .5 m .71144 .45691 L .7318 .4588 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.73502 .5 m .7318 .5412 L .71144 .54309 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.70237 .58461 m .71144 .54309 L .7318 .5412 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28556 .60107 m
.2864 .60485 L
s
.2864 .60485 m
.28895 .60896 L
s
.5 Mabswid
.567 .786 .59 r
.50627 .73498 m .5084 .72084 L .54132 .71973 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.50627 .26502 m .5084 .27916 L .47494 .27954 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.71144 .54309 m .71452 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.62029 .69114 m .59764 .71354 L .57165 .71723 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.59764 .28646 m .62029 .30886 L .58863 .30478 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.58863 .30478 m .57165 .28277 L .59764 .28646 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28895 .60896 m
.29252 .61158 L
s
1 .5 0 r
.72278 .41834 m
.72404 .42235 L
s
.72013 .41214 m
.72278 .41834 L
s
0 0 0 r
.28556 .60107 m
.28653 .59946 L
s
.27912 .58354 m
.27983 .58795 L
s
1 .5 0 r
.72404 .42235 m
.72515 .4282 L
s
.71738 .40776 m
.72013 .41214 L
s
.72491 .43191 m
.72515 .4282 L
s
.71526 .4054 m
.71738 .40776 L
s
0 0 0 r
.27912 .58354 m
.28114 .58175 L
s
.5 Mabswid
.538 .718 .564 r
.31222 .58629 m .32606 .62534 L .30132 .62071 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.30132 .62071 m .28614 .58285 L .31222 .58629 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28653 .59946 m
.29078 .59845 L
s
.29252 .61158 m
.29551 .61232 L
s
.5 Mabswid
.287 .335 .264 r
.34445 .34018 m .32606 .37466 L .30132 .37929 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.28614 .41715 m .30132 .37929 L .32606 .37466 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71306 .40492 m
.71526 .4054 L
s
.72402 .43366 m
.72491 .43191 L
s
.5 Mabswid
.605 .828 .634 r
.42948 .69679 m .44307 .71864 L .41472 .71552 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.41472 .71552 m .39471 .69332 L .42948 .69679 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.39471 .30668 m .41472 .28448 L .44307 .28136 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.41472 .28448 m .39471 .30668 L .36656 .31129 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.34445 .34018 m .36656 .31129 L .39471 .30668 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.37677 .66439 m .39471 .69332 L .36656 .68871 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.36656 .68871 m .34445 .65982 L .37677 .66439 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72178 .4333 m
.72402 .43366 L
s
0 0 0 r
.29551 .61232 m
.29797 .61112 L
s
1 .5 0 r
.71225 .40665 m
.71306 .40492 L
s
.5 Mabswid
.326 .383 .264 r
.66819 .34276 m .68772 .37692 L .65741 .37255 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.65741 .37255 m .64051 .33778 L .66819 .34276 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.68772 .62308 m .66819 .65724 L .64051 .66222 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.62029 .69114 m .64051 .66222 L .66819 .65724 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.30362 .54399 m .31222 .58629 L .28614 .58285 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.28614 .58285 m .27676 .54216 L .30362 .54399 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28114 .58175 m
.28422 .58231 L
s
.5 Mabswid
.36 .439 .345 r
.32606 .37466 m .31222 .41371 L .28614 .41715 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.27676 .45784 m .28614 .41715 L .31222 .41371 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71204 .41046 m
.71225 .40665 L
s
.5 Mabswid
.552 .758 .556 r
.57165 .71723 m .58863 .69522 L .62029 .69114 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.58863 .69522 m .57165 .71723 L .54132 .71973 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.57165 .28277 m .58863 .30478 L .55125 .302 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.55125 .302 m .54132 .28027 L .57165 .28277 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71969 .43107 m
.72178 .4333 L
s
0 0 0 r
.29078 .59845 m
.29224 .59672 L
s
.28422 .58231 m
.28837 .58528 L
s
.29748 .60742 m
.29797 .61112 L
s
.5 Mabswid
.419 .525 .411 r
.31222 .41371 m .30362 .45601 L .27676 .45784 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.27358 .5 m .27676 .45784 L .30362 .45601 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.3007 .5 m .30362 .54399 L .27676 .54216 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.27676 .54216 m .27358 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71698 .4268 m
.71969 .43107 L
s
.71204 .41046 m
.71318 .41648 L
s
.5 Mabswid
.465 .594 .465 r
.30362 .45601 m .3007 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29186 .59247 m
.29224 .59672 L
s
.5 Mabswid
.627 .854 .647 r
.4689 .69883 m .47494 .72046 L .44307 .71864 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.44307 .71864 m .42948 .69679 L .4689 .69883 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.42948 .30321 m .44307 .28136 L .47494 .27954 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.44307 .28136 m .42948 .30321 L .39471 .30668 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71318 .41648 m
.71441 .42057 L
s
.71441 .42057 m
.71698 .4268 L
s
.5 Mabswid
.581 .785 .571 r
.64051 .66222 m .62029 .69114 L .58863 .69522 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.62029 .30886 m .64051 .33778 L .60391 .33372 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.60391 .33372 m .58863 .30478 L .62029 .30886 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28837 .58528 m
.29108 .59018 L
s
.29108 .59018 m
.29186 .59247 L
s
.5 Mabswid
.369 .448 .302 r
.68772 .37692 m .70237 .41539 L .67017 .41214 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.67017 .41214 m .65741 .37255 L .68772 .37692 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.70237 .58461 m .68772 .62308 L .65741 .62745 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.64051 .66222 m .65741 .62745 L .68772 .62308 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.54132 .71973 m .55125 .698 L .58863 .69522 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.55125 .698 m .54132 .71973 L .5084 .72084 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.54132 .28027 m .55125 .302 L .51043 .30076 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.51043 .30076 m .5084 .27916 L .54132 .28027 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.39471 .30668 m .37677 .33561 L .34445 .34018 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.32606 .37466 m .34445 .34018 L .37677 .33561 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.36172 .62936 m .37677 .66439 L .34445 .65982 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.34445 .65982 m .32606 .62534 L .36172 .62936 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.51043 .69924 m .5084 .72084 L .47494 .72046 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.47494 .72046 m .4689 .69883 L .51043 .69924 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.4689 .30117 m .47494 .27954 L .5084 .27916 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.47494 .27954 m .4689 .30117 L .42948 .30321 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.5084 .72084 m .51043 .69924 L .55125 .698 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.5084 .27916 m .51043 .30076 L .4689 .30117 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30491 .6008 m
.31613 .62783 L
s
.5 Mabswid
.355 .416 .306 r
.37677 .33561 m .39471 .30668 L .42948 .30321 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.41721 .66786 m .42948 .69679 L .39471 .69332 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.39471 .69332 m .37677 .66439 L .41721 .66786 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7037 .40913 m
.70665 .4155 L
s
.70665 .4155 m
.70786 .41964 L
s
.70025 .40465 m
.7037 .40913 L
s
.5 Mabswid
.505 .66 .46 r
.71144 .54309 m .70237 .58461 L .67017 .58786 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.65741 .62745 m .67017 .58786 L .70237 .58461 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.70237 .41539 m .71144 .45691 L .67811 .45518 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70786 .41964 m
.70851 .42568 L
s
.5 Mabswid
.405 .504 .337 r
.67811 .45518 m .67017 .41214 L .70237 .41539 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6974 .40224 m
.70025 .40465 L
s
.70742 .42953 m
.70851 .42568 L
s
.69407 .40179 m
.6974 .40224 L
s
.5 Mabswid
.448 .568 .386 r
.71144 .45691 m .71452 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.6808 .5 m .67811 .45518 L .71144 .45691 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.71452 .5 m .71144 .54309 L .67811 .54482 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.67017 .58786 m .67811 .54482 L .71144 .54309 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70572 .43135 m
.70742 .42953 L
s
0 0 0 r
.29893 .58678 m
.29969 .58452 L
s
.29893 .58678 m
.30114 .58938 L
s
.30114 .58938 m
.30192 .58715 L
s
.5 Mabswid
.38 .454 .309 r
.64051 .33778 m .65741 .37255 L .61675 .36896 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.61675 .36896 m .60391 .33372 L .64051 .33778 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.65741 .62745 m .64051 .66222 L .60391 .66628 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.58863 .69522 m .60391 .66628 L .64051 .66222 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.67811 .54482 m .6808 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.35034 .58928 m .36172 .62936 L .32606 .62534 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.32606 .62534 m .31222 .58629 L .35034 .58928 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.37677 .33561 m .36172 .37064 L .32606 .37466 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.31222 .41371 m .32606 .37466 L .36172 .37064 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.58863 .30478 m .60391 .33372 L .56023 .33093 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.56023 .33093 m .55125 .302 L .58863 .30478 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.60391 .66628 m .58863 .69522 L .55125 .698 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69245 .4036 m
.69407 .40179 L
s
0 0 0 r
.29969 .58452 m
.30192 .58715 L
s
1 .5 0 r
.70228 .43102 m
.70572 .43135 L
s
.68398 .38631 m
.69742 .43058 L
s
.69138 .40755 m
.69245 .4036 L
s
.69942 .42873 m
.70228 .43102 L
s
.5 Mabswid
.652 .874 .659 r
.46342 .6699 m .4689 .69883 L .42948 .69679 L p F P
.505 .664 .505 r
s
.652 .874 .659 r
.42948 .69679 m .41721 .66786 L .46342 .6699 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.41721 .33214 m .42948 .30321 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.42948 .30321 m .41721 .33214 L .37677 .33561 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69598 .42435 m
.69942 .42873 L
s
.5 Mabswid
.592 .774 .593 r
.34324 .54559 m .35034 .58928 L .31222 .58629 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.31222 .58629 m .30362 .54399 L .34324 .54559 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.36172 .37064 m .35034 .41072 L .31222 .41371 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.30362 .45601 m .31222 .41371 L .35034 .41072 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68374 .43475 m
.68434 .4006 L
s
.68358 .44386 m
.68374 .43475 L
s
.5 Mabswid
.433 .526 .39 r
.36172 .37064 m .37677 .33561 L .41721 .33214 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.40686 .63243 m .41721 .66786 L .37677 .66439 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.37677 .66439 m .36172 .62936 L .40686 .63243 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.55125 .698 m .56023 .66907 L .60391 .66628 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.56023 .66907 m .55125 .698 L .51043 .69924 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.55125 .302 m .56023 .33093 L .51227 .32969 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.51227 .32969 m .51043 .30076 L .55125 .302 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.65741 .37255 m .67017 .41214 L .6265 .40946 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.6265 .40946 m .61675 .36896 L .65741 .37255 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.67017 .58786 m .65741 .62745 L .61675 .63104 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.60391 .66628 m .61675 .63104 L .65741 .62745 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.35034 .41072 m .34324 .45441 L .30362 .45601 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.3007 .5 m .30362 .45601 L .34324 .45441 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.34082 .5 m .34324 .54559 L .30362 .54399 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.30362 .54399 m .3007 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.51227 .67031 m .51043 .69924 L .4689 .69883 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.4689 .69883 m .46342 .6699 L .51227 .67031 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.46342 .3301 m .4689 .30117 L .51043 .30076 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.4689 .30117 m .46342 .3301 L .41721 .33214 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.51043 .69924 m .51227 .67031 L .56023 .66907 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.51043 .30076 m .51227 .32969 L .46342 .3301 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.34324 .45441 m .34082 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.60391 .33372 m .61675 .36896 L .56782 .36649 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.56782 .36649 m .56023 .33093 L .60391 .33372 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.61675 .63104 m .60391 .66628 L .56023 .66907 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.67017 .41214 m .67811 .45518 L .63259 .45374 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.63259 .45374 m .6265 .40946 L .67017 .41214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.67003 .41389 m
.68468 .4151 L
s
.5 Mabswid
.57 .742 .528 r
.67811 .54482 m .67017 .58786 L .6265 .59054 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.61675 .63104 m .6265 .59054 L .67017 .58786 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.39899 .59158 m .40686 .63243 L .36172 .62936 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.36172 .62936 m .35034 .58928 L .39899 .59158 L p F P
.505 .664 .505 r
s
.433 .526 .39 r
.41721 .33214 m .40686 .36757 L .36172 .37064 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.35034 .41072 m .36172 .37064 L .40686 .36757 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66136 .39839 m
.67501 .42633 L
s
.67501 .42633 m
.68358 .44386 L
s
.5 Mabswid
.459 .56 .408 r
.40686 .36757 m .41721 .33214 L .46342 .3301 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.45878 .63424 m .46342 .6699 L .41721 .66786 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.41721 .66786 m .40686 .63243 L .45878 .63424 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.67811 .45518 m .6808 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.63466 .5 m .63259 .45374 L .67811 .45518 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.6808 .5 m .67811 .54482 L .63259 .54626 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.6265 .59054 m .63259 .54626 L .67811 .54482 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.63259 .54626 m .63466 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.56023 .66907 m .56782 .63351 L .61675 .63104 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.56023 .33093 m .56782 .36649 L .51383 .36538 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.51383 .36538 m .51227 .32969 L .56023 .33093 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.56782 .63351 m .56023 .66907 L .51227 .67031 L p F P
.505 .664 .505 r
s
.621 .815 .591 r
.6265 .59054 m .61675 .63104 L .56782 .63351 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.61675 .36896 m .6265 .40946 L .57359 .40761 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.57359 .40761 m .56782 .36649 L .61675 .36896 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.39407 .54682 m .39899 .59158 L .35034 .58928 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.35034 .58928 m .34324 .54559 L .39407 .54682 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.40686 .36757 m .39899 .40842 L .35034 .41072 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.34324 .45441 m .35034 .41072 L .39899 .40842 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.45878 .36576 m .46342 .3301 L .51227 .32969 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.51383 .63462 m .51227 .67031 L .46342 .6699 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.46342 .6699 m .45878 .63424 L .51383 .63462 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.46342 .3301 m .45878 .36576 L .40686 .36757 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.51227 .67031 m .51383 .63462 L .56782 .63351 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.51227 .32969 m .51383 .36538 L .45878 .36576 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.39899 .40842 m .39407 .45318 L .34324 .45441 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.34082 .5 m .34324 .45441 L .39407 .45318 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.3924 .5 m .39407 .54682 L .34324 .54559 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.34324 .54559 m .34082 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.45525 .59294 m .45878 .63424 L .40686 .63243 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.40686 .63243 m .39899 .59158 L .45525 .59294 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.39899 .40842 m .40686 .36757 L .45878 .36576 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.39407 .45318 m .3924 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.63259 .54626 m .6265 .59054 L .57359 .59239 L p F P
.505 .664 .505 r
s
.621 .815 .591 r
.56782 .63351 m .57359 .59239 L .6265 .59054 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.6265 .40946 m .63259 .45374 L .57721 .45275 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.57721 .45275 m .57359 .40761 L .6265 .40946 L p F P
.505 .664 .505 r
s
.641 .84 .615 r
.57359 .59239 m .56782 .63351 L .51383 .63462 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.56782 .36649 m .57359 .40761 L .51502 .40678 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.51502 .40678 m .51383 .36538 L .56782 .36649 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.51502 .59322 m .51383 .63462 L .45878 .63424 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.45878 .63424 m .45525 .59294 L .51502 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.45525 .40706 m .45878 .36576 L .51383 .36538 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.45878 .36576 m .45525 .40706 L .39899 .40842 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.63259 .45374 m .63466 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.57845 .5 m .57721 .45275 L .63259 .45374 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.63466 .5 m .63259 .54626 L .57721 .54725 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.57359 .59239 m .57721 .54725 L .63259 .54626 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.45304 .54755 m .45525 .59294 L .39899 .59158 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.39899 .59158 m .39407 .54682 L .45304 .54755 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.39407 .45318 m .39899 .40842 L .45525 .40706 L p F P
.505 .664 .505 r
s
.641 .84 .615 r
.51383 .63462 m .51502 .59322 L .57359 .59239 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.51383 .36538 m .51502 .40678 L .45525 .40706 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.57721 .54725 m .57845 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.57359 .40761 m .57721 .45275 L .51576 .4523 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.51576 .4523 m .51502 .40678 L .57359 .40761 L p F P
.505 .664 .505 r
s
.626 .813 .593 r
.57721 .54725 m .57359 .59239 L .51502 .59322 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.45525 .40706 m .45304 .45245 L .39407 .45318 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.3924 .5 m .39407 .45318 L .45304 .45245 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.45228 .5 m .45304 .54755 L .39407 .54682 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.39407 .54682 m .3924 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.45304 .45245 m .45228 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.45304 .45245 m .45525 .40706 L .51502 .40678 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.51576 .5477 m .51502 .59322 L .45525 .59294 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.45525 .59294 m .45304 .54755 L .51576 .5477 L p F P
.505 .664 .505 r
s
.626 .813 .593 r
.51502 .59322 m .51576 .5477 L .57721 .54725 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.51502 .40678 m .51576 .4523 L .45304 .45245 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.57721 .45275 m .57845 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.51602 .5 m .51576 .4523 L .57721 .45275 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.57845 .5 m .57721 .54725 L .51576 .5477 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.51576 .5477 m .51602 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.45228 .5 m .45304 .45245 L .51576 .4523 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.51602 .5 m .51576 .5477 L .45304 .54755 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.45304 .54755 m .45228 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.51576 .4523 m .51602 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>l0/>3V4P21ZH7b0;3PiP40oooo003X0;3PiPP0PJV10P0S9A`0
0`21ZH409BLN02DW7P0602DW7P04086YP@0U9ah09BLN02DW7Pl0PJV1i@2`h>H10?ooo`00hP2`h>H6
086YP@0301hQ6@21ZH40PJV100H08bDL00<0PJV102DW7P0U9ah01`0U9ah00`21ZH409BLN02DW7P06
02DW7P80PJV11`0R9A`6086YPN00/>3V0@3oool00=`0/>3V1`21ZH4401hQ6@80PJV1200S9A`00`21
ZH409BLN02DW7P0802DW7P03086YP@0U9ah09BLN00L09BLN0P21ZH47028U7080PJV10P0M8AT3086Y
PMd0/>3V0@3oool00=P0/>3V1@21ZH400`0G6a@0PJV1086YP@0501hQ6@80PJV1100S9A`S086YP@<0
8RDL0P21ZH4201dQ6@@0PJV1fP2`h>H10?ooo`00eP2`h>H4086YP@0301LK5021ZH40PJV100807R4I
3021ZH4403@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=3HX
03@f:00203@f:0T0PJV100<07B4I086YP@21ZH400`21ZH7F0;3PiP40oooo003C0;3PiP`0PJV1100_
<BD00`21ZH40=3HX03@f:00903@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02`0g
>2/00`21ZH40=3HX03@f:00803@f:003086YP@0^<2D0PJV100L0PJV1e02`h>H10?ooo`00d02`h>H9
086YP@T0;c4U00<0PJV103@f:00d=RP02@0d=RP00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0g>2/0
=cP[00`0=cP[00<0PJV103@f:00d=RP0200d=RP00`21ZH40;S0U02h`9@0302h`9@H0PJV1d@2`h>H1
0?ooo`00cP2`h>H5086YP@<09RTO00<0PJV102la9@0_<BD0200_<BD00`21ZH40=3HX03@f:00:03@f
:003086YP@0g>2/0=cP[00`0=cP[00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=3HX03@f:00903@f
:003086YP@0^<2D0;S0U00D0;S0U1P21ZH7>0;3PiP40oooo003;0;3PiPD0PJV1100V:Al2086YP@X0
;c4U00<0PJV103@f:00d=RP02P0d=RP00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0g>2/0=cP[00`0
=cP[00<0PJV103@f:00d=RP02@0d=RP2086YP@L0;S0U0P21ZH400`0V:1h0PJV1086YP@02086YPL/0
/>3V0@3oool00<T0/>3V0P21ZH400`0K7QL0PJV1086YP@0402HY7`80PJV12`0_<BD00`21ZH40=3HX
03@f:00;03@f:003086YP@0g>2/0=cP[00d0=cP[00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=3HX
03@f:00:03@f:003086YP@0^<2D0;S0U00H0;S0U00@0PJV102HX7P0V:1h09RPN0`21ZH790;3PiP40
oooo00370;3PiP80PJV10P0K7QL00`21ZH409RTO02HY7`0302HY7`03086YP@0_<BD0;c4U00X0;c4U
00<0PJV103@f:00d=RP0100d=RP]086YP@T0=3HX00<0PJV102h`9@0^<2D01P0^<2D2086YP@<09RPN
0`21ZH770;3PiP40oooo00350;3PiP80PJV10P0K7QL2086YP@@09RTO0P21ZH4502la9@l0PJV11`1:
DSX00`21ZH40CUPn04iH?P0>04iH?P03086YP@1>F3h0CUPn00h0CUPn00@0PJV104YB>`1:DS/0BU8k
2021ZH4203@f:003086YP@0^<2D0;S0U00L0;S0U0P21ZH4302HX7P<0PJV1a@2`h>H10?ooo`00``2`
h>H2086YP@<06ahG00<0PJV102HY7`0V:Al00P0V:Al9086YP@H0@DHc00<0PJV104YB>P1:DSX0301:
DSX00`21ZH40CUPn04iH?P0?04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0201:
DS/:086YP@@0;S0U0P21ZH4302HX7P<0PJV1``2`h>H10?ooo`00`@2`h>H2086YP@<06ahG0P21ZH40
0`0V:Al0PJV1086YP@03086YP@h0@DHc00<0PJV104YB>P1:DSX0301:DSX00`21ZH40CUPn04iH?P0?
04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`03
0456<`P0PJV10P0V:1h4086YPL40/>3V0@3oool00;l0/>3V0P21ZH4301/N5`D0PJV10`0b=2L00`21
ZH40@DHc0456<`0<0456<`03086YP@1:DSX0BU8j00d0BU8j00<0PJV104iH?P1>F3h03`1>F3h00`21
ZH40CUPn04iH?P0@04iH?P03086YP@1:DS/0BU8k00/0BU8k00<0PJV10456<`11AS<02P11AS<4086Y
P@0302HX7P21ZH40PJV10080PJV1_`2`h>H10?ooo`00_@2`h>H2086YP@806ahG1021ZH46038d9`03
086YP@11AS<0@DHc00`0@DHc00<0PJV104YB>P1:DSX03P1:DSX00`21ZH40CUPn04iH?P0?04iH?P03
086YP@1>F3h0CUPn0100CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`0:0456<`03
086YP@0b=2L0<S@W00L0PJV1_@2`h>H10?ooo`00^`2`h>H6086YP@0302DX7P21ZH40<S@W00L0<S@W
00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0=04YB>P03086YP@1>F3h0CUPn0140CUPn
00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0<04YB>`03086YP@11AS<0@DHc00X0@DHc
00<0PJV1038d9`0b=2L00`0b=2L5086YPK/0/>3V0@3oool00;X0/>3V0`21ZH4402DX7P03086YP@0b
=2L0<S@W00H0<S@W00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0>04YB>P03086YP@1>
F3h0CUPn0140CUPn00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0=04YB>`03086YP@11
AS<0@DHc00X0@DHc00<0PJV1038d9`0b=2L0100b=2L5086YPKT0/>3V0@3oool00;P0/>3V0P21ZH45
02DX7P80PJV1200b=2L00`21ZH40@DHc0456<`0=0456<`03086YP@1:DSX0BU8j00h0BU8j00<0PJV1
04iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A04iH?P03086YP@1:DS/0BU8k00`0BU8k00<0PJV1
0456<`11AS<02`11AS<00`21ZH40<S@W038d9`04038d9`04086YP@0T9ah092LN02@W7P80PJV1]`2`
h>H10?ooo`00]P2`h>H3086YP@D09BPN00<0PJV1038d9`0b=2L01`0b=2L00`21ZH40@DHc0456<`0=
0456<`03086YP@1:DSX0BU8j00l0BU8j00<0PJV104iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A
04iH?P03086YP@1:DS/0BU8k00d0BU8k00<0PJV10456<`11AS<02P11AS<00`21ZH40<S@W038d9`05
038d9`80PJV10`0T9ah00`21ZH40/>3V0;3PiP2d0;3PiP40oooo002e0;3PiP<0PJV11@0U:1h00`21
ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc00d0@DHc00<0PJV104YB>P1:DSX03`1:DSX00`21
ZH40CUPn04iH?P0B04iH?P03086YP@1>F3h0CUPn0180CUPn00<0PJV104YB>`1:DS/03@1:DS/00`21
ZH40@DHc0456<`0:0456<`03086YP@0b=2L0<S@W00H0<S@W00D0PJV102@W7P0T9ah092LN086YP@2e
0;3PiP40oooo002c0;3PiP<0PJV11P0U:1h00`21ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc
00h0@DHc00<0PJV104YB>P1:DSX01P1:DSXh086YP@`0BU8k00<0PJV10456<`11AS<02P11AS<00`21
ZH40<S@W038d9`06038d9`04086YP@0T9ah092LN02@W7P80PJV1/`2`h>H10?ooo`00/P2`h>H00`21
ZH4051PB086YP@0602DX7P03086YP@0b=2L0<S@W00P0<S@W00<0PJV10456<`11AS<02@11AS<>086Y
P@T0HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00B065cD003086YP@1KJdX0Ff]:
0080Ff]:2@21ZH4304YB>`03086YP@11AS<0@DHc00/0@DHc00<0PJV1038d9`0b=2L01P0b=2L00`21
ZH4092LN02@W7P0202@W7P03086YP@2`h>H0/>3V0;00/>3V0@3oool00;40/>3V00<0PJV101@H4P21
ZH401@0U:1h2086YP@X0<S@W00@0PJV10456<`11AS<0@DHc2@21ZH4405YZCP03086YP@1RM5@0HWAD
0100HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:
00X0Ff]:2021ZH4:0456<`03086YP@0b=2L0<S@W00H0<S@W00<0PJV102@W7P0T9ah00P0T9ah00`21
ZH40/>3V0;3PiP2_0;3PiP40oooo002_0;3PiP04086YP@0D618051PB086YP@D09BPN00<0PJV1038d
9`0b=2L01P0b=2L8086YP@`0FVY>00<0PJV1069dE01RM5@04@1RM5@00`21ZH40I7MD06AgE00B06Ag
E003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX03`1KJdX00`21ZH40Df1305=P@`08086Y
P@<0@DHc00<0PJV1038d9`0b=2L01P0b=2L2086YP@<092LN00<0PJV10;3PiP2`h>H0[P2`h>H10?oo
o`00[P2`h>H01021ZH4051PB01@H4P21ZH4502DX7P03086YP@0b=2L0<S@W00L0PJV10P1;ET400`21
ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0100HWAD00<0PJV106AgE01TMe@04`1TMe@00`21
ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:00l0Ff]:00<0PJV105=P@`1CH4<0201CH4<7086Y
P@L0<S@W00D0PJV102@W7P0T9ah092LN086YP@2_0;3PiP40oooo002]0;3PiP04086YP@0D6180PJV1
086YP@@09BPN1@21ZH4904]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1069dE01RM5@04@1RM5@0
0`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX0401KJdX0
0`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0PJV100D0PJV10P0b=2L01@21ZH4092LN02@W7P0T
9ah0PJV10:h0/>3V0@3oool00:/0/>3V00@0PJV101@H4P0D6180PJV10`0U:1h4086YP@`0BeI100<0
PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD069dE00A069dE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0?05][BP03086YP@1CH4<0Df1300`0Df1300<0
PJV104A<=P14C3H01@14C3H5086YP@8092LN0P21ZH6/0;3PiP40oooo002Z0;3PiP03086YP@0D6180
51PB00D0PJV10P0b=R/00`21ZH40BeI104]F@@0;04]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1
069dE01RM5@04P1RM5@00`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV1
05][BP1KJdX0401KJdX00`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0A4`f00P0A4`f0`21ZH42
02@W7P03086YP@2`h>H0/>3V0:T0/>3V0@3oool00:T0/>3V0P0D6183086YP@H0<SH[00<0PJV104]F
@@1;ET402P1;ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0180HWAD00<0PJV106Ag
E01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:0100Ff]:00<0PJV105=P
@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0PJV100<0PJV1ZP2`h>H10?oo
o`00Y`2`h>H5086YP@L0<SH[00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0?05YZCP03
086YP@1RM5@0HWAD0180HWAD00<0PJV106AgE01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003
086YP@1KJdX0Ff]:0140Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0704A<=P03
086YP@0];b@0;BlT0080;BlT0P21ZH6Y0;3PiP40oooo002V0;3PiP80PJV10P0K7aL00`21ZH40<SH[
038f:`05038f:`03086YP@1;ET40BeI100/0BeI100<0PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD
069dE00C069dE003086YP@1TMe@0I7MD01@0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:
05][BP0A05][BP03086YP@1CH4<0Df1300`0Df1300<0PJV104A<=P14C3H02014C3H00`21ZH40;BlT
02d_900302d_9080PJV1Y`2`h>H10?ooo`00Y@2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[
00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0@05YZCP03086YP@1RM5@0HWAD0180HWAD
00<0PJV106AgE01TMe@05@1TMe@00`21ZH40HG=@065cD00D065cD003086YP@1KJdX0Ff]:0140Ff]:
00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00<0;BlT
0P21ZH6V0;3PiP40oooo002T0;3PiP03086YP@0K7aL06alG00806alG00<0PJV1038f:`0b=R/0100b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00l0FVY>00<0PJV1069dE01RM5@04`1R
M5@00`21ZH40I7MD06AgE00E06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV105][BP1KJdX04P1K
JdX00`21ZH40Df1305=P@`0=05=P@`03086YP@14C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0]
;b@2086YPJD0/>3V0@3oool00:@0/>3V00D0PJV101/O5`0K7aL06alG086YP@07038f:`03086YP@1;
ET40BeI100/0BeI100<0PJV105YZCP1JJTh0401JJTh00`21ZH40HWAD069dE00C069dE003086YP@1T
Me@0I7MD01D0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0B05][BP03086YP@1C
H4<0Df1300d0Df1300<0PJV104A<=P14C3H02@14C3H00`21ZH40;BlT02d_900302d_9080PJV1Y02`
h>H10?ooo`00X`2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[00<0PJV104]F@@1;ET40301;
ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD00T0HWAD;`21ZH4<065cD003086YP@1K
JdX0Ff]:0180Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0]
;b@0;BlT00@0;BlT0P21ZH6S0;3PiP40oooo002R0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00`0FVY>4021ZH4;07F?J003086YP@1g
TFP0Mi5X01D0Mi5X00<0PJV107B=I01dSF@02@1dSF@G086YP@X0Ff]:00<0PJV105=P@`1CH4<03P1C
H4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00@0;BlT0P21ZH6R0;3PiP40oooo002Q
0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b=R/00`21ZH40BeI104]F@@0=04]F@@03086YP@1J
JTh0FVY>0080FVY>2P21ZH4406j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05@1g
TFP00`21ZH40M8eT07B=I00E07B=I003086YP@1/Pe/0K8=K00P0K8=K4021ZH4<05=P@`03086YP@14
C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2Q0;3PiP40oooo002P
0;3PiP05086YP@0K7aL06alG01/O5`21ZH40200b=R/00`21ZH40BeI104]F@@0804]F@@X0PJV13@1^
QV<00`21ZH40MHmX07F?J00D07F?J003086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05@1d
SF@00`21ZH40K8=K06b3F`0C06b3F`03086YP@1QM4l0HGA?0080HGA?2@21ZH4305=P@`03086YP@14
C3H0A4`f00T0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2P0;3PiP40oooo002P
0;3PiP04086YP@0K7aL06alG086YP@P0<SH[00@0PJV104]F@@1;ET40BeI12021ZH44065dF003086Y
P@1^QV<0KXIS0100KXIS00<0PJV107F?J01eSfP0501eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01H0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0:065dC`L0PJV1
2@14C3H00`21ZH40;BlT02d_900302d_9003086YP@0I7AH0PJV109l0/>3V0@3oool009l0/>3V00D0
PJV101/O5`0K7aL06alG086YP@06038f:`H0PJV12`1QM5P00`21ZH40KXIS06j6H`0A06j6H`03086Y
P@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086Y
P@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df93086YP@03086YP@D0A4`f
00<0PJV102d_900];b@0100];b@2086YPIl0/>3V0@3oool009h0/>3V00D0PJV101/O5`0K7aL06alG
086YP@03038f:`D0PJV1401QM5P00`21ZH40KXIS06j6H`0A06j6H`03086YP@1eSfP0MHmX01@0MHmX
00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0K8=K01<0K8=K
00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df9305=R@`0305=R@`D0PJV100<0A4`f086YP@0];b@0
1@0];b@2086YPIh0/>3V0@3oool009d0/>3V00@0PJV101/O5`0K7aL06alG1@21ZH4404UE@`03086Y
P@1QM5P0HGAH00d0HGAH00<0PJV106j6H`1^QV<04@1^QV<00`21ZH40MHmX07F?J00E07F?J003086Y
P@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05P1dSF@00`21ZH40K8=K06b3F`0D06b3F`03086Y
P@1QM4l0HGA?00l0HGA?00<0PJV105=R@`1CHT<01`1CHT<5086YP@@0;BlT0P21ZH6M0;3PiP40oooo
002L0;3PiP04086YP@0K7aL06alG01/O5`80PJV11`19ED<00`21ZH40HGAH065dF00>065dF003086Y
P@1^QV<0KXIS0140KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01L0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0?065dC`03086Y
P@1CHT<0Df9300X0Df9300<0PJV103]3<021ZH400`21ZH400`0];b@0PJV1086YP@2L0;3PiP40oooo
002L0;3PiP04086YP@0K7aL0PJV1086YP@T0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS
06j6H`0B06j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05`1gTFP00`21ZH40M8eT
07B=I00G07B=I003086YP@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df93
05=R@`0905=R@`03086YP@0k@c00>d<`00<0>d<`1021ZH6K0;3PiP40oooo002K0;3PiP<0PJV100<0
:2hV086YP@19ED<01`19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0140KXIS00<0
PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01H0M8eT00<0
PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0?065dC`03086YP@1CHT<0Df9300X0Df9300<0
PJV103]3<00k@c001@0k@c02086YPIX0/>3V0@3oool009X0/>3V0P21ZH4202P^9P03086YP@19ED<0
BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0B06j6H`03086YP@1eSfP0
MHmX01D0MHmX00<0PJV107NAJ01gTFP0601gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0
K8=K01@0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df9305=R@`0905=R@`03086YP@0k@c00
>d<`00D0>d<`0`21ZH6I0;3PiP40oooo002I0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE
@`19ED<01P19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c001@0k@c000`21ZH407b8J086YP@2H0;3PiP40oooo002I0;3PiP05086YP@0X;RH0:2hV02P^
9P21ZH402@19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c00100k@c001021ZH407b8J01lR6P21ZH6G0;3PiP40oooo002H0;3PiP05086YP@0X;RH0:2hV
02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV1
07F?J01eSfP05P1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV1
06b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV1
03]3<00k@c001@0k@c000`21ZH407b8J086YP@2G0;3PiP40oooo002G0;3PiP03086YP@0X;RH0:2hV
0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01L0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002G0;3PiP05
086YP@0X;RH0:2hV02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002F0;3PiP03
086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003
086YP@1^QV<0KXIS01@0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003
086YP@1dSF@0M8eT01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03
086YP@1CHT<0Df9300X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2E0;3PiP40
oooo002E0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH
065dF00>065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?J01eSfP02P1eSfQ9086YPA40K8=K
00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086YP@0k@c00>d<`00D0>d<`
00@0PJV101lR6P0O8QX0PJV1U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^9P0302P^9P03086Y
P@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0906j6HaP0PJV1
3023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0PJV107^HJ`1kV6/0
0`1kV6/<086YP@H0K8=K00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086Y
P@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^
9P0202P^9P03086YP@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P02P1QM5P@086YP@/0OIad00<0
PJV108>SN023XgP05P23XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0
PJV107^HJ`1kV6/03`1kV6/A086YP@T0HGA?00<0PJV105=R@`1CHT<02`1CHT<00`21ZH40>d<`03]3
<00403]3<004086YP@0O8QX07b8J086YPI<0/>3V0@3oool009<0/>3V00<0PJV102P^9P0X;RH00P0X
;RH00`21ZH40BEE304UE@`0804UE@`04086YP@1QM5P0HGAH065dF0T0PJV1101bSF/00`21ZH40OIad
07fLM00D07fLM003086YP@23XgP0Pj=h01H0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c
086QL`0H086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d0201^R5d=086YP@X0Df93
00<0PJV103]3<00k@c001@0k@c001021ZH407b8J01lR6P21ZH6B0;3PiP40oooo002B0;3PiP03086Y
P@0X;RH0:2hV00<0:2hV00<0PJV104UE@`19ED<01P19ED<6086YP@`0LXe[00<0PJV107fLM01mW7@0
501mW7@00`21ZH40Pj=h08>SN00G08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<0
6@21XG<00`21ZH40NiQ[07^HJ`0D07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0
1@21ZH4605=R@`03086YP@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40TP2`h>H10?ooo`00TP2`
h>H00`21ZH40:2hV02P^9P0202P^9P03086YP@19ED<0BEE300<0BEE31021ZH400`1LL5P0PJV107:=
J`0?07:=J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BT
M`0I08BTM`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8
G@0B06j8G@03086YP@1NLTd0GW9=00@0GW9=1@21ZH400`1CHT<0PJV103]3<00603]3<004086YP@0O
8QX07b8J086YPI40/>3V0@3oool00940/>3V00<0PJV102P^9P0X;RH00`0X;RH00`21ZH40BEE3086Y
P@03086YP@@0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23
XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I086QL`03086YP@1k
V6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0905ibC@D0PJV11@0k
@c000`21ZH407b8J086YP@2A0;3PiP40oooo002@0;3PiP03086YP@0X;RH0:2hV0080:2hV1021ZH48
05a`F003086YP@1bSF/0LXe[00h0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00G
08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21XG<00`21ZH40NiQ[07^HJ`0E
07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21ZH40AeDj04ME>P04
086YP@0503]3<021ZH407b8J01lR6P21ZH40T02`h>H10?ooo`00T02`h>H00`0X;RH0PJV1086YP@02
086YP@0303M0=`21ZH40G71H00T0G71H00<0PJV107:=J`1bSF/03P1bSF/00`21ZH40OIad07fLM00E
07fLM003086YP@23XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I
086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0<
05ibC@03086YP@17ECX0AeDj00<0AeDj0`21ZH4201lR6P03086YP@2`h>H0/>3V08d0/>3V0@3oool0
08l0/>3V0P21ZH4403M0=`03086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21
ZH40OIad07fLM00D07fLM003086YP@23XgP0Pj=h01P0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21
ZH40PJ5c086QL`0I086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21
ZH40GW9=05ibC@0805ibC@040?mo001NLTd0GW9=086YP@L0AeDj1021ZH6?0;3PiP40oooo002?0;3P
iP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=
J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0I08BT
M`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8
G@03086YP@1NLTd0GW9=00L0GW9=0`3oO`000`1NLTd0PJV104ME>P0704ME>P04086YP@0T9ad0PJV1
086YPHh0/>3V0@3oool008h0/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`
F003086YP@1bSF/0LXe[00h0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00G08>S
N003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21XG<06P21XG<00`21ZH40NiQ[07^HJ`0E07^H
J`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0201NLTd20?mo0080GW9=00<0PJV104ME
>P17ECX01@17ECX01021ZH4092LM02@W7@0T9af>0;3PiP40oooo002>0;3PiP03086YP@0g@3L0=d0g
00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad
01D0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c
01X0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=
00L0GW9=0P3oO`0205ibC@03086YP@17ECX0AeDj00H0AeDj00@0PJV102@W7@0T9ad0PJV1S@2`h>H1
0?ooo`00S@2`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV107:=
J`1bSF/03`1bSF/00`21ZH40OIad07fLM00E07fLM003086YP@23XgP0Pj=h01L0Pj=h00<0PJV108BT
M`24Y7L06P24Y7L00`21ZH40PJ5c086QL`0J086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8
G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0705ibC@<0ogl00P1NLTd00`21ZH40AeDj04ME>P0504ME
>P04086YP@0T9ad092LM086YPHd0/>3V0@3oool008d0/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21
ZH40G71H05a`F00805a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21
ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21XG<06P21XG<00`21
ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0201NLTd20?mo
0080GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM02@W7@21ZH6<0;3PiP40oooo002<0;3P
iP03086YP@0g@3L0=d0g00@0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=
J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BT
M`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0A06j8
G@030?mo001^R5d0PJV100T0GW9=0P3oO`0205ibC@03086YP@17ECX0AeDj00H0AeDj00@0PJV102@W
7@0T9ad0PJV1S02`h>H10?ooo`00S02`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H
00T0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00E07fLM003086YP@23XgP0Pj=h
01P0Pj=h00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PJ5c086QL`0J086QL`03086YP@1kV6/0NiQ[
01H0NiQ[00<0PJV106j8G@1^R5d0401^R5d30?mo0003086YP@1NLTd0GW9=00L0GW9=0`3oO`0205ib
C@03086YP@17ECX0AeDj00D0AeDj00D0PJV102@W7@0T9ad092LM086YP@2;0;3PiP40oooo002;0;3P
iP03086YP@0g@3L0=d0g00@0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=
J`03086YP@1mW7@0OIad01H0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BT
M`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05`1kV6/00`21ZH40KXQM06j8G@0@06j8
G@80ogl000<0PJV105ibC@1NLTd01@1NLTd20?mo000705ibC@3oO`00ogl005ibC@3oO`00PJV10?mo
000704ME>P04086YP@0T9ad092LM086YPH/0/>3V0@3oool008/0/>3V00<0PJV103M0=`0g@3L00`0g
@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01mW7@05P1m
W7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21XG<06`21
XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0100KXQM0`3oO`0705ibC@80ogl000<0
GW9=0?mo003oO`001@3oO`0604ME>P05086YP@0T9ad092LM02@W7@21ZH40RP2`h>H10?ooo`00R`2`
h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV107:=J`1bSF/03`1b
SF/00`21ZH40OIad07fLM00E07fLM003086YP@23XgP0Pj=h01T0Pj=h00<0PJV108BTM`24Y7L06P24
Y7L00`21ZH40PJ5c086QL`0K086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04@1^
R5d20?mo0003086YP@1NLTd0GW9=00@0GW9=0P3oO`000`1NLTd0ogl00?mo00060?mo00D0AeDj00D0
ogl0086YP@0T9ad092LM086YP@2:0;3PiP40oooo002:0;3PiP03086YP@0g@3L0=d0g00@0=d0g00<0
PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0@07:=J`03086YP@1mW7@0OIad01D0OIad00<0
PJV108>SN023XgP06@23XgP00`21ZH40Q:Ag08BTM`0<08BTMad0PJV13`21XG<00`21ZH40NiQ[07^H
J`0F07^HJ`03086YP@1^R5d0KXQM0140KXQM0P3oO`000`21ZH40GW9=05ibC@0405ibC@80ogl00P1N
LTd20?mo0080GW9=00<0PJV10?mo003oO`000P17ECX50?mo008092LM00<0ogl00;3PiP3oO`00R02`
h>H10?ooo`00RP2`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV1
07:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00:07fLM3L0PJV13P2>/h<00`21ZH40S;1n08b`OP0<
08b`OQ`0PJV13@1kV6/00`21ZH40KXQM06j8G@0@06j8G@<0ogl01P1NLTd20?mo0080GW9=0P3oO`03
05ibC@04086YP@3oO`00ogl004ME>P/0ogl0Q`2`h>H10?ooo`00R@2`h>H00`21ZH40=d0g03M0=`04
03M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV107:=J`1bSF/02`1bSF/A086YP@`0RJf100<0PJV1
08jcQ02>/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV1
08JXM`26Z7L02P26Z7LH086YP@T0KXQM0P3oO`000`21ZH40GW9=05ibC@0305ibC@80ogl00P1NLTd2
0?mo00<0GW9=00D0PJV10?mo003oO`00ogl004ME>P020?mo000304ME>P3oO`00ogl000D0ogl0Q`2`
h>H10?ooo`00R@2`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV1
07:=J`1bSF/00P1bSF/:086YP@@0Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00I
08jcQ003086YP@2>/h<0S[>301X0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G
08JXM`03086YP@1kVV/0NiY[00P0NiY[2@21ZH430?mo00<0PJV10P1NLTd20?mo0080GW9=0`3oO`02
05ibC@05086YP@17ECX0ogl00?mo0017ECX00P3oO`0204ME>PL0ogl0QP2`h>H10?ooo`00R02`h>H0
0`21ZH40=d0g03M0=`0403M0=`03086YP@1LL5P0G71H00H0G71H2021ZH4>07nPNP03086YP@29[H40
RJf101H0RJf100<0PJV108jcQ02>/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0
S;1n01/0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0B07^JJ`T0ogl00`21ZH42
0?mo00<0GW9=00@0PJV10?mo003oO`00AeDj0P3oO`0304ME>PL0ogl0Q@2`h>H10?ooo`00R02`h>H0
0`21ZH40=d0g03M0=`0303M0=`04086YP@1LL5P0G71H05a`F0H0PJV10`1[QVT00`21ZH40Oj1j07nP
NP0@07nPNP03086YP@29[H40RJf101D0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jc
P`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^J
J`0B07^JJ`T0ogl00`1WPEH20?mo00@0PJV11@3oO`0304ME>PL0ogl0Q@2`h>H10?ooo`00Q`2`h>H0
1021ZH40=d0g03M0=`0g@3L7086YP@T0JhIY00<0PJV107nPNP1oX7X03`1oX7X00`21ZH40RJf108V]
P@0F08V]P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`
OP0K08b`OP03086YP@26Z7L0QZQg01P0QZQg00<0PJV107^JJ`1kVV/04P1kVV/20?mo00@0Ih5F0P3o
O`0306N1EP<0ogl00P1WPEH00`21ZH40DF=30?mo00040?mo0003086YP@17ECX0ogl000H0ogl0Q@2`
h>H10?ooo`00Q`2`h>H4086YP@<0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21ZH40Oj1j07nPNP0@
07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0J
08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0B
07^JJ`80ogl0101WPEH20?mo00@0Ih5F0P3oO`0206N1EP05086YP@1AHd<0ogl00?mo001AHd<00`3o
O`02086YP@H0ogl0Q@2`h>H10?ooo`00QP2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02@1[QVT0
0`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@0
0`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L0
0`21ZH40NiY[07^JJ`0B07^JJ`<0ogl00`1WPEH20?mo00@0Ih5F0P3oO`0306N1EP03086YP@3oO`00
ogl00080DF=30P3oO`02055S@`L0ogl0Q02`h>H10?ooo`00QP2`h>H2086YP@D0AeQ900<0PJV106^6
J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jc
Q02>/h@06P2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JX
M`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`80ogl00`1WPEH20?mo00@0Ih5F0`3oO`0206N1
EP03086YP@3oO`00ogl00080DF=30P3oO`02055S@`L0ogl0Q02`h>H10?ooo`00QP2`h>H00`21ZH40
AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40
RJf108V]P@0F08V]P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40
S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/30?mo0080
Ih5F0P3oO`0506N1EP<0ogl000@0Ih5F086YP@3oO`00ogl00P1AHd<30?mo0003055S@`3oO`00ogl0
00D0ogl0Q02`h>H10?ooo`00QP2`h>H00`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY00X0
JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>401X0
S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg01L0
QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40ogl00?mo000206N1EP80ogl01@1WPEH40?mo0003
086YP@3oO`00ogl000<0DF=30P3oO`000`1AHd<0ogl00?mo00050?mo08@0/>3V0@3oool008D0/>3V
0P21ZH4604MHB@03086YP@1[QVT0JhIY00T0JhIY00<0PJV107nPNP1oX7X04@1oX7X00`21ZH40RJf1
08V]P@0F08V]P@03086YP@2>/h@0S[>401T0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n
08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/0501kVV/01021ZH40ogl0
06N1EP1WPEH20?mo00D0Ih5F103oO`00101WPEH0ogl00?mo003oO`03055S@`@0ogl000<0;CDU0?mo
003oO`000`3oO`230;3PiP40oooo00250;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6J@03
086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003
086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G08JXM`03
086YP@1kVV/0NiY[01@0NiY[00@0PJV10?mo003oO`00Ih5F0P3oO`0606N1EPH0ogl0101AHd<40?mo
0003086YP@3oO`00ogl000<0ogl0P`2`h>H10?ooo`00Q@2`h>H2086YP@D0AeQ900<0PJV106^6J@1[
QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>
/h@06P2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26
Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`04086YP@1WPEH0ogl006N1EP80ogl01`1WPEH40?mo
00H0DF=30`3oO`000`21ZH40ogl00?mo00030?mo08<0/>3V0@3oool008D0/>3V00<0PJV104MHB@17
F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29
[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2<
/7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1EP3o
O`000`3oO`0:06N1EP03086YP@1AHd<0DF=300@0DF=30`3oO`000`21ZH40;CDU0?mo00030?mo08<0
/>3V0@3oool008D0/>3V00<0PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086Y
P@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086Y
P@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086Y
P@1kVV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH00`3oO`0;06N1EP03086YP@1AHd<0DF=300H0DF=3
00<0PJV102de9@3oO`00103oO`220;3PiP40oooo00240;3PiP80PJV11P17F4T00`21ZH40JhIY06^6
J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jc
Q00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JX
M`0H08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH00P3oO`0;06N1EP03086YP@1A
Hd<0DF=300L0DF=300<0PJV10?mo003oO`000`3oO`220;3PiP40oooo00240;3PiP80PJV11P17F4T0
0`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405P29[H40
0`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h0702</7h0
0`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH00P3oO`0;
06N1EP03086YP@1AHd<0DF=300L0DF=300<0PJV102de9@3oO`000P3oO`230;3PiP40oooo00240;3P
iP80PJV11@17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]
P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`
OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1
EP1WPEH00P3oO`0;06N1EP03086YP@1AHd<0DF=300L0DF=300<0PJV102de9@3oO`000P3oO`230;3P
iP40oooo00240;3PiP03086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40
Oj1j07nPNP0A07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40
S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40
NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F0080ogl0301WPEH00`21ZH40DF=3055S@`06055S@`03
086YP@0]=BD0ogl000<0ogl0PP2`h>H10?ooo`00P`2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT0
2P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@0
6`2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L0
6026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S@`1AHd<0
1`1AHd<00`21ZH40ogl00?mo00020?mo0880/>3V0@3oool008<0/>3V0P21ZH4604MHB@03086YP@1[
QVT0JhIY00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>
/h@0S[>401/0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26
Z7L0QZQg01P0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0>06N1EP03086YP@1A
Hd<0DF=300L0DF=300D0PJV102de9@3oO`00;CDU0?mo00220;3PiP40oooo00230;3PiP80PJV11P17
F4T00`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405P29
[H400`21ZH40S[>408jcQ00=08jcQ5X0PJV13@26Z7L00`21ZH40NiY[07^JJ`0D07^JJ`03086YP@1W
PEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0ogl00880/>3V
0@3oool008<0/>3V00<07BHS086YP@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1o
X7X0Oj1j00P0Oj1j<P21ZH4>09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D
_HP00`21ZH40S[F108jeP@0;08jePAT0PJV12`1kVV/00`21ZH40Ih5F06N1EP0>06N1EP03086YP@1A
Hd<0DF=300H0DF=300D0PJV102de9@0]=BD0;CDU086YP@220;3PiP40oooo00230;3PiP03086YP@17
F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT0101[QVTA086YP@T0RJn600<0PJV109:kS02B^h`05P2B
^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D
_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf00T0Q:Qf8@21ZH45055S@`04086YP@0]
=BD0;CDU086YPH80/>3V0@3oool00880/>3V0P21ZH4304MHB@X0PJV11P1gV7L00`21ZH40RJn608V_
QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0
S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BX
MP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT00P1GKTT7086YP@80;CDU00<0
PJV10;3PiP2`h>H0O`2`h>H10?ooo`00PP2`h>H5086YP@<0E6]I00<0PJV107NHM`1gV7L02P1gV7L0
0`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh0
0`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H40
0`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT0
0`21ZH40<d4/086YP@02086YPH40/>3V0@3oool00880/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg
00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>
01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F1
01P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi9
00L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00220;3PiP80PJV11P1DJeT00`21
ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21
ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21
ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21
ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00PP2`h>H2086Y
P@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<
01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f8
01`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R
00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840/>3V0@3oool0
0880/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21
ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21
ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21
ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@21
0;3PiP40oooo00220;3PiP03086YP@1DJeT0E6]I00@0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21
ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21
ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21
ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21
ZH40<d4/03=1;00c@B`0PJV10840/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg
00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>
01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F1
01P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi9
00L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21
ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21
ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21
ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21
ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00P@2`h>H2086Y
P@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<
01H0T[^<00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f8
01`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R
00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840/>3V0@3oool0
0840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21
ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21
ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H04`24Z7H00`21
ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@21
0;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn6
0140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<
01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf
01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@04086YP@0c@B`0<d4/
086YPH40/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_
QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0
S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BX
MP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1
;00c@B`0<d4/086YP@200;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NH
M`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09Jo
SP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08je
P@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^
B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NH
M`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109Jo
SP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108je
P@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^
B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00840/>3V00<092l]086Y
P@1DJeT01@1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:k
S02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109Bm
R02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:A
HP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H1
0?ooo`00P@2`h>H00`21ZH40E6]I05A[F@0405A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_
QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0
S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BX
MP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1
;00c@B`0<d4/086YP@200;3PiP40oooo00200;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NH
M`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09Jo
SP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08je
P@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^
B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0E6]I00<0PJV107NH
M`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109Jo
SP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108je
P@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^
B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00800/>3V0P21ZH4605A[
F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:k
S003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09Bm
R003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:A
HP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40oooo00200;3P
iP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:k
S02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109Bm
R02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:A
HP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H1
0?ooo`00P02`h>Kc086YPH00/>3V0@3oool00800/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0
P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0
WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0
UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0
G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00200;3PiP80PJV11P1NNfD00`21ZH40
P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40
WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40
UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40
G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0
GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0
V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0
VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0
Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V0@3oool00800
/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40
V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40
VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40
Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3P
iP40oooo00210;3PiP03086YP@1NNfD0GW]U00@0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40
TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40
WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40
S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40
>4Ta03Q9<@0hBC40PJV10800/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0
P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0
WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0
UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0
G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40
P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40
WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40
UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40
G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0
GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0
V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0
VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0
Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V0@3oool00840
/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40
V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40
VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40
Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3P
iP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140
TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0
WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0
S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`04086YP@0hBC40>4Ta086Y
PH40/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A
_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02M
bY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<
]7l04`2<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0h
BC40>4Ta086YP@210;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03
086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0J09g:UP03
086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03
086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05
086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20
YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2M
bYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E
`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1L
N4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00840/>3V0P21ZH4605ikI@03
086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03
086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003
086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03
086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiP03
086YP@1NNfD0GW]U00@0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03
086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003
086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03
086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV1
0840/>3V0@3oool00880/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A
_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02M
bY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<
]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0h
BC40>4Ta086YP@210;3PiP40oooo00220;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03
086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03
086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03
086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05
086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H2086YP@H0GW]U00<0PJV1082VPP20
YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2M
bYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E
`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1L
N4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00880/>3V0P21ZH4605ikI@03
086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03
086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003
086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03
086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiPD0
PJV10`1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2J
aYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02K
ai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1k
WVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`03086YP@0hBC40>4Ta0080PJV1P@2`h>H10?ooo`00
PP2`h>H2086YP@<0IHM^2P21ZH46082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD0
5P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00
702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd0
1P1kWVdE086YP@0303]?<`21ZH40/>3V0800/>3V0@3oool008<0/>3V00<0PJV106F7KP1UQfh0101U
Qfh00`21ZH40Q[2:08J`RP0408J`RQ00PJV12P2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2M
bYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E
`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l02@2<]7lD086YP@P0PJQe00<0PJV106>3F01SPeP01`1S
PeP01021ZH40>dlc03]?<`0kCc>20;3PiP40oooo00230;3PiP80PJV11@1UQfh00`21ZH40Q[2:08J`
RP0:08J`RP03086YP@2GaYL0UlJG00L0UlJG<P21ZH4?09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0;09G0RQT0PJV12`2A_HL00`21ZH40PJQe086X
M@0>086XM@03086YP@1SPeP0Hh=H00H0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@220;3PiP40oooo
00230;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG0140UlJG00<0
PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0<0:;CWE/0PJV13@2KbI400`21ZH40TKf7096m
Q`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01@21ZH40>dlc03]?
<`0kCc<0PJV10880/>3V0@3oool008<0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0
PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01/0X]>M00<0
PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01P0VlVA00<0
PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0>086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0
PJV103]?<`0kCc<0>dlc086YP@220;3PiP40oooo00230;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`
RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;C
W@0K0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9
T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3
F00706>3F004086YP@0kCc<0>dlc086YPH<0/>3V0@3oool008@0/>3V00<0PJV106F7KP1UQfh0101U
Qfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2O
ci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702P
d9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03P21
Z7D00`21ZH40Hh=H06>3F00606>3F005086YP@0kCc<0>dlc03]?<`21ZH40P`2`h>H10?ooo`00Q02`
h>H2086YP@D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0A09O6U`03086YP@2O
ci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2P
d9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21
Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108<0/>3V
0@3oool008@0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6U`2GaYL04@2G
aYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702R
di/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL0502A
_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc
086YP@230;3PiP40oooo00240;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2G
aYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2R
di/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A
_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F004086YP@0k
Cc<0>dlc086YPH@0/>3V0@3oool008D0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`
RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;C
W@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9
T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3
F00606>3F005086YP@0kCc<0>dlc03]?<`21ZH40Q02`h>H10?ooo`00Q@2`h>H00`21ZH40IHM^06F7
KP0406F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?
W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@
U`0K0:3@U`03086YP@2KbI40VlVA01P0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086X
M@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@240;3PiP40oooo
00250;3PiP80PJV11@1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0
PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0
PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0
PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40
Q02`h>H10?ooo`00Q@2`h>H2086YP@H0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6
U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;C
V`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096m
Q`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?
<`21ZH650;3PiP40oooo00250;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0908J`RP03086YP@2G
aYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0I0:;CW@03086YP@2R
di/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A
_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00606>3F005086YP@0k
Cc<0>dlc03]?<`21ZH40Q@2`h>H10?ooo`00QP2`h>H00`21ZH40IHM^06F7KP0406F7KP03086YP@26
/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2R
did0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2K
bI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1S
PeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@250;3PiP40oooo00240;3PiP80000000<0
PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0
PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0
PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0
PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40
Q@2`h>H10?ooo`00Q02`h>H4000000D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6
U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;C
V`0J0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096m
Q`0C096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?
<`21ZH660;3PiP40oooo00240;3PiP@000001P1UQfh00`21ZH40Q[2:08J`RP0908J`RP03086YP@2G
aYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2R
di/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A
_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00606>3F003086YP@0k
Cc<0>dlc0080PJV1QP2`h>H10?ooo`00Q02`h>H500000080PJV100@0IHM^000000000000PJV12`26
/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2R
did00`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2K
bI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00`0PJQe00<0PJV106>3F01SPeP01@1S
PeP5086YP@0303]B=021ZH40/>3V08D0/>3V0@3oool008D0/>3V0P0000001021ZH40000006R>M01X
SW@4000000<0PJV10`26/8X00`000000Q[2:08J`RP0308J`RP03086YP@2GaYL0UlJG00l0UlJG00<0
PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0
PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0
PJV1086XM@21Z7D03021Z7D00`21ZH40Hh=H06>3F005086YP@80Ih]O00@0PJV103]B=00kDS@0PJV1
Q`2`h>H10?ooo`00Q@2`h>H;00000080RKN@0P21ZH4300000005086YP@26/8X0Q[2:08J`RP21ZH40
4P2GaYL00`21ZH40WlnL09o?W00E09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0
6P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL0
4`2A_HL00`21ZH40PJQe086XM@0:086XM@H0PJV11P1WRel01@21ZH40>e8d03]B=00kDS@0PJV108L0
/>3V0@3oool008D0/>3V0`0000001021ZH40000000000000000206R>M0<000000`29]i04000000P0
PJV13P2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01T0X]>M00<0PJV10:;CV`2R
di/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A
_HL04`2A_HL00`21ZH40PJQe086XM@02086XM@P0PJV10`25/7`00`21ZH40Ih]O06N;G`0606N;G`04
086YP@0kDS@0>e8d086YPHP0/>3V0@3oool008H0/>3V1P00000306R>M0<000000P29]i03000000@0
RKN@00<0PJV109_=W@2KcId00P2KcId:086YP@@0UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40
X]>M0:;CW@0I0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40
VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf700T0TKf73`21ZH4:08F`O003086YP@1WRel0Ih]O00H0
Ih]O00D0PJV103]B=00kDS@0>e8d086YP@280;3PiP40oooo00260;3PiP<0000000<0PJV100000000
0000101XSW@300000080RKN@0P00000508VgT003086YP@2KcId0VlfM00/0VlfM4@21ZH4<09o?W003
086YP@2Rdid0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03
086YP@2KbI40VlVA00/0VlVA6021ZH4:09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1W
Rel01P1WRel01021ZH40>e8d03]B=021ZH690;3PiP40oooo00270;3PiP<0000000<0PJV106R>M01X
SW@00`1XSW@2000000<0RKN@0P00000508VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2S
eZ802P2SeZ8g086YP@h0X]>K00<0PJV10:3@U`2Pd9L03@2Pd9LL086YP@`0W]2G00<0PJV109G4S@2E
a8d04P2Ea8d00`21ZH40QK1l08F`O00=08F`O003086YP@1WRel0Ih]O00D0Ih]O00D0PJV103]B=00k
DS@0>e8d086YP@290;3PiP40oooo00270;3PiP<0000000<0PJV106R>M01XSW@00`1XSW@2000000X0
RKN@00<0PJV109_=W@2KcId0402KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01T0
Y]ZS00<0PJV10:KJX@2VfZ40302VfZ4N086YP@h0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40
ULB=09G4S@0C09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01P1WRel01021ZH40
>e8d03]B=021ZH6:0;3PiP40oooo00280;3PiP@00000101XSW@2000000/0RKN@00<0PJV109_=W@2K
cId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01T0Y]ZS00<0PJV10:KJX@2V
fZ406P2VfZ400`21ZH40Y=NM0:CGW@0K0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2E
a8d04`2Ea8d00`21ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00k
DS@0PJV1RP2`h>H10?ooo`00R@2`h>H40000000306R>M0000000000000<000001@29]i000`000000
RKN@08VgT00208VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805P2SeZ800`21ZH40
Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06`2Teid00`21ZH40
W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40
Ih]O06N;G`0606N;G`05086YP@0kDS@0>e8d03]B=021ZH40RP2`h>H10?ooo`00R@2`h>H900000003
086YP@29]i00RKN@0080RKN@0`00000308VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2S
eZ805P2SeZ800`21ZH40Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2T
eid06P2Teid00`21ZH40W]2G09k@U`0G09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025
/7`03025/7`00`21ZH40Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d086YPH/0/>3V0@3oool008T0
/>3V1P00000306R>M003086YP@29]i00RKN@00<0RKN@0P00000408VgT003086YP@2KcId0VlfM00l0
VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0
Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=01<0
ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O06N;G`0506N;G`05086YP@0kDS@0>e8d03]B
=021ZH40R`2`h>H10?ooo`00R@2`h>H7000000<0J8id00<0PJV108VgT029]i000P29]i02000000@0
RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01P0
Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01H0
W]2G00<0PJV109G4S@2Ea8d04`2Ea8d00`21ZH40QK1l08F`O00;08F`O003086YP@1WRel0Ih]O00H0
Ih]O00@0PJV103]B=00kDS@0PJV1S02`h>H10?ooo`00R@2`h>H800000080J8id00<0PJV108VgT029
]i000P29]i03000000<0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03
086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03
086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00<08F`O003
086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV1S02`h>H10?ooo`00RP2`h>H300000003
086YP@1XSW@000000080000000<0J8id0000000000001029]i02000000@0RKN@00<0PJV109_=W@2K
cId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2V
fZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2E
a8d04P2Ea8d00`21ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00D0Ih]O00@0PJV103]B=00k
DS@0PJV1S@2`h>H10?ooo`00RP2`h>H3000000030;3PiP21ZH40J8id0080000000@0J8id00000000
000000000`29]i02000000@0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?F
XP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CG
W@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2Ea8d04`2Ea8d00`21ZH40QK1l08F`O00;08F`
O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV1S@2`h>H10?ooo`00R`2`h>H30000
0003086YP@1XSW@0000000@000001029]i03000000@0RKN@00<0PJV109_=W@2KcId03P2KcId00`21
ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21
ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21
ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00D0Ih]O00@0PJV103]B=00kDS@0PJV1SP2`h>H1
0?ooo`00S02`h>H2000000030;3PiP21ZH40000000<0000000<0J8id086YP@29]i000`29]i020000
00@0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS
01P0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21ZH40Y=NM0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G
01H0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00;08F`O003086YP@1WRel0Ih]O
00H0Ih]O00@0PJV103]B=00kDS@0PJV1SP2`h>H10?ooo`00S02`h>H300000080PJV1101XSW@00`21
ZH40RKN@08VgT00208VgT0<000000`29]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR
01@0XmJR00<0PJV10:KJX`2VfZ<0602VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM
01T0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l
00/0QK1l00<0PJV106N;G`1WRel01@1WRel01021ZH40>e8d086YP@21ZH6?0;3PiP40oooo002=0;3P
iP030000002`h>H0/>3V00D0PJV100<0J8id086YP@29]i000`29]i02000000@0RKN@00<0PJV109_=
W@2KcId03P2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJ
X@2VfZ406@2VfZ400`21ZH40Y=NM0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4
S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00<0Ih]O1021ZH400`0m
F3X0PJV10;3PiP2>0;3PiP40oooo002@0;3PiP03086YP@1YTGL0JI5g0080JI5g0`21ZH4308VgT080
00001029]i000`21ZH40VlfM09_=W@0>09_=W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2V
fZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2N
d9L05@2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00/0QK1l00<0PJV106N;G`1W
Rel01021ZH401@1XSf<0PJV103eH>P0mF3X0PJV10900/>3V0@3oool00940/>3V00<0PJV106VAM`1Y
TGL00`1YTGL4086YP@<000000`29]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR01@0
XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0
Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00T0
QK1l1@21ZH4506R?H`03086YP@0mF3X0?EPj0940/>3V0@3oool00980/>3V00<0PJV106VAM`1YTGL0
0P1YTGL00`21ZH40RKZB08VjTP0208VjTP8000000P21ZH4208VgT003086YP@2KcId0VlfM00h0VlfM
00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40Y]ZS0:KJX`0G0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ
00<0PJV10:CGW@2Teid06@2Teid00`21ZH40W]2G09k@U`0E09k@U`03086YP@2Ea8d0ULB=0180ULB=
00<0PJV108F`O025/7`01025/7`5086YP@0308FcO`21ZH40J8mS00H0J8mS00@0PJV103eH>P0mF3X0
PJV1T@2`h>H10?ooo`00TP2`h>H00`21ZH40JI5g06VAM`0306VAM`04086YP@29^Y80RKZB08VjTP80
00000P29^Y87086YP@`0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40Y]ZS0:KJX`0G0:KJX`03
086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40W]2G09k@U`0D09k@U`03
086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`01@21ZH4608FcO`03086YP@1XSf<0J8mS00D0
J8mS00<0PJV103eH>P21ZH40TP2`h>H10?ooo`00T`2`h>H00`21ZH40JI5g06VAM`0206VAM`04086Y
P@29^Y80RKZB08VjTP<000001029^Y801021ZH40Vm2P09_@X02Kd:09086YP@@0VlfM00<0PJV10:?F
XP2SeZ80502SeZ800`21ZH40Y]ZS0:KJX`0F0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CG
W@2Teid0602Teid00`21ZH40W]2G09k@U`0E09k@U`03086YP@2Ea8d0ULB=00P0ULB=3@21ZH4:08Fc
O`03086YP@1XSf<0J8mS00D0J8mS00@0PJV103eH>P0mF3X0PJV1TP2`h>H10?ooo`00U02`h>H00`21
ZH40JI5g06VAM`0206VAM`05086YP@29^Y80RKZB08VjTP0000001@29^Y800`21ZH40Vm2P09_@X00:
09_@X100PJV12`2SeZ800`21ZH40Y]ZS0:KJX`0F0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV1
0:CGW@2Teid0602Teid00`21ZH40W]2G09k@U`0@09k@Ua00PJV12@2GbI400`21ZH40QK=o08FcO`0;
08FcO`03086YP@1XSf<0J8mS00@0J8mS00@0PJV103eH>P0mF3X0PJV1T`2`h>H10?ooo`00U02`h>H0
0`21ZH40JI5g06VAM`0306VAM`03086YP@29^Y80RKZB00L0RKZB00<0PJV109_@X02Kd:003@2Kd:00
0`21ZH40Y=ZV0:CJYP090:CJYQP0PJV1302VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0
Y=NM01P0Y=NM00<0PJV109k@U`2Nd9L0102Nd9L<086YP@D0X=FK00<0PJV109O9T@2GbI404@2GbI40
0`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40U02`h>H1
0?ooo`00U@2`h>H00`21ZH40JI5g06VAM`0206VAM`03086YP@29^Y80RKZB00L0RKZB00<0PJV109_@
X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0C0:CJYP03086YP@2XgZL0Z=jW00X0Z=jWBP21ZH4@0:3E
V`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?
H`04086YP@0mF3X0?EPj086YPI@0/>3V0@3oool009H0/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21
ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH0502TfZH00`21
ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2Ufj40602Ufj400`21
ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25/gl02P25/gl00`21
ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109D0/>3V0@3oool009L0/>3V00D0PJV106VAM`1Y
TGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04`2TfZH00`21
ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2Ufj40602Ufj400`21
ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl02P25/gl00`21
ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3oool009L0/>3V00<0PJV106VAM`1Y
TGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2T
fZH04`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2U
fj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25
/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3oool009P0/>3V
00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2T
fZH04P2TfZH00`21ZH40Z=jW0:SNY`0F0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0PJV10:GKX@2U
fj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25
/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109L0/>3V0@3oool009T0/>3V
00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2T
fZH04`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0PJV10:GKX@2U
fj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25
/gl02P25/gl00`21ZH40J8mS06R?H`0406R?H`04086YP@0mF3X0?EPj086YPIL0/>3V0@3oool009T0
/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0608VjTP03086YP@2Kd:00Vm2P00h0
Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0
Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA0100
UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109P0
/>3V0@3oool009X0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00d0
Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0
Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100
UlVA00<0PJV108FcO`25/gl02@25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109T0
/>3V0@3oool009/0/>3V0P21ZH4206VAM`03086YP@29^Y80RKZB00H0RKZB00<0PJV109_@X02Kd:00
3P2Kd:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD0
602XgZD00`21ZH40YM^Q0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI40
3`2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS0P21ZH6J0;3PiP40oooo
002L0;3PiP@0PJV12@29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV0180Y=ZV00<0
PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0G0:SNY@03086YP@2Ufj40YM^Q01L0YM^Q00<0
PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0@09O9T@03086YP@25/gl0QK=o00T0QK=o00<0
PJV106R?H`1XSf<00`1XSf<4086YPI/0/>3V0@3oool009`0/>3V00<0PJV106F?M@1USgD00`21ZH47
08VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0E
0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0C
0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS086YP@03
086YP@0306F>I021ZH40PJV109`0/>3V0@3oool009d0/>3V00@0PJV106F?M@1USgD0IHme1@21ZH44
08VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0E
0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D
0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl01`25/gl5086YP@@0IHiT0P21ZH6M
0;3PiP40oooo002N0;3PiP05086YP@1USgD0IHme06F?M@21ZH400`25]i05086YPA00Vm2P00<0PJV1
0:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV1
0:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV1
08FcO`25/gl01025/gl4086YP@0308:bP021ZH40IHiT00D0IHiT0P21ZH6N0;3PiP40oooo002O0;3P
iP05086YP@1USgD0IHme06F?M@21ZH401P25]i06086YP@/0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH0
0`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj40
0`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`21ZH401021ZH44
08:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6O0;3PiP40oooo002P0;3PiP04086YP@1USgD0IHme
086YP@P0QKN@00@0PJV109S>W`2HcYl0V<jO2021ZH4409_@X003086YP@2TfZH0Y=ZV0100Y=ZV00<0
PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q01H0YM^Q00<0
PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0:09O9T@L0PJV12@22/X000`21ZH40IHiT06F>
I00306F>I003086YP@0mFch0PJV109l0/>3V0@3oool00:00/>3V00D0PJV106F?M@1USgD0IHme086Y
P@0808FgT003086YP@2HcYl0V<jO00P0V<jO2@21ZH4>0:CJYP03086YP@2XgZL0Z=jW01@0Z=jW00<0
PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0E0:GKX@03086YP@2PeI/0X=FK01<0X=FK00<0
PJV109O9T@2GbI400P2GbI49086YP@<0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40IHiT06F>
I00306F>I003086YP@0mFch0PJV10:00/>3V0@3oool00:40/>3V00D0PJV106F?M@1USgD0IHme086Y
P@0708FgT003086YP@2HcYl0V<jO00d0V<jO00@0PJV10:;JYP2RfZH0X]ZV2P21ZH450:CJYP03086Y
P@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05@2XgZD00`21ZH40YM^Q0:GKX@0E0:GKX@03086Y
P@2PeI/0X=FK00T0X=FK3`21ZH4<09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@0
0`1USV@00`21ZH40?E/n086YP@2Q0;3PiP40oooo002R0;3PiP05086YP@1USgD0IHme06F?M@21ZH40
1`25]i000`21ZH40V<jO09S>W`0<09S>W`03086YP@2RfZH0X]ZV00/0X]ZV4@21ZH4;0:SNY`03086Y
P@2XgZD0Z=jU01D0Z=jU00<0PJV10:GKX@2Ufj402P2Ufj4G086YP@T0WmJL00<0PJV109C8TP2Db980
3P2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6R0;3PiP40oooo
002S0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0<09S>W`03086Y
P@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP02@2VgjP`086YP@/0YMfS00<0PJV109oFW02OeY`0
4P2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@0
101USV@2086YPJ<0/>3V0@3oool00:@0/>3V00D0PJV106F?M@1USgD0IHme086YP@0708FgT003086Y
P@2HcYl0V<jO00/0V<jO00<0PJV10:;JYP2RfZH0402RfZH00`21ZH40Y]nX0:KOZ00C0:KOZ003086Y
P@2Wh:L0Yn2W01D0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00B09oFW003086Y
P@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40IHiT06F>I00306F>I080PJV1
Y02`h>H10?ooo`00Y02`h>H00`21ZH40IHme06F?M@0206F?M@03086YP@25]i00QKN@00@0QKN@00<0
PJV109S>W`2HcYl0302HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0
PJV10:OPY`2Wh:L05@2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0180WmJL00<0
PJV109C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21
ZH6U0;3PiP40oooo002U0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40V<jO09S>
W`0;09S>W`03086YP@2RfZH0X]ZV0100X]ZV00<0PJV10:KOZ02VgjP04P2VgjP00`21ZH40Yn2W0:OP
Y`0E0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04@2OeY`00`21ZH40U<RB09C8
TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1USV@2086YPJH0/>3V0@3o
ool00:H0/>3V0P21ZH4206F?M@03086YP@25]i00QKN@00D0QKN@00<0PJV109S>W`2HcYl02`2HcYl0
0`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0PJV10:OPY`2Wh:L0502Wh:L0
0`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0140WmJL00<0PJV109C8TP2Db980302Db980
0`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6W0;3PiP40oooo002W0;3P
iPD0PJV11`25]i000`21ZH40V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KO
Z02VgjP04P2VgjP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oF
W02OeY`04@2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000L0P[:000<0PJV106F>
I01USV@00P1USV@2086YPJT0/>3V0@3oool00:T0/>3V00<0PJV105f6KP21ZH400P21ZH4608FgT003
086YP@2HcYl0V<jO00X0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003
086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oFW00@09oFW003
086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I003086YPJX0
/>3V0@3oool00:X0/>3V00<0PJV105f6KP1MQVh01021ZH4308FgT003086YP@2HcYl0V<jO00/0V<jO
00<0PJV10:;JYP2RfZH03P2RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W
00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00@09oFW003086YP@2Db980U<RB00`0U<RB
00<0PJV108:bP022/X002022/X04086YP@0305j7H@21ZH40/>3V0:X0/>3V0@3oool00:/0/>3V0P21
ZH40101MQVh0PJV107^/R@1k[8T5086YP@`0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX
0:KOZ00A0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL
09oFW00?09oFW003086YP@2Db980U<RB00`0U<RB00<0PJV108:bP022/X001P22/X04086YP@80GXMQ
0P21ZH6/0;3PiP40oooo002]0;3PiP04086YP@1MQVh0PJV1086YP@@0Njb91@21ZH4909S>W`03086Y
P@2RfZH0X]ZV00h0X]ZV00<0PJV10:KOZ02VgjP04@2VgjP00`21ZH40Yn2W0:OPY`0C0:OPY`03086Y
P@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`0402OeY`00`21ZH40U<RB09C8TP0<09C8TP03086Y
P@22/X00P[:000H0PJV100<0NZYk086YP@1NQf400P1NQf400`21ZH40/>3V0;3PiP2/0;3PiP40oooo
002^0;3PiP04086YP@1MQVh0GHI^086YP@D0Njb900<0PJV108o5V@2?aIT01`21ZH4209S>W`03086Y
P@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP0402VgjP00`21ZH40Yn2W0:OPY`0C0:OPY`03086Y
P@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`03`2OeY`00`21ZH40U<RB09C8TP0909C8TPL0PJV1
1P1jZW/01@21ZH40GXMQ05j7H@1NQf40PJV10:l0/>3V0@3oool00:l0/>3V0P21ZH400`1MQVh0PJV1
07^/R@0407^/R@03086YP@2?aIT0SlFI00H0SlFI2021ZH4<0:;JYP03086YP@2VgjP0Y]nX0140Y]nX
00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00l0WmJL
00@0PJV109C8TP2Db980U<RB2021ZH4208g2SP03086YP@1jZW/0NZYk00H0NZYk0P21ZH4305j7H@03
086YP@2`h>H0/>3V0:h0/>3V0@3oool00;40/>3V00<0PJV105f6KP21ZH401@1k[8T2086YP@X0SlFI
00@0PJV109[CXP2Jdj80V]>R2@21ZH440:;JYP03086YP@2VgjP0Y]nX0100Y]nX00<0PJV10:OPY`2W
h:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00X0WmJL2@21ZH4908g2SP03
086YP@1jZW/0NZYk00H0NZYk00<0PJV105j7H@1NQf400P1NQf400`21ZH40/>3V0;3PiP2_0;3PiP40
oooo002b0;3PiP03086YP@1MQVh0PJV100H0Njb900<0PJV108o5V@2?aIT0202?aIT00`21ZH40V]>R
09[CXP0909[CXPh0PJV12@2VgjP00`21ZH40Yn2W0:OPY`0B0:OPY`03086YP@2UgJ<0YMfS0180YMfS
00<0PJV109oFW02OeY`00P2OeY`9086YP@<0V=2J00<0PJV108g2SP2=`Xh02`2=`Xh00`21ZH40NZYk
07ZZN`0607ZZN`03086YP@1NQf40GXMQ0080GXMQ00<0PJV10;3PiP2`h>H0/02`h>H10?ooo`00/`2`
h>H3086YP@H0Njb900<0PJV108o5V@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0>09[CXP03086YP@2P
fZD0X=ZU00H0X=ZU>021ZH4<09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01P1j
ZW/01021ZH40GXMQ05j7H@1NQf42086YPK<0/>3V0@3oool00;D0/>3V0`21ZH4507^/R@03086YP@2?
aIT0SlFI00L0SlFI00<0PJV109[CXP2Jdj803@2Jdj800`21ZH40X=ZU0:3JY@0?0:3JY@03086YP@2Q
fj@0XM^T0180XM^T00<0PJV109oHX@2Of:404P2Of:400`21ZH40V=2J09S@VP0=09S@VP03086YP@2=
`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01P1jZW/01@21ZH40GXMQ05j7H@1NQf40PJV10;D0/>3V
0@3oool00;H0/>3V0`21ZH4507^/R@03086YP@2?aIT0SlFI00L0SlFI00<0PJV109[CXP2Jdj803@2J
dj800`21ZH40X=ZU0:3JY@0?0:3JY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109oHX@2Of:404@2O
f:400`21ZH40V=2J09S@VP0=09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01@1j
ZW/2086YP@<0GXMQ00<0PJV10;3PiP2`h>H0]02`h>H10?ooo`00^02`h>H2086YP@D0Njb90P21ZH48
08o5V@03086YP@2Jdj80V]>R00d0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00A
0:7KY003086YP@2Of:40WmRQ0140WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2SP0;
08g2SP03086YP@1jZW/0NZYk00@0NZYk00@0PJV105j7H@1NQf40GXMQ0P21ZH6g0;3PiP40oooo002j
0;3PiP<0PJV1101k[8T00`21ZH40SlFI08o5V@0608o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV1
0:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV1
09S@VP2Hd9X03@2Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0NZYk00@0NZYk1P21ZH6h
0;3PiP40oooo002k0;3PiPH0PJV100<0Njb9086YP@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0<09[C
XP03086YP@2PfZD0X=ZU00d0X=ZU00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40WmRQ09oHX@0@09oH
X@03086YP@2Hd9X0V=2J00`0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk07ZZN`0307ZZ
N`<0PJV100<0DWYI086YP@21ZH40^P2`h>H10?ooo`00_@2`h>H2086YP@80JYUj1021ZH4608o5V@03
086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00?0:7KY003
086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2SP0:08g2SP04
086YP@1jZW/0NZYk07ZZN`@0PJV100<0DWYI086YP@21ZH40_02`h>H10?ooo`00_`2`h>H2086YP@<0
JYUj1@21ZH4308o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03@2PfZD00`21ZH40
XM^T0:7KY00?0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X02`2Hd9X00`21ZH40
SL:>08g2SP0:08g2SPL0PJV100<0DWYI086YP@21ZH40_P2`h>H10?ooo`00`@2`h>H2086YP@<0JYUj
0P21ZH400`1n/X/0PJV1086YP@03086YP@h0V]>R00<0PJV10:3JY@2PfZD0302PfZD00`21ZH40XM^T
0:7KY00?0:7KY003086YP@2Of:40WmRQ00l0WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>
08g2SP0308g2SPP0PJV10P1[VG42086YP@03059jF@21ZH40PJV10<00/>3V0@3oool00<<0/>3V0P21
ZH4306ZINP03086YP@1n/X/0O[:;0080O[:;2@21ZH4609[CXP03086YP@2PfZD0X=ZU00`0X=ZU00<0
PJV10:7KY02Qfj@03`2Qfj@00`21ZH40WmRQ09oHX@0?09oHX@03086YP@2Hd9X0V=2J00P0V=2J2P21
ZH4407faP`80PJV10`1[VG401021ZH40DWYI086YP@21ZH720;3PiP40oooo00350;3PiP80PJV10P1Z
VGX2086YP@@0O[:;0P21ZH4508[2U@l0PJV11`2PfZD00`21ZH40XM^T0:7KY00>0:7KY003086YP@2O
f:40WmRQ00h0WmRQ00@0PJV109S@VP2Hd9X0V=2J2021ZH4208W0S`03086YP@1m/H<0OK6300L0OK63
0P21ZH4306^IL@@0PJV1a02`h>H10?ooo`00aP2`h>H3086YP@80JYUj00<0PJV107jbR`1n/X/00`1n
/X/00`21ZH40R/:E08[2U@0:08[2U@03086YP@2AbYX0TLZJ00@0TLZJ;@21ZH4908W0S`03086YP@1m
/H<0OK6300L0OK6300@0PJV106^IL@1[VG40JiUa1021ZH760;3PiP40oooo00380;3PiP<0PJV100<0
JYUj086YP@21ZH40101n/X/2086YP@/0R/:E00<0PJV1097:VP2AbYX02`2AbYX00`21ZH40TlbJ09?<
VP0=09?<VP03086YP@2AbIL0TLVG00d0TLVG00<0PJV108W0S`29`8l02P29`8l00`21ZH40OK6307fa
P`0607faP`80PJV10P1[VG43086YPLT0/>3V0@3oool00</0/>3V1@21ZH4407jbR`80PJV12P2:`YD0
0`21ZH40TLZJ097:VP0:097:VP03086YP@2Cc9X0TlbJ00d0TlbJ00<0PJV10979U`2AbIL0302AbIL0
0`21ZH40RL2?08W0S`0908W0S`80PJV11`1m/H<2086YP@80JiUa0`21ZH7;0;3PiP40oooo003=0;3P
iPH0PJV10`1n/X/00`21ZH40R/:E08[2U@0808[2U@03086YP@2AbYX0TLZJ00X0TLZJ00<0PJV109?<
VP2Cc9X0302Cc9X00`21ZH40TLVG0979U`0;0979U`03086YP@29`8l0RL2?00T0RL2?00<0PJV107fa
P`1m/H<01@1m/H<6086YPLh0/>3V0@3oool00=00/>3V2@21ZH4908[2U@03086YP@2AbYX0TLZJ00T0
TLZJ00<0PJV109?<VP2Cc9X02`2Cc9X00`21ZH40TLVG0979U`0<0979U`03086YP@29`8l0RL2?00P0
RL2?00<0PJV107faP`1m/H<00`1m/H<6086YPM40/>3V0@3oool00=<0/>3V3021ZH4408[2U@03086Y
P@2AbYX0TLZJ00T0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21ZH40TLVG0979U`0;0979U`03086Y
P@29`8l0RL2?00P0RL2?00<0PJV107faP`21ZH402021ZH7C0;3PiP40oooo003E0;3PiPD0PJV100D0
I99d086YP@21ZH40PJV106nQO@0;086YP@D0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21ZH40TLVG
0979U`0:0979U`03086YP@29`8l0RL2?00<0RL2?2021ZH400`1TTfl0PJV1086YP@03086YPMH0/>3V
0@3oool00=P0/>3V1@21ZH400`1TTW@0PJV1086YP@0506nQO@80PJV10`1fZH<U086YP@80L:5j0P21
ZH4206BCK`D0PJV1f@2`h>H10?ooo`00g02`h>H7086YP@@0Kj5m0P21ZH4807JYP`03086YP@1h[8@0
N:b400P0N:b400<0PJV107JYP@1fZH401`1fZH42086YP@L0L:5j0P21ZH4206BCK`<0PJV1g@2`h>H1
0?ooo`00h@2`h>H7086YP@0306nQO@21ZH40PJV100H0MZV300<0PJV107R/Q01h[8@01`1h[8@00`21
ZH40MZV107JYP@0607JYP@80PJV11`1`XGX6086YPN00/>3V0@3oool00>P0/>3V1`21ZH4307JYP`03
086YP@1h[8@0N:b400H0N:b400<0PJV107JYP@1fZH400P1fZH4?086YPN@0/>3V0@3oool00>l0/>3V
4P21ZH7b0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.606 .779 .568 r
.46017 .46966 m .45976 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.5 .5 m .5 .46978 L .46017 .46966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.5 .53022 m .5 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.5 .46978 m .5 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.5 .5 m .5 .53022 L .53983 .53034 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.53983 .53034 m .54024 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.46139 .43966 m .46017 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.5 .46978 m .5 .43989 L .46139 .43966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.45976 .5 m .46017 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.5 .56011 m .5 .53022 L .46017 .53034 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.5 .43989 m .5 .46978 L .53983 .46966 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.54024 .5 m .53983 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.5 .53022 m .5 .56011 L .53861 .56034 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.53861 .56034 m .53983 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.42114 .46929 m .42033 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.45976 .5 m .46017 .46966 L .42114 .46929 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.46017 .53034 m .45976 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.53983 .46966 m .54024 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.54024 .5 m .53983 .53034 L .57886 .53071 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.57886 .53071 m .57967 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.42358 .43896 m .42114 .46929 L .46017 .46966 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.46017 .46966 m .46139 .43966 L .42358 .43896 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.42033 .5 m .42114 .53071 L .46017 .53034 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.46139 .56034 m .46017 .53034 L .42114 .53071 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.46017 .53034 m .46139 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.53983 .46966 m .53861 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.53861 .43966 m .53983 .46966 L .57886 .46929 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.57967 .5 m .57886 .46929 L .53983 .46966 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.53983 .53034 m .53861 .56034 L .57642 .56104 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.57642 .56104 m .57886 .53071 L .53983 .53034 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.46342 .41036 m .46139 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.5 .43989 m .5 .41069 L .46342 .41036 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.5 .41069 m .5 .43989 L .53861 .43966 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.5 .58931 m .5 .56011 L .46139 .56034 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.5 .56011 m .5 .58931 L .53658 .58964 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.53658 .58964 m .53861 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.42766 .40937 m .42358 .43896 L .46139 .43966 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.46139 .43966 m .46342 .41036 L .42766 .40937 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.53861 .43966 m .53658 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.53658 .41036 m .53861 .43966 L .57642 .43896 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.57886 .46929 m .57642 .43896 L .53861 .43966 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.42114 .53071 m .42358 .56104 L .46139 .56034 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.46342 .58964 m .46139 .56034 L .42358 .56104 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.46139 .56034 m .46342 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.53861 .56034 m .53658 .58964 L .57234 .59063 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.57234 .59063 m .57642 .56104 L .53861 .56034 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.57886 .46929 m .57967 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.57967 .5 m .57886 .53071 L .61622 .53132 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.61622 .53132 m .61745 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.38378 .46868 m .38255 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.42033 .5 m .42114 .46929 L .38378 .46868 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.42114 .53071 m .42033 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.38745 .43778 m .38378 .46868 L .42114 .46929 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.42114 .46929 m .42358 .43896 L .38745 .43778 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.38255 .5 m .38378 .53132 L .42114 .53071 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.42358 .56104 m .42114 .53071 L .38378 .53132 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.57642 .43896 m .57886 .46929 L .61622 .46868 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.61745 .5 m .61622 .46868 L .57886 .46929 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.57886 .53071 m .57642 .56104 L .61255 .56222 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.61255 .56222 m .61622 .53132 L .57886 .53071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45038 .58128 m
.45101 .58073 L
s
.5 Mabswid
.643 .84 .618 r
.46628 .38215 m .46342 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.5 .41069 m .5 .38255 L .46628 .38215 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.5 .38255 m .5 .41069 L .53658 .41036 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.5 .61745 m .5 .58931 L .46342 .58964 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.5 .58931 m .5 .61745 L .53372 .61785 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.53372 .61785 m .53658 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44665 .58287 m
.45038 .58128 L
s
.42281 .56214 m
.42713 .56559 L
s
.42713 .56559 m
.42967 .57066 L
s
.41868 .56043 m
.42281 .56214 L
s
.5 Mabswid
.636 .831 .608 r
.43336 .38095 m .42766 .40937 L .46342 .41036 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.46342 .41036 m .46628 .38215 L .43336 .38095 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.42358 .56104 m .42766 .59063 L .46342 .58964 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.46628 .61785 m .46342 .58964 L .42766 .59063 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.46342 .58964 m .46628 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.53658 .41036 m .53372 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.53372 .38215 m .53658 .41036 L .57234 .40937 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.57642 .43896 m .57234 .40937 L .53658 .41036 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.53658 .58964 m .53372 .61785 L .56664 .61905 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.56664 .61905 m .57234 .59063 L .53658 .58964 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.57234 .40937 m .57642 .43896 L .61255 .43778 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.61622 .46868 m .61255 .43778 L .57642 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.39355 .40772 m .38745 .43778 L .42358 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.42358 .43896 m .42766 .40937 L .39355 .40772 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.38378 .53132 m .38745 .56222 L .42358 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.42766 .59063 m .42358 .56104 L .38745 .56222 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.57642 .56104 m .57234 .59063 L .60645 .59228 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.60645 .59228 m .61255 .56222 L .57642 .56104 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.41623 .58383 m
.41795 .58377 L
s
.5 Mabswid
.625 .818 .594 r
.40208 .37896 m .39355 .40772 L .42766 .40937 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.42766 .40937 m .43336 .38095 L .40208 .37896 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.57234 .40937 m .56664 .38095 L .53372 .38215 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.56664 .38095 m .57234 .40937 L .60645 .40772 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.61255 .43778 m .60645 .40772 L .57234 .40937 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.38745 .56222 m .39355 .59228 L .42766 .59063 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.43336 .61905 m .42766 .59063 L .39355 .59228 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.42766 .59063 m .43336 .61905 L .46628 .61785 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.57234 .59063 m .56664 .61905 L .59792 .62104 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.59792 .62104 m .60645 .59228 L .57234 .59063 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.46995 .35545 m .46628 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.5 .38255 m .5 .35589 L .46995 .35545 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.5 .64411 m .5 .61745 L .46628 .61785 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.5 .35589 m .5 .38255 L .53372 .38215 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.5 .61745 m .5 .64411 L .53005 .64455 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.53005 .64455 m .53372 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.61622 .46868 m .61745 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.61745 .5 m .61622 .53132 L .65095 .53217 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.65095 .53217 m .65259 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.34905 .46783 m .34741 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.38255 .5 m .38378 .46868 L .34905 .46783 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.38378 .53132 m .38255 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.35394 .43614 m .34905 .46783 L .38378 .46868 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.38378 .46868 m .38745 .43778 L .35394 .43614 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.34741 .5 m .34905 .53217 L .38378 .53132 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.38745 .56222 m .38378 .53132 L .34905 .53217 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.61255 .43778 m .61622 .46868 L .65095 .46783 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.65259 .5 m .65095 .46783 L .61622 .46868 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.61622 .53132 m .61255 .56222 L .64606 .56386 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.64606 .56386 m .65095 .53217 L .61622 .53132 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.44068 .35415 m .43336 .38095 L .46628 .38215 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.46628 .38215 m .46995 .35545 L .44068 .35415 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.46995 .64455 m .46628 .61785 L .43336 .61905 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.46628 .61785 m .46995 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.53372 .38215 m .53005 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.53005 .35545 m .53372 .38215 L .56664 .38095 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.53372 .61785 m .53005 .64455 L .55932 .64585 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.55932 .64585 m .56664 .61905 L .53372 .61785 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.60645 .40772 m .61255 .43778 L .64606 .43614 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.65095 .46783 m .64606 .43614 L .61255 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.36206 .40542 m .35394 .43614 L .38745 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.38745 .43778 m .39355 .40772 L .36206 .40542 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.34905 .53217 m .35394 .56386 L .38745 .56222 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.39355 .59228 m .38745 .56222 L .35394 .56386 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.61255 .56222 m .60645 .59228 L .63794 .59458 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.63794 .59458 m .64606 .56386 L .61255 .56222 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.41299 .35198 m .40208 .37896 L .43336 .38095 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.43336 .38095 m .44068 .35415 L .41299 .35198 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.39355 .59228 m .40208 .62104 L .43336 .61905 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.44068 .64585 m .43336 .61905 L .40208 .62104 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.43336 .61905 m .44068 .64585 L .46995 .64455 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.56664 .38095 m .55932 .35415 L .53005 .35545 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.55932 .35415 m .56664 .38095 L .59792 .37896 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.60645 .40772 m .59792 .37896 L .56664 .38095 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.56664 .61905 m .55932 .64585 L .58701 .64802 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.58701 .64802 m .59792 .62104 L .56664 .61905 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.37336 .37619 m .36206 .40542 L .39355 .40772 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.39355 .40772 m .40208 .37896 L .37336 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.59792 .37896 m .60645 .40772 L .63794 .40542 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.64606 .43614 m .63794 .40542 L .60645 .40772 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.35394 .56386 m .36206 .59458 L .39355 .59228 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.40208 .62104 m .39355 .59228 L .36206 .59458 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.60645 .59228 m .59792 .62104 L .62664 .62381 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.62664 .62381 m .63794 .59458 L .60645 .59228 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.47443 .33074 m .46995 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.5 .35589 m .5 .33118 L .47443 .33074 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.5 .33118 m .5 .35589 L .53005 .35545 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.5 .66882 m .5 .64411 L .46995 .64455 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.5 .64411 m .5 .66882 L .52557 .66926 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.52557 .66926 m .53005 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.4496 .32944 m .44068 .35415 L .46995 .35545 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.46995 .35545 m .47443 .33074 L .4496 .32944 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.53005 .35545 m .52557 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.52557 .33074 m .53005 .35545 L .55932 .35415 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.47443 .66926 m .46995 .64455 L .44068 .64585 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.46995 .64455 m .47443 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.53005 .64455 m .52557 .66926 L .5504 .67056 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.5504 .67056 m .55932 .64585 L .53005 .64455 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.31808 .46673 m .31604 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.34741 .5 m .34905 .46783 L .31808 .46673 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.34905 .53217 m .34741 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.65095 .46783 m .65259 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.65259 .5 m .65095 .53217 L .68192 .53327 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.68192 .53327 m .68396 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.32417 .43403 m .31808 .46673 L .34905 .46783 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.34905 .46783 m .35394 .43614 L .32417 .43403 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.31604 .5 m .31808 .53327 L .34905 .53217 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.35394 .56386 m .34905 .53217 L .31808 .53327 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.64606 .43614 m .65095 .46783 L .68192 .46673 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.68396 .5 m .68192 .46673 L .65095 .46783 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.65095 .53217 m .64606 .56386 L .67583 .56597 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.67583 .56597 m .68192 .53327 L .65095 .53217 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.38776 .34897 m .37336 .37619 L .40208 .37896 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.40208 .37896 m .41299 .35198 L .38776 .34897 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.36206 .59458 m .37336 .62381 L .40208 .62104 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.41299 .64802 m .40208 .62104 L .37336 .62381 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.40208 .62104 m .41299 .64802 L .44068 .64585 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.59792 .37896 m .58701 .35198 L .55932 .35415 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.58701 .35198 m .59792 .37896 L .62664 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.63794 .40542 m .62664 .37619 L .59792 .37896 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.59792 .62104 m .58701 .64802 L .61224 .65103 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.61224 .65103 m .62664 .62381 L .59792 .62104 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.55932 .35415 m .5504 .32944 L .52557 .33074 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.5504 .32944 m .55932 .35415 L .58701 .35198 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.42624 .32729 m .41299 .35198 L .44068 .35415 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.44068 .35415 m .4496 .32944 L .42624 .32729 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.55932 .64585 m .5504 .67056 L .57376 .67271 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.57376 .67271 m .58701 .64802 L .55932 .64585 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.4496 .67056 m .44068 .64585 L .41299 .64802 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.44068 .64585 m .4496 .67056 L .47443 .66926 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.33425 .40248 m .32417 .43403 L .35394 .43614 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.35394 .43614 m .36206 .40542 L .33425 .40248 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.31808 .53327 m .32417 .56597 L .35394 .56386 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.36206 .59458 m .35394 .56386 L .32417 .56597 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.63794 .40542 m .64606 .43614 L .67583 .43403 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.68192 .46673 m .67583 .43403 L .64606 .43614 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.64606 .56386 m .63794 .59458 L .66575 .59752 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.66575 .59752 m .67583 .56597 L .64606 .56386 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.34822 .37266 m .33425 .40248 L .36206 .40542 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.36206 .40542 m .37336 .37619 L .34822 .37266 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.32417 .56597 m .33425 .59752 L .36206 .59458 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.37336 .62381 m .36206 .59458 L .33425 .59752 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.62664 .37619 m .63794 .40542 L .66575 .40248 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.67583 .43403 m .66575 .40248 L .63794 .40542 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.63794 .59458 m .62664 .62381 L .65178 .62734 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.65178 .62734 m .66575 .59752 L .63794 .59458 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.47972 .30855 m .47443 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.5 .33118 m .5 .30894 L .47972 .30855 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.5 .30894 m .5 .33118 L .52557 .33074 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.5 .69106 m .5 .66882 L .47443 .66926 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.5 .66882 m .5 .69106 L .52028 .69145 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.52028 .69145 m .52557 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.46008 .30739 m .4496 .32944 L .47443 .33074 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.47443 .33074 m .47972 .30855 L .46008 .30739 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.52557 .33074 m .52028 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.52028 .30855 m .52557 .33074 L .5504 .32944 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.47972 .69145 m .47443 .66926 L .4496 .67056 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.47443 .66926 m .47972 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.52557 .66926 m .52028 .69145 L .53992 .69261 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.53992 .69261 m .5504 .67056 L .52557 .66926 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.40515 .32433 m .38776 .34897 L .41299 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.41299 .35198 m .42624 .32729 L .40515 .32433 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.37336 .62381 m .38776 .65103 L .41299 .64802 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.42624 .67271 m .41299 .64802 L .38776 .65103 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.41299 .64802 m .42624 .67271 L .4496 .67056 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.58701 .35198 m .57376 .32729 L .5504 .32944 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.57376 .32729 m .58701 .35198 L .61224 .34897 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.62664 .37619 m .61224 .34897 L .58701 .35198 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.58701 .64802 m .57376 .67271 L .59485 .67567 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.59485 .67567 m .61224 .65103 L .58701 .64802 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.36592 .34517 m .34822 .37266 L .37336 .37619 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.37336 .37619 m .38776 .34897 L .36592 .34517 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.33425 .59752 m .34822 .62734 L .37336 .62381 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.38776 .65103 m .37336 .62381 L .34822 .62734 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.61224 .34897 m .62664 .37619 L .65178 .37266 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.66575 .40248 m .65178 .37266 L .62664 .37619 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.62664 .62381 m .61224 .65103 L .63408 .65483 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.63408 .65483 m .65178 .62734 L .62664 .62381 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.44174 .30547 m .42624 .32729 L .4496 .32944 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.4496 .32944 m .46008 .30739 L .44174 .30547 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.46008 .69261 m .4496 .67056 L .42624 .67271 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.4496 .67056 m .46008 .69261 L .47972 .69145 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.5504 .32944 m .53992 .30739 L .52028 .30855 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.53992 .30739 m .5504 .32944 L .57376 .32729 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.5504 .67056 m .53992 .69261 L .55826 .69453 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.55826 .69453 m .57376 .67271 L .5504 .67056 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.29221 .4654 m .28979 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.31604 .5 m .31808 .46673 L .29221 .4654 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.31808 .53327 m .31604 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.68192 .46673 m .68396 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.68396 .5 m .68192 .53327 L .70779 .5346 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.70779 .5346 m .71021 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.29943 .43148 m .29221 .4654 L .31808 .46673 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.31808 .46673 m .32417 .43403 L .29943 .43148 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.28979 .5 m .29221 .5346 L .31808 .53327 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.32417 .56597 m .31808 .53327 L .29221 .5346 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.67583 .43403 m .68192 .46673 L .70779 .4654 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.71021 .5 m .70779 .4654 L .68192 .46673 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.68192 .53327 m .67583 .56597 L .70057 .56852 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.70057 .56852 m .70779 .5346 L .68192 .53327 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.31135 .39893 m .29943 .43148 L .32417 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.32417 .43403 m .33425 .40248 L .31135 .39893 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.29221 .5346 m .29943 .56852 L .32417 .56597 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.33425 .59752 m .32417 .56597 L .29943 .56852 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.57376 .32729 m .55826 .30547 L .53992 .30739 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.55826 .30547 m .57376 .32729 L .59485 .32433 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.61224 .34897 m .59485 .32433 L .57376 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42535 .30284 m .40515 .32433 L .42624 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42624 .32729 m .44174 .30547 L .42535 .30284 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57376 .67271 m .55826 .69453 L .57465 .69716 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57465 .69716 m .59485 .67567 L .57376 .67271 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.38776 .65103 m .40515 .67567 L .42624 .67271 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.44174 .69453 m .42624 .67271 L .40515 .67567 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.42624 .67271 m .44174 .69453 L .46008 .69261 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.66575 .40248 m .67583 .43403 L .70057 .43148 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.70779 .4654 m .70057 .43148 L .67583 .43403 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.67583 .56597 m .66575 .59752 L .68865 .60107 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.68865 .60107 m .70057 .56852 L .67583 .56597 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38713 .32061 m .36592 .34517 L .38776 .34897 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38776 .34897 m .40515 .32433 L .38713 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.59485 .32433 m .61224 .34897 L .63408 .34517 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.65178 .37266 m .63408 .34517 L .61224 .34897 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.34822 .62734 m .36592 .65483 L .38776 .65103 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.40515 .67567 m .38776 .65103 L .36592 .65483 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61224 .65103 m .59485 .67567 L .61287 .67939 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61287 .67939 m .63408 .65483 L .61224 .65103 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.48578 .28949 m .47972 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.5 .30894 m .5 .28979 L .48578 .28949 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.5 .28979 m .5 .30894 L .52028 .30855 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.5 .71021 m .5 .69106 L .47972 .69145 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.5 .69106 m .5 .71021 L .51422 .71051 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51422 .71051 m .52028 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.32778 .36843 m .31135 .39893 L .33425 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.33425 .40248 m .34822 .37266 L .32778 .36843 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.29943 .56852 m .31135 .60107 L .33425 .59752 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.34822 .62734 m .33425 .59752 L .31135 .60107 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.65178 .37266 m .66575 .40248 L .68865 .39893 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.70057 .43148 m .68865 .39893 L .66575 .40248 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.66575 .59752 m .65178 .62734 L .67222 .63157 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.67222 .63157 m .68865 .60107 L .66575 .59752 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47206 .28859 m .46008 .30739 L .47972 .30855 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47972 .30855 m .48578 .28949 L .47206 .28859 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.52028 .30855 m .51422 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.51422 .28949 m .52028 .30855 L .53992 .30739 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.48578 .71051 m .47972 .69145 L .46008 .69261 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47972 .69145 m .48578 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52028 .69145 m .51422 .71051 L .52794 .71141 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52794 .71141 m .53992 .69261 L .52028 .69145 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.53992 .30739 m .52794 .28859 L .51422 .28949 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.52794 .28859 m .53992 .30739 L .55826 .30547 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.45934 .28712 m .44174 .30547 L .46008 .30739 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.46008 .30739 m .47206 .28859 L .45934 .28712 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.53992 .69261 m .52794 .71141 L .54066 .71288 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.54066 .71288 m .55826 .69453 L .53992 .69261 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.47206 .71141 m .46008 .69261 L .44174 .69453 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.46008 .69261 m .47206 .71141 L .48578 .71051 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34844 .34065 m .32778 .36843 L .34822 .37266 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34822 .37266 m .36592 .34517 L .34844 .34065 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.31135 .60107 m .32778 .63157 L .34822 .62734 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.36592 .65483 m .34822 .62734 L .32778 .63157 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.63408 .34517 m .65178 .37266 L .67222 .36843 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.68865 .39893 m .67222 .36843 L .65178 .37266 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65178 .62734 m .63408 .65483 L .65156 .65935 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65156 .65935 m .67222 .63157 L .65178 .62734 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.41156 .29957 m .38713 .32061 L .40515 .32433 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.40515 .32433 m .42535 .30284 L .41156 .29957 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.59485 .32433 m .57465 .30284 L .55826 .30547 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.57465 .30284 m .59485 .32433 L .61287 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.63408 .34517 m .61287 .32061 L .59485 .32433 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.36592 .65483 m .38713 .67939 L .40515 .67567 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.42535 .69716 m .40515 .67567 L .38713 .67939 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.40515 .67567 m .42535 .69716 L .44174 .69453 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.59485 .67567 m .57465 .69716 L .58844 .70043 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.58844 .70043 m .61287 .67939 L .59485 .67567 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.55826 .30547 m .54066 .28712 L .52794 .28859 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.54066 .28712 m .55826 .30547 L .57465 .30284 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44812 .28512 m .42535 .30284 L .44174 .30547 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44174 .30547 m .45934 .28712 L .44812 .28512 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.45934 .71288 m .44174 .69453 L .42535 .69716 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.44174 .69453 m .45934 .71288 L .47206 .71141 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55826 .69453 m .54066 .71288 L .55188 .71488 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55188 .71488 m .57465 .69716 L .55826 .69453 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.37301 .31621 m .34844 .34065 L .36592 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.36592 .34517 m .38713 .32061 L .37301 .31621 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.32778 .63157 m .34844 .65935 L .36592 .65483 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.38713 .67939 m .36592 .65483 L .34844 .65935 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.61287 .32061 m .63408 .34517 L .65156 .34065 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.67222 .36843 m .65156 .34065 L .63408 .34517 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.63408 .65483 m .61287 .67939 L .62699 .68379 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.62699 .68379 m .65156 .65935 L .63408 .65483 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29905 .56965 m
.30032 .57096 L
s
.30656 .59152 m
.3071 .58945 L
s
.5 Mabswid
.394 .508 .339 r
.27297 .46384 m .2702 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.28979 .5 m .29221 .4654 L .27297 .46384 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.29221 .5346 m .28979 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.49256 .27421 m .48578 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.5 .28979 m .5 .27438 L .49256 .27421 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.5 .27438 m .5 .28979 L .51422 .28949 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.5 .72562 m .5 .71021 L .48578 .71051 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.5 .71021 m .5 .72562 L .50744 .72579 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.50744 .72579 m .51422 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.70779 .4654 m .71021 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.71021 .5 m .70779 .5346 L .72703 .53616 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.72703 .53616 m .7298 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.2812 .42852 m .27297 .46384 L .29221 .4654 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.29221 .4654 m .29943 .43148 L .2812 .42852 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.2702 .5 m .27297 .53616 L .29221 .5346 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.29943 .56852 m .29221 .5346 L .27297 .53616 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.70057 .43148 m .70779 .4654 L .72703 .46384 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.7298 .5 m .72703 .46384 L .70779 .4654 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.70779 .5346 m .70057 .56852 L .7188 .57148 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.7188 .57148 m .72703 .53616 L .70779 .5346 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.43884 .28266 m .41156 .29957 L .42535 .30284 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.42535 .30284 m .44812 .28512 L .43884 .28266 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.57465 .30284 m .55188 .28512 L .54066 .28712 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.55188 .28512 m .57465 .30284 L .58844 .29957 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.61287 .32061 m .58844 .29957 L .57465 .30284 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.38713 .67939 m .41156 .70043 L .42535 .69716 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.44812 .71488 m .42535 .69716 L .41156 .70043 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.42535 .69716 m .44812 .71488 L .45934 .71288 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.57465 .69716 m .55188 .71488 L .56116 .71734 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.56116 .71734 m .58844 .70043 L .57465 .69716 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48542 .27371 m .47206 .28859 L .48578 .28949 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48578 .28949 m .49256 .27421 L .48542 .27371 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51422 .28949 m .50744 .27421 L .5 .27438 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.50744 .27421 m .51422 .28949 L .52794 .28859 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.49256 .72579 m .48578 .71051 L .47206 .71141 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.48578 .71051 m .49256 .72579 L .5 .72562 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51422 .71051 m .50744 .72579 L .51458 .72629 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51458 .72629 m .52794 .71141 L .51422 .71051 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29473 .39483 m .2812 .42852 L .29943 .43148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29943 .43148 m .31135 .39893 L .29473 .39483 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.27297 .53616 m .2812 .57148 L .29943 .56852 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29764 .56881 m
.29905 .56965 L
s
.5 Mabswid
.334 .406 .275 r
.31135 .60107 m .29943 .56852 L .2812 .57148 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.40102 .29574 m .37301 .31621 L .38713 .32061 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.38713 .32061 m .41156 .29957 L .40102 .29574 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.34844 .65935 m .37301 .68379 L .38713 .67939 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.41156 .70043 m .38713 .67939 L .37301 .68379 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.58844 .29957 m .61287 .32061 L .62699 .31621 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.65156 .34065 m .62699 .31621 L .61287 .32061 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.61287 .67939 m .58844 .70043 L .59898 .70426 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.59898 .70426 m .62699 .68379 L .61287 .67939 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.68865 .39893 m .70057 .43148 L .7188 .42852 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.72703 .46384 m .7188 .42852 L .70057 .43148 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70057 .56852 m .68865 .60107 L .70527 .60517 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70527 .60517 m .7188 .57148 L .70057 .56852 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47886 .27289 m .45934 .28712 L .47206 .28859 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47206 .28859 m .48542 .27371 L .47886 .27289 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.52794 .28859 m .51458 .27371 L .50744 .27421 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.51458 .27371 m .52794 .28859 L .54066 .28712 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52794 .71141 m .51458 .72629 L .52114 .72711 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52114 .72711 m .54066 .71288 L .52794 .71141 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.48542 .72629 m .47206 .71141 L .45934 .71288 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.47206 .71141 m .48542 .72629 L .49256 .72579 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31326 .36358 m .29473 .39483 L .31135 .39893 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31135 .39893 m .32778 .36843 L .31326 .36358 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.2812 .57148 m .29473 .60517 L .31135 .60107 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.32778 .63157 m .31135 .60107 L .29473 .60517 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68865 .60107 m .67222 .63157 L .68674 .63642 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68674 .63642 m .70527 .60517 L .68865 .60107 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.67222 .36843 m .68865 .39893 L .70527 .39483 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.7188 .42852 m .70527 .39483 L .68865 .39893 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.3364 .3355 m .31326 .36358 L .32778 .36843 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.32778 .36843 m .34844 .34065 L .3364 .3355 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.29473 .60517 m .31326 .63642 L .32778 .63157 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.34844 .65935 m .32778 .63157 L .31326 .63642 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.54066 .28712 m .52114 .27289 L .51458 .27371 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.52114 .27289 m .54066 .28712 L .55188 .28512 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.47314 .27179 m .44812 .28512 L .45934 .28712 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.45934 .28712 m .47886 .27289 L .47314 .27179 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.47886 .72711 m .45934 .71288 L .44812 .71488 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.45934 .71288 m .47886 .72711 L .48542 .72629 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.54066 .71288 m .52114 .72711 L .52686 .72821 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.52686 .72821 m .55188 .71488 L .54066 .71288 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.65156 .34065 m .67222 .36843 L .68674 .36358 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.70527 .39483 m .68674 .36358 L .67222 .36843 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.67222 .63157 m .65156 .65935 L .6636 .6645 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.6636 .6645 m .68674 .63642 L .67222 .63157 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.41156 .70043 m .43884 .71734 L .44812 .71488 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.43196 .2798 m .40102 .29574 L .41156 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.41156 .29957 m .43884 .28266 L .43196 .2798 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.37301 .68379 m .40102 .70426 L .41156 .70043 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.43884 .71734 m .41156 .70043 L .40102 .70426 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.58844 .29957 m .56116 .28266 L .55188 .28512 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.56116 .28266 m .58844 .29957 L .59898 .29574 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.62699 .31621 m .59898 .29574 L .58844 .29957 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.58844 .70043 m .56116 .71734 L .56804 .7202 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.56804 .7202 m .59898 .70426 L .58844 .70043 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.36362 .31126 m .3364 .3355 L .34844 .34065 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.34844 .34065 m .37301 .31621 L .36362 .31126 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.31326 .63642 m .3364 .6645 L .34844 .65935 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.37301 .68379 m .34844 .65935 L .3364 .6645 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.62699 .31621 m .65156 .34065 L .6636 .3355 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.68674 .36358 m .6636 .3355 L .65156 .34065 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.65156 .65935 m .62699 .68379 L .63638 .68874 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.63638 .68874 m .6636 .6645 L .65156 .65935 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.46851 .27044 m .43884 .28266 L .44812 .28512 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.44812 .28512 m .47314 .27179 L .46851 .27044 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.55188 .28512 m .52686 .27179 L .52114 .27289 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.52686 .27179 m .55188 .28512 L .56116 .28266 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.47314 .72821 m .44812 .71488 L .43884 .71734 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.44812 .71488 m .47314 .72821 L .47886 .72711 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.55188 .71488 m .52686 .72821 L .53149 .72956 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.53149 .72956 m .56116 .71734 L .55188 .71488 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.39434 .29148 m .36362 .31126 L .37301 .31621 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.37301 .31621 m .40102 .29574 L .39434 .29148 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.3364 .6645 m .36362 .68874 L .37301 .68379 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.40102 .70426 m .37301 .68379 L .36362 .68874 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.59898 .29574 m .62699 .31621 L .63638 .31126 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.6636 .3355 m .63638 .31126 L .62699 .31621 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.62699 .68379 m .59898 .70426 L .60566 .70852 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.60566 .70852 m .63638 .68874 L .62699 .68379 L p F P
.505 .664 .505 r
s
.555 .774 .586 r
.5 .27438 m .5 .26345 L .49256 .27421 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50744 .27421 m .5 .26345 L .5 .27438 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .5 .72562 L .49256 .72579 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50744 .72579 L .5 .72562 L closepath p F P
.505 .664 .505 r
s
.233 .243 .182 r
.43884 .71734 m .46851 .72956 L .47314 .72821 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.46519 .2689 m .43196 .2798 L .43884 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.43884 .28266 m .46851 .27044 L .46519 .2689 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.40102 .70426 m .43196 .7202 L .43884 .71734 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.46851 .72956 m .43884 .71734 L .43196 .7202 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.56116 .28266 m .53149 .27044 L .52686 .27179 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.53149 .27044 m .56116 .28266 L .56804 .2798 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.59898 .29574 m .56804 .2798 L .56116 .28266 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.56116 .71734 m .53149 .72956 L .53481 .7311 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.53481 .7311 m .56804 .7202 L .56116 .71734 L p F P
.505 .664 .505 r
s
.553 .771 .583 r
.49256 .27421 m .5 .26345 L .48542 .27371 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51458 .27371 m .5 .26345 L .50744 .27421 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .49256 .72579 L .48542 .72629 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51458 .72629 L .50744 .72579 L closepath p F P
.505 .664 .505 r
s
.549 .766 .579 r
.48542 .27371 m .5 .26345 L .47886 .27289 L closepath p F P
.505 .664 .505 r
s
.552 .771 .585 r
.52114 .27289 m .5 .26345 L .51458 .27371 L closepath p F P
.505 .664 .505 r
s
.197 .204 .155 r
.5 .73655 m .52114 .72711 L .51458 .72629 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .48542 .72629 L .47886 .72711 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28103 .5725 m
.28218 .57392 L
s
.5 Mabswid
.524 .728 .536 r
.42783 .27666 m .39434 .29148 L .40102 .29574 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.40102 .29574 m .43196 .2798 L .42783 .27666 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.36362 .68874 m .39434 .70852 L .40102 .70426 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.43196 .7202 m .40102 .70426 L .39434 .70852 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.56804 .2798 m .59898 .29574 L .60566 .29148 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.63638 .31126 m .60566 .29148 L .59898 .29574 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.59898 .70426 m .56804 .7202 L .57217 .72334 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.57217 .72334 m .60566 .70852 L .59898 .70426 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28954 .59511 m
.28961 .59242 L
s
.5 Mabswid
.543 .759 .573 r
.47886 .27289 m .5 .26345 L .47314 .27179 L closepath p F P
.505 .664 .505 r
s
.548 .765 .582 r
.52686 .27179 m .5 .26345 L .52114 .27289 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .52686 .72821 L .52114 .72711 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .47886 .72711 L .47314 .72821 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71696 .4198 m
.71819 .42147 L
s
.71689 .41785 m
.71696 .4198 L
s
.72112 .43042 m
.72715 .45461 L
s
.5 Mabswid
.535 .75 .567 r
.47314 .27179 m .5 .26345 L .46851 .27044 L closepath p F P
.505 .664 .505 r
s
.541 .758 .578 r
.53149 .27044 m .5 .26345 L .52686 .27179 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .47314 .72821 L .46851 .72956 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .53149 .72956 L .52686 .72821 L closepath p F P
.505 .664 .505 r
s
.279 .362 .238 r
.26206 .46211 m .25902 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.2702 .5 m .27297 .46384 L .26206 .46211 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.27297 .53616 m .2702 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.72703 .46384 m .7298 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.7298 .5 m .72703 .53616 L .73794 .53789 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.73794 .53789 m .74098 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27109 .42521 m .26206 .46211 L .27297 .46384 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27297 .46384 m .2812 .42852 L .27109 .42521 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.25902 .5 m .26206 .53789 L .27297 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.2812 .57148 m .27297 .53616 L .26206 .53789 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27878 .57074 m
.28103 .5725 L
s
.5 Mabswid
.379 .505 .416 r
.7188 .42852 m .72703 .46384 L .73794 .46211 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.74098 .5 m .73794 .46211 L .72703 .46384 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72703 .53616 m .7188 .57148 L .72891 .57479 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72891 .57479 m .73794 .53789 L .72703 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.26206 .53789 m .27109 .57479 L .2812 .57148 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.29473 .60517 m .2812 .57148 L .27109 .57479 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.28585 .39028 m .27109 .42521 L .2812 .42852 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.2812 .42852 m .29473 .39483 L .28585 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.70527 .39483 m .7188 .42852 L .72891 .42521 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.73794 .46211 m .72891 .42521 L .7188 .42852 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.7188 .57148 m .70527 .60517 L .71415 .60972 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.71415 .60972 m .72891 .57479 L .7188 .57148 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.46333 .26722 m .42783 .27666 L .43196 .2798 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.43196 .2798 m .46519 .2689 L .46333 .26722 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.39434 .70852 m .42783 .72334 L .43196 .7202 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.46519 .7311 m .43196 .7202 L .42783 .72334 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.43196 .7202 m .46519 .7311 L .46851 .72956 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.56804 .2798 m .53481 .2689 L .53149 .27044 L p F P
.505 .664 .505 r
s
.544 .761 .586 r
.53481 .2689 m .56804 .2798 L .57217 .27666 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.60566 .29148 m .57217 .27666 L .56804 .2798 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.56804 .7202 m .53481 .7311 L .53667 .73278 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.53667 .73278 m .57217 .72334 L .56804 .7202 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.30594 .35823 m .28585 .39028 L .29473 .39483 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.29473 .39483 m .31326 .36358 L .30594 .35823 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.27109 .57479 m .28585 .60972 L .29473 .60517 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.31326 .63642 m .29473 .60517 L .28585 .60972 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.70527 .60517 m .68674 .63642 L .69406 .64177 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.69406 .64177 m .71415 .60972 L .70527 .60517 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.68674 .36358 m .70527 .39483 L .71415 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.72891 .42521 m .71415 .39028 L .70527 .39483 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.33081 .32987 m .30594 .35823 L .31326 .36358 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.31326 .36358 m .3364 .3355 L .33081 .32987 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.28585 .60972 m .30594 .64177 L .31326 .63642 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.3364 .6645 m .31326 .63642 L .30594 .64177 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.6636 .3355 m .68674 .36358 L .69406 .35823 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.71415 .39028 m .69406 .35823 L .68674 .36358 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.68674 .63642 m .6636 .6645 L .66919 .67013 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.66919 .67013 m .69406 .64177 L .68674 .63642 L p F P
.505 .664 .505 r
s
.527 .74 .559 r
.46851 .27044 m .5 .26345 L .46519 .2689 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .46851 .72956 L .46519 .7311 L closepath p F P
.505 .664 .505 r
s
.533 .749 .571 r
.53481 .2689 m .5 .26345 L .53149 .27044 L closepath p F P
.505 .664 .505 r
s
.183 .19 .145 r
.5 .73655 m .53481 .7311 L .53149 .72956 L closepath p F P
.505 .664 .505 r
s
.425 .593 .423 r
.35976 .30591 m .33081 .32987 L .3364 .3355 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.3364 .3355 m .36362 .31126 L .35976 .30591 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.30594 .64177 m .33081 .67013 L .3364 .6645 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.36362 .68874 m .3364 .6645 L .33081 .67013 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.63638 .31126 m .6636 .3355 L .66919 .32987 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.69406 .35823 m .66919 .32987 L .6636 .3355 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.6636 .6645 m .63638 .68874 L .64024 .69409 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.64024 .69409 m .66919 .67013 L .6636 .6645 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.39203 .28693 m .35976 .30591 L .36362 .31126 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.36362 .31126 m .39434 .29148 L .39203 .28693 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.33081 .67013 m .35976 .69409 L .36362 .68874 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.39434 .70852 m .36362 .68874 L .35976 .69409 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.60566 .29148 m .63638 .31126 L .64024 .30591 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.66919 .32987 m .64024 .30591 L .63638 .31126 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.63638 .68874 m .60566 .70852 L .60797 .71307 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.60797 .71307 m .64024 .69409 L .63638 .68874 L p F P
.505 .664 .505 r
s
.517 .728 .55 r
.46519 .2689 m .5 .26345 L .46333 .26722 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42783 .72334 m .46333 .73278 L .46519 .7311 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .46519 .7311 L .46333 .73278 L closepath p F P
.505 .664 .505 r
s
.524 .738 .564 r
.53667 .26722 m .5 .26345 L .53481 .2689 L closepath p F P
.505 .664 .505 r
s
.544 .761 .586 r
.57217 .27666 m .53667 .26722 L .53481 .2689 L p F P
.505 .664 .505 r
s
.176 .185 .14 r
.5 .73655 m .53667 .73278 L .53481 .7311 L closepath p F P
.505 .664 .505 r
s
.475 .67 .494 r
.42676 .27336 m .39203 .28693 L .39434 .29148 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.39434 .29148 m .42783 .27666 L .42676 .27336 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.35976 .69409 m .39203 .71307 L .39434 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.42783 .72334 m .39434 .70852 L .39203 .71307 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.57217 .27666 m .60566 .29148 L .60797 .28693 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.64024 .30591 m .60797 .28693 L .60566 .29148 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.60566 .70852 m .57217 .72334 L .57324 .72664 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.57324 .72664 m .60797 .71307 L .60566 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.39203 .71307 m .42676 .72664 L .42783 .72334 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.46333 .73278 m .42783 .72334 L .42676 .72664 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.46306 .26549 m .42676 .27336 L .42783 .27666 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.42783 .27666 m .46333 .26722 L .46306 .26549 L p F P
.505 .664 .505 r
s
.515 .726 .562 r
.53667 .26722 m .57217 .27666 L .57324 .27336 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.60797 .28693 m .57324 .27336 L .57217 .27666 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.57217 .72334 m .53667 .73278 L .53694 .73451 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.53694 .73451 m .57324 .72664 L .57217 .72334 L p F P
.505 .664 .505 r
s
.506 .715 .541 r
.46333 .26722 m .5 .26345 L .46306 .26549 L closepath p F P
.505 .664 .505 r
s
.177 .185 .14 r
.42676 .72664 m .46306 .73451 L .46333 .73278 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .46333 .73278 L .46306 .73451 L closepath p F P
.505 .664 .505 r
s
.514 .725 .555 r
.53694 .26549 m .5 .26345 L .53667 .26722 L closepath p F P
.505 .664 .505 r
s
.515 .726 .562 r
.57324 .27336 m .53694 .26549 L .53667 .26722 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .53694 .73451 L .53667 .73278 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .53558 .73624 L .53694 .73451 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .53263 .73787 L .53558 .73624 L closepath p F P
.505 .664 .505 r
s
.149 .16 .121 r
.5 .73655 m .52817 .73933 L .53263 .73787 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .73655 m .5224 .74056 L .52817 .73933 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .51556 .74148 L .5224 .74056 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50797 .74206 L .51556 .74148 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .5 .74225 L .50797 .74206 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49203 .74206 L .5 .74225 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .48444 .74148 L .49203 .74206 L closepath p F P
.505 .664 .505 r
s
.141 .152 .116 r
.5 .73655 m .4776 .74056 L .48444 .74148 L closepath p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .73655 m .47183 .73933 L .4776 .74056 L closepath p F P
.505 .664 .505 r
s
.152 .162 .123 r
.5 .73655 m .46737 .73787 L .47183 .73933 L closepath p F P
.505 .664 .505 r
s
.159 .168 .128 r
.5 .73655 m .46442 .73624 L .46737 .73787 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .46306 .73451 L .46442 .73624 L closepath p F P
.505 .664 .505 r
s
.503 .712 .546 r
.53558 .26376 m .5 .26345 L .53694 .26549 L closepath p F P
.505 .664 .505 r
s
.492 .698 .536 r
.53263 .26213 m .5 .26345 L .53558 .26376 L closepath p F P
.505 .664 .505 r
s
.496 .702 .532 r
.46306 .26549 m .5 .26345 L .46442 .26376 L closepath p F P
.505 .664 .505 r
s
.481 .685 .526 r
.52817 .26067 m .5 .26345 L .53263 .26213 L closepath p F P
.505 .664 .505 r
s
.485 .689 .523 r
.46442 .26376 m .5 .26345 L .46737 .26213 L closepath p F P
.505 .664 .505 r
s
.471 .673 .518 r
.5224 .25944 m .5 .26345 L .52817 .26067 L closepath p F P
.505 .664 .505 r
s
.475 .677 .515 r
.46737 .26213 m .5 .26345 L .47183 .26067 L closepath p F P
.505 .664 .505 r
s
.463 .663 .51 r
.51556 .25852 m .5 .26345 L .5224 .25944 L closepath p F P
.505 .664 .505 r
s
.466 .667 .508 r
.47183 .26067 m .5 .26345 L .4776 .25944 L closepath p F P
.505 .664 .505 r
s
.457 .656 .504 r
.50797 .25794 m .5 .26345 L .51556 .25852 L closepath p F P
.505 .664 .505 r
s
.459 .658 .503 r
.4776 .25944 m .5 .26345 L .48444 .25852 L closepath p F P
.505 .664 .505 r
s
.453 .652 .5 r
.5 .25775 m .5 .26345 L .50797 .25794 L closepath p F P
.505 .664 .505 r
s
.455 .653 .499 r
.48444 .25852 m .5 .26345 L .49203 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49203 .25794 m .5 .26345 L .5 .25775 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72531 .41668 m
.7258 .41707 L
s
.73251 .43991 m
.73281 .439 L
s
.5 Mabswid
.155 .165 .125 r
.42894 .72997 m .46442 .73624 L .46306 .73451 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.46306 .73451 m .42676 .72664 L .42894 .72997 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.42676 .27336 m .46306 .26549 L .46442 .26376 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.57324 .72664 m .53694 .73451 L .53558 .73624 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.53694 .26549 m .57324 .27336 L .57106 .27003 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.57106 .27003 m .53558 .26376 L .53694 .26549 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73042 .43138 m
.73076 .43179 L
s
.5 Mabswid
.144 .154 .117 r
.3945 .71771 m .42894 .72997 L .42676 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.42676 .72664 m .39203 .71307 L .3945 .71771 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.46442 .26376 m .42894 .27003 L .42676 .27336 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.39203 .28693 m .42676 .27336 L .42894 .27003 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.57324 .27336 m .60797 .28693 L .6055 .28229 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.6055 .28229 m .57106 .27003 L .57324 .27336 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60797 .71307 m .57324 .72664 L .57106 .72997 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.53558 .73624 m .57106 .72997 L .57324 .72664 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7258 .41707 m
.72749 .42064 L
s
.73076 .43179 m
.73217 .43529 L
s
.73217 .43529 m
.73281 .439 L
s
0 0 0 r
.27468 .58558 m
.27622 .58947 L
s
.27622 .58947 m
.2782 .59529 L
s
.27201 .57971 m
.27468 .58558 L
s
.5 Mabswid
.415 .597 .441 r
.42894 .27003 m .3945 .28229 L .39203 .28693 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.35976 .30591 m .39203 .28693 L .3945 .28229 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.36207 .69962 m .3945 .71771 L .39203 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.39203 .71307 m .35976 .69409 L .36207 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.64024 .69409 m .60797 .71307 L .6055 .71771 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.57106 .72997 m .6055 .71771 L .60797 .71307 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.60797 .28693 m .64024 .30591 L .63793 .30038 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.63793 .30038 m .6055 .28229 L .60797 .28693 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.43439 .73316 m .46737 .73787 L .46442 .73624 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.46442 .73624 m .42894 .72997 L .43439 .73316 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.42894 .27003 m .46442 .26376 L .46737 .26213 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.57106 .72997 m .53558 .73624 L .53263 .73787 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.53558 .26376 m .57106 .27003 L .56561 .26684 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.56561 .26684 m .53263 .26213 L .53558 .26376 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2782 .59529 m
.27912 .59934 L
s
.26978 .57585 m
.27201 .57971 L
s
.5 Mabswid
.122 .134 .102 r
.33261 .67601 m .36207 .69962 L .35976 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.35976 .69409 m .33081 .67013 L .33261 .67601 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.3945 .28229 m .36207 .30038 L .35976 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.33081 .32987 m .35976 .30591 L .36207 .30038 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.66919 .67013 m .64024 .69409 L .63793 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.6055 .71771 m .63793 .69962 L .64024 .69409 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.64024 .30591 m .66919 .32987 L .66739 .32399 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.66739 .32399 m .63793 .30038 L .64024 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.36207 .30038 m .33261 .32399 L .33081 .32987 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.30594 .35823 m .33081 .32987 L .33261 .32399 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.30703 .64742 m .33261 .67601 L .33081 .67013 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.33081 .67013 m .30594 .64177 L .30703 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.69406 .64177 m .66919 .67013 L .66739 .67601 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.63793 .69962 m .66739 .67601 L .66919 .67013 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.66919 .32987 m .69406 .35823 L .69297 .35258 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.69297 .35258 m .66739 .32399 L .66919 .32987 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2684 .57404 m
.26978 .57585 L
s
.5 Mabswid
.11 .123 .094 r
.443 .73607 m .47183 .73933 L .46737 .73787 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.46737 .73787 m .43439 .73316 L .443 .73607 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.43439 .26684 m .46737 .26213 L .47183 .26067 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.46737 .26213 m .43439 .26684 L .42894 .27003 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.53263 .73787 m .56561 .73316 L .57106 .72997 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.56561 .73316 m .53263 .73787 L .52817 .73933 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.53263 .26213 m .56561 .26684 L .557 .26393 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.557 .26393 m .52817 .26067 L .53263 .26213 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.33261 .32399 m .30703 .35258 L .30594 .35823 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.28585 .39028 m .30594 .35823 L .30703 .35258 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.28616 .61456 m .30703 .64742 L .30594 .64177 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.30594 .64177 m .28585 .60972 L .28616 .61456 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.69406 .35823 m .71415 .39028 L .71384 .38544 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.71384 .38544 m .69297 .35258 L .69406 .35823 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.71415 .60972 m .69406 .64177 L .69297 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66739 .67601 m .69297 .64742 L .69406 .64177 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.30703 .35258 m .28616 .38544 L .28585 .39028 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.27109 .42521 m .28585 .39028 L .28616 .38544 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.27072 .57833 m .28616 .61456 L .28585 .60972 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27613 .58955 m
.27622 .58947 L
s
.5 Mabswid
.097 .112 .085 r
.28585 .60972 m .27109 .57479 L .27072 .57833 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2732 .59206 m
.27567 .58994 L
s
.27912 .59934 m
.27936 .60156 L
s
.5 Mabswid
.241 .34 .302 r
.71415 .39028 m .72891 .42521 L .72928 .42167 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.72928 .42167 m .71384 .38544 L .71415 .39028 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.72891 .57479 m .71415 .60972 L .71384 .61456 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.69297 .64742 m .71384 .61456 L .71415 .60972 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27869 .60228 m
.27936 .60156 L
s
.5 Mabswid
.104 .118 .09 r
.40194 .72224 m .43439 .73316 L .42894 .72997 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.42894 .72997 m .3945 .71771 L .40194 .72224 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.3945 .28229 m .42894 .27003 L .43439 .26684 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.6055 .71771 m .57106 .72997 L .56561 .73316 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.57106 .27003 m .6055 .28229 L .59806 .27776 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.59806 .27776 m .56561 .26684 L .57106 .27003 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72861 .41541 m
.73007 .4215 L
s
.5 Mabswid
.165 .239 .153 r
.28616 .38544 m .27072 .42167 L .27109 .42521 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.26206 .46211 m .27109 .42521 L .27072 .42167 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.26123 .53976 m .27072 .57833 L .27109 .57479 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.27109 .57479 m .26206 .53789 L .26123 .53976 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26762 .57459 m
.2684 .57404 L
s
.5 Mabswid
.115 .151 .14 r
.73794 .53789 m .72891 .57479 L .72928 .57833 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.71384 .61456 m .72928 .57833 L .72891 .57479 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.72891 .42521 m .73794 .46211 L .73877 .46024 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.73877 .46024 m .72928 .42167 L .72891 .42521 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7273 .41398 m
.73568 .4399 L
s
.5 Mabswid
.141 .198 .13 r
.27072 .42167 m .26123 .46024 L .26206 .46211 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.25902 .5 m .26206 .46211 L .26123 .46024 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.25803 .5 m .26123 .53976 L .26206 .53789 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.26206 .53789 m .25902 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.73794 .46211 m .74098 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.74197 .5 m .73877 .46024 L .73794 .46211 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.74098 .5 m .73794 .53789 L .73877 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.72928 .57833 m .73877 .53976 L .73794 .53789 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.26123 .46024 m .25803 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.73877 .53976 m .74197 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.45445 .73853 m .4776 .74056 L .47183 .73933 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.47183 .73933 m .443 .73607 L .45445 .73853 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.52817 .73933 m .557 .73607 L .56561 .73316 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.557 .73607 m .52817 .73933 L .5224 .74056 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.443 .26393 m .47183 .26067 L .4776 .25944 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.47183 .26067 m .443 .26393 L .43439 .26684 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.52817 .26067 m .557 .26393 L .54555 .26147 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.54555 .26147 m .5224 .25944 L .52817 .26067 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72819 .4132 m
.72861 .41541 L
s
0 0 0 r
.27754 .60098 m
.27869 .60228 L
s
.5 Mabswid
.072 .089 .067 r
.46823 .7404 m .48444 .74148 L .4776 .74056 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.4776 .74056 m .45445 .73853 L .46823 .7404 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.5224 .74056 m .54555 .73853 L .557 .73607 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.54555 .73853 m .5224 .74056 L .51556 .74148 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.45445 .26147 m .4776 .25944 L .48444 .25852 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.4776 .25944 m .45445 .26147 L .443 .26393 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.5224 .25944 m .54555 .26147 L .53177 .2596 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.53177 .2596 m .51556 .25852 L .5224 .25944 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26762 .57459 m
.26797 .57716 L
s
1 .5 0 r
.72819 .4132 m
.72854 .41273 L
s
.5 Mabswid
.075 .092 .07 r
.37097 .70507 m .40194 .72224 L .3945 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.3945 .71771 m .36207 .69962 L .37097 .70507 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.43439 .26684 m .40194 .27776 L .3945 .28229 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.36207 .30038 m .3945 .28229 L .40194 .27776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63793 .69962 m .6055 .71771 L .59806 .72224 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.56561 .73316 m .59806 .72224 L .6055 .71771 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.6055 .28229 m .63793 .30038 L .62903 .29493 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.62903 .29493 m .59806 .27776 L .6055 .28229 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48368 .74157 m .49203 .74206 L .48444 .74148 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48444 .74148 m .46823 .7404 L .48368 .74157 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.51556 .74148 m .53177 .7404 L .54555 .73853 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.53177 .7404 m .51556 .74148 L .50797 .74206 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51556 .25852 m .53177 .2596 L .51632 .25843 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51632 .25843 m .50797 .25794 L .51556 .25852 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.46823 .2596 m .48444 .25852 L .49203 .25794 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.48444 .25852 m .46823 .2596 L .45445 .26147 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27659 .5994 m
.27754 .60098 L
s
.26797 .57716 m
.26923 .58186 L
s
.5 Mabswid
.056 .074 .056 r
.50797 .74206 m .51632 .74157 L .53177 .7404 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.51632 .74157 m .50797 .74206 L .5 .74225 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.5 .74197 m .5 .74225 L .49203 .74206 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.49203 .74206 m .48368 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50797 .25794 m .51632 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.5 .25803 m .5 .25775 L .50797 .25794 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.49203 .25794 m .48368 .25843 L .46823 .2596 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.48368 .25843 m .49203 .25794 L .5 .25775 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.40194 .27776 m .43439 .26684 L .443 .26393 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.41427 .7264 m .443 .73607 L .43439 .73316 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.43439 .73316 m .40194 .72224 L .41427 .7264 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .56561 .73316 L .557 .73607 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.56561 .26684 m .59806 .27776 L .58573 .2736 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.58573 .2736 m .557 .26393 L .56561 .26684 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27483 .59591 m
.27659 .5994 L
s
.5 Mabswid
.315 .477 .372 r
.5 .74225 m .5 .74197 L .51632 .74157 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.5 .25775 m .5 .25803 L .48368 .25843 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72854 .41273 m
.72943 .41433 L
s
0 0 0 r
.2732 .59206 m
.27483 .59591 L
s
1 .5 0 r
.73159 .41991 m
.72943 .41433 L
s
.5 Mabswid
.329 .482 .401 r
.34248 .68188 m .37097 .70507 L .36207 .69962 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.36207 .69962 m .33261 .67601 L .34248 .68188 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.40194 .27776 m .37097 .29493 L .36207 .30038 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.33261 .32399 m .36207 .30038 L .37097 .29493 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .62903 .70507 L .63793 .69962 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.66739 .67601 m .63793 .69962 L .62903 .70507 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.63793 .30038 m .66739 .32399 L .65752 .31812 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.65752 .31812 m .62903 .29493 L .63793 .30038 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73159 .41991 m
.73735 .43865 L
s
.5 Mabswid
.378 .556 .442 r
.43113 .72997 m .45445 .73853 L .443 .73607 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.443 .73607 m .41427 .7264 L .43113 .72997 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.443 .26393 m .41427 .2736 L .40194 .27776 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.41427 .2736 m .443 .26393 L .45445 .26147 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.557 .73607 m .58573 .7264 L .59806 .72224 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.58573 .7264 m .557 .73607 L .54555 .73853 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.557 .26393 m .58573 .2736 L .56887 .27003 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.56887 .27003 m .54555 .26147 L .557 .26393 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.31748 .65312 m .34248 .68188 L .33261 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.33261 .67601 m .30703 .64742 L .31748 .65312 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.37097 .29493 m .34248 .31812 L .33261 .32399 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.30703 .35258 m .33261 .32399 L .34248 .31812 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.69297 .64742 m .66739 .67601 L .65752 .68188 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.62903 .70507 m .65752 .68188 L .66739 .67601 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.66739 .32399 m .69297 .35258 L .68252 .34688 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.68252 .34688 m .65752 .31812 L .66739 .32399 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2741 .59559 m
.27568 .59919 L
s
.27568 .59919 m
.27748 .60314 L
s
.5 Mabswid
.394 .571 .46 r
.38653 .71016 m .41427 .7264 L .40194 .72224 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.40194 .72224 m .37097 .70507 L .38653 .71016 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.37097 .29493 m .40194 .27776 L .41427 .2736 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.62903 .70507 m .59806 .72224 L .58573 .7264 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.59806 .27776 m .62903 .29493 L .61347 .28984 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.61347 .28984 m .58573 .2736 L .59806 .27776 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2677 .57888 m
.26915 .58307 L
s
.27748 .60314 m
.27883 .60569 L
s
.27356 .59407 m
.2741 .59559 L
s
1 .5 0 r
.72858 .41097 m
.73731 .43772 L
s
0 0 0 r
.26738 .5772 m
.2677 .57888 L
s
1 .5 0 r
.7404 .45071 m
.74071 .45243 L
s
.73996 .4488 m
.7404 .45071 L
s
.5 Mabswid
.087 .102 .078 r
.34248 .31812 m .31748 .34688 L .30703 .35258 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.28616 .38544 m .30703 .35258 L .31748 .34688 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.2969 .61949 m .31748 .65312 L .30703 .64742 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.30703 .64742 m .28616 .61456 L .2969 .61949 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45177 .7327 m .46823 .7404 L .45445 .73853 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45445 .73853 m .43113 .72997 L .45177 .7327 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.54555 .73853 m .56887 .72997 L .58573 .7264 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.56887 .72997 m .54555 .73853 L .53177 .7404 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.43113 .27003 m .45445 .26147 L .46823 .2596 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.45445 .26147 m .43113 .27003 L .41427 .2736 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54555 .26147 m .56887 .27003 L .54823 .2673 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54823 .2673 m .53177 .2596 L .54555 .26147 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.69297 .35258 m .71384 .38544 L .7031 .38051 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.7031 .38051 m .68252 .34688 L .69297 .35258 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.71384 .61456 m .69297 .64742 L .68252 .65312 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.65752 .68188 m .68252 .65312 L .69297 .64742 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.74026 .45052 m
.73996 .4488 L
s
.74071 .45243 m
.74026 .45052 L
s
.5 Mabswid
.367 .503 .418 r
.28156 .58196 m .2969 .61949 L .28616 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28616 .61456 m .27072 .57833 L .28156 .58196 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27883 .60569 m
.2796 .60643 L
s
.27356 .59407 m
.27397 .59317 L
s
.5 Mabswid
.131 .152 .126 r
.31748 .34688 m .2969 .38051 L .28616 .38544 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.27072 .42167 m .28616 .38544 L .2969 .38051 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71384 .38544 m .72928 .42167 L .71844 .41804 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71844 .41804 m .7031 .38051 L .71384 .38544 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.72928 .57833 m .71384 .61456 L .7031 .61949 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.68252 .65312 m .7031 .61949 L .71384 .61456 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.47517 .73443 m .48368 .74157 L .46823 .7404 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.46823 .7404 m .45177 .7327 L .47517 .73443 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.53177 .7404 m .54823 .7327 L .56887 .72997 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.54823 .7327 m .53177 .7404 L .51632 .74157 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.45177 .2673 m .46823 .2596 L .48368 .25843 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.46823 .2596 m .45177 .2673 L .43113 .27003 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53177 .2596 m .54823 .2673 L .52483 .26557 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.52483 .26557 m .51632 .25843 L .53177 .2596 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2796 .60643 m
.27977 .60534 L
s
.5 Mabswid
.351 .472 .394 r
.27208 .54168 m .28156 .58196 L .27072 .57833 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27072 .57833 m .26123 .53976 L .27208 .54168 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26738 .5772 m
.2681 .57777 L
s
.5 Mabswid
.177 .207 .182 r
.2969 .38051 m .28156 .41804 L .27072 .42167 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.26123 .46024 m .27072 .42167 L .28156 .41804 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.36072 .68742 m .38653 .71016 L .37097 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.37097 .70507 m .34248 .68188 L .36072 .68742 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.41427 .2736 m .38653 .28984 L .37097 .29493 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.34248 .31812 m .37097 .29493 L .38653 .28984 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.65752 .68188 m .62903 .70507 L .61347 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.58573 .7264 m .61347 .71016 L .62903 .70507 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.62903 .29493 m .65752 .31812 L .63928 .31258 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.63928 .31258 m .61347 .28984 L .62903 .29493 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72928 .42167 m .73877 .46024 L .72792 .45832 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72792 .45832 m .71844 .41804 L .72928 .42167 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.73877 .53976 m .72928 .57833 L .71844 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.7031 .61949 m .71844 .58196 L .72928 .57833 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72734 .40968 m
.73402 .42914 L
s
.5 Mabswid
.446 .641 .486 r
.51632 .74157 m .52483 .73443 L .54823 .7327 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.52483 .73443 m .51632 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.5 .73502 m .5 .74197 L .48368 .74157 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.48368 .74157 m .47517 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.51632 .25843 m .52483 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .26498 m .5 .25803 L .51632 .25843 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.47517 .26557 m .48368 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.48368 .25843 m .47517 .26557 L .45177 .2673 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.40837 .71456 m .43113 .72997 L .41427 .7264 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.41427 .7264 m .38653 .71016 L .40837 .71456 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.38653 .28984 m .41427 .2736 L .43113 .27003 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.61347 .71016 m .58573 .7264 L .56887 .72997 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.58573 .2736 m .61347 .28984 L .59163 .28544 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.59163 .28544 m .56887 .27003 L .58573 .2736 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.28156 .41804 m .27208 .45832 L .26123 .46024 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.25803 .5 m .26123 .46024 L .27208 .45832 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26887 .5 m .27208 .54168 L .26123 .53976 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26123 .53976 m .25803 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73877 .46024 m .74197 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73113 .5 m .72792 .45832 L .73877 .46024 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.74197 .5 m .73877 .53976 L .72792 .54168 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.71844 .58196 m .72792 .54168 L .73877 .53976 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2681 .57777 m
.26987 .58064 L
s
.27386 .59155 m
.27397 .59317 L
s
.5 Mabswid
.283 .361 .307 r
.27208 .45832 m .26887 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.5 .74197 m .5 .73502 L .52483 .73443 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .25803 m .5 .26498 L .47517 .26557 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.72792 .54168 m .73113 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73402 .42914 m
.73543 .43475 L
s
.73543 .43475 m
.73543 .43642 L
s
0 0 0 r
.27845 .6018 m
.27977 .60534 L
s
.27263 .5875 m
.27386 .59155 L
s
.26987 .58064 m
.27183 .58532 L
s
1 .5 0 r
.73454 .43606 m
.73543 .43642 L
s
0 0 0 r
.27183 .58532 m
.27263 .5875 L
s
.5 Mabswid
.494 .682 .543 r
.33783 .65855 m .36072 .68742 L .34248 .68188 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.34248 .68188 m .31748 .65312 L .33783 .65855 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.38653 .28984 m .36072 .31258 L .34248 .31812 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.31748 .34688 m .34248 .31812 L .36072 .31258 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.68252 .65312 m .65752 .68188 L .63928 .68742 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.61347 .71016 m .63928 .68742 L .65752 .68188 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.65752 .31812 m .68252 .34688 L .66217 .34145 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.66217 .34145 m .63928 .31258 L .65752 .31812 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73334 .4339 m
.73454 .43606 L
s
.5 Mabswid
.532 .746 .577 r
.43559 .71798 m .45177 .7327 L .43113 .72997 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43113 .72997 m .40837 .71456 L .43559 .71798 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.56887 .72997 m .59163 .71456 L .61347 .71016 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.59163 .71456 m .56887 .72997 L .54823 .7327 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.40837 .28544 m .43113 .27003 L .45177 .2673 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.43113 .27003 m .40837 .28544 L .38653 .28984 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56887 .27003 m .59163 .28544 L .56441 .28202 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56441 .28202 m .54823 .2673 L .56887 .27003 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73053 .42769 m
.73334 .4339 L
s
.72381 .40788 m
.73267 .43547 L
s
0 0 0 r
.27944 .59563 m
.29151 .62163 L
s
.5 Mabswid
.543 .752 .588 r
.38699 .69227 m .40837 .71456 L .38653 .71016 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38653 .71016 m .36072 .68742 L .38699 .69227 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.36072 .31258 m .38653 .28984 L .40837 .28544 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.63928 .68742 m .61347 .71016 L .59163 .71456 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61347 .28984 m .63928 .31258 L .61301 .30773 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61301 .30773 m .59163 .28544 L .61347 .28984 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.36072 .31258 m .33783 .34145 L .31748 .34688 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.2969 .38051 m .31748 .34688 L .33783 .34145 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31882 .62423 m .33783 .65855 L .31748 .65312 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31748 .65312 m .2969 .61949 L .31882 .62423 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68252 .34688 m .7031 .38051 L .68118 .37577 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68118 .37577 m .66217 .34145 L .68252 .34688 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.7031 .61949 m .68252 .65312 L .66217 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.63928 .68742 m .66217 .65855 L .68252 .65312 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27386 .58007 m
.27397 .58221 L
s
.27397 .58221 m
.27541 .58471 L
s
.5 Mabswid
.564 .784 .6 r
.46675 .72014 m .47517 .73443 L .45177 .7327 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.45177 .7327 m .43559 .71798 L .46675 .72014 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.54823 .7327 m .56441 .71798 L .59163 .71456 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.56441 .71798 m .54823 .7327 L .52483 .73443 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.43559 .28202 m .45177 .2673 L .47517 .26557 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.45177 .2673 m .43559 .28202 L .40837 .28544 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.54823 .2673 m .56441 .28202 L .53325 .27986 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.53325 .27986 m .52483 .26557 L .54823 .2673 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27532 .5826 m
.27541 .58471 L
s
.27386 .58007 m
.27532 .5826 L
s
1 .5 0 r
.72468 .41881 m
.72594 .4228 L
s
.72209 .41264 m
.72468 .41881 L
s
.72594 .4228 m
.72712 .42861 L
s
.71946 .40828 m
.72209 .41264 L
s
.5 Mabswid
.548 .763 .57 r
.52483 .73443 m .53325 .72014 L .56441 .71798 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.53325 .72014 m .52483 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.5 .72088 m .5 .73502 L .47517 .73443 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.47517 .73443 m .46675 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.52483 .26557 m .53325 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.5 .27912 m .5 .26498 L .52483 .26557 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.46675 .27986 m .47517 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.47517 .26557 m .46675 .27986 L .43559 .28202 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.30454 .58546 m .31882 .62423 L .2969 .61949 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.2969 .61949 m .28156 .58196 L .30454 .58546 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.33783 .34145 m .31882 .37577 L .2969 .38051 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.28156 .41804 m .2969 .38051 L .31882 .37577 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.71844 .58196 m .7031 .61949 L .68118 .62423 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.66217 .65855 m .68118 .62423 L .7031 .61949 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.7031 .38051 m .71844 .41804 L .69546 .41454 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.69546 .41454 m .68118 .37577 L .7031 .38051 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72701 .43231 m
.72712 .42861 L
s
.71745 .40593 m
.71946 .40828 L
s
.5 Mabswid
.571 .791 .595 r
.5 .73502 m .5 .72088 L .53325 .72014 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5 .26498 m .5 .27912 L .46675 .27986 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71544 .40544 m
.71745 .40593 L
s
.5 Mabswid
.58 .79 .614 r
.36786 .66334 m .38699 .69227 L .36072 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36072 .68742 m .33783 .65855 L .36786 .66334 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.40837 .28544 m .38699 .30773 L .36072 .31258 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.33783 .34145 m .36072 .31258 L .38699 .30773 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.66217 .65855 m .63928 .68742 L .61301 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.59163 .71456 m .61301 .69227 L .63928 .68742 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63928 .31258 m .66217 .34145 L .63214 .33666 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63214 .33666 m .61301 .30773 L .63928 .31258 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.31882 .37577 m .30454 .41454 L .28156 .41804 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.27208 .45832 m .28156 .41804 L .30454 .41454 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.29568 .54355 m .30454 .58546 L .28156 .58196 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.28156 .58196 m .27208 .54168 L .29568 .54355 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.42026 .69605 m .43559 .71798 L .40837 .71456 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.40837 .71456 m .38699 .69227 L .42026 .69605 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.61301 .69227 m .59163 .71456 L .56441 .71798 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.38699 .30773 m .40837 .28544 L .43559 .28202 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.59163 .28544 m .61301 .30773 L .57974 .30395 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.57974 .30395 m .56441 .28202 L .59163 .28544 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.72792 .54168 m .71844 .58196 L .69546 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.68118 .62423 m .69546 .58546 L .71844 .58196 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.71844 .41804 m .72792 .45832 L .70432 .45645 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72625 .43404 m
.72701 .43231 L
s
.5 Mabswid
.343 .423 .283 r
.70432 .45645 m .69546 .41454 L .71844 .41804 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72421 .43369 m
.72625 .43404 L
s
.71476 .40717 m
.71544 .40544 L
s
.5 Mabswid
.391 .488 .386 r
.30454 .41454 m .29568 .45645 L .27208 .45832 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.26887 .5 m .27208 .45832 L .29568 .45645 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.29268 .5 m .29568 .54355 L .27208 .54168 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.27208 .54168 m .26887 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.72792 .45832 m .73113 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.70732 .5 m .70432 .45645 L .72792 .45832 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.73113 .5 m .72792 .54168 L .70432 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.69546 .58546 m .70432 .54355 L .72792 .54168 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.29568 .45645 m .29268 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.70432 .54355 m .70732 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71469 .41096 m
.71476 .40717 L
s
.72225 .43146 m
.72421 .43369 L
s
.71965 .42721 m
.72225 .43146 L
s
.71469 .41096 m
.7159 .41694 L
s
.71714 .42101 m
.71965 .42721 L
s
.7159 .41694 m
.71714 .42101 L
s
.5 Mabswid
.623 .849 .645 r
.45874 .69847 m .46675 .72014 L .43559 .71798 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.43559 .71798 m .42026 .69605 L .45874 .69847 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.56441 .71798 m .57974 .69605 L .61301 .69227 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.56441 .28202 m .57974 .30395 L .54126 .30153 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.54126 .30153 m .53325 .27986 L .56441 .28202 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.57974 .69605 m .56441 .71798 L .53325 .72014 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.42026 .30395 m .43559 .28202 L .46675 .27986 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.43559 .28202 m .42026 .30395 L .38699 .30773 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.38699 .30773 m .36786 .33666 L .33783 .34145 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.31882 .37577 m .33783 .34145 L .36786 .33666 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.35184 .62843 m .36786 .66334 L .33783 .65855 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.33783 .65855 m .31882 .62423 L .35184 .62843 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.66217 .34145 m .68118 .37577 L .64816 .37157 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.64816 .37157 m .63214 .33666 L .66217 .34145 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.68118 .62423 m .66217 .65855 L .63214 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.61301 .69227 m .63214 .66334 L .66217 .65855 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70571 .40353 m
.71623 .44257 L
s
.71623 .44257 m
.71723 .44626 L
s
.5 Mabswid
.627 .846 .647 r
.40645 .66711 m .42026 .69605 L .38699 .69227 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.38699 .69227 m .36786 .66334 L .40645 .66711 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.36786 .33666 m .38699 .30773 L .42026 .30395 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.63214 .66334 m .61301 .69227 L .57974 .69605 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.61301 .30773 m .63214 .33666 L .59355 .33289 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.59355 .33289 m .57974 .30395 L .61301 .30773 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.53325 .72014 m .54126 .69847 L .57974 .69605 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.54126 .69847 m .53325 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.5 .6993 m .5 .72088 L .46675 .72014 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.46675 .72014 m .45874 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.53325 .27986 m .54126 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.5 .3007 m .5 .27912 L .53325 .27986 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45874 .30153 m .46675 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.46675 .27986 m .45874 .30153 L .42026 .30395 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.5 .72088 m .5 .6993 L .54126 .69847 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.5 .27912 m .5 .3007 L .45874 .30153 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.33974 .58859 m .35184 .62843 L .31882 .62423 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.31882 .62423 m .30454 .58546 L .33974 .58859 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.36786 .33666 m .35184 .37157 L .31882 .37577 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.30454 .41454 m .31882 .37577 L .35184 .37157 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.69546 .58546 m .68118 .62423 L .64816 .62843 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.63214 .66334 m .64816 .62843 L .68118 .62423 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.68118 .37577 m .69546 .41454 L .66026 .41141 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.66026 .41141 m .64816 .37157 L .68118 .37577 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69769 .40228 m
.70632 .43553 L
s
.70632 .43553 m
.70891 .44552 L
s
.5 Mabswid
.58 .759 .584 r
.3322 .54522 m .33974 .58859 L .30454 .58546 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.30454 .58546 m .29568 .54355 L .3322 .54522 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.35184 .37157 m .33974 .41141 L .30454 .41454 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.29568 .45645 m .30454 .41454 L .33974 .41141 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.70432 .54355 m .69546 .58546 L .66026 .58859 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.64816 .62843 m .66026 .58859 L .69546 .58546 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.69546 .41454 m .70432 .45645 L .6678 .45478 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.6678 .45478 m .66026 .41141 L .69546 .41454 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.57974 .69605 m .59355 .66711 L .63214 .66334 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.59355 .66711 m .57974 .69605 L .54126 .69847 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.45149 .66953 m .45874 .69847 L .42026 .69605 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.42026 .69605 m .40645 .66711 L .45149 .66953 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.57974 .30395 m .59355 .33289 L .54851 .33047 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.54851 .33047 m .54126 .30153 L .57974 .30395 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.40645 .33289 m .42026 .30395 L .45874 .30153 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.42026 .30395 m .40645 .33289 L .36786 .33666 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.35184 .37157 m .36786 .33666 L .40645 .33289 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.39481 .63177 m .40645 .66711 L .36786 .66334 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.36786 .66334 m .35184 .62843 L .39481 .63177 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.63214 .33666 m .64816 .37157 L .60519 .36823 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.60519 .36823 m .59355 .33289 L .63214 .33666 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.64816 .62843 m .63214 .66334 L .59355 .66711 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.33974 .41141 m .3322 .45478 L .29568 .45645 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.29268 .5 m .29568 .45645 L .3322 .45478 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.32963 .5 m .3322 .54522 L .29568 .54355 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.29568 .54355 m .29268 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.70432 .45645 m .70732 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.67037 .5 m .6678 .45478 L .70432 .45645 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.70732 .5 m .70432 .54355 L .6678 .54522 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.66026 .58859 m .6678 .54522 L .70432 .54355 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69356 .41391 m
.69471 .41812 L
s
.69047 .40744 m
.69356 .41391 L
s
.68664 .40291 m
.69047 .40744 L
s
.69471 .41812 m
.69506 .42427 L
s
.5 Mabswid
.525 .67 .513 r
.3322 .45478 m .32963 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.6678 .54522 m .67037 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68339 .40049 m
.68664 .40291 L
s
.69346 .42821 m
.69506 .42427 L
s
.6794 .40006 m
.68339 .40049 L
s
.5 Mabswid
.63 .845 .621 r
.54126 .69847 m .54851 .66953 L .59355 .66711 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.54851 .66953 m .54126 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.5 .67037 m .5 .6993 L .45874 .69847 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.45874 .69847 m .45149 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.54126 .30153 m .54851 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.5 .32963 m .5 .3007 L .54126 .30153 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.45149 .33047 m .45874 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.45874 .30153 m .45149 .33047 L .40645 .33289 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69126 .43007 m
.69346 .42821 L
s
.67729 .40193 m
.6794 .40006 L
s
.68713 .42975 m
.69126 .43007 L
s
.5 Mabswid
.649 .868 .644 r
.5 .6993 m .5 .67037 L .54851 .66953 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.5 .3007 m .5 .32963 L .45149 .33047 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6757 .40595 m
.67729 .40193 L
s
.5 Mabswid
.632 .832 .632 r
.38598 .59108 m .39481 .63177 L .35184 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.35184 .62843 m .33974 .58859 L .38598 .59108 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.40645 .33289 m .39481 .36823 L .35184 .37157 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.33974 .41141 m .35184 .37157 L .39481 .36823 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.66026 .58859 m .64816 .62843 L .60519 .63177 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.59355 .66711 m .60519 .63177 L .64816 .62843 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.64816 .37157 m .66026 .41141 L .61402 .40892 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.61402 .40892 m .60519 .36823 L .64816 .37157 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68383 .42745 m
.68713 .42975 L
s
.6757 .40595 m
.67597 .41226 L
s
.68 .42302 m
.68383 .42745 L
s
.67597 .41226 m
.67703 .41653 L
s
.67703 .41653 m
.68 .42302 L
s
.5 Mabswid
.434 .527 .367 r
.59355 .33289 m .60519 .36823 L .55465 .36608 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.55465 .36608 m .54851 .33047 L .59355 .33289 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.60519 .63177 m .59355 .66711 L .54851 .66953 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.39481 .36823 m .40645 .33289 L .45149 .33047 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.44535 .63392 m .45149 .66953 L .40645 .66711 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.40645 .66711 m .39481 .63177 L .44535 .63392 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65757 .40022 m
.66196 .40481 L
s
.66196 .40481 m
.66519 .41142 L
s
.5 Mabswid
.618 .805 .609 r
.38045 .54655 m .38598 .59108 L .33974 .58859 L p F P
.505 .664 .505 r
s
.618 .805 .609 r
.33974 .58859 m .3322 .54522 L .38045 .54655 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.39481 .36823 m .38598 .40892 L .33974 .41141 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.3322 .45478 m .33974 .41141 L .38598 .40892 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.6678 .54522 m .66026 .58859 L .61402 .59108 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.60519 .63177 m .61402 .59108 L .66026 .58859 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.66026 .41141 m .6678 .45478 L .61955 .45345 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66519 .41142 m
.6662 .41573 L
s
.5 Mabswid
.494 .619 .432 r
.61955 .45345 m .61402 .40892 L .66026 .41141 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6537 .39779 m
.65757 .40022 L
s
.66597 .42206 m
.6662 .41573 L
s
.64864 .39742 m
.6537 .39779 L
s
.66349 .42614 m
.66597 .42206 L
s
.63749 .38157 m
.64798 .42747 L
s
.5 Mabswid
.634 .841 .614 r
.54851 .66953 m .55465 .63392 L .60519 .63177 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.54851 .33047 m .55465 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.5 .36534 m .5 .32963 L .54851 .33047 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.55465 .63392 m .54851 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.44535 .36608 m .45149 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.5 .63466 m .5 .67037 L .45149 .66953 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.45149 .66953 m .44535 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.45149 .33047 m .44535 .36608 L .39481 .36823 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.64574 .39938 m
.64864 .39742 L
s
.66048 .42808 m
.66349 .42614 L
s
.5 Mabswid
.531 .669 .502 r
.38598 .40892 m .38045 .45345 L .3322 .45478 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.32963 .5 m .3322 .45478 L .38045 .45345 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.37857 .5 m .38045 .54655 L .3322 .54522 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.3322 .54522 m .32963 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.6678 .45478 m .67037 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.62143 .5 m .61955 .45345 L .6678 .45478 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.67037 .5 m .6678 .54522 L .61955 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.61402 .59108 m .61955 .54655 L .6678 .54522 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.64325 .40354 m
.64574 .39938 L
s
.65523 .42781 m
.66048 .42808 L
s
.5 Mabswid
.652 .863 .636 r
.5 .67037 m .5 .63466 L .55465 .63392 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.5 .32963 m .5 .36534 L .44535 .36608 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.38045 .45345 m .37857 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.61955 .54655 m .62143 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.44068 .5927 m .44535 .63392 L .39481 .63177 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.39481 .63177 m .38598 .59108 L .44068 .5927 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.38598 .40892 m .39481 .36823 L .44535 .36608 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.61402 .59108 m .60519 .63177 L .55465 .63392 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.60519 .36823 m .61402 .40892 L .55932 .4073 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.55932 .4073 m .55465 .36608 L .60519 .36823 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65127 .42549 m
.65523 .42781 L
s
.62822 .43212 m
.63446 .3965 L
s
.62656 .44161 m
.62822 .43212 L
s
.64685 .42099 m
.65127 .42549 L
s
.5 Mabswid
.633 .824 .615 r
.43776 .54742 m .44068 .5927 L .38598 .59108 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.38598 .59108 m .38045 .54655 L .43776 .54742 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.44535 .36608 m .44068 .4073 L .38598 .40892 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.38045 .45345 m .38598 .40892 L .44068 .4073 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.61402 .40892 m .61955 .45345 L .56224 .45258 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.56224 .45258 m .55932 .4073 L .61402 .40892 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.61212 .41075 m
.63208 .41161 L
s
.5 Mabswid
.612 .795 .575 r
.61955 .54655 m .61402 .59108 L .55932 .5927 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.55465 .63392 m .55932 .5927 L .61402 .59108 L p F P
.505 .664 .505 r
s
.644 .844 .62 r
.55932 .5927 m .55465 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.5 .59326 m .5 .63466 L .44535 .63392 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.44535 .63392 m .44068 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.44068 .4073 m .44535 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.55465 .36608 m .55932 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.5 .40674 m .5 .36534 L .55465 .36608 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.60327 .39492 m
.61755 .42354 L
s
.61755 .42354 m
.62656 .44161 L
s
.5 Mabswid
.644 .844 .62 r
.5 .63466 m .5 .59326 L .55932 .5927 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.5 .36534 m .5 .40674 L .44068 .4073 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.61955 .45345 m .62143 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.56324 .5 m .56224 .45258 L .61955 .45345 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.62143 .5 m .61955 .54655 L .56224 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.55932 .5927 m .56224 .54742 L .61955 .54655 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.44068 .4073 m .43776 .45258 L .38045 .45345 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.37857 .5 m .38045 .45345 L .43776 .45258 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.43676 .5 m .43776 .54742 L .38045 .54655 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.38045 .54655 m .37857 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.43776 .45258 m .43676 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.56224 .54742 m .56324 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.56224 .54742 m .55932 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.5 .54772 m .5 .59326 L .44068 .5927 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.44068 .5927 m .43776 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.55932 .4073 m .56224 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.5 .45228 m .5 .40674 L .55932 .4073 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.43776 .45258 m .44068 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.5 .59326 m .5 .54772 L .56224 .54742 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.5 .40674 m .5 .45228 L .43776 .45258 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.56224 .45258 m .56324 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.5 .5 m .5 .45228 L .56224 .45258 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.56324 .5 m .56224 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.43676 .5 m .43776 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.5 .5 m .5 .54772 L .43776 .54742 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.43776 .54742 m .43676 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.5 .45228 m .5 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.5 .54772 m .5 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>h0/>3V5`21ZH7^0;3PiP40oooo003V0;3PiPP0PJV10P0R9A`0
0`21ZH4092LN02@W7P0602@W7P03086YP@0U:1h09BPN00H09BPN00<0PJV102<V7@0S9Qd02021ZH7V
0;3PiP40oooo003P0;3PiPH0PJV100<0720H086YP@21ZH401P0R9A`00`21ZH4092LN02@W7P0702@W
7P03086YP@0U:1h09BPN00L09BPN00<0PJV102<V7@0S9Qd0100S9Qd2086YP@0301lR6P21ZH40PJV1
00@0PJV1h02`h>H10?ooo`00g02`h>H5086YP@@0720H0P21ZH47028U7003086YP@0T9ah092LN00P0
92LN00<0PJV102DX7P0U:1h0200U:1h00`21ZH408bHM02<V7@0502<V7@80PJV1100O8QX5086YPM`0
/>3V0@3oool00=T0/>3V1@21ZH4501`P6080PJV10`0R9A`S086YP@<08bHM0P21ZH4501lR6PD0PJV1
f@2`h>H10?ooo`00eP2`h>H2086YP@0301DI4`21ZH40PJV10080720H2`21ZH4403<d:003086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@0203Df:@/0PJV100<0
7b8J086YP@21ZH401021ZH7F0;3PiP40oooo003C0;3PiPX0PJV10`0];b@00`21ZH40<c@X03<d:009
03<d:003086YP@0f>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@09
03Df:@04086YP@0`<RH0<38V030b9PX0PJV1d`2`h>H10?ooo`00d02`h>H7086YP@P0;BlT00<0PJV1
03<d:00c=2P02@0c=2P00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0g>2/0=cP[00/0=cP[00<0PJV1
03Df:@0e=RT02@0e=RT00`21ZH40<38V030b9P06030b9PL0PJV1d02`h>H10?ooo`00c@2`h>H4086Y
P@<092HM00<0PJV102d_900];b@01`0];b@00`21ZH40<c@X03<d:00903<d:003086YP@0f>2X0=SPZ
00`0=SPZ00<0PJV103Lh:`0g>2/0300g>2/00`21ZH40=CHY03Df:@0903Df:@03086YP@0`<RH0<38V
00L0<38V00@0PJV102P[800X:b00:2/P1021ZH7=0;3PiP40oooo003:0;3PiP@0PJV1100T9Qd2086Y
P@P0;BlT0P21ZH4;03<d:003086YP@0f>2X0=SPZ00d0=SPZ00<0PJV103Lh:`0g>2/03@0g>2/00`21
ZH40=CHY03Df:@0903Df:@80PJV1200`<RH2086YP@@0:2/P1021ZH7:0;3PiP40oooo00380;3PiP@0
PJV11@0T9Qd00`21ZH40;BlT02d_900702d_9003086YP@0c=2P0<c@X00/0<c@X00<0PJV103Hh:P0f
>2X03@0f>2X00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0e=RT0=CHY00/0=CHY00<0PJV1030b9P0`
<RH01`0`<RH00`21ZH40:2/P02P[800302P[80@0PJV1b02`h>H10?ooo`00aP2`h>H4086YP@D092HM
0P21ZH4902d_9003086YP@0c=2P0<c@X00@0<c@X<@21ZH4603Df:@03086YP@0`<RH0<38V00L0<38V
0P21ZH4502P[8080PJV100<07B0H086YP@2`h>H0a@2`h>H10?ooo`00a02`h>H2086YP@0301LK5021
ZH4092HM00D092HM00<0PJV102d_900];b@01@0];b@;086YP@L0B50i00<0PJV104eG?@1=Ecd03P1=
Ecd00`21ZH40CeTn04mI?P0>04mI?P03086YP@1<E3`0C5@l00D0C5@l2`21ZH47030b9P03086YP@0X
:b00:2/P00@0:2/P00@0PJV101dP6021ZH40PJV1a02`h>H10?ooo`00`P2`h>H2086YP@0301LK5021
ZH40PJV100D092HM0P21ZH400`0];b@0PJV1086YP@05086YP@80?D8`00<0PJV104Q@>@18D3T03018
D3T00`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<
E3`00`21ZH40@dXe04=:=@07086YP@03030b9P21ZH40PJV100D0:2/P0P21ZH400`0M81P0PJV1086Y
P@320;3PiP40oooo00300;3PiPD0PJV1100T9Qd6086YP@T0?D8`00<0PJV104Q@>@18D3T03018D3T0
0`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<E3`0
0`21ZH40@dXe04=:=@0704=:=@H0PJV1100X:b05086YPL00/>3V0@3oool00;h0/>3V2`21ZH400`0`
<BD0PJV103e2<00;03e2<003086YP@18D3T0B50i00d0B50i00<0PJV104eG?@1=Ecd03`1=Ecd00`21
ZH40CeTn04mI?P0?04mI?P03086YP@1<E3`0C5@l00d0C5@l00<0PJV104=:=@13BSD02P13BSD00`21
ZH40=SPZ086YP@0:086YPKh0/>3V0@3oool00;d0/>3V1P21ZH46030a9@03086YP@0m@S00?D8`00X0
?D8`00<0PJV104Q@>@18D3T03@18D3T00`21ZH40CELm04eG?@0@04eG?@03086YP@1?FCh0CeTn0100
CeTn00<0PJV104aD?01<E3`03@1<E3`00`21ZH40@dXe04=:=@0:04=:=@03086YP@0f>2X0=SPZ00@0
=SPZ1P21ZH6m0;3PiP40oooo002k0;3PiPD0PJV1200`<BD00`21ZH40?D8`03e2<00:03e2<003086Y
P@18D3T0B50i00h0B50i00<0PJV104eG?@1=Ecd0401=Ecd00`21ZH40CeTn04mI?P0@04mI?P03086Y
P@1<E3`0C5@l00h0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0603Hh:PD0PJV1
^`2`h>H10?ooo`00^@2`h>H4086YP@03028T7021ZH40<34U00L0<34U00<0PJV103e2<00m@S002`0m
@S000`21ZH40B50i04Q@>@0=04Q@>@03086YP@1=Ecd0CELm0140CELm00<0PJV104mI?P1?FCh04@1?
FCh00`21ZH40C5@l04aD?00=04aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f
>2X00`21ZH40:2/P086YP@03086YPKT0/>3V0@3oool00;L0/>3V1021ZH42028T7003086YP@0`<BD0
<34U00H0<34U00<0PJV103e2<00m@S002`0m@S000`21ZH40B50i04Q@>@0>04Q@>@03086YP@1=Ecd0
CELm0140CELm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40C5@l04aD?00>04aD?003086YP@13BSD0
@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f>2X2086YP@0302P[8021ZH40PJV10080PJV1]`2`h>H1
0?ooo`00]@2`h>H4086YP@<08R@L00<0PJV1030a9@0`<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2
<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=Ecd04@1=Ecd00`21ZH40CeTn04mI?P0A04mI
?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh
:P03086YP@0X:b00:2/P00@0PJV1]@2`h>H10?ooo`00]02`h>H3086YP@@08R@L00<0PJV1030a9@0`
<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=
Ecd04P1=Ecd00`21ZH40CeTn04mI?P0B04mI?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13
BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh:P04086YP@0X:b00:2/P02P[80<0PJV1]02`h>H10?oo
o`00/`2`h>H00`21ZH4041@?086YP@03028T7080PJV12@0`<BD00`21ZH40?D8`03e2<00;03e2<003
086YP@18D3T0B50i00H0B50i?@21ZH4804aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f
>2X0200f>2X01@21ZH40:2/P02P[800X:b00PJV1008061/D/`2`h>H10?ooo`00/@2`h>H4086YP@<0
8R@L00<0PJV1030a9@0`<BD0200`<BD00`21ZH40?D8`03e2<00803e2<0d0PJV12@1QLU<00`21ZH40
I7ME06AgE@0B06AgE@03086YP@1SME80HgEB0180HgEB00<0PJV105e]B`1MKD/01`1MKD/=086YP@X0
@dXe00<0PJV103Hh:P0f>2X0200f>2X01021ZH40:2/P02P[800X:b02086YP@0301PK5021ZH40/>3V
0;00/>3V0@3oool00;00/>3V00<0PJV1010D3`21ZH40100R91`00`21ZH40<34U030a9@08030a9@04
086YP@0m@S00?D8`03e2<0P0PJV10`1GIT/00`21ZH40HG9C065bD`0@065bD`03086YP@1TMeD0I7ME
0180I7ME00<0PJV106=eDP1SME804P1SME800`21ZH40GFe;05e]B`0@05e]B`04086YP@1FI4D0EVA5
05ITA@P0PJV10`13BSD00`21ZH40=SPZ03Hh:P0803Hh:P80PJV10`0X:b000`21ZH4061/D086YP@2`
0;3PiP40oooo002_0;3PiP03086YP@0@50l0PJV100@08R@L00<0PJV1030a9@0`<BD01@0`<BD8086Y
P@X0EfI;00<0PJV1065bD`1QLU<0401QLU<00`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB
01<0HgEB00<0PJV105e]B`1MKD/0401MKD/00`21ZH40EVA505ITA@0805ITA@P0PJV1200f>2X01`21
ZH40:2/P02P[800X:b00PJV101PK5021ZH40[`2`h>H10?ooo`00[P2`h>H3086YP@@08R@L00<0PJV1
030a9@0`<BD01P21ZH4204I??003086YP@1GIT/0EfI;00d0EfI;00<0PJV1065bD`1QLU<0401QLU<0
0`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB01<0HgEB00<0PJV105e]B`1MKD/0401MKD/0
0`21ZH40EVA505ITA@0=05ITA@03086YP@18DSX0B58j00L0PJV10P0f>2X01021ZH40:2/P02P[800X
:b03086YPJh0/>3V0@3oool00:`0/>3V0`21ZH44028T70D0PJV12016Cc`00`21ZH40EfI;05MVB`0<
05MVB`03086YP@1QLU<0HG9C0140HG9C00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgEB06=eDP0C
06=eDP03086YP@1MKD/0GFe;0140GFe;00<0PJV105ITA@1FI4D0301FI4D00`21ZH40B58j04QB>P07
04QB>PD0PJV10`0X:b03086YPJ`0/>3V0@3oool00:/0/>3V00<0PJV1010D3`21ZH400P0R91`4086Y
P@/0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01<0I7ME00<0PJV106=eDP1SME804`1SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00d0EVA500<0PJV104QB>P18DSX02P18DSX4086YP@0402P[8021ZH4061/D086YPJ/0/>3V0@3oool0
0:X0/>3V1P21ZH4202d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21
ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=eDP1SME804`1SME800`21
ZH40GFe;05e]B`0B05e]B`03086YP@1FI4D0EVA500d0EVA500<0PJV104QB>P18DSX02@18DSX01021
ZH40<cHX03<f:00c=RP5086YPJX0/>3V0@3oool00:T0/>3V0`21ZH4602d`9P03086YP@16Cc`0ATll
00P0ATll00<0PJV105MVB`1GIT/03P1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01@0I7ME00<0PJV106=eDP1SME80501SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00h0EVA500<0PJV104QB>P18DSX02@18DSX00`21ZH40<cHX03<f:00303<f:0<0PJV1Z@2`h>H10?oo
o`00Y`2`h>H3086YP@L0;C0V00<0PJV104I??016Cc`02@16Cc`00`21ZH40EfI;05MVB`0=05MVB`03
086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgEB06=eDP0D06=eDP03
086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03@1FI4D00`21ZH40B58j04QB>P0:04QB>P03
086YP@0c=RP0<cHX00@0<cHX0`21ZH6W0;3PiP40oooo002V0;3PiP<0PJV11`0]<2H00`21ZH40ATll
04I??00904I??003086YP@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04P1QLU<00`21ZH40I7ME
06AgE@0D06AgE@03086YP@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04P1MKD/00`21ZH40EVA5
05ITA@0>05ITA@03086YP@18DSX0B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP3086YPJH0/>3V
0@3oool00:D0/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H00`21ZH40ATll04I??00904I??003086Y
P@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04`1QLU<00`21ZH40I7ME06AgE@0D06AgE@03086Y
P@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04`1MKD/00`21ZH40EVA505ITA@0>05ITA@03086Y
P@18DSX0B58j00T0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6U0;3PiP40
oooo002T0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02P16Cc`00`21ZH40
EfI;05MVB`0>05MVB`03086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD05@1TMeD00`21ZH40
HgEB06=eDP0E06=eDP03086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03P1FI4D00`21ZH40
B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1Y02`h>H10?oo
o`00X`2`h>H01021ZH405QXC01HJ4`21ZH4702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MV
B`1GIT/03P1GIT/00`21ZH40HG9C065bD`0C065bD`03086YP@1TMeD0I7ME01D0I7ME00<0PJV106=e
DP1SME805@1SME800`21ZH40GFe;05e]B`0C05e]B`03086YP@1FI4D0EVA500h0EVA500<0PJV104QB
>P18DSX02P18DSX00`21ZH40<cHX03<f:00403<f:004086YP@0O8QX07b8J086YPJ<0/>3V0@3oool0
0:80/>3V00@0PJV101HJ4`0F6Q<0PJV11`0]<2H00`21ZH40ATll04I??00904I??003086YP@1GIT/0
EfI;00l0EfI;00<0PJV1065bD`1QLU<03P1QLU<k086YPA00GFe;00<0PJV105ITA@1FI4D03`1FI4D0
0`21ZH40B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1XP2`
h>H10?ooo`00XP2`h>H00`21ZH405QXC086YP@0702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV1
05MVB`1GIT/03`1GIT/00`21ZH40HG9C065bD`03065bD``0PJV11@1dSFL00`21ZH40Mi5X07NAJ00E
07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0PJV106n6G@1_QUd00`1_QUd<086YP@D0GFe;00<0PJV1
05ITA@1FI4D03`1FI4D00`21ZH40B58j04QB>P0904QB>P03086YP@0c=RP0<cHX00D0<cHX00<0PJV1
01lR6P21ZH40XP2`h>H10?ooo`00X@2`h>H01021ZH405QXC01HJ4`21ZH4602d`9P03086YP@16Cc`0
ATll00X0ATll00<0PJV105MVB`1GIT/01P1GIT/?086YPA40M8eW00<0PJV107NAJ01gTFP05@1gTFP0
0`21ZH40MHmU07F?I@0E07F?I@03086YP@1_QUd0KhIM00l0KhIM3`21ZH4805ITA@03086YP@18DSX0
B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6Q0;3PiP40oooo002P
0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02016Cc`<086YP@T0K8=Q00<0
PJV107B=I`1dSFL04`1dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0
PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00706=gD0`0PJV12P18DSX00`21ZH40<cHX03<f
:00403<f:004086YP@0O8QX07b8J086YPJ00/>3V0@3oool009l0/>3V00@0PJV101HJ4`0F6Q<0PJV1
1`0]<2H00`21ZH40ATll04I??00304I??0D0PJV10P1LKU@00`21ZH40K8=Q06b3H@0?06b3H@03086Y
P@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40MHmU07F?I@0F07F?I@03086Y
P@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe003`1SMe000`21ZH40EfM705MWA`05086YP@H0B58j
00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6O0;3PiP40oooo002N0;3PiP04086Y
P@0F6Q<05QXC086YP@L0;C0V00<0PJV104I??021ZH401021ZH4605a^E003086YP@1/Pf40K8=Q0100
K8=Q00<0PJV107B=I`1dSFL0501dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0
MHmU00<0PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00@06=gD003086YP@1GIdL0EfM700@0
EfM71@21ZH400`18DSX0PJV103<f:00603<f:004086YP@0O8QX07b8J086YPIh0/>3V0@3oool009d0
/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H4086YP@/0G6iD00<0PJV106b3H@1/Pf40401/Pf400`21
ZH40M8eW07B=I`0D07B=I`03086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107F?I@1eSfD05P1eSfD00`21
ZH40KhIM06n6G@0D06n6G@03086YP@1SMe00HgM@0100HgM@00<0PJV105MWA`1GIdL02@1GIdL4086Y
P@H0<cHX00@0PJV101lR6P0O8QX0PJV1W@2`h>H10?ooo`00W02`h>H01@21ZH405QXC01HJ4`0F6Q<0
PJV100<0;C0V1021ZH4=05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL0501dSFL0
0`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd0501_QUd0
0`21ZH40HgM@06=gD00A06=gD003086YP@1GIdL0EfM700/0EfM71021ZH4303<f:005086YP@0O8QX0
7b8J01lR6P21ZH40W02`h>H10?ooo`00W02`h>H301HJ4`D0PJV10`11Bc`00`21ZH40G6iD05a^E00;
05a^E003086YP@1/Pf40K8=Q0100K8=Q00<0PJV107B=I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00F
07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00@
06=gD003086YP@1GIdL0EfM700/0EfM700@0PJV1049<=P12C3H0@T`f1@21ZH4201lR6P03086YP@2`
h>H0/>3V09X0/>3V0@3oool009/0/>3V0P0F6Q<3086YP@H0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0F07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00@0@T`f0`21ZH400`0O8QX0PJV10;3PiP2J
0;3PiP40oooo002J0;3PiP0401HJ4`21ZH40PJV1086YP@P0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f1021ZH6J0;3PiP40oooo002I0;3P
iP80PJV10P0Q9R000`21ZH40@D/l045;?005045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3
H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086YP@1gTFP0Mi5X01L0Mi5X00<0PJV107F?
I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0E06n6G@03086YP@1SMe00HgM@0140HgM@00<0PJV105MW
A`1GIdL02`1GIdL00`21ZH40@T`f049<=P05049<=P03086YP@0U9ah09BLN0080PJV1V@2`h>H10?oo
o`00V02`h>H01@21ZH408BHP024V800Q9R00PJV100P0@D/l00<0PJV105a^E01LKU@02`1LKU@00`21
ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP00`21
ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe000`21
ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f00D0PJV102DW7P0U9ah09BLN086YP@2H
0;3PiP40oooo002H0;3PiP04086YP@0Q9R008BHP086YP@P0@D/l00<0PJV105a^E01LKU@0301LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0<05MWA`03086YP@12C3H0@T`f00D0@T`f00D0PJV102DW7P0U9ah09BLN086Y
P@2H0;3PiP40oooo002G0;3PiP05086YP@0Q9R008BHP024V8021ZH402011Bc`00`21ZH40G6iD05a^
E00;05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL05P1dSFL00`21ZH40Mi5X07NA
J00G07NAJ003086YP@1eSfD0MHmU01L0MHmU00<0PJV106n6G@1_QUd05P1_QUd00`21ZH40HgM@06=g
D00A06=gD003086YP@1GIdL0EfM700/0EfM700<0PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW
7P0U9ah0PJV109L0/>3V0@3oool009H0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086Y
P@1LKU@0G6iD00`0G6iD00<0PJV106b3H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086Y
P@1gTFP0Mi5X01P0Mi5X00<0PJV107F?I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0F06n6G@03086Y
P@1SMe00HgM@0140HgM@00<0PJV105MWA`1GIdL0301GIdL00`21ZH40@T`f049<=P06049<=P05086Y
P@0U9ah09BLN02DW7P21ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH408BHP024V800Q9R00PJV100P0
@D/l00<0PJV105a^E01LKU@02`1LKU@00`21ZH40K8=Q06b3H@0B06b3H@03086YP@1dSFL0M8eW01D0
M8eW00<0PJV107NAJ01gTFP0601gTFP00`21ZH40MHmU07F?I@0H07F?I@03086YP@1_QUd0KhIM01D0
KhIM00<0PJV106=gD01SMe004P1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0
@T`f00D0PJV102DW7P0U9ah09BLN086YP@2F0;3PiP40oooo002E0;3PiP05086YP@0Q9R008BHP024V
8021ZH402011Bc`00`21ZH40G6iD05a^E00<05a^E003086YP@1/Pf40K8=Q0180K8=Q00<0PJV107B=
I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1eSfD0MHmU01P0MHmU00<0PJV106n6
G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0EfM700`0EfM700<0PJV1049<
=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109D0/>3V0@3oool009@0/>3V00D0PJV1024V
800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf404P1/Pf40
0`21ZH40M8eW07B=I`0:07B=Idl0PJV1301_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0
EfM700/0EfM700<0PJV1049<=P12C3H01`12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3o
ool009@0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086YP@1LKU@0G6iD00`0G6iD00<0
PJV106b3H@1/Pf403@1/Pf4B086YP@`0PZ9g00<0PJV108BTM`24Y7L06024Y7L00`21ZH40PZ9d08:R
M00H08:RM003086YP@1mVfd0OI]]00X0OI]]4P21ZH4?06=gD003086YP@1GIdL0EfM700`0EfM700<0
PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3oool009<0/>3V00D0
PJV1024V800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf40
0`1/Pf4;086YP@D0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03086Y
P@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0307:=H@/0PJV1
1@1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00L0@T`f00D0PJV102DW7P0U9ah0
9BLN086YP@2C0;3PiP40oooo002C0;3PiP04086YP@0Q9R008BHP086YP@T0@D/l00<0PJV105a^E01L
KU@02@1LKU@9086YPA00NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03
086YP@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0>07:=H@T0
PJV12`1GIdL00`21ZH40@T`f049<=P06049<=P05086YP@0U9ah09BLN02DW7P21ZH40T`2`h>H10?oo
o`00TP2`h>H01@21ZH408BHP024V800Q9R00PJV100T0@D/l00@0PJV105a^E01LKU@0G6iD2021ZH43
06j7I`03086YP@1kVG80NiUb0180NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0I
08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0B
07:=H@04086YP@1RMe00HWM@069gD0P0PJV10`1GIdL00`21ZH40@T`f049<=P07049<=P05086YP@0U
9ah09BLN02DW7P21ZH40TP2`h>H10?ooo`00T@2`h>H01@21ZH408BHP024V800Q9R00PJV100L0@D/l
1`21ZH4:06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag
08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ
07:=H@0C07:=H@03086YP@1RMe00HWM@00P0HWM@1`21ZH47049<=P05086YP@0U9ah09BLN02DW7P21
ZH40T@2`h>H10?ooo`00T@2`h>H01P21ZH408BHP024V800Q9R00PJV1045;?0H0PJV10P1DIU400`21
ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21
ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00`0HWM@00<0PJV104iN@01>GT001P21ZH400`12
C3H0PJV102DW7P0202DW7P03086YP@2`h>H0/>3V08l0/>3V0@3oool00900/>3V00@0PJV1024V800Q
9R008BHP0`21ZH4705AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG804`1kVG800`21
ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21
ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21
ZH40CUi004iN@00504iN@0<0PJV10`0U9ah00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP03
086YP@0Q9R008BHP00<0PJV12@1DIU400`21ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0
NiUb00<0PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0
PZ9d00<0PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0<07:=H@80ogl0101bSF400`21ZH40
HWM@069gD00=069gD003086YP@1>GT00CUi000L0CUi00`21ZH4202DW7P03086YP@2`h>H0/>3V08d0
/>3V0@3oool008l0/>3V00D08BHP086YP@21ZH40;C@^086YP@0905AVD@03086YP@1^QfL0KXMW00d0
KXMW00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01T0
Q:Ag00<0PJV108:RM022XW@06@22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ00`0
LXeQ0P3oO`0507:=H@03086YP@1RMe00HWM@00d0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40
;S@U086YP@02086YPHl0/>3V0@3oool008h0/>3V0P21ZH4302dd;P03086YP@1DIU40E6IA00L0E6IA
00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g
00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PZ9d08:RM00I08:RM003086YP@1mVfd0OI]]01L0OI]]
00<0PJV107:=H@1bSF40301bSF420?mo00D0LXeQ00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi0
04iN@00704iN@004086YP@0^=2D0;S@U02hd9@80PJV1SP2`h>H10?ooo`00SP2`h>H01@21ZH40;C@^
02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03
086YP@22XWL0PZ9g01H0PZ9g00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003
086YP@1mVfd0OI]]01H0OI]]00<0PJV107:=H@1bSF40301bSF420?mo00D0LXeQ00<0PJV1069gD01R
Me003P1RMe000`21ZH40CUi004iN@00704iN@003086YP@0^=2D0;S@U0080;S@USP2`h>H10?ooo`00
S@2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3@1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L0
6P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF40
2`1bSF420?mo00H0LXeQ00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@003086Y
P@0^=2D0;S@U0080;S@U00<0PJV10;3PiP2`h>H0R`2`h>H10?ooo`00S@2`h>H01@21ZH40;C@^02dd
;P0]=2h0PJV100X0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086Y
P@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086Y
P@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF40301bSF420?mo00D0LXeQ00<0PJV1069gD01RMe00
3@1RMe000`21ZH40CUi004iN@00804iN@005086YP@0^=2D0;S@U02hd9@21ZH40S@2`h>H10?ooo`00
S02`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L0
6P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01@0OI]]00@0ogl007fKK@1mVfd0
PJV13P1bSF420?mo00D0LXeQ00<0PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@003
086YP@0^=2D0;S@U0080;S@U00<0PJV10;3PiP2`h>H0RP2`h>H10?ooo`00S02`h>H00`21ZH40;C@^
02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40NiUb
07^ILP0D07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PZ9d
08:RM00J08:RM003086YP@1mVfd0OI]]01@0OI]]00@0ogl007fKK@1mVfd0PJV12`1bSF420?mo0003
07:=H@3oO`00ogl00080LXeQ00D0ogl007:=H@1bSF40ogl0086YP@0?069gD003086YP@1>GT00CUi0
00L0CUi000<0PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002<0;3PiP05
086YP@0]=2h0;C@^02dd;P21ZH402@1DIU400`21ZH40KXMW06j7I`0>06j7I`03086YP@1kVG80NiUb
01<0NiUb00<0PJV108:RM`22XWL06022XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d
01X0PZ9d00<0PJV107fKK@1mVfd0501mVfd20?mo0080OI]]00<0PJV107:=H@1bSF401`1bSF420?mo
0080LXeQ0P3oO`000`1bSF40ogl00?mo00050?mo00X0HWM@00<0ogl0069gD03oO`000P1RMe000`21
ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40S02`h>H10?ooo`00R`2`h>H00`21
ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL03P1^QfL00`21
ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0PJV108BTM`24Y7L06P24Y7L00`21
ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01D0OI]]00@0ogl007fKK@1mVfd0PJV12@1bSF42
0?mo0080LXeQ2`3oO`07069gD0D0ogl00P1RMe001@21ZH40CUi004iN@01>GT00ogl000D0CUi000<0
PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP05086YP@0]=2h0
;C@^02dd;P21ZH402P1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0K08BTM`03086YP@22XW@0PZ9d01/0PZ9d00<0
PJV107fKK@1mVfd0501mVfd20?mo000307fKK@21ZH40LXeQ00P0LXeQ0P3oO`0307:=H@<0ogl0101b
SF401021ZH40ogl00?mo003oO`05069gD0L0ogl000@0HWM@086YP@1>GT00CUi00`3oO`0204iN@004
0?mo001>GT00CUi0086YP@<0;S@U00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H00`21ZH40
;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL03P1^QfL00`21ZH40
NiUb07^ILP0D07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06`24Y7L00`21ZH40
PZ9d08:RM00K08:RM003086YP@1mVfd0OI]]01D0OI]]00<0ogl007fKK@21ZH402@1bSF420?mo0080
LXeQ0`3oO`0607:=H@04086YP@3oO`00ogl00?mo00@0HWM@0P3oO`03069gD0<0ogl000@0HWM@086Y
P@1>GT00CUi00P3oO`001`1>GT00ogl00?mo003oO`00CUi0086YP@0^=2D00P3oO`000`21ZH40/>3V
0;3PiP290;3PiP40oooo002:0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU401`1D
IU400`21ZH40KXMW06j7I`0>06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL06022
XWL00`21ZH40Q:Ag08BTM`0=08BTMad0PJV13`22XW@00`21ZH40OI]]07fKK@0E07fKK@80ogl000<0
OI]]086YP@1bSF401`1bSF420?mo00<0LXeQ0P3oO`0607:=H@04086YP@1RMe00ogl00?mo00@0HWM@
0P3oO`04069gD0<0ogl000<0PJV104iN@01>GT000P3oO`0204iN@080ogl000<0CUi0086YP@3oO`00
0`3oO`000`21ZH40ogl00;3PiP280;3PiP40oooo002:0;3PiP05086YP@0]=2h0;C@^02dd;P21ZH40
2@1DIU400`21ZH40KXMW06j7I`0?06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL0
2`22XWLM086YP@h0S[B300<0PJV108faP02=/H00302=/H0M086YP@/0OI]]0P3oO`000`21ZH40LXeQ
07:=H@0607:=H@80ogl00`1bSF420?mo00H0LXeQ00@0PJV1069gD03oO`00ogl0101RMe020?mo00D0
HWM@0`3oO`001021ZH40CUi00?mo003oO`0204iN@080ogl000<0CUi00?mo003oO`001P3oO`280;3P
iP40oooo00290;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU401`1DIU400`21ZH40
KXMW06j7I`0>06j7I`03086YP@1kVG80NiUb00T0NiUb6@21ZH4=08fbQ003086YP@2>]8<0S[B301/0
S[B300<0PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0;08N[N@/0PJV1303oO`02086YP@<0
LXeQ0P3oO`0607:=H@03086YP@3oO`00ogl000@0HWM@0P3oO`06069gD080ogl000<0PJV104iN@03o
O`000P3oO`00101>GT00ogl00?mo001>GT020?mo0080;S@U1@3oO`270;3PiP40oooo00290;3PiP05
086YP@0]=2h0;C@^02dd;P21ZH402@1DIU400`21ZH40KXMW06j7I`0706j7Ia@0PJV12`27Zh000`21
ZH40SK:408fbQ00H08fbQ003086YP@2>]8<0S[B301/0S[B300<0PJV108faP02=/H006`2=/H000`21
ZH40Qj]i08N[N@0G08N[N@/0ogl00P1nWVh3086YP@80ogl01`21ZH430?mo00<0PJV10P3oO`07069g
D080ogl000D0PJV104iN@03oO`00ogl004iN@0060?mo000302hd9@3oO`00ogl000@0ogl0QP2`h>H1
0?ooo`00R@2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100L0E6IA3021ZH4807^KM`03086YP@27Zh00
Qj^001@0Qj^000<0PJV108fbQ02=/X@0602=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00
SK6001/0SK6000<0PJV108N[N@27ZgT05`27ZgT20?mo00L0OYi^0P3oO`0507jNKP80ogl01P1nWVh0
1021ZH40KHQL0?mo003oO`0306f8G080ogl01`21ZH420?mo0080PJV10P3oO`0204iN@0D0ogl00P0^
=2D50?mo08H0/>3V0@3oool008P0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0205AVD@H0PJV10P1T
O6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@0602=
/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06027
ZgT00`3oO`00OYi^07jNKP0507jNKP80ogl01@1nWVh20?mo00H0OYi^00@0PJV106f8G03oO`00ogl0
0`1]R5`20?mo00L0KHQL0P3oO`001021ZH40Efa80?mo003oO`02086YP@80ogl000D0PJV10?mo003o
O`00PJV102hd9@050?mo08H0/>3V0@3oool008P0/>3V00<0PJV102dd;P0]=2h01021ZH4806AlHP03
086YP@1kVgL0Ni]g00h0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003
086YP@2>]8<0S[B301/0S[B300<0PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0H08N[N@80
ogl01P1nWVh20?mo00D0OYi^0P3oO`0707jNKP03086YP@3oO`00ogl000<0KHQL0`3oO`0606f8G080
ogl000@0PJV105M/B03oO`00ogl00P1GK4P20?mo000505M/B03oO`00ogl00?mo0021ZH401P3oO`25
0;3PiP40oooo00270;3PiP06086YP@0]=2h0PJV1086YP@0kB3h0PJV12@1TO6800`21ZH40Ni]g07^K
M`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jd
P`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT00`3oO`00OYi^07jN
KP0307jNKP80ogl01`1nWVh20?mo00H0OYi^00<0PJV10?mo003oO`001@1]R5`00`3oO`00KHQL06f8
G00406f8G080ogl000<0KHQL086YP@3oO`000P3oO`000`1GK4P0ogl00?mo00030?mo0003086YP@0g
@Rh0PJV100H0ogl0Q02`h>H10?ooo`00Q`2`h>H2086YP@80>dPn00<0PJV106AlHP1TO680201TO680
0`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@0
0`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT2
0?mo00@0OYi^0P3oO`0607jNKP<0ogl01P1nWVh00`21ZH40ogl00?mo000506f8G080ogl01@1]R5`2
0?mo000306f8G021ZH40Efa80080ogl00P1GK4P40?mo0003086YP@0g@Rh0=d8^00H0ogl0Q02`h>H1
0?ooo`00Q`2`h>H01@21ZH40>dPn03]8?P0kB3h0PJV100X0I7aR00<0PJV107^KM`1kVgL03`1kVgL0
0`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<06`2>]8<0
0`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV10?mo001nWVh00`1nWVh2
0?mo00L0OYi^0`3oO`0507jNKP03086YP@3oO`00ogl000D0KHQL0`3oO`0406f8G080ogl000<0KHQL
086YP@1GK4P00P3oO`0205M/B0D0ogl000<0PJV103M2;P3oO`001@3oO`240;3PiP40oooo00260;3P
iP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^K
M`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0K08jd
P`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40ogl00?mo000307jN
KP80ogl01`1nWVh50?mo0080OYi^103oO`0606f8G0<0ogl00`1]R5`20?mo000306f8G021ZH40Efa8
0080ogl00P1GK4P30?mo000405M/B03oO`00ogl003M2;PH0ogl0Q02`h>H10?ooo`00QP2`h>H00`21
ZH40>dPn03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21
ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21
ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP3oO`000`1nWVh20?mo
00L0OYi^2P3oO`0806f8G0<0ogl000<0KHQL0?mo003oO`000P3oO`000`21ZH40Efa80?mo00020?mo
0080Efa80P3oO`0205M/B0030?mo000g@Rh0ogl000D0ogl0Q02`h>H10?ooo`00QP2`h>H01@21ZH40
>dPn03]8?P0kB3h0PJV100X0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00E08N[
P003086YP@2=/X@0SK:401P0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00K08fa
P003086YP@27ZgT0Qj]i01T0Qj]i00@0PJV107jNKP3oO`00ogl00P1nWVh20?mo00P0OYi^1`3oO`00
0`1nWVh0PJV106f8G00806f8G0H0ogl00P1]R5`01021ZH40Efa80?mo003oO`0205M/B080ogl00P1G
K4P90?mo08<0/>3V0@3oool008H0/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0:06AlHP03086YP@1k
VgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>
]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@0H08N[N@05086YP@1n
WVh0OYi^0?mo001nWVh00P3oO`0A07jNKP03086YP@1]R5`0KHQL00L0KHQL103oO`0406f8G004086Y
P@1GK4P0ogl00?mo0080Efa80P3oO`0205M/B0@0ogl000<0=d8^0?mo003oO`000P3oO`230;3PiP40
oooo00250;3PiP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g
07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B3
08jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT01021ZH40OYi^
0?mo001nWVh20?mo0140OYi^00<0PJV106f8G01]R5`03`1]R5`01021ZH40Efa80?mo003oO`0205M/
B0<0ogl00P1GK4P30?mo000303M2;P3oO`00ogl00080ogl0P`2`h>H10?ooo`00Q@2`h>H00`21ZH40
>dPn03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40
Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40
SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP3oO`000`3oO`0A07jNKP03
086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B03oO`000P3oO`0205M/B080ogl00P1GK4P30?mo0003
03M2;P3oO`00ogl00080ogl0P`2`h>H10?ooo`00Q@2`h>H01@21ZH40>dPn03]8?P0kB3h0PJV100/0
I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0
SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0
Qj]i00<0PJV107jNKP1nWVh00`3oO`0A07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01G
K4P00P3oO`0205M/B080ogl00P1GK4P01021ZH40=d8^03M2;P0g@Rh50?mo0880/>3V0@3oool008D0
/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0;06AlHP03086YP@1kVgL0Ni]g00h0Ni]g00<0PJV108N[
P027Zh005@27Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108fa
P02=/H00702=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^00<0ogl04P1nWVh00`21
ZH40KHQL06f8G00>06f8G003086YP@1GK4P0Efa80080ogl00P1GK4P20?mo00<0Efa800D0PJV103M2
;P0g@Rh0=d8^086YP@030?mo0880/>3V0@3oool008@0/>3V00<0PJV103]8?P0kB3h00P0kB3h00`21
ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005@27Zh000`21
ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21
ZH40Qj]i08N[N@0I08N[N@04086YP@1nWVh0OYi^07jNKP80ogl04P1nWVh00`21ZH40KHQL06f8G00?
06f8G004086YP@1GK4P0ogl00?mo0080Efa80`3oO`0205M/B003086YP@0g@Rh0=d8^0080=d8^00<0
PJV10?mo002`h>H0PP2`h>H10?ooo`00Q02`h>H00`21ZH40>dPn03]8?P0203]8?P03086YP@1TO680
I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0
SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0
Qj]i01T0Qj]i00<0PJV107jNKP1nWVh00P3oO`0C07jNKP03086YP@1]R5`0KHQL00l0KHQL00@0PJV1
05M/B03oO`00ogl00P1GK4P20?mo00<0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3P
iP220;3PiP40oooo00240;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21ZH40Ni]g07^K
M`0?07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jd
P`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jN
KP0E07jNKP03086YP@1]R5`0KHQL00l0KHQL00@0PJV105M/B03oO`00ogl00P1GK4P20?mo00<0Efa8
00<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP220;3PiP40oooo00240;3PiP05086YP@0k
B3h0>dPn03]8?P21ZH402`1TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^0
00<0PJV108fbQ02=/X@06P2=/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK60
00<0PJV108N[N@27ZgT06P27ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL
00<0PJV105M/B01GK4P00P3oO`000`1GK4P0ogl00?mo000405M/B006086YP@0g@Rh0=d8^03M2;P21
ZH40/>3V0P3oO`210;3PiP40oooo00230;3PiP03086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1T
O6802@1TO6800`21ZH40Ni]g07^KM`0>07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=
/X@06P2=/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27
ZgT06P27ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@1]R5`0KHQL00h0KHQL00<0PJV105M/B01G
K4P02@1GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@3oO`00ogl00840/>3V0@3oool008<0/>3V
00<0PJV103]8?P0kB3h00P0kB3h00`21ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g
00<0PJV108N[P027Zh005@27Zh000`21ZH40SK:408fbQ00<08fbQ5/0PJV13P27ZgT00`21ZH40OYi^
07jNKP0E07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^
03M2;P0203M2;P03086YP@3oO`00ogl00840/>3V0@3oool008<0/>3V00D0PJV103]8?P0kB3h0>dPn
086YP@0;06AlHP03086YP@1kVgL0Ni]g00L0Ni]g;`21ZH4>09JoSP03086YP@2G`8d0Ul2=01`0Ul2=
00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0<092hPbl0PJV12@1]R5`00`21ZH40Efa8
05M/B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10?mo003oO`00P@2`h>H10?ooo`00P`2`
h>H403]8?P03086YP@1TO680I7aR00@0I7aR3`21ZH4808J[P`03086YP@2A^H/0TKV;01D0TKV;00<0
PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0
PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00H0N9QX3`21
ZH4605M/B005086YP@0g@Rh0=d8^03M2;P21ZH40P`2`h>H10?ooo`00PP2`h>H00`21ZH40>dPn03]8
?P09086YP@D0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F
_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@
^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1N
Mdh0GWM>00<0GWM>2@21ZH4203M2;P03086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V0`21ZH42
04QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E
096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L
09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?
07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`21ZH620;3PiP40oooo00220;3P
iP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[
P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0
S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/
N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>
=003086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40
L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40
U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40
T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40
GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00
PP2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<0
3`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0
702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T0
5@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@0
0P0nCS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@18G4h0B5a>0080B5a>00<0
PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0
PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0
PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0
PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V0800/>3V0@3o
ool00840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0
QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0
Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0
?Thd0080?Thd00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0304QL
CP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096i
R`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09Fn
R@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RH
J003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1o0;3P
iP40oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40
QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40
Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40
?Thd03i>=00303i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h0
0`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/0
5@2A^H/00`21ZH40U[n>09JoSP0I09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT0
702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P0
3`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0
O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00P0L8ma00<0
PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0
PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0
PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00>07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0
PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0
B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0
TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0
UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0
N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0
/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?
L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09Jo
SP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092h
P`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905ig
CP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40
B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40
TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40
UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40
N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40
/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg40
2@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh0
6P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<0
6P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh0
2@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0
PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0
PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0
PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P02`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40
L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0
U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0
T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0
GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00200;3P
iP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[
P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0
S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/
N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>
=003086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40
L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40
U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40
T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40
GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00
P02`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<0
3`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0
7@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T0
5@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@0
0`0nCS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@18G4h0B5a>00<0B5a>00<0
PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0
PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0
PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0
PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003086YP@2`h>H0/>3V07h0/>3V0@3o
ool00800/>3Vl`21ZH600;3PiP40oooo00200;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VM
O01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9
UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2
S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3
F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07h0/>3V0@3oool00800
/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0
S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0
WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0
SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0
@eLi00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03059/F`03086Y
P@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086Y
P@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086Y
P@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086Y
P@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n0;3PiP40oooo
00200;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jh
S@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;
U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nh
PP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G
>@0304=G>@03086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV1059/F`1BK5/00`1BK5/0
0`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@0
0`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb980
0`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG80
0`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H1
0?ooo`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jh
S@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;
U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nh
PP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G
>@13EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK0080
DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0
V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0
VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0
P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0
/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086Y
P@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086Y
P@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086Y
P@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086Y
P@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/
F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4
U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8
TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082U
LP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3P
iP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`0
0`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH0
0`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`0
0`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP0
0`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/
F`1BK5/00`1BK5/00`21ZH40NIel07VMO00807VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4
U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8
TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082U
LP20YG803P20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3P
iP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0
NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01T0
W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0
Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0
IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086Y
P@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086Y
P@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086Y
P@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086Y
P@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086Y
P@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VM
O00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9
UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2
S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3
F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H0
0`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d0
0`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD0
0`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^880
0`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT0
0`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VM
O01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9
UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2
S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3
F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V0800/>3V0@3oool00880
/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0
S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0
WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0
SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080
@eLi00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02059/F`03086Y
P@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086Y
P@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086Y
P@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086Y
P@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP200;3PiP40oooo
00220;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jh
S@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;
U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nh
PP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G
>@0204=G>@03086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V0`21ZH42059/F`03086YP@1iWG`0
NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0
W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0
Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0
IX=H00T0IX=H00<0PJV104=G>@13EcT00`21ZH620;3PiP40oooo00220;3PiP03086YP@1IN6@0FGQT
00P0PJV11P1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9
UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2
S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3
F01VPeP0101VPeP8086YP@80AE`l00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00P`2`h>H01@21ZH40
FGQT05UhI01IN6@0PJV100D0OjR53`21ZH4908jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9
UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2
S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00L0P:Eb3`21ZH4506b>
H@03086YP@15G3`0AE`l0080AE`lP`2`h>H10?ooo`00P`2`h>H01@21ZH40FGQT05UhI01IN6@0PJV1
00/0OjR500<0PJV109C2U@2D`YD01P2D`YD`086YP@h0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<00`0Ul:<<021ZH4808J_NP03086YP@1/SV40K8iQ
00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP210;3PiP40oooo00230;3PiP03
086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03
086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd0302RdYeK086YP@h0W<^C00<0PJV109C1RP2D
`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015
G3`00P15G3`00`21ZH40/>3V0;3PiP210;3PiP40oooo00230;3PiP03086YP@1IN6@0FGQT0080FGQT
00<0PJV107nXQ@1oZ8D02@1oZ8D00`21ZH40U<:E09C2U@0>09C2U@03086YP@2NcY/0W/jK01D0W/jK
00<0PJV10:;BW@2RdYd06P2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H
00<0PJV109c;T`2Lbi<06P2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00h0QZmj
00<0PJV106b>H@1/SV402@1/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0840/>3V
0@3oool008@0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00l0U<:E
00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0J0:;BW@03086YP@2Rdi`0X]>L01`0X]>L
00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0J09c;T`03086YP@2D`HX0U<6:01@0U<6:
00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0906b>H@05086YP@15G3`0AE`l04EL?021
ZH40Q02`h>H10?ooo`00Q02`h>H01@21ZH40FGQT05UhI01IN6@0PJV100/0OjR500<0PJV109C2U@2D
`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02R
di`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D
`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015
G3`00P15G3`00`21ZH40/>3V0;3PiP220;3PiP40oooo00240;3PiP03086YP@1IN6@0FGQT0080FGQT
00<0PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK
00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H
00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj
00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0880/>3V
0@3oool008@0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D
`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2R
di`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D
`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15
G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00Q@2`h>H01@21ZH40FGQT05UhI01I
N6@0PJV100/0OjR500<0PJV109C2U@2D`YD03P2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2R
dYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2L
bi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0>08J_NP03086YP@1/
SV40K8iQ00T0K8iQ00D0PJV104EL?015G3`0AE`l086YP@250;3PiP40oooo00250;3PiP05086YP@1I
N6@0FGQT05UhI021ZH402`1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK
00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H
00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj
00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08<0/>3V
0@3oool008D0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D
`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2R
di`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D
`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15
G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q@2`h>H00`21ZH40FGQT05UhI002
05UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D
09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L
0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?
08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP23
0;3PiP40oooo00260;3PiP05086YP@1IN6@0FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?
09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L
0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<0602Lbi<00`21ZH40U<6:09C1RP0E
09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40201/SV401@21ZH40AE`l04EL?015
G3`0PJV108H0/>3V0@3oool008H0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0:07nXQ@03086YP@2D
`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0H0:;BW@03086YP@2R
di`0X]>L01`0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D
`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0706b>H@03086YP@15
G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`h>H00`000000PJV105UhI003
05UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03P2D`YD00`21ZH40W/jK09k>V`0E
09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K
0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0>
08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP24
0;3PiP40oooo00230;3PiP<0000000<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nX
Q@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;B
W@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;
T`03086YP@2D`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>
H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00P`2`h>H400000005
086YP@1IN6@0FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK
01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H
01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj
00l0QZmj00<0PJV106b>H@1/SV40201/SV401@21ZH40AE`l04EL?015G3`0PJV108L0/>3V0@3oool0
08<0/>3V100000001@21ZH40000005UhI01IN6@0PJV100X0OjR500<0PJV109C2U@2D`YD03`2D`YD0
0`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`0
0`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX0
0`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00L0K8iQ00@0PJV104EL?015G3`0AE`l0P21
ZH670;3PiP40oooo00230;3PiPL0000000<0PJV105UhI021ZH402@1oZ8D00`21ZH40U<:E09C2U@0?
09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K
0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D
09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV401`1/SV401P21ZH40AE`l086YP@21
ZH40Af90086YPHL0/>3V0@3oool008H0/>3V1@000004086YP@P0OjR500<0PJV109C2U@2D`YD03P2D
`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2R
di`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D
`HX00`21ZH40QZmj08J_NP0>08J_NP03086YP@1/SV40K8iQ00H0K8iQ1021ZH4204MR@003086YP@2`
h>H0/>3V08H0/>3V0@3oool008H0/>3V1@000000101MP6/0PJV108>_R`23[h/6086YP@80OjR500<0
PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01P0X]:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0
PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00H0PJV10P1`
UVP01@21ZH40Af9004MR@017HT00PJV108P0/>3V0@3oool008H0/>3V1000000305f0J`03086YP@23
[h/0Pjn;00D0Pjn;2`21ZH4909C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd0602R
dYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<0602L
bi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00L0QZmj2`21ZH47072FJ005086YP@17
HT00Af9004MR@021ZH40R@2`h>H10?ooo`00Q`2`h>H3000000<0GH1[00<0PJV108>_R`23[h/01`23
[h/00`21ZH40UlVK09O9V`0609O9VaD0PJV12`2NcY/00`21ZH40X]:M0:;BW@0H0:;BW@03086YP@2R
di`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0H09c;T`03086YP@2D
`HX0U<6:00T0U<6:5@21ZH4808ZfP@03086YP@1`UVP0L9IX00L0L9IX00D0PJV104MR@017HT00Af90
086YP@290;3PiP40oooo00270;3PiP80000000<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_
R`0708>_R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:402@2Qe:4I086YP@d0X]:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C00/0W<^C6@21
ZH4;09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR
@00204MR@003086YP@2`h>H0/>3V08L0/>3V0@3oool008H0/>3V100000001@21ZH40GH1[05f0J`1M
P6/0PJV100T0Pjn;00<0PJV109O9V`2GbI/03`2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2U
fJ<0YMVS00/0YMVS7021ZH4?0:;CW003086YP@2QdIP0XM6H00d0XM6H7021ZH4=0:3BV@03086YP@2H
b900V<R@01<0V<R@00<0PJV108ZfP@2:]X403`2:]X400`21ZH40L9IX072FJ007072FJ005086YP@17
HT00Af9004MR@021ZH40RP2`h>H10?ooo`00QP2`h>H400000003086YP@000000GH1[0080GH1[00<0
PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0>09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0
PJV10:GIX`2UfJ<0602UfJ<00`21ZH40Y]ZR0:KJXP0<0:KJXQl0PJV13P2Tf9h00`21ZH40X=:I0:3B
V@0H0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403P2:]X400`21ZH40L9IX072F
J007072FJ003086YP@17HT00Af900080Af9000<0PJV10;3PiP2`h>H0R02`h>H10?ooo`00Q`2`h>H3
00000003086YP@000000GH1[0080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0>
09O9V`03086YP@2Qe:40XMBQ01@0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0K
0:KJXP03086YP@2Tf9h0Y=RN01/0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00D
09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017
HT00PJV108/0/>3V0@3oool008L0/>3V1P00000205f0J`03086YP@23[h/0Pjn;00P0Pjn;00<0PJV1
09O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7DX@0D0:7DX@03086YP@2UfJ<0YMVS01L0YMVS00<0PJV1
0:KJXP2VfZ806`2VfZ800`21ZH40Y=RN0:CHWP0K0:CHWP03086YP@2PdYT0X=:I01L0X=:I00<0PJV1
09S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00P0L9IX00D0PJV1
04MR@017HT00Af90086YP@2;0;3PiP40oooo00280;3PiP<0000000<0PJV10000001MP6/00P1MP6/0
0`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:404`2Qe:40
0`21ZH40YMVS0:GIX`0H0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:CHWP2Tf9h06P2Tf9h0
0`21ZH40X=:I0:3BV@0H0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403P2:]X40
0`21ZH40L9IX072FJ007072FJ003086YP@17HT00Af900080Af9000<0PJV10;3PiP2`h>H0R@2`h>H1
0?ooo`00R02`h>H600000080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0>09O9
V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<0602UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJ
XP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT0602PdYT00`21ZH40V<R@09S8T00C09S8
T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017HT00
PJV108`0/>3V0@3oool008T0/>3V0`0000000`21ZH40000005f0J`0205f0J`03086YP@23[h/0Pjn;
00L0Pjn;00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7DX@0D0:7DX@03086YP@2UfJ<0YMVS
01L0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40Y=RN0:CHWP0J0:CHWP03086YP@2PdYT0X=:I
01L0X=:I00<0PJV109S8T02Hb900502Hb9000`21ZH40R[J108ZfP@0=08ZfP@03086YP@1`UVP0L9IX
00L0L9IX00<0PJV104MR@017HT000P17HT000`21ZH40/>3V0;3PiP2:0;3PiP40oooo00290;3PiP<0
000000<0PJV10000000000000P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00h0
UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0
Y]ZR00<0PJV10:CHWP2Tf9h06P2Tf9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0
V<R@00<0PJV108ZfP@2:]X403P2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00Af900080
Af9000<0PJV10;3PiP2`h>H0RP2`h>H10?ooo`00R@2`h>H3000000030;3PiP21ZH4000000080GH1[
00<0PJV108>_R`23[h/02023[h/00`21ZH40UlVK09O9V`0=09O9V`03086YP@2Qe:40XMBQ01<0XMBQ
00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN
00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100d0R[J1
00<0PJV1072FJ01`UVP0201`UVP01@21ZH40Af9004MR@017HT00PJV108d0/>3V0@3oool008d0/>3V
00<0PJV10000001MP6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00d0UlVK
00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR
00<0PJV10:CHWP2Tf9h06P2Tf9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@
00<0PJV108ZfP@2:]X403@2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00Af900080Af90
00<0PJV10;3PiP2`h>H0R`2`h>H10?ooo`00SP2`h>H200000080GH1[00<0PJV108>_R`23[h/01`23
[h/00`21ZH40UlVK09O9V`0>09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<05P2U
fJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT05P2P
dYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`
UVP01@21ZH40Af9004MR@017HT00PJV108h0/>3V0@3oool008h0/>3V00<0PJV10000001MP6/00P1M
P6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00d0UlVK00<0PJV10:7DX@2Qe:404`2Q
e:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2T
f9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403@2:
]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00Af900080Af9000<0PJV10;3PiP2`h>H0S02`
h>H10?ooo`00S`2`h>H200000080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0=
09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0I
0:KJXP03086YP@2Tf9h0Y=RN01T0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C
09S8T003086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@002
086YPHl0/>3V0@3oool008l0/>3V00H0PJV100000021ZH40PJV105f0J`21ZH4908>_R`03086YP@2G
bI/0UlVK00`0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2V
fZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2H
b900V<R@0180V<R@00<0PJV108ZfP@2:]X403@2:]X400`21ZH40L9IX072FJ007072FJ006086YP@17
HT00PJV1086YP@19IdD0PJV1S`2`h>H10?ooo`00T02`h>H20000000305j4K@21ZH40PJV10080PJV1
1`23[h/00`21ZH40UlVK09O9V`0=09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<0
5P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN01T0Y=RN00<0PJV10:3BV@2PdYT0
5P2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP0
1@1`UVP4086YP@80BFM500<0PJV10;3PiP2`h>H0SP2`h>H10?ooo`00T@2`h>H01P000000GXA]05j4
K@1NQ6d0PJV108>aS@H0PJV10P23[h/00`21ZH40UlVK09O9V`0<09O9V`03086YP@2Qe:40XMBQ01<0
XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN01T0
Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100`0
R[J100<0PJV1072FJ01`UVP01P21ZH400`1aVV`0PJV104UWA@0204UWA@03086YP@2`h>H0/>3V08l0
/>3V0@3oool00940/>3V00D0000005j4K@1NQ6d0GXA]086YP@0708>aS@H0PJV12`2GbI/00`21ZH40
XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40
Y=RN0:CHWP0I0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8T02Hb9004`2Hb9000`21ZH40
R[J108ZfP@0908ZfP@H0PJV11`1aVV`01@21ZH40BFM504UWA@19IdD0PJV10940/>3V0@3oool00980
/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0908>aS@03086YP@2Hc9h0V<bN00P0PJV1102GbI/00`21
ZH40XMBQ0:7DX@0B0:7DX@03086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21
ZH40Y=RN0:CHWP0I0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8T02Hb9004P2Hb9000`21
ZH40R[J108ZfP@0208ZfP@P0PJV10P2;^XD00`21ZH40LIY/076JK007076JK005086YP@19IdD0BFM5
04UWA@21ZH40TP2`h>H10?ooo`00T`2`h>H01021ZH40GXA]05j4K@21ZH4908>aS@03086YP@2Hc9h0
V<bN00P0V<bN2P21ZH4@0:7DX@03086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ80602VfZ80
0`21ZH40Y=RN0:CHWP0H0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8T02Hb9003P2Hb90:
086YP@X0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109<0/>3V0@3o
ool009<0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0908>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0
PJV10:?IY@2SfJD00`2SfJD;086YP@D0XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJ
XP0H0:KJXP03086YP@2Tf9h0Y=RN01P0Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8
T00309S8T0/0PJV11@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00L0LIY/00D0
PJV104UWA@19IdD0BFM5086YP@2C0;3PiP40oooo002D0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH40
2023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0XmVU00d0XmVU4P21ZH4<0:GIX`03086Y
P@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:CHWP2Tf9h0602Tf9h00`21ZH40X=:I0:3BV@0:0:3BVA80PJV1
3`2Ic9@00`21ZH40RkZ508^jQ@0<08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0
BFM5086YP@2D0;3PiP40oooo002D0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402@23/Hd00`21ZH40
V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0180XmVU00<0PJV10:ONY`2WgZL02P2WgZM?086YP@`0
X]NM00<0PJV109W<U02Ic9@04P2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00L0
LIY/00D0PJV104UWA@19IdD0BFM5086YP@2D0;3PiP40oooo002E0;3PiP05086YP@1NQ6d0GXA]05j4
K@21ZH402023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0XmVU0180XmVU00<0PJV10:ON
Y`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0H0:SOYP03086YP@2Vg:80Y]bR01P0Y]bR00<0PJV10:;G
W@2Reid05@2Reid00`21ZH40VLbD09W<U00B09W<U003086YP@2;^XD0RkZ500`0RkZ500<0PJV1076J
K01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109D0/>3V0@3oool009H0/>3V00D0PJV105j4
K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0PJV10:?IY@2SfJD04P2SfJD0
0`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01P0Z=nV00<0PJV10:KLXP2Vg:80602Vg:80
0`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0180VLbD00<0PJV108^jQ@2;^XD02`2;^XD0
0`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40UP2`h>H10?ooo`00UP2`h>H0
1@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h0302Hc9h00`21ZH40XmVU0:?I
Y@0A0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SOYP2XgjH0602XgjH00`21ZH40Y]bR0:KL
XP0G0:KLXP03086YP@2Reid0X]NM01H0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^j
Q@0<08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2F0;3PiP40oooo
002G0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402023/Hd00`21ZH40V<bN09S<WP0;09S<WP03086Y
P@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL05P2WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086Y
P@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid05P2Reid00`21ZH40VLbD09W<U00A09W<U003086Y
P@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109L0
/>3V0@3oool009P0/>3V00@0PJV105j4K@1NQ6d0PJV12023/Hd00`21ZH40V<bN09S<WP0<09S<WP03
086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03
086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00A09W<U003
086YP@2;^XD0RkZ500`0RkZ500<0PJV1076JK01aVV`01@1aVV`01@21ZH40BFM504UWA@19IdD0PJV1
09P0/>3V0@3oool009P0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN
00/0V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV
01L0Z=nV00<0PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD
0140VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM5
04UWA@21ZH40V02`h>H10?ooo`00V@2`h>H2086YP@80GXA]00<0PJV108>aS@23/Hd01@23/Hd00`21
ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21
ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21
ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01@1aVV`00`21
ZH40BFM504UWA@02086YPIT0/>3V0@3oool009X0/>3V1021ZH4808>aS@03086YP@2Hc9h0V<bN00/0
V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01L0
Z=nV00<0PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD0140
VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK006076JK0@0PJV1VP2`h>H10?ooo`00
V`2`h>H00`21ZH40Fh9/086YP@02086YP@H0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU
0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR
0:KLXP0F0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ5
08^jQ@0;08^jQ@03086YP@1aVV`0LIY/00@0LIY/0`21ZH400`18JDP0PJV10;3PiP2J0;3PiP40oooo
002L0;3PiP03086YP@1KPV`0Fh9/00@0PJV11023/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2S
fJD0XmVU0100XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2V
g:80Y]bR01H0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00@09W<U003086YP@2;
^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`00P1aVV`4086YP@80B6U800<0PJV10;3PiP2`h>H0VP2`
h>H10?ooo`00W02`h>H01@21ZH40Fh9/05^2K01KPV`0PJV10080OZj;1@21ZH4=09S<WP03086YP@2S
fJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL0502WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2V
g:80Y]bR01H0Y]bR00<0PJV10:;GW@2Reid0502Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;
^XD0RkZ500/0RkZ51@21ZH4206jIK005086YP@18JDP0B6U804QYB021ZH40W02`h>H10?ooo`00W@2`
h>H01021ZH40Fh9/05^2K021ZH4607j^R`@0PJV12`2Hc9h00`21ZH40XmVU0:?IY@0@0:?IY@03086Y
P@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086Y
P@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@0402Ic9@00`21ZH40RkZ508^jQ@0908^jQ@@0PJV1
1P1^VF`01021ZH40B6U804QYB021ZH6M0;3PiP40oooo002N0;3PiP04086YP@1KPV`0Fh9/086YP@L0
OZj;00<0PJV109C:W@21ZH401021ZH4609S<WP03086YP@2SfJD0XmVU0100XmVU00<0PJV10:ONY`2W
gZL0502WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV10:;GW@2R
eid0502Reid00`21ZH40VLbD09W<U00@09W<U003086YP@2;^XD0RkZ500@0RkZ51@21ZH400`28^HD0
PJV106jIK00606jIK004086YP@18JDP0B6U8086YPIh0/>3V0@3oool009l0/>3V00@0PJV105^2K01K
PV`0PJV11`1n[X/00`21ZH40U<ZM09C:W@0309C:W@D0PJV10P2Hc9h00`21ZH40XmVU0:?IY@0?0:?I
Y@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KL
XP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@03`2Ic9@00`21ZH40RkZ508^jQ@05086Y
P@H0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6O0;3PiP40oooo002P0;3P
iP04086YP@1KPV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2DbYd0202DbYd<086YP@T0XmVU00<0PJV1
0:ONY`2WgZL04`2WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01D0Y]bR00<0PJV1
0:;GW@2Reid0502Reid00`21ZH40VLbD09W<U00709W<U0`0PJV12P28^HD00`21ZH40KYU/06jIK004
06jIK004086YP@18JDP0B6U8086YPJ00/>3V0@3oool00:40/>3V00@0PJV105^2K01KPV`0PJV11P1n
[X/00`21ZH40U<ZM09C:W@0:09C:W@03086YP@2Pf:D0X=RU00H0X=RU3`21ZH4A0:ONY`03086YP@2X
gjH0Z=nV01D0Z=nV00<0PJV10:KLXP2Vg:805@2Vg:800`21ZH40X]NM0:;GW@0?0:;GW@l0PJV1202H
cID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1
X@2`h>H10?ooo`00XP2`h>H00`21ZH40Fh9/086YP@0707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0
PJV10:3HY@2Pf:D03`2Pf:D00`21ZH40Y]jX0:KNZ0030:KNZ0`0PJV11@2WgZL00`21ZH40Z=nV0:SO
YP0E0:SOYP03086YP@2Vg:80Y]bR01D0Y]bR00<0PJV10:;GW@2Reid00`2Reid<086YP@D0XMRN00<0
PJV109S=U@2HcID03`2HcID00`21ZH40R;V508RiQ@0908RiQ@03086YP@1^VF`0KYU/00D0KYU/00<0
PJV104QYB021ZH40XP2`h>H10?ooo`00XP2`h>H01021ZH40Fh9/05^2K021ZH4707j^R`03086YP@2D
bYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03`2Pf:D00`21ZH40Y]jX0:KNZ00>0:KNZ3/0PJV1402Q
f9h00`21ZH40V<fE09S=U@0?09S=U@03086YP@28^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^
VF`01021ZH40B6U804QYB021ZH6R0;3PiP40oooo002S0;3PiP04086YP@1KPV`0Fh9/086YP@L0OZj;
00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX01<0Y]jX
00<0PJV10:OPY`2Wh:L05@2Wh:L00`21ZH40Y]jT0:KNY00E0:KNY003086YP@2Qf9h0XMRN01<0XMRN
00<0PJV109S=U@2HcID03P2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/
00@0PJV104QYB018JDP0PJV1X`2`h>H10?ooo`00Y02`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03
086YP@2DbYd0U<ZM00X0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00B0:KNZ003
086YP@2Wh:L0Yn2W01D0Yn2W00<0PJV10:KNY02VgZ@05@2VgZ@00`21ZH40XMRN0:7HWP0B0:7HWP03
086YP@2HcID0V<fE00h0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK00406jIK004
086YP@18JDP0B6U8086YPJ@0/>3V0@3oool00:D0/>3V00@0PJV105^2K01KPV`0PJV11P1n[X/00`21
ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04`2VgZP00`21
ZH40Yn2W0:OPY`0D0:OPY`03086YP@2VgZ@0Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04`2Qf9h00`21
ZH40V<fE09S=U@0>09S=U@03086YP@28^HD0R;V500T0R;V500<0PJV106jIK01^VF`0101^VF`01021
ZH40B6U804QYB021ZH6U0;3PiP40oooo002V0;3PiP<0PJV11`1n[X/00`21ZH40U<ZM09C:W@0909C:
W@03086YP@2Pf:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04P2VgZP00`21ZH40Yn2W0:OPY`0D0:OP
Y`03086YP@2VgZ@0Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0>09S=
U@03086YP@28^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`3086YPJH0/>3V0@3oool00:L0
/>3V0`21ZH4707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21ZH40
Y]jX0:KNZ00B0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@0502VgZ@00`21ZH40
XMRN0:7HWP0B0:7HWP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40
KYU/06jIK00406jIK0<0PJV1Y`2`h>H10?ooo`00Z@2`h>H3086YP@H0OZj;00<0PJV109C:W@2DbYd0
202DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L0
502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0XMRN0140XMRN00<0PJV109S=U@2HcID0
3P2HcID00`21ZH40R;V508RiQ@0908RiQ@03086YP@1^VF`0KYU/00<0KYU/0`21ZH6Y0;3PiP40oooo
002Z0;3PiPD0PJV10`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU00d0X=RU00<0
PJV10:KNZ02VgZP04@2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2VgZ@0Y]jT01<0Y]jT00<0
PJV10:7HWP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28^HD0R;V500T0R;V500@0
PJV106jIK01^VF`0KYU/1@21ZH6Z0;3PiP40oooo002[0;3PiP04086YP@1DNfH0PJV107BTP`D0PJV1
2`2DbYd00`21ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L0
4`2Wh:L00`21ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0140XMRN00<0PJV109S=U@2HcID0
3@2HcID00`21ZH40R;V508RiQ@0:08RiQ@@0PJV100@0IY5X086YP@14IDP0PJV1Z`2`h>H10?ooo`00
[02`h>H3086YP@@0M:B31@21ZH4809C:W@03086YP@2Pf:D0X=RU00`0X=RU00<0PJV10:KNZ02VgZP0
4@2VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2VgZ@0Y]jT01<0Y]jT00<0PJV10:7HWP2Qf9h0
4@2Qf9h00`21ZH40V<fE09S=U@0<09S=U@03086YP@28^HD0R;V500L0R;V51@21ZH4306JAJ0<0PJV1
[02`h>H10?ooo`00[P2`h>H3086YP@@0M:B300<0PJV108_0UP2;`9H01P21ZH4209C:W@03086YP@2P
f:D0X=RU00d0X=RU00<0PJV10:KNZ02VgZP0402VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2V
gZ@0Y]jT01<0Y]jT00<0PJV10:7HWP2Qf9h0402Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28
^HD0R;V500L0PJV10P1o/H401021ZH40IY5X06JAJ01VTFP3086YPJh0/>3V0@3oool00:l0/>3V00<0
PJV105AkIP21ZH40101dY8<00`21ZH40Rl2F08_0UP0508_0UPL0PJV12`2Pf:D00`21ZH40Y]jX0:KN
Z00@0:KNZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7H
WP0@0:7HWP03086YP@2HcID0V<fE00T0V<fE1`21ZH4807naP@07086YP@1VTFP0IY5X06JAJ021ZH40
A6E8086YP@2_0;3PiP40oooo002`0;3PiP03086YP@1DNfH0PJV100@0M:B300<0PJV108_0UP2;`9H0
202;`9H00`21ZH40V=6P09SAX008086YP@@0X=RU00<0PJV10:KNZ02VgZP0402VgZP00`21ZH40Yn2W
0:OPY`0B0:OPY`03086YP@2VgZ@0Y]jT0180Y]jT00<0PJV10:7HWP2Qf9h0402Qf9h00`21ZH40V<fE
09S=U@0209S=U@P0PJV10P2@aY400`21ZH40Ok6107naP@0807naP@80PJV10`1VTFP00`21ZH40A6E8
086YP@2`0;3PiP40oooo002a0;3PiP@0PJV10`1dY8<00`21ZH40Rl2F08_0UP0808_0UP03086YP@2H
dJ00V=6P00L0V=6P3P21ZH490:KNZ003086YP@2Wh:L0Yn2W0180Yn2W00<0PJV10:KNY02VgZ@04P2V
gZ@00`21ZH40XMRN0:7HWP070:7HWPh0PJV12@2@aY400`21ZH40Ok6107naP@0807naP@04086YP@1V
TFP0IY5X06JAJ0@0PJV1/@2`h>H10?ooo`00/`2`h>H00`21ZH40E7]V086YP@0307BTP`03086YP@2;
`9H0Rl2F00P0Rl2F00<0PJV109SAX02HdJ002`2HdJ000`21ZH40WmVU09oIY@0609oIYCd0PJV1202J
dY`00`21ZH40T<JA0936T@0;0936T@03086YP@1o/H40Ok6100P0Ok6100L0PJV106JAJ01VTFP0IY5X
086YP@14IDP0PJV10;<0/>3V0@3oool00;@0/>3V0`21ZH4307BTP`80PJV12@2;`9H00`21ZH40V=6P
09SAX00:09SAX003086YP@2OfJD0WmVU00l0WmVU00<0PJV10:7KY@2QfjD04P2QfjD00`21ZH40X=VR
0:3IXP0B0:3IXP03086YP@2JdY`0V]:L00l0V]:L00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok61
07naP@0807naP@04086YP@1VTFP0IY5X06JAJ0<0PJV1]02`h>H10?ooo`00]@2`h>H4086YP@<0M:B3
00<0PJV108_0UP2;`9H01`2;`9H00`21ZH40V=6P09SAX00:09SAX003086YP@2OfJD0WmVU00l0WmVU
00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40X=VR0:3IXP0A0:3IXP03086YP@2JdY`0V]:L00l0V]:L
00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok6107naP@0807naP@03086YP@1VTFP0IY5X00@0PJV1
]@2`h>H10?ooo`00]`2`h>H4086YP@80M:B300<0PJV108_0UP2;`9H01P2;`9H00`21ZH40V=6P09SA
X00;09SAX003086YP@2OfJD0WmVU00h0WmVU00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40X=VR0:3I
XP0A0:3IXP03086YP@2JdY`0V]:L00h0V]:L00<0PJV10936T@2@aY402`2@aY400`21ZH40Ok6107na
P@0607naP@80PJV100<0IY5X086YP@21ZH400P21ZH6g0;3PiP40oooo002i0;3PiP@0PJV100<0M:B3
086YP@2;`9H01`2;`9H00`21ZH40V=6P09SAX00;09SAX003086YP@2OfJD0WmVU00d0WmVU00<0PJV1
0:7KY@2QfjD04@2QfjD00`21ZH40X=VR0:3IXP0A0:3IXP03086YP@2JdY`0V]:L00d0V]:L00<0PJV1
0936T@2@aY402`2@aY400`21ZH40Ok6107naP@0607naP@03086YP@1VTFP0PJV100<0PJV1^@2`h>H1
0?ooo`00^`2`h>H5086YP@P0Rl2F00<0PJV109SAX02HdJ002P2HdJ000`21ZH40WmVU09oIY@0>09oI
Y@03086YP@2QfjD0XM^U0100XM^U00<0PJV10:3IXP2PfJ80402PfJ800`21ZH40V]:L09[BW00>09[B
W003086YP@2@aY40T<JA00X0T<JA00<0PJV107naP@1o/H401P1o/H45086YPK/0/>3V0@3oool00;`0
/>3V1`21ZH4608_0UP03086YP@2HdJ00V=6P00X0V=6P00<0PJV109oIY@2OfJD03@2OfJD00`21ZH40
XM^U0:7KY@0@0:7KY@03086YP@2PfJ80X=VR0100X=VR00<0PJV109[BW02JdY`03@2JdY`00`21ZH40
T<JA0936T@0:0936T@03086YP@1o/H40Ok6100@0Ok611`21ZH6l0;3PiP40oooo002n0;3PiP/0PJV1
00<0Rl2F086YP@2HdJ002`2HdJ000`21ZH40WmVU09oIY@0=09oIY@03086YP@2QfjD0XM^U00l0XM^U
00<0PJV10:3IXP2PfJ803`2PfJ800`21ZH40V]:L09[BW00=09[BW003086YP@2@aY40T<JA00X0T<JA
00<0PJV107naP@21ZH402P21ZH6n0;3PiP40oooo00300;3PiPD0PJV1101j[HP6086YP@T0V=6P00<0
PJV109oIY@2OfJD0302OfJD00`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2PfJ80X=VR00l0X=VR00<0
PJV109[BW02JdY`0302JdY`00`21ZH40T<JA0936T@070936T@H0PJV1101`X7H5086YPL00/>3V0@3o
ool00<80/>3V0P21ZH400`1TTWD0PJV1086YP@0507Z]R080PJV100<0R;jC086YP@21ZH401@21ZH42
09SAX003086YP@2OfJD0WmVU00`0WmVU00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40X=VR0:3IXP0?
0:3IXP03086YP@2JdY`0V]:L00`0V]:L00<0PJV10936T@2@aY401`21ZH400`21]HH0PJV1086YP@05
072PMP80PJV100<0FH9O086YP@21ZH40`P2`h>H10?ooo`00a02`h>H2086YP@0306BBM@21ZH40NZf8
00D0NZf800<0PJV108RnT`28_Y<01@28_Y<;086YP@L0WmVU00<0PJV10:7KY@2QfjD03P2QfjD00`21
ZH40X=VR0:3IXP0>0:3IXP03086YP@2JdY`0V]:L00D0V]:L2`21ZH47086eQP03086YP@1`X7H0L:1f
00@0L:1f00@0PJV105V2G`21ZH40PJV1a02`h>H10?ooo`00a@2`h>H5086YP@D0NZf80P21ZH4908Rn
T`03086YP@2@b9T0T<RI00@0T<RI<@21ZH4608c3T@03086YP@21]HH0PKF600L0PKF60P21ZH45072P
MPD0PJV1a@2`h>H10?ooo`00a`2`h>H5086YP@D0NZf800<0PJV108RnT`28_Y<01`28_Y<00`21ZH40
T<RI0938V@0;0938V@03086YP@2Cc9/0TlbK00d0TlbK00<0PJV109;:V02BbYP03@2BbYP00`21ZH40
S<>A08c3T@0;08c3T@03086YP@21]HH0PKF600L0PKF600<0PJV1072PMP1`X7H00`1`X7H5086YPLL0
/>3V0@3oool00<X0/>3V1021ZH4407Z]R080PJV12028_Y<00`21ZH40T<RI0938V@0:0938V@03086Y
P@2Cc9/0TlbK00d0TlbK00<0PJV109;:V02BbYP03@2BbYP00`21ZH40S<>A08c3T@0:08c3T@03086Y
P@21]HH0PKF600H0PKF60P21ZH44072PMP@0PJV1bP2`h>H10?ooo`00c@2`h>H4086YP@<0NZf800<0
PJV108RnT`28_Y<01P28_Y<2086YP@/0T<RI00<0PJV109?<V`2Cc9/0302Cc9/00`21ZH40T/ZH09;:
V00<09;:V003086YP@2<`i40S<>A00T0S<>A0P21ZH48086eQP04086YP@1`X7H0L:1f072PMP@0PJV1
c@2`h>H10?ooo`00d02`h>H7086YP@P0R;jC00<0PJV10938V@2@b9T02@2@b9T00`21ZH40TlbK09?<
V`0;09?<V`03086YP@2BbYP0T/ZH00/0T/ZH00<0PJV108c3T@2<`i402@2<`i400`21ZH40PKF6086e
QP06086eQPL0PJV1d02`h>H10?ooo`00d`2`h>H9086YP@@0R;jC00<0PJV10938V@2@b9T02@2@b9T0
0`21ZH40TlbK09?<V`0:09?<V`03086YP@2BbYP0T/ZH00X0T/ZH00<0PJV108c3T@2<`i402@2<`i40
0`21ZH40PKF6086eQP02086eQPT0PJV1d`2`h>H10?ooo`00eP2`h>HA086YP@D0T<RI00<0PJV109?<
V`2Cc9/02P2Cc9/00`21ZH40T/ZH09;:V00:09;:V003086YP@2<`i40S<>A00<0S<>A2`21ZH400`1X
Ug80PJV1086YP@03086YPMH0/>3V0@3oool00=T0/>3V1@21ZH4406fNO080PJV10`1eZ88U086YP@<0
LZAl0P21ZH4406RGLPD0PJV1f@2`h>H10?ooo`00g02`h>H5086YP@<0KIil0P21ZH4807FXPP03086Y
P@1h[8@0N:b400P0N:b400<0PJV107N[PP1gZh80201gZh800`21ZH40LZAl07:TO00607:TO080PJV1
0`1XUg85086YPM`0/>3V0@3oool00>00/>3V2021ZH4707FXPP03086YP@1h[8@0N:b400L0N:b400<0
PJV107N[PP1gZh801`1gZh800`21ZH40LZAl07:TO00507:TO0P0PJV1h02`h>H10?ooo`00iP2`h>H7
086YP@<0MJR200<0PJV107R/Q01h[8@01P1h[8@00`21ZH40Mj^207N[PP0607N[PP04086YP@1bY7`0
LZAl07:TO0L0PJV1iP2`h>H10?ooo`00k@2`h>HI086YPNd0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.608 .781 .571 r
.47008 .46971 m .46978 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.608 .781 .571 r
.51009 .5 m .50999 .46977 L .47008 .46971 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.50999 .53023 m .51009 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.50999 .46977 m .51009 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.51009 .5 m .50999 .53023 L .5497 .53041 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.5497 .53041 m .5502 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.43078 .46941 m .43007 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.46978 .5 m .47008 .46971 L .43078 .46941 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.47008 .53029 m .46978 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.46978 .5 m .47008 .53029 L .50999 .53023 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.471 .43976 m .47008 .46971 L .50999 .46977 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.50999 .46977 m .50968 .43988 L .471 .43976 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.50968 .56012 m .50999 .53023 L .47008 .53029 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.50968 .43988 m .50999 .46977 L .5497 .46959 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.5502 .5 m .5497 .46959 L .50999 .46977 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.50999 .53023 m .50968 .56012 L .54817 .56047 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.54817 .56047 m .5497 .53041 L .50999 .53023 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.43291 .43918 m .43078 .46941 L .47008 .46971 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.47008 .46971 m .471 .43976 L .43291 .43918 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.43007 .5 m .43078 .53059 L .47008 .53029 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.471 .56024 m .47008 .53029 L .43078 .53059 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.47008 .53029 m .471 .56024 L .50968 .56012 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.5497 .46959 m .5502 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.5502 .5 m .5497 .53041 L .58839 .53084 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.58839 .53084 m .58931 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.5497 .46959 m .54817 .43953 L .50968 .43988 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.54817 .43953 m .5497 .46959 L .58839 .46916 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.58931 .5 m .58839 .46916 L .5497 .46959 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.5497 .53041 m .54817 .56047 L .58564 .56129 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.58564 .56129 m .58839 .53084 L .5497 .53041 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.47252 .41051 m .471 .43976 L .50968 .43988 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.50968 .43988 m .50918 .41067 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.50918 .41067 m .50968 .43988 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.50918 .58933 m .50968 .56012 L .471 .56024 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.50968 .56012 m .50918 .58933 L .54563 .58982 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51183 .56014 m
.51308 .56293 L
s
.5 Mabswid
.555 .699 .51 r
.54563 .58982 m .54817 .56047 L .50968 .56012 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4664 .55956 m
.47055 .56131 L
s
.47055 .56131 m
.47476 .56478 L
s
.46029 .55963 m
.4664 .55956 L
s
.5 Mabswid
.627 .816 .595 r
.43648 .40968 m .43291 .43918 L .471 .43976 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.471 .43976 m .47252 .41051 L .43648 .40968 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.43078 .53059 m .43291 .56082 L .471 .56024 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.47252 .58949 m .471 .56024 L .43291 .56082 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.471 .56024 m .47252 .58949 L .50918 .58933 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.39291 .46886 m .39179 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.43007 .5 m .43078 .46941 L .39291 .46886 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.43078 .53059 m .43007 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.39627 .43812 m .39291 .46886 L .43078 .46941 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.43078 .46941 m .43291 .43918 L .39627 .43812 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.39179 .5 m .39291 .53114 L .43078 .53059 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.43291 .56082 m .43078 .53059 L .39291 .53114 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.54817 .43953 m .54563 .41018 L .50918 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.54563 .41018 m .54817 .43953 L .58564 .43871 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.58839 .46916 m .58564 .43871 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.54817 .56047 m .54563 .58982 L .58106 .59098 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.58106 .59098 m .58564 .56129 L .54817 .56047 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.46182 .58255 m
.46291 .58254 L
s
.4536 .57816 m
.45778 .58113 L
s
.45778 .58113 m
.46182 .58255 L
s
.5 Mabswid
.606 .779 .582 r
.58839 .46916 m .58931 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.58931 .5 m .58839 .53084 L .62519 .53151 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.62519 .53151 m .62652 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.47466 .38233 m .47252 .41051 L .50918 .41067 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.50918 .41067 m .50846 .38253 L .47466 .38233 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.50846 .38253 m .50918 .41067 L .54563 .41018 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.50846 .61747 m .50918 .58933 L .47252 .58949 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.50918 .58933 m .50846 .61747 L .54206 .61807 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.54206 .61807 m .54563 .58982 L .50918 .58933 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.40187 .4082 m .39627 .43812 L .43291 .43918 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.43291 .43918 m .43648 .40968 L .40187 .4082 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.39291 .53114 m .39627 .56188 L .43291 .56082 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.43648 .59032 m .43291 .56082 L .39627 .56188 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.43291 .56082 m .43648 .59032 L .47252 .58949 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.44147 .38133 m .43648 .40968 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.47252 .41051 m .47466 .38233 L .44147 .38133 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.58564 .43871 m .58839 .46916 L .62519 .46849 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.62652 .5 m .62519 .46849 L .58839 .46916 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.58839 .53084 m .58564 .56129 L .62122 .56259 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.62122 .56259 m .62519 .53151 L .58839 .53084 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.47466 .61767 m .47252 .58949 L .43648 .59032 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.47252 .58949 m .47466 .61767 L .50846 .61747 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.54563 .41018 m .54206 .38193 L .50846 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.54206 .38193 m .54563 .41018 L .58106 .40902 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.58564 .43871 m .58106 .40902 L .54563 .41018 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.54563 .58982 m .54206 .61807 L .57465 .61947 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.57465 .61947 m .58106 .59098 L .54563 .58982 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.42524 .5835 m
.42676 .58345 L
s
.5 Mabswid
.634 .826 .619 r
.58106 .40902 m .58564 .43871 L .62122 .43741 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.62519 .46849 m .62122 .43741 L .58564 .43871 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.58564 .56129 m .58106 .59098 L .61461 .59279 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.61461 .59279 m .62122 .56259 L .58564 .56129 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.35742 .46806 m .35589 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.39179 .5 m .39291 .46886 L .35742 .46806 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.39291 .53114 m .39179 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.40969 .37953 m .40187 .4082 L .43648 .40968 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.43648 .40968 m .44147 .38133 L .40969 .37953 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.39627 .56188 m .40187 .5918 L .43648 .59032 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.44147 .61867 m .43648 .59032 L .40187 .5918 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.43648 .59032 m .44147 .61867 L .47466 .61767 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.36201 .43659 m .35742 .46806 L .39291 .46886 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.39291 .46886 m .39627 .43812 L .36201 .43659 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.35589 .5 m .35742 .53194 L .39291 .53114 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.39627 .56188 m .39291 .53114 L .35742 .53194 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.47742 .35564 m .47466 .38233 L .50846 .38253 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.50846 .38253 m .50754 .35586 L .47742 .35564 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.50754 .64414 m .50846 .61747 L .47466 .61767 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.50754 .35586 m .50846 .38253 L .54206 .38193 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.50846 .61747 m .50754 .64414 L .53747 .64479 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.53747 .64479 m .54206 .61807 L .50846 .61747 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.44788 .35455 m .44147 .38133 L .47466 .38233 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.47466 .38233 m .47742 .35564 L .44788 .35455 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.47742 .64436 m .47466 .61767 L .44147 .61867 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.47466 .61767 m .47742 .64436 L .50754 .64414 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.36963 .40606 m .36201 .43659 L .39627 .43812 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.39627 .43812 m .40187 .4082 L .36963 .40606 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.35742 .53194 m .36201 .56341 L .39627 .56188 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.40187 .5918 m .39627 .56188 L .36201 .56341 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.58106 .40902 m .57465 .38053 L .54206 .38193 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.57465 .38053 m .58106 .40902 L .61461 .40721 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.62122 .43741 m .61461 .40721 L .58106 .40902 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.58106 .59098 m .57465 .61947 L .60538 .62166 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.60538 .62166 m .61461 .59279 L .58106 .59098 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.54206 .38193 m .53747 .35521 L .50754 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.53747 .35521 m .54206 .38193 L .57465 .38053 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.54206 .61807 m .53747 .64479 L .56643 .64632 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.56643 .64632 m .57465 .61947 L .54206 .61807 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.62519 .46849 m .62652 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.62652 .5 m .62519 .53151 L .6591 .53242 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.6591 .53242 m .66083 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.40719 .59571 m
.40737 .59553 L
s
.4051 .59445 m
.40537 .59418 L
s
.5 Mabswid
.61 .792 .598 r
.62122 .43741 m .62519 .46849 L .6591 .46758 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.66083 .5 m .6591 .46758 L .62519 .46849 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.62519 .53151 m .62122 .56259 L .6539 .56435 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.6539 .56435 m .6591 .53242 L .62519 .53151 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4051 .59445 m
.40719 .59571 L
s
.5 Mabswid
.636 .838 .612 r
.41972 .3526 m .40969 .37953 L .44147 .38133 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.44147 .38133 m .44788 .35455 L .41972 .3526 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.40187 .5918 m .40969 .62047 L .44147 .61867 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.44788 .64545 m .44147 .61867 L .40969 .62047 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.44147 .61867 m .44788 .64545 L .47742 .64436 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.38025 .37696 m .36963 .40606 L .40187 .4082 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.40187 .4082 m .40969 .37953 L .38025 .37696 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.36201 .56341 m .36963 .59394 L .40187 .5918 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.40969 .62047 m .40187 .5918 L .36963 .59394 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.61461 .40721 m .62122 .43741 L .6539 .43565 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.6591 .46758 m .6539 .43565 L .62122 .43741 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.62122 .56259 m .61461 .59279 L .64528 .59525 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.64528 .59525 m .6539 .56435 L .62122 .56259 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.57465 .38053 m .56643 .35368 L .53747 .35521 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.56643 .35368 m .57465 .38053 L .60538 .37834 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.61461 .40721 m .60538 .37834 L .57465 .38053 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.57465 .61947 m .56643 .64632 L .59358 .6487 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.59358 .6487 m .60538 .62166 L .57465 .61947 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.3254 .46703 m .32346 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.35589 .5 m .35742 .46806 L .3254 .46703 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.35742 .53194 m .35589 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.48078 .33093 m .47742 .35564 L .50754 .35586 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.50754 .35586 m .50642 .33115 L .48078 .33093 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.50642 .66885 m .50754 .64414 L .47742 .64436 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.50642 .33115 m .50754 .35586 L .53747 .35521 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.50754 .64414 m .50642 .66885 L .53187 .6695 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.53187 .6695 m .53747 .64479 L .50754 .64414 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.33119 .4346 m .3254 .46703 L .35742 .46806 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.35742 .46806 m .36201 .43659 L .33119 .4346 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.32346 .5 m .3254 .53297 L .35742 .53194 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.36201 .56341 m .35742 .53194 L .3254 .53297 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.4557 .32985 m .44788 .35455 L .47742 .35564 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.47742 .35564 m .48078 .33093 L .4557 .32985 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.48078 .66907 m .47742 .64436 L .44788 .64545 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.47742 .64436 m .48078 .66907 L .50642 .66885 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.60538 .37834 m .61461 .40721 L .64528 .40475 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.6539 .43565 m .64528 .40475 L .61461 .40721 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.61461 .59279 m .60538 .62166 L .6333 .62462 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.6333 .62462 m .64528 .59525 L .61461 .59279 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.53747 .35521 m .53187 .3305 L .50642 .33115 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.53187 .3305 m .53747 .35521 L .56643 .35368 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.53747 .64479 m .53187 .6695 L .55641 .67102 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.55641 .67102 m .56643 .64632 L .53747 .64479 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.39379 .3498 m .38025 .37696 L .40969 .37953 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.40969 .37953 m .41972 .3526 L .39379 .3498 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.36963 .59394 m .38025 .62304 L .40969 .62047 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.41972 .6474 m .40969 .62047 L .38025 .62304 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.40969 .62047 m .41972 .6474 L .44788 .64545 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.3254 .53297 m .33119 .5654 L .36201 .56341 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.36963 .59394 m .36201 .56341 L .33119 .5654 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.34079 .40328 m .33119 .4346 L .36201 .43659 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.36201 .43659 m .36963 .40606 L .34079 .40328 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.4319 .32791 m .41972 .3526 L .44788 .35455 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.44788 .35455 m .4557 .32985 L .4319 .32791 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.4557 .67015 m .44788 .64545 L .41972 .6474 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.44788 .64545 m .4557 .67015 L .48078 .66907 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.35411 .37361 m .34079 .40328 L .36963 .40606 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.36963 .40606 m .38025 .37696 L .35411 .37361 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.56643 .35368 m .55641 .32898 L .53187 .3305 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.55641 .32898 m .56643 .35368 L .59358 .3513 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.60538 .37834 m .59358 .3513 L .56643 .35368 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.56643 .64632 m .55641 .67102 L .57927 .67338 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.57927 .67338 m .59358 .6487 L .56643 .64632 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.33119 .5654 m .34079 .59672 L .36963 .59394 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.38025 .62304 m .36963 .59394 L .34079 .59672 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.6591 .46758 m .66083 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.66083 .5 m .6591 .53242 L .68892 .53358 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.68892 .53358 m .69106 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.59358 .3513 m .60538 .37834 L .6333 .37538 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.64528 .40475 m .6333 .37538 L .60538 .37834 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.60538 .62166 m .59358 .6487 L .61805 .65191 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.61805 .65191 m .6333 .62462 L .60538 .62166 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.6539 .43565 m .6591 .46758 L .68892 .46642 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.69106 .5 m .68892 .46642 L .6591 .46758 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.6591 .53242 m .6539 .56435 L .68254 .56657 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.68254 .56657 m .68892 .53358 L .6591 .53242 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.64528 .40475 m .6539 .43565 L .68254 .43343 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.68892 .46642 m .68254 .43343 L .6539 .43565 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.6539 .56435 m .64528 .59525 L .67199 .59835 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.67199 .59835 m .68254 .56657 L .6539 .56435 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41017 .32514 m .39379 .3498 L .41972 .3526 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41972 .3526 m .4319 .32791 L .41017 .32514 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.38025 .62304 m .39379 .6502 L .41972 .6474 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.4319 .67209 m .41972 .6474 L .39379 .6502 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.41972 .6474 m .4319 .67209 L .4557 .67015 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.48475 .30872 m .48078 .33093 L .50642 .33115 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.50642 .33115 m .5051 .30892 L .48475 .30872 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.5051 .69108 m .50642 .66885 L .48078 .66907 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.5051 .30892 m .50642 .33115 L .53187 .3305 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.50642 .66885 m .5051 .69108 L .52528 .69167 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.52528 .69167 m .53187 .6695 L .50642 .66885 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.4649 .30775 m .4557 .32985 L .48078 .33093 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.48078 .33093 m .48475 .30872 L .4649 .30775 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.48475 .69128 m .48078 .66907 L .4557 .67015 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.48078 .66907 m .48475 .69128 L .5051 .69108 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.37101 .34619 m .35411 .37361 L .38025 .37696 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.38025 .37696 m .39379 .3498 L .37101 .34619 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.34079 .59672 m .35411 .62639 L .38025 .62304 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.39379 .6502 m .38025 .62304 L .35411 .62639 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.53187 .3305 m .52528 .30833 L .5051 .30892 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.52528 .30833 m .53187 .3305 L .55641 .32898 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.53187 .6695 m .52528 .69167 L .54465 .69302 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.54465 .69302 m .55641 .67102 L .53187 .6695 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.6333 .37538 m .64528 .40475 L .67199 .40165 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.68254 .43343 m .67199 .40165 L .64528 .40475 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.64528 .59525 m .6333 .62462 L .65738 .62833 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.65738 .62833 m .67199 .59835 L .64528 .59525 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.59358 .3513 m .57927 .32662 L .55641 .32898 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.57927 .32662 m .59358 .3513 L .61805 .34809 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.6333 .37538 m .61805 .34809 L .59358 .3513 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59358 .6487 m .57927 .67338 L .59968 .67653 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59968 .67653 m .61805 .65191 L .59358 .6487 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.44617 .30602 m .4319 .32791 L .4557 .32985 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.4557 .32985 m .4649 .30775 L .44617 .30602 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4649 .69225 m .4557 .67015 L .4319 .67209 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.4557 .67015 m .4649 .69225 L .48475 .69128 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3315 .56648 m
.33153 .56651 L
s
.5 Mabswid
.496 .637 .442 r
.29812 .46575 m .29579 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.32346 .5 m .3254 .46703 L .29812 .46575 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.3254 .53297 m .32346 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.30507 .43216 m .29812 .46575 L .3254 .46703 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.3254 .46703 m .33119 .4346 L .30507 .43216 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.29579 .5 m .29812 .53425 L .3254 .53297 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.33119 .5654 m .3254 .53297 L .29812 .53425 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.55641 .32898 m .54465 .30698 L .52528 .30833 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.54465 .30698 m .55641 .32898 L .57927 .32662 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.55641 .67102 m .54465 .69302 L .56257 .69512 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.56257 .69512 m .57927 .67338 L .55641 .67102 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.29812 .53425 m .30507 .56784 L .33119 .5654 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.32958 .56555 m
.3315 .56648 L
s
.5 Mabswid
.415 .512 .345 r
.34079 .59672 m .33119 .5654 L .30507 .56784 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.31654 .39987 m .30507 .43216 L .33119 .4346 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.33119 .4346 m .34079 .40328 L .31654 .39987 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.61805 .34809 m .6333 .37538 L .65738 .37167 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.67199 .40165 m .65738 .37167 L .6333 .37538 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6333 .62462 m .61805 .65191 L .6389 .65589 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6389 .65589 m .65738 .62833 L .6333 .62462 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.3913 .3216 m .37101 .34619 L .39379 .3498 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.39379 .3498 m .41017 .32514 L .3913 .3216 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.39379 .6502 m .41017 .67486 L .4319 .67209 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.35411 .62639 m .37101 .65381 L .39379 .6502 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.41017 .67486 m .39379 .6502 L .37101 .65381 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.42923 .30356 m .41017 .32514 L .4319 .32791 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.4319 .32791 m .44617 .30602 L .42923 .30356 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.44617 .69398 m .4319 .67209 L .41017 .67486 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4319 .67209 m .44617 .69398 L .4649 .69225 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.33238 .36955 m .31654 .39987 L .34079 .40328 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.34079 .40328 m .35411 .37361 L .33238 .36955 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.30507 .56784 m .31654 .60013 L .34079 .59672 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.35411 .62639 m .34079 .59672 L .31654 .60013 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.57927 .32662 m .56257 .30488 L .54465 .30698 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.56257 .30488 m .57927 .32662 L .59968 .32347 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.61805 .34809 m .59968 .32347 L .57927 .32662 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57927 .67338 m .56257 .69512 L .57837 .69792 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57837 .69792 m .59968 .67653 L .57927 .67338 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.68892 .46642 m .69106 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.69106 .5 m .68892 .53358 L .71329 .53497 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.71329 .53497 m .7158 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.48931 .28962 m .48475 .30872 L .5051 .30892 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.5051 .30892 m .50357 .28977 L .48931 .28962 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50357 .28977 m .5051 .30892 L .52528 .30833 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.50357 .71023 m .5051 .69108 L .48475 .69128 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.5051 .69108 m .50357 .71023 L .51772 .71068 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.51772 .71068 m .52528 .69167 L .5051 .69108 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.47542 .28887 m .4649 .30775 L .48475 .30872 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.48475 .30872 m .48931 .28962 L .47542 .28887 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.48931 .71038 m .48475 .69128 L .4649 .69225 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.48475 .69128 m .48931 .71038 L .50357 .71023 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.68254 .43343 m .68892 .46642 L .71329 .46503 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.7158 .5 m .71329 .46503 L .68892 .46642 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.68892 .53358 m .68254 .56657 L .7058 .56923 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.7058 .56923 m .71329 .53497 L .68892 .53358 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.59968 .32347 m .61805 .34809 L .6389 .34411 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.65738 .37167 m .6389 .34411 L .61805 .34809 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.61805 .65191 m .59968 .67653 L .6168 .68043 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.6168 .68043 m .6389 .65589 L .61805 .65191 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35235 .34184 m .33238 .36955 L .35411 .37361 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35411 .37361 m .37101 .34619 L .35235 .34184 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.31654 .60013 m .33238 .63045 L .35411 .62639 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.37101 .65381 m .35411 .62639 L .33238 .63045 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.52528 .30833 m .51772 .28932 L .50357 .28977 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.51772 .28932 m .52528 .30833 L .54465 .30698 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.52528 .69167 m .51772 .71068 L .53123 .71173 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.53123 .71173 m .54465 .69302 L .52528 .69167 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.67199 .40165 m .68254 .43343 L .7058 .43077 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.71329 .46503 m .7058 .43077 L .68254 .43343 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.68254 .56657 m .67199 .59835 L .69345 .60204 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.69345 .60204 m .7058 .56923 L .68254 .56657 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4624 .28754 m .44617 .30602 L .4649 .30775 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4649 .30775 m .47542 .28887 L .4624 .28754 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.47542 .71113 m .4649 .69225 L .44617 .69398 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.4649 .69225 m .47542 .71113 L .48931 .71038 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.41017 .67486 m .42923 .69644 L .44617 .69398 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41472 .30044 m .3913 .3216 L .41017 .32514 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41017 .32514 m .42923 .30356 L .41472 .30044 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.37101 .65381 m .3913 .6784 L .41017 .67486 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.42923 .69644 m .41017 .67486 L .3913 .6784 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.54465 .30698 m .53123 .28827 L .51772 .28932 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.53123 .28827 m .54465 .30698 L .56257 .30488 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54465 .69302 m .53123 .71173 L .54362 .71333 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54362 .71333 m .56257 .69512 L .54465 .69302 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.65738 .37167 m .67199 .40165 L .69345 .39796 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.7058 .43077 m .69345 .39796 L .67199 .40165 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67199 .59835 m .65738 .62833 L .67646 .63273 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67646 .63273 m .69345 .60204 L .67199 .59835 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37612 .31737 m .35235 .34184 L .37101 .34619 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37101 .34619 m .3913 .3216 L .37612 .31737 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.33238 .63045 m .35235 .65816 L .37101 .65381 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.3913 .6784 m .37101 .65381 L .35235 .65816 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.45076 .28567 m .42923 .30356 L .44617 .30602 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.44617 .30602 m .4624 .28754 L .45076 .28567 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.4624 .71246 m .44617 .69398 L .42923 .69644 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.44617 .69398 m .4624 .71246 L .47542 .71113 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.59968 .32347 m .57837 .30208 L .56257 .30488 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.57837 .30208 m .59968 .32347 L .6168 .31957 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.6389 .34411 m .6168 .31957 L .59968 .32347 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59968 .67653 m .57837 .69792 L .59141 .70134 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59141 .70134 m .6168 .68043 L .59968 .67653 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.6389 .34411 m .65738 .37167 L .67646 .36727 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.69345 .39796 m .67646 .36727 L .65738 .37167 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65738 .62833 m .6389 .65589 L .65512 .66059 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65512 .66059 m .67646 .63273 L .65738 .62833 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.27706 .46425 m .27438 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.29579 .5 m .29812 .46575 L .27706 .46425 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.29812 .53425 m .29579 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.28506 .42929 m .27706 .46425 L .29812 .46575 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.29812 .46575 m .30507 .43216 L .28506 .42929 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.27438 .5 m .27706 .53575 L .29812 .53425 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.30507 .56784 m .29812 .53425 L .27706 .53575 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30307 .5671 m
.30523 .56831 L
s
.5 Mabswid
.637 .863 .652 r
.56257 .30488 m .54362 .28667 L .53123 .28827 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.54362 .28667 m .56257 .30488 L .57837 .30208 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.56257 .69512 m .54362 .71333 L .5544 .71545 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.5544 .71545 m .57837 .69792 L .56257 .69512 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.27706 .53575 m .28506 .57071 L .30507 .56784 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.31654 .60013 m .30507 .56784 L .28506 .57071 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.29822 .3959 m .28506 .42929 L .30507 .43216 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.30507 .43216 m .31654 .39987 L .29822 .3959 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.42923 .69644 m .45076 .71433 L .4624 .71246 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.44095 .28331 m .41472 .30044 L .42923 .30356 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.42923 .30356 m .45076 .28567 L .44095 .28331 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.3913 .6784 m .41472 .69956 L .42923 .69644 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.45076 .71433 m .42923 .69644 L .41472 .69956 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.6168 .31957 m .6389 .34411 L .65512 .33941 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.67646 .36727 m .65512 .33941 L .6389 .34411 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.6389 .65589 m .6168 .68043 L .62982 .68498 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.62982 .68498 m .65512 .66059 L .6389 .65589 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.40332 .29675 m .37612 .31737 L .3913 .3216 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.3913 .3216 m .41472 .30044 L .40332 .29675 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.35235 .65816 m .37612 .68263 L .3913 .6784 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.41472 .69956 m .3913 .6784 L .37612 .68263 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31627 .36485 m .29822 .3959 L .31654 .39987 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31654 .39987 m .33238 .36955 L .31627 .36485 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.28506 .57071 m .29822 .6041 L .31654 .60013 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.33238 .63045 m .31654 .60013 L .29822 .6041 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.49441 .27429 m .48931 .28962 L .50357 .28977 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.50357 .28977 m .50187 .27437 L .49441 .27429 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50187 .27437 m .50357 .28977 L .51772 .28932 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.50187 .72563 m .50357 .71023 L .48931 .71038 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50357 .71023 m .50187 .72563 L .50926 .72588 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50926 .72588 m .51772 .71068 L .50357 .71023 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48716 .27387 m .47542 .28887 L .48931 .28962 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48931 .28962 m .49441 .27429 L .48716 .27387 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.49441 .72571 m .48931 .71038 L .47542 .71113 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.48931 .71038 m .49441 .72571 L .50187 .72563 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51772 .28932 m .50926 .27412 L .50187 .27437 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.50926 .27412 m .51772 .28932 L .53123 .28827 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51772 .71068 m .50926 .72588 L .51628 .72647 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51628 .72647 m .53123 .71173 L .51772 .71068 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33884 .33683 m .31627 .36485 L .33238 .36955 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33238 .36955 m .35235 .34184 L .33884 .33683 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.29822 .6041 m .31627 .63515 L .33238 .63045 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.35235 .65816 m .33238 .63045 L .31627 .63515 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.48043 .27312 m .4624 .28754 L .47542 .28887 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.47542 .28887 m .48716 .27387 L .48043 .27312 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.48716 .72613 m .47542 .71113 L .4624 .71246 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.47542 .71113 m .48716 .72613 L .49441 .72571 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.57837 .30208 m .5544 .28455 L .54362 .28667 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.5544 .28455 m .57837 .30208 L .59141 .29866 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.6168 .31957 m .59141 .29866 L .57837 .30208 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.57837 .69792 m .5544 .71545 L .56312 .71802 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.56312 .71802 m .59141 .70134 L .57837 .69792 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.53123 .28827 m .51628 .27353 L .50926 .27412 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.51628 .27353 m .53123 .28827 L .54362 .28667 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.53123 .71173 m .51628 .72647 L .52266 .72736 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.52266 .72736 m .54362 .71333 L .53123 .71173 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.59141 .29866 m .6168 .31957 L .62982 .31502 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.65512 .33941 m .62982 .31502 L .6168 .31957 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.6168 .68043 m .59141 .70134 L .60104 .70529 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.60104 .70529 m .62982 .68498 L .6168 .68043 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.47448 .27209 m .45076 .28567 L .4624 .28754 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.4624 .28754 m .48043 .27312 L .47448 .27209 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.48043 .72688 m .4624 .71246 L .45076 .71433 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.4624 .71246 m .48043 .72688 L .48716 .72613 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.71329 .46503 m .7158 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.7158 .5 m .71329 .53497 L .73061 .53658 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.73061 .53658 m .73345 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.7058 .43077 m .71329 .46503 L .73061 .46342 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.73345 .5 m .73061 .46342 L .71329 .46503 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.71329 .53497 m .7058 .56923 L .72215 .57228 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.72215 .57228 m .73061 .53658 L .71329 .53497 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.36548 .31254 m .33884 .33683 L .35235 .34184 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.35235 .34184 m .37612 .31737 L .36548 .31254 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.31627 .63515 m .33884 .66317 L .35235 .65816 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.37612 .68263 m .35235 .65816 L .33884 .66317 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.43343 .28055 m .40332 .29675 L .41472 .30044 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.41472 .30044 m .44095 .28331 L .43343 .28055 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.37612 .68263 m .40332 .70325 L .41472 .69956 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.44095 .71669 m .41472 .69956 L .40332 .70325 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.41472 .69956 m .44095 .71669 L .45076 .71433 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.69345 .39796 m .7058 .43077 L .72215 .42772 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.73061 .46342 m .72215 .42772 L .7058 .43077 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.7058 .56923 m .69345 .60204 L .70827 .60627 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.70827 .60627 m .72215 .57228 L .7058 .56923 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.54362 .28667 m .52266 .27264 L .51628 .27353 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.52266 .27264 m .54362 .28667 L .5544 .28455 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.54362 .71333 m .52266 .72736 L .52813 .72853 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.52813 .72853 m .5544 .71545 L .54362 .71333 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.67646 .36727 m .69345 .39796 L .70827 .39373 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.72215 .42772 m .70827 .39373 L .69345 .39796 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.69345 .60204 m .67646 .63273 L .68929 .63772 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.68929 .63772 m .70827 .60627 L .69345 .60204 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.46955 .2708 m .44095 .28331 L .45076 .28567 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.45076 .28567 m .47448 .27209 L .46955 .2708 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.45076 .71433 m .47448 .72791 L .48043 .72688 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.47448 .72791 m .45076 .71433 L .44095 .71669 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.39561 .29258 m .36548 .31254 L .37612 .31737 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.37612 .31737 m .40332 .29675 L .39561 .29258 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.33884 .66317 m .36548 .68746 L .37612 .68263 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.40332 .70325 m .37612 .68263 L .36548 .68746 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.65512 .33941 m .67646 .36727 L .68929 .36228 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.70827 .39373 m .68929 .36228 L .67646 .36727 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.67646 .63273 m .65512 .66059 L .66565 .66587 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.66565 .66587 m .68929 .63772 L .67646 .63273 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.59141 .29866 m .56312 .28198 L .5544 .28455 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.56312 .28198 m .59141 .29866 L .60104 .29471 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.62982 .31502 m .60104 .29471 L .59141 .29866 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.59141 .70134 m .56312 .71802 L .56935 .72096 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.56935 .72096 m .60104 .70529 L .59141 .70134 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.5544 .28455 m .52813 .27147 L .52266 .27264 L p F P
.505 .664 .505 r
s
.582 .805 .615 r
.52813 .27147 m .5544 .28455 L .56312 .28198 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.5544 .71545 m .52813 .72853 L .53245 .72993 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.53245 .72993 m .56312 .71802 L .5544 .71545 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2852 .5717 m
.28567 .57226 L
s
.29345 .59411 m
.29361 .5924 L
s
.5 Mabswid
.544 .746 .586 r
.62982 .31502 m .65512 .33941 L .66565 .33413 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.68929 .36228 m .66565 .33413 L .65512 .33941 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.65512 .66059 m .62982 .68498 L .63789 .69005 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.63789 .69005 m .66565 .66587 L .65512 .66059 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.46589 .2693 m .43343 .28055 L .44095 .28331 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.44095 .28331 m .46955 .2708 L .46589 .2693 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.40332 .70325 m .43343 .71945 L .44095 .71669 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.46955 .7292 m .44095 .71669 L .43343 .71945 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.44095 .71669 m .46955 .7292 L .47448 .72791 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.42859 .27747 m .39561 .29258 L .40332 .29675 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.40332 .29675 m .43343 .28055 L .42859 .27747 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.36548 .68746 m .39561 .70742 L .40332 .70325 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.43343 .71945 m .40332 .70325 L .39561 .70742 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.26391 .46256 m .26093 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.27438 .5 m .27706 .46425 L .26391 .46256 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.27706 .53575 m .27438 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.556 .775 .586 r
.50187 .27437 m .5 .26345 L .49441 .27429 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50926 .27412 m .5 .26345 L .50187 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50187 .72563 L .49441 .72571 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .50926 .72588 L .50187 .72563 L closepath p F P
.505 .664 .505 r
s
.554 .772 .584 r
.49441 .27429 m .5 .26345 L .48716 .27387 L closepath p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27276 .42606 m .26391 .46256 L .27706 .46425 L p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27706 .46425 m .28506 .42929 L .27276 .42606 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.26093 .5 m .26391 .53744 L .27706 .53575 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.28506 .57071 m .27706 .53575 L .26391 .53744 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.28276 .56996 m
.2852 .5717 L
s
.5 Mabswid
.201 .208 .158 r
.5 .73655 m .49441 .72571 L .48716 .72613 L closepath p F P
.505 .664 .505 r
s
.549 .758 .592 r
.60104 .29471 m .62982 .31502 L .63789 .30995 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.66565 .33413 m .63789 .30995 L .62982 .31502 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.62982 .68498 m .60104 .70529 L .60667 .70964 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.60667 .70964 m .63789 .69005 L .62982 .68498 L p F P
.505 .664 .505 r
s
.554 .773 .587 r
.51628 .27353 m .5 .26345 L .50926 .27412 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51628 .72647 L .50926 .72588 L closepath p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28726 .39146 m .27276 .42606 L .28506 .42929 L p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28506 .42929 m .29822 .3959 L .28726 .39146 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.26391 .53744 m .27276 .57394 L .28506 .57071 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.29822 .6041 m .28506 .57071 L .27276 .57394 L p F P
.505 .664 .505 r
s
.55 .767 .58 r
.48716 .27387 m .5 .26345 L .48043 .27312 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48716 .72613 L .48043 .72688 L closepath p F P
.505 .664 .505 r
s
.582 .805 .615 r
.56312 .28198 m .53245 .27007 L .52813 .27147 L p F P
.505 .664 .505 r
s
.563 .782 .6 r
.53245 .27007 m .56312 .28198 L .56935 .27904 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.60104 .29471 m .56935 .27904 L .56312 .28198 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.56312 .71802 m .53245 .72993 L .53542 .73151 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.53542 .73151 m .56935 .72096 L .56312 .71802 L p F P
.505 .664 .505 r
s
.551 .769 .585 r
.52266 .27264 m .5 .26345 L .51628 .27353 L closepath p F P
.505 .664 .505 r
s
.393 .535 .368 r
.30703 .35961 m .28726 .39146 L .29822 .3959 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.29822 .3959 m .31627 .36485 L .30703 .35961 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.27276 .57394 m .28726 .60854 L .29822 .6041 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.31627 .63515 m .29822 .6041 L .28726 .60854 L p F P
.505 .664 .505 r
s
.197 .203 .154 r
.5 .73655 m .52266 .72736 L .51628 .72647 L closepath p F P
.505 .664 .505 r
s
.544 .761 .575 r
.48043 .27312 m .5 .26345 L .47448 .27209 L closepath p F P
.505 .664 .505 r
s
.197 .203 .155 r
.5 .73655 m .48043 .72688 L .47448 .72791 L closepath p F P
.505 .664 .505 r
s
.422 .581 .408 r
.33154 .33131 m .30703 .35961 L .31627 .36485 L p F P
.505 .664 .505 r
s
.422 .581 .408 r
.31627 .36485 m .33884 .33683 L .33154 .33131 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.28726 .60854 m .30703 .64039 L .31627 .63515 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.33884 .66317 m .31627 .63515 L .30703 .64039 L p F P
.505 .664 .505 r
s
.546 .764 .581 r
.52813 .27147 m .5 .26345 L .52266 .27264 L closepath p F P
.505 .664 .505 r
s
.192 .199 .152 r
.5 .73655 m .52813 .72853 L .52266 .72736 L closepath p F P
.505 .664 .505 r
s
.547 .76 .59 r
.56935 .27904 m .60104 .29471 L .60667 .29036 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.63789 .30995 m .60667 .29036 L .60104 .29471 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.60104 .70529 m .56935 .72096 L .57273 .72415 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.57273 .72415 m .60667 .70964 L .60104 .70529 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.46365 .26765 m .42859 .27747 L .43343 .28055 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.43343 .28055 m .46589 .2693 L .46365 .26765 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.39561 .70742 m .42859 .72253 L .43343 .71945 L p F P
.505 .664 .505 r
s
.2 .206 .157 r
.46589 .7307 m .43343 .71945 L .42859 .72253 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.43343 .71945 m .46589 .7307 L .46955 .7292 L p F P
.505 .664 .505 r
s
.537 .753 .568 r
.47448 .27209 m .5 .26345 L .46955 .2708 L closepath p F P
.505 .664 .505 r
s
.448 .622 .444 r
.36017 .30728 m .33154 .33131 L .33884 .33683 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.33884 .33683 m .36548 .31254 L .36017 .30728 L p F P
.505 .664 .505 r
s
.193 .199 .152 r
.5 .73655 m .47448 .72791 L .46955 .7292 L closepath p F P
.505 .664 .505 r
s
.223 .246 .179 r
.30703 .64039 m .33154 .66869 L .33884 .66317 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.36548 .68746 m .33884 .66317 L .33154 .66869 L p F P
.505 .664 .505 r
s
.539 .756 .576 r
.53245 .27007 m .5 .26345 L .52813 .27147 L closepath p F P
.505 .664 .505 r
s
.187 .194 .148 r
.5 .73655 m .53245 .72993 L .52813 .72853 L closepath p F P
.505 .664 .505 r
s
.205 .216 .162 r
.33154 .66869 m .36017 .69272 L .36548 .68746 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.39561 .70742 m .36548 .68746 L .36017 .69272 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.39217 .28809 m .36017 .30728 L .36548 .31254 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.36548 .31254 m .39561 .29258 L .39217 .28809 L p F P
.505 .664 .505 r
s
.529 .742 .561 r
.46955 .2708 m .5 .26345 L .46589 .2693 L closepath p F P
.505 .664 .505 r
s
.187 .195 .148 r
.5 .73655 m .46955 .7292 L .46589 .7307 L closepath p F P
.505 .664 .505 r
s
.563 .782 .6 r
.56935 .27904 m .53542 .26849 L .53245 .27007 L p F P
.505 .664 .505 r
s
.538 .753 .58 r
.53542 .26849 m .56935 .27904 L .57273 .27585 L p F P
.505 .664 .505 r
s
.547 .76 .59 r
.60667 .29036 m .57273 .27585 L .56935 .27904 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.56935 .72096 m .53542 .73151 L .53689 .73321 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.53689 .73321 m .57273 .72415 L .56935 .72096 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.42673 .27419 m .39217 .28809 L .39561 .29258 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.39561 .29258 m .42859 .27747 L .42673 .27419 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.36017 .69272 m .39217 .71191 L .39561 .70742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.42859 .72253 m .39561 .70742 L .39217 .71191 L p F P
.505 .664 .505 r
s
.531 .746 .57 r
.53542 .26849 m .5 .26345 L .53245 .27007 L closepath p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .53542 .73151 L .53245 .72993 L closepath p F P
.505 .664 .505 r
s
.52 .731 .553 r
.46589 .2693 m .5 .26345 L .46365 .26765 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.42859 .72253 m .46365 .73235 L .46589 .7307 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .46589 .7307 L .46365 .73235 L closepath p F P
.505 .664 .505 r
s
.301 .396 .336 r
.73061 .46342 m .73345 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73345 .5 m .73061 .53658 L .73916 .53835 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73916 .53835 m .74225 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.72215 .42772 m .73061 .46342 L .73916 .46165 L p F P
.505 .664 .505 r
s
.301 .396 .336 r
.74225 .5 m .73916 .46165 L .73061 .46342 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.73061 .53658 m .72215 .57228 L .72998 .57566 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.72998 .57566 m .73916 .53835 L .73061 .53658 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.70827 .39373 m .72215 .42772 L .72998 .42434 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.73916 .46165 m .72998 .42434 L .72215 .42772 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.72215 .57228 m .70827 .60627 L .71499 .61091 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.71499 .61091 m .72998 .57566 L .72215 .57228 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.46298 .26592 m .42673 .27419 L .42859 .27747 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.42859 .27747 m .46365 .26765 L .46298 .26592 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.39217 .71191 m .42673 .72581 L .42859 .72253 L p F P
.505 .664 .505 r
s
.182 .189 .144 r
.46365 .73235 m .42859 .72253 L .42673 .72581 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.70827 .60627 m .68929 .63772 L .69462 .64316 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.69462 .64316 m .71499 .61091 L .70827 .60627 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.68929 .36228 m .70827 .39373 L .71499 .38909 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.72998 .42434 m .71499 .38909 L .70827 .39373 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.66565 .33413 m .68929 .36228 L .69462 .35684 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.71499 .38909 m .69462 .35684 L .68929 .36228 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.68929 .63772 m .66565 .66587 L .66947 .67158 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.66947 .67158 m .69462 .64316 L .68929 .63772 L p F P
.505 .664 .505 r
s
.522 .735 .562 r
.53689 .26679 m .5 .26345 L .53542 .26849 L closepath p F P
.505 .664 .505 r
s
.538 .753 .58 r
.57273 .27585 m .53689 .26679 L .53542 .26849 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .53689 .73321 L .53542 .73151 L closepath p F P
.505 .664 .505 r
s
.461 .645 .517 r
.63789 .30995 m .66565 .33413 L .66947 .32842 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.69462 .35684 m .66947 .32842 L .66565 .33413 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.66565 .66587 m .63789 .69005 L .64026 .69546 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.64026 .69546 m .66947 .67158 L .66565 .66587 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.60667 .29036 m .63789 .30995 L .64026 .30454 L p F P
.505 .664 .505 r
s
.461 .645 .517 r
.66947 .32842 m .64026 .30454 L .63789 .30995 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.63789 .69005 m .60667 .70964 L .60781 .71423 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.60781 .71423 m .64026 .69546 L .63789 .69005 L p F P
.505 .664 .505 r
s
.509 .719 .544 r
.46365 .26765 m .5 .26345 L .46298 .26592 L closepath p F P
.505 .664 .505 r
s
.182 .189 .144 r
.42673 .72581 m .46298 .73408 L .46365 .73235 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .46365 .73235 L .46298 .73408 L closepath p F P
.505 .664 .505 r
s
.497 .701 .55 r
.57273 .27585 m .60667 .29036 L .60781 .28577 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.64026 .30454 m .60781 .28577 L .60667 .29036 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.60667 .70964 m .57273 .72415 L .573 .72747 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.573 .72747 m .60781 .71423 L .60667 .70964 L p F P
.505 .664 .505 r
s
.507 .716 .555 r
.53689 .26679 m .57273 .27585 L .573 .27253 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.60781 .28577 m .573 .27253 L .57273 .27585 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.57273 .72415 m .53689 .73321 L .53675 .73495 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.53675 .73495 m .573 .72747 L .57273 .72415 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27924 .59034 m
.28054 .59249 L
s
.28179 .59547 m
.28236 .59756 L
s
.5 Mabswid
.511 .722 .553 r
.53675 .26505 m .5 .26345 L .53689 .26679 L closepath p F P
.505 .664 .505 r
s
.507 .716 .555 r
.573 .27253 m .53675 .26505 L .53689 .26679 L p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .53675 .73495 L .53689 .73321 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27108 .57282 m
.27282 .57407 L
s
.27747 .58888 m
.27924 .59034 L
s
.28174 .59997 m
.28236 .59756 L
s
.5 Mabswid
.161 .17 .129 r
.5 .73655 m .53499 .73666 L .53675 .73495 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .53165 .73825 L .53499 .73666 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .52684 .73967 L .53165 .73825 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .52077 .74082 L .52684 .73967 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .51372 .74166 L .52077 .74082 L closepath p F P
.505 .664 .505 r
s
.136 .148 .112 r
.5 .73655 m .506 .74214 L .51372 .74166 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49799 .74224 L .506 .74214 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49008 .74195 L .49799 .74224 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48265 .74128 L .49008 .74195 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .47605 .74028 L .48265 .74128 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .47058 .73899 L .47605 .74028 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .46649 .73747 L .47058 .73899 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .46392 .73581 L .46649 .73747 L closepath p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .46298 .73408 L .46392 .73581 L closepath p F P
.505 .664 .505 r
s
.5 .709 .543 r
.53499 .26334 m .5 .26345 L .53675 .26505 L closepath p F P
.505 .664 .505 r
s
.498 .705 .534 r
.46298 .26592 m .5 .26345 L .46392 .26419 L closepath p F P
.505 .664 .505 r
s
.489 .695 .534 r
.53165 .26175 m .5 .26345 L .53499 .26334 L closepath p F P
.505 .664 .505 r
s
.487 .692 .525 r
.46392 .26419 m .5 .26345 L .46649 .26253 L closepath p F P
.505 .664 .505 r
s
.478 .682 .524 r
.52684 .26033 m .5 .26345 L .53165 .26175 L closepath p F P
.505 .664 .505 r
s
.477 .68 .517 r
.46649 .26253 m .5 .26345 L .47058 .26101 L closepath p F P
.505 .664 .505 r
s
.469 .671 .515 r
.52077 .25918 m .5 .26345 L .52684 .26033 L closepath p F P
.505 .664 .505 r
s
.468 .669 .509 r
.47058 .26101 m .5 .26345 L .47605 .25972 L closepath p F P
.505 .664 .505 r
s
.461 .661 .508 r
.51372 .25834 m .5 .26345 L .52077 .25918 L closepath p F P
.505 .664 .505 r
s
.461 .66 .504 r
.47605 .25972 m .5 .26345 L .48265 .25872 L closepath p F P
.505 .664 .505 r
s
.456 .655 .503 r
.506 .25786 m .5 .26345 L .51372 .25834 L closepath p F P
.505 .664 .505 r
s
.456 .654 .5 r
.48265 .25872 m .5 .26345 L .49008 .25805 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49799 .25776 m .5 .26345 L .506 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49008 .25805 m .5 .26345 L .49799 .25776 L closepath p F P
.505 .664 .505 r
s
.468 .666 .499 r
.42673 .27419 m .46298 .26592 L .46392 .26419 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.42808 .72914 m .46392 .73581 L .46298 .73408 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.46298 .73408 m .42673 .72581 L .42808 .72914 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.46392 .26419 m .42808 .27086 L .42673 .27419 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.39217 .28809 m .42673 .27419 L .42808 .27086 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.39342 .71655 m .42808 .72914 L .42673 .72581 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.42673 .72581 m .39217 .71191 L .39342 .71655 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.42808 .27086 m .39342 .28345 L .39217 .28809 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.36017 .30728 m .39217 .28809 L .39342 .28345 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.36089 .69823 m .39342 .71655 L .39217 .71191 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.39217 .71191 m .36017 .69272 L .36089 .69823 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.573 .72747 m .53675 .73495 L .53499 .73666 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.53675 .26505 m .573 .27253 L .57001 .26922 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.57001 .26922 m .53499 .26334 L .53675 .26505 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.39342 .28345 m .36089 .30177 L .36017 .30728 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.33154 .33131 m .36017 .30728 L .36089 .30177 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.33142 .67453 m .36089 .69823 L .36017 .69272 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.36017 .69272 m .33154 .66869 L .33142 .67453 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.30591 .64599 m .33142 .67453 L .33154 .66869 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.33154 .66869 m .30703 .64039 L .30591 .64599 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.36089 .30177 m .33142 .32547 L .33154 .33131 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.30703 .35961 m .33154 .33131 L .33142 .32547 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.43272 .73238 m .46649 .73747 L .46392 .73581 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.46392 .73581 m .42808 .72914 L .43272 .73238 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.42808 .27086 m .46392 .26419 L .46649 .26253 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.33142 .32547 m .30591 .35401 L .30703 .35961 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.28726 .39146 m .30703 .35961 L .30591 .35401 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.28515 .61333 m .30591 .64599 L .30703 .64039 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.30703 .64039 m .28726 .60854 L .28515 .61333 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.30591 .35401 m .28515 .38667 L .28726 .39146 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.27276 .42606 m .28726 .39146 L .28515 .38667 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.26981 .57743 m .28515 .61333 L .28726 .60854 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27598 .58842 m
.27747 .58888 L
s
.5 Mabswid
.123 .136 .103 r
.28726 .60854 m .27276 .57394 L .26981 .57743 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.573 .27253 m .60781 .28577 L .60411 .28114 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.60411 .28114 m .57001 .26922 L .573 .27253 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.60781 .71423 m .573 .72747 L .57001 .73078 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53499 .73666 m .57001 .73078 L .573 .72747 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.28515 .38667 m .26981 .42257 L .27276 .42606 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26391 .46256 m .27276 .42606 L .26981 .42257 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.2604 .53929 m .26981 .57743 L .27276 .57394 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.27276 .57394 m .26391 .53744 L .2604 .53929 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26981 .42257 m .2604 .46071 L .26391 .46256 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.26093 .5 m .26391 .46256 L .2604 .46071 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.25723 .5 m .2604 .53929 L .26391 .53744 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.26391 .53744 m .26093 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.2604 .46071 m .25723 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.57001 .73078 m .53499 .73666 L .53165 .73825 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.53499 .26334 m .57001 .26922 L .56374 .26608 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.56374 .26608 m .53165 .26175 L .53499 .26334 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27876 .59961 m
.27947 .60003 L
s
.26938 .57607 m
.26941 .57581 L
s
.27315 .58645 m
.2741 .58747 L
s
.5 Mabswid
.115 .128 .098 r
.44056 .73538 m .47058 .73899 L .46649 .73747 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.46649 .73747 m .43272 .73238 L .44056 .73538 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.43272 .26762 m .46649 .26253 L .47058 .26101 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.46649 .26253 m .43272 .26762 L .42808 .27086 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.60781 .28577 m .64026 .30454 L .63633 .299 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.63633 .299 m .60411 .28114 L .60781 .28577 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.64026 .69546 m .60781 .71423 L .60411 .71886 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.57001 .73078 m .60411 .71886 L .60781 .71423 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.39342 .28345 m .42808 .27086 L .43272 .26762 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.39961 .72113 m .43272 .73238 L .42808 .72914 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.42808 .72914 m .39342 .71655 L .39961 .72113 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.53165 .73825 m .56374 .73392 L .57001 .73078 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.56374 .73392 m .53165 .73825 L .52684 .73967 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.53165 .26175 m .56374 .26608 L .55439 .26327 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.55439 .26327 m .52684 .26033 L .53165 .26175 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27685 .59623 m
.27876 .59961 L
s
.27132 .5826 m
.27315 .58645 L
s
.26938 .57607 m
.27056 .58052 L
s
.5 Mabswid
.344 .5 .414 r
.64026 .30454 m .66947 .32842 L .6657 .32251 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.6657 .32251 m .63633 .299 L .64026 .30454 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.66947 .67158 m .64026 .69546 L .63633 .701 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.60411 .71886 m .63633 .701 L .64026 .69546 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.45134 .73796 m .47605 .74028 L .47058 .73899 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.47058 .73899 m .44056 .73538 L .45134 .73796 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.44056 .26462 m .47058 .26101 L .47605 .25972 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.47058 .26101 m .44056 .26462 L .43272 .26762 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.27056 .58052 m
.27132 .5826 L
s
.5 Mabswid
.096 .11 .084 r
.52684 .73967 m .55439 .73673 L .56374 .73392 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.55439 .73673 m .52684 .73967 L .52077 .74082 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.52684 .26033 m .55439 .26327 L .5423 .26094 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.5423 .26094 m .52077 .25918 L .52684 .26033 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.66947 .32842 m .69462 .35684 L .69127 .35115 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.69127 .35115 m .6657 .32251 L .66947 .32842 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.69462 .64316 m .66947 .67158 L .6657 .67749 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.63633 .701 m .6657 .67749 L .66947 .67158 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.57001 .26922 m .60411 .28114 L .59543 .27668 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.59543 .27668 m .56374 .26608 L .57001 .26922 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.60411 .71886 m .57001 .73078 L .56374 .73392 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.36811 .70373 m .39961 .72113 L .39342 .71655 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.39342 .71655 m .36089 .69823 L .36811 .70373 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.43272 .26762 m .39961 .27887 L .39342 .28345 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.36089 .30177 m .39342 .28345 L .39961 .27887 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.4646 .73999 m .48265 .74128 L .47605 .74028 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.47605 .74028 m .45134 .73796 L .4646 .73999 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.45134 .26204 m .47605 .25972 L .48265 .25872 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.47605 .25972 m .45134 .26204 L .44056 .26462 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.69462 .35684 m .71499 .38909 L .71217 .3842 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.71217 .3842 m .69127 .35115 L .69462 .35684 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.71499 .61091 m .69462 .64316 L .69127 .64885 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.6657 .67749 m .69127 .64885 L .69462 .64316 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.52077 .74082 m .5423 .73906 L .55439 .73673 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.5423 .73906 m .52077 .74082 L .51372 .74166 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52077 .25918 m .5423 .26094 L .52803 .25924 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52803 .25924 m .51372 .25834 L .52077 .25918 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.4797 .74135 m .49008 .74195 L .48265 .74128 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.48265 .74128 m .4646 .73999 L .4797 .74135 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.4646 .26001 m .48265 .25872 L .49008 .25805 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.48265 .25872 m .4646 .26001 L .45134 .26204 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.69127 .64885 m .71217 .6158 L .71499 .61091 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.72998 .57566 m .71499 .61091 L .71217 .6158 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.71499 .38909 m .72998 .42434 L .72767 .42076 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72829 .41309 m
.72888 .41515 L
s
.72888 .41515 m
.72973 .41689 L
s
.5 Mabswid
.086 .102 .077 r
.72767 .42076 m .71217 .3842 L .71499 .38909 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.41074 .72541 m .44056 .73538 L .43272 .73238 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.43272 .73238 m .39961 .72113 L .41074 .72541 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.39961 .27887 m .43272 .26762 L .44056 .26462 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72829 .41309 m
.72914 .41484 L
s
.72914 .41484 m
.72973 .41689 L
s
.733 .42631 m
.73974 .45185 L
s
.5 Mabswid
.063 .08 .061 r
.51372 .74166 m .52803 .74076 L .5423 .73906 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.52803 .74076 m .51372 .74166 L .506 .74214 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51372 .25834 m .52803 .25924 L .51229 .25826 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51229 .25826 m .506 .25786 L .51372 .25834 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.72998 .42434 m .73916 .46165 L .7372 .45976 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.7372 .45976 m .72767 .42076 L .72998 .42434 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.73916 .53835 m .72998 .57566 L .72767 .57924 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.71217 .6158 m .72767 .57924 L .72998 .57566 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49589 .74194 m .49799 .74224 L .49008 .74195 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49008 .74195 m .4797 .74135 L .49589 .74194 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.49008 .25805 m .4797 .25865 L .4646 .26001 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.4797 .25865 m .49008 .25805 L .49799 .25776 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.33923 .68043 m .36811 .70373 L .36089 .69823 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.36089 .69823 m .33142 .67453 L .33923 .68043 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.39961 .27887 m .36811 .29627 L .36089 .30177 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33142 .32547 m .36089 .30177 L .36811 .29627 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.506 .74214 m .51229 .74174 L .52803 .74076 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.51229 .74174 m .506 .74214 L .49799 .74224 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.506 .25786 m .51229 .25826 L .49589 .25806 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49589 .25806 m .49799 .25776 L .506 .25786 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.73916 .46165 m .74225 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.74042 .5 m .7372 .45976 L .73916 .46165 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.74225 .5 m .73916 .53835 L .7372 .54024 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.72767 .57924 m .7372 .54024 L .73916 .53835 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.49799 .74224 m .49589 .74194 L .51229 .74174 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.49799 .25776 m .49589 .25806 L .4797 .25865 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.7372 .54024 m .74042 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.56374 .73392 m .59543 .72332 L .60411 .71886 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.63633 .701 m .60411 .71886 L .59543 .72332 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.60411 .28114 m .63633 .299 L .62576 .29361 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.62576 .29361 m .59543 .27668 L .60411 .28114 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.59543 .72332 m .56374 .73392 L .55439 .73673 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.56374 .26608 m .59543 .27668 L .58191 .27264 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.58191 .27264 m .55439 .26327 L .56374 .26608 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.2723 .59035 m
.28411 .61527 L
s
.26686 .57555 m
.26769 .57758 L
s
.26836 .57995 m
.26769 .57758 L
s
.5 Mabswid
.316 .457 .385 r
.31395 .65171 m .33923 .68043 L .33142 .67453 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.33142 .67453 m .30591 .64599 L .31395 .65171 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36811 .29627 m .33923 .31957 L .33142 .32547 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.30591 .35401 m .33142 .32547 L .33923 .31957 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.26755 .57796 m
.26836 .57995 L
s
.26686 .57555 m
.26755 .57796 L
s
.5 Mabswid
.362 .536 .428 r
.42652 .72914 m .45134 .73796 L .44056 .73538 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.44056 .73538 m .41074 .72541 L .42652 .72914 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.44056 .26462 m .41074 .27459 L .39961 .27887 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.41074 .27459 m .44056 .26462 L .45134 .26204 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72954 .41359 m
.73098 .41759 L
s
.73166 .4195 m
.73098 .41759 L
s
.73166 .4195 m
.73298 .42317 L
s
.5 Mabswid
.369 .539 .437 r
.38203 .70894 m .41074 .72541 L .39961 .72113 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.39961 .72113 m .36811 .70373 L .38203 .70894 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.36811 .29627 m .39961 .27887 L .41074 .27459 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73592 .43275 m
.73697 .43636 L
s
.5 Mabswid
.065 .082 .063 r
.33923 .31957 m .31395 .34829 L .30591 .35401 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.28515 .38667 m .30591 .35401 L .31395 .34829 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.29319 .61827 m .31395 .65171 L .30591 .64599 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.30591 .64599 m .28515 .61333 L .29319 .61827 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.6657 .67749 m .63633 .701 L .62576 .70639 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.59543 .72332 m .62576 .70639 L .63633 .701 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.63633 .299 m .6657 .32251 L .65374 .31669 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.65374 .31669 m .62576 .29361 L .63633 .299 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72867 .41118 m
.72954 .41359 L
s
.73298 .42317 m
.73355 .4248 L
s
.73697 .43636 m
.73739 .43786 L
s
.5 Mabswid
.298 .451 .339 r
.55439 .73673 m .58191 .72736 L .59543 .72332 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.58191 .72736 m .55439 .73673 L .5423 .73906 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.55439 .26327 m .58191 .27264 L .56403 .26926 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.56403 .26926 m .5423 .26094 L .55439 .26327 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73355 .4248 m
.73375 .42601 L
s
.5 Mabswid
.32 .443 .376 r
.27773 .58105 m .29319 .61827 L .28515 .61333 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.28515 .61333 m .26981 .57743 L .27773 .58105 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.31395 .34829 m .29319 .38173 L .28515 .38667 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.26981 .42257 m .28515 .38667 L .29319 .38173 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7284 .41069 m
.72867 .41118 L
s
.5 Mabswid
.417 .605 .476 r
.44631 .73211 m .4646 .73999 L .45134 .73796 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.45134 .73796 m .42652 .72914 L .44631 .73211 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.42652 .27086 m .45134 .26204 L .4646 .26001 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.45134 .26204 m .42652 .27086 L .41074 .27459 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73716 .43751 m
.73739 .43786 L
s
.5 Mabswid
.303 .41 .35 r
.2682 .5412 m .27773 .58105 L .26981 .57743 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.26981 .57743 m .2604 .53929 L .2682 .5412 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.29319 .38173 m .27773 .41895 L .26981 .42257 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.2604 .46071 m .26981 .42257 L .27773 .41895 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.62576 .70639 m .59543 .72332 L .58191 .72736 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.59543 .27668 m .62576 .29361 L .60857 .28866 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60857 .28866 m .58191 .27264 L .59543 .27668 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.69127 .64885 m .6657 .67749 L .65374 .68331 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.62576 .70639 m .65374 .68331 L .6657 .67749 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.6657 .32251 m .69127 .35115 L .67836 .34548 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.67836 .34548 m .65374 .31669 L .6657 .32251 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7284 .41069 m
.72873 .41217 L
s
.5 Mabswid
.182 .22 .201 r
.27773 .41895 m .2682 .4588 L .2604 .46071 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.25723 .5 m .2604 .46071 L .2682 .4588 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.26498 .5 m .2682 .5412 L .2604 .53929 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.2604 .53929 m .25723 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.2682 .4588 m .26498 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.5423 .73906 m .56403 .73074 L .58191 .72736 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.56403 .73074 m .5423 .73906 L .52803 .74076 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.5423 .26094 m .56403 .26926 L .54259 .26676 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.54259 .26676 m .52803 .25924 L .5423 .26094 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73626 .43527 m
.73716 .43751 L
s
.5 Mabswid
.427 .607 .489 r
.35538 .68609 m .38203 .70894 L .36811 .70373 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.36811 .70373 m .33923 .68043 L .35538 .68609 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.41074 .27459 m .38203 .29106 L .36811 .29627 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.33923 .31957 m .36811 .29627 L .38203 .29106 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73375 .42601 m
.73406 .42766 L
s
.5 Mabswid
.452 .65 .505 r
.46913 .7341 m .4797 .74135 L .4646 .73999 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.4646 .73999 m .44631 .73211 L .46913 .7341 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.44631 .26789 m .4646 .26001 L .4797 .25865 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.4646 .26001 m .44631 .26789 L .42652 .27086 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72873 .41217 m
.73001 .41591 L
s
.73406 .42766 m
.73503 .43135 L
s
.5 Mabswid
.458 .653 .516 r
.40236 .71354 m .42652 .72914 L .41074 .72541 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.41074 .72541 m .38203 .70894 L .40236 .71354 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.38203 .29106 m .41074 .27459 L .42652 .27086 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73503 .43135 m
.73626 .43527 L
s
.5 Mabswid
.418 .606 .458 r
.52803 .74076 m .54259 .73324 L .56403 .73074 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.54259 .73324 m .52803 .74076 L .51229 .74174 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.52803 .25924 m .54259 .26676 L .51871 .26531 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.51871 .26531 m .51229 .25826 L .52803 .25924 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69127 .35115 m .71217 .3842 L .69868 .37929 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69868 .37929 m .67836 .34548 L .69127 .35115 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.71217 .6158 m .69127 .64885 L .67836 .65452 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.65374 .68331 m .67836 .65452 L .69127 .64885 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.49373 .73498 m .49589 .74194 L .4797 .74135 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.4797 .74135 m .46913 .7341 L .49373 .73498 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.46913 .2659 m .4797 .25865 L .49589 .25806 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.4797 .25865 m .46913 .2659 L .44631 .26789 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.51229 .74174 m .51871 .73469 L .54259 .73324 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.51871 .73469 m .51229 .74174 L .49589 .74194 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.51229 .25826 m .51871 .26531 L .49373 .26502 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.49373 .26502 m .49589 .25806 L .51229 .25826 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.49589 .74194 m .49373 .73498 L .51871 .73469 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.49589 .25806 m .49373 .26502 L .46913 .2659 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.72767 .57924 m .71217 .6158 L .69868 .62071 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.67836 .65452 m .69868 .62071 L .71217 .6158 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71217 .3842 m .72767 .42076 L .71386 .41715 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71386 .41715 m .69868 .37929 L .71217 .3842 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.65374 .68331 m .62576 .70639 L .60857 .71134 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.58191 .72736 m .60857 .71134 L .62576 .70639 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.62576 .29361 m .65374 .31669 L .63344 .31129 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.63344 .31129 m .60857 .28866 L .62576 .29361 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33181 .65724 m .35538 .68609 L .33923 .68043 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33923 .68043 m .31395 .65171 L .33181 .65724 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.38203 .29106 m .35538 .31391 L .33923 .31957 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.31395 .34829 m .33923 .31957 L .35538 .31391 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.60857 .71134 m .58191 .72736 L .56403 .73074 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58191 .27264 m .60857 .28866 L .58528 .28448 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58528 .28448 m .56403 .26926 L .58191 .27264 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.7372 .54024 m .72767 .57924 L .71386 .58285 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.69868 .62071 m .71386 .58285 L .72767 .57924 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72767 .42076 m .7372 .45976 L .72324 .45784 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72324 .45784 m .71386 .41715 L .72767 .42076 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72609 .40891 m
.73493 .43621 L
s
.72585 .41041 m
.72901 .41681 L
s
.5 Mabswid
.521 .731 .568 r
.42835 .71723 m .44631 .73211 L .42652 .72914 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42652 .72914 m .40236 .71354 L .42835 .71723 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.40236 .28646 m .42652 .27086 L .44631 .26789 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.42652 .27086 m .40236 .28646 L .38203 .29106 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.7372 .45976 m .74042 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.72642 .5 m .72324 .45784 L .7372 .45976 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.74042 .5 m .7372 .54024 L .72324 .54216 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.71386 .58285 m .72324 .54216 L .7372 .54024 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.72324 .54216 m .72642 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72433 .40809 m
.72585 .41041 L
s
.5 Mabswid
.155 .168 .131 r
.35538 .31391 m .33181 .34276 L .31395 .34829 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.29319 .38173 m .31395 .34829 L .33181 .34276 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31228 .62308 m .33181 .65724 L .31395 .65171 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31395 .65171 m .29319 .61827 L .31228 .62308 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.37971 .69114 m .40236 .71354 L .38203 .70894 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.38203 .70894 m .35538 .68609 L .37971 .69114 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.35538 .31391 m .38203 .29106 L .40236 .28646 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72306 .4076 m
.72433 .40809 L
s
.5 Mabswid
.459 .651 .481 r
.56403 .73074 m .58528 .71552 L .60857 .71134 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.58528 .71552 m .56403 .73074 L .54259 .73324 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.56403 .26926 m .58528 .28448 L .55693 .28136 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.55693 .28136 m .54259 .26676 L .56403 .26926 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.67836 .65452 m .65374 .68331 L .63344 .68871 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.60857 .71134 m .63344 .68871 L .65374 .68331 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65374 .31669 m .67836 .34548 L .65555 .34018 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65555 .34018 m .63344 .31129 L .65374 .31669 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72288 .40928 m
.72306 .4076 L
s
.5 Mabswid
.221 .25 .205 r
.33181 .34276 m .31228 .37692 L .29319 .38173 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.27773 .41895 m .29319 .38173 L .31228 .37692 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29763 .58461 m .31228 .62308 L .29319 .61827 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29319 .61827 m .27773 .58105 L .29763 .58461 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.45868 .71973 m .46913 .7341 L .44631 .73211 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.44631 .73211 m .42835 .71723 L .45868 .71973 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.42835 .28277 m .44631 .26789 L .46913 .2659 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.44631 .26789 m .42835 .28277 L .40236 .28646 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72288 .40928 m
.72454 .41515 L
s
.5 Mabswid
.519 .718 .524 r
.63344 .68871 m .60857 .71134 L .58528 .71552 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60857 .28866 m .63344 .31129 L .60529 .30668 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60529 .30668 m .58528 .28448 L .60857 .28866 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72454 .41515 m
.73047 .4349 L
s
.5 Mabswid
.518 .725 .54 r
.54259 .73324 m .55693 .71864 L .58528 .71552 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.55693 .71864 m .54259 .73324 L .51871 .73469 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.54259 .26676 m .55693 .28136 L .52506 .27954 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.52506 .27954 m .51871 .26531 L .54259 .26676 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.31228 .37692 m .29763 .41539 L .27773 .41895 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.2682 .4588 m .27773 .41895 L .29763 .41539 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.28856 .54309 m .29763 .58461 L .27773 .58105 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.27773 .58105 m .2682 .5412 L .28856 .54309 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.4916 .72084 m .49373 .73498 L .46913 .7341 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.46913 .7341 m .45868 .71973 L .4916 .72084 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.45868 .28027 m .46913 .2659 L .49373 .26502 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.46913 .2659 m .45868 .28027 L .42835 .28277 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67836 .34548 m .69868 .37929 L .67394 .37466 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67394 .37466 m .65555 .34018 L .67836 .34548 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.69868 .62071 m .67836 .65452 L .65555 .65982 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.63344 .68871 m .65555 .65982 L .67836 .65452 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35949 .66222 m .37971 .69114 L .35538 .68609 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35538 .68609 m .33181 .65724 L .35949 .66222 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.40236 .28646 m .37971 .30886 L .35538 .31391 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.33181 .34276 m .35538 .31391 L .37971 .30886 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.51871 .73469 m .52506 .72046 L .55693 .71864 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.52506 .72046 m .51871 .73469 L .49373 .73498 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.29763 .41539 m .28856 .45691 L .2682 .4588 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.26498 .5 m .2682 .4588 L .28856 .45691 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.28548 .5 m .28856 .54309 L .2682 .5412 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.2682 .5412 m .26498 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.51871 .26531 m .52506 .27954 L .4916 .27916 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.4916 .27916 m .49373 .26502 L .51871 .26531 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.49373 .73498 m .4916 .72084 L .52506 .72046 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.49373 .26502 m .4916 .27916 L .45868 .28027 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.28856 .45691 m .28548 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.41137 .69522 m .42835 .71723 L .40236 .71354 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.40236 .71354 m .37971 .69114 L .41137 .69522 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.37971 .30886 m .40236 .28646 L .42835 .28277 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71698 .40581 m
.72577 .43395 L
s
.5 Mabswid
.471 .627 .436 r
.71386 .58285 m .69868 .62071 L .67394 .62534 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.65555 .65982 m .67394 .62534 L .69868 .62071 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.69868 .37929 m .71386 .41715 L .68778 .41371 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.68778 .41371 m .67394 .37466 L .69868 .37929 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7292 .44952 m
.72949 .44769 L
s
.72844 .44567 m
.72949 .44769 L
s
.72815 .4475 m
.72844 .44567 L
s
.5 Mabswid
.519 .718 .524 r
.58528 .71552 m .60529 .69332 L .63344 .68871 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.60529 .69332 m .58528 .71552 L .55693 .71864 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.58528 .28448 m .60529 .30668 L .57052 .30321 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.57052 .30321 m .55693 .28136 L .58528 .28448 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72815 .4475 m
.7292 .44952 L
s
.5 Mabswid
.55 .747 .54 r
.65555 .65982 m .63344 .68871 L .60529 .69332 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.63344 .31129 m .65555 .34018 L .62323 .33561 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.62323 .33561 m .60529 .30668 L .63344 .31129 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.37971 .30886 m .35949 .33778 L .33181 .34276 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.31228 .37692 m .33181 .34276 L .35949 .33778 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.34259 .62745 m .35949 .66222 L .33181 .65724 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.33181 .65724 m .31228 .62308 L .34259 .62745 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.72324 .54216 m .71386 .58285 L .68778 .58629 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.67394 .62534 m .68778 .58629 L .71386 .58285 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.71386 .41715 m .72324 .45784 L .69638 .45601 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.69638 .45601 m .68778 .41371 L .71386 .41715 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71113 .40452 m
.71771 .42497 L
s
.5 Mabswid
.274 .303 .218 r
.41137 .30478 m .42835 .28277 L .45868 .28027 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.44875 .698 m .45868 .71973 L .42835 .71723 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.42835 .71723 m .41137 .69522 L .44875 .698 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.42835 .28277 m .41137 .30478 L .37971 .30886 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71771 .42497 m
.71848 .43089 L
s
.5 Mabswid
.395 .499 .332 r
.72324 .45784 m .72642 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.6993 .5 m .69638 .45601 L .72324 .45784 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.72642 .5 m .72324 .54216 L .69638 .54399 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.68778 .58629 m .69638 .54399 L .72324 .54216 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.69638 .54399 m .6993 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71725 .43267 m
.71848 .43089 L
s
.5 Mabswid
.577 .79 .582 r
.55693 .71864 m .57052 .69679 L .60529 .69332 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.57052 .69679 m .55693 .71864 L .52506 .72046 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.55693 .28136 m .57052 .30321 L .5311 .30117 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.5311 .30117 m .52506 .27954 L .55693 .28136 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.39609 .66628 m .41137 .69522 L .37971 .69114 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.37971 .69114 m .35949 .66222 L .39609 .66628 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.35949 .33778 m .37971 .30886 L .41137 .30478 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.32983 .58786 m .34259 .62745 L .31228 .62308 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.31228 .62308 m .29763 .58461 L .32983 .58786 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.35949 .33778 m .34259 .37255 L .31228 .37692 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.29763 .41539 m .31228 .37692 L .34259 .37255 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7145 .43232 m
.71725 .43267 L
s
.5 Mabswid
.3 .337 .239 r
.44875 .302 m .45868 .28027 L .4916 .27916 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.48957 .69924 m .4916 .72084 L .45868 .71973 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.45868 .71973 m .44875 .698 L .48957 .69924 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.45868 .28027 m .44875 .302 L .41137 .30478 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.65555 .34018 m .67394 .37466 L .63828 .37064 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.63828 .37064 m .62323 .33561 L .65555 .34018 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.67394 .62534 m .65555 .65982 L .62323 .66439 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.60529 .69332 m .62323 .66439 L .65555 .65982 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.52506 .72046 m .5311 .69883 L .57052 .69679 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.52506 .27954 m .5311 .30117 L .48957 .30076 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.48957 .30076 m .4916 .27916 L .52506 .27954 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.5311 .69883 m .52506 .72046 L .4916 .72084 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.71209 .43006 m
.7145 .43232 L
s
.5 Mabswid
.629 .854 .639 r
.4916 .72084 m .48957 .69924 L .5311 .69883 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.4916 .27916 m .48957 .30076 L .44875 .302 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70111 .40279 m
.70953 .43175 L
s
.5 Mabswid
.605 .814 .594 r
.62323 .66439 m .60529 .69332 L .57052 .69679 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.60529 .30668 m .62323 .33561 L .58279 .33214 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.58279 .33214 m .57052 .30321 L .60529 .30668 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70749 .42357 m
.71209 .43006 L
s
.5 Mabswid
.565 .74 .573 r
.32189 .54482 m .32983 .58786 L .29763 .58461 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.29763 .58461 m .28856 .54309 L .32189 .54482 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.34259 .37255 m .32983 .41214 L .29763 .41539 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.28856 .45691 m .29763 .41539 L .32983 .41214 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.32983 .41214 m .32189 .45518 L .28856 .45691 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.28548 .5 m .28856 .45691 L .32189 .45518 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.3192 .5 m .32189 .54482 L .28856 .54309 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.28856 .54309 m .28548 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.41137 .30478 m .39609 .33372 L .35949 .33778 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.34259 .37255 m .35949 .33778 L .39609 .33372 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.38325 .63104 m .39609 .66628 L .35949 .66222 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.35949 .66222 m .34259 .62745 L .38325 .63104 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.32189 .45518 m .3192 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.43977 .66907 m .44875 .698 L .41137 .69522 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.41137 .69522 m .39609 .66628 L .43977 .66907 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.39609 .33372 m .41137 .30478 L .44875 .302 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.68778 .58629 m .67394 .62534 L .63828 .62936 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.62323 .66439 m .63828 .62936 L .67394 .62534 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.67394 .37466 m .68778 .41371 L .64966 .41072 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.64966 .41072 m .63828 .37064 L .67394 .37466 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69747 .41435 m
.69864 .41853 L
s
.69442 .4079 m
.69747 .41435 L
s
.69069 .40339 m
.69442 .4079 L
s
.69864 .41853 m
.69907 .42465 L
s
.68755 .40097 m
.69069 .40339 L
s
.69762 .42857 m
.69907 .42465 L
s
.5 Mabswid
.605 .814 .594 r
.57052 .69679 m .58279 .66786 L .62323 .66439 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.58279 .66786 m .57052 .69679 L .5311 .69883 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.57052 .30321 m .58279 .33214 L .53658 .3301 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.53658 .3301 m .5311 .30117 L .57052 .30321 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68374 .40053 m
.68755 .40097 L
s
.5 Mabswid
.542 .707 .498 r
.69638 .54399 m .68778 .58629 L .64966 .58928 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.63828 .62936 m .64966 .58928 L .68778 .58629 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.68778 .41371 m .69638 .45601 L .65676 .45441 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.65676 .45441 m .64966 .41072 L .68778 .41371 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69556 .43042 m
.69762 .42857 L
s
.5 Mabswid
.402 .484 .33 r
.62323 .33561 m .63828 .37064 L .59314 .36757 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.59314 .36757 m .58279 .33214 L .62323 .33561 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.63828 .62936 m .62323 .66439 L .58279 .66786 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68177 .40238 m
.68374 .40053 L
s
.5 Mabswid
.655 .877 .658 r
.48773 .67031 m .48957 .69924 L .44875 .698 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.44875 .698 m .43977 .66907 L .48773 .67031 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.43977 .33093 m .44875 .302 L .48957 .30076 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.44875 .302 m .43977 .33093 L .39609 .33372 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69162 .4301 m
.69556 .43042 L
s
.68032 .40639 m
.68177 .40238 L
s
.5 Mabswid
.625 .824 .628 r
.3735 .59054 m .38325 .63104 L .34259 .62745 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.34259 .62745 m .32983 .58786 L .3735 .59054 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.39609 .33372 m .38325 .36896 L .34259 .37255 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.32983 .41214 m .34259 .37255 L .38325 .36896 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.5311 .69883 m .53658 .6699 L .58279 .66786 L p F P
.505 .664 .505 r
s
.651 .872 .648 r
.53658 .6699 m .5311 .69883 L .48957 .69924 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.5311 .30117 m .53658 .3301 L .48773 .32969 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.48773 .32969 m .48957 .30076 L .5311 .30117 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.69638 .45601 m .6993 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.65918 .5 m .65676 .45441 L .69638 .45601 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.6993 .5 m .69638 .54399 L .65676 .54559 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.64966 .58928 m .65676 .54559 L .69638 .54399 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68844 .4278 m
.69162 .4301 L
s
.5 Mabswid
.651 .872 .648 r
.48957 .69924 m .48773 .67031 L .53658 .6699 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.48957 .30076 m .48773 .32969 L .43977 .33093 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68032 .40639 m
.68069 .41266 L
s
.5 Mabswid
.519 .668 .467 r
.65676 .54559 m .65918 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68471 .42338 m
.68844 .4278 L
s
.68069 .41266 m
.68178 .41692 L
s
.5 Mabswid
.449 .547 .402 r
.38325 .36896 m .39609 .33372 L .43977 .33093 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.43218 .63351 m .43977 .66907 L .39609 .66628 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.39609 .66628 m .38325 .63104 L .43218 .63351 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68178 .41692 m
.68471 .42338 L
s
.5 Mabswid
.473 .586 .441 r
.38325 .36896 m .3735 .40946 L .32983 .41214 L p F P
.505 .664 .505 r
s
.522 .657 .495 r
.32189 .45518 m .32983 .41214 L .3735 .40946 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.36741 .54626 m .3735 .59054 L .32983 .58786 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.32983 .58786 m .32189 .54482 L .36741 .54626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66683 .39886 m
.6758 .43964 L
s
.6758 .43964 m
.67665 .4435 L
s
.5 Mabswid
.605 .795 .573 r
.64966 .58928 m .63828 .62936 L .59314 .63243 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.58279 .66786 m .59314 .63243 L .63828 .62936 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.63828 .37064 m .64966 .41072 L .60101 .40842 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.60101 .40842 m .59314 .36757 L .63828 .37064 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.58279 .33214 m .59314 .36757 L .54122 .36576 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.54122 .36576 m .53658 .3301 L .58279 .33214 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.59314 .63243 m .58279 .66786 L .53658 .6699 L p F P
.505 .664 .505 r
s
.522 .657 .495 r
.3735 .40946 m .36741 .45374 L .32189 .45518 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.3192 .5 m .32189 .45518 L .36741 .45374 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.36534 .5 m .36741 .54626 L .32189 .54482 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.32189 .54482 m .3192 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.36741 .45374 m .36534 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66119 .43246 m
.66331 .44289 L
s
.5 Mabswid
.464 .567 .41 r
.43218 .36649 m .43977 .33093 L .48773 .32969 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.48617 .63462 m .48773 .67031 L .43977 .66907 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.43977 .66907 m .43218 .63351 L .48617 .63462 L p F P
.505 .664 .505 r
s
.449 .547 .402 r
.43977 .33093 m .43218 .36649 L .38325 .36896 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.42641 .59239 m .43218 .63351 L .38325 .63104 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.38325 .63104 m .3735 .59054 L .42641 .59239 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.3735 .40946 m .38325 .36896 L .43218 .36649 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.65676 .54559 m .64966 .58928 L .60101 .59158 L p F P
.505 .664 .505 r
s
.605 .795 .573 r
.59314 .63243 m .60101 .59158 L .64966 .58928 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.64966 .41072 m .65676 .45441 L .60593 .45318 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65414 .39782 m
.66119 .43246 L
s
.5 Mabswid
.505 .634 .445 r
.60593 .45318 m .60101 .40842 L .64966 .41072 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.53658 .6699 m .54122 .63424 L .59314 .63243 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.53658 .3301 m .54122 .36576 L .48617 .36538 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.48617 .36538 m .48773 .32969 L .53658 .3301 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.54122 .63424 m .53658 .6699 L .48773 .67031 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.48773 .67031 m .48617 .63462 L .54122 .63424 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.48773 .32969 m .48617 .36538 L .43218 .36649 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.64194 .40346 m
.64519 .41013 L
s
.63729 .39884 m
.64194 .40346 L
s
.64519 .41013 m
.64609 .4145 L
s
.63311 .39642 m
.63729 .39884 L
s
.6455 .42092 m
.64609 .4145 L
s
.6275 .39609 m
.63311 .39642 L
s
.5 Mabswid
.541 .688 .487 r
.65676 .45441 m .65918 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.6076 .5 m .60593 .45318 L .65676 .45441 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.65918 .5 m .65676 .54559 L .60593 .54682 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.60101 .59158 m .60593 .54682 L .65676 .54559 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.60101 .59158 m .59314 .63243 L .54122 .63424 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.59314 .36757 m .60101 .40842 L .54475 .40706 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.54475 .40706 m .54122 .36576 L .59314 .36757 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.64252 .42508 m
.6455 .42092 L
s
.62417 .3981 m
.6275 .39609 L
s
.5 Mabswid
.569 .732 .521 r
.60593 .54682 m .6076 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.63906 .42707 m
.64252 .42508 L
s
.5 Mabswid
.631 .821 .615 r
.42279 .54725 m .42641 .59239 L .3735 .59054 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.3735 .59054 m .36741 .54626 L .42279 .54725 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.43218 .36649 m .42641 .40761 L .3735 .40946 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.36741 .45374 m .3735 .40946 L .42641 .40761 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.62117 .40234 m
.62417 .3981 L
s
.63322 .42684 m
.63906 .42707 L
s
.62042 .40889 m
.62117 .40234 L
s
.5 Mabswid
.651 .854 .635 r
.48498 .59322 m .48617 .63462 L .43218 .63351 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.43218 .63351 m .42641 .59239 L .48498 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.42641 .40761 m .43218 .36649 L .48617 .36538 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.62893 .42451 m
.63322 .42684 L
s
.62042 .40889 m
.62118 .41331 L
s
.62426 .41999 m
.62893 .42451 L
s
.62118 .41331 m
.62426 .41999 L
s
.5 Mabswid
.632 .829 .604 r
.54122 .63424 m .54475 .59294 L .60101 .59158 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.54122 .36576 m .54475 .40706 L .48498 .40678 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.48498 .40678 m .48617 .36538 L .54122 .36576 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.54475 .59294 m .54122 .63424 L .48617 .63462 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.42641 .40761 m .42279 .45275 L .36741 .45374 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.36534 .5 m .36741 .45374 L .42279 .45275 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.42155 .5 m .42279 .54725 L .36741 .54626 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.36741 .54626 m .36534 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.59799 .39693 m
.60292 .40156 L
s
.60292 .40156 m
.60608 .40832 L
s
.5 Mabswid
.538 .677 .483 r
.60101 .40842 m .60593 .45318 L .54696 .45245 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.54696 .45245 m .54475 .40706 L .60101 .40842 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.576 .37832 m
.58197 .42532 L
s
.5 Mabswid
.617 .802 .582 r
.60593 .54682 m .60101 .59158 L .54475 .59294 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.59341 .39453 m
.59799 .39693 L
s
.5 Mabswid
.646 .847 .624 r
.48617 .63462 m .48498 .59322 L .54475 .59294 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.48617 .36538 m .48498 .40678 L .42641 .40761 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.58703 .39431 m
.59341 .39453 L
s
.5 Mabswid
.583 .744 .554 r
.42279 .45275 m .42155 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.60608 .40832 m
.60675 .41276 L
s
.60555 .41933 m
.60675 .41276 L
s
.58305 .39641 m
.58703 .39431 L
s
.57928 .40077 m
.58305 .39641 L
s
.60179 .42361 m
.60555 .41933 L
s
.59767 .42569 m
.60179 .42361 L
s
.5579 .43049 m
.56958 .39378 L
s
.5548 .44025 m
.5579 .43049 L
s
.5 Mabswid
.636 .827 .612 r
.48424 .5477 m .48498 .59322 L .42641 .59239 L p F P
.505 .664 .505 r
s
.636 .827 .612 r
.42641 .59239 m .42279 .54725 L .48424 .5477 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.42279 .45275 m .42641 .40761 L .48498 .40678 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.60593 .45318 m .6076 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.54772 .5 m .54696 .45245 L .60593 .45318 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.6076 .5 m .60593 .54682 L .54696 .54755 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.54475 .59294 m .54696 .54755 L .60593 .54682 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.59101 .42552 m
.59767 .42569 L
s
.58629 .42321 m
.59101 .42552 L
s
.58133 .41867 m
.58629 .42321 L
s
.5 Mabswid
.597 .768 .555 r
.54696 .54755 m .54772 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.54475 .40706 m .54696 .45245 L .48424 .4523 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54687 .42293 m
.5548 .44025 L
s
.54641 .42193 m
.54687 .42293 L
s
.5 Mabswid
.554 .699 .506 r
.48424 .4523 m .48498 .40678 L .54475 .40706 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.5332 .39308 m
.54641 .42193 L
s
.5 Mabswid
.632 .82 .601 r
.54696 .54755 m .54475 .59294 L .48498 .59322 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54116 .409 m
.56449 .40938 L
s
.5 Mabswid
.632 .82 .601 r
.48498 .59322 m .48424 .5477 L .54696 .54755 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.48498 .40678 m .48424 .4523 L .42279 .45275 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.42155 .5 m .42279 .45275 L .48424 .4523 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.48398 .5 m .48424 .5477 L .42279 .54725 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.42279 .54725 m .42155 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.48424 .4523 m .48398 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.54696 .45245 m .54772 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.48398 .5 m .48424 .4523 L .54696 .45245 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.54772 .5 m .54696 .54755 L .48424 .5477 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.48424 .5477 m .48398 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003U0;3PiPl0PJV10`0T9ad0
0`21ZH409BPN02DX7P0602DX7P03086YP@0T9ad092LM00P0PJV1j02`h>H10?ooo`00h02`h>H6086Y
P@L08B@K0P21ZH4702@W7@03086YP@0U:1h09BPN00L09BPN00<0PJV102@W7@0T9ad01@0T9ad2086Y
P@03020S6`21ZH40PJV100@0PJV1hP2`h>H10?ooo`00g@2`h>H3086YP@806ahG0P21ZH47024T6`80
PJV12@0T9ad00`21ZH409BPN02DX7P0802DX7P03086YP@0T9ad092LM00H092LM0P21ZH44020S6`L0
PJV1g02`h>H10?ooo`00fP2`h>H4086YP@806ahG0P21ZH43024T6b<0PJV1100T9ad2086YP@D082<K
0P21ZH400`0J7QL0PJV1086YP@03086YPMP0/>3V0@3oool00=H0/>3V1@21ZH400`0K7QL0PJV1086Y
P@07086YP@@0<S<W00<0PJV103Hg:P0f=bX02P0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f
=bX0=SLZ0080=SLZ3021ZH401@0P8a/0PJV1086YP@21ZH406QhG0080PJV100<04QHA086YP@2`h>H0
e@2`h>H10?ooo`00e02`h>H00`21ZH404aLA086YP@05086YP@0302/]8P21ZH40<S<W00T0<S<W00<0
PJV103Hg:P0f=bX02`0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0
PJV1038c9`0b<bL00P0b<bL<086YPM<0/>3V0@3oool00=40/>3V00<0PJV101<G4@21ZH400`21ZH45
02/]8P03086YP@0b<bL0<S<W00P0<S<W00<0PJV103Hg:P0f=bX0300f=bX00`21ZH40=cP[03Lh:`0;
03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0PJV1038c9`0b<bL01`0b<bL9086YPM00/>3V0@3oool0
0<h0/>3V1P21ZH4702/]8P03086YP@0b<bL0<S<W00T0<S<W00<0PJV103Hg:P0f=bX02`0f=bX00`21
ZH40=cP[03Lh:`0<03Lh:`03086YP@0f=bX0=SLZ00X0=SLZ00<0PJV1038c9`0b<bL0200b<bL01021
ZH40:RdR02X]8P0Z;B85086YPLh0/>3V0@3oool00</0/>3V1021ZH400`0Q91/0PJV1086YP@0702/]
8P80PJV12`0b<bL00`21ZH40=SLZ03Hg:P0<03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg
:P0f=bX02P0f=bX00`21ZH40<S<W038c9`08038c9`80PJV1100Z;B85086YPL/0/>3V0@3oool00<T0
/>3V0`21ZH43024T6`03086YP@0[;B80:bdR00H0:bdR00<0PJV1038c9`0b<bL02P0b<bL00`21ZH40
=SLZ03Hg:P0=03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg:P0f=bX02`0f=bX00`21ZH40
<S<W038c9`09038c9`80PJV1100Z;B82086YP@03020S6P21ZH40PJV10<T0/>3V0@3oool00<L0/>3V
0`21ZH43024T6`80PJV1200[;B800`21ZH40<S<W038c9`07038c9bd0PJV11P0f=bX00`21ZH40<S<W
038c9`0:038c9`03086YP@0Z;B80:RdR00<0:RdR00<0PJV1020S6P0P8aX00P21ZH770;3PiP40oooo
00350;3PiP<0PJV10`0Q91/2086YP@T0:bdR00<0PJV1038c9`0b<bL02021ZH4304I==`03086YP@1<
ESd0C5Hm00h0C5Hm00<0PJV104mI?P1?FCh03P1?FCh00`21ZH40CEHm04eF?@0504eF?@l0PJV11@0b
<bL2086YP@@0:RdR0P21ZH42020S6P80PJV1a@2`h>H10?ooo`00``2`h>H00`21ZH4051PB086YP@03
024T6`80PJV1100[;B8:086YP@X0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI?P0?
04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL01016CCL9086YP@@0:RdR00@0PJV1
020S6P0P8aX082<J0P21ZH730;3PiP40oooo00310;3PiP04086YP@0D6180PJV1086YP@808B@K2021
ZH4503Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL03016CCL5086YP@0302X]8P21
ZH40PJV100<082<J0P21ZH710;3PiP40oooo002o0;3PiP05086YP@0D6180PJV1086YP@0Q91/01021
ZH4<03Xn;P03086YP@16CCL0ATdg00/0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00d0CEHm00<0PJV104I==`16CCL03016CCL01021ZH40>Sd]03Xm
;@0j?Bd5086YP@<082<J0P21ZH6o0;3PiP40oooo002m0;3PiP03086YP@0D6180PJV100@0PJV10P0/
;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd0401<
ESd00`21ZH40CeTn04mI?P0?04mI?P03086YP@1=ESd0CEHm00h0CEHm00<0PJV104I==`16CCL02`16
CCL00`21ZH40>Sd]03Xm;@0503Xm;@@0PJV10P0P8aX2086YPKd0/>3V0@3oool00;/0/>3V00<0PJV1
01@H4P21ZH400P21ZH4502`_8`03086YP@0j?Rh0>Sh^00X0>Sh^00<0PJV104I==`16CCL03016CCL0
0`21ZH40C5Hm04aF?@0@04aF?@03086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03@1=ESd0
0`21ZH40ATdg04I==`0<04I==`03086YP@0j?Bd0>Sd]00H0>Sd]00<0PJV102`^8`21ZH401@21ZH6k
0;3PiP40oooo002i0;3PiPD0PJV11P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg
00d0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI?P0A04mI?P03086YP@1=ESd0CEHm
00h0CEHm00<0PJV104I==`16CCL03016CCL00`21ZH40>Sd]03Xm;@0603Xm;@03086YP@0/;R<0;2hS
0080;2hS0`21ZH6j0;3PiP40oooo002g0;3PiP80PJV10`0M8AT00`21ZH40;2lS02`_8`0402`_8`03
086YP@0j?Rh0>Sh^00/0>Sh^00<0PJV104I==`16CCL03016CCL00`21ZH40C5Hm04aF?@0A04aF?@03
086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03P1=ESd00`21ZH40ATdg04I==`0=04I==`03
086YP@0j?Bd0>Sd]00H0>Sd]0P21ZH4502`^8`80PJV1^02`h>H10?ooo`00]P2`h>H01021ZH407B4I
01dQ6@0M8AT2086YP@H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh00`21ZH40ATdg04I==`0=04I==`03
086YP@1<ESd0C5Hm0140C5Hm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40CEHm04eF?@0?04eF?@03
086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0
PJV1]P2`h>H10?ooo`00]@2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV100P0;2lS00<0PJV103Xn;P0j
?Rh02P0j?Rh00`21ZH40ATdg04I==`0=04I==`03086YP@1<ESd0C5Hm0180C5Hm00<0PJV104mI?P1?
FCh04P1?FCh00`21ZH40CEHm04eF?@0?04eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j
?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0PJV1]@2`h>H10?ooo`00/`2`h>H2086YP@<07B4I
00<0PJV102`_8`0/;b<01P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00X0ATdg
>021ZH4804eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd0200j?Bd00`21ZH40;2hS
02`^8`0402`^8`<0PJV1/`2`h>H10?ooo`00/P2`h>H00`21ZH407B4I01dQ6@0201dQ6@03086YP@0/
;b<0;2lS00H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh01021ZH40ATdg04I==`16CCL9086YP@@0Gg1B
00<0PJV106AgE@1TMeD04P1TMeD00`21ZH40HgIC06=fD`0B06=fD`03086YP@1NKd`0GVm<00L0GVm<
3P21ZH4;04I==`03086YP@0j?Bd0>Sd]00P0>Sd]00<0PJV102`^8`0/;R<0100/;R<00`21ZH4071lH
086YP@2b0;3PiP40oooo002a0;3PiP03086YP@0M8AT07B4I00807B4I00<0PJV102`_8`0/;b<01P0/
;b<00`21ZH40>Sh^03Xn;P0803Xn;PP0PJV1301OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1S
MU<0HgIC0180HgIC00<0PJV105i_C01NKd`0401NKd`00`21ZH40F6M705QWA`0205QWA`T0PJV10`16
CCL00`21ZH40>Sd]03Xm;@0803Xm;@80PJV11@0/;R<00`21ZH4071lH086YP@2a0;3PiP40oooo002`
0;3PiP04086YP@0M8AT07B4I01dQ6@80PJV1200/;b<01021ZH40>Sh^03Xn;P0j?Rh8086YP@80E658
00<0PJV105m`DP1OL5803`1OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC0180HgIC
00<0PJV105i_C01NKd`04@1NKd`00`21ZH40F6M705QWA`0:05QWA`P0PJV1200j?Bd00`21ZH40;2hS
02`^8`0302`^8`04086YP@0L7aP0PJV1086YPJl0/>3V0@3oool00:l0/>3V00D0PJV101dQ6@0M8AT0
7B4I086YP@0702`_8`L0PJV12P1DHDP00`21ZH40Gg1B05m`DP0?05m`DP03086YP@1TMeD0I7ME01<0
I7ME00<0PJV106=fD`1SMU<04`1SMU<00`21ZH40GVm<05i_C00@05i_C003086YP@1HIdL0F6M700l0
F6M700<0PJV104eG?@1=Ecd01`21ZH4203Xm;@03086YP@0/;R<0;2hS00<0;2hS00@0PJV101`O600L
7aP0PJV1[P2`h>H10?ooo`00[P2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV10080;2lS1P21ZH400`10
AcL0PJV105AQB00=05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21
ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21
ZH40CELm04eG?@0704eG?@D0PJV1100/;R<2086YP@0301`O6021ZH40/>3V0:`0/>3V0@3oool00:`0
/>3V0P21ZH4201dQ6@D0PJV11`10AcL00`21ZH40E65805AQB00<05AQB003086YP@1OL580Gg1B00l0
Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140
GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@@0PJV10`0/;R<01021ZH40
71lH086YP@21ZH6[0;3PiP40oooo002[0;3PiP03086YP@0M8AT07B4I00<0PJV12P10AcL00`21ZH40
E65805AQB00<05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40
HgIC06=fD`0D06=fD`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21ZH40
CELm04eG?@0;04eG?@03086YP@0i?Rh0>Ch^00D0PJV10P0L7aP00`21ZH40/>3V0;3PiP2X0;3PiP40
oooo002Z0;3PiP@0PJV100<09b/Q086YP@10AcL02@10AcL00`21ZH40E65805AQB00=05AQB003086Y
P@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgIC06=fD`0D06=fD`03086Y
P@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@03086Y
P@0i?Rh0>Ch^00@0>Ch^0`21ZH400`0L7aP0PJV10;3PiP2X0;3PiP40oooo002Y0;3PiP80PJV1100W
:b400`21ZH40@4Lg0417=`070417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`DP1OL5804@1O
L5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC01@0HgIC00<0PJV105i_C01NKd`04P1N
Kd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn;P0i?Rh01@0i
?Rh5086YPJL0/>3V0@3oool00:L0/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00P0@4Lg00<0PJV1
05AQB01DHDP0301DHDP00`21ZH40Gg1B05m`DP0A05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV1
06=fD`1SMU<0501SMU<00`21ZH40GVm<05i_C00C05i_C003086YP@1HIdL0F6M700l0F6M700<0PJV1
04eG?@1=Ecd02`1=Ecd00`21ZH40>Ch^03Tn;P0503Tn;P03086YP@0T9ad092LM0080PJV1YP2`h>H1
0?ooo`00YP2`h>H2086YP@D09b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQ
B003086YP@1OL580Gg1B0140Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0E06=f
D`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL0401HIdL00`21ZH40CELm04eG?@0;04eG
?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2U0;3PiP40oooo002U0;3P
iP80PJV11@0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`
DP1OL5804P1OL5800`21ZH40I7ME06AgE@0D06AgE@03086YP@1SMU<0HgIC01D0HgIC00<0PJV105i_
C01NKd`04`1NKd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn
;P0i?Rh01@0i?Rh00`21ZH4092LM02@W7@0202@W7@03086YP@2`h>H0/>3V0:80/>3V0@3oool00:@0
/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00T0@4Lg00<0PJV105AQB01DHDP03@1DHDP00`21ZH40
Gg1B05m`DP0B05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=fD`1SMU<05@1SMU<00`21ZH40
GVm<05i_C00C05i_C003086YP@1HIdL0F6M70100F6M700<0PJV104eG?@1=Ecd02`1=Ecd00`21ZH40
>Ch^03Tn;P0503Tn;P05086YP@0T9ad092LM02@W7@21ZH40Y02`h>H10?ooo`00X`2`h>H2086YP@H0
9b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQB003086YP@1OL580Gg1B0180
Gg1B00<0PJV106AgE@1TMeD02P1TMeD_086YP@/0GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40
CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2S0;3P
iP40oooo002R0;3PiP80PJV11P0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800h0
E65800<0PJV105m`DP1OL580201OL58G086YP@/0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40
LHUP0769H0090769H100PJV13P1HIdL00`21ZH40CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0
>Ch^00D0PJV102@W7@0T9ad092LM086YP@2R0;3PiP40oooo002Q0;3PiP80PJV11P0W:b400`21ZH40
@4Lg0417=`080417=`03086YP@1DHDP0E65800X0E6584021ZH4:07:<IP03086YP@1fTFP0MY5X01D0
MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D0080
IW]D2P21ZH4405QWA`03086YP@1=Ecd0CELm00d0CELm00<0PJV103Tn;P0i?Rh01@0i?Rh01@21ZH40
92LM02@W7@0T9ad0PJV10:40/>3V0@3oool00:00/>3V00<0PJV1010D4021ZH401@0W:b400`21ZH40
@4Lg0417=`090417=`04086YP@1DHDP0E65805AQB0T0PJV1101YOel00`21ZH40LXaV07:<IP0C07:<
IP03086YP@1fTFP0MY5X01D0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00E0769
H003086YP@1VNe@0IW]D00/0IW]D2P21ZH4:04eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00D0PJV102@W
7@0T9ad092LM086YP@2P0;3PiP40oooo002O0;3PiP03086YP@0@5100PJV100D09b/Q00<0PJV10417
=`10AcL01`10AcL7086YP@`0JGmO00<0PJV107:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00F07JA
J003086YP@1fT6H0MY1V01H0MY1V00<0PJV10769H01aRF00501aRF000`21ZH40IW]D06IkE00@06Ik
E003086YP@1KK4T0Ffa90080Ffa92021ZH4304eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00@0PJV102@W
7@0T9ad0PJV1X02`h>H10?ooo`00WP2`h>H00`21ZH4041@@086YP@0602L[8@03086YP@10AcL0@4Lg
00<0@4Lg1021ZH400`1GIdl0PJV106UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JA
J01fTFP05P1fTFP00`21ZH40MY1V07J@IP0F07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106Ik
E01VNe@04@1VNe@00`21ZH40Ffa905]/B@0905]/B@H0PJV11P0i?Rh01@21ZH4092LM02@W7@0T9ad0
PJV109l0/>3V0@3oool009h0/>3V00<041@@086YP@0W:b401@0W:b400`21ZH40@4Lg086YP@04086Y
P@D0EfM?00<0PJV106UoG`1YOel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X
01H0MY5X00<0PJV107J@IP1fT6H05P1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D
0140IW]D00<0PJV105]/B@1KK4T03P1KK4T5086YP@<0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2N
0;3PiP40oooo002M0;3PiP03010D4021ZH409b/Q00<09b/Q1@21ZH4905MWC`03086YP@1YOel0JGmO
00l0JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V
01H0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00A06IkE003086YP@1KK4T0Ffa9
00d0Ffa900<0PJV104QD>`18E3/00P18E3/5086YP@<092LM00<0PJV10;3PiP2`h>H0V`2`h>H10?oo
o`00W02`h>H00`0@5100PJV102L[8@04086YP@0303Po=021ZH40EfM?00/0EfM?00<0PJV106UoG`1Y
Oel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X01L0MY5X00<0PJV107J@IP1f
T6H05P1fT6H00`21ZH40LHUP0769H00E0769H003086YP@1VNe@0IW]D0140IW]D00<0PJV105]/B@1K
K4T03P1KK4T00`21ZH40B5@k04QD>`0504QD>`80PJV10`0T9ad00`21ZH40/>3V0;3PiP2J0;3PiP40
oooo002K0;3PiP04010D4021ZH40PJV1086YP@D0>3ld00<0PJV105MWC`1GIdl02@1GIdl00`21ZH40
JGmO06UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40
MY1V07J@IP0G07J@IP03086YP@1aRF00LHUP01D0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40
Ffa905]/B@0=05]/B@03086YP@18E3/0B5@k00L0B5@k0P21ZH400`0T9ad0PJV10;3PiP2K0;3PiP40
oooo002J0;3PiP03010D4021ZH40>3ld00H0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO
06UoG`0?06UoG`03086YP@1bS6H0LXaV01@0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40MY1V
07J@IP0H07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40Ffa9
05]/B@0>05]/B@03086YP@18E3/0B5@k00H0B5@k00<0PJV102/^8`21ZH400P21ZH6K0;3PiP40oooo
002I0;3PiP<0PJV11`0h?c@00`21ZH40EfM?05MWC`0905MWC`03086YP@1YOel0JGmO0100JGmO00<0
PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0
PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900d0Ffa900<0
PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02086YPIX0/>3V0@3oool009P0/>3V00<0PJV1
01TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV1
07:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0PJV1
0769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV1
04QD>`18E3/01P18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V09L0/>3V0@3oool0
09L0/>3V00@0PJV101TN6@0I7QT0PJV11P0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109T0/>3V0@3o
ool009L0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0
Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109P0/>3V0@3o
ool009H0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0
/>3V09D0/>3V0@3oool009D0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C
06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[
;R<0PJV109L0/>3V0@3oool009D0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00D
06IkE003086YP@1KK4T0Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02
02/^8`03086YP@2`h>H0/>3V09@0/>3V0@3oool009@0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@0
0`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H03`1bS6I9
086YP@`0LHUP00<0PJV106IkE01VNe@04`1VNe@00`21ZH40Ffa905]/B@0>05]/B@03086YP@18E3/0
B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP03086YP@0I7QT0PJV100L0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO06UoG`0A06Uo
G`03086YP@1bS6H0LXaV00@0LXaV3021ZH45086PMP03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108>S
M@23XgD06@23XgD00`21ZH40OYe_07jMK`0:07jMKaP0PJV12`1VNe@00`21ZH40Ffa905]/B@0=05]/
B@03086YP@18E3/0B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3P
iP40oooo002C0;3PiP04086YP@0I7QT06AhI086YP@H0>3ld00<0PJV105MWC`1GIdl02`1GIdl00`21
ZH40JGmO06UoG`0706UoGa40PJV14@21X7H00`21ZH40Q:Ah08BTN00H08BTN003086YP@23XgD0Pj=e
01T0Pj=e00<0PJV107jMK`1nWFl05P1nWFl00`21ZH40MI5T07FAI00907FAI100PJV1301KK4T00`21
ZH40B5@k04QD>`0704QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3PiP2`h>H0TP2`h>H10?oo
o`00TP2`h>H01021ZH406AhI01TN6@21ZH4703Po=003086YP@1GIdl0EfM?00P0EfM?3@21ZH4:07VF
L003086YP@21X7H0PJ1f01D0PJ1f00<0PJV108BTN024Y7P06024Y7P00`21ZH40Pj=e08>SM@0I08>S
M@03086YP@1nWFl0OYe_01H0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0206El
D`T0PJV10`1KK4T00`21ZH40B5@k04QD>`0804QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3P
iP2`h>H0T@2`h>H10?ooo`00TP2`h>H00`21ZH406AhI086YP@0703Po=003086YP@1GIdl0EfM?00@0
EfM?1@21ZH4206R0H`03086YP@1iUW00NII`0140NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40
Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40
MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00X0IGaC1P21ZH4804QD>`03086YP@0[;R<0:bhS00<0
:bhS00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00T@2`h>H01021ZH406AhI01TN6@21ZH4703Po=003
086YP@1GIdl0PJV100@0PJV11P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0
PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01L0
OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0PJV100<0
PJV11@18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V0900/>3V0@3oool00900/>3V
00@0PJV101TN6@0I7QT0PJV11@0h?c@5086YP@/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40
PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40
OYe_07jMK`0=07jMK`80ogl0201nWFl00`21ZH40MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00l0
IGaC00<0PJV105AUA@1DIDD00P1DIDD4086YP@0304QD>`21ZH40:bhS00@0:bhS00<0PJV10;3PiP2`
h>H0S`2`h>H10?ooo`00T02`h>H00`21ZH406AhI01TN6@0203Po=0@0PJV10P1;FdT00`21ZH40J81S
06R0H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40Q:Ah
08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl03P1nWFl20?mo00L0OYe_
00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500H0E6E5
1021ZH4402/^8`03086YP@2`h>H0/>3V08h0/>3V0@3oool008l0/>3V00<0PJV101TN6@0I7QT00`21
ZH4504]KB@03086YP@1XP6<0J81S00/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086P
MP0F086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jM
K`0>07jMK`80ogl01`1nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0IGaC00h0IGaC00<0
PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]086YP@04086YPI00/>3V0@3oool008l0/>3V00@06AhI
086YP@21ZH40PJV11`1;FdT00`21ZH40J81S06R0H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0
PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0
PJV107jMK`1nWFl03P1nWFl20?mo00P0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06El
D`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV103M0;@0g@2d00P0g@2d2086YPHl0/>3V0@3o
ool008h0/>3V0P21ZH400`0T;2L0PJV104]KB@0704]KB@03086YP@1XP6<0J81S00/0J81S00<0PJV1
07VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0F086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV1
08>SM@23XgD06@23XgD00`21ZH40OYe_07jMK`0>07jMK`80ogl0201nWFl00`21ZH40MI5T07FAI00D
07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@04
03M0;Hl0/>3V0@3oool008h0/>3V00@0PJV102@/9`0T;2L0PJV11`1;FdT00`21ZH40J81S06R0H`0<
06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40Q:Ah08BTN00J
08BTN003086YP@23XgD0Pj=e01X0Pj=e00<0PJV107jMK`1nWFl03@1nWFl20?mo00P0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV1
03M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3PiP04086YP@0T;2L092`W
086YP@P0Be]900<0PJV106R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0
PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0
OYe_00d0OYe_0P3oO`0807jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV106ElD`1UO5<03`1UO5<0
0`21ZH40E6E505AUA@0805AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0S02`h>H1
0?ooo`00S@2`h>H01021ZH4092`W02@/9`21ZH4704]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV1
07VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0F086PMP03086YP@24Y7P0Q:Ah01X0Q:Ah00<0PJV1
08>SM@23XgD05@23XgD00`3oO`00Pj=e08>SM@0208>SM@03086YP@1nWFl0OYe_00X0OYe_00<0ogl0
07jMK`1nWFl00P3oO`0307jMK`060?mo001nWFl0OYe_07jMK`3oO`00PJV15`1eTF@00`21ZH40IGaC
06ElD`0?06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V
0;3PiP2;0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1XP6<0
301XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P0
6P24Y7P00`21ZH40Pj=e08>SM@0D08>SM@<0ogl00`23XgD00`21ZH40OYe_07jMK`0907jMK`<0ogl0
00@0OYe_0?mo003oO`00OYe_203oO`000`21ZH40MI5T07FAI00<07FAI0030?mo001eTF@0ogl000H0
MI5T00<0PJV106ElD`1UO5<03P1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00<0
=d0]00<0PJV10;3PiP2`h>H0R`2`h>H10?ooo`00S02`h>H01021ZH4092`W02@/9`21ZH4804]KB@03
086YP@1XP6<0J81S00/0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086PMP0F086PMP03
086YP@24Y7P0Q:Ah01X0Q:Ah00<0PJV108>SM@23XgD05@23XgD20?mo00<0Pj=e00<0PJV107jMK`1n
WFl02@1nWFl20?mo00<0OYe_2`3oO`0<07FAI0H0ogl01@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03
086YP@1DIDD0E6E500P0E6E500<0PJV103M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP2:0;3PiP40
oooo002;0;3PiP05086YP@0T;2L092`W02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0<06R0H`03
086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003
086YP@23XgD0Pj=e01D0Pj=e0`3oO`0208>SM@03086YP@1nWFl0OYe_00T0OYe_0P3oO`0307jMK`<0
ogl01P1nWFl30?mo00X0MI5T2@3oO`0307FAI003086YP@1UO5<0IGaC0080ogl01@1UO5<00`3oO`00
IGaC06ElD`0506ElD`03086YP@3oO`00E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40
/>3V0;3PiP2:0;3PiP40oooo002;0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1X
P6<0301XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01L0PJ1f00<0PJV108BTN024
Y7P06P24Y7P00`21ZH40Pj=e08>SM@0F08>SM@80ogl00P23XgD00`21ZH40OYe_07jMK`0807jMK`<0
ogl00`1nWFl20?mo00P0OYe_0`3oO`0807FAI0<0ogl0101eTF@40?mo0080MI5T00@0PJV106ElD`1U
O5<0IGaC0P3oO`0306ElD`<0ogl01P1UO5<40?mo00D0E6E500@0ogl005AUA@1DIDD0PJV11P0g@2d0
0`21ZH40/>3V0;3PiP290;3PiP40oooo002:0;3PiP05086YP@0T;2L092`W02@/9`21ZH40201;FdT0
0`21ZH40J81S06R0H`0;06R0H`03086YP@1iUW00NII`01<0NII`00<0PJV1086PMP21X7H05P21X7H0
0`21ZH40Q:Ah08BTN00K08BTN003086YP@23XgD0Pj=e01H0Pj=e0P3oO`0208>SM@03086YP@1nWFl0
OYe_00P0OYe_0P3oO`0407jMK`80ogl0201nWFl01021ZH40ogl00?mo003oO`0607FAI0<0ogl01`1e
TF@30?mo0080MI5T00<0PJV106ElD`1UO5<00P3oO`0406ElD`80ogl01@1UO5<60?mo00<0E6E50`3o
O`0205AUA@03086YP@3oO`00=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H0
1021ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW004`1i
UW000`21ZH40PJ1f086PMP0F086PMP03086YP@24Y7P0Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD05P23
XgD30?mo000308>SM@21ZH40OYe_00T0OYe_0P3oO`0407jMK`80ogl02@1nWFl00`21ZH40ogl00?mo
000607FAI080ogl02@1eTF@30?mo000407FAI021ZH40IGaC06ElD`80ogl0101UO5<20?mo00D0IGaC
0P3oO`000`21ZH40E6E50?mo00020?mo00<0E6E50P3oO`0205AUA@<0ogl000@0=d0]0?mo000g@2d0
PJV1R`2`h>H10?ooo`00RP2`h>H01021ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S00`0
J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0G086PMP03086YP@24Y7P0Q:Ah00d0
Q:Ah7@21ZH4;08>SM@80ogl000<0Pj=e086YP@1nWFl0201nWFl30?mo00@0OYe_0P3oO`0907jMK`04
086YP@1eTF@0ogl00?mo00D0MI5T0P3oO`0:07FAI080ogl000@0MI5T086YP@1UO5<0IGaC0P3oO`04
06ElD`80ogl0101UO5<20?mo0080IGaC00<0PJV105AUA@3oO`000P3oO`0205AUA@80ogl00P1DIDD0
0`21ZH40ogl00?mo00030?mo000303M0;@21ZH40ogl008T0/>3V0@3oool008T0/>3V00D0PJV102@/
9`0T;2L092`W086YP@0704]KB@03086YP@1XP6<0J81S00d0J81S00<0PJV107VFL01iUW004P1iUW00
0`21ZH40PJ1f086PMP0;086PMQ`0PJV13P2>]8@00`21ZH40SK:108fbP@0<08fbP@/0PJV10`3oO`0:
086YP@80ogl01@21ZH420?mo00/0PJV10P3oO`05086YP@80ogl00P21ZH4807FAI080ogl00P1eTF@0
1021ZH40IGaC0?mo003oO`0406ElD`<0ogl00`1UO5<20?mo0080IGaC00<0PJV105AUA@1DIDD00`3o
O`00101DIDD0ogl00?mo003oO`0205AUA@80ogl000<0=d0]0?mo003oO`00103oO`280;3PiP40oooo
00290;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1XP6<0301XP6<00`21ZH40NII`
07VFL00907VFL1P0PJV1302</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101P0SK:1
3P3oO`0508V]N`80ogl02@29[G/01021ZH40PJ9a0?mo003oO`05086RL@80ogl00P21XW48086YP@<0
ogl01021ZH420?mo00@0IGaC0P3oO`0306ElD`80ogl00P1UO5<01021ZH40E6E505AUA@1DIDD20?mo
0080E6E50P3oO`0205AUA@X0ogl0Q`2`h>H10?ooo`00R02`h>H01@21ZH4092`W02@/9`0T;2L0PJV1
00P0Be]900<0PJV106R0H`1XP6<02@1XP6<?086YP@X0QJQn00<0PJV108baP`2</H<05`2</H<00`21
ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101P0SK:13P3oO`0608V]N`80ogl02029[G/01021
ZH40PJ9a0?mo003oO`05086RL@80ogl02`21XW420?mo0004086RL@21ZH40LXmQ07:?H@80ogl01021
ZH420?mo00<0PJV10`3oO`0206ElD`04086YP@1DIDD0E6E505AUA@80ogl000<0E6E50?mo003oO`00
0`1DIDD:0?mo08H0/>3V0@3oool008P0/>3V00@0PJV102@/9`0T;2L0PJV1201;FdT00`21ZH40J81S
06R0H`0206R0H`P0PJV10`1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301L0S;63
00<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0I08fbP@80ogl02029[G/20?mo00L0RJek
0P3oO`0808V]N`04086YP@21XW40ogl00?mo00D0PJ9a0P3oO`0;086RL@80ogl000@0PJ9a086YP@1b
Sf40LXmQ0P3oO`0407:?H@80ogl00`1bSf430?mo00H0PJV10P3oO`00101DIDD0ogl00?mo003oO`02
05AUA@80ogl000<0=d0]0?mo003oO`001P3oO`250;3PiP40oooo00270;3PiP05086YP@0T;2L092`W
02@/9`21ZH401P1;FdT7086YP@/0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G
08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X406@2=/X420?mo00P0RJek0P3oO`07
08V]N`80ogl02@29[G/00`21ZH40ogl00?mo0005086RL@<0ogl02P21XW420?mo0004086RL@21ZH40
LXmQ07:?H@80ogl0101bSf430?mo00<0LXmQ0P3oO`0207:?H@04086YP@1MLdd0GG==05ecC@80ogl0
0P21ZH420?mo0080E6E52P3oO`260;3PiP40oooo00270;3PiP04086YP@0T;2L092`W086YP@80Be]9
1@21ZH4205]bF`03086YP@1gUG<0MiEc00`0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;63
08baP`0H08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X406@2=/X430?mo00H0RJek
0`3oO`0708V]N`80ogl02@29[G/00`21ZH40ogl00?mo0007086RL@80ogl02@21XW420?mo0080PJ9a
00@0PJV107:?H@3oO`00ogl01@1bSf420?mo00<0LXmQ0`3oO`000`1bSf40PJV105ecC@0205ecC@80
ogl00P1MLdd20?mo00<0PJV12P3oO`250;3PiP40oooo00260;3PiP03086YP@0T;2L092`W00@0PJV1
1P1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<0
5`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:101X0SK:10P3oO`0608V]N`80ogl0
2029[G/30?mo00P0RJek00@0PJV10?mo003oO`00ogl01P21XW430?mo00P0PJ9a0P3oO`02086RL@04
086YP@1bSf40ogl00?mo00D0LXmQ0P3oO`0407:?H@80ogl00P1bSf400`21ZH40GG==05ecC@020?mo
0080GG==0`3oO`0205ecC@/0ogl0Q02`h>H10?ooo`00QP2`h>H3086YP@0302hh<`21ZH40Fg9K00L0
Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301L0
S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@<0ogl01@29[G/20?mo00P0
RJek103oO`0708V]N`<0ogl02021XW430?mo00L0PJ9a0`3oO`001021XW40PJV107:?H@1bSf420?mo
00@0LXmQ0P3oO`0407:?H@80ogl00P1bSf400`21ZH40GG==05ecC@020?mo00<0GG==0P3oO`0205ec
C@03086YP@3oO`00ogl000L0ogl0Q@2`h>H10?ooo`00QP2`h>H01021ZH40;SPc02hh<`21ZH4905]b
F`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G08ba
P`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X406P2=/X420?mo00D0RJek0`3oO`0808V]
N`H0ogl00`29[G/40?mo00X0PJ9a103oO`04086RL@<0ogl00P21XW400`21ZH40LXmQ07:?H@020?mo
00@0LXmQ0`3oO`0307:?H@<0ogl000@0LXmQ086YP@1MLdd0GG==0P3oO`0305ecC@80ogl00`1MLdd2
0?mo0003045>=P3oO`00ogl000D0ogl0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc02hh<`0^>3<0
PJV100T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0
S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@<0ogl01029[G/2
0?mo00T0RJek0P3oO`000`29[G/0ogl00?mo00070?mo00`0PJ9a2@3oO`03086RL@03086YP@1bSf40
LXmQ0080ogl01@1bSf420?mo00@0LXmQ0`3oO`000`21ZH40GG==05ecC@020?mo00<0GG==0`3oO`02
05ecC@X0ogl0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV1
07NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV1
08jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0ogl000@0RJek0P3oO`0:
08V]N`80ogl000<0RJek0?mo003oO`00103oO`000`29[G/0PJV1086RL@0=086RL@H0ogl01021XW40
0`21ZH40LXmQ07:?H@020?mo00D0LXmQ0P3oO`0507:?H@@0ogl000@0GG==0?mo003oO`00ogl00`1M
Ldd30?mo000405ecC@3oO`00ogl0045>=PL0ogl0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc02hh
<`0^>3<0PJV100P0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086Y
P@2</H<0S;6301L0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0K08fbP@04086Y
P@29[G/0ogl00?mo0080RJek0`3oO`0D08V]N`03086YP@21XW40PJ9a00l0PJ9a00<0ogl0086RL@21
XW401021XW400`21ZH40LXmQ07:?H@020?mo00D0LXmQ0P3oO`0607:?H@H0ogl0101MLdd60?mo0080
@Dhf1P3oO`240;3PiP40oooo00250;3PiP04086YP@0^>3<0;SPc086YP@T0Fg9K00<0PJV107NEL`1g
UG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jdQ02>
]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0ogl00080RJek0P3oO`0F08V]N`03
086YP@21XW40PJ9a01D0PJ9a00<0PJV107:?H@1bSf400`3oO`0407:?H@<0ogl01P1bSf440?mo00D0
GG==1P3oO`02045>=PL0ogl0P`2`h>H10?ooo`00Q02`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100T0
Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0
S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0ogl000@0
ogl05P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0080ogl01@1bSf420?mo00L0
LXmQ00<0PJV105ecC@1MLdd01P1MLdd50?mo0080@Dhf1`3oO`230;3PiP40oooo00240;3PiP05086Y
P@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0QJQn01<0
QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101`0
SK:100<0PJV108V]N`29[G/00`3oO`0G08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1b
Sf400P3oO`0507:?H@80ogl01`1bSf400`21ZH40GG==05ecC@0:05ecC@04086YP@11CSH0@Dhf045>
=PH0ogl0P`2`h>H10?ooo`00Q02`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV107NE
L`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jd
Q02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek00<0ogl05`29[G/00`21
ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0080ogl01@1bSf420?mo00L0LXmQ00<0PJV105ec
C@1MLdd02P1MLdd00`21ZH40@Dhf045>=P03045>=P040?mo0021ZH40ogl00?mo08<0/>3V0@3oool0
08@0/>3V00@0PJV102hh<`0^>3<0PJV12@1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0
QJQn01@0QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40
SK:101`0SK:100<0PJV108V]N`29[G/00`3oO`0G08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV1
07:?H@1bSf400P3oO`0507:?H@<0ogl01P1bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0
@Dhf00@0@Dhf00@0PJV10?mo003oO`00ogl0PP2`h>H10?ooo`00P`2`h>H01@21ZH40;SPc02hh<`0^
>3<0PJV100T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2<
/H<0S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0L08fbP@05086YP@29
[G/0RJek08V]N`3oO`006029[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0080ogl0
1@1bSf420?mo00P0LXmQ00<0PJV105ecC@1MLdd02@1MLdd00`21ZH40@Dhf045>=P04045>=P80PJV1
0P3oO`220;3PiP40oooo00230;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc
07NEL`0>07NEL`03086YP@25Z7h0QJQn01@0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B4
08jdQ00L08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a
086RL@0F086RL@04086YP@1bSf40LXmQ07:?H@80ogl0101bSf420?mo00P0LXmQ00<0PJV105ecC@1M
Ldd02P1MLdd01P21ZH40@Dhf045>=P11CSH0ogl0045>=P80PJV10P3oO`220;3PiP40oooo00230;3P
iP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0
QJQn01@0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40
SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@04086YP@1bSf40
LXmQ07:?H@80ogl0101bSf420?mo00P0LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>
=P030?mo0003045>=P21ZH40ogl00080ogl0P@2`h>H10?ooo`00P`2`h>H01021ZH40;SPc02hh<`21
ZH4905]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308ba
P`0H08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=/X400`21ZH40RJek08V]
N`0K08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ec
C@0:05ecC@03086YP@11CSH0@Dhf00@0ogl00P21ZH420?mo0840/>3V0@3oool00880/>3V00D0PJV1
02hh<`0^>3<0;SPc086YP@0905]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV108FXOP25Z7h04`25
Z7h00`21ZH40S;6308baP`0H08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=
/X400`21ZH40RJek08V]N`0K08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401b
Sf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0ogl000<0@Dhf086YP@21ZH400P3o
O`210;3PiP40oooo00220;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NE
L`0>07NEL`03086YP@25Z7h0QJQn01@0QJQn00<0PJV108baP`2</H<02`2</H=J086YP@l0RJek00<0
PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00T0GG==00<0
PJV1045>=P11CSH00P3oO`02045>=P80PJV10`3oO`200;3PiP40oooo00220;3PiP05086YP@0^>3<0
;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0QJQn00T0QJQn6@21
ZH4=09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:j
Q@0<09:jQC80PJV12P1bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0@Dhf0P21
ZH400`2`h>H0ogl00;3PiP200;3PiP40oooo00220;3PiP<0;SPc00<0PJV105]bF`1KLU/00`1KLU/Q
086YP@/0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0
U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0
O9i]00L0O9i]4@21ZH4605ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0P@2`h>H1
0?ooo`00P@2`h>H00`21ZH40;SPc02hh<`07086YP@@0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21
ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21
ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21
ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00@0IGmD2P21ZH43045>=P80PJV1PP2`h>H10?oo
o`00P@2`h>H3086YP@0303]<@P21ZH40J8AZ00P0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00@0PJV104MJ?017FS`0AeXl1@21ZH620;3P
iP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:V
O`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0
S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`
O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ
?080PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:V
O`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0
S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`
O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ
?017FS`01017FS`00`21ZH407B@J0;3PiP210;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<
@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109Fn
S@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:j
Q@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106Eo
E01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?003086YP@0M91X0/>3V0840/>3V0@3oool00840
/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nf
RP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109Jo
R`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bN
K@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl00<0PJV101dT
6P2`h>H0P@2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:V
O`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0
S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`
O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ
?017FS`00`17FS`00`21ZH407B@J0;3PiP210;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<
@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109Fn
S@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:j
Q@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106Eo
E01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40
>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nf
RP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09Jo
R`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bN
K@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00840
/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nf
RP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109Jo
R`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bN
K@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3P
iP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH40201XQ6X00`21ZH40PZIo08:VO`0>08:V
O`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0
S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`
O003086YP@1lWVd0O9i]0100O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ
?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:V
O`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0
S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`
O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ
?017FS`01017FS`2086YPH40/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4
JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09Fn
S@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:j
Q@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06Eo
E003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<
@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109Fn
S@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:j
Q@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106Eo
E01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40
>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nf
RP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09Jo
R`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bN
K@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00800
/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nf
RP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109Jo
R`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bN
K@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3P
iP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:V
O`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0
S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`
O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00304MJ
?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:V
O`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0
S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`
O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ
?017FS`01017FS`2086YPH00/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4
JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09Fn
S@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:j
Q@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06Eo
E003086YP@17FS`0AeXl00@0AeXl0P21ZH600;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<
@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109Fn
S@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:j
Q@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106Eo
E01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40
>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nf
RP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09Jo
R`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bN
K@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH00/>3V0@3oool00800
/>3Vl`21ZH600;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40
R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40
WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40
TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40
C69104aR@@0404aR@@80PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0
LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0
W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0
V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0
KXeO00<0PJV104aR@@1<HT40101<HT42086YPH00/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0
AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40
W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40
V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40
KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH600;3PiP40oooo00200;3PiP05086Y
P@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0
U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0
W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140
Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P02`h>H10?ooo`00
P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40
U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40
W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40
Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT400`1<HT400`21ZH40
8RdN0;3PiP200;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40
R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40
WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40
TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40
C69104aR@@0404aR@@03086YP@0R;Ah0/>3V0800/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0
AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40
W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40
V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40
KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00200;3PiP05086Y
P@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0
U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0
W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140
Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00
P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40
U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40
W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40
Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40
/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0
R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0
WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0
TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0
C6910P21ZH610;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40
R[>:08ZcRP0=08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40
WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40
TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0100Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40
C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0
LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0
W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0
V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0
KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0
AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40
W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40
V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40
KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00210;3PiP05086Y
P@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0
U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0
W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140
Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00
P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40
U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40
W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40
Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT400`1<HT42086YPH80
/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0
R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0
WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0
TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0
C6910P21ZH620;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40
R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40
WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40
TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40
C69104aR@@0404aR@@80PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0
LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0
W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0
V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0
KXeO00<0PJV104aR@@1<HT40101<HT42086YPH80/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0
AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40
W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40
V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40
KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH620;3PiP40oooo00210;3PiP80PJV1
0P15G4l00`21ZH40LI=f076CMP07076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0:06j=G`04086YP@1<HT40C69104aR@@D0PJV1PP2`h>H10?ooo`00
P@2`h>H00`21ZH40CFQI086YP@0D086YP@P0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF
09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>
09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO
06j=G`0406j=G`X0PJV10`1>J4<2086YPH80/>3V0@3oool00880/>3V00@0PJV104eXF@1=J5T0PJV1
2@1hWWh00`21ZH40T;fB092mTP06092mTQ@0PJV12`2F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL02024ZgL@086YP@H0M9QX00<0PJV104iX@`1>J4<0
101>J4<00`21ZH40/>3V0;3PiP210;3PiP40oooo00220;3PiP05086YP@1=J5T0CFQI04eXF@21ZH40
201hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ00T0W<bJ6@21ZH4=09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0=09S4SS80PJV1
2@2:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300<0CVQ300<0PJV102@c8P2`h>H0
PP2`h>H10?ooo`00PP2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I80
3@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M00/0XM:MF`21ZH4>09g=U003086Y
P@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086Y
P@1>J4<0CVQ300@0CVQ30P21ZH630;3PiP40oooo00220;3PiP05086YP@1=J5T0CFQI04eXF@21ZH40
2@1hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0
602QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@0
6`2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P0
2P1dV6P00`21ZH40CVQ304iX@`0404iX@`80PJV1P`2`h>H10?ooo`00P`2`h>H01021ZH40CFQI04eX
F@21ZH4907RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M
0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD
09g=U00K09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX
07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH630;3PiP40oooo00230;3PiP05086YP@1=
J5T0CFQI04eXF@21ZH40201hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01@0W<bJ
00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0XM6I
00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0140R[Ao
00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V0880/>3V
0@3oool008<0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB
00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L
00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<
00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300<0CVQ3
0P21ZH640;3PiP40oooo00230;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB
092mTP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L
0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<
09O4S00F09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40CVQ3
04iX@`0404iX@`80PJV1Q02`h>H10?ooo`00Q02`h>H01021ZH40CFQI04eXF@21ZH4907RNOP03086Y
P@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086Y
P@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086Y
P@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086Y
P@1>J4<0CVQ300@0CVQ30P21ZH640;3PiP40oooo00240;3PiP05086YP@1=J5T0CFQI04eXF@21ZH40
201hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0
602QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@0
6P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P0
2P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V08<0/>3V0@3oool008@0/>3V00D0
PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X0
4`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0
702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0
402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0
P`2`h>H10?ooo`00Q02`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I80
3@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`0
6`2Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`0
5P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0
0`1>J4<2086YPHD0/>3V0@3oool008D0/>3V00@0PJV104eXF@1=J5T0PJV12@1hWWh00`21ZH40T;fB
092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L
0:;CW00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<
09O4S00E09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40CVQ3
04iX@`0404iX@`80PJV1Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100P0N9in
00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01L0XM:M
00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0K0:7AV@03086YP@2McI@0WLfD01X0WLfD
00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0M9QX
00<0PJV104iX@`1>J4<0101>J4<2086YPHD0/>3V0@3oool008D0/>3V00D0PJV104eXF@1=J5T0CFQI
086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M
0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD
09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX
07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`
h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ
09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I
0:7AV@0J0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao
08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V
0;3PiP240;3PiP40oooo00240;3PiP80000000@0PJV104eXF@1=J5T0PJV12@1hWWh00`21ZH40T;fB
092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L
0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<
09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ3
04iX@`0304iX@`80PJV1QP2`h>H10?ooo`00Q02`h>H200000080PJV10P1=J5T00`21ZH40N9in07RN
OP0607RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7B
W@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=
U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BH
J00907BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH660;3PiP40oooo00240;3PiP80000000<0PJV1
055aH021ZH401021ZH4707RNOP03086YP@2@_I80T;fB00`0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X0
0`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT0
0`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l0
0`21ZH40M9QX07BHJ00907BHJ004086YP@1>J4<0CVQ304iX@`@0PJV1Q`2`h>H10?ooo`00Q02`h>H3
00000004086YP@1ALF00DG5P086YP@80NjJ41@21ZH4207RNOP03086YP@2@_I80T;fB00`0T;fB00<0
PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0
PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0
PJV108ZdO`2:]7l03`2:]7l00`21ZH40M9QX07BHJ00707BHJ0L0PJV10`1CLD/00`21ZH40/>3V0;3P
iP250;3PiP40oooo00260;3PiP0300000021ZH40DG5P0080DG5P00<0PJV107^VQ01kYX@0101kYX@6
086YP@`0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0
X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0
UlB<01D0UlB<00<0PJV108ZdO`2:]7l0402:]7l01021ZH40M9QX07BHJ01dV6P6086YP@<0N:1_00<0
PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP260;3PiP40oooo00270;3PiP0500000021ZH40
DG5P055aH021ZH40201kYX@01021ZH40TlBH09?4V02Ca9P8086YP@@0T;fB00<0PJV109c<VP2Lc9X0
4`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0
6P2QdIT00`21ZH40WLfD09g=U00I09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0
302:]7l8086YP@P0N:1_00<0PJV105=aB`1CLD/0101CLD/00`21ZH40/>3V0;3PiP260;3PiP40oooo
00270;3PiP0300000021ZH40DG5P0080DG5P00<0PJV107^VQ01kYX@01P1kYX@00`21ZH40TlBH09?4
V00809?4V0l0PJV12`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0
PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00I09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0
PJV108ZdO`2:]7l00P2:]7l:086YP@@0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=a
B`0305=aB`03086YP@2`h>H0/>3V08L0/>3V0@3oool008L0/>3V0P0000001021ZH40DG5P055aH021
ZH4807^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ00202OdZ0H086YP@d0XM:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01T0WLfD00<0
PJV109O4S02Ga8`02P2Ga8`A086YP@d0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=a
B`0405=aB`03086YP@2`h>H0/>3V08L0/>3V0@3oool008L0/>3V0P0000001@21ZH40DG5P055aH01A
LF00PJV100L0NjJ400<0PJV109?4V02Ca9P03@2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2U
fJ<0YMVS00X0YMVS7021ZH4?0:;CW003086YP@2QdIT0XM6I00`0XM6I=`21ZH4<09[;TP03086YP@2>
_8D0S[b500l0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`
h>H0/>3V08P0/>3V0@3oool008P0/>3V00<000000;3PiP21ZH400P1ALF000`21ZH40NjJ407^VQ006
07^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0G
0:GIX`03086YP@2VfZ80Y]ZR00`0Y]ZR7P21ZH4>0:GHW`03086YP@2Qe9X0XMBJ01T0XMBJ00<0PJV1
09[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0@08jlQ@03086YP@1hX6l0N:1_00P0N:1_00<0PJV1
05=aB`1CLD/0101CLD/00`21ZH40/>3V0;3PiP280;3PiP40oooo00280;3PiP80000000@0PJV1055a
H01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P01<0Wm:P00<0PJV1
0:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0K0:KJXP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV1
0:7DVP2Qe9X06@2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500l0S[b500<0PJV1
07RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08T0/>3V0@3oool0
08T0/>3V00<00000086YP@1ALF000P1ALF000`21ZH40NjJ407^VQ00607^VQ003086YP@2Ca9P0TlBH
00/0TlBH00<0PJV109oBX02OdZ004`2OdZ000`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR
01/0Y]ZR00<0PJV10:GHW`2Uf9l06P2Uf9l00`21ZH40XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B
01H0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;
00<0Dg5;00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00R@2`h>H200000004086YP@1ALF00DG5P086Y
P@P0NjJ400<0PJV109?4V02Ca9P0302Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS
01L0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ
01P0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0@08jlQ@03086YP@1hX6l0N:1_
00P0N:1_00<0PJV105=aB`1CLD/0101CLD/00`21ZH40/>3V0;3PiP290;3PiP40oooo00290;3PiP80
000000D0PJV1055aH01ALF00DG5P086YP@0707^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oB
X02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GH
W`2Uf9l06P2Uf9l00`21ZH40XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B01D0V/^B00<0PJV108jl
Q@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3P
iP2`h>H0RP2`h>H10?ooo`00RP2`h>H00`000000/>3V086YP@02055aH003086YP@1kYX@0NjJ400H0
NjJ400<0PJV109?4V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00C09oBX003086YP@2UfJ<0YMVS01H0
YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ01P0
XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00P0
N:1_00<0PJV105=aB`1CLD/0101CLD/00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002:0;3PiP800000
00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P0180
Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO01X0
YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500h0
S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08/0
/>3V0@3oool008/0/>3V00<000000;3PiP21ZH400P1ALF000`21ZH40NjJ407^VQ00507^VQ003086Y
P@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0F0:GIX`03086Y
P@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GHW`2Uf9l06P2Uf9l00`21ZH40XMBJ0:7DVP0G0:7DVP03086Y
P@2Jbi80V/^B01D0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0907RPK`03086Y
P@1CLD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0R`2`h>H10?ooo`00R`2`h>H200000004086YP@1A
LF00DG5P086YP@P0NjJ400<0PJV109?4V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086Y
P@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086Y
P@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086Y
P@1hX6l0N:1_00P0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP2<0;3PiP40oooo
002<0;3PiP030000002`h>H0PJV10080DG5P00<0PJV107^VQ01kYX@01@1kYX@00`21ZH40TlBH09?4
V00<09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJ
XP0J0:KJXP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B09[;
TP0E09[;TP03086YP@2>_8D0S[b500h0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=a
B`0305=aB`03086YP@2`h>H0/>3V08`0/>3V0@3oool008`0/>3V0P0000001021ZH40DG5P055aH021
ZH4807^VQ003086YP@2Ca9P0TlBH00/0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GI
X`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7D
VP0H0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RP
K`0807RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3PiP2`h>H0S@2`h>H10?ooo`00S@2`h>H0
1P000000/>3V086YP@21ZH40DG5P086YP@L0NjJ400<0PJV109?4V02Ca9P02`2Ca9P00`21ZH40Wm:P
09oBX00B09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMRO
0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01P0XMBJ00<0PJV109[;TP2Jbi80502Jbi800`21ZH40S[b5
08jlQ@0?08jlQ@03086YP@1hX6l0N:1_00P0N:1_00<0PJV105=aB`1CLD/00P1CLD/2086YPHl0/>3V
0@3oool008d0/>3V00@000000;3PiP21ZH40DgES1021ZH4507^VQ003086YP@2Ca9P0TlBH00/0TlBH
00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR
00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01D0V/^B
00<0PJV108jlQ@2>_8D03P2>_8D00`21ZH40N:1_07RPK`0807RPK`03086YP@1CLD/0PJV100<0PJV1
00<0E7I@0;3PiP2`h>H0SP2`h>H10?ooo`00T02`h>H01@21ZH40DgES05=eH`21ZH40NjR600@0PJV1
0P1kYX@00`21ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<0
5@2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0PJV10:7DVP2Qe9X0
5`2Qe9X00`21ZH40V/^B09[;TP0D09[;TP03086YP@2>_8D0S[b500l0S[b500<0PJV107RPK`1hX6l0
1`1hX6l3086YP@@0E7I@00<0PJV10;3PiP2`h>H0SP2`h>H10?ooo`00T02`h>H01021ZH40DgES05=e
H`21ZH4507^XQPD0PJV12`2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01D0YMVS
00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ
00<0PJV109[;TP2Jbi80502Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00<0N:1_
1@21ZH4505AfD003086YP@2`h>H0/>3V08l0/>3V0@3oool00940/>3V00@0PJV105=eH`1CMF<0PJV1
1`1kZ8H00`21ZH40U<NK086YP@04086YP@H0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS
0:GIX`0E0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ
0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0PJV108jlQ@2>_8D03P2>_8D00`21ZH40N:1_
07RPK`04086YP@@0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2@0;3PiP40oooo
002B0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/0102Dai/5086YP@80TlBH00<0
PJV109oBX02OdZ004@2OdZ000`21ZH40YMVS0:GIX`0E0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0
PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0
PJV108jlQ@2>_8D02P2>_8D7086YP@L0NJAc00<0PJV105AfD01DMU000`1DMU000`21ZH40/>3V0;3P
iP2@0;3PiP40oooo002B0;3PiP04086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`2Dai/0202D
ai/=086YP@X0Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2U
f9l0YMRO01T0YMRO00<0PJV10:7DVP2Qe9X05P2Qe9X00`21ZH40V/^B09[;TP0D09[;TP03086YP@2>
_8D0S[b50080S[b52@21ZH4308noR@03086YP@1iY7<0NJAc00P0NJAc00<0PJV105AfD01DMU000P1D
MU000`21ZH40/>3V0;3PiP2A0;3PiP40oooo002C0;3PiP04086YP@1CMF<0DgES086YP@H0NjR600<0
PJV109C7V`2Dai/02`2Dai/00`21ZH40XMJT0:7FY0070:7FY100PJV14P2UfJ<00`21ZH40Y]ZR0:KJ
XP0H0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0PJV10:7DVP2Qe9X05P2Qe9X00`21ZH40V/^B09[;
TP0909[;TQ00PJV1302?_hT00`21ZH40NJAc07VTL`0707VTL`03086YP@1DMU00E7I@0080E7I@00<0
PJV10;3PiP2`h>H0TP2`h>H10?ooo`00U02`h>H00`21ZH40DgES086YP@0707^XQP03086YP@2Dai/0
U<NK00X0U<NK00<0PJV10:7FY02QeZ@04@2QeZ@00`21ZH40Y]fW0:KMY`030:KMY``0PJV11P2UfJ<0
0`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0PJV10:7DVP2Qe9X02P2Qe9XH
086YP@/0W=2F00<0PJV108noR@2?_hT03@2?_hT00`21ZH40NJAc07VTL`0707VTL`03086YP@1DMU00
E7I@0080E7I@00<0PJV10;3PiP2`h>H0T`2`h>H10?ooo`00U02`h>H01021ZH40DgES05=eH`21ZH47
07^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@04@2QeZ@00`21ZH40Y]fW0:KMY`0>
0:KMYdX0PJV1302SfIh00`21ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV1
07VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V09<0/>3V0@3oool0
09D0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT
0140XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0H0:SOYP03086YP@2WgJ<0YmfS
01T0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0D09c@UP03086YP@2?_hT0Skn9
00d0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V
09@0/>3V0@3oool009D0/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H00`21ZH40U<NK09C7V`0:09C7
V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0H0:SO
YP03086YP@2WgJ<0YmfS01T0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0C09c@
UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01`1iY7<01@21ZH40E7I@05AfD01DMU00
PJV109L0/>3V0@3oool009H0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:09C7
V`03086YP@2QeZ@0XMJT0140XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0G0:SO
YP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05P2SfIh00`21ZH40W=2F09c@UP0C09c@
UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205Af
D003086YP@2`h>H0/>3V09D0/>3V0@3oool009L0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40
U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40
Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05P2SfIh00`21ZH40
W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01`1iY7<01@21ZH40
E7I@05AfD01DMU00PJV109P0/>3V0@3oool009L0/>3V00@0PJV105=eH`1CMF<0PJV11P1kZ8H00`21
ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21
ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21
ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<01@21
ZH40E7I@05AfD01DMU00PJV109T0/>3V0@3oool009P0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21
ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21
ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21
ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01P1iY7<00`21
ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V09L0/>3V0@3oool009T0/>3V00<0PJV105=eH`21
ZH401`1kZ8H00`21ZH40U<NK09C7V`0909C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2V
gJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2S
fIh05@2SfIh00`21ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1i
Y7<01`1iY7<01@21ZH40E7I@05AfD01DMU00PJV109X0/>3V0@3oool009X0/>3V0P21ZH4707^XQP03
086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@03`2QeZ@00`21ZH40Y]fW0:KMY`0D0:KMY`03
086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03
086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT03P2?_hT00`21ZH40NJAc07VTL`0607VTL`03
086YP@1DMU00E7I@0080PJV1V`2`h>H10?ooo`00V`2`h>H4086YP@D0NjR600<0PJV109C7V`2Dai/0
2@2Dai/00`21ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH0
5P2XgjH00`21ZH40YmfS0:OMX`0G0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H0
4P2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc1021ZH6L0;3PiP40oooo
002L0;3PiP80PJV100<0MZF4086YP@21ZH400P21ZH400`1kZ8H0PJV109C7V`0;09C7V`03086YP@2Q
eZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2W
gJ<0YmfS01H0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?
_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01@1iY7<3086YP@80DWIB00<0PJV10;3PiP2`h>H0VP2`
h>H10?ooo`00W@2`h>H2086YP@@0MZF41@21ZH4909C7V`03086YP@2QeZ@0XMJT00l0XMJT00<0PJV1
0:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01H0YmfS00<0PJV1
0:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV1
07VTL`1iY7<00P1iY7<5086YP@<0DWIB00<0PJV10;3PiP2`h>H0V`2`h>H10?ooo`00WP2`h>H2086Y
P@H0MZF400<0PJV10934V@21ZH400`21ZH4609C7V`03086YP@2QeZ@0XMJT00l0XMJT00<0PJV10:KM
Y`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01H0YmfS00<0PJV10:?I
WP2SfIh0502SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?_hT0Skn900h0Skn91@21ZH4307FR
L`05086YP@1BMU80DWIB059fDP21ZH40WP2`h>H10?ooo`00WP2`h>H00`21ZH40D7AR086YP@0607JU
Q003086YP@2@a9T0T<BI0080T<BI1@21ZH400`2Dai/0PJV10:7FY00@0:7FY003086YP@2VgJL0Y]fW
01<0Y]fW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0XmVN
01@0XmVN00<0PJV109c@UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0908noR@H0PJV11P1eXW<01@21
ZH40DWIB059fDP1BMU80PJV109l0/>3V0@3oool009l0/>3V00<0PJV1051dHP21ZH401@1fYH@00`21
ZH40T<BI0934V@070934V@L0PJV1302QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV
01H0Z=nV00<0PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2Ld9H0W=2F
0100W=2F00<0PJV108noR@2?_hT00P2?_hT8086YP@<0S;n:00<0PJV107FRL`1eXW<01P1eXW<01021
ZH40DWIB059fDP21ZH6P0;3PiP40oooo002P0;3PiP03086YP@1@M680PJV100D0MZF400<0PJV10934
V@2@a9T02@2@a9T01021ZH40W]JT09kFY02NeZ@9086YP@@0XMJT00<0PJV10:KMY`2VgJL04`2VgJL0
0`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgJ<0YmfS01D0YmfS00<0PJV10:?IWP2SfIh05@2SfIh0
0`21ZH40W=2F09c@UP0<09c@UPT0PJV12P2<_hX00`21ZH40MJ9c07FRL`0607FRL`05086YP@1BMU80
DWIB059fDP21ZH40X02`h>H10?ooo`00X@2`h>H2086YP@H0MZF400<0PJV10934V@2@a9T0202@a9T0
0`21ZH40W]JT09kFY00:09kFY0l0PJV12`2VgJL00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgJ<0
YmfS01D0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0309c@UPX0PJV10`2Jd9P0
0`21ZH40S;n:08boRP0=08boRP03086YP@1eXW<0MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086Y
P@2Q0;3PiP40oooo002R0;3PiP80PJV11P1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0
W]JT00h0W]JT00<0PJV10:GMZ02UgJP01`2UgJPG086YP@`0Z=nV00<0PJV10:OMX`2WgJ<05@2WgJ<0
0`21ZH40XmVN0:?IWP090:?IWQ40PJV13@2Jd9P00`21ZH40S;n:08boRP0<08boRP03086YP@1eXW<0
MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2R0;3PiP40oooo002S0;3PiP80PJV11P1fYH@0
0`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP04P2UgJP0
0`21ZH40Yn2X0:OPZ0090:OPZ300PJV12`2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<_hX0
S;n:00`0S;n:00<0PJV107FRL`1eXW<01@1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:<0/>3V0@3o
ool00:@0/>3V0P21ZH4507JUQ003086YP@2@a9T0T<BI00T0T<BI00<0PJV109kFY02NeZ@03@2NeZ@0
0`21ZH40YMfX0:GMZ00B0:GMZ003086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD05@2VgjD0
0`21ZH40X]ZP0:;JX00C0:;JX003086YP@2Jd9P0V]2H0100V]2H00<0PJV108boRP2<_hX02`2<_hX0
0`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80DWIB059fDP21ZH40Y02`h>H10?ooo`00Y@2`h>H2
086YP@D0MZF400<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0
YMfX0180YMfX00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0E0:KOY@03086YP@2RfZ00
X]ZP01<0X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0
MJ9c00D0MJ9c00<0PJV1059fDP1BMU800P1BMU800`21ZH40/>3V0;3PiP2R0;3PiP40oooo002V0;3P
iP80PJV11@1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GM
Z02UgJP04@2UgJP00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2VgjD0Y]nU01D0Y]nU00<0PJV10:;J
X02RfZ004P2RfZ000`21ZH40V]2H09[@V00@09[@V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FR
L`1eXW<01@1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:D0/>3V0@3oool00:L0/>3V0P21ZH4507JU
Q003086YP@2@a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40YMfX0:GMZ00A0:GM
Z003086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD0502VgjD00`21ZH40X]ZP0:;JX00C0:;J
X003086YP@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FR
L`03086YP@1BMU80DWIB0080PJV1YP2`h>H10?ooo`00Z@2`h>H2086YP@@0MZF400<0PJV10934V@2@
a9T01`2@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0140YMfX00<0PJV10:OPZ02W
h:P04`2Wh:P00`21ZH40Y]nU0:KOY@0D0:KOY@03086YP@2RfZ00X]ZP0180X]ZP00<0PJV109[@V02J
d9P03`2Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0MJ9c00D0MJ9c1@21ZH6W0;3PiP40
oooo002Z0;3PiP<0PJV10P1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT
00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU01@0Y]nU
00<0PJV10:;JX02RfZ004P2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<_hX0S;n:00X0S;n:
00<0PJV107FRL`1eXW<0101eXW<3086YP@80CG5@Z@2`h>H10?ooo`00Z`2`h>H00`21ZH40KI]m086Y
P@03086YP@X0T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40YMfX0:GMZ00@0:GMZ003086YP@2W
h:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD0502VgjD00`21ZH40X]ZP0:;JX00B0:;JX003086YP@2J
d9P0V]2H00h0V]2H00<0PJV108boRP2<_hX02`2<_hX01021ZH40MJ9c07FRL`1eXW<4086YP@80CG5@
00<0PJV10;3PiP2`h>H0Z02`h>H10?ooo`00[02`h>H2086YP@80KI]m1021ZH480934V@03086YP@2N
eZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP03`2UgJP00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2V
gjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ004@2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<
_hX0S;n:00X0S;n:1@21ZH4206fJK`04086YP@1=LE00CG5@086YPJ/0/>3V0@3oool00:h0/>3V00H0
PJV106fKO@1]Vgd0KI]m086YP@26^Y86086YP@80T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40
YMfX0:GMZ00@0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD04`2VgjD00`21ZH40
X]ZP0:;JX00A0:;JX003086YP@2Jd9P0V]2H00h0V]2H00<0PJV108boRP2<_hX01`2<_hX5086YP@@0
KIY_0P21ZH400`1=LE00PJV10;3PiP2/0;3PiP40oooo002_0;3PiP05086YP@1]Vgd0KI]m06fKO@21
ZH401P26^Y87086YP@/0W]JT00<0PJV10:GMZ02UgJP03`2UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003
086YP@2VgjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ00402RfZ000`21ZH40V]2H09[@V00?09[@V003
086YP@2<_hX0S;n:00L0PJV10P24]hH00`21ZH40KIY_06fJK`0306fJK`04086YP@1=LE00CG5@086Y
PJh0/>3V0@3oool00;00/>3V00@0PJV106fKO@1]Vgd0KI]m0P21ZH4808JjTP03086YP@2FcYh0U/jN
00P0PJV10`2NeZ@00`21ZH40YMfX0:GMZ00?0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KO
Y@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX00A0:;JX003086YP@2Jd9P0V]2H00X0V]2H2021ZH4808Bg
QP03086YP@1]VVl0KIY_00<0KIY_00@0PJV104eaD021ZH40PJV1[`2`h>H10?ooo`00/@2`h>H00`21
ZH40KI]m06fKO@0206fKO@03086YP@26^Y80Q[ZB00H0Q[ZB00<0PJV109K>WP2FcYh01`2FcYh9086Y
P@`0YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0B0:KOY@03086YP@2RfZ00X]ZP
0100X]ZP00<0PJV109[@V02Jd9P00P2Jd9P9086YP@<0TlZD00<0PJV108BgQP24]hH02024]hH2086Y
P@D0KIY_00<0PJV104eaD021ZH40/@2`h>H10?ooo`00/P2`h>H00`21ZH40KI]m06fKO@0206fKO@03
086YP@26^Y80Q[ZB00H0Q[ZB00<0PJV109K>WP2FcYh02`2FcYh01021ZH40W]RT09kHY02Nf:@9086Y
P@@0YMfX00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40Y]nU0:KOY@0B0:KOY@03086YP@2RfZ00X]ZP
00L0X]ZP3P21ZH4;09?:U003086YP@24]hH0Q;N600P0Q;N600<0PJV106fJK`1]VVl0101]VVl00`21
ZH40CG5@086YP@2b0;3PiP40oooo002c0;3PiP80PJV10`1]Vgd00`21ZH40Q[ZB08JjTP0608JjTP03
086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@02P2Nf:@h086YP@P0W=FN00<0PJV109?:U02C
bY@03@2CbY@00`21ZH40Q;N608BgQP0808BgQP03086YP@1]VVl0KIY_00@0KIY_0`21ZH6c0;3PiP40
oooo002e0;3PiP05086YP@1]Vgd0KI]m06fKO@21ZH402026^Y800`21ZH40U/jN09K>WP0:09K>WP03
086YP@2Nf:@0W]RT00d0W]RT00<0PJV10:7KY@2QfjD04P2QfjD00`21ZH40XMZS0:7JX`0B0:7JX`03
086YP@2LeIh0W=FN00l0W=FN00<0PJV109?:U02CbY@03@2CbY@00`21ZH40Q;N608BgQP0708BgQP03
086YP@1]VVl0KIY_00<0KIY_0`21ZH6e0;3PiP40oooo002f0;3PiP04086YP@1]Vgd0KI]m06fKO@80
PJV11P26^Y800`21ZH40U/jN09K>WP0;09K>WP03086YP@2Nf:@0W]RT00d0W]RT00<0PJV10:7KY@2Q
fjD04@2QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086YP@2LeIh0W=FN00l0W=FN00<0PJV109?:U02C
bY@03@2CbY@00`21ZH40Q;N608BgQP0708BgQP03086YP@1]VVl0KIY_00<0KIY_0`21ZH6f0;3PiP40
oooo002g0;3PiP80PJV10`1]Vgd00`21ZH40Q[ZB08JjTP0408JjTP03086YP@2FcYh0U/jN00/0U/jN
00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2QfZ<0XMZS0140XMZS
00<0PJV109cEWP2LeIh03P2LeIh00`21ZH40TlZD09?:U00=09?:U003086YP@24]hH0Q;N600H0Q;N6
0P21ZH4506fJK`80PJV1^02`h>H10?ooo`00^02`h>H6086YP@H0Q[ZB00<0PJV109K>WP2FcYh02P2F
cYh00`21ZH40W]RT09kHY00=09kHY003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<04@2Q
fZ<00`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00`0TlZD00<0PJV108BgQP24]hH01P24
]hH00`21ZH40KIY_06fJK`0206fJK`<0PJV1^P2`h>H10?ooo`00^P2`h>H2086YP@0405j9K`21ZH40
PJV1086YP@D0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00<09kHY003086YP@2Q
fjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<04@2QfZ<00`21ZH40W=FN09cEWP0=09cEWP03086YP@2C
bY@0TlZD00`0TlZD00<0PJV108BgQP24]hH01P24]hH00`21ZH40KIY_086YP@05086YPK/0/>3V0@3o
ool00;`0/>3V0P21ZH400`1NRFl0PJV1086YP@02086YP@<0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh0
0`21ZH40W]RT09kHY00<09kHY003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<0
0`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00/0TlZD00<0PJV108BgQP24]hH01@24]hH4
086YP@80Gh]V0P21ZH6m0;3PiP40oooo002n0;3PiP80PJV100<0GXU_086YP@21ZH401@21ZH4<09K>
WP03086YP@2Nf:@0W]RT00/0W]RT00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40XMZS0:7JX`0?0:7J
X`03086YP@2LeIh0W=FN00d0W=FN00<0PJV109?:U02CbY@0302CbY@01021ZH40Q;N608BgQP24]hH5
086YP@<0Gh]V0P21ZH6o0;3PiP40oooo00300;3PiP80PJV100<0GXU_086YP@21ZH400P1eYh@8086Y
P@D0U/jN00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2QfZ<0XMZS
00l0XMZS00<0PJV109cEWP2LeIh0302LeIh00`21ZH40TlZD09?:U00<09?:U0D0PJV100<0MJIk086Y
P@21ZH400`1ORfH2086YPL40/>3V0@3oool00<80/>3V0P21ZH400`1NRFl0PJV107FWQ00207FWQ080
PJV11025^i4:086YP@X0W]RT00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XMZS0:7JX`0?0:7JX`03
086YP@2LeIh0W=FN00`0W=FN00<0PJV109?:U02CbY@0102CbY@9086YP@@0MJIk00@0PJV105n;IP1O
RfH0Gh]V0P21ZH730;3PiP40oooo00340;3PiP@0PJV10`1eYh@2086YP@T0QK^A00<0PJV108k6V02>
aYP02021ZH4309kHY003086YP@2QfjD0XM^U00h0XM^U00<0PJV10:7JX`2QfZ<03P2QfZ<00`21ZH40
W=FN09cEWP0509cEWPl0PJV11@24^HX2086YP@@0MJIk0P21ZH4205n;IP80PJV1a@2`h>H10?ooo`00
aP2`h>H4086YP@<0MJN400<0PJV108FkT@25^i401`25^i400`21ZH40S/JH08k6V00708k6V2d0PJV1
1P2>aI<00`21ZH40Q;V:08BiRP0:08BiRP03086YP@1eYW/0MJIk00<0MJIk00<0PJV105n;IP1ORfH0
0`21ZH760;3PiP40oooo00390;3PiP<0PJV10P1eYh@2086YP@P0QK^A00<0PJV108k6V02>aYP02P2>
aYP00`21ZH40TlbK09?<V`0=09?<V`03086YP@2BbiT0T/^I00d0T/^I00<0PJV108k5T`2>aI<02`2>
aI<00`21ZH40Q;V:08BiRP0908BiRP80PJV1101eYW/2086YP@0405n;IP21ZH40PJV1086YPLP0/>3V
0@3oool00</0/>3V0`21ZH4207FWQ080PJV11`25^i42086YP@/0S/JH00<0PJV109?<V`2Cc9/0302C
c9/00`21ZH40T/^I09;;V@0=09;;V@03086YP@2>aI<0S/FC00X0S/FC00<0PJV108BiRP24^HX02024
^HX2086YP@@0MJIk1@21ZH7;0;3PiP40oooo003>0;3PiPH0PJV11`25^i400`21ZH40S/JH08k6V009
08k6V003086YP@2Cc9/0TlbK00/0TlbK00<0PJV109;;V@2BbiT0302BbiT00`21ZH40S/FC08k5T`0:
08k5T`03086YP@24^HX0Q;V:00P0Q;V:00@0PJV107FVN`1eYW/0MJIk1P21ZH7=0;3PiP40oooo003A
0;3PiPH0PJV11@25^i400`21ZH40S/JH08k6V00808k6V003086YP@2Cc9/0TlbK00`0TlbK00<0PJV1
09;;V@2BbiT02`2BbiT00`21ZH40S/FC08k5T`0908k5T`03086YP@24^HX0Q;V:00L0Q;V:2@21ZH7@
0;3PiP40oooo003C0;3PiPT0PJV100<0QK^A086YP@2>aYP02@2>aYP00`21ZH40TlbK09?<V`0;09?<
V`03086YP@2BbiT0T/^I00X0T/^I00<0PJV108k5T`2>aI<02@2>aI<00`21ZH40Q;V:08BiRP0208Bi
RP`0PJV1d`2`h>H10?ooo`00eP2`h>H5086YP@0306ZJN@21ZH40PJV100H0PJV11@2>aYP00`21ZH40
TlbK09?<V`0:09?<V`03086YP@2BbiT0T/^I00X0T/^I00<0PJV108k5T`2>aI<00`2>aI<;086YP@80
Ji]e0P21ZH400`1MRFL0PJV1086YP@03086YPMD0/>3V0@3oool00=T0/>3V1@21ZH4206ZJN@80PJV1
0P1cYX4U086YP@<0LjIn0P21ZH4506^KM@80PJV100<0GHUW086YP@21ZH400`21ZH7H0;3PiP40oooo
003M0;3PiP<0PJV10P1ZVWT2086YP@L0LjJ10P21ZH4907R/Q003086YP@1hZh<0N:^300P0N:^300<0
PJV107>VOP1cYWh01P1cYWh2086YP@@0Ji]e1`21ZH7L0;3PiP40oooo003P0;3PiPH0PJV11`1cYX42
086YP@L0N:b400<0PJV107R[P`1hZh<01`1hZh<00`21ZH40LjIn07>VOP0507>VOP80PJV100<0Ji]e
086YP@21ZH401@21ZH7Q0;3PiP40oooo003T0;3PiPl0PJV1101h[8@00`21ZH40N:^307R[P`0607R[
P`04086YP@1cYWh0LjIn07>VOPL0PJV1j02`h>H10?ooo`00lP2`h>HB086YPNl0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.609 .783 .573 r
.48003 .46975 m .47983 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.52017 .5 m .51997 .46975 L .48003 .46975 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.51997 .53025 m .52017 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.51997 .46975 m .52017 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.52017 .5 m .51997 .53025 L .5595 .53049 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.5595 .53049 m .56011 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.4405 .46951 m .43989 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.47983 .5 m .48003 .46975 L .4405 .46951 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.48003 .53025 m .47983 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.47983 .5 m .48003 .53025 L .51997 .53025 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.48064 .43983 m .48003 .46975 L .51997 .46975 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.51997 .46975 m .51936 .43983 L .48064 .43983 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.51936 .56017 m .51997 .53025 L .48003 .53025 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.51936 .43983 m .51997 .46975 L .5595 .46951 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.56011 .5 m .5595 .46951 L .51997 .46975 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.51997 .53025 m .51936 .56017 L .55767 .56063 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.55767 .56063 m .5595 .53049 L .51997 .53025 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.44233 .43937 m .4405 .46951 L .48003 .46975 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.48003 .46975 m .48064 .43983 L .44233 .43937 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.43989 .5 m .4405 .53049 L .48003 .53025 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.48064 .56017 m .48003 .53025 L .4405 .53049 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.48003 .53025 m .48064 .56017 L .51936 .56017 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50492 .56118 m
.50726 .56017 L
s
.51686 .56017 m
.51925 .56123 L
s
.50492 .56118 m
.50082 .56467 L
s
.5 Mabswid
.61 .785 .582 r
.5595 .46951 m .56011 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.56011 .5 m .5595 .53049 L .59781 .53098 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.59781 .53098 m .59883 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.40219 .46902 m .40117 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.43989 .5 m .4405 .46951 L .40219 .46902 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.4405 .53049 m .43989 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.44539 .40995 m .44233 .43937 L .48064 .43983 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.48064 .43983 m .48166 .41061 L .44539 .40995 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.48166 .41061 m .48064 .43983 L .51936 .43983 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.51936 .43983 m .51834 .41061 L .48166 .41061 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.51834 .58939 m .51936 .56017 L .48064 .56017 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.51834 .41061 m .51936 .43983 L .55767 .43937 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.5595 .46951 m .55767 .43937 L .51936 .43983 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.51936 .56017 m .51834 .58939 L .55461 .59005 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.55461 .59005 m .55767 .56063 L .51936 .56017 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.4405 .53049 m .44233 .56063 L .48064 .56017 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.48166 .58939 m .48064 .56017 L .44233 .56063 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.48064 .56017 m .48166 .58939 L .51834 .58939 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.48718 .58939 m
.48725 .59211 L
s
.5 Mabswid
.625 .808 .601 r
.55767 .43937 m .5595 .46951 L .59781 .46902 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.59883 .5 m .59781 .46902 L .5595 .46951 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.5595 .53049 m .55767 .56063 L .59475 .56157 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.59475 .56157 m .59781 .53098 L .5595 .53049 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.40525 .43843 m .40219 .46902 L .4405 .46951 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.4405 .46951 m .44233 .43937 L .40525 .43843 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.40117 .5 m .40219 .53098 L .4405 .53049 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.44233 .56063 m .4405 .53049 L .40219 .53098 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4655 .57757 m
.46719 .58098 L
s
.47122 .58241 m
.47211 .5824 L
s
.46719 .58098 m
.47122 .58241 L
s
.5 Mabswid
.638 .83 .614 r
.55767 .43937 m .55461 .40995 L .51834 .41061 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.55461 .40995 m .55767 .43937 L .59475 .43843 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.59781 .46902 m .59475 .43843 L .55767 .43937 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.55767 .56063 m .55461 .59005 L .58966 .59137 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.58966 .59137 m .59475 .56157 L .55767 .56063 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.40219 .53098 m .40525 .56157 L .44233 .56063 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.44539 .59005 m .44233 .56063 L .40525 .56157 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.44233 .56063 m .44539 .59005 L .48166 .58939 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.41034 .40863 m .40525 .43843 L .44233 .43937 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.44233 .43937 m .44539 .40995 L .41034 .40863 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43424 .58214 m
.43436 .5832 L
s
.5 Mabswid
.645 .844 .622 r
.48309 .38245 m .48166 .41061 L .51834 .41061 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.51834 .41061 m .51691 .38245 L .48309 .38245 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.51691 .38245 m .51834 .41061 L .55461 .40995 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.44966 .38165 m .44539 .40995 L .48166 .41061 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.48166 .41061 m .48309 .38245 L .44966 .38165 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.51691 .61755 m .51834 .58939 L .48166 .58939 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.51834 .58939 m .51691 .61755 L .55034 .61835 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.55034 .61835 m .55461 .59005 L .51834 .58939 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.48309 .61755 m .48166 .58939 L .44539 .59005 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.48166 .58939 m .48309 .61755 L .51691 .61755 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.59781 .46902 m .59883 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.59883 .5 m .59781 .53098 L .63399 .53171 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.63399 .53171 m .63541 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.36601 .46829 m .36459 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.40117 .5 m .40219 .46902 L .36601 .46829 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.40219 .53098 m .40117 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44895 .59273 m
.449 .59269 L
s
.44895 .59273 m
.44974 .59323 L
s
.5 Mabswid
.619 .802 .601 r
.59475 .43843 m .59781 .46902 L .63399 .46829 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.63541 .5 m .63399 .46829 L .59781 .46902 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.59781 .53098 m .59475 .56157 L .6297 .56298 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.6297 .56298 m .63399 .53171 L .59781 .53098 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.3703 .43702 m .36601 .46829 L .40219 .46902 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.40219 .46902 m .40525 .43843 L .3703 .43702 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.36459 .5 m .36601 .53171 L .40219 .53098 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.40525 .56157 m .40219 .53098 L .36601 .53171 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.55461 .40995 m .55034 .38165 L .51691 .38245 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.55034 .38165 m .55461 .40995 L .58966 .40863 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.59475 .43843 m .58966 .40863 L .55461 .40995 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.55461 .59005 m .55034 .61835 L .58254 .61994 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.58254 .61994 m .58966 .59137 L .55461 .59005 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.41746 .38006 m .41034 .40863 L .44539 .40995 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.44539 .40995 m .44966 .38165 L .41746 .38006 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.40525 .56157 m .41034 .59137 L .44539 .59005 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.44966 .61835 m .44539 .59005 L .41034 .59137 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.44539 .59005 m .44966 .61835 L .48309 .61755 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.58966 .40863 m .59475 .43843 L .6297 .43702 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.63399 .46829 m .6297 .43702 L .59475 .43843 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.59475 .56157 m .58966 .59137 L .62259 .59335 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.62259 .59335 m .6297 .56298 L .59475 .56157 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.37741 .40665 m .3703 .43702 L .40525 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.40525 .43843 m .41034 .40863 L .37741 .40665 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.36601 .53171 m .3703 .56298 L .40525 .56157 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.41034 .59137 m .40525 .56157 L .3703 .56298 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.48493 .35578 m .48309 .38245 L .51691 .38245 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.51691 .38245 m .51507 .35578 L .48493 .35578 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.51507 .64422 m .51691 .61755 L .48309 .61755 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.51507 .35578 m .51691 .38245 L .55034 .38165 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.51691 .61755 m .51507 .64422 L .54484 .64509 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.54484 .64509 m .55034 .61835 L .51691 .61755 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.45516 .35491 m .44966 .38165 L .48309 .38245 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.48309 .38245 m .48493 .35578 L .45516 .35491 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.48493 .64422 m .48309 .61755 L .44966 .61835 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.48309 .61755 m .48493 .64422 L .51507 .64422 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.58966 .40863 m .58254 .38006 L .55034 .38165 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.58254 .38006 m .58966 .40863 L .62259 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.6297 .43702 m .62259 .40665 L .58966 .40863 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.58966 .59137 m .58254 .61994 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.61266 .62233 m .62259 .59335 L .58966 .59137 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.41034 .59137 m .41746 .61994 L .44966 .61835 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.38734 .37767 m .37741 .40665 L .41034 .40863 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.41034 .40863 m .41746 .38006 L .38734 .37767 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.3703 .56298 m .37741 .59335 L .41034 .59137 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.41746 .61994 m .41034 .59137 L .37741 .59335 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.55034 .38165 m .54484 .35491 L .51507 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.54484 .35491 m .55034 .38165 L .58254 .38006 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.55034 .61835 m .54484 .64509 L .57342 .64683 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.57342 .64683 m .58254 .61994 L .55034 .61835 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.42658 .35317 m .41746 .38006 L .44966 .38165 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.44966 .38165 m .45516 .35491 L .42658 .35317 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.45516 .64509 m .44966 .61835 L .41746 .61994 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.44966 .61835 m .45516 .64509 L .48493 .64422 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.63399 .46829 m .63541 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.63541 .5 m .63399 .53171 L .66699 .53269 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.66699 .53269 m .66882 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.33301 .46731 m .33118 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.36459 .5 m .36601 .46829 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.36601 .53171 m .36459 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.33851 .43514 m .33301 .46731 L .36601 .46829 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.36601 .46829 m .3703 .43702 L .33851 .43514 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.33118 .5 m .33301 .53269 L .36601 .53171 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.3703 .56298 m .36601 .53171 L .33301 .53269 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.6297 .43702 m .63399 .46829 L .66699 .46731 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.66882 .5 m .66699 .46731 L .63399 .46829 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.63399 .53171 m .6297 .56298 L .66149 .56486 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.66149 .56486 m .66699 .53269 L .63399 .53171 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3673 .56234 m
.37047 .56371 L
s
.5 Mabswid
.621 .812 .615 r
.62259 .40665 m .6297 .43702 L .66149 .43514 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.66699 .46731 m .66149 .43514 L .6297 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.34762 .40403 m .33851 .43514 L .3703 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.3703 .43702 m .37741 .40665 L .34762 .40403 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.33301 .53269 m .33851 .56486 L .3703 .56298 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.37741 .59335 m .3703 .56298 L .33851 .56486 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.6297 .56298 m .62259 .59335 L .65238 .59597 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.65238 .59597 m .66149 .56486 L .6297 .56298 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.46188 .3302 m .45516 .35491 L .48493 .35578 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.48493 .35578 m .48717 .33107 L .46188 .3302 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.48717 .33107 m .48493 .35578 L .51507 .35578 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.51507 .35578 m .51283 .33107 L .48717 .33107 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.51283 .33107 m .51507 .35578 L .54484 .35491 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.48717 .66893 m .48493 .64422 L .45516 .64509 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.48493 .64422 m .48717 .66893 L .51283 .66893 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.51283 .66893 m .51507 .64422 L .48493 .64422 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.51507 .64422 m .51283 .66893 L .53812 .6698 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.53812 .6698 m .54484 .64509 L .51507 .64422 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.41746 .61994 m .42658 .64683 L .45516 .64509 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.58254 .38006 m .57342 .35317 L .54484 .35491 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.57342 .35317 m .58254 .38006 L .61266 .37767 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.62259 .40665 m .61266 .37767 L .58254 .38006 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.58254 .61994 m .57342 .64683 L .59998 .64942 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.59998 .64942 m .61266 .62233 L .58254 .61994 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.40002 .35058 m .38734 .37767 L .41746 .38006 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.41746 .38006 m .42658 .35317 L .40002 .35058 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.37741 .59335 m .38734 .62233 L .41746 .61994 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.42658 .64683 m .41746 .61994 L .38734 .62233 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.54484 .35491 m .53812 .3302 L .51283 .33107 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.53812 .3302 m .54484 .35491 L .57342 .35317 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.54484 .64509 m .53812 .6698 L .56231 .67153 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.56231 .67153 m .57342 .64683 L .54484 .64509 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.43769 .32847 m .42658 .35317 L .45516 .35491 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.45516 .35491 m .46188 .3302 L .43769 .32847 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.46188 .6698 m .45516 .64509 L .42658 .64683 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.45516 .64509 m .46188 .6698 L .48717 .66893 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.36027 .37452 m .34762 .40403 L .37741 .40665 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.37741 .40665 m .38734 .37767 L .36027 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.61266 .37767 m .62259 .40665 L .65238 .40403 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.66149 .43514 m .65238 .40403 L .62259 .40665 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.62259 .59335 m .61266 .62233 L .63973 .62548 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.63973 .62548 m .65238 .59597 L .62259 .59335 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.33851 .56486 m .34762 .59597 L .37741 .59335 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.38734 .62233 m .37741 .59335 L .34762 .59597 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.57342 .35317 m .56231 .32847 L .53812 .3302 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.56231 .32847 m .57342 .35317 L .59998 .35058 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.61266 .37767 m .59998 .35058 L .57342 .35317 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.42658 .64683 m .43769 .67153 L .46188 .6698 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.57342 .64683 m .56231 .67153 L .58464 .67409 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.58464 .67409 m .59998 .64942 L .57342 .64683 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.41536 .32591 m .40002 .35058 L .42658 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.42658 .35317 m .43769 .32847 L .41536 .32591 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.38734 .62233 m .40002 .64942 L .42658 .64683 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.43769 .67153 m .42658 .64683 L .40002 .64942 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.59998 .35058 m .61266 .37767 L .63973 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.65238 .40403 m .63973 .37452 L .61266 .37767 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.61266 .62233 m .59998 .64942 L .62364 .65283 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.62364 .65283 m .63973 .62548 L .61266 .62233 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.37636 .34717 m .36027 .37452 L .38734 .37767 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.38734 .37767 m .40002 .35058 L .37636 .34717 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.34762 .59597 m .36027 .62548 L .38734 .62233 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.40002 .64942 m .38734 .62233 L .36027 .62548 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.30442 .46609 m .30218 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.33118 .5 m .33301 .46731 L .30442 .46609 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.33301 .53269 m .33118 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.66699 .46731 m .66882 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.66882 .5 m .66699 .53269 L .69558 .53391 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.69558 .53391 m .69782 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.48982 .30885 m .48717 .33107 L .51283 .33107 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.51283 .33107 m .51018 .30885 L .48982 .30885 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.51018 .30885 m .51283 .33107 L .53812 .3302 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.46978 .30806 m .46188 .3302 L .48717 .33107 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.48717 .33107 m .48982 .30885 L .46978 .30806 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.51018 .69115 m .51283 .66893 L .48717 .66893 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.51283 .66893 m .51018 .69115 L .53022 .69194 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.53022 .69194 m .53812 .6698 L .51283 .66893 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.48982 .69115 m .48717 .66893 L .46188 .6698 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.48717 .66893 m .48982 .69115 L .51018 .69115 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.31108 .43281 m .30442 .46609 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.33301 .46731 m .33851 .43514 L .31108 .43281 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.30218 .5 m .30442 .53391 L .33301 .53269 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.33851 .56486 m .33301 .53269 L .30442 .53391 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.33698 .56412 m
.33845 .56481 L
s
.5 Mabswid
.581 .757 .58 r
.66149 .43514 m .66699 .46731 L .69558 .46609 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.69782 .5 m .69558 .46609 L .66699 .46731 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.66699 .53269 m .66149 .56486 L .68892 .56719 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.68892 .56719 m .69558 .53391 L .66699 .53269 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.53812 .3302 m .53022 .30806 L .51018 .30885 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.53022 .30806 m .53812 .3302 L .56231 .32847 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.53812 .6698 m .53022 .69194 L .54929 .69348 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.54929 .69348 m .56231 .67153 L .53812 .6698 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.45071 .30652 m .43769 .32847 L .46188 .3302 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.46188 .3302 m .46978 .30806 L .45071 .30652 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.3221 .40078 m .31108 .43281 L .33851 .43514 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.33851 .43514 m .34762 .40403 L .3221 .40078 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.30442 .53391 m .31108 .56719 L .33851 .56486 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.34762 .59597 m .33851 .56486 L .31108 .56719 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.46978 .69194 m .46188 .6698 L .43769 .67153 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.46188 .6698 m .46978 .69194 L .48982 .69115 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.66149 .56486 m .65238 .59597 L .6779 .59922 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.6779 .59922 m .68892 .56719 L .66149 .56486 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.65238 .40403 m .66149 .43514 L .68892 .43281 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.69558 .46609 m .68892 .43281 L .66149 .43514 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.3957 .32256 m .37636 .34717 L .40002 .35058 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.40002 .35058 m .41536 .32591 L .3957 .32256 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.59998 .35058 m .58464 .32591 L .56231 .32847 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.58464 .32591 m .59998 .35058 L .62364 .34717 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.63973 .37452 m .62364 .34717 L .59998 .35058 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.36027 .62548 m .37636 .65283 L .40002 .64942 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.41536 .67409 m .40002 .64942 L .37636 .65283 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.40002 .64942 m .41536 .67409 L .43769 .67153 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.59998 .64942 m .58464 .67409 L .6043 .67744 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.6043 .67744 m .62364 .65283 L .59998 .64942 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.33733 .37063 m .3221 .40078 L .34762 .40403 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.34762 .40403 m .36027 .37452 L .33733 .37063 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.31108 .56719 m .3221 .59922 L .34762 .59597 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.36027 .62548 m .34762 .59597 L .3221 .59922 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.63973 .37452 m .65238 .40403 L .6779 .40078 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.68892 .43281 m .6779 .40078 L .65238 .40403 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.65238 .59597 m .63973 .62548 L .66267 .62937 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.66267 .62937 m .6779 .59922 L .65238 .59597 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.56231 .32847 m .54929 .30652 L .53022 .30806 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.54929 .30652 m .56231 .32847 L .58464 .32591 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56231 .67153 m .54929 .69348 L .56674 .69576 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56674 .69576 m .58464 .67409 L .56231 .67153 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43326 .30424 m .41536 .32591 L .43769 .32847 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43769 .32847 m .45071 .30652 L .43326 .30424 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.43769 .67153 m .45071 .69348 L .46978 .69194 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.45071 .69348 m .43769 .67153 L .41536 .67409 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.35657 .34299 m .33733 .37063 L .36027 .37452 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.36027 .37452 m .37636 .34717 L .35657 .34299 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.3221 .59922 m .33733 .62937 L .36027 .62548 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.37636 .65283 m .36027 .62548 L .33733 .62937 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.62364 .34717 m .63973 .37452 L .66267 .37063 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.6779 .40078 m .66267 .37063 L .63973 .37452 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.63973 .62548 m .62364 .65283 L .64343 .65701 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.64343 .65701 m .66267 .62937 L .63973 .62548 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.47883 .28911 m .46978 .30806 L .48982 .30885 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.48982 .30885 m .49286 .28971 L .47883 .28911 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.49286 .28971 m .48982 .30885 L .51018 .30885 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.51018 .30885 m .50714 .28971 L .49286 .28971 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50714 .28971 m .51018 .30885 L .53022 .30806 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.50714 .71029 m .51018 .69115 L .48982 .69115 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.51018 .69115 m .50714 .71029 L .52117 .71089 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.52117 .71089 m .53022 .69194 L .51018 .69115 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.49286 .71029 m .48982 .69115 L .46978 .69194 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.48982 .69115 m .49286 .71029 L .50714 .71029 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41809 .30128 m .3957 .32256 L .41536 .32591 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41536 .32591 m .43326 .30424 L .41809 .30128 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.58464 .32591 m .56674 .30424 L .54929 .30652 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.56674 .30424 m .58464 .32591 L .6043 .32256 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.62364 .34717 m .6043 .32256 L .58464 .32591 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.37636 .65283 m .3957 .67744 L .41536 .67409 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.43326 .69576 m .41536 .67409 L .3957 .67744 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.41536 .67409 m .43326 .69576 L .45071 .69348 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58464 .67409 m .56674 .69576 L .58191 .69872 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58191 .69872 m .6043 .67744 L .58464 .67409 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.53022 .30806 m .52117 .28911 L .50714 .28971 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.52117 .28911 m .53022 .30806 L .54929 .30652 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53022 .69194 m .52117 .71089 L .53445 .71208 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53445 .71208 m .54929 .69348 L .53022 .69194 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46555 .28792 m .45071 .30652 L .46978 .30806 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46978 .30806 m .47883 .28911 L .46555 .28792 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.47883 .71089 m .46978 .69194 L .45071 .69348 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.46978 .69194 m .47883 .71089 L .49286 .71029 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37952 .31849 m .35657 .34299 L .37636 .34717 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37636 .34717 m .3957 .32256 L .37952 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.6043 .32256 m .62364 .34717 L .64343 .34299 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.66267 .37063 m .64343 .34299 L .62364 .34717 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.33733 .62937 m .35657 .65701 L .37636 .65283 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.3957 .67744 m .37636 .65283 L .35657 .65701 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62364 .65283 m .6043 .67744 L .62048 .68151 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62048 .68151 m .64343 .65701 L .62364 .65283 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.28166 .46465 m .27906 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.30218 .5 m .30442 .46609 L .28166 .46465 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.30442 .53391 m .30218 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.69558 .46609 m .69782 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.69782 .5 m .69558 .53391 L .71834 .53535 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.71834 .53535 m .72094 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.28941 .43004 m .28166 .46465 L .30442 .46609 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.30442 .46609 m .31108 .43281 L .28941 .43004 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.27906 .5 m .28166 .53535 L .30442 .53391 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.31108 .56719 m .30442 .53391 L .28166 .53535 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.30923 .56644 m
.31118 .56748 L
s
.5 Mabswid
.534 .699 .545 r
.68892 .43281 m .69558 .46609 L .71834 .46465 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.72094 .5 m .71834 .46465 L .69558 .46609 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.69558 .53391 m .68892 .56719 L .71059 .56996 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.71059 .56996 m .71834 .53535 L .69558 .53391 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.54929 .30652 m .53445 .28792 L .52117 .28911 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.53445 .28792 m .54929 .30652 L .56674 .30424 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.45071 .69348 m .46555 .71208 L .47883 .71089 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54929 .69348 m .53445 .71208 L .54649 .71382 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54649 .71382 m .56674 .69576 L .54929 .69348 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45351 .28618 m .43326 .30424 L .45071 .30652 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45071 .30652 m .46555 .28792 L .45351 .28618 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.46555 .71208 m .45071 .69348 L .43326 .69576 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.30216 .39695 m .28941 .43004 L .31108 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.31108 .43281 m .3221 .40078 L .30216 .39695 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.28166 .53535 m .28941 .56996 L .31108 .56719 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.3221 .59922 m .31108 .56719 L .28941 .56996 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.6779 .40078 m .68892 .43281 L .71059 .43004 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.71834 .46465 m .71059 .43004 L .68892 .43281 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.68892 .56719 m .6779 .59922 L .69784 .60305 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.69784 .60305 m .71059 .56996 L .68892 .56719 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3197 .36608 m .30216 .39695 L .3221 .40078 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3221 .40078 m .33733 .37063 L .3197 .36608 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.28941 .56996 m .30216 .60305 L .3221 .59922 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.33733 .62937 m .3221 .59922 L .30216 .60305 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.66267 .37063 m .6779 .40078 L .69784 .39695 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.71059 .43004 m .69784 .39695 L .6779 .40078 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6779 .59922 m .66267 .62937 L .6803 .63392 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6803 .63392 m .69784 .60305 L .6779 .59922 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.40584 .29772 m .37952 .31849 L .3957 .32256 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.3957 .32256 m .41809 .30128 L .40584 .29772 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.35657 .65701 m .37952 .68151 L .3957 .67744 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.41809 .69872 m .3957 .67744 L .37952 .68151 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.3957 .67744 m .41809 .69872 L .43326 .69576 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.6043 .32256 m .58191 .30128 L .56674 .30424 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.58191 .30128 m .6043 .32256 L .62048 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.64343 .34299 m .62048 .31849 L .6043 .32256 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.6043 .67744 m .58191 .69872 L .59416 .70228 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.59416 .70228 m .62048 .68151 L .6043 .67744 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.56674 .30424 m .54649 .28618 L .53445 .28792 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.54649 .28618 m .56674 .30424 L .58191 .30128 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.44321 .28394 m .41809 .30128 L .43326 .30424 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.43326 .30424 m .45351 .28618 L .44321 .28394 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.45351 .71382 m .43326 .69576 L .41809 .69872 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.43326 .69576 m .45351 .71382 L .46555 .71208 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.56674 .69576 m .54649 .71382 L .55679 .71606 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.55679 .71606 m .58191 .69872 L .56674 .69576 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.34168 .33814 m .3197 .36608 L .33733 .37063 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.33733 .37063 m .35657 .34299 L .34168 .33814 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.30216 .60305 m .3197 .63392 L .33733 .62937 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.35657 .65701 m .33733 .62937 L .3197 .63392 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.64343 .34299 m .66267 .37063 L .6803 .36608 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.69784 .39695 m .6803 .36608 L .66267 .37063 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.66267 .62937 m .64343 .65701 L .65832 .66186 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.65832 .66186 m .6803 .63392 L .66267 .62937 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.49626 .27434 m .49286 .28971 L .50714 .28971 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.50714 .28971 m .50374 .27434 L .49626 .27434 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50374 .27434 m .50714 .28971 L .52117 .28911 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.48894 .274 m .47883 .28911 L .49286 .28971 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.49286 .28971 m .49626 .27434 L .48894 .274 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.50374 .72566 m .50714 .71029 L .49286 .71029 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.50714 .71029 m .50374 .72566 L .51106 .726 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.51106 .726 m .52117 .71089 L .50714 .71029 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.49626 .72566 m .49286 .71029 L .47883 .71089 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.49286 .71029 m .49626 .72566 L .50374 .72566 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.52117 .28911 m .51106 .274 L .50374 .27434 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.51106 .274 m .52117 .28911 L .53445 .28792 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.52117 .71089 m .51106 .726 L .51795 .72666 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.51795 .72666 m .53445 .71208 L .52117 .71089 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.48205 .27334 m .46555 .28792 L .47883 .28911 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.47883 .28911 m .48894 .274 L .48205 .27334 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.48894 .726 m .47883 .71089 L .46555 .71208 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.47883 .71089 m .48894 .726 L .49626 .72566 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.36767 .3138 m .34168 .33814 L .35657 .34299 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.35657 .34299 m .37952 .31849 L .36767 .3138 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.3197 .63392 m .34168 .66186 L .35657 .65701 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.37952 .68151 m .35657 .65701 L .34168 .66186 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.62048 .31849 m .64343 .34299 L .65832 .33814 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.6803 .36608 m .65832 .33814 L .64343 .34299 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.64343 .65701 m .62048 .68151 L .63233 .6862 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.63233 .6862 m .65832 .66186 L .64343 .65701 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.53445 .28792 m .51795 .27334 L .51106 .274 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.51795 .27334 m .53445 .28792 L .54649 .28618 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.47588 .27237 m .45351 .28618 L .46555 .28792 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.46555 .28792 m .48205 .27334 L .47588 .27237 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.46555 .71208 m .48205 .72666 L .48894 .726 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.53445 .71208 m .51795 .72666 L .52412 .72763 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.52412 .72763 m .54649 .71382 L .53445 .71208 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.48205 .72666 m .46555 .71208 L .45351 .71382 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.43508 .28127 m .40584 .29772 L .41809 .30128 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.41809 .30128 m .44321 .28394 L .43508 .28127 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.37952 .68151 m .40584 .70228 L .41809 .69872 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.44321 .71606 m .41809 .69872 L .40584 .70228 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.41809 .69872 m .44321 .71606 L .45351 .71382 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.58191 .30128 m .55679 .28394 L .54649 .28618 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.55679 .28394 m .58191 .30128 L .59416 .29772 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.62048 .31849 m .59416 .29772 L .58191 .30128 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.58191 .69872 m .55679 .71606 L .56492 .71873 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.56492 .71873 m .59416 .70228 L .58191 .69872 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.29854 .59481 m
.29886 .59448 L
s
.5 Mabswid
.297 .339 .238 r
.34168 .66186 m .36767 .6862 L .37952 .68151 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.40584 .70228 m .37952 .68151 L .36767 .6862 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.39716 .29366 m .36767 .3138 L .37952 .31849 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.37952 .31849 m .40584 .29772 L .39716 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.59416 .29772 m .62048 .31849 L .63233 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.65832 .33814 m .63233 .3138 L .62048 .31849 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.62048 .68151 m .59416 .70228 L .60284 .70634 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.60284 .70634 m .63233 .6862 L .62048 .68151 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.54649 .28618 m .52412 .27237 L .51795 .27334 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.52412 .27237 m .54649 .28618 L .55679 .28394 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.47068 .27114 m .44321 .28394 L .45351 .28618 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.45351 .28618 m .47588 .27237 L .47068 .27114 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.54649 .71382 m .52412 .72763 L .52932 .72886 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.52932 .72886 m .55679 .71606 L .54649 .71382 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.47588 .72763 m .45351 .71382 L .44321 .71606 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.45351 .71382 m .47588 .72763 L .48205 .72666 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.26636 .46299 m .26345 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.27906 .5 m .28166 .46465 L .26636 .46299 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.28166 .53535 m .27906 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.71834 .46465 m .72094 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.72094 .5 m .71834 .53535 L .73364 .53701 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.73364 .53701 m .73655 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.27502 .4269 m .26636 .46299 L .28166 .46465 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.28166 .46465 m .28941 .43004 L .27502 .4269 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.26345 .5 m .26636 .53701 L .28166 .53535 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.28941 .56996 m .28166 .53535 L .26636 .53701 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.71059 .43004 m .71834 .46465 L .73364 .46299 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.73655 .5 m .73364 .46299 L .71834 .46465 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.71834 .53535 m .71059 .56996 L .72498 .5731 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.72498 .5731 m .73364 .53701 L .71834 .53535 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28923 .39261 m .27502 .4269 L .28941 .43004 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28941 .43004 m .30216 .39695 L .28923 .39261 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.26636 .53701 m .27502 .5731 L .28941 .56996 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.30216 .60305 m .28941 .56996 L .27502 .5731 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.69784 .39695 m .71059 .43004 L .72498 .4269 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.73364 .46299 m .72498 .4269 L .71059 .43004 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71059 .56996 m .69784 .60305 L .71077 .60739 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71077 .60739 m .72498 .5731 L .71059 .56996 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30862 .36096 m .28923 .39261 L .30216 .39695 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30216 .39695 m .3197 .36608 L .30862 .36096 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.27502 .5731 m .28923 .60739 L .30216 .60305 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.3197 .63392 m .30216 .60305 L .28923 .60739 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.6803 .36608 m .69784 .39695 L .71077 .39261 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.72498 .4269 m .71077 .39261 L .69784 .39695 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69784 .60305 m .6803 .63392 L .69138 .63904 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69138 .63904 m .71077 .60739 L .69784 .60305 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.42953 .27826 m .39716 .29366 L .40584 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.40584 .29772 m .43508 .28127 L .42953 .27826 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.36767 .6862 m .39716 .70634 L .40584 .70228 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.43508 .71873 m .40584 .70228 L .39716 .70634 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.40584 .70228 m .43508 .71873 L .44321 .71606 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.59416 .29772 m .56492 .28127 L .55679 .28394 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.56492 .28127 m .59416 .29772 L .60284 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.63233 .3138 m .60284 .29366 L .59416 .29772 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.59416 .70228 m .56492 .71873 L .57047 .72174 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.57047 .72174 m .60284 .70634 L .59416 .70228 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.46668 .26969 m .43508 .28127 L .44321 .28394 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.44321 .28394 m .47068 .27114 L .46668 .26969 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.55679 .28394 m .52932 .27114 L .52412 .27237 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.52932 .27114 m .55679 .28394 L .56492 .28127 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.47068 .72886 m .44321 .71606 L .43508 .71873 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.44321 .71606 m .47068 .72886 L .47588 .72763 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.55679 .71606 m .52932 .72886 L .53332 .73031 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.53332 .73031 m .56492 .71873 L .55679 .71606 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.33273 .33273 m .30862 .36096 L .3197 .36608 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.3197 .36608 m .34168 .33814 L .33273 .33273 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.28923 .60739 m .30862 .63904 L .3197 .63392 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.34168 .66186 m .3197 .63392 L .30862 .63904 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.65832 .33814 m .6803 .36608 L .69138 .36096 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.71077 .39261 m .69138 .36096 L .6803 .36608 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.6803 .63392 m .65832 .66186 L .66727 .66727 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.66727 .66727 m .69138 .63904 L .6803 .63392 L p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50374 .27434 m .5 .26345 L .49626 .27434 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.51106 .274 m .5 .26345 L .50374 .27434 L closepath p F P
.505 .664 .505 r
s
.554 .773 .585 r
.49626 .27434 m .5 .26345 L .48894 .274 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49626 .72566 L .48894 .726 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50374 .72566 L .49626 .72566 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .51106 .726 L .50374 .72566 L closepath p F P
.505 .664 .505 r
s
.554 .773 .586 r
.51795 .27334 m .5 .26345 L .51106 .274 L closepath p F P
.505 .664 .505 r
s
.551 .769 .581 r
.48894 .274 m .5 .26345 L .48205 .27334 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .51795 .72666 L .51106 .726 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48894 .726 L .48205 .72666 L closepath p F P
.505 .664 .505 r
s
.47 .648 .464 r
.36096 .30862 m .33273 .33273 L .34168 .33814 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.34168 .33814 m .36767 .3138 L .36096 .30862 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.30862 .63904 m .33273 .66727 L .34168 .66186 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.36767 .6862 m .34168 .66186 L .33273 .66727 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.63233 .3138 m .65832 .33814 L .66727 .33273 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.69138 .36096 m .66727 .33273 L .65832 .33814 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.65832 .66186 m .63233 .6862 L .63904 .69138 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.63904 .69138 m .66727 .66727 L .65832 .66186 L p F P
.505 .664 .505 r
s
.55 .768 .584 r
.52412 .27237 m .5 .26345 L .51795 .27334 L closepath p F P
.505 .664 .505 r
s
.546 .763 .576 r
.48205 .27334 m .5 .26345 L .47588 .27237 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .52412 .72763 L .51795 .72666 L closepath p F P
.505 .664 .505 r
s
.198 .204 .155 r
.5 .73655 m .48205 .72666 L .47588 .72763 L closepath p F P
.505 .664 .505 r
s
.537 .749 .559 r
.46407 .26807 m .42953 .27826 L .43508 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.43508 .28127 m .46668 .26969 L .46407 .26807 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.39716 .70634 m .42953 .72174 L .43508 .71873 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.46668 .73031 m .43508 .71873 L .42953 .72174 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.43508 .71873 m .46668 .73031 L .47068 .72886 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.56492 .28127 m .53332 .26969 L .52932 .27114 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.53332 .26969 m .56492 .28127 L .57047 .27826 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.60284 .29366 m .57047 .27826 L .56492 .28127 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.56492 .71873 m .53332 .73031 L .53593 .73193 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.53593 .73193 m .57047 .72174 L .56492 .71873 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.39261 .28923 m .36096 .30862 L .36767 .3138 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.36767 .3138 m .39716 .29366 L .39261 .28923 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.33273 .66727 m .36096 .69138 L .36767 .6862 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.39716 .70634 m .36767 .6862 L .36096 .69138 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.60284 .29366 m .63233 .3138 L .63904 .30862 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.66727 .33273 m .63904 .30862 L .63233 .3138 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.63233 .6862 m .60284 .70634 L .60739 .71077 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.60739 .71077 m .63904 .69138 L .63233 .6862 L p F P
.505 .664 .505 r
s
.539 .755 .57 r
.47588 .27237 m .5 .26345 L .47068 .27114 L closepath p F P
.505 .664 .505 r
s
.545 .762 .58 r
.52932 .27114 m .5 .26345 L .52412 .27237 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .47588 .72763 L .47068 .72886 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .52932 .72886 L .52412 .72763 L closepath p F P
.505 .664 .505 r
s
.501 .701 .516 r
.4269 .27502 m .39261 .28923 L .39716 .29366 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.39716 .29366 m .42953 .27826 L .4269 .27502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.36096 .69138 m .39261 .71077 L .39716 .70634 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42953 .72174 m .39716 .70634 L .39261 .71077 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.57047 .27826 m .60284 .29366 L .60739 .28923 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.63904 .30862 m .60739 .28923 L .60284 .29366 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.60284 .70634 m .57047 .72174 L .5731 .72498 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.5731 .72498 m .60739 .71077 L .60284 .70634 L p F P
.505 .664 .505 r
s
.531 .745 .563 r
.47068 .27114 m .5 .26345 L .46668 .26969 L closepath p F P
.505 .664 .505 r
s
.537 .753 .575 r
.53332 .26969 m .5 .26345 L .52932 .27114 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .47068 .72886 L .46668 .73031 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .53332 .73031 L .52932 .72886 L closepath p F P
.505 .664 .505 r
s
.509 .716 .534 r
.46299 .26636 m .4269 .27502 L .42953 .27826 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.42953 .27826 m .46407 .26807 L .46299 .26636 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.39261 .71077 m .4269 .72498 L .42953 .72174 L p F P
.505 .664 .505 r
s
.187 .194 .147 r
.46407 .73193 m .42953 .72174 L .4269 .72498 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.42953 .72174 m .46407 .73193 L .46668 .73031 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.57047 .27826 m .53593 .26807 L .53332 .26969 L p F P
.505 .664 .505 r
s
.53 .744 .575 r
.53593 .26807 m .57047 .27826 L .5731 .27502 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.60739 .28923 m .5731 .27502 L .57047 .27826 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57047 .72174 m .53593 .73193 L .53701 .73364 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.53701 .73364 m .5731 .72498 L .57047 .72174 L p F P
.505 .664 .505 r
s
.522 .734 .555 r
.46668 .26969 m .5 .26345 L .46407 .26807 L closepath p F P
.505 .664 .505 r
s
.183 .191 .145 r
.5 .73655 m .46668 .73031 L .46407 .73193 L closepath p F P
.505 .664 .505 r
s
.529 .743 .568 r
.53593 .26807 m .5 .26345 L .53332 .26969 L closepath p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .53593 .73193 L .53332 .73031 L closepath p F P
.505 .664 .505 r
s
.512 .722 .546 r
.46407 .26807 m .5 .26345 L .46299 .26636 L closepath p F P
.505 .664 .505 r
s
.187 .194 .147 r
.4269 .72498 m .46299 .73364 L .46407 .73193 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.5 .73655 m .46407 .73193 L .46299 .73364 L closepath p F P
.505 .664 .505 r
s
.519 .731 .56 r
.53701 .26636 m .5 .26345 L .53593 .26807 L closepath p F P
.505 .664 .505 r
s
.53 .744 .575 r
.5731 .27502 m .53701 .26636 L .53593 .26807 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .53701 .73364 L .53593 .73193 L closepath p F P
.505 .664 .505 r
s
.33 .466 .323 r
.33073 .32695 m .30537 .35543 L .30862 .36096 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.30862 .36096 m .33273 .33273 L .33073 .32695 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.28923 .39261 m .30862 .36096 L .30537 .35543 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.28477 .61211 m .30537 .64457 L .30862 .63904 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.30862 .63904 m .28923 .60739 L .28477 .61211 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.33273 .66727 m .30862 .63904 L .30537 .64457 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26959 .42346 m .26028 .46118 L .26636 .46299 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26636 .46299 m .27502 .4269 L .26959 .42346 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26345 .5 m .26636 .46299 L .26028 .46118 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.25714 .5 m .26028 .53882 L .26636 .53701 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.26636 .53701 m .26345 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.27502 .5731 m .26636 .53701 L .26028 .53882 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.26959 .57654 m .28477 .61211 L .28923 .60739 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.28923 .60739 m .27502 .5731 L .26959 .57654 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.30537 .35543 m .28477 .38789 L .28923 .39261 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.27502 .4269 m .28923 .39261 L .28477 .38789 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26028 .46118 m .25714 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.26028 .53882 m .26959 .57654 L .27502 .5731 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.28477 .38789 m .26959 .42346 L .27502 .4269 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.33073 .67305 m .36011 .69684 L .36096 .69138 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.36096 .69138 m .33273 .66727 L .33073 .67305 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.39261 .71077 m .36096 .69138 L .36011 .69684 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.46353 .26462 m .42744 .27169 L .4269 .27502 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.4269 .27502 m .46299 .26636 L .46353 .26462 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.39261 .28923 m .4269 .27502 L .42744 .27169 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.36011 .69684 m .39265 .71539 L .39261 .71077 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.4269 .72498 m .39261 .71077 L .39265 .71539 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.39265 .28461 m .36011 .30316 L .36096 .30862 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.36096 .30862 m .39261 .28923 L .39265 .28461 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.33273 .33273 m .36096 .30862 L .36011 .30316 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.42744 .27169 m .39265 .28461 L .39261 .28923 L p F P
.505 .664 .505 r
s
.501 .709 .537 r
.46299 .26636 m .5 .26345 L .46353 .26462 L closepath p F P
.505 .664 .505 r
s
.508 .719 .551 r
.53647 .26462 m .5 .26345 L .53701 .26636 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .53647 .73538 L .53701 .73364 L closepath p F P
.505 .664 .505 r
s
.159 .169 .128 r
.5 .73655 m .5343 .73707 L .53647 .73538 L closepath p F P
.505 .664 .505 r
s
.152 .162 .124 r
.5 .73655 m .53058 .73863 L .5343 .73707 L closepath p F P
.505 .664 .505 r
s
.147 .157 .119 r
.5 .73655 m .52543 .73998 L .53058 .73863 L closepath p F P
.505 .664 .505 r
s
.142 .152 .116 r
.5 .73655 m .51909 .74106 L .52543 .73998 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .51184 .74182 L .51909 .74106 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50401 .7422 L .51184 .74182 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49599 .7422 L .50401 .7422 L closepath p F P
.505 .664 .505 r
s
.137 .148 .112 r
.5 .73655 m .48816 .74182 L .49599 .7422 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48091 .74106 L .48816 .74182 L closepath p F P
.505 .664 .505 r
s
.144 .154 .117 r
.5 .73655 m .47457 .73998 L .48091 .74106 L closepath p F P
.505 .664 .505 r
s
.149 .159 .121 r
.5 .73655 m .46942 .73863 L .47457 .73998 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .4657 .73707 L .46942 .73863 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .46353 .73538 L .4657 .73707 L closepath p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .46299 .73364 L .46353 .73538 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.42744 .72831 m .46353 .73538 L .46299 .73364 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.46299 .73364 m .4269 .72498 L .42744 .72831 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.39265 .71539 m .42744 .72831 L .4269 .72498 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.30537 .64457 m .33073 .67305 L .33273 .66727 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.36011 .30316 m .33073 .32695 L .33273 .33273 L p F P
.505 .664 .505 r
s
.497 .705 .541 r
.5343 .26293 m .5 .26345 L .53647 .26462 L closepath p F P
.505 .664 .505 r
s
.49 .696 .528 r
.46353 .26462 m .5 .26345 L .4657 .26293 L closepath p F P
.505 .664 .505 r
s
.486 .692 .531 r
.53058 .26137 m .5 .26345 L .5343 .26293 L closepath p F P
.505 .664 .505 r
s
.476 .679 .522 r
.52543 .26002 m .5 .26345 L .53058 .26137 L closepath p F P
.505 .664 .505 r
s
.48 .683 .519 r
.4657 .26293 m .5 .26345 L .46942 .26137 L closepath p F P
.505 .664 .505 r
s
.467 .668 .513 r
.51909 .25894 m .5 .26345 L .52543 .26002 L closepath p F P
.505 .664 .505 r
s
.47 .672 .511 r
.46942 .26137 m .5 .26345 L .47457 .26002 L closepath p F P
.505 .664 .505 r
s
.46 .659 .507 r
.51184 .25818 m .5 .26345 L .51909 .25894 L closepath p F P
.505 .664 .505 r
s
.462 .662 .505 r
.47457 .26002 m .5 .26345 L .48091 .25894 L closepath p F P
.505 .664 .505 r
s
.455 .653 .502 r
.50401 .2578 m .5 .26345 L .51184 .25818 L closepath p F P
.505 .664 .505 r
s
.457 .655 .501 r
.48091 .25894 m .5 .26345 L .48816 .25818 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49599 .2578 m .5 .26345 L .50401 .2578 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.48816 .25818 m .5 .26345 L .49599 .2578 L closepath p F P
.505 .664 .505 r
s
.155 .165 .126 r
.5731 .72498 m .53701 .73364 L .53647 .73538 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.53701 .26636 m .5731 .27502 L .57256 .27169 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.57256 .27169 m .53647 .26462 L .53701 .26636 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.5731 .27502 m .60739 .28923 L .60735 .28461 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.60735 .28461 m .57256 .27169 L .5731 .27502 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.60739 .71077 m .5731 .72498 L .57256 .72831 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.53647 .73538 m .57256 .72831 L .5731 .72498 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.60739 .28923 m .63904 .30862 L .63989 .30316 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.63989 .30316 m .60735 .28461 L .60739 .28923 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.63904 .69138 m .60739 .71077 L .60735 .71539 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.57256 .72831 m .60735 .71539 L .60739 .71077 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.63904 .30862 m .66727 .33273 L .66927 .32695 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.66927 .32695 m .63989 .30316 L .63904 .30862 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.66727 .66727 m .63904 .69138 L .63989 .69684 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.60735 .71539 m .63989 .69684 L .63904 .69138 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.66727 .33273 m .69138 .36096 L .69463 .35543 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.69463 .35543 m .66927 .32695 L .66727 .33273 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.69138 .63904 m .66727 .66727 L .66927 .67305 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.63989 .69684 m .66927 .67305 L .66727 .66727 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.69138 .36096 m .71077 .39261 L .71523 .38789 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.71523 .38789 m .69463 .35543 L .69138 .36096 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.71077 .60739 m .69138 .63904 L .69463 .64457 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.66927 .67305 m .69463 .64457 L .69138 .63904 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.71077 .39261 m .72498 .4269 L .73041 .42346 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.73041 .42346 m .71523 .38789 L .71077 .39261 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.72498 .5731 m .71077 .60739 L .71523 .61211 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.69463 .64457 m .71523 .61211 L .71077 .60739 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.72498 .4269 m .73364 .46299 L .73972 .46118 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.73972 .46118 m .73041 .42346 L .72498 .4269 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73364 .53701 m .72498 .5731 L .73041 .57654 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.71523 .61211 m .73041 .57654 L .72498 .5731 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.73364 .46299 m .73655 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73655 .5 m .73364 .53701 L .73972 .53882 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73972 .53882 m .74286 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.74286 .5 m .73972 .46118 L .73364 .46299 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73041 .57654 m .73972 .53882 L .73364 .53701 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.43126 .73159 m .4657 .73707 L .46353 .73538 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.46353 .73538 m .42744 .72831 L .43126 .73159 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.42744 .27169 m .46353 .26462 L .4657 .26293 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.57256 .72831 m .53647 .73538 L .5343 .73707 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.53647 .26462 m .57256 .27169 L .56874 .26841 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.56874 .26841 m .5343 .26293 L .53647 .26462 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.43832 .73466 m .46942 .73863 L .4657 .73707 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.4657 .73707 m .43126 .73159 L .43832 .73466 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.43126 .26841 m .4657 .26293 L .46942 .26137 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.4657 .26293 m .43126 .26841 L .42744 .27169 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.5343 .73707 m .56874 .73159 L .57256 .72831 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.56874 .73159 m .5343 .73707 L .53058 .73863 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.5343 .26293 m .56874 .26841 L .56168 .26534 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.56168 .26534 m .53058 .26137 L .5343 .26293 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.39759 .72 m .43126 .73159 L .42744 .72831 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.42744 .72831 m .39265 .71539 L .39759 .72 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.39265 .28461 m .42744 .27169 L .43126 .26841 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.60735 .71539 m .57256 .72831 L .56874 .73159 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.57256 .27169 m .60735 .28461 L .60241 .28 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.60241 .28 m .56874 .26841 L .57256 .27169 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.44839 .73736 m .47457 .73998 L .46942 .73863 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.46942 .73863 m .43832 .73466 L .44839 .73736 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.53058 .73863 m .56168 .73466 L .56874 .73159 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.56168 .73466 m .53058 .73863 L .52543 .73998 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.43832 .26534 m .46942 .26137 L .47457 .26002 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.46942 .26137 m .43832 .26534 L .43126 .26841 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.53058 .26137 m .56168 .26534 L .55161 .26264 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.55161 .26264 m .52543 .26002 L .53058 .26137 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.36568 .70237 m .39759 .72 L .39265 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.39265 .71539 m .36011 .69684 L .36568 .70237 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.43126 .26841 m .39759 .28 L .39265 .28461 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.36011 .30316 m .39265 .28461 L .39759 .28 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.63989 .69684 m .60735 .71539 L .60241 .72 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56874 .73159 m .60241 .72 L .60735 .71539 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.60735 .28461 m .63989 .30316 L .63432 .29763 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.63432 .29763 m .60241 .28 L .60735 .28461 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.46108 .73954 m .48091 .74106 L .47457 .73998 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.47457 .73998 m .44839 .73736 L .46108 .73954 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.52543 .73998 m .55161 .73736 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.55161 .73736 m .52543 .73998 L .51909 .74106 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.44839 .26264 m .47457 .26002 L .48091 .25894 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.47457 .26002 m .44839 .26264 L .43832 .26534 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.52543 .26002 m .55161 .26264 L .53892 .26046 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.53892 .26046 m .51909 .25894 L .52543 .26002 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.33651 .67897 m .36568 .70237 L .36011 .69684 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.36011 .69684 m .33073 .67305 L .33651 .67897 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.39759 .28 m .36568 .29763 L .36011 .30316 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.33073 .32695 m .36011 .30316 L .36568 .29763 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.66927 .67305 m .63989 .69684 L .63432 .70237 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.60241 .72 m .63432 .70237 L .63989 .69684 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.63989 .30316 m .66927 .32695 L .66349 .32103 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.66349 .32103 m .63432 .29763 L .63989 .30316 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.40751 .72438 m .43832 .73466 L .43126 .73159 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.43126 .73159 m .39759 .72 L .40751 .72438 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.39759 .28 m .43126 .26841 L .43832 .26534 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.56874 .26841 m .60241 .28 L .59249 .27562 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.59249 .27562 m .56168 .26534 L .56874 .26841 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.60241 .72 m .56874 .73159 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.51909 .74106 m .53892 .73954 L .55161 .73736 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.53892 .73954 m .51909 .74106 L .51184 .74182 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.47579 .74108 m .48816 .74182 L .48091 .74106 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.48091 .74106 m .46108 .73954 L .47579 .74108 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.51909 .25894 m .53892 .26046 L .52421 .25892 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.52421 .25892 m .51184 .25818 L .51909 .25894 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.46108 .26046 m .48091 .25894 L .48816 .25818 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.48091 .25894 m .46108 .26046 L .44839 .26264 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.31104 .65028 m .33651 .67897 L .33073 .67305 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.33073 .67305 m .30537 .64457 L .31104 .65028 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.36568 .29763 m .33651 .32103 L .33073 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.30537 .35543 m .33073 .32695 L .33651 .32103 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63432 .70237 m .66349 .67897 L .66927 .67305 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.69463 .64457 m .66927 .67305 L .66349 .67897 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.66927 .32695 m .69463 .35543 L .68896 .34972 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.68896 .34972 m .66349 .32103 L .66927 .32695 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.51184 .74182 m .52421 .74108 L .53892 .73954 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.52421 .74108 m .51184 .74182 L .50401 .7422 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.49179 .74187 m .49599 .7422 L .48816 .74182 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.48816 .74182 m .47579 .74108 L .49179 .74187 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.51184 .25818 m .52421 .25892 L .50821 .25813 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.50821 .25813 m .50401 .2578 L .51184 .25818 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.48816 .25818 m .47579 .25892 L .46108 .26046 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.47579 .25892 m .48816 .25818 L .49599 .2578 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.50401 .7422 m .50821 .74187 L .52421 .74108 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.50821 .74187 m .50401 .7422 L .49599 .7422 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.49599 .7422 m .49179 .74187 L .50821 .74187 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50401 .2578 m .50821 .25813 L .49179 .25813 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49179 .25813 m .49599 .2578 L .50401 .2578 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.49599 .2578 m .49179 .25813 L .47579 .25892 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33651 .32103 m .31104 .34972 L .30537 .35543 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.28477 .38789 m .30537 .35543 L .31104 .34972 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.29017 .61703 m .31104 .65028 L .30537 .64457 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.30537 .64457 m .28477 .61211 L .29017 .61703 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.69463 .35543 m .71523 .38789 L .70983 .38297 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.70983 .38297 m .68896 .34972 L .69463 .35543 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.71523 .61211 m .69463 .64457 L .68896 .65028 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.66349 .67897 m .68896 .65028 L .69463 .64457 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.42217 .72827 m .44839 .73736 L .43832 .73466 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.43832 .73466 m .40751 .72438 L .42217 .72827 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.43832 .26534 m .40751 .27562 L .39759 .28 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.40751 .27562 m .43832 .26534 L .44839 .26264 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.56168 .73466 m .59249 .72438 L .60241 .72 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.59249 .72438 m .56168 .73466 L .55161 .73736 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.56168 .26534 m .59249 .27562 L .57783 .27173 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.57783 .27173 m .55161 .26264 L .56168 .26534 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.37793 .70768 m .40751 .72438 L .39759 .72 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.39759 .72 m .36568 .70237 L .37793 .70768 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.36568 .29763 m .39759 .28 L .40751 .27562 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.63432 .70237 m .60241 .72 L .59249 .72438 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.60241 .28 m .63432 .29763 L .62207 .29232 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.62207 .29232 m .59249 .27562 L .60241 .28 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.31104 .34972 m .29017 .38297 L .28477 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.26959 .42346 m .28477 .38789 L .29017 .38297 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.27466 .58014 m .29017 .61703 L .28477 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.28477 .61211 m .26959 .57654 L .27466 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.73041 .57654 m .71523 .61211 L .70983 .61703 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.68896 .65028 m .70983 .61703 L .71523 .61211 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.71523 .38789 m .73041 .42346 L .72534 .41986 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.72534 .41986 m .70983 .38297 L .71523 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.29017 .38297 m .27466 .41986 L .26959 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.26028 .46118 m .26959 .42346 L .27466 .41986 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26511 .54072 m .27466 .58014 L .26959 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26959 .57654 m .26028 .53882 L .26511 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.73972 .53882 m .73041 .57654 L .72534 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.70983 .61703 m .72534 .58014 L .73041 .57654 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73041 .42346 m .73972 .46118 L .73489 .45928 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73489 .45928 m .72534 .41986 L .73041 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.27466 .41986 m .26511 .45928 L .26028 .46118 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.25714 .5 m .26028 .46118 L .26511 .45928 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26189 .5 m .26511 .54072 L .26028 .53882 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26028 .53882 m .25714 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73972 .46118 m .74286 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73811 .5 m .73489 .45928 L .73972 .46118 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.74286 .5 m .73972 .53882 L .73489 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.72534 .58014 m .73489 .54072 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.26511 .45928 m .26189 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.73489 .54072 m .73811 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44103 .73145 m .46108 .73954 L .44839 .73736 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44839 .73736 m .42217 .72827 L .44103 .73145 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.55161 .73736 m .57783 .72827 L .59249 .72438 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.57783 .72827 m .55161 .73736 L .53892 .73954 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.42217 .27173 m .44839 .26264 L .46108 .26046 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.44839 .26264 m .42217 .27173 L .40751 .27562 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55161 .26264 m .57783 .27173 L .55897 .26855 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55897 .26855 m .53892 .26046 L .55161 .26264 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.35056 .68472 m .37793 .70768 L .36568 .70237 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.36568 .70237 m .33651 .67897 L .35056 .68472 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.40751 .27562 m .37793 .29232 L .36568 .29763 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.33651 .32103 m .36568 .29763 L .37793 .29232 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.66349 .67897 m .63432 .70237 L .62207 .70768 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.59249 .72438 m .62207 .70768 L .63432 .70237 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.63432 .29763 m .66349 .32103 L .64944 .31528 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.64944 .31528 m .62207 .29232 L .63432 .29763 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.39671 .71247 m .42217 .72827 L .40751 .72438 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.40751 .72438 m .37793 .70768 L .39671 .71247 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.37793 .29232 m .40751 .27562 L .42217 .27173 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.62207 .70768 m .59249 .72438 L .57783 .72827 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.59249 .27562 m .62207 .29232 L .60329 .28753 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.60329 .28753 m .57783 .27173 L .59249 .27562 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.4632 .7337 m .47579 .74108 L .46108 .73954 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.46108 .73954 m .44103 .73145 L .4632 .7337 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.53892 .73954 m .55897 .73145 L .57783 .72827 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.55897 .73145 m .53892 .73954 L .52421 .74108 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.44103 .26855 m .46108 .26046 L .47579 .25892 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.46108 .26046 m .44103 .26855 L .42217 .27173 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.53892 .26046 m .55897 .26855 L .5368 .2663 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.5368 .2663 m .52421 .25892 L .53892 .26046 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.32641 .65589 m .35056 .68472 L .33651 .67897 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.33651 .67897 m .31104 .65028 L .32641 .65589 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.37793 .29232 m .35056 .31528 L .33651 .32103 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.31104 .34972 m .33651 .32103 L .35056 .31528 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.66349 .32103 m .68896 .34972 L .67359 .34411 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.67359 .34411 m .64944 .31528 L .66349 .32103 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.68896 .65028 m .66349 .67897 L .64944 .68472 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.62207 .70768 m .64944 .68472 L .66349 .67897 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.48749 .73487 m .49179 .74187 L .47579 .74108 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.47579 .74108 m .4632 .7337 L .48749 .73487 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.52421 .74108 m .5368 .7337 L .55897 .73145 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.5368 .7337 m .52421 .74108 L .50821 .74187 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.4632 .2663 m .47579 .25892 L .49179 .25813 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.47579 .25892 m .4632 .2663 L .44103 .26855 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.52421 .25892 m .5368 .2663 L .51251 .26513 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.51251 .26513 m .50821 .25813 L .52421 .25892 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.50821 .74187 m .51251 .73487 L .5368 .7337 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.51251 .73487 m .50821 .74187 L .49179 .74187 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.49179 .74187 m .48749 .73487 L .51251 .73487 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.50821 .25813 m .51251 .26513 L .48749 .26513 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.48749 .26513 m .49179 .25813 L .50821 .25813 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.49179 .25813 m .48749 .26513 L .4632 .2663 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.35056 .31528 m .32641 .34411 L .31104 .34972 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.29017 .38297 m .31104 .34972 L .32641 .34411 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.30644 .6219 m .32641 .65589 L .31104 .65028 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.31104 .65028 m .29017 .61703 L .30644 .6219 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.68896 .34972 m .70983 .38297 L .69356 .3781 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.69356 .3781 m .67359 .34411 L .68896 .34972 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.70983 .61703 m .68896 .65028 L .67359 .65589 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.64944 .68472 m .67359 .65589 L .68896 .65028 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42138 .71641 m .44103 .73145 L .42217 .72827 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42217 .72827 m .39671 .71247 L .42138 .71641 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.57783 .72827 m .60329 .71247 L .62207 .70768 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.60329 .71247 m .57783 .72827 L .55897 .73145 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.39671 .28753 m .42217 .27173 L .44103 .26855 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.42217 .27173 m .39671 .28753 L .37793 .29232 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57783 .27173 m .60329 .28753 L .57862 .28359 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57862 .28359 m .55897 .26855 L .57783 .27173 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.3729 .68995 m .39671 .71247 L .37793 .70768 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.37793 .70768 m .35056 .68472 L .3729 .68995 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.35056 .31528 m .37793 .29232 L .39671 .28753 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.64944 .68472 m .62207 .70768 L .60329 .71247 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.62207 .29232 m .64944 .31528 L .6271 .31005 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.6271 .31005 m .60329 .28753 L .62207 .29232 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.2915 .58374 m .30644 .6219 L .29017 .61703 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.29017 .61703 m .27466 .58014 L .2915 .58374 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.32641 .34411 m .30644 .3781 L .29017 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.27466 .41986 m .29017 .38297 L .30644 .3781 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.72534 .58014 m .70983 .61703 L .69356 .6219 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.67359 .65589 m .69356 .6219 L .70983 .61703 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.70983 .38297 m .72534 .41986 L .7085 .41626 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.7085 .41626 m .69356 .3781 L .70983 .38297 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7252 .41013 m
.72554 .41196 L
s
.72403 .40797 m
.7252 .41013 L
s
.72403 .40797 m
.72438 .40981 L
s
.72438 .40981 m
.72554 .41196 L
s
.5 Mabswid
.435 .578 .467 r
.28225 .54263 m .2915 .58374 L .27466 .58014 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.27466 .58014 m .26511 .54072 L .28225 .54263 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.30644 .3781 m .2915 .41626 L .27466 .41986 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.26511 .45928 m .27466 .41986 L .2915 .41626 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.73489 .54072 m .72534 .58014 L .7085 .58374 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.69356 .6219 m .7085 .58374 L .72534 .58014 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.72534 .41986 m .73489 .45928 L .71775 .45737 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.73322 .43832 m
.73597 .44886 L
s
.72894 .42187 m
.73322 .43832 L
s
.5 Mabswid
.287 .351 .238 r
.71775 .45737 m .7085 .41626 L .72534 .41986 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.45078 .71923 m .4632 .7337 L .44103 .73145 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.44103 .73145 m .42138 .71641 L .45078 .71923 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.55897 .73145 m .57862 .71641 L .60329 .71247 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.57862 .71641 m .55897 .73145 L .5368 .7337 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.42138 .28359 m .44103 .26855 L .4632 .2663 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.44103 .26855 m .42138 .28359 L .39671 .28753 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.55897 .26855 m .57862 .28359 L .54922 .28077 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.54922 .28077 m .5368 .2663 L .55897 .26855 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.2915 .41626 m .28225 .45737 L .26511 .45928 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.26189 .5 m .26511 .45928 L .28225 .45737 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.27912 .5 m .28225 .54263 L .26511 .54072 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.26511 .54072 m .26189 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.73489 .45928 m .73811 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.72088 .5 m .71775 .45737 L .73489 .45928 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.73811 .5 m .73489 .54072 L .71775 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.7085 .58374 m .71775 .54263 L .73489 .54072 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.28225 .45737 m .27912 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.71775 .54263 m .72088 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35168 .66105 m .3729 .68995 L .35056 .68472 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35056 .68472 m .32641 .65589 L .35168 .66105 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.39671 .28753 m .3729 .31005 L .35056 .31528 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.32641 .34411 m .35056 .31528 L .3729 .31005 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.67359 .65589 m .64944 .68472 L .6271 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.60329 .71247 m .6271 .68995 L .64944 .68472 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64944 .31528 m .67359 .34411 L .64832 .33895 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64832 .33895 m .6271 .31005 L .64944 .31528 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.48324 .7207 m .48749 .73487 L .4632 .7337 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.4632 .7337 m .45078 .71923 L .48324 .7207 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.5368 .7337 m .54922 .71923 L .57862 .71641 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.54922 .71923 m .5368 .7337 L .51251 .73487 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5368 .2663 m .54922 .28077 L .51676 .2793 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.51676 .2793 m .51251 .26513 L .5368 .2663 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.45078 .28077 m .4632 .2663 L .48749 .26513 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.4632 .2663 m .45078 .28077 L .42138 .28359 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.40284 .69431 m .42138 .71641 L .39671 .71247 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.39671 .71247 m .3729 .68995 L .40284 .69431 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.3729 .31005 m .39671 .28753 L .42138 .28359 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.6271 .68995 m .60329 .71247 L .57862 .71641 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.60329 .28753 m .6271 .31005 L .59716 .30569 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.59716 .30569 m .57862 .28359 L .60329 .28753 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72036 .40853 m
.72239 .41272 L
s
.72239 .41272 m
.72309 .41473 L
s
.72309 .41473 m
.72385 .4186 L
s
.71779 .40601 m
.72036 .40853 L
s
.72743 .42868 m
.72793 .4325 L
s
.72329 .42032 m
.72385 .4186 L
s
.5 Mabswid
.562 .78 .585 r
.51251 .73487 m .51676 .7207 L .54922 .71923 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.51676 .7207 m .51251 .73487 L .48749 .73487 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.48749 .73487 m .48324 .7207 L .51676 .7207 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.51251 .26513 m .51676 .2793 L .48324 .2793 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.48324 .2793 m .48749 .26513 L .51251 .26513 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.48749 .26513 m .48324 .2793 L .45078 .28077 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7266 .4341 m
.72793 .4325 L
s
.71581 .40553 m
.71779 .40601 L
s
.72058 .42163 m
.72329 .42032 L
s
.5 Mabswid
.226 .247 .193 r
.3729 .31005 m .35168 .33895 L .32641 .34411 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.30644 .3781 m .32641 .34411 L .35168 .33895 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.33398 .62642 m .35168 .66105 L .32641 .65589 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.32641 .65589 m .30644 .6219 L .33398 .62642 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.67359 .34411 m .69356 .3781 L .66602 .37358 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.66602 .37358 m .64832 .33895 L .67359 .34411 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.69356 .6219 m .67359 .65589 L .64832 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.6271 .68995 m .64832 .66105 L .67359 .65589 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.72459 .43375 m
.7266 .4341 L
s
.71442 .4071 m
.71581 .40553 L
s
.72189 .43141 m
.72459 .43375 L
s
.7197 .42338 m
.72058 .42163 L
s
.71442 .4071 m
.7151 .41104 L
s
.5 Mabswid
.536 .739 .541 r
.57862 .71641 m .59716 .69431 L .6271 .68995 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.59716 .69431 m .57862 .71641 L .54922 .71923 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.40284 .30569 m .42138 .28359 L .45078 .28077 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.43899 .69745 m .45078 .71923 L .42138 .71641 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.42138 .71641 m .40284 .69431 L .43899 .69745 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.42138 .28359 m .40284 .30569 L .3729 .31005 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.57862 .28359 m .59716 .30569 L .56101 .30255 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.56101 .30255 m .54922 .28077 L .57862 .28359 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7197 .42338 m
.72007 .42728 L
s
.72007 .42728 m
.72189 .43141 L
s
.5 Mabswid
.56 .744 .581 r
.32065 .58709 m .33398 .62642 L .30644 .6219 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.30644 .6219 m .2915 .58374 L .32065 .58709 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.35168 .33895 m .33398 .37358 L .30644 .3781 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.2915 .41626 m .30644 .3781 L .33398 .37358 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.7085 .58374 m .69356 .6219 L .66602 .62642 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.64832 .66105 m .66602 .62642 L .69356 .6219 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.69356 .3781 m .7085 .41626 L .67935 .41291 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.67935 .41291 m .66602 .37358 L .69356 .3781 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.38619 .66538 m .40284 .69431 L .3729 .68995 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.3729 .68995 m .35168 .66105 L .38619 .66538 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.35168 .33895 m .3729 .31005 L .40284 .30569 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.64832 .66105 m .6271 .68995 L .59716 .69431 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.6271 .31005 m .64832 .33895 L .61381 .33462 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.61381 .33462 m .59716 .30569 L .6271 .31005 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.54922 .71923 m .56101 .69745 L .59716 .69431 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.56101 .69745 m .54922 .71923 L .51676 .7207 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.47919 .69909 m .48324 .7207 L .45078 .71923 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.45078 .71923 m .43899 .69745 L .47919 .69909 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.31236 .54441 m .32065 .58709 L .2915 .58374 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.2915 .58374 m .28225 .54263 L .31236 .54441 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.54922 .28077 m .56101 .30255 L .52081 .30091 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.52081 .30091 m .51676 .2793 L .54922 .28077 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.43899 .30255 m .45078 .28077 L .48324 .2793 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.45078 .28077 m .43899 .30255 L .40284 .30569 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.33398 .37358 m .32065 .41291 L .2915 .41626 L p F P
.505 .664 .505 r
s
.444 .557 .432 r
.28225 .45737 m .2915 .41626 L .32065 .41291 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.71775 .54263 m .7085 .58374 L .67935 .58709 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.66602 .62642 m .67935 .58709 L .7085 .58374 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.7085 .41626 m .71775 .45737 L .68764 .45559 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.68764 .45559 m .67935 .41291 L .7085 .41626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.7071 .40377 m
.71568 .43246 L
s
.70506 .40538 m
.70993 .41205 L
s
.70238 .40298 m
.70506 .40538 L
s
.5 Mabswid
.444 .557 .432 r
.32065 .41291 m .31236 .45559 L .28225 .45737 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.27912 .5 m .28225 .45737 L .31236 .45559 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.30955 .5 m .31236 .54441 L .28225 .54263 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.28225 .54263 m .27912 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.71775 .45737 m .72088 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.69045 .5 m .68764 .45559 L .71775 .45737 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.72088 .5 m .71775 .54263 L .68764 .54441 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.67935 .58709 m .68764 .54441 L .71775 .54263 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.51676 .7207 m .52081 .69909 L .56101 .69745 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.52081 .69909 m .51676 .7207 L .48324 .7207 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.48324 .7207 m .47919 .69909 L .52081 .69909 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.51676 .2793 m .52081 .30091 L .47919 .30091 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.47919 .30091 m .48324 .2793 L .51676 .2793 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.48324 .2793 m .47919 .30091 L .43899 .30255 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69932 .40252 m
.70238 .40298 L
s
.5 Mabswid
.489 .624 .484 r
.31236 .45559 m .30955 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.68764 .54441 m .69045 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.40284 .30569 m .38619 .33462 L .35168 .33895 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.33398 .37358 m .35168 .33895 L .38619 .33462 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.3722 .63023 m .38619 .66538 L .35168 .66105 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.35168 .66105 m .33398 .62642 L .3722 .63023 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.64832 .33895 m .66602 .37358 L .6278 .36977 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.6278 .36977 m .61381 .33462 L .64832 .33895 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.66602 .62642 m .64832 .66105 L .61381 .66538 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.59716 .69431 m .61381 .66538 L .64832 .66105 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6979 .40432 m
.69932 .40252 L
s
.5 Mabswid
.641 .862 .655 r
.42833 .66851 m .43899 .69745 L .40284 .69431 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.40284 .69431 m .38619 .66538 L .42833 .66851 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.61381 .66538 m .59716 .69431 L .56101 .69745 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.38619 .33462 m .40284 .30569 L .43899 .30255 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.59716 .30569 m .61381 .33462 L .57167 .33149 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.57167 .33149 m .56101 .30255 L .59716 .30569 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6979 .40432 m
.69882 .41047 L
s
.69882 .41047 m
.70436 .43122 L
s
.5 Mabswid
.616 .814 .622 r
.36161 .58993 m .3722 .63023 L .33398 .62642 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.33398 .62642 m .32065 .58709 L .36161 .58993 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.38619 .33462 m .3722 .36977 L .33398 .37358 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.32065 .41291 m .33398 .37358 L .3722 .36977 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.67935 .58709 m .66602 .62642 L .6278 .63023 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.61381 .66538 m .6278 .63023 L .66602 .62642 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.66602 .37358 m .67935 .41291 L .63839 .41007 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.63839 .41007 m .6278 .36977 L .66602 .37358 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68663 .40086 m
.69461 .43034 L
s
.5 Mabswid
.614 .826 .604 r
.56101 .69745 m .57167 .66851 L .61381 .66538 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.57167 .66851 m .56101 .69745 L .52081 .69909 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.42833 .33149 m .43899 .30255 L .47919 .30091 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.47552 .67016 m .47919 .69909 L .43899 .69745 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.43899 .69745 m .42833 .66851 L .47552 .67016 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.43899 .30255 m .42833 .33149 L .38619 .33462 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.56101 .30255 m .57167 .33149 L .52448 .32984 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.52448 .32984 m .52081 .30091 L .56101 .30255 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69773 .44671 m
.6987 .44477 L
s
.69704 .44266 m
.6987 .44477 L
s
.69607 .4446 m
.69704 .44266 L
s
.69607 .4446 m
.69773 .44671 L
s
.5 Mabswid
.442 .538 .397 r
.3722 .36977 m .38619 .33462 L .42833 .33149 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.41933 .63301 m .42833 .66851 L .38619 .66538 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.38619 .66538 m .3722 .63023 L .41933 .63301 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.61381 .33462 m .6278 .36977 L .58067 .36699 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.58067 .36699 m .57167 .33149 L .61381 .33462 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.6278 .63023 m .61381 .66538 L .57167 .66851 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.52081 .69909 m .52448 .67016 L .57167 .66851 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.52448 .67016 m .52081 .69909 L .47919 .69909 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.47919 .69909 m .47552 .67016 L .52448 .67016 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.47552 .32984 m .47919 .30091 L .52081 .30091 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.47919 .30091 m .47552 .32984 L .42833 .33149 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.52081 .30091 m .52448 .32984 L .47552 .32984 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.35499 .54593 m .36161 .58993 L .32065 .58709 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.32065 .58709 m .31236 .54441 L .35499 .54593 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.3722 .36977 m .36161 .41007 L .32065 .41291 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.31236 .45559 m .32065 .41291 L .36161 .41007 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.68764 .54441 m .67935 .58709 L .63839 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.6278 .63023 m .63839 .58993 L .67935 .58709 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.67935 .41291 m .68764 .45559 L .64501 .45407 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.64501 .45407 m .63839 .41007 L .67935 .41291 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.67599 .39972 m
.68175 .42107 L
s
.6817 .4273 m
.68175 .42107 L
s
.5 Mabswid
.511 .643 .487 r
.36161 .41007 m .35499 .45407 L .31236 .45559 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.30955 .5 m .31236 .45559 L .35499 .45407 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.35274 .5 m .35499 .54593 L .31236 .54441 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.31236 .54441 m .30955 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.68764 .45559 m .69045 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.64726 .5 m .64501 .45407 L .68764 .45559 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.69045 .5 m .68764 .54441 L .64501 .54593 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.63839 .58993 m .64501 .54593 L .68764 .54441 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.67915 .42919 m
.6817 .4273 L
s
.5 Mabswid
.55 .702 .533 r
.35499 .45407 m .35274 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.64501 .54593 m .64726 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.67453 .4289 m
.67915 .42919 L
s
.65945 .39824 m
.66646 .42841 L
s
.67094 .42658 m
.67453 .4289 L
s
.5 Mabswid
.62 .823 .599 r
.57167 .66851 m .58067 .63301 L .6278 .63023 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.57167 .33149 m .58067 .36699 L .52759 .36552 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.52759 .36552 m .52448 .32984 L .57167 .33149 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.58067 .63301 m .57167 .66851 L .52448 .67016 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.41933 .36699 m .42833 .33149 L .47552 .32984 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.47241 .63448 m .47552 .67016 L .42833 .66851 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.42833 .66851 m .41933 .63301 L .47241 .63448 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.42833 .33149 m .41933 .36699 L .3722 .36977 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.41249 .59201 m .41933 .63301 L .3722 .63023 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.3722 .63023 m .36161 .58993 L .41249 .59201 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.6278 .36977 m .63839 .41007 L .58751 .40799 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.58751 .40799 m .58067 .36699 L .6278 .36977 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.63839 .58993 m .6278 .63023 L .58067 .63301 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.36161 .41007 m .3722 .36977 L .41933 .36699 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66475 .41987 m
.67094 .42658 L
s
.5 Mabswid
.645 .854 .627 r
.52448 .67016 m .52759 .63448 L .58067 .63301 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.52448 .32984 m .52759 .36552 L .47241 .36552 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.47241 .36552 m .47552 .32984 L .52448 .32984 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.52759 .63448 m .52448 .67016 L .47552 .67016 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.47552 .67016 m .47241 .63448 L .52759 .63448 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.47552 .32984 m .47241 .36552 L .41933 .36699 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.64774 .40382 m
.65099 .41048 L
s
.64316 .39921 m
.64774 .40382 L
s
.65099 .41048 m
.65192 .41483 L
s
.63906 .39678 m
.64316 .39921 L
s
.65144 .42123 m
.65192 .41483 L
s
.6336 .39645 m
.63906 .39678 L
s
.6486 .42536 m
.65144 .42123 L
s
.5 Mabswid
.627 .817 .614 r
.4082 .54705 m .41249 .59201 L .36161 .58993 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.36161 .58993 m .35499 .54593 L .4082 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.64501 .54593 m .63839 .58993 L .58751 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.58067 .63301 m .58751 .59201 L .63839 .58993 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.41933 .36699 m .41249 .40799 L .36161 .41007 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.35499 .45407 m .36161 .41007 L .41249 .40799 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.63839 .41007 m .64501 .45407 L .5918 .45295 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.5918 .45295 m .58751 .40799 L .63839 .41007 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.63038 .39844 m
.6336 .39645 L
s
.64526 .42734 m
.6486 .42536 L
s
.62753 .40265 m
.63038 .39844 L
s
.63958 .4271 m
.64526 .42734 L
s
.5 Mabswid
.651 .853 .636 r
.47004 .59312 m .47241 .63448 L .41933 .63301 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.41933 .63301 m .41249 .59201 L .47004 .59312 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.58067 .36699 m .58751 .40799 L .52996 .40688 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.52996 .40688 m .52759 .36552 L .58067 .36699 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.58751 .59201 m .58067 .63301 L .52759 .63448 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.41249 .40799 m .41933 .36699 L .47241 .36552 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.62688 .40918 m
.62753 .40265 L
s
.5 Mabswid
.544 .686 .511 r
.41249 .40799 m .4082 .45295 L .35499 .45407 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.35274 .5 m .35499 .45407 L .4082 .45295 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.40674 .5 m .4082 .54705 L .35499 .54593 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.35499 .54593 m .35274 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.64501 .45407 m .64726 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.59326 .5 m .5918 .45295 L .64501 .45407 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.64726 .5 m .64501 .54593 L .5918 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.58751 .59201 m .5918 .54705 L .64501 .54593 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.63537 .42477 m
.63958 .4271 L
s
.62688 .40918 m
.62768 .41359 L
s
.63076 .42025 m
.63537 .42477 L
s
.62768 .41359 m
.63076 .42025 L
s
.5 Mabswid
.578 .743 .531 r
.5918 .54705 m .59326 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.4082 .45295 m .40674 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.61045 .39523 m
.61662 .43736 L
s
.61662 .43736 m
.6172 .44135 L
s
.5 Mabswid
.637 .835 .61 r
.52759 .63448 m .52996 .59312 L .58751 .59201 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.52759 .36552 m .52996 .40688 L .47004 .40688 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.47004 .40688 m .47241 .36552 L .52759 .36552 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.52996 .59312 m .52759 .63448 L .47241 .63448 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.47241 .63448 m .47004 .59312 L .52996 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.47241 .36552 m .47004 .40688 L .41249 .40799 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.59397 .39455 m
.59841 .43019 L
s
.59841 .43019 m
.59976 .44095 L
s
.5 Mabswid
.636 .826 .614 r
.46856 .54764 m .47004 .59312 L .41249 .59201 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.41249 .59201 m .4082 .54705 L .46856 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.5918 .54705 m .58751 .59201 L .52996 .59312 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.4082 .45295 m .41249 .40799 L .47004 .40688 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.58751 .40799 m .5918 .45295 L .53144 .45236 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.53144 .45236 m .52996 .40688 L .58751 .40799 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.57267 .39611 m
.57766 .40073 L
s
.56795 .39374 m
.57267 .39611 L
s
.56124 .39357 m
.56795 .39374 L
s
.57766 .40073 m
.5807 .40752 L
s
.55696 .39573 m
.56124 .39357 L
s
.5807 .40752 m
.58121 .41199 L
s
.57967 .41863 m
.58121 .41199 L
s
.5528 .40016 m
.55696 .39573 L
s
.57551 .42297 m
.57967 .41863 L
s
.55102 .40689 m
.5528 .40016 L
s
.5 Mabswid
.576 .733 .528 r
.5918 .45295 m .59326 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.53195 .5 m .53144 .45236 L .5918 .45295 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.59326 .5 m .5918 .54705 L .53144 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.52996 .59312 m .53144 .54764 L .5918 .54705 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.47004 .40688 m .46856 .45236 L .4082 .45295 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.40674 .5 m .4082 .45295 L .46856 .45236 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.46805 .5 m .46856 .54764 L .4082 .54705 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.4082 .54705 m .40674 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.51517 .39292 m
.52218 .39297 L
s
.52218 .39297 m
.52695 .39528 L
s
.51052 .39517 m
.51517 .39292 L
s
.52695 .39528 m
.53186 .39986 L
s
.57107 .4251 m
.57551 .42297 L
s
.5 Mabswid
.556 .701 .509 r
.52996 .40688 m .53144 .45236 L .46856 .45236 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.46856 .45236 m .47004 .40688 L .52996 .40688 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.50561 .37705 m
.50606 .42448 L
s
.46994 .42276 m
.47626 .44001 L
s
.46958 .42177 m
.46994 .42276 L
s
.4591 .39319 m
.46958 .42177 L
s
.48047 .43015 m
.4964 .39288 L
s
.47626 .44001 m
.48047 .43015 L
s
.5 Mabswid
.634 .823 .605 r
.53144 .54764 m .52996 .59312 L .47004 .59312 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.47004 .59312 m .46856 .54764 L .53144 .54764 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.55102 .40689 m
.55135 .41139 L
s
.51052 .39517 m
.50586 .39969 L
s
.53457 .40666 m
.53186 .39986 L
s
.56406 .42498 m
.57107 .4251 L
s
.55135 .41139 m
.55417 .41815 L
s
.5 Mabswid
.602 .774 .561 r
.53144 .54764 m .53195 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.46856 .45236 m .46805 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.53457 .40666 m
.53479 .41118 L
s
.5592 .42268 m
.56406 .42498 L
s
.55417 .41815 m
.5592 .42268 L
s
.46516 .40892 m
.48909 .40876 L
s
.53269 .4179 m
.53479 .41118 L
s
.52802 .42234 m
.53269 .4179 L
s
.52321 .42454 m
.52802 .42234 L
s
.50601 .41776 m
.51094 .42225 L
s
.51587 .4245 m
.52321 .42454 L
s
.51094 .42225 m
.51587 .4245 L
s
.5 Mabswid
.588 .75 .547 r
.53144 .45236 m .53195 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.46805 .5 m .46856 .45236 L .53144 .45236 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.53195 .5 m .53144 .54764 L .46856 .54764 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.46856 .54764 m .46805 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?40/>3V4@21ZH7a0;3PiP40oooo003U0;3PiPd0PJV10P0S9Qd0
0`21ZH409BPN02DX7P0602DX7P04086YP@0T9ah092LN02@W7Pd0PJV1i@2`h>H10?ooo`00h@2`h>H2
086YP@0301TM5P21ZH40PJV100D07b8J0P21ZH4702<V7@03086YP@0U:1h09BPN00L09BPN00<0PJV1
02@W7P0T9ah01@0T9ah2086YP@D08B@K1@21ZH7Q0;3PiP40oooo003M0;3PiP<0PJV10P0I7AH2086Y
P@D07b8J0P21ZH4802<V7@03086YP@0U:1h09BPN00P09BPN00<0PJV102@W7P0T9ah01`0T9ah2086Y
P@D08B@K0P21ZH400`0L7aP0PJV1086YP@02086YPMd0/>3V0@3oool00=T0/>3V0`21ZH4401TM5P80
PJV10`0O8QXY086YP@<08B@K0P21ZH4201`O60D0PJV1f@2`h>H10?ooo`00eP2`h>H3086YP@D06AdF
1`21ZH400`0`<RH0PJV103Df:@0;03Df:@03086YP@0g>2/0=cP[00T0=cP[00<0PJV103Hh:P0f>2X0
2P0f>2X00`21ZH40<c@X086YP@06086YP@<071lH1@21ZH7F0;3PiP40oooo003C0;3PiP<0PJV10P0I
7AH7086YP@H0<38V00<0PJV103Df:@0e=RT02P0e=RT00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103<d:00c=2P0100c=2P7086YP@0301`O6021ZH40PJV10080PJV1d`2`
h>H10?ooo`00d02`h>H8086YP@80:2/Q0P21ZH48030b9P03086YP@0e=RT0=CHY00/0=CHY00<0PJV1
03Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0c=2P0<c@X00H0<c@X0P21ZH42
02d_8`P0PJV1d02`h>H10?ooo`00c@2`h>H5086YP@L0:2/Q00<0PJV1030b9P0`<RH01`0`<RH00`21
ZH40=CHY03Df:@0<03Df:@03086YP@0g>2/0=cP[00/0=cP[00<0PJV103Hh:P0f>2X02`0f>2X00`21
ZH40<c@X03<d:00803<d:003086YP@0];b<0;BlS00D0;BlS1@21ZH7=0;3PiP40oooo003:0;3PiP<0
PJV100<07R4I086YP@21ZH40200X:b400`21ZH40<38V030b9P08030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X00<0PJV102d_8`0];b<01P0];b<2086YP@0402<V7021ZH40PJV1086YPLX0/>3V0@3oool00<P0
/>3V0`21ZH4201hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH4:030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X0P21ZH4802d_8`03086YP@0S9Q`08bHL00<0PJV1b02`h>H10?ooo`00aP2`h>H3086YP@807R4I
0P21ZH4802P[8@03086YP@0`<RH0<38V00T0<38V00<0PJV103Df:@0e=RT01@0e=RTQ086YP@L0=SPZ
00<0PJV103<d:00c=2P02@0c=2P00`21ZH40;BlS02d_8`0602d_8`80PJV10P0S9Q`3086YPLH0/>3V
0@3oool00<@0/>3V0`21ZH4301hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH45030b9Pl0PJV1201;
E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>Ech0CULn00H0CULn3`21ZH4503<d:080PJV1200]
;b<01021ZH408bHL02<V700S9Q`3086YPL@0/>3V0@3oool00<80/>3V0`21ZH4301hQ6@80PJV11@0X
:b4;086YP@D0@dXe00<0PJV104]D?01;E3`03`1;E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>
Ech0CULn00h0CULn00<0PJV104Q@>@18D3T01018D3T;086YP@D0;BlS0P21ZH4302<V70<0PJV1`P2`
h>H10?ooo`00`02`h>H3086YP@<07R4I0P21ZH400`0X:b40PJV1086YP@04086YP@80=STZ00<0PJV1
04=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00>04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV1
04iG?P1>Ech03P1>Ech00`21ZH40B50i04Q@>@0;04Q@>@03086YP@0m@S00?D8`00H0PJV100<0;BlS
086YP@21ZH400`0S9Q`3086YPL00/>3V0@3oool00;l0/>3V0P21ZH4201hQ6@H0PJV11`0f>BX00`21
ZH40@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21
ZH40CULn04iG?P0>04iG?P03086YP@18D3T0B50i00`0B50i00<0PJV103e2<00m@S001@0m@S06086Y
P@808bHL0P21ZH6o0;3PiP40oooo002m0;3PiPH0PJV100<0:B/Q086YP@0f>BX02P0f>BX00`21ZH40
@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21ZH40
CULn04iG?P0?04iG?P03086YP@18D3T0B50i00/0B50i00<0PJV103e2<00m@S002@0m@S000`21ZH40
;c4U086YP@05086YPKd0/>3V0@3oool00;/0/>3V1021ZH4402T[8@03086YP@0f>BX0=STZ00T0=STZ
00<0PJV104=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn00l0CUTn
00<0PJV104iG?P1>Ech03`1>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m@S00?D8`00T0?D8`
00<0PJV102la9@0_<BD00P0_<BD4086YPK/0/>3V0@3oool00;T0/>3V0`21ZH4602T[8@03086YP@0f
>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>
FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m
@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD3086YPKT0/>3V0@3oool00;L0/>3V1021ZH46
02T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00A
04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0=
04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086YPKL0/>3V0@3oool0
0;H0/>3V1021ZH4602T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03@13BSD00`21
ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn0140CUTn00<0PJV104iG?P1>Ech0401>Ech00`21
ZH40B50i04Q@>@0=04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086Y
PKH0/>3V0@3oool00;D0/>3V00<0PJV101TM5P21ZH401`0Y:b400`21ZH40=STZ03Hi:P0903Hi:P03
086YP@13BSD0@dXe00d0@dXe00<0PJV104]D?01;E3`04@1;E3`00`21ZH40CUTn04iI?P0A04iI?P03
086YP@1>Ech0CULn0100CULn00<0PJV104Q@>@18D3T03P18D3T00`21ZH40?D8`03e2<00903e2<003
086YP@0_<BD0;c4U00D0;c4U00<0PJV1020S6`21ZH40]@2`h>H10?ooo`00/`2`h>H2086YP@0301TM
5P21ZH40:B/Q00H0:B/Q00<0PJV103Hi:P0f>BX02P0f>BX00`21ZH40@dXe04=:=@0904=:=DD0PJV1
2`18D3T00`21ZH40?D8`03e2<00:03e2<003086YP@0_<BD0;c4U00D0;c4U00@0PJV1020S6`21ZH40
PJV1/`2`h>H10?ooo`00/P2`h>H01021ZH406AdF01TM5P21ZH4702T[8@03086YP@0f>BX0=STZ00X0
=STZ00@0PJV104=:=@13BSD0@dXe2@21ZH4405e]D003086YP@1SMU@0HgID0140HgID00<0PJV106Ag
E01TMe@04@1TMe@00`21ZH40H75>061aCP0A061aCP03086YP@1JJDP0FVU80080FVU82@21ZH4304Q@
>@03086YP@0m@S00?D8`00X0?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S6`21ZH6b
0;3PiP40oooo002a0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0PJV103Hi:P0f>BX01`0f>BX8
086YP@`0GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0
H75>0180H75>00<0PJV105YYB01JJDP02P1JJDP8086YP@T0?D8`00<0PJV102la9@0_<BD01@0_<BD0
1021ZH4082<K020S6`21ZH6a0;3PiP40oooo002`0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0
PJV103Hi:P0f>BX02021ZH42051LA@03086YP@1MKE00GFe@00l0GFe@00<0PJV106=fE01SMU@04P1S
MU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP03`1J
JDP00`21ZH40D5a0051L@008086YP@80?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S
6`21ZH6`0;3PiP40oooo002^0;3PiP80PJV100<06AdF086YP@21ZH401P0Y:b45086YP@X0D5a500<0
PJV105e]D01MKE003P1MKE000`21ZH40HgID06=fE00B06=fE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1061aCP1PLDh04P1PLDh00`21ZH40FVU805YYB00>05YYB003086YP@1@G400D5a000P0D5a01@21
ZH4602la9@80PJV100<082<K086YP@21ZH40[P2`h>H10?ooo`00[@2`h>H01021ZH406AdF01TM5P21
ZH4402T[8@D0PJV13@1@G4D00`21ZH40GFe@05e]D00?05e]D003086YP@1SMU@0HgID0180HgID00<0
PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0B061aCP03086YP@1JJDP0FVU800l0FVU800<0
PJV1051L@01@G4002`1@G405086YP@@0;c4U00@0PJV1020S6`0P8a/0PJV1[@2`h>H10?ooo`00[02`
h>H01@21ZH406AdF01TM5P21ZH40:B/Q00@0PJV1100i?c400`21ZH40D5a5051LA@0:051LA@03086Y
P@1MKE00GFe@0100GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00C06AgE003086Y
P@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP0401JJDP00`21ZH40D5a0051L@00:051L@003086Y
P@0oAS80?dHb0080?dHb1021ZH401@0_<BD0PJV1020S6`0P8a/0PJV10:`0/>3V0@3oool00:/0/>3V
00<0PJV101TM5P21ZH400`21ZH4703To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00
3`1MKE000`21ZH40HgID06=fE00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh0
4`1PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS80
1@0oAS84086YP@03020S6`21ZH40/>3V0:X0/>3V0@3oool00:T0/>3V00<0PJV101TM5P21ZH400P21
ZH4903To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00401MKE000`21ZH40HgID06=f
E00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh04`1PLDh00`21ZH40FVU805YY
B00@05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS801`0oAS85086YPJT0/>3V0@3o
ool00:P0/>3V0`21ZH400`0Q91`0PJV103To<@0803To<@03086YP@1@G4D0D5a500/0D5a500<0PJV1
05e]D01MKE00401MKE000`21ZH40HgID06=fE00D06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1
061aCP1PLDh0501PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000`0D5a000<0PJV1
03m6<P0oAS801`0oAS800`21ZH40:B/Q086YP@02086YPJP0/>3V0@3oool00:L0/>3V0P21ZH42024T
7003086YP@0i?c40>Cla00P0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00@05e]
D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0D061a
CP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6
<P03086YP@0Y:b40:B/Q0080PJV1Y`2`h>H10?ooo`00YP2`h>H00`21ZH408B@L024T7002024T7003
086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00A05e]D003
086YP@1SMU@0HgID01<0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>061aCP0C061aCP03
086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0703m6<P03
086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y@2`h>H00`21ZH408B@L
024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@
05e]D00@05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>
061aCP0D061aCP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G400301@G4000`21ZH40?dHb
03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00Y02`
h>H00`21ZH408B@L024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1T
Me@00`21ZH40H75>061aCP0D061aCP03086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G400301@
G4000`21ZH40?dHb03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0XP2`
h>H10?ooo`00Y02`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla00<0PJV1051LA@1@G4D02`1@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID00X0HgID;`21ZH4<061aCP03086YP@1J
JDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6<P05086YP@0Y
:b40:B/Q02T[8@21ZH40Y02`h>H10?ooo`00X`2`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla
00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@05e]D00705e]D1L0PJV12`1fT6P00`21ZH40MY1W
07J@I`0E07J@I`03086YP@1bRf80LX]R00T0LX]R5`21ZH4905YYB003086YP@1@G400D5a000`0D5a0
00<0PJV103m6<P0oAS80200oAS801@21ZH40:B/Q02T[8@0Y:b40PJV10:<0/>3V0@3oool00:80/>3V
00D0PJV1024T700Q91`08B@L086YP@0:03To<@03086YP@1@G4D0D5a500X0D5a53@21ZH4:0769I@03
086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03
086YP@1YOeP0JGmH00P0JGmH3@21ZH4<051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[8@0Y
:b40:B/Q086YP@2R0;3PiP40oooo002Q0;3PiP05086YP@0Q91`08B@L024T7021ZH402P0i?c400`21
ZH40D5a5051LA@05051LA@H0PJV10P1UNU`00`21ZH40LHUU0769I@0B0769I@03086YP@1fT6P0MY1X
01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03086YP@1YOeP0JGmH
0180JGmH00<0PJV105i`C01NL4`01P21ZH47051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[
8@0Y:b40:B/Q086YP@2Q0;3PiP40oooo002P0;3PiP03086YP@0Q91`08B@L00808B@L00<0PJV103To
<@0i?c40200i?c400`21ZH40D5a5086YP@05086YP@L0IGYL00<0PJV10769I@1aRFD04P1aRFD00`21
ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01D0MY1W00<0PJV107:;HP1bRf805P1bRf800`21
ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00D0GW1<1P21ZH400`1@G400PJV103m6<P0903m6
<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00W`2`h>H00`21ZH40
8B@L024T7002024T7003086YP@0i?c40>Cla00D0>Cla1P21ZH4=06EjG003086YP@1aRFD0LHUU0180
LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01D0
LX]R00<0PJV106UoF01YOeP04P1YOeP00`21ZH40GW1<05i`C00;05i`C0H0PJV11`0oAS800`21ZH40
:B/Q02T[8@0202T[8@03086YP@2`h>H0/>3V09d0/>3V0@3oool009h0/>3V00<0PJV1024T700Q91`0
0P0Q91`00`21ZH40>Cla03To<@06086YP@80D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU
0769I@0C0769I@03086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R
07:;HP0E07:;HP03086YP@1YOeP0JGmH01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o
04iK?`06086YP@80?dHb00<0PJV102T[8@0Y:b400P0Y:b400`21ZH40/>3V0;3PiP2L0;3PiP40oooo
002N0;3PiP03086YP@0Q91`08B@L00D0PJV1201@GTT00`21ZH40IGYL06EjG00=06EjG003086YP@1a
RFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1b
Rf80LX]R01D0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`C00=05i`C003086YP@1>
Fcl0CU/o00H0CU/o1@21ZH4202T[8@03086YP@2`h>H0/>3V09`0/>3V0@3oool009d0/>3V00<0PJV1
024T7021ZH400P21ZH4;051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD04P1aRFD0
0`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf80
0`21ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl3
086YP@0302T[8@21ZH40/>3V09`0/>3V0@3oool009`0/>3V0`21ZH42030e;@03086YP@1@GTT0D5i9
00T0D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU0769I@0C0769I@03086YP@1fT6P0MY1X
01H0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH
01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY
00<0PJV1W02`h>H10?ooo`00V`2`h>H2086YP@<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00@0PJV103@i:@0d>BT0=3TY0P21ZH6K0;3P
iP40oooo002J0;3PiP03086YP@0`=Bd0<3D]00<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00=06EjG003086YP@1aRFD0LHUU01@0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00<0PJV103@i:@0d>BT00`0d>BT00`21ZH40
/>3V0;3PiP2H0;3PiP40oooo002I0;3PiP80PJV1100`=Bd00`21ZH40D5i9051NB@09051NB@03086Y
P@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086Y
P@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086Y
P@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl00`21ZH40=3TY03@i:@0203@i:@80PJV1
V@2`h>H10?ooo`00V02`h>H2086YP@@0<3D]00<0PJV1051NB@1@GTT02P1@GTT00`21ZH40IGYL06Ej
G00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05`1fT6P00`21ZH40MY1W07J@
I`0G07J@I`03086YP@1bRf80LX]R01L0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`
C00>05i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i:@0d>BT00P0d>BT2086YPIP0/>3V0@3o
ool009L0/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03P1UNU`0
0`21ZH40LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L0
0`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03P1NL4`0
0`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6G0;3PiP40oooo002G0;3P
iP80PJV1100`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769
I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;
HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK
?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i:@03086YP@0I71H0/>3V09H0/>3V0@3oool009H0
/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40
LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L00`21ZH40
LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03`1NL4`00`21ZH40
CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6F0;3PiP40oooo002E0;3PiP80PJV1
1@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0
501aRFD00`21ZH40MY1X07J@J00G07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;HP1bRf80
5`1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl0
2P1>Fcl00`21ZH40=3TY03@i:@0303@i:@03086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V0P21
ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40LHUU0769
I@0D0769I@03086YP@1fT6P0MY1X00/0MY1X=@21ZH4=07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0
PJV105i`C01NL4`03`1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21
ZH6E0;3PiP40oooo002D0;3PiP80PJV11@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0
IGYL00h0IGYL00<0PJV10769I@1aRFD02P1aRFDI086YP@`0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H0
0`21ZH40P9ma082OL@0:082OLAT0PJV1301YOeP00`21ZH40GW1<05i`C00>05i`C003086YP@1>Fcl0
CU/o00X0CU/o00<0PJV103@i:@0d>BT00`0d>BT2086YPI@0/>3V0@3oool009@0/>3V0P21ZH44030e
;@03086YP@1@GTT0D5i900X0D5i900<0PJV106EjG01UNU`02`1UNU`A086YP@/0Oiie00<0PJV108BT
N024Y7P05`24Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01L0P9ma00<0PJV107RE
J01hUFP02@1hUFPA086YP@d0GW1<00<0PJV104iK?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i
:@80PJV1U02`h>H10?ooo`00T`2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT02P1@GTT01021ZH40
IGYL06EjG01UNU`:086YP@@0MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00G08BT
N003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg405`20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0080JX9H2P21ZH4305i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i
:@0d>BT00`0d>BT2086YPI<0/>3V0@3oool00980/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900L0
D5i92021ZH4=07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06024Y7P00`21ZH40
Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP0501hUFP00`21ZH40
JX9H06Z2F00<06Z2F0P0PJV12@1>Fcl00`21ZH40=3TY03@i:@0303@i:@80PJV1TP2`h>H10?ooo`00
TP2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT01`21ZH4306=iGP03086YP@1fTFh0MY5^00l0MY5^
00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H00l0JX9H
00@0PJV105Y/B@1JK4T0FVa91`21ZH4204iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6B0;3PiP40
oooo002A0;3PiP80PJV1100`=Bd5086YP@T0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie
07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H03@24Y7H20?mo00X0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H
00<0PJV105Y/B@1JK4T01`1JK4T5086YP@@0=3TY0P21ZH6A0;3PiP40oooo002@0;3PiP80PJV10`0`
=Bd2086YP@03049>@@21ZH40HgUN00/0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nN
M@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H03@24Y7H20?mo00X0Q:Af00<0
PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0
PJV105Y/B@1JK4T02P1JK4T01021ZH40@4/d086YP@21ZH4303@i:@03086YP@2`h>H0/>3V08l0/>3V
0@3oool00900/>3V00<0PJV1030e;@21ZH400P21ZH42049>@@03086YP@1SNEh0HgUN00/0HgUN00<0
PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0
PJV108BTMP24Y7H03@24Y7H20?mo00X0Q:Af00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07RE
J00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;
=005086YPI00/>3V0@3oool008l0/>3V0`21ZH45049>@@03086YP@1SNEh0HgUN00X0HgUN00<0PJV1
07JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV1
08BTMP24Y7H03@24Y7H20?mo00X0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21ZH40N9EX07REJ00E
07REJ003086YP@1ZPUP0JX9H00l0JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=003
041;=0<0PJV1S`2`h>H10?ooo`00S`2`h>H2086YP@H0@Ti100<0PJV106=iGP1SNEh02P1SNEh00`21
ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06@24Y7P00`21
ZH40Q:Af08BTMP0=08BTMP80ogl02P24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX
01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0:05Y/B@03086YP@10Bc@0@4/d
00@0@4/d0P21ZH6?0;3PiP40oooo002>0;3PiP80PJV11P12CT400`21ZH40HgUN06=iGP0;06=iGP03
086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003
086YP@24Y7H0Q:Af00h0Q:Af0P3oO`0;08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01h
UFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010
Bc@01010Bc@2086YPHh0/>3V0@3oool008h0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah
00<0PJV108BTMP24Y7H03P24Y7H20?mo00/0Q:Af00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX
07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d
041;=004041;=003086YP@0L81P0/>3V08d0/>3V0@3oool008d0/>3V0P21ZH46049>@@03086YP@1S
NEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24
Y7P0Q:Ah01<0Q:Ah00<0ogl008BTN024Y7P00P24Y7P00`21ZH40Q:Af08BTMP0:08BTMP040?mo0024
Y7H0Q:Af08BTMP80ogl01024Y7H0103oO`00Q:Af08BTMP3oO`0308BTMP03086YP@20Wg40P9ma00d0
P9ma00@0ogl0082OL@20Wg40ogl01`20Wg400`21ZH40N9EX07REJ00F07REJ003086YP@1ZPUP0JX9H
0100JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080PJV1S@2`h>H10?oo
o`00S@2`h>H2086YP@H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03
086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P04`24Y7P30?mo00<0Q:Ah00<0PJV108BTMP24
Y7H02P24Y7H0103oO`00Q:Af08BTMP24Y7H20?mo000308BTMP3oO`00ogl000L0ogl000<0Q:Af086Y
P@20Wg402`20Wg490?mo00H0P9ma00<0PJV107REJ01hUFP00P3oO`0C07REJ0030?mo001ZPUP0ogl0
0100JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080PJV1S@2`h>H10?oo
o`00S02`h>H00`21ZH406b<O086YP@06049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1f
TFh0401fTFh00`21ZH40Oiie07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01@0Q:Ah0P3oO`0308BTN003
086YP@24Y7H0Q:Af00T0Q:Af0P3oO`0308BTMPd0ogl000<0PJV1082OL@20Wg402@20Wg4;0?mo00D0
P9ma00@0PJV107REJ01hUFP0N9EX0P3oO`0607REJ080ogl0201hUFP60?mo00l0JX9H00<0PJV105Y/
B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV108`0/>3V0@3oool008`0
/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40
Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01@0Q:Ah0P3oO`0308BTN003086YP@24Y7H0Q:Af00T0
Q:Af00<0ogl008BTMP24Y7H00P24Y7H40?mo00L0Q:Af103oO`09082OL@<0ogl01`20Wg440?mo00<0
P9ma00@0PJV107REJ01hUFP0N9EX0P3oO`0607REJ080ogl01`1hUFP80?mo00P0JX9H0P3oO`0506Z2
F003086YP@3oO`00FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@2086YPH`0/>3V0@3oool008/0
/>3V00<0PJV101/S7`21ZH401P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^0100
MY5^00<0PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00D08BTN0<0ogl00P24Y7P00`21ZH40
Q:Af08BTMP0808BTMP80ogl01024Y7H30?mo00T0Q:Af103oO`07082OL@<0ogl02@20Wg440?mo0080
P9ma00@0PJV107REJ01hUFP0N9EX0P3oO`0607REJ080ogl01`1hUFP20?mo0080N9EX00<0PJV106Z2
F03oO`000P3oO`0706Z2F080ogl01@1ZPUP30?mo00<0FVa900<0ogl005Y/B@1JK4T00`1JK4T00`3o
O`00FVa9086YP@06041;=003086YP@0L81P0PJV108/0/>3V0@3oool008/0/>3V0P21ZH47049>@@03
086YP@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F07nNM@03
086YP@24Y7P0Q:Ah01D0Q:Ah0P3oO`0208BTN003086YP@24Y7H0Q:Af00P0Q:Af00<0ogl008BTMP24
Y7H00`24Y7H20?mo00/0Q:Af00<0PJV10?mo003oO`001`20Wg420?mo00`0P9ma0P3oO`02082OL@04
086YP@1hUFP0N9EX07REJ080ogl01P1hUFP20?mo00H0N9EX0`3oO`0207REJ003086YP@1ZPUP0JX9H
00@0ogl01@1ZPUP20?mo00D0JX9H00<0PJV10?mo003oO`000P1JK4T30?mo00<0FVa9103oO`000`10
Bc@0ogl0041;=003041;=003086YP@0L81P0PJV108/0/>3V0@3oool008X0/>3V00<0PJV101/S7`21
ZH401P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^0140MY5^00<0PJV107nNM@1o
WWD05@1oWWD00`21ZH40Q:Ah08BTN00F08BTN080ogl00P24Y7P00`21ZH40Q:Af08BTMP0808BTMP03
0?mo0024Y7H0Q:Af00<0Q:Af0P3oO`0;08BTMP03086YP@3oO`00ogl000L0P9ma0P3oO`0<082OL@80
ogl00`20Wg400`21ZH40N9EX07REJ0020?mo00H0N9EX0P3oO`0607REJ080ogl00`1hUFP01021ZH40
JX9H06Z2F01ZPUP40?mo00@0JX9H0P3oO`0506Z2F003086YP@3oO`00ogl000<0FVa90P3oO`0305Y/
B@L0ogl00`10Bc@20?mo000301`P6021ZH40/>3V08T0/>3V0@3oool008X0/>3V00<0PJV101/S7`21
ZH401P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1o
WWD05P1oWWD00`21ZH40Q:Ah08BTN00F08BTN0<0ogl000<0Q:Ah086YP@24Y7H02024Y7H20?mo00D0
Q:Af0P3oO`0;08BTMP04086YP@3oO`00ogl00?mo00H0P9ma0P3oO`0<082OL@80ogl00`20Wg400`21
ZH40N9EX07REJ0020?mo00H0N9EX0P3oO`0607REJ080ogl00`1hUFP00`21ZH40JX9H06Z2F00306Z2
F080ogl0101ZPUP20?mo00H0JX9H0P3oO`0305Y/B@80ogl00`1JK4T20?mo000305Y/B@3oO`00ogl0
0080ogl00P10Bc@40?mo0003086YP@2`h>H0/>3V08P0/>3V0@3oool008X0/>3V00<06b<O086YP@12
CT401@12CT400`21ZH40HgUN06=iGP0<06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1o
WWD02P1oWWDV086YP@h0ogl01P21ZH420?mo00`0PJV10P3oO`06086YP@<0ogl03021ZH430?mo00D0
PJV10P3oO`06086YP@80ogl01P1hUFP20?mo00@0N9EX00<0PJV106Z2F01ZPUP00P1ZPUP20?mo00D0
JX9H0P3oO`0506Z2F0<0ogl00P1JK4T30?mo0080FVa90P3oO`0205Y/B@<0ogl000<0@4/d0?mo003o
O`001@3oO`290;3PiP40oooo00290;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh0
301SNEh00`21ZH40MY5^07JAKP0<07JAKQ40PJV1302;[h800`21ZH40S[>408jcQ00G08jcQ0h0ogl0
1P2>/h820?mo00/0S[>200<0PJV10?mo003oO`001`2;[gd20?mo00d0Rjmm0P3oO`0208^_O@03086Y
P@23YG@0PjEd0080ogl01`23YG@20?mo00@0PJV10`3oO`09086YP@<0ogl0101ZPUP20?mo00D0JX9H
00<0PJV10?mo003oO`000`1JK4T20?mo0080FVa90`3oO`0205Y/B@D0ogl00P10Bc@40?mo08P0/>3V
0@3oool008T0/>3V0P0K8al00`21ZH40@Ti1049>@@04049>@@03086YP@1SNEh0HgUN00/0HgUN00<0
PJV107JAKP1fTFh00`1fTFh:086YP@@0PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jc
Q00G08jcQ0<0ogl000<0PJV108jcPP2>/h801P2>/h800`3oO`00S[>208jcPP0508jcPP80ogl02`2>
/h801021ZH40ogl00?mo003oO`0608^_O@<0ogl0302;[gd30?mo000408^_O@21ZH40PjEd08>UM080
ogl01`23YG@20?mo00D0PjEd0P3oO`0408>UM003086YP@1gU6H0MiAV0080MiAV00<0PJV10?mo003o
O`001021ZH420?mo0003086YP@1ZPUP0JX9H00<0JX9H0P3oO`0305Y/B@80ogl00P1JK4T30?mo0080
FVa900<0PJV10?mo003oO`000P3oO`02041;=0D0ogl0Q`2`h>H10?ooo`00R02`h>H00`21ZH406b<O
086YP@06049>@@03086YP@1SNEh0HgUN00D0HgUN3@21ZH4>08:TO003086YP@2;[h80Rjn201H0Rjn2
00<0PJV108jcQ02>/h@0602>/h@20?mo0003086YP@2>/h80S[>200D0S[>20P3oO`0708jcPP80ogl0
2`2>/h800`21ZH40ogl00?mo000808^_O@80ogl0302;[gd20?mo0080Rjmm00@0PJV108>UM023YG@0
PjEd0P3oO`0608>UM080ogl01@23YG@30?mo00<0PjEd00<0PJV107NDIP1gU6H00`1gU6H20?mo00@0
MiAV0P3oO`000`1gU6H0PJV1086YP@03086YP@<0ogl00P21ZH420?mo0003086YP@1JK4T0FVa90080
ogl00`1JK4T40?mo0080@4/d0P3oO`000`0L81P0ogl00;3PiP270;3PiP40oooo00280;3PiP806b<O
00<0PJV1049>@@12CT400`12CT49086YP@L0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21ZH40Rjn2
08^_PP0F08^_PP03086YP@2>/h@0S[>401P0S[>40`3oO`0708jcPP030?mo002>/h80S[>200H0S[>2
0P3oO`0;08jcPP03086YP@3oO`00ogl000P0Rjmm0P3oO`0<08^_O@80ogl00P2;[gd01021ZH40PjEd
08>UM023YG@20?mo00H0PjEd0P3oO`0608>UM080ogl00`23YG@00`21ZH40MiAV07NDIP0307NDIP80
ogl0101gU6H20?mo00H0MiAV00<0PJV10?mo003oO`000P1RNU430?mo0080PJV10P3oO`03086YP@<0
ogl00`10Bc@30?mo0003086YP@2`h>H0/>3V08H0/>3V0@3oool008L0/>3V00<0PJV101/S7`21ZH40
0P12CT44086YP@03055UD`21ZH40LHi^00d0LHi^00<0PJV108:TO022Y7`04022Y7`00`21ZH40Rjn2
08^_PP0G08^_PP03086YP@2>/h@0S[>401T0S[>40P3oO`0608jcPP80ogl0202>/h830?mo00X0S[>2
0`3oO`0808^_O@<0ogl02P2;[gd30?mo0080Rjmm00@0PJV108>UM023YG@0PjEd0P3oO`0608>UM080
ogl01P23YG@20?mo00@0PjEd00<0PJV107NDIP1gU6H00P1gU6H20?mo00@0MiAV0P3oO`0607NDIP03
086YP@3oO`00ogl000<0HWYA0P3oO`02069jD@<0ogl00P1RNU400`21ZH40ogl00?mo0003086YP@05
041;=03oO`00ogl00?mo0021ZH40Q`2`h>H10?ooo`00Q`2`h>H201/S7`<0PJV11@1AIE<00`21ZH40
LHi^076>KP0;076>KP03086YP@22Y7`0PZAl0140PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40
S[>408jcQ00J08jcQ080ogl01P2>/h800`3oO`00S[>208jcPP0708jcPP@0ogl0202>/h830?mo00X0
Rjmm103oO`0808^_O@80ogl0102;[gd00`21ZH40PjEd08>UM0020?mo00H0PjEd0P3oO`0608>UM0<0
ogl00`23YG@00`21ZH40MiAV07NDIP0207NDIP80ogl0101gU6H30?mo00H0MiAV0P3oO`03069jD@80
ogl00`1RNU420?mo0080HWYA00@0PJV10?mo003oO`00ogl00P19FC`30?mo000301`P603oO`00/>3V
08H0/>3V0@3oool008H0/>3V1021ZH46055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022
Y7`04@22Y7`00`21ZH40Rjn208^_PP0F08^_PP03086YP@2>/h@0S[>401T0S[>4103oO`0508jcPP03
0?mo002>/h80S[>200L0S[>21`3oO`0308jcPP@0ogl0302;[gd40?mo00H0Rjmm0P3oO`0508^_O@03
086YP@23YG@0PjEd0080ogl01P23YG@20?mo00L0PjEd103oO`000`23YG@0PJV107NDIP0307NDIP<0
ogl0101gU6H30?mo00D0MiAV0`3oO`02069jD@80ogl00`1RNU420?mo00<0HWYA00@0PJV10?mo003o
O`00BETl0`3oO`001021ZH40ogl00?mo003oO`260;3PiP40oooo00260;3PiP03086YP@0U;R/0PJV1
00L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn2
01H0Rjn200<0PJV108jcQ02>/h@06@2>/h@40?mo00@0S[>20P3oO`0908jcPP80ogl000<0S[>20?mo
003oO`00203oO`000`21ZH40Rjmm08^_O@0<08^_O@<0ogl00P2;[gd50?mo00D0Rjmm00<0PJV108>U
M023YG@00P3oO`0608>UM080ogl02023YG@40?mo0004086YP@1gU6H0MiAV07NDIP<0ogl01@1gU6H4
0?mo00@0MiAV0P3oO`03069jD@<0ogl00P1RNU430?mo0080HWYA00@0PJV10?mo003oO`00BETl0P3o
O`000`19FC`0PJV1028W7@020?mo08H0/>3V0@3oool008H0/>3V00<0PJV102D^:`21ZH401`1AIE<0
0`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl0140PZAl00<0PJV108^_PP2;[h805P2;[h80
0`21ZH40S[>408jcQ00K08jcQ080ogl0102>/h800`3oO`00S[>208jcPP0808jcPP80ogl00`2>/h86
0?mo0080S[>200<0PJV108^_O@2;[gd03@2;[gd80?mo00H0Rjmm00<0PJV108>UM023YG@00P3oO`07
08>UM080ogl02@23YG@30?mo000307NDIP3oO`00ogl00080ogl01P1gU6H50?mo00<0MiAV0P3oO`04
069jD@80ogl00`1RNU420?mo0080HWYA00<0PJV10?mo003oO`000`3oO`0204UI?0<0ogl0QP2`h>H1
0?ooo`00Q@2`h>H01021ZH409Bh[02D^:`21ZH47055UD`03086YP@1aSVh0LHi^00/0LHi^00<0PJV1
08:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0F08^_PP03086YP@2>/h@0S[>401/0S[>40`3oO`02
08jcPP80ogl05`2>/h800`21ZH40Rjmm08^_O@0=08^_O@D0ogl02@2;[gd00`21ZH40PjEd08>UM002
0?mo00L0PjEd0P3oO`0:08>UM0H0ogl01`1gU6H20?mo000507NDIP3oO`00ogl00?mo001gU6H0103o
O`03069jD@80ogl00`1RNU420?mo0080HWYA00<0PJV104UI?03oO`000`3oO`0204UI?0<0ogl000<0
PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q@2`h>H01021ZH409Bh[02D^:`21ZH46055UD`03086YP@1a
SVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0F08^_PP03086YP@2>
/h@0S[>401X0S[>400D0PJV108jcPP3oO`00ogl008jcPP030?mo01L0S[>200<0PJV108^_O@2;[gd0
6`2;[gd00`21ZH40PjEd08>UM0030?mo00H0PjEd0P3oO`0:08>UM0@0ogl02P1gU6H20?mo000307ND
IP3oO`00ogl000@0ogl0101RNU430?mo0080HWYA0P3oO`03069jD@03086YP@3oO`00ogl000<0ogl0
00<0BETl0?mo003oO`000P3oO`250;3PiP40oooo00250;3PiP03086YP@0U;R/0PJV100L0DFEC00<0
PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201L0Rjn200<0
PJV108jcQ02>/h@06P2>/h@01@21ZH40S[>20?mo003oO`00S[>20080ogl06@2>/h800`21ZH40Rjmm
08^_O@0J08^_O@04086YP@23YG@0PjEd08>UM080ogl01P23YG@20?mo00/0PjEd00<0PJV107NDIP1g
U6H03@1gU6H40?mo000307NDIP21ZH40HWYA00@0HWYA00@0ogl0069jD@1RNU40HWYA0`3oO`02069j
D@03086YP@3oO`00ogl000P0ogl0Q@2`h>H10?ooo`00Q@2`h>H00`21ZH409Bh[086YP@07055UD`03
086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21ZH40Rjn208^_PP0G08^_PP03
086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP3oO`00103oO`0I08jcPP03086YP@2;[gd0Rjmm01X0
Rjmm00@0PJV108>UM023YG@0PjEd0P3oO`0608>UM080ogl03023YG@00`21ZH40MiAV07NDIP0A07ND
IP03086YP@1RNU40HWYA00P0HWYA00L0ogl0069jD@1RNU40HWYA086YP@19FC`0ogl00080BETl1P3o
O`250;3PiP40oooo00240;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1a
SVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>
/h@00`21ZH40S[>208jcPP030?mo01X0S[>200<0PJV108^_O@2;[gd06P2;[gd01021ZH40PjEd08>U
M023YG@20?mo00H0PjEd0P3oO`0<08>UM003086YP@1gU6H0MiAV0180MiAV00<0PJV1069jD@1RNU40
2`1RNU400`21ZH40BETl04UI?00204UI?0<0ogl000@0PJV10?mo003oO`00PJV1Q02`h>H10?ooo`00
Q02`h>H01021ZH409Bh[02D^:`21ZH46055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022
Y7`04P22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>
/h800`3oO`0J08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00@0PJV108>UM023YG@0PjEd0P3oO`0608>U
M080ogl03023YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI
?019FC`01019FC`01021ZH40ogl00?mo003oO`240;3PiP40oooo00240;3PiP03086YP@0U;R/0PJV1
00L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn2
01L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP030?mo01X0S[>200<0PJV108^_
O@2;[gd06P2;[gd01021ZH40PjEd08>UM023YG@20?mo00H0PjEd0`3oO`0;08>UM003086YP@1gU6H0
MiAV0180MiAV00<0PJV1069jD@1RNU400`1RNU400`3oO`00HWYA069jD@06069jD@03086YP@19FC`0
BETl00@0BETl00@0PJV1028W7@3oO`00ogl0Q02`h>H10?ooo`00Q02`h>H00`21ZH409Bh[086YP@07
055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0G
08^_PP03086YP@2>/h@0S[>401X0S[>400D0PJV108jcPP2>/h80S[>20?mo000K08jcPP03086YP@2;
[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@00P23YG@20?mo00D0PjEd0P3oO`0<08>UM003086YP@1g
U6H0MiAV0180MiAV00<0PJV1069jD@1RNU400P1RNU430?mo00L0HWYA00<0PJV104UI?019FC`01@19
FC`00`21ZH40ogl00?mo00240;3PiP40oooo00230;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0
PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:TO00C08:TO003086YP@2;[h80Rjn201H0Rjn200<0
PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00@0
PJV108>UM023YG@0PjEd0P3oO`0508>UM080ogl03023YG@00`21ZH40MiAV07NDIP0C07NDIP04086Y
P@1RNU40HWYA069jD@@0ogl01P1RNU400`21ZH40BETl04UI?00504UI?004086YP@3oO`00ogl00?mo
08<0/>3V0@3oool008<0/>3V00@0PJV102D^:`0U;R/0PJV11P1AIE<00`21ZH40LHi^076>KP0<076>
KP03086YP@22Y7`0PZAl01<0PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00K08jc
Q003086YP@2>/h80S[>201d0S[>200<0PJV108^_O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00F08>U
M003086YP@1gU6H0MiAV01<0MiAV00@0PJV1069jD@1RNU40HWYA103oO`07069jD@03086YP@19FC`0
BETl00@0BETl00@0PJV1028W7@3oO`00ogl0P`2`h>H10?ooo`00P`2`h>H00`21ZH409Bh[086YP@07
055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0G
08^_PP03086YP@2>/h@0S[>401/0S[>400<0PJV108jcPP2>/h807@2>/h800`21ZH40Rjmm08^_O@0K
08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40HWYA069jD@02
069jD@80ogl0201RNU400`21ZH40BETl04UI?00404UI?003086YP@0R9ad0ogl00080ogl0PP2`h>H1
0?ooo`00P`2`h>H00`21ZH409Bh[086YP@07055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV108:T
O022Y7`04P22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>401/0S[>400<0PJV108jc
PP2>/h807@2>/h800`21ZH40Rjmm08^_O@0K08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107ND
IP1gU6H04P1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@19FC`0BETl00D0BETl00<0PJV1028W
7@3oO`00P`2`h>H10?ooo`00PP2`h>H01021ZH409Bh[02D^:`21ZH47055UD`03086YP@1aSVh0LHi^
00/0LHi^00<0PJV108:TO022Y7`04`22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>4
00d0S[>4?@21ZH4?08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04`1gU6H00`21
ZH40HWYA069jD@0;069jD@03086YP@19FC`0BETl00D0BETl00@0PJV1028W7@0R9ad0PJV1PP2`h>H1
0?ooo`00PP2`h>H01021ZH409Bh[02D^:`21ZH46055UD`03086YP@1aSVh0LHi^00`0LHi^00<0PJV1
08:TO022Y7`02@22Y7`d086YP@h0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0<
09>kQc@0PJV12`1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1
028W7@0R9ad0PJV1PP2`h>H10?ooo`00PP2`h>H00`21ZH409Bh[086YP@07055UD`03086YP@1aSVh0
LHi^00D0LHi^4`21ZH4:08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h0
0`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl0
0`21ZH40PJ=b086SLP08086SLQ<0PJV11`1RNU400`21ZH40BETl04UI?00404UI?004086YP@0R9ad0
8RLM086YPH80/>3V0@3oool00880/>3V0P0U;R/00`21ZH40DFEC055UD`02055UD`/0PJV11`1mWg/0
0`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h0
0`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl0
0`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00D0K8UL2`21ZH4404UI?003086YP@0R9ad0
PJV10880/>3V0@3oool00840/>3V00<0PJV102D^:`21ZH401@21ZH4305iiHP03086YP@1mWg/0OImk
00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>
01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o
01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G004086YP@1@ID<0D6E3
051U@`H0PJV100<08RLM086YP@2`h>H0P02`h>H10?ooo`00P@2`h>H2086YP@0302dj=P21ZH40GWUR
00H0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=
01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^7
01/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL
00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<01021ZH40:3<S086YP@21ZH610;3PiP40oooo00210;3P
iP04086YP@0]>SH0;CXf086YP@L0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C
08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40U[n<09JoS00M
09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C
086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<01021ZH40:3<S02Pc8`21
ZH610;3PiP40oooo00210;3PiP04086YP@0]>SH0;CXf086YP@L0GWUR00<0PJV107fON`1mWg/0301m
Wg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F
`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2<
/gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@
ID<01021ZH40:3<S02Pc8`21ZH610;3PiP40oooo00210;3PiP04086YP@0]>SH0;CXf086YP@L0GWUR
00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=
00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^7
00<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL
00<0PJV1051U@`1@ID<01@1@ID<01021ZH40:3<S02Pc8`21ZH610;3PiP40oooo00210;3PiP03086Y
P@0]>SH0PJV100P0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086Y
P@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40U[n<09JoS00M09JoS003086Y
P@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086Y
P@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<01021ZH40:3<S02Pc8`21ZH610;3PiP40
oooo00210;3PiP03086YP@0]>SH0PJV100P0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>8
08bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40U[n<
09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b
086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01P1@ID<00`21ZH40:3<S
086YP@210;3PiP40oooo00210;3PiP03086YP@0]>SH0PJV100P0GWUR00<0PJV107fON`1mWg/0301m
Wg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F
`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2<
/gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01P1@
ID<00`21ZH40:3<S086YP@210;3PiP40oooo00210;3PiP03086YP@0]>SH0PJV100P0GWUR00<0PJV1
07fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV1
09K0SP2F`8h06`2F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV1
08bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1
051U@`1@ID<01P1@ID<00`21ZH40:3<S086YP@210;3PiP40oooo00210;3PiP03086YP@0]>SH0PJV1
00P0GWUR00<0PJV107fON`1mWg/02`1mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=
01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^7
01`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0B086SLP03086YP@1/RE`0K8UL
00`0K8UL00<0PJV1051U@`1@ID<01P1@ID<00`21ZH40:3<S086YP@210;3PiP40oooo00210;3PiP03
086YP@0]>SH0PJV100L0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003
086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09JoS003
086YP@2C^hL0Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03
086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<00`21ZH40:3<S086YP@210;3PiP40
oooo00200;3PiP04086YP@0]>SH0;CXf086YP@L0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40
S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40
U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40
PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<01021ZH40
:3<S02Pc8`21ZH600;3PiP40oooo00200;3PiP04086YP@0]>SH0;CXf086YP@L0GWUR00<0PJV107fO
N`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0
SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701`0Tk^700<0PJV108bc
O`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U
@`1@ID<01@1@ID<01021ZH40:3<S02Pc8`21ZH600;3PiP40oooo00200;3PiP04086YP@0]>SH0;CXf
086YP@L0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0
U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0
Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0
K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<01021ZH40:3<S02Pc8`21ZH600;3PiP40oooo0020
0;3PiP04086YP@0]>SH0;CXf086YP@L0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bc
R00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09Jo
S00M09JoS003086YP@2C^hL0Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086S
LP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@ID<01021ZH40:3<S02Pc
8`21ZH600;3PiP40oooo00200;3PiP03086YP@0]>SH0PJV100P0GWUR00<0PJV107fON`1mWg/0301m
Wg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F
`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701`0Tk^700<0PJV108bcO`2</gl05`2<
/gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01@1@
ID<01021ZH40:3<S02Pc8`21ZH600;3PiP40oooo00200;3PiP03086YP@0]>SH0PJV100P0GWUR00<0
PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0
PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701`0Tk^700<0
PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0
PJV1051U@`1@ID<01P1@ID<00`21ZH40:3<S086YP@200;3PiP40oooo00200;3PiP03086YP@0]>SH0
PJV100P0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bcR003086YP@2D_Hd0
U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0
Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086SLP03086YP@1/RE`0
K8UL00`0K8UL00<0PJV1051U@`1@ID<01P1@ID<00`21ZH40:3<S086YP@200;3PiP40oooo00200;3P
iP03086YP@0]>SH0PJV100P0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40S;>808bcR00C08bc
R003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40U[n<09JoS00M09Jo
S003086YP@2C^hL0Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40PJ=b086SLP0C086S
LP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01P1@ID<00`21ZH40:3<S086YP@200;3P
iP40oooo00200;3PiP03086YP@0]>SH0PJV100P0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40
S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h0702F`8h00`21ZH40
U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701`0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40
PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00<0PJV1051U@`1@ID<01P1@ID<00`21ZH40
:3<S086YP@200;3PiP40oooo00200;3Pi_<0PJV1P02`h>H10?ooo`00P02`h>H00`21ZH40>4Y3086Y
P@0806R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8
UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6
S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BF
I`0<07BFI`03086YP@1DKDL0E6e700H0E6e700<0PJV102dk:021ZH40P02`h>H10?ooo`00P02`h>H0
0`21ZH40>4Y3086YP@0806R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i40
0`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2LbY<0
0`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/0
0`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700H0E6e700<0PJV102dk:021ZH40P02`h>H1
0?ooo`00P02`h>H00`21ZH40>4Y3086YP@0806R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109Bo
T@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:
T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`
N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700H0E6e700<0PJV102dk
:021ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40>4Y3086YP@0806R8KP03086YP@25[HH0QJf600`0
QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0
WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0
Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700H0
E6e700<0PJV102dk:021ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40>4Y3086YP@0806R8KP03086Y
P@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0L09[6S`03086Y
P@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086Y
P@1DKDL0E6e700D0E6e700@0PJV102dk:00]>bP0PJV1P02`h>H10?ooo`00P02`h>H01021ZH40>4Y3
03Q:@`21ZH4706R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40
VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40
V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40
M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk:00]>bP0PJV1P02`h>H10?oo
o`00P02`h>H01021ZH40>4Y303Q:@`21ZH4706R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109Bo
T@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:
T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`
N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk
:00]>bP0PJV1P02`h>H10?ooo`00P02`h>H01021ZH40>4Y303Q:@`21ZH4706R8KP03086YP@25[HH0
QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0
WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0
Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0
E6e700D0E6e700@0PJV102dk:00]>bP0PJV1P02`h>H10?ooo`00P02`h>H01021ZH40>4Y303Q:@`21
ZH4706R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8
UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6
S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BF
I`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk:00]>bP0PJV1P02`h>H10?ooo`00P@2`
h>H00`21ZH40>4Y3086YP@0706R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D
_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c:T`2LbY<07@2L
bY<00`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28
/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e700<0PJV102dk:021ZH40P@2`
h>H10?ooo`00P@2`h>H00`21ZH40>4Y3086YP@0806R8KP03086YP@25[HH0QJf600/0QJf600<0PJV1
09BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV1
09c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0L09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV1
08R`N`28/7/04P28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700H0E6e700<0PJV1
02dk:021ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40>4Y3086YP@0806R8KP03086YP@25[HH0QJf6
00`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F
01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj7
01L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e7
00H0E6e700<0PJV102dk:021ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40>4Y3086YP@0806R8KP03
086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03
086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03
086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03
086YP@1DKDL0E6e700H0E6e700<0PJV102dk:021ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40>4Y3
086YP@0806R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF
09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?
09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW
07BFI`0<07BFI`03086YP@1DKDL0E6e700H0E6e700<0PJV102dk:021ZH40P@2`h>H10?ooo`00P@2`
h>H00`21ZH40>4Y3086YP@0806R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D
_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2L
bY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28
/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk:00]>bP0PJV1
P@2`h>H10?ooo`00P@2`h>H01021ZH40>4Y303Q:@`21ZH4706R8KP03086YP@25[HH0QJf600`0QJf6
00<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F
00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj7
00<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e7
00@0PJV102dk:00]>bP0PJV1P@2`h>H10?ooo`00P@2`h>H01021ZH40>4Y303Q:@`21ZH4706R8KP03
086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03
086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03
086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03
086YP@1DKDL0E6e700D0E6e700@0PJV102dk:00]>bP0PJV1P@2`h>H10?ooo`00P@2`h>H01021ZH40
>4Y303Q:@`21ZH4706R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21
ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21
ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21
ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk:00]>bP0PJV1P@2`h>H1
0?ooo`00P@2`h>H2086YP@0303Q:@`21ZH40J8Q^00H0J8Q^00<0PJV108F]QP25[HH03025[HH00`21
ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21
ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21
ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021
ZH40;C/X086YP@21ZH610;3PiP40oooo00210;3PiP03086YP@0oEdd0PJV100@0PJV1101XR6h00`21
ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21
ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21
ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21
ZH40E6e705A]A`0205A]A`D0PJV100<0<48[086YP@2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40
?eM=086YP@0306nCM``0PJV11`25[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0
VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0
V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00D0
M9IW3021ZH4305UfCP03086YP@0`@R/0<48[0880/>3V0@3oool00880/>3V00<0PJV103mGC@21ZH40
1`1_TgL00`21ZH40S;N?08bgS`0508bgSa80PJV12`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086Y
P@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086Y
P@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/02@28/7/B086YP@L0Nj5_00<0PJV105UfCP1IMTh0
101IMTh01021ZH40<48[0312:`21ZH620;3PiP40oooo00220;3PiP04086YP@0oEdd0?eM=086YP@H0
Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0809[9VC@0PJV13`2MbiH00`21ZH40
W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?00d0V/J?=021ZH4:08jiP`03086YP@1kXFl0Nj5_00`0
Nj5_00<0PJV105UfCP1IMTh0101IMTh01021ZH40<48[0312:`21ZH620;3PiP40oooo00220;3PiP04
086YP@0oEdd0?eM=086YP@L0Ki=g00<0PJV108bgS`2<]hl02`2<]hl00`21ZH40V/VI09[9V@0C09[9
V@03086YP@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid0302Rdido086YP@h0WljF00<0PJV109W7
S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0C08jiP`03086YP@1kXFl0Nj5_00/0Nj5_00<0PJV105Uf
CP1IMTh01@1IMTh01021ZH40<48[0312:`21ZH620;3PiP40oooo00230;3PiP03086YP@0oEdd0PJV1
00L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0B09[9V@03086YP@2PdId0X=6M
01L0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0M0:;BVP03086YP@2OcYH0WljF
01/0WljF00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0B08jiP`03086YP@1kXFl0Nj5_
00`0Nj5_00<0PJV105UfCP1IMTh01@1IMTh00`21ZH40<48[086YP@230;3PiP40oooo00230;3PiP03
086YP@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0B09[9V@03
086YP@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0M0:;BVP03
086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0B08jiP`03
086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh01021ZH40<48[0312:`21ZH630;3P
iP40oooo00230;3PiP04086YP@0oEdd0?eM=086YP@H0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21
ZH40V/VI09[9V@0C09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21
ZH40X]:J0:;BVP0M0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21
ZH40S[V308jiP`0C08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh01021
ZH40<48[0312:`21ZH630;3PiP40oooo00230;3PiP04086YP@0oEdd0?eM=086YP@L0Ki=g00<0PJV1
08bgS`2<]hl02`2<]hl00`21ZH40V/VI09[9V@0C09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV1
0:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0M0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV1
09W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0C08jiP`03086YP@1kXFl0Nj5_00/0Nj5_00<0PJV1
05UfCP1IMTh01@1IMTh01021ZH40<48[0312:`21ZH630;3PiP40oooo00240;3PiP03086YP@0oEdd0
PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0B09[9V@03086YP@2PdId0
X=6M01L0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0M0:;BVP03086YP@2OcYH0
WljF01X0WljF00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0B08jiP`03086YP@1kXFl0
Nj5_00`0Nj5_00<0PJV105UfCP1IMTh01@1IMTh00`21ZH40<48[086YP@240;3PiP40oooo00240;3P
iP03086YP@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0B09[9
V@03086YP@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0M0:;B
VP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0B08ji
P`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh01021ZH40<48[0312:`21ZH64
0;3PiP40oooo00240;3PiP04086YP@0oEdd0?eM=086YP@H0Ki=g00<0PJV108bgS`2<]hl0302<]hl0
0`21ZH40V/VI09[9V@0B09[9V@03086YP@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]:J0:;BVP0M0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05`2Iahl0
0`21ZH40S[V308jiP`0B08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh0
1021ZH40<48[0312:`21ZH640;3PiP40oooo00240;3PiP04086YP@0oEdd0?eM=086YP@L0Ki=g00<0
PJV108bgS`2<]hl02`2<]hl00`21ZH40V/VI09[9V@0B09[9V@03086YP@2PdId0X=6M01L0X=6M00<0
PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0M0:;BVP03086YP@2OcYH0WljF01X0WljF00<0
PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0B08jiP`03086YP@1kXFl0Nj5_00/0Nj5_00<0
PJV105UfCP1IMTh01@1IMTh01021ZH40<48[0312:`21ZH640;3PiP40oooo00250;3PiP03086YP@0o
Edd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A09[9V@03086YP@2P
dId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0M0:;BVP03086YP@2O
cYH0WljF01X0WljF00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0A08jiP`03086YP@1k
XFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh01@1IMTh00`21ZH40<48[086YP@250;3PiP40oooo0025
0;3PiP03086YP@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A
09[9V@03086YP@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0M
0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0B
08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh01021ZH40<48[0312:`21
ZH650;3PiP40oooo00250;3PiP04086YP@0oEdd0?eM=086YP@H0Ki=g00<0PJV108bgS`2<]hl0302<
]hl00`21ZH40V/VI09[9V@0B09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06P2R
did00`21ZH40X]:J0:;BVP0L0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2I
ahl00`21ZH40S[V308jiP`0B08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101I
MTh01021ZH40<48[0312:`21ZH650;3PiP40oooo00250;3PiP04086YP@0oEdd0?eM=086YP@L0Ki=g
00<0PJV108bgS`2<]hl02`2<]hl00`21ZH40V/VI09[9V@0B09[9V@03086YP@2PdId0X=6M01H0X=6M
00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01/0WljF
00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0B08jiP`03086YP@1kXFl0Nj5_00/0Nj5_
00<0PJV105UfCP1IMTh01@1IMTh01021ZH40<48[0312:`21ZH650;3PiP40oooo00260;3PiP03086Y
P@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A09[9V@03086Y
P@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086Y
P@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0A08jiP`03086Y
P@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh01@1IMTh00`21ZH40<48[086YP@260;3PiP40oooo
00260;3PiP03086YP@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9
V@0A09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;B
VP0K0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308ji
P`0A08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh01021ZH40<48[0312
:`21ZH660;3PiP40oooo00260;3PiP@0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2J
bIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2R
dYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>
^H<0S[V30140S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP@0PJV1QP2`
h>H10?ooo`00Q`2`h>H01021ZH40AF5D086YP@21ZH4606nCM`03086YP@2<]hl0S;N?00/0S;N?00<0
PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0
PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0
PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00@0FGI>0P21
ZH400`0`AB`0PJV10;3PiP260;3PiP40oooo00270;3PiP04086YP@15HE@0PJV107:KO@@0PJV10P1_
TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0100V/VI00<0PJV10:3AW@2PdId05`2P
dId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06P2O
cYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30100S[V300<0PJV107^QK`1kXFl0301k
XFl00`21ZH40FGI>05UfCP04086YP@0405ioEP21ZH40<4D/086YPHL0/>3V0@3oool008P0/>3V00<0
PJV104EQE021ZH40101bVgd:086YP@L0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3A
W@0F0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>
UP0J09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^Q
K`0507^QK`X0PJV1101NOeH00`21ZH40<4D/086YP@280;3PiP40oooo00280;3PiP03086YP@15HE@0
PJV100H0LY]m00<0PJV108nnU02?_Y@01@2?_Y@<086YP@l0V/VI00<0PJV10:3AW@2PdId05P2PdId0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06P2OcYH0
0`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V300d0S[V33021ZH4707nXMP03086YP@1NOeH0
GWmF00@0GWmF00<0PJV10315;021ZH40R02`h>H10?ooo`00R@2`h>H00`21ZH40AF5D086YP@0607:K
O@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l00P2Md9l:086YP@D0V/VI00<0PJV10:3A
W@2PdId05P2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>
UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V300<0S[V32P21ZH4409;0
R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@290;3P
iP40oooo00290;3PiP03086YP@15HE@0PJV100H0LY]m00<0PJV108nnU02?_Y@0302?_Y@00`21ZH40
WM2O09g@W`0;09g@Wa80PJV1302PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01/0
X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0:09W7Sa80PJV13@2B`8T00`21ZH40
OjQf07nXMP0<07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40R@2`h>H10?ooo`00
RP2`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@0302?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086Y
P@2Tf:80Y=RR00X0Y=RRL@21ZH4<09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H0
301oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1RP2`h>H10?ooo`00RP2`h>H00`21ZH40AF5D086Y
P@0607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CH
XP0F0:CHXP03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21ZH40XmFL0:?E
W00J0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T04@2B`8T00`21ZH40OjQf07nX
MP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40RP2`h>H10?ooo`00RP2`h>H0
0`21ZH40AF5D086YP@0607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l04@2Md9l0
0`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ00
0`21ZH40XmFL0:?EW00J0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B`8T0
0`21ZH40OjQf07nXMP0<07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40RP2`h>H1
0?ooo`00R`2`h>H2086YP@L0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@
W`03086YP@2Tf:80Y=RR01H0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMVP0:GIX00K0:GI
X003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05P2McYD00`21ZH40T/2909;0R@0@09;0
R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40<4D/086YP@2;0;3P
iP40oooo002;0;3PiP03086YP@15HE@0PJV100H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40
WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR01H0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40
YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05P2McYD00`21ZH40
T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH00`21ZH40
<4D/086YP@2;0;3PiP40oooo002<0;3PiP80PJV11P1bVgd00`21ZH40SkjD08nnU00;08nnU003086Y
P@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR0:KJXP0I0:KJXP03086Y
P@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02SeI`06@2SeI`00`21ZH40WLjE09g>U@0E09g>U@03086Y
P@2B`8T0T/290140T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1
S02`h>H10?ooo`00S02`h>H00`21ZH40AF5D086YP@0607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0
PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0
PJV10:GIX02UfJ006`2UfJ000`21ZH40XmFL0:?EW00I0:?EW003086YP@2McYD0WLjE01D0WLjE00<0
PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0
PJV10315;021ZH40S02`h>H10?ooo`00S@2`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@0
0`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ80
0`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05@2McYD0
0`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH2
086YPHd0/>3V0@3oool008d0/>3V0P21ZH4607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@
W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0F0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GI
X02UfJ006`2UfJ000`21ZH40XmFL0:?EW00H0:?EW003086YP@2McYD0WLjE01H0WLjE00<0PJV109;0
R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF0P21ZH6=0;3P
iP40oooo002>0;3PiP80PJV11P1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O00l0
WM2O00<0PJV10:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP01/0
YMVP00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/290100
T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1SP2`h>H10?ooo`00
SP2`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086Y
P@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMVP0:GIX00K0:GIX003086Y
P@2SeI`0XmFL01P0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0@09;0R@03086Y
P@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH2086YPHh0/>3V0@3oool008l0/>3V0P21
ZH4607:KO@03086YP@2?_Y@0SkjD00X0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CH
XP0E0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?E
W00I0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nX
MP0:07nXMP03086YP@1NOeH0GWmF00@0GWmF0P21ZH6?0;3PiP40oooo002?0;3PiP<0PJV11@1bVgd0
0`21ZH40SkjD08nnU00:08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805@2Tf:80
0`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`06@2SeI`0
0`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/2900l0T/2900<0PJV107nXMP1oZ7H02`1oZ7H0
0`21ZH40GWmF05ioEP0305ioEP<0PJV1S`2`h>H10?ooo`00T02`h>H4086YP@<0LY]m00<0PJV108nn
U02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0?09g@W`03086YP@2Tf:80Y=RR01H0Y=RR00<0PJV10:KJ
XP2VfZ80602VfZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01P0XmFL00<0PJV109g>
U@2McYD05@2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00/0OjQf00@0PJV105io
EP1NOeH0GWmF0P21ZH400`1OPeX0PJV10;3PiP2?0;3PiP40oooo002@0;3PiP80PJV10P1bWGl3086Y
P@0307:KO@21ZH40SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0E0:CH
XP03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?E
W003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0:07nX
MP03086YP@1NOeH0PJV10080PJV10P1OPeX00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002A0;3PiP80
PJV1101bWGl5086YP@T0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03
086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?EW003
086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0707nXMPD0
PJV1101OPeX2086YPI40/>3V0@3oool00980/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00L0PJV1
0`2?_Y@00`21ZH40WM2O09g@W`0?09g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80
602VfZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01P0XmFL00<0PJV109g>U@2McYD0
5@2McYD00`21ZH40T/2909;0R@0?09;0R@04086YP@1oZ7H0OjQf07nXMPL0PJV10P1o[7X00`21ZH40
Gh=J05n3FP0305n3FP80PJV1TP2`h>H10?ooo`00TP2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL0
1`2?`IL8086YP@d0WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086Y
P@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0D09g>U@03086Y
P@2B`8T0T/2900`0T/292021ZH4907n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6B0;3PiP40oooo
002C0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0:08o1U`04086YP@2Ndj80W]>R09kCXPX0PJV1
102Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01L0Y]ZR00<0PJV10:GIX02UfJ00
6@2UfJ000`21ZH40XmFL0:?EW00G0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0
0P2B`8T:086YP@<0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV1
T`2`h>H10?ooo`00U02`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40W]>R09kC
XP0;09kCXQ00PJV1302Tf:800`21ZH40Y]ZR0:KJXP0G0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0
PJV10:?EW02SeI`05`2SeI`00`21ZH40WLjE09g>U@0:09g>UA00PJV13@2Ca8d00`21ZH40Ojaj07n/
NP0:07n/NP03086YP@1OPeX0Gh=J0080Gh=J0P21ZH6D0;3PiP40oooo002D0;3PiP80PJV11@1bWGl0
0`21ZH40Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H02@2Ug:HI
086YP@d0Y]ZR00<0PJV10:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00;0:?EW1T0PJV12`2NdYT0
0`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2
086YPI@0/>3V0@3oool009D0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kC
XP2Ndj803`2Ndj800`21ZH40YMbV0:GLYP0D0:GLYP03086YP@2XgjH0Z=nV00X0Z=nV=`21ZH4<0:GJ
X003086YP@2NdYT0W]:I01@0W]:I00<0PJV109?4S@2Ca8d03`2Ca8d00`21ZH40Ojaj07n/NP0907n/
NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6E0;3PiP40oooo002E0;3PiP80PJV11@1bWGl00`21ZH40
Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40
Z=nV0:SOYP0G0:SOYP03086YP@2WgZ@0YmjT01T0YmjT00<0PJV10:GJX02UfZ005`2UfZ000`21ZH40
W]:I09kBV@0D09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40
Gh=J05n3FP0305n3FP03086YP@2`h>H0/>3V09@0/>3V0@3oool009H0/>3V0P21ZH4507:MO`03086Y
P@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803`2Ndj800`21ZH40YMbV0:GLYP0D0:GLYP03086Y
P@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@06@2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086Y
P@2NdYT0W]:I01@0W]:I00<0PJV109?4S@2Ca8d03`2Ca8d00`21ZH40Ojaj07n/NP0907n/NP03086Y
P@1OPeX0Gh=J00<0Gh=J0P21ZH6F0;3PiP40oooo002G0;3PiP80PJV1101bWGl00`21ZH40Sl6G08o1
U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SO
YP0F0:SOYP03086YP@2WgZ@0YmjT01T0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kB
V@0D09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3
FP0205n3FP80PJV1U`2`h>H10?ooo`00U`2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL02@2?`IL0
0`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH0
0`21ZH40YmjT0:ONY00I0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT0502NdYT0
0`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00T0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2
086YPIL0/>3V0@3oool009P0/>3V0P21ZH4407:MO`03086YP@2?`IL0Sl6G00X0Sl6G00<0PJV109kC
XP2Ndj803P2Ndj800`21ZH40YMbV0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:ON
Y02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00G0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4
S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0:07n/NP03086YP@1OPeX0Gh=J0080Gh=J0P21ZH6H0;3P
iP40oooo002I0;3PiP80PJV1101bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00h0
W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0
YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0D09kBV@03086YP@2Ca8d0TlB=00h0
TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0205n3FP80PJV1V@2`h>H10?ooo`00
VP2`h>H00`21ZH40LYeo07:MO`0307:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj80
3@2Ndj800`21ZH40YMbV0:GLYP0D0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@0
5`2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d0
3P2Ca8d00`21ZH40Ojaj07n/NP0907n/NP03086YP@1OPeX0Gh=J00<0Gh=J00<0PJV10;3PiP2`h>H0
V02`h>H10?ooo`00V`2`h>H2086YP@<0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kC
XP0>09kCXP03086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ON
Y00G0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4
S@0>09?4S@03086YP@1o[7X0Ojaj00T0Ojaj00@0PJV105n3FP1OPeX0Gh=J0P21ZH6K0;3PiP40oooo
002L0;3PiP<0PJV10P1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00d0W]>R00<0
PJV10:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0
PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00d0TlB=00<0
PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP03086YPI`0/>3V0@3oool009d0/>3V00<0PJV1
06jJO@21ZH400P21ZH4;08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H0
0`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005P2UfZ00
0`21ZH40W]:I09kBV@0B09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/NP1o[7X02@1o[7X3
086YP@0305b3F`21ZH40/>3V09`0/>3V0@3oool009h0/>3V00<0PJV106jJO@1^VWd01@21ZH4808o1
U`03086YP@2Ndj80W]>R00d0W]>R00<0PJV10:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0E0:SO
YP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I09kBV@0C09kB
V@03086YP@2Ca8d0TlB=00d0TlB=00<0PJV107n/NP1o[7X01P1o[7X5086YP@80G8=K00<0PJV10;3P
iP2`h>H0W02`h>H10?ooo`00WP2`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00H0
PJV10P2?`IL00`21ZH40W]>R09kCXP0=09kCXP03086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2X
gjH05@2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2N
dYT04`2NdYT00`21ZH40TlB=09?4S@0=09?4S@03086YP@1o[7X0Ojaj00H0PJV10P1lZgX00`21ZH40
G8=K05b3F`0205b3F`03086YP@2`h>H0/>3V09`0/>3V0@3oool009l0/>3V00<0PJV106jJO@1^VWd0
0P1^VWd00`21ZH40RkjE08^nU@0508^nU@H0PJV13@2Ndj800`21ZH40YMbV0:GLYP0B0:GLYP03086Y
P@2XgjH0Z=nV01D0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086Y
P@2NdYT0W]:I0180W]:I00<0PJV109?4S@2Ca8d02`2Ca8d6086YP@L0O:]j00<0PJV105b3F`1LPe/0
0P1LPe/00`21ZH40/>3V0;3PiP2M0;3PiP40oooo002P0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0
PJV108^nU@2;_YD0202;_YD00`21ZH40Vm:R086YP@05086YP@L0W]>R00<0PJV10:GLYP2Ug:H04P2U
g:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01D0YmjT00<0PJV10:GJX02UfZ005P2U
fZ000`21ZH40W]:I09kBV@0B09kBV@03086YP@2Ca8d0TlB=00D0TlB=1P21ZH400`2Aa8h0PJV107b[
NP0907b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00X@2`h>H0
1@21ZH40KYYm06jJO@1^VWd0PJV100X0RkjE00<0PJV109_BXP2KdZ801@2KdZ86086YP@80W]>R00<0
PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgZ@0YmjT01D0YmjT00<0
PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I09kBV@0B09kBV@03086YP@2Ca8d0TlB=00H0PJV11`2A
a8h00`21ZH40O:]j07b[NP0807b[NP05086YP@1LPe/0G8=K05b3F`21ZH40X@2`h>H10?ooo`00XP2`
h>H01@21ZH40KYYm06jJO@1^VWd0PJV100X0RkjE00<0PJV109_BXP2KdZ802P2KdZ8=086YP@X0YMbV
00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2UfZ00YMZP01D0YMZP
00<0PJV109kBV@2NdYT0202NdYT=086YP@`0TLB>00<0PJV107b[NP1lZgX0201lZgX01@21ZH40G8=K
05b3F`1LPe/0PJV10:80/>3V0@3oool00:<0/>3V00D0PJV106jJO@1^VWd0KYYm086YP@0:08^nU@03
086YP@2KdZ80Vm:R00`0Vm:R00<0PJV10:CLY`2Tg:L01`2Tg:LF086YP@`0Z=nV00<0PJV10:ONY02W
gZ@05@2WgZ@00`21ZH40YMZP0:GJX00:0:GJX1H0PJV12@2MdiX00`21ZH40TLB>0974SP0<0974SP03
086YP@1lZgX0O:]j00P0O:]j00D0PJV105b3F`1LPe/0G8=K086YP@2S0;3PiP40oooo002T0;3PiP05
086YP@1^VWd0KYYm06jJO@21ZH402P2;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW
0140Y=bW00<0PJV10:OPZ02Wh:P02@2Wh:Pa086YP@/0Y=^R00<0PJV109gCVP2MdiX04@2MdiX00`21
ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00P0O:]j00D0PJV105b3F`1LPe/0G8=K086YP@2T
0;3PiP40oooo002T0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;_YD01`2;_YD00`21
ZH40Vm:R09_BXP0<09_BXP03086YP@2Tg:L0Y=bW0140Y=bW00<0PJV10:OPZ02Wh:P0502Wh:P00`21
ZH40YmnV0:OOYP0E0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX04@2MdiX00`21
ZH40TLB>0974SP0<0974SP03086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21
ZH40/>3V0;3PiP2R0;3PiP40oooo002U0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;
_YD01`2;_YD00`21ZH40Vm:R09_BXP0<09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02W
h:P0502Wh:P00`21ZH40YmnV0:OOYP0E0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2M
diX0402MdiX00`21ZH40TLB>0974SP0<0974SP03086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`1L
Pe/00P1LPe/00`21ZH40/>3V0;3PiP2S0;3PiP40oooo002V0;3PiP03086YP@1^VWd0KYYm0080KYYm
00<0PJV108^nU@2;_YD01`2;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0140Y=bW
00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40YmnV0:OOYP0E0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R
00<0PJV109gCVP2MdiX04@2MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00L0O:]j
00<0PJV105b3F`1LPe/00P1LPe/00`21ZH40/>3V0;3PiP2T0;3PiP40oooo002W0;3PiP80PJV10P1^
VWd00`21ZH40RkjE08^nU@0808^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L0402T
g:L00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj80502T
fj800`21ZH40WM>J09gCVP0@09gCVP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[NP1lZgX0201l
ZgX00`21ZH40G8=K05b3F`02086YPJL0/>3V0@3oool00:P0/>3V0`21ZH400`1^VWd0PJV108^nU@08
08^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00D
0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj80502Tfj800`21ZH40WM>J09gCVP0?
09gCVP03086YP@2Aa8h0TLB>00`0TLB>00<0PJV107b[NP1lZgX01`1lZgX00`21ZH40G8=K086YP@02
086YPJP0/>3V0@3oool00:T0/>3V1@21ZH4908^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CL
Y`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CK
XP2Tfj804`2Tfj800`21ZH40WM>J09gCVP0@09gCVP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[
NP1lZgX01`1lZgX3086YP@0305IlF@21ZH40/>3V0:P0/>3V0@3oool00:/0/>3V00<0PJV106FAMP21
ZH400P21ZH4808^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L03`2Tg:L00`21ZH40
Yn2X0:OPZ00C0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj804`2Tfj800`21ZH40
WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[NP1lZgX01P1lZgX3086YP@03
05IlF@21ZH40/>3V0:X0/>3V0@3oool00:`0/>3V00<0PJV106FAMP1UTGH01@21ZH4508^nU@03086Y
P@2KdZ80Vm:R00X0Vm:R00<0PJV10:CLY`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086Y
P@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj804P2Tfj800`21ZH40WM>J09gCVP0@09gCVP03086Y
P@2Aa8h0TLB>00X0TLB>00<0PJV107b[NP1lZgX00`1lZgX5086YP@80EWaI00<0PJV10;3PiP2`h>H0
ZP2`h>H10?ooo`00[@2`h>H01021ZH40II5f06FAMP21ZH43086dSP@0PJV100<0RkjE086YP@2KdZ80
302KdZ800`21ZH40Y=bW0:CLY`0?0:CLY`03086YP@2Wh:P0Yn2X0180Yn2X00<0PJV10:OOYP2WgjH0
4`2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086YP@2MdiX0WM>J00l0WM>J00<0PJV10974SP2Aa8h0
2`2Aa8h00`21ZH40O:]j086YP@03086YP@<0M:=f00@0PJV105IlF@1FO5T0PJV1[@2`h>H10?ooo`00
[P2`h>H2086YP@0306FAMP21ZH40PJV100D0PKB>1P21ZH4:09_BXP03086YP@2Tg:L0Y=bW00h0Y=bW
00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R0180Y=^R
00<0PJV109gCVP2MdiX03P2MdiX00`21ZH40TLB>0974SP080974SPH0PJV11@1dXgH2086YP@0305Il
F@21ZH40PJV10:h0/>3V0@3oool00;00/>3V00@0PJV106FAMP1UTGH0PJV11`21]8h00`21ZH40T/ZL
09;:W008086YP@80Vm:R00<0PJV10:CLY`2Tg:L03`2Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086Y
P@2WgjH0YmnV0140YmnV00<0PJV10:CKXP2Tfj804P2Tfj800`21ZH40WM>J09gCVP0?09gCVP03086Y
P@2Aa8h0TLB>00P0PJV10P29_HX00`21ZH40M:=f07BSMP0507BSMP04086YP@1FO5T0EWaI086YPK00
/>3V0@3oool00;40/>3V00@0PJV106FAMP1UTGH0PJV11`21]8h00`21ZH40T/ZL09;:W00709;:W0P0
PJV1302Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2WgjH0YmnV0140YmnV00<0PJV10:CKXP2T
fj804P2Tfj800`21ZH40WM>J09gCVP0:09gCVPP0PJV12@29_HX00`21ZH40M:=f07BSMP0507BSMP04
086YP@1FO5T0EWaI086YPK40/>3V0@3oool00;80/>3V00@0PJV106FAMP1UTGH0PJV11`21]8h00`21
ZH40T/ZL09;:W00:09;:W004086YP@2LeZ<0W=JS09cFX`T0PJV1102Tg:L00`21ZH40Yn2X0:OPZ00A
0:OPZ003086YP@2WgjH0YmnV0140YmnV00<0PJV10:CKXP2Tfj804@2Tfj800`21ZH40WM>J09gCVP02
09gCVPT0PJV10`2FcIL00`21ZH40RKf:08VmRP0:08VmRP03086YP@1dXgH0M:=f00D0M:=f00@0PJV1
05IlF@1FO5T0PJV1/P2`h>H10?ooo`00/`2`h>H2086YP@0306FAMP21ZH40PKB>00H0PKB>00<0PJV1
09;:W02BbY`02P2BbY`00`21ZH40W=JS09cFX`0909cFXdD0PJV12`2FcIL00`21ZH40RKf:08VmRP0:
08VmRP03086YP@1dXgH0M:=f00D0M:=f00@0PJV105IlF@21ZH40PJV1/`2`h>H10?ooo`00]@2`h>H0
0`21ZH40II5f086YP@07086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<03@2LeZ<0
0`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109kGW`2Neil0402Neil0
0`21ZH40U/fG09K=U`0>09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BSMP1dXgH01@1dXgH0
0`21ZH40EWaI086YP@2e0;3PiP40oooo002f0;3PiP04086YP@1UTGH0PJV1086YP@H0PKB>00<0PJV1
09;:W02BbY`02@2BbY`00`21ZH40W=JS09cFX`0=09cFX`03086YP@2QfjD0XM^U0100XM^U00<0PJV1
0:7KY02Qfj@04@2Qfj@00`21ZH40W]NO09kGW`0@09kGW`03086YP@2FcIL0U/fG00d0U/fG00<0PJV1
08VmRP29_HX02@29_HX00`21ZH40M:=f07BSMP0407BSMP80PJV100<0EWaI086YP@2`h>H0]@2`h>H1
0?ooo`00]`2`h>H2086YP@0306FAMP21ZH40PKB>00D0PKB>00<0PJV109;:W02BbY`02@2BbY`00`21
ZH40W=JS09cFX`0<09cFX`03086YP@2QfjD0XM^U0140XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21
ZH40W]NO09kGW`0@09kGW`03086YP@2FcIL0U/fG00d0U/fG00<0PJV108VmRP29_HX02@29_HX00`21
ZH40M:=f07BSMP0407BSMP04086YP@1FO5T0PJV1086YPKL0/>3V0@3oool00;T0/>3V0`21ZH46086d
SP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<0302LeZ<00`21ZH40XM^U0:7KY@0@0:7K
Y@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil0402Neil00`21ZH40U/fG09K=U`0<09K=
U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BSMP1dXgH0101dXgH3086YPKT0/>3V0@3oool00;/0
/>3V1021ZH44086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<02`2LeZ<00`21ZH40
XM^U0:7KY@0@0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil03`2Neil00`21ZH40
U/fG09K=U`0<09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BSMP1dXgH00P1dXgH4086YPK/0
/>3V0@3oool00;d0/>3V1P21ZH400`21]8h0PJV109;:W00:09;:W003086YP@2LeZ<0W=JS00/0W=JS
00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO00l0W]NO
00<0PJV109K=U`2FcIL02`2FcIL00`21ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0PJV100D0PJV1
_@2`h>H10?ooo`00_P2`h>H3086YP@80L:1o1P21ZH4709;:W003086YP@2LeZ<0W=JS00/0W=JS00<0
PJV10:7KY@2QfjD03`2QfjD00`21ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO00h0W]NO00<0
PJV109K=U`2FcIL0302FcIL00`21ZH40RKf:08VmRP0508VmRPH0PJV10P1UTV`3086YPKh0/>3V0@3o
ool00<00/>3V0`21ZH43072PO`80PJV100<0P[N>086YP@21ZH401021ZH4209;:W003086YP@2LeZ<0
W=JS00/0W=JS00<0PJV10:7KY@2QfjD03P2QfjD00`21ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0
W]NO00h0W]NO00<0PJV109K=U`2FcIL02`2FcIL00`21ZH40RKf:08VmRP06086YP@0307V/O`21ZH40
PJV100<0II9/0`21ZH700;3PiP40oooo00320;3PiP<0PJV10`1`X7l2086YP@D0P[N>2P21ZH4609cF
X`03086YP@2QfjD0XM^U00l0XM^U00<0PJV10:7KY02Qfj@03@2Qfj@00`21ZH40W]NO09kGW`0>09kG
W`03086YP@2FcIL0U/fG00D0U/fG2P21ZH4507V/O`80PJV10`1UTV`3086YPL80/>3V0@3oool00<@0
/>3V0`21ZH43072PO`03086YP@22]hh0P[N>00H0P[N>0P21ZH4408g4Ua00PJV1202QfjD00`21ZH40
XM^T0:7KY00=0:7KY003086YP@2Neil0W]NO00H0W]NO4021ZH4408NmS@80PJV1201i[7l01021ZH40
II9/06FBK01UTV`3086YPL@0/>3V0@3oool00<H0/>3V0`21ZH42072PO`80PJV12022]hh00`21ZH40
SLBG08g4U`0908g4U`03086YP@2BbiX0T/^J00D0T/^J8@21ZH4708o7U@03086YP@27_Hd0Qkf=00T0
Qkf=00<0PJV107V/O`1i[7l01P1i[7l2086YP@80II9/0`21ZH760;3PiP40oooo00380;3PiP<0PJV1
0P1`X7l00`21ZH40P[N>08:gSP0608:gSP03086YP@2=a9L0SLBG00T0SLBG00<0PJV109;;VP2BbiX0
302BbiX00`21ZH40TlbJ09?<VP0=09?<VP03086YP@2?aiD0SlNE00`0SlNE00<0PJV108NmS@27_Hd0
2@27_Hd00`21ZH40NJao07V/O`0607V/O`03086YP@1UTV`0II9/00<0PJV1b02`h>H10?ooo`00bP2`
h>H3086YP@03072PO`21ZH40PJV100L0P[N>0P21ZH4:08g4U`03086YP@2BbiX0T/^J00`0T/^J00<0
PJV109?<VP2Cc9X02`2Cc9X00`21ZH40SlNE08o7U@0<08o7U@03086YP@27_Hd0Qkf=00P0Qkf=0P21
ZH4707V/O`80PJV100@0II9/086YP@21ZH40PJV1bP2`h>H10?ooo`00c@2`h>H5086YP@L0P[N>00<0
PJV108g4U`2=a9L01`2=a9L00`21ZH40T/^J09;;VP0<09;;VP03086YP@2Cc9X0TlbJ00/0TlbJ00<0
PJV108o7U@2?aiD02`2?aiD00`21ZH40Qkf=08NmS@0808NmS@03086YP@1i[7l0NJao00D0NJao1@21
ZH7=0;3PiP40oooo003@0;3PiPL0PJV10`22]hh2086YP@P0SLBG00<0PJV109;;VP2BbiX02`2BbiX0
0`21ZH40TlbJ09?<VP0;09?<VP03086YP@2?aiD0SlNE00/0SlNE00<0PJV108NmS@27_Hd01P27_Hd2
086YP@<0NJao1`21ZH7@0;3PiP40oooo003C0;3PiP`0PJV11P2=a9L00`21ZH40T/^J09;;VP0:09;;
VP03086YP@2Cc9X0TlbJ00/0TlbJ00<0PJV108o7U@2?aiD02P2?aiD00`21ZH40Qkf=08NmS@0408Nm
S@P0PJV100@0HHi[086YP@21ZH40PJV1d`2`h>H10?ooo`00eP2`h>H5086YP@80IiMg2021ZH400`2=
a9L0PJV109;;VP0;09;;VP03086YP@2Cc9X0TlbJ00T0TlbJ00<0PJV108o7U@2?aiD02P2?aiD00`21
ZH40Qkf=086YP@07086YP@@0HHi[0`21ZH7F0;3PiP40oooo003I0;3PiPD0PJV100<0IiMg086YP@21
ZH40101aY7lY086YP@@0KIig0P21ZH42066>J`@0PJV1f@2`h>H10?ooo`00g@2`h>H6086YP@D0LJAo
0P21ZH4907N[P`03086YP@1h[8<0N:b300P0N:b300<0PJV107FXO`1eZ7l0201eZ7l2086YP@D0KIig
0P21ZH40101QSV/0PJV1086YP@21ZH7M0;3PiP40oooo003Q0;3PiP@0PJV11@1aY7l2086YP@P0Mj^3
00<0PJV107R/P`1h[8<01`1h[8<00`21ZH40MJQo07FXO`0607FXO`80PJV11@1]WWL4086YPN40/>3V
0@3oool00>D0/>3V3021ZH4307N[P`03086YP@1h[8<0N:b300H0N:b300<0PJV107FXO`1eZ7l00P1e
Z7l<086YPND0/>3V0@3oool00?00/>3V4`21ZH7`0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.605 .777 .566 r
.4503 .46959 m .4498 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.605 .777 .566 r
.48991 .5 m .49001 .46977 L .4503 .46959 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.49001 .53023 m .48991 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.49001 .46977 m .48991 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.48991 .5 m .49001 .53023 L .52992 .53029 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.52992 .53029 m .53022 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.53022 .5 m .52992 .46971 L .49001 .46977 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.52992 .46971 m .53022 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.53022 .5 m .52992 .53029 L .56922 .53059 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.56922 .53059 m .56993 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.45183 .43953 m .4503 .46959 L .49001 .46977 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.49001 .46977 m .49032 .43988 L .45183 .43953 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.4498 .5 m .4503 .53041 L .49001 .53023 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.49032 .56012 m .49001 .53023 L .4503 .53041 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.49032 .43988 m .49001 .46977 L .52992 .46971 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.49001 .53023 m .49032 .56012 L .529 .56024 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.529 .56024 m .52992 .53029 L .49001 .53023 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.52992 .46971 m .529 .43976 L .49032 .43988 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.529 .43976 m .52992 .46971 L .56922 .46941 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.56993 .5 m .56922 .46941 L .52992 .46971 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.52992 .53029 m .529 .56024 L .56709 .56082 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.56709 .56082 m .56922 .53059 L .52992 .53029 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.41161 .46916 m .41069 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.4498 .5 m .4503 .46959 L .41161 .46916 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.4503 .53041 m .4498 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.4503 .53041 m .45183 .56047 L .49032 .56012 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.41436 .43871 m .41161 .46916 L .4503 .46959 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.4503 .46959 m .45183 .43953 L .41436 .43871 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.41069 .5 m .41161 .53084 L .4503 .53041 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.45183 .56047 m .4503 .53041 L .41161 .53084 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.45437 .41018 m .45183 .43953 L .49032 .43988 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.49032 .43988 m .49082 .41067 L .45437 .41018 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.49082 .41067 m .49032 .43988 L .529 .43976 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.49082 .58933 m .49032 .56012 L .45183 .56047 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.49032 .56012 m .49082 .58933 L .52748 .58949 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49631 .56014 m
.49634 .56488 L
s
.5 Mabswid
.554 .698 .507 r
.52748 .58949 m .529 .56024 L .49032 .56012 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.529 .43976 m .52748 .41051 L .49082 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.52748 .41051 m .529 .43976 L .56709 .43918 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.56922 .46941 m .56709 .43918 L .529 .43976 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.529 .56024 m .52748 .58949 L .56352 .59032 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.56352 .59032 m .56709 .56082 L .529 .56024 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.56922 .46941 m .56993 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.56993 .5 m .56922 .53059 L .60709 .53114 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.60709 .53114 m .60821 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.56709 .43918 m .56922 .46941 L .60709 .46886 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.60821 .5 m .60709 .46886 L .56922 .46941 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.56922 .53059 m .56709 .56082 L .60373 .56188 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.60373 .56188 m .60709 .53114 L .56922 .53059 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.41894 .40902 m .41436 .43871 L .45183 .43953 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.45183 .43953 m .45437 .41018 L .41894 .40902 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.45183 .56047 m .45437 .58982 L .49082 .58933 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.41161 .53084 m .41436 .56129 L .45183 .56047 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.45437 .58982 m .45183 .56047 L .41436 .56129 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.56698 .56173 m
.56732 .5619 L
s
.49651 .59072 m
.49459 .59207 L
s
.49845 .59207 m
.49651 .59072 L
s
.49653 .5934 m
.49845 .59207 L
s
.49459 .59207 m
.49653 .5934 L
s
.5 Mabswid
.58 .745 .534 r
.37481 .46849 m .37348 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.41069 .5 m .41161 .46916 L .37481 .46849 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.41161 .53084 m .41069 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.45794 .38193 m .45437 .41018 L .49082 .41067 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.49082 .41067 m .49154 .38253 L .45794 .38193 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.49154 .38253 m .49082 .41067 L .52748 .41051 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.49154 .61747 m .49082 .58933 L .45437 .58982 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.49082 .58933 m .49154 .61747 L .52534 .61767 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.52534 .61767 m .52748 .58949 L .49082 .58933 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.56709 .43918 m .56352 .40968 L .52748 .41051 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.56352 .40968 m .56709 .43918 L .60373 .43812 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.60709 .46886 m .60373 .43812 L .56709 .43918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.56709 .56082 m .56352 .59032 L .59813 .5918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.59813 .5918 m .60373 .56188 L .56709 .56082 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44357 .58294 m
.44468 .58292 L
s
.5 Mabswid
.646 .845 .624 r
.52748 .41051 m .52534 .38233 L .49154 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.52534 .38233 m .52748 .41051 L .56352 .40968 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.52748 .58949 m .52534 .61767 L .55853 .61867 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.55853 .61867 m .56352 .59032 L .52748 .58949 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.37878 .43741 m .37481 .46849 L .41161 .46916 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.41161 .46916 m .41436 .43871 L .37878 .43741 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.37348 .5 m .37481 .53151 L .41161 .53084 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.41436 .56129 m .41161 .53084 L .37481 .53151 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43749 .57779 m
.43954 .58155 L
s
.43954 .58155 m
.44357 .58294 L
s
.5 Mabswid
.633 .829 .605 r
.42535 .38053 m .41894 .40902 L .45437 .41018 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.45437 .41018 m .45794 .38193 L .42535 .38053 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.45437 .58982 m .45794 .61807 L .49154 .61747 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.41436 .56129 m .41894 .59098 L .45437 .58982 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.45794 .61807 m .45437 .58982 L .41894 .59098 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.41166 .56062 m
.41443 .56178 L
s
.5 Mabswid
.61 .793 .573 r
.38539 .40721 m .37878 .43741 L .41436 .43871 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.41436 .43871 m .41894 .40902 L .38539 .40721 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.37481 .53151 m .37878 .56259 L .41436 .56129 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.41894 .59098 m .41436 .56129 L .37878 .56259 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.60709 .46886 m .60821 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.60821 .5 m .60709 .53114 L .64258 .53194 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.64258 .53194 m .64411 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.56352 .40968 m .55853 .38133 L .52534 .38233 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.55853 .38133 m .56352 .40968 L .59813 .4082 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.60373 .43812 m .59813 .4082 L .56352 .40968 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.56352 .59032 m .55853 .61867 L .59031 .62047 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.59031 .62047 m .59813 .5918 L .56352 .59032 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.60373 .43812 m .60709 .46886 L .64258 .46806 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.64411 .5 m .64258 .46806 L .60709 .46886 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.60709 .53114 m .60373 .56188 L .63799 .56341 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.63799 .56341 m .64258 .53194 L .60709 .53114 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.46253 .35521 m .45794 .38193 L .49154 .38253 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.49154 .38253 m .49246 .35586 L .46253 .35521 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.49246 .64414 m .49154 .61747 L .45794 .61807 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.49246 .35586 m .49154 .38253 L .52534 .38233 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.49154 .61747 m .49246 .64414 L .52258 .64436 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.52258 .64436 m .52534 .61767 L .49154 .61747 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.52534 .38233 m .52258 .35564 L .49246 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.52258 .35564 m .52534 .38233 L .55853 .38133 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.52534 .61767 m .52258 .64436 L .55212 .64545 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.55212 .64545 m .55853 .61867 L .52534 .61767 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.59813 .4082 m .60373 .43812 L .63799 .43659 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.64258 .46806 m .63799 .43659 L .60373 .43812 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.60373 .56188 m .59813 .5918 L .63037 .59394 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.63037 .59394 m .63799 .56341 L .60373 .56188 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.39462 .37834 m .38539 .40721 L .41894 .40902 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.41894 .40902 m .42535 .38053 L .39462 .37834 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.37878 .56259 m .38539 .59279 L .41894 .59098 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.42535 .61947 m .41894 .59098 L .38539 .59279 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.41894 .59098 m .42535 .61947 L .45794 .61807 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.45794 .61807 m .46253 .64479 L .49246 .64414 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.43357 .35368 m .42535 .38053 L .45794 .38193 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.45794 .38193 m .46253 .35521 L .43357 .35368 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.46253 .64479 m .45794 .61807 L .42535 .61947 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.3409 .46758 m .33917 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.37348 .5 m .37481 .46849 L .3409 .46758 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.37481 .53151 m .37348 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.3461 .43565 m .3409 .46758 L .37481 .46849 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.37481 .46849 m .37878 .43741 L .3461 .43565 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.33917 .5 m .3409 .53242 L .37481 .53151 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.37878 .56259 m .37481 .53151 L .3409 .53242 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37772 .56185 m
.37801 .56198 L
s
.5 Mabswid
.655 .863 .643 r
.55853 .38133 m .55212 .35455 L .52258 .35564 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.55212 .35455 m .55853 .38133 L .59031 .37953 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.59813 .4082 m .59031 .37953 L .55853 .38133 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.55853 .61867 m .55212 .64545 L .58028 .6474 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.58028 .6474 m .59031 .62047 L .55853 .61867 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.59031 .37953 m .59813 .4082 L .63037 .40606 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.63799 .43659 m .63037 .40606 L .59813 .4082 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.59813 .5918 m .59031 .62047 L .61975 .62304 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.61975 .62304 m .63037 .59394 L .59813 .5918 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.35472 .40475 m .3461 .43565 L .37878 .43741 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.37878 .43741 m .38539 .40721 L .35472 .40475 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.3409 .53242 m .3461 .56435 L .37878 .56259 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.38539 .59279 m .37878 .56259 L .3461 .56435 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.40642 .3513 m .39462 .37834 L .42535 .38053 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.42535 .38053 m .43357 .35368 L .40642 .3513 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.38539 .59279 m .39462 .62166 L .42535 .61947 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.43357 .64632 m .42535 .61947 L .39462 .62166 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.42535 .61947 m .43357 .64632 L .46253 .64479 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.64258 .46806 m .64411 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.64411 .5 m .64258 .53194 L .6746 .53297 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.6746 .53297 m .67654 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.46813 .3305 m .46253 .35521 L .49246 .35586 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.49246 .35586 m .49358 .33115 L .46813 .3305 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.49358 .33115 m .49246 .35586 L .52258 .35564 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.49358 .66885 m .49246 .64414 L .46253 .64479 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.49246 .64414 m .49358 .66885 L .51922 .66907 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.51922 .66907 m .52258 .64436 L .49246 .64414 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.52258 .35564 m .51922 .33093 L .49358 .33115 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.51922 .33093 m .52258 .35564 L .55212 .35455 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.63799 .43659 m .64258 .46806 L .6746 .46703 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.67654 .5 m .6746 .46703 L .64258 .46806 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.64258 .53194 m .63799 .56341 L .66881 .5654 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.66881 .5654 m .6746 .53297 L .64258 .53194 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.52258 .64436 m .51922 .66907 L .5443 .67015 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.5443 .67015 m .55212 .64545 L .52258 .64436 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.3667 .37538 m .35472 .40475 L .38539 .40721 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.38539 .40721 m .39462 .37834 L .3667 .37538 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.3461 .56435 m .35472 .59525 L .38539 .59279 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.39462 .62166 m .38539 .59279 L .35472 .59525 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.46253 .64479 m .46813 .6695 L .49358 .66885 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.44359 .32898 m .43357 .35368 L .46253 .35521 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.46253 .35521 m .46813 .3305 L .44359 .32898 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.46813 .6695 m .46253 .64479 L .43357 .64632 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.59031 .37953 m .58028 .3526 L .55212 .35455 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.58028 .3526 m .59031 .37953 L .61975 .37696 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.63037 .40606 m .61975 .37696 L .59031 .37953 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.59031 .62047 m .58028 .6474 L .60621 .6502 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.60621 .6502 m .61975 .62304 L .59031 .62047 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.63037 .40606 m .63799 .43659 L .66881 .4346 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.6746 .46703 m .66881 .4346 L .63799 .43659 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.63799 .56341 m .63037 .59394 L .65921 .59672 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.65921 .59672 m .66881 .5654 L .63799 .56341 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.55212 .35455 m .5443 .32985 L .51922 .33093 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.5443 .32985 m .55212 .35455 L .58028 .3526 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.55212 .64545 m .5443 .67015 L .5681 .67209 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.5681 .67209 m .58028 .6474 L .55212 .64545 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.61975 .37696 m .63037 .40606 L .65921 .40328 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.66881 .4346 m .65921 .40328 L .63037 .40606 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.63037 .59394 m .61975 .62304 L .64589 .62639 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.64589 .62639 m .65921 .59672 L .63037 .59394 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.42073 .32662 m .40642 .3513 L .43357 .35368 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.43357 .35368 m .44359 .32898 L .42073 .32662 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.39462 .62166 m .40642 .6487 L .43357 .64632 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.44359 .67102 m .43357 .64632 L .40642 .6487 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.43357 .64632 m .44359 .67102 L .46813 .6695 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.31108 .46642 m .30894 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.33917 .5 m .3409 .46758 L .31108 .46642 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.3409 .53242 m .33917 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.38195 .34809 m .3667 .37538 L .39462 .37834 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.39462 .37834 m .40642 .3513 L .38195 .34809 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.35472 .59525 m .3667 .62462 L .39462 .62166 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.40642 .6487 m .39462 .62166 L .3667 .62462 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.31746 .43343 m .31108 .46642 L .3409 .46758 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.3409 .46758 m .3461 .43565 L .31746 .43343 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.30894 .5 m .31108 .53358 L .3409 .53242 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.3461 .56435 m .3409 .53242 L .31108 .53358 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34472 .5636 m
.34582 .5641 L
s
.5 Mabswid
.559 .731 .518 r
.32801 .40165 m .31746 .43343 L .3461 .43565 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.3461 .43565 m .35472 .40475 L .32801 .40165 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.31108 .53358 m .31746 .56657 L .3461 .56435 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.35472 .59525 m .3461 .56435 L .31746 .56657 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.58028 .3526 m .5681 .32791 L .5443 .32985 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.5681 .32791 m .58028 .3526 L .60621 .3498 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.61975 .37696 m .60621 .3498 L .58028 .3526 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58028 .6474 m .5681 .67209 L .58983 .67486 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58983 .67486 m .60621 .6502 L .58028 .6474 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.47472 .30833 m .46813 .3305 L .49358 .33115 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.49358 .33115 m .4949 .30892 L .47472 .30833 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.4949 .30892 m .49358 .33115 L .51922 .33093 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.4949 .69108 m .49358 .66885 L .46813 .6695 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.49358 .66885 m .4949 .69108 L .51525 .69128 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.51525 .69128 m .51922 .66907 L .49358 .66885 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.51922 .33093 m .51525 .30872 L .4949 .30892 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.51525 .30872 m .51922 .33093 L .5443 .32985 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.51922 .66907 m .51525 .69128 L .5351 .69225 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.5351 .69225 m .5443 .67015 L .51922 .66907 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.60621 .3498 m .61975 .37696 L .64589 .37361 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.65921 .40328 m .64589 .37361 L .61975 .37696 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.61975 .62304 m .60621 .6502 L .62899 .65381 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.62899 .65381 m .64589 .62639 L .61975 .62304 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.46813 .6695 m .47472 .69167 L .4949 .69108 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.45535 .30698 m .44359 .32898 L .46813 .3305 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.46813 .3305 m .47472 .30833 L .45535 .30698 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.47472 .69167 m .46813 .6695 L .44359 .67102 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.34262 .37167 m .32801 .40165 L .35472 .40475 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.35472 .40475 m .3667 .37538 L .34262 .37167 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.31746 .56657 m .32801 .59835 L .35472 .59525 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.3667 .62462 m .35472 .59525 L .32801 .59835 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40032 .32347 m .38195 .34809 L .40642 .3513 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40642 .3513 m .42073 .32662 L .40032 .32347 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.3667 .62462 m .38195 .65191 L .40642 .6487 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.42073 .67338 m .40642 .6487 L .38195 .65191 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.40642 .6487 m .42073 .67338 L .44359 .67102 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.5443 .32985 m .5351 .30775 L .51525 .30872 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5351 .30775 m .5443 .32985 L .5681 .32791 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.5443 .67015 m .5351 .69225 L .55383 .69398 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.55383 .69398 m .5681 .67209 L .5443 .67015 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.6746 .46703 m .67654 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.67654 .5 m .6746 .53297 L .70188 .53425 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.70188 .53425 m .70421 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.66881 .4346 m .6746 .46703 L .70188 .46575 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.70421 .5 m .70188 .46575 L .6746 .46703 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.6746 .53297 m .66881 .5654 L .69493 .56784 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.69493 .56784 m .70188 .53425 L .6746 .53297 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.43743 .30488 m .42073 .32662 L .44359 .32898 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.44359 .32898 m .45535 .30698 L .43743 .30488 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.45535 .69302 m .44359 .67102 L .42073 .67338 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.44359 .67102 m .45535 .69302 L .47472 .69167 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.65921 .40328 m .66881 .4346 L .69493 .43216 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.70188 .46575 m .69493 .43216 L .66881 .4346 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.66881 .5654 m .65921 .59672 L .68346 .60013 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.68346 .60013 m .69493 .56784 L .66881 .5654 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3611 .34411 m .34262 .37167 L .3667 .37538 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3667 .37538 m .38195 .34809 L .3611 .34411 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.32801 .59835 m .34262 .62833 L .3667 .62462 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.38195 .65191 m .3667 .62462 L .34262 .62833 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.60621 .3498 m .58983 .32514 L .5681 .32791 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.58983 .32514 m .60621 .3498 L .62899 .34619 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.64589 .37361 m .62899 .34619 L .60621 .3498 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.60621 .6502 m .58983 .67486 L .6087 .6784 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.6087 .6784 m .62899 .65381 L .60621 .6502 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5681 .32791 m .55383 .30602 L .5351 .30775 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.55383 .30602 m .5681 .32791 L .58983 .32514 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.5681 .67209 m .55383 .69398 L .57077 .69644 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.57077 .69644 m .58983 .67486 L .5681 .67209 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.64589 .37361 m .65921 .40328 L .68346 .39987 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.69493 .43216 m .68346 .39987 L .65921 .40328 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.65921 .59672 m .64589 .62639 L .66762 .63045 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.66762 .63045 m .68346 .60013 L .65921 .59672 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42163 .30208 m .40032 .32347 L .42073 .32662 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42073 .32662 m .43743 .30488 L .42163 .30208 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.38195 .65191 m .40032 .67653 L .42073 .67338 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.43743 .69512 m .42073 .67338 L .40032 .67653 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.42073 .67338 m .43743 .69512 L .45535 .69302 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.28671 .46503 m .2842 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.30894 .5 m .31108 .46642 L .28671 .46503 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.31108 .53358 m .30894 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.48228 .28932 m .47472 .30833 L .4949 .30892 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.4949 .30892 m .49643 .28977 L .48228 .28932 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.49643 .28977 m .4949 .30892 L .51525 .30872 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.49643 .71023 m .4949 .69108 L .47472 .69167 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.4949 .69108 m .49643 .71023 L .51069 .71038 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51069 .71038 m .51525 .69128 L .4949 .69108 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.51525 .30872 m .51069 .28962 L .49643 .28977 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.51069 .28962 m .51525 .30872 L .5351 .30775 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.51525 .69128 m .51069 .71038 L .52458 .71113 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.52458 .71113 m .5351 .69225 L .51525 .69128 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.2942 .43077 m .28671 .46503 L .31108 .46642 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.31108 .46642 m .31746 .43343 L .2942 .43077 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.2842 .5 m .28671 .53497 L .31108 .53358 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.31746 .56657 m .31108 .53358 L .28671 .53497 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.3832 .31957 m .3611 .34411 L .38195 .34809 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.38195 .34809 m .40032 .32347 L .3832 .31957 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.34262 .62833 m .3611 .65589 L .38195 .65191 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.40032 .67653 m .38195 .65191 L .3611 .65589 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.62899 .34619 m .64589 .37361 L .66762 .36955 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.68346 .39987 m .66762 .36955 L .64589 .37361 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64589 .62639 m .62899 .65381 L .64765 .65816 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64765 .65816 m .66762 .63045 L .64589 .62639 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.46877 .28827 m .45535 .30698 L .47472 .30833 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.47472 .30833 m .48228 .28932 L .46877 .28827 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47472 .69167 m .48228 .71068 L .49643 .71023 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.48228 .71068 m .47472 .69167 L .45535 .69302 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.30655 .39796 m .2942 .43077 L .31746 .43343 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.31746 .43343 m .32801 .40165 L .30655 .39796 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.28671 .53497 m .2942 .56923 L .31746 .56657 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.32801 .59835 m .31746 .56657 L .2942 .56923 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.5351 .30775 m .52458 .28887 L .51069 .28962 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.52458 .28887 m .5351 .30775 L .55383 .30602 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5351 .69225 m .52458 .71113 L .5376 .71246 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5376 .71246 m .55383 .69398 L .5351 .69225 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.58983 .32514 m .57077 .30356 L .55383 .30602 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.57077 .30356 m .58983 .32514 L .6087 .3216 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.62899 .34619 m .6087 .3216 L .58983 .32514 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58983 .67486 m .57077 .69644 L .58528 .69956 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58528 .69956 m .6087 .6784 L .58983 .67486 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32354 .36727 m .30655 .39796 L .32801 .40165 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32801 .40165 m .34262 .37167 L .32354 .36727 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45638 .28667 m .43743 .30488 L .45535 .30698 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45535 .30698 m .46877 .28827 L .45638 .28667 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.2942 .56923 m .30655 .60204 L .32801 .59835 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.34262 .62833 m .32801 .59835 L .30655 .60204 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.46877 .71173 m .45535 .69302 L .43743 .69512 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.45535 .69302 m .46877 .71173 L .48228 .71068 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.6087 .3216 m .62899 .34619 L .64765 .34184 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.66762 .36955 m .64765 .34184 L .62899 .34619 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62899 .65381 m .6087 .6784 L .62388 .68263 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62388 .68263 m .64765 .65816 L .62899 .65381 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.55383 .30602 m .5376 .28754 L .52458 .28887 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.5376 .28754 m .55383 .30602 L .57077 .30356 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.55383 .69398 m .5376 .71246 L .54924 .71433 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.54924 .71433 m .57077 .69644 L .55383 .69398 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40859 .29866 m .3832 .31957 L .40032 .32347 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40032 .32347 m .42163 .30208 L .40859 .29866 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.3611 .65589 m .3832 .68043 L .40032 .67653 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.42163 .69792 m .40032 .67653 L .3832 .68043 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.40032 .67653 m .42163 .69792 L .43743 .69512 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34488 .33941 m .32354 .36727 L .34262 .37167 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34262 .37167 m .3611 .34411 L .34488 .33941 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.30655 .60204 m .32354 .63273 L .34262 .62833 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.3611 .65589 m .34262 .62833 L .32354 .63273 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.70188 .46575 m .70421 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.70421 .5 m .70188 .53425 L .72294 .53575 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.72294 .53575 m .72562 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.69493 .43216 m .70188 .46575 L .72294 .46425 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.72562 .5 m .72294 .46425 L .70188 .46575 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.70188 .53425 m .69493 .56784 L .71494 .57071 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.71494 .57071 m .72294 .53575 L .70188 .53425 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.4456 .28455 m .42163 .30208 L .43743 .30488 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.43743 .30488 m .45638 .28667 L .4456 .28455 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45638 .71333 m .43743 .69512 L .42163 .69792 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.43743 .69512 m .45638 .71333 L .46877 .71173 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.68346 .39987 m .69493 .43216 L .71494 .42929 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.72294 .46425 m .71494 .42929 L .69493 .43216 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.69493 .56784 m .68346 .60013 L .70178 .6041 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.70178 .6041 m .71494 .57071 L .69493 .56784 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.57077 .30356 m .54924 .28567 L .5376 .28754 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.54924 .28567 m .57077 .30356 L .58528 .30044 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.6087 .3216 m .58528 .30044 L .57077 .30356 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.57077 .69644 m .54924 .71433 L .55905 .71669 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.55905 .71669 m .58528 .69956 L .57077 .69644 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.37018 .31502 m .34488 .33941 L .3611 .34411 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.3611 .34411 m .3832 .31957 L .37018 .31502 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.32354 .63273 m .34488 .66059 L .3611 .65589 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.3832 .68043 m .3611 .65589 L .34488 .66059 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.58528 .30044 m .6087 .3216 L .62388 .31737 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.64765 .34184 m .62388 .31737 L .6087 .3216 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.6087 .6784 m .58528 .69956 L .59668 .70325 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.59668 .70325 m .62388 .68263 L .6087 .6784 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.66762 .36955 m .68346 .39987 L .70178 .3959 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.71494 .42929 m .70178 .3959 L .68346 .39987 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68346 .60013 m .66762 .63045 L .68373 .63515 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68373 .63515 m .70178 .6041 L .68346 .60013 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49074 .27412 m .48228 .28932 L .49643 .28977 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49643 .28977 m .49813 .27437 L .49074 .27412 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.49813 .27437 m .49643 .28977 L .51069 .28962 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49813 .72563 m .49643 .71023 L .48228 .71068 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49643 .71023 m .49813 .72563 L .50559 .72571 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.50559 .72571 m .51069 .71038 L .49643 .71023 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.51069 .28962 m .50559 .27429 L .49813 .27437 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.50559 .27429 m .51069 .28962 L .52458 .28887 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51069 .71038 m .50559 .72571 L .51284 .72613 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51284 .72613 m .52458 .71113 L .51069 .71038 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48372 .27353 m .46877 .28827 L .48228 .28932 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48228 .28932 m .49074 .27412 L .48372 .27353 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.48228 .71068 m .49074 .72588 L .49813 .72563 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.49074 .72588 m .48228 .71068 L .46877 .71173 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.64765 .34184 m .66762 .36955 L .68373 .36485 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.70178 .3959 m .68373 .36485 L .66762 .36955 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66762 .63045 m .64765 .65816 L .66116 .66317 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66116 .66317 m .68373 .63515 L .66762 .63045 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.52458 .28887 m .51284 .27387 L .50559 .27429 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.51284 .27387 m .52458 .28887 L .5376 .28754 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.52458 .71113 m .51284 .72613 L .51957 .72688 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.51957 .72688 m .5376 .71246 L .52458 .71113 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.43688 .28198 m .40859 .29866 L .42163 .30208 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.42163 .30208 m .4456 .28455 L .43688 .28198 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.3832 .68043 m .40859 .70134 L .42163 .69792 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.4456 .71545 m .42163 .69792 L .40859 .70134 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.42163 .69792 m .4456 .71545 L .45638 .71333 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.47734 .27264 m .45638 .28667 L .46877 .28827 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.46877 .28827 m .48372 .27353 L .47734 .27264 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.48372 .72647 m .46877 .71173 L .45638 .71333 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.46877 .71173 m .48372 .72647 L .49074 .72588 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.39896 .29471 m .37018 .31502 L .3832 .31957 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.3832 .31957 m .40859 .29866 L .39896 .29471 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.34488 .66059 m .37018 .68498 L .3832 .68043 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.40859 .70134 m .3832 .68043 L .37018 .68498 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.5376 .28754 m .51957 .27312 L .51284 .27387 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.51957 .27312 m .5376 .28754 L .54924 .28567 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.5376 .71246 m .51957 .72688 L .52552 .72791 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.52552 .72791 m .54924 .71433 L .5376 .71246 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.26939 .46342 m .26655 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.2842 .5 m .28671 .46503 L .26939 .46342 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.28671 .53497 m .2842 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.27785 .42772 m .26939 .46342 L .28671 .46503 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.28671 .46503 m .2942 .43077 L .27785 .42772 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.26655 .5 m .26939 .53658 L .28671 .53497 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.2942 .56923 m .28671 .53497 L .26939 .53658 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.62388 .31737 m .64765 .34184 L .66116 .33683 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.68373 .36485 m .66116 .33683 L .64765 .34184 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.64765 .65816 m .62388 .68263 L .63452 .68746 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.63452 .68746 m .66116 .66317 L .64765 .65816 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.58528 .30044 m .55905 .28331 L .54924 .28567 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.55905 .28331 m .58528 .30044 L .59668 .29675 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.62388 .31737 m .59668 .29675 L .58528 .30044 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.58528 .69956 m .55905 .71669 L .56657 .71945 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.56657 .71945 m .59668 .70325 L .58528 .69956 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.29173 .39373 m .27785 .42772 L .2942 .43077 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.2942 .43077 m .30655 .39796 L .29173 .39373 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.26939 .53658 m .27785 .57228 L .2942 .56923 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.30655 .60204 m .2942 .56923 L .27785 .57228 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.47187 .27147 m .4456 .28455 L .45638 .28667 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.45638 .28667 m .47734 .27264 L .47187 .27147 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.47734 .72736 m .45638 .71333 L .4456 .71545 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.45638 .71333 m .47734 .72736 L .48372 .72647 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.27785 .57228 m .29173 .60627 L .30655 .60204 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.32354 .63273 m .30655 .60204 L .29173 .60627 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.31071 .36228 m .29173 .39373 L .30655 .39796 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.30655 .39796 m .32354 .36727 L .31071 .36228 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.54924 .28567 m .52552 .27209 L .51957 .27312 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.52552 .27209 m .54924 .28567 L .55905 .28331 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.54924 .71433 m .52552 .72791 L .53045 .7292 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.53045 .7292 m .55905 .71669 L .54924 .71433 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.59668 .29675 m .62388 .31737 L .63452 .31254 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.66116 .33683 m .63452 .31254 L .62388 .31737 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.62388 .68263 m .59668 .70325 L .60439 .70742 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.60439 .70742 m .63452 .68746 L .62388 .68263 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.33435 .33413 m .31071 .36228 L .32354 .36727 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.32354 .36727 m .34488 .33941 L .33435 .33413 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.29173 .60627 m .31071 .63772 L .32354 .63273 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.34488 .66059 m .32354 .63273 L .31071 .63772 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.43065 .27904 m .39896 .29471 L .40859 .29866 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.40859 .29866 m .43688 .28198 L .43065 .27904 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.37018 .68498 m .39896 .70529 L .40859 .70134 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.43688 .71802 m .40859 .70134 L .39896 .70529 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.40859 .70134 m .43688 .71802 L .4456 .71545 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.46755 .27007 m .43688 .28198 L .4456 .28455 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.4456 .28455 m .47187 .27147 L .46755 .27007 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.47187 .72853 m .4456 .71545 L .43688 .71802 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.4456 .71545 m .47187 .72853 L .47734 .72736 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.36211 .30995 m .33435 .33413 L .34488 .33941 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.34488 .33941 m .37018 .31502 L .36211 .30995 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.31071 .63772 m .33435 .66587 L .34488 .66059 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.37018 .68498 m .34488 .66059 L .33435 .66587 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.55905 .28331 m .53045 .2708 L .52552 .27209 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.53045 .2708 m .55905 .28331 L .56657 .28055 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.59668 .29675 m .56657 .28055 L .55905 .28331 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.55905 .71669 m .53045 .7292 L .53411 .7307 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.53411 .7307 m .56657 .71945 L .55905 .71669 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.56657 .28055 m .59668 .29675 L .60439 .29258 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.63452 .31254 m .60439 .29258 L .59668 .29675 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.59668 .70325 m .56657 .71945 L .57141 .72253 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.57141 .72253 m .60439 .70742 L .59668 .70325 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.72294 .46425 m .72562 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.72562 .5 m .72294 .53575 L .73609 .53744 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.73609 .53744 m .73907 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.555 .774 .585 r
.49813 .27437 m .5 .26345 L .49074 .27412 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50559 .27429 m .5 .26345 L .49813 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49813 .72563 L .49074 .72588 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50559 .72571 L .49813 .72563 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51284 .27387 m .5 .26345 L .50559 .27429 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .51284 .72613 L .50559 .72571 L closepath p F P
.505 .664 .505 r
s
.415 .55 .447 r
.71494 .42929 m .72294 .46425 L .73609 .46256 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.73907 .5 m .73609 .46256 L .72294 .46425 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72294 .53575 m .71494 .57071 L .72724 .57394 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72724 .57394 m .73609 .53744 L .72294 .53575 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.39333 .29036 m .36211 .30995 L .37018 .31502 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.37018 .31502 m .39896 .29471 L .39333 .29036 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.33435 .66587 m .36211 .69005 L .37018 .68498 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.39896 .70529 m .37018 .68498 L .36211 .69005 L p F P
.505 .664 .505 r
s
.552 .77 .582 r
.49074 .27412 m .5 .26345 L .48372 .27353 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .49074 .72588 L .48372 .72647 L closepath p F P
.505 .664 .505 r
s
.444 .597 .482 r
.70178 .3959 m .71494 .42929 L .72724 .42606 L p F P
.505 .664 .505 r
s
.415 .55 .447 r
.73609 .46256 m .72724 .42606 L .71494 .42929 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71494 .57071 m .70178 .6041 L .71274 .60854 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71274 .60854 m .72724 .57394 L .71494 .57071 L p F P
.505 .664 .505 r
s
.553 .772 .586 r
.51957 .27312 m .5 .26345 L .51284 .27387 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .51957 .72688 L .51284 .72613 L closepath p F P
.505 .664 .505 r
s
.544 .757 .564 r
.46458 .26849 m .43065 .27904 L .43688 .28198 L p F P
.505 .664 .505 r
s
.544 .757 .564 r
.43688 .28198 m .46755 .27007 L .46458 .26849 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.39896 .70529 m .43065 .72096 L .43688 .71802 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.46755 .72993 m .43688 .71802 L .43065 .72096 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.43688 .71802 m .46755 .72993 L .47187 .72853 L p F P
.505 .664 .505 r
s
.547 .764 .578 r
.48372 .27353 m .5 .26345 L .47734 .27264 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .48372 .72647 L .47734 .72736 L closepath p F P
.505 .664 .505 r
s
.469 .638 .513 r
.68373 .36485 m .70178 .3959 L .71274 .39146 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.72724 .42606 m .71274 .39146 L .70178 .3959 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.70178 .6041 m .68373 .63515 L .69297 .64039 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.69297 .64039 m .71274 .60854 L .70178 .6041 L p F P
.505 .664 .505 r
s
.549 .767 .583 r
.52552 .27209 m .5 .26345 L .51957 .27312 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .52552 .72791 L .51957 .72688 L closepath p F P
.505 .664 .505 r
s
.491 .673 .537 r
.66116 .33683 m .68373 .36485 L .69297 .35961 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.71274 .39146 m .69297 .35961 L .68373 .36485 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.68373 .63515 m .66116 .66317 L .66846 .66869 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.66846 .66869 m .69297 .64039 L .68373 .63515 L p F P
.505 .664 .505 r
s
.541 .757 .572 r
.47734 .27264 m .5 .26345 L .47187 .27147 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .47734 .72736 L .47187 .72853 L closepath p F P
.505 .664 .505 r
s
.513 .715 .527 r
.42727 .27585 m .39333 .29036 L .39896 .29471 L p F P
.505 .664 .505 r
s
.513 .715 .527 r
.39896 .29471 m .43065 .27904 L .42727 .27585 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.36211 .69005 m .39333 .70964 L .39896 .70529 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.43065 .72096 m .39896 .70529 L .39333 .70964 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.56657 .28055 m .53411 .2693 L .53045 .2708 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.53411 .2693 m .56657 .28055 L .57141 .27747 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.60439 .29258 m .57141 .27747 L .56657 .28055 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.56657 .71945 m .53411 .7307 L .53635 .73235 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.53635 .73235 m .57141 .72253 L .56657 .71945 L p F P
.505 .664 .505 r
s
.543 .76 .579 r
.53045 .2708 m .5 .26345 L .52552 .27209 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .53045 .7292 L .52552 .72791 L closepath p F P
.505 .664 .505 r
s
.507 .701 .556 r
.63452 .31254 m .66116 .33683 L .66846 .33131 L p F P
.505 .664 .505 r
s
.491 .673 .537 r
.69297 .35961 m .66846 .33131 L .66116 .33683 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.66116 .66317 m .63452 .68746 L .63983 .69272 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.63983 .69272 m .66846 .66869 L .66116 .66317 L p F P
.505 .664 .505 r
s
.533 .748 .565 r
.47187 .27147 m .5 .26345 L .46755 .27007 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .47187 .72853 L .46755 .72993 L closepath p F P
.505 .664 .505 r
s
.518 .721 .567 r
.60439 .29258 m .63452 .31254 L .63983 .30728 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.66846 .33131 m .63983 .30728 L .63452 .31254 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.63452 .68746 m .60439 .70742 L .60783 .71191 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60783 .71191 m .63983 .69272 L .63452 .68746 L p F P
.505 .664 .505 r
s
.535 .751 .573 r
.53411 .2693 m .5 .26345 L .53045 .2708 L closepath p F P
.505 .664 .505 r
s
.184 .192 .146 r
.5 .73655 m .53411 .7307 L .53045 .7292 L closepath p F P
.505 .664 .505 r
s
.517 .725 .541 r
.46311 .26679 m .42727 .27585 L .43065 .27904 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.43065 .27904 m .46458 .26849 L .46311 .26679 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.39333 .70964 m .42727 .72415 L .43065 .72096 L p F P
.505 .664 .505 r
s
.191 .198 .151 r
.46458 .73151 m .43065 .72096 L .42727 .72415 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.43065 .72096 m .46458 .73151 L .46755 .72993 L p F P
.505 .664 .505 r
s
.524 .737 .557 r
.46755 .27007 m .5 .26345 L .46458 .26849 L closepath p F P
.505 .664 .505 r
s
.185 .192 .146 r
.5 .73655 m .46755 .72993 L .46458 .73151 L closepath p F P
.505 .664 .505 r
s
.524 .733 .572 r
.57141 .27747 m .60439 .29258 L .60783 .28809 L p F P
.505 .664 .505 r
s
.518 .721 .567 r
.63983 .30728 m .60783 .28809 L .60439 .29258 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60439 .70742 m .57141 .72253 L .57327 .72581 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57327 .72581 m .60783 .71191 L .60439 .70742 L p F P
.505 .664 .505 r
s
.526 .74 .566 r
.53635 .26765 m .5 .26345 L .53411 .2693 L closepath p F P
.505 .664 .505 r
s
.551 .768 .591 r
.57141 .27747 m .53635 .26765 L .53411 .2693 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .53635 .73235 L .53411 .7307 L closepath p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26084 .46165 m .25775 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26655 .5 m .26939 .46342 L .26084 .46165 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.26939 .53658 m .26655 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.27002 .42434 m .26084 .46165 L .26939 .46342 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.26939 .46342 m .27785 .42772 L .27002 .42434 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.25775 .5 m .26084 .53835 L .26939 .53658 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.27785 .57228 m .26939 .53658 L .26084 .53835 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.28501 .38909 m .27002 .42434 L .27785 .42772 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.27785 .42772 m .29173 .39373 L .28501 .38909 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.26084 .53835 m .27002 .57566 L .27785 .57228 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.29173 .60627 m .27785 .57228 L .27002 .57566 L p F P
.505 .664 .505 r
s
.523 .735 .568 r
.53635 .26765 m .57141 .27747 L .57327 .27419 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.60783 .28809 m .57327 .27419 L .57141 .27747 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57141 .72253 m .53635 .73235 L .53702 .73408 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.53702 .73408 m .57327 .72581 L .57141 .72253 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.30538 .35684 m .28501 .38909 L .29173 .39373 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.29173 .39373 m .31071 .36228 L .30538 .35684 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.27002 .57566 m .28501 .61091 L .29173 .60627 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.31071 .63772 m .29173 .60627 L .28501 .61091 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.33053 .32842 m .30538 .35684 L .31071 .36228 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.31071 .36228 m .33435 .33413 L .33053 .32842 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.28501 .61091 m .30538 .64316 L .31071 .63772 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.33435 .66587 m .31071 .63772 L .30538 .64316 L p F P
.505 .664 .505 r
s
.514 .725 .548 r
.46458 .26849 m .5 .26345 L .46311 .26679 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.42727 .72415 m .46311 .73321 L .46458 .73151 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .46458 .73151 L .46311 .73321 L closepath p F P
.505 .664 .505 r
s
.399 .562 .4 r
.35974 .30454 m .33053 .32842 L .33435 .33413 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.33435 .33413 m .36211 .30995 L .35974 .30454 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.30538 .64316 m .33053 .67158 L .33435 .66587 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.36211 .69005 m .33435 .66587 L .33053 .67158 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.39219 .28577 m .35974 .30454 L .36211 .30995 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.36211 .30995 m .39333 .29036 L .39219 .28577 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.33053 .67158 m .35974 .69546 L .36211 .69005 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39333 .70964 m .36211 .69005 L .35974 .69546 L p F P
.505 .664 .505 r
s
.516 .728 .557 r
.53702 .26592 m .5 .26345 L .53635 .26765 L closepath p F P
.505 .664 .505 r
s
.523 .735 .568 r
.57327 .27419 m .53702 .26592 L .53635 .26765 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .53702 .73408 L .53635 .73235 L closepath p F P
.505 .664 .505 r
s
.461 .653 .481 r
.427 .27253 m .39219 .28577 L .39333 .29036 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.39333 .29036 m .42727 .27585 L .427 .27253 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.35974 .69546 m .39219 .71423 L .39333 .70964 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.42727 .72415 m .39333 .70964 L .39219 .71423 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39219 .71423 m .427 .72747 L .42727 .72415 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.46311 .73321 m .42727 .72415 L .427 .72747 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.46325 .26505 m .427 .27253 L .42727 .27585 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.42727 .27585 m .46311 .26679 L .46325 .26505 L p F P
.505 .664 .505 r
s
.504 .712 .539 r
.46311 .26679 m .5 .26345 L .46325 .26505 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.427 .72747 m .46325 .73495 L .46311 .73321 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .46311 .73321 L .46325 .73495 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .53608 .73581 L .53702 .73408 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .53351 .73747 L .53608 .73581 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .52942 .73899 L .53351 .73747 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .52395 .74028 L .52942 .73899 L closepath p F P
.505 .664 .505 r
s
.141 .151 .115 r
.5 .73655 m .51735 .74128 L .52395 .74028 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50992 .74195 L .51735 .74128 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50201 .74224 L .50992 .74195 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .494 .74214 L .50201 .74224 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .48628 .74166 L .494 .74214 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .47923 .74082 L .48628 .74166 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .47316 .73967 L .47923 .74082 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .46835 .73825 L .47316 .73967 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .46501 .73666 L .46835 .73825 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .46325 .73495 L .46501 .73666 L closepath p F P
.505 .664 .505 r
s
.506 .715 .548 r
.53608 .26419 m .5 .26345 L .53702 .26592 L closepath p F P
.505 .664 .505 r
s
.494 .702 .539 r
.53351 .26253 m .5 .26345 L .53608 .26419 L closepath p F P
.505 .664 .505 r
s
.493 .699 .53 r
.46325 .26505 m .5 .26345 L .46501 .26334 L closepath p F P
.505 .664 .505 r
s
.483 .689 .529 r
.52942 .26101 m .5 .26345 L .53351 .26253 L closepath p F P
.505 .664 .505 r
s
.482 .686 .521 r
.46501 .26334 m .5 .26345 L .46835 .26175 L closepath p F P
.505 .664 .505 r
s
.473 .676 .52 r
.52395 .25972 m .5 .26345 L .52942 .26101 L closepath p F P
.505 .664 .505 r
s
.472 .674 .513 r
.46835 .26175 m .5 .26345 L .47316 .26033 L closepath p F P
.505 .664 .505 r
s
.465 .666 .512 r
.51735 .25872 m .5 .26345 L .52395 .25972 L closepath p F P
.505 .664 .505 r
s
.464 .664 .506 r
.47316 .26033 m .5 .26345 L .47923 .25918 L closepath p F P
.505 .664 .505 r
s
.458 .658 .505 r
.50992 .25805 m .5 .26345 L .51735 .25872 L closepath p F P
.505 .664 .505 r
s
.458 .657 .502 r
.47923 .25918 m .5 .26345 L .48628 .25834 L closepath p F P
.505 .664 .505 r
s
.454 .652 .501 r
.50201 .25776 m .5 .26345 L .50992 .25805 L closepath p F P
.505 .664 .505 r
s
.454 .652 .499 r
.48628 .25834 m .5 .26345 L .494 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.494 .25786 m .5 .26345 L .50201 .25776 L closepath p F P
.505 .664 .505 r
s
.15 .16 .122 r
.57327 .72581 m .53702 .73408 L .53608 .73581 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.53702 .26592 m .57327 .27419 L .57192 .27086 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.57192 .27086 m .53608 .26419 L .53702 .26592 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.60783 .71191 m .57327 .72581 L .57192 .72914 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.53608 .73581 m .57192 .72914 L .57327 .72581 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.57327 .27419 m .60783 .28809 L .60658 .28345 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.60658 .28345 m .57192 .27086 L .57327 .27419 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.63983 .69272 m .60783 .71191 L .60658 .71655 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.57192 .72914 m .60658 .71655 L .60783 .71191 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.60783 .28809 m .63983 .30728 L .63911 .30177 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.63911 .30177 m .60658 .28345 L .60783 .28809 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.42999 .73078 m .46501 .73666 L .46325 .73495 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.46325 .73495 m .427 .72747 L .42999 .73078 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.427 .27253 m .46325 .26505 L .46501 .26334 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.63983 .30728 m .66846 .33131 L .66858 .32547 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.66858 .32547 m .63911 .30177 L .63983 .30728 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.66846 .66869 m .63983 .69272 L .63911 .69823 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.60658 .71655 m .63911 .69823 L .63983 .69272 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.66846 .33131 m .69297 .35961 L .69409 .35401 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.69409 .35401 m .66858 .32547 L .66846 .33131 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.69297 .64039 m .66846 .66869 L .66858 .67453 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.63911 .69823 m .66858 .67453 L .66846 .66869 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.57192 .72914 m .53608 .73581 L .53351 .73747 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.53608 .26419 m .57192 .27086 L .56728 .26762 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.56728 .26762 m .53351 .26253 L .53608 .26419 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.69297 .35961 m .71274 .39146 L .71485 .38667 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.71485 .38667 m .69409 .35401 L .69297 .35961 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.71274 .60854 m .69297 .64039 L .69409 .64599 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.66858 .67453 m .69409 .64599 L .69297 .64039 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.72724 .57394 m .71274 .60854 L .71485 .61333 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.69409 .64599 m .71485 .61333 L .71274 .60854 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.71274 .39146 m .72724 .42606 L .73019 .42257 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.73019 .42257 m .71485 .38667 L .71274 .39146 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.39589 .71886 m .42999 .73078 L .427 .72747 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.427 .72747 m .39219 .71423 L .39589 .71886 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.46501 .26334 m .42999 .26922 L .427 .27253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.39219 .28577 m .427 .27253 L .42999 .26922 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73609 .53744 m .72724 .57394 L .73019 .57743 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.71485 .61333 m .73019 .57743 L .72724 .57394 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.72724 .42606 m .73609 .46256 L .7396 .46071 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.7396 .46071 m .73019 .42257 L .72724 .42606 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.73609 .46256 m .73907 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.74277 .5 m .7396 .46071 L .73609 .46256 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.73907 .5 m .73609 .53744 L .7396 .53929 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73019 .57743 m .7396 .53929 L .73609 .53744 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.7396 .53929 m .74277 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.43626 .73392 m .46835 .73825 L .46501 .73666 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.46501 .73666 m .42999 .73078 L .43626 .73392 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.42999 .26922 m .46501 .26334 L .46835 .26175 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.36367 .701 m .39589 .71886 L .39219 .71423 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.39219 .71423 m .35974 .69546 L .36367 .701 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.42999 .26922 m .39589 .28114 L .39219 .28577 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.35974 .30454 m .39219 .28577 L .39589 .28114 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.53351 .73747 m .56728 .73238 L .57192 .72914 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56728 .73238 m .53351 .73747 L .52942 .73899 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.53351 .26253 m .56728 .26762 L .55944 .26462 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.55944 .26462 m .52942 .26101 L .53351 .26253 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.60658 .71655 m .57192 .72914 L .56728 .73238 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.57192 .27086 m .60658 .28345 L .60039 .27887 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.60039 .27887 m .56728 .26762 L .57192 .27086 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.44561 .73673 m .47316 .73967 L .46835 .73825 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.46835 .73825 m .43626 .73392 L .44561 .73673 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.43626 .26608 m .46835 .26175 L .47316 .26033 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.46835 .26175 m .43626 .26608 L .42999 .26922 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.3343 .67749 m .36367 .701 L .35974 .69546 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.35974 .69546 m .33053 .67158 L .3343 .67749 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.39589 .28114 m .36367 .299 L .35974 .30454 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.33053 .32842 m .35974 .30454 L .36367 .299 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.52942 .73899 m .55944 .73538 L .56728 .73238 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.55944 .73538 m .52942 .73899 L .52395 .74028 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.52942 .26101 m .55944 .26462 L .54866 .26204 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.54866 .26204 m .52395 .25972 L .52942 .26101 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.30873 .64885 m .3343 .67749 L .33053 .67158 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.33053 .67158 m .30538 .64316 L .30873 .64885 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.4577 .73906 m .47923 .74082 L .47316 .73967 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.47316 .73967 m .44561 .73673 L .4577 .73906 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.36367 .299 m .3343 .32251 L .33053 .32842 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.30538 .35684 m .33053 .32842 L .3343 .32251 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.44561 .26327 m .47316 .26033 L .47923 .25918 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.47316 .26033 m .44561 .26327 L .43626 .26608 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.40457 .72332 m .43626 .73392 L .42999 .73078 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.42999 .73078 m .39589 .71886 L .40457 .72332 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.39589 .28114 m .42999 .26922 L .43626 .26608 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.63911 .69823 m .60658 .71655 L .60039 .72113 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.56728 .73238 m .60039 .72113 L .60658 .71655 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.60658 .28345 m .63911 .30177 L .63189 .29627 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.63189 .29627 m .60039 .27887 L .60658 .28345 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.52395 .74028 m .54866 .73796 L .55944 .73538 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.54866 .73796 m .52395 .74028 L .51735 .74128 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.52395 .25972 m .54866 .26204 L .5354 .26001 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.5354 .26001 m .51735 .25872 L .52395 .25972 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.3343 .32251 m .30873 .35115 L .30538 .35684 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.28501 .38909 m .30538 .35684 L .30873 .35115 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.28783 .6158 m .30873 .64885 L .30538 .64316 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.30538 .64316 m .28501 .61091 L .28783 .6158 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47197 .74076 m .48628 .74166 L .47923 .74082 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47923 .74082 m .4577 .73906 L .47197 .74076 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.4577 .26094 m .47923 .25918 L .48628 .25834 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.47923 .25918 m .4577 .26094 L .44561 .26327 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.27233 .57924 m .28783 .6158 L .28501 .61091 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.28501 .61091 m .27002 .57566 L .27233 .57924 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.51735 .74128 m .5354 .73999 L .54866 .73796 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.5354 .73999 m .51735 .74128 L .50992 .74195 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.30873 .35115 m .28783 .3842 L .28501 .38909 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.27002 .42434 m .28501 .38909 L .28783 .3842 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.51735 .25872 m .5354 .26001 L .5203 .25865 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.5203 .25865 m .50992 .25805 L .51735 .25872 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.60039 .72113 m .56728 .73238 L .55944 .73538 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.56728 .26762 m .60039 .27887 L .58926 .27459 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.58926 .27459 m .55944 .26462 L .56728 .26762 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48771 .74174 m .494 .74214 L .48628 .74166 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48628 .74166 m .47197 .74076 L .48771 .74174 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.48628 .25834 m .47197 .25924 L .4577 .26094 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.47197 .25924 m .48628 .25834 L .494 .25786 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.28783 .3842 m .27233 .42076 L .27002 .42434 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.26084 .46165 m .27002 .42434 L .27233 .42076 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.2628 .54024 m .27233 .57924 L .27002 .57566 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.27002 .57566 m .26084 .53835 L .2628 .54024 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.50992 .74195 m .5203 .74135 L .5354 .73999 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.5203 .74135 m .50992 .74195 L .50201 .74224 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50992 .25805 m .5203 .25865 L .50411 .25806 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50411 .25806 m .50201 .25776 L .50992 .25805 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.60039 .72113 m .63189 .70373 L .63911 .69823 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.66858 .67453 m .63911 .69823 L .63189 .70373 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.63911 .30177 m .66858 .32547 L .66077 .31957 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66077 .31957 m .63189 .29627 L .63911 .30177 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.50411 .74194 m .50201 .74224 L .494 .74214 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.494 .74214 m .48771 .74174 L .50411 .74194 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.27233 .42076 m .2628 .45976 L .26084 .46165 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.25775 .5 m .26084 .46165 L .2628 .45976 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.25958 .5 m .2628 .54024 L .26084 .53835 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.26084 .53835 m .25775 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.48771 .25826 m .494 .25786 L .50201 .25776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.494 .25786 m .48771 .25826 L .47197 .25924 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.50201 .74224 m .50411 .74194 L .5203 .74135 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.50201 .25776 m .50411 .25806 L .48771 .25826 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.2628 .45976 m .25958 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.37424 .70639 m .40457 .72332 L .39589 .71886 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.39589 .71886 m .36367 .701 L .37424 .70639 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.43626 .26608 m .40457 .27668 L .39589 .28114 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36367 .299 m .39589 .28114 L .40457 .27668 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.41809 .72736 m .44561 .73673 L .43626 .73392 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.43626 .73392 m .40457 .72332 L .41809 .72736 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.40457 .27668 m .43626 .26608 L .44561 .26327 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.66858 .32547 m .69409 .35401 L .68605 .34829 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.68605 .34829 m .66077 .31957 L .66858 .32547 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.69409 .64599 m .66858 .67453 L .66077 .68043 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.63189 .70373 m .66077 .68043 L .66858 .67453 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.55944 .73538 m .58926 .72541 L .60039 .72113 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.58926 .72541 m .55944 .73538 L .54866 .73796 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.55944 .26462 m .58926 .27459 L .57348 .27086 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.57348 .27086 m .54866 .26204 L .55944 .26462 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.63189 .70373 m .60039 .72113 L .58926 .72541 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.60039 .27887 m .63189 .29627 L .61797 .29106 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.61797 .29106 m .58926 .27459 L .60039 .27887 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.69409 .35401 m .71485 .38667 L .70681 .38173 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.70681 .38173 m .68605 .34829 L .69409 .35401 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.71485 .61333 m .69409 .64599 L .68605 .65171 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.66077 .68043 m .68605 .65171 L .69409 .64599 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.34626 .68331 m .37424 .70639 L .36367 .701 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.36367 .701 m .3343 .67749 L .34626 .68331 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.40457 .27668 m .37424 .29361 L .36367 .299 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.3343 .32251 m .36367 .299 L .37424 .29361 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.43597 .73074 m .4577 .73906 L .44561 .73673 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.44561 .73673 m .41809 .72736 L .43597 .73074 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.41809 .27264 m .44561 .26327 L .4577 .26094 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.44561 .26327 m .41809 .27264 L .40457 .27668 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.73019 .57743 m .71485 .61333 L .70681 .61827 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.68605 .65171 m .70681 .61827 L .71485 .61333 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.71485 .38667 m .73019 .42257 L .72227 .41895 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.72227 .41895 m .70681 .38173 L .71485 .38667 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.54866 .73796 m .57348 .72914 L .58926 .72541 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.57348 .72914 m .54866 .73796 L .5354 .73999 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.54866 .26204 m .57348 .27086 L .55369 .26789 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.55369 .26789 m .5354 .26001 L .54866 .26204 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.7396 .53929 m .73019 .57743 L .72227 .58105 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.70681 .61827 m .72227 .58105 L .73019 .57743 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.73019 .42257 m .7396 .46071 L .7318 .4588 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.7318 .4588 m .72227 .41895 L .73019 .42257 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.39143 .71134 m .41809 .72736 L .40457 .72332 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.40457 .72332 m .37424 .70639 L .39143 .71134 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.37424 .29361 m .40457 .27668 L .41809 .27264 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.32164 .65452 m .34626 .68331 L .3343 .67749 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.3343 .67749 m .30873 .64885 L .32164 .65452 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.37424 .29361 m .34626 .31669 L .3343 .32251 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.30873 .35115 m .3343 .32251 L .34626 .31669 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.7396 .46071 m .74277 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.73502 .5 m .7318 .4588 L .7396 .46071 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.74277 .5 m .7396 .53929 L .7318 .5412 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.72227 .58105 m .7318 .5412 L .7396 .53929 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.7318 .5412 m .73502 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.45741 .73324 m .47197 .74076 L .4577 .73906 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.4577 .73906 m .43597 .73074 L .45741 .73324 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.43597 .26926 m .4577 .26094 L .47197 .25924 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.4577 .26094 m .43597 .26926 L .41809 .27264 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.66077 .68043 m .63189 .70373 L .61797 .70894 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.58926 .72541 m .61797 .70894 L .63189 .70373 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.63189 .29627 m .66077 .31957 L .64462 .31391 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.64462 .31391 m .61797 .29106 L .63189 .29627 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.5354 .73999 m .55369 .73211 L .57348 .72914 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.55369 .73211 m .5354 .73999 L .5203 .74135 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5354 .26001 m .55369 .26789 L .53087 .2659 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.53087 .2659 m .5203 .25865 L .5354 .26001 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.58926 .27459 m .61797 .29106 L .59764 .28646 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.59764 .28646 m .57348 .27086 L .58926 .27459 L p F P
.505 .664 .505 r
s
.42 .601 .443 r
.61797 .70894 m .58926 .72541 L .57348 .72914 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.48129 .73469 m .48771 .74174 L .47197 .74076 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.47197 .74076 m .45741 .73324 L .48129 .73469 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.45741 .26676 m .47197 .25924 L .48771 .25826 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.47197 .25924 m .45741 .26676 L .43597 .26926 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.34626 .31669 m .32164 .34548 L .30873 .35115 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.28783 .3842 m .30873 .35115 L .32164 .34548 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30132 .62071 m .32164 .65452 L .30873 .64885 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30873 .64885 m .28783 .6158 L .30132 .62071 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.5203 .74135 m .53087 .7341 L .55369 .73211 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.53087 .7341 m .5203 .74135 L .50411 .74194 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.5203 .25865 m .53087 .2659 L .50627 .26502 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.50627 .26502 m .50411 .25806 L .5203 .25865 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.50627 .73498 m .50411 .74194 L .48771 .74174 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.48771 .74174 m .48129 .73469 L .50627 .73498 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.48129 .26531 m .48771 .25826 L .50411 .25806 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.48771 .25826 m .48129 .26531 L .45741 .26676 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.50411 .74194 m .50627 .73498 L .53087 .7341 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.50411 .25806 m .50627 .26502 L .48129 .26531 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28614 .58285 m .30132 .62071 L .28783 .6158 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28783 .6158 m .27233 .57924 L .28614 .58285 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.32164 .34548 m .30132 .37929 L .28783 .3842 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.27233 .42076 m .28783 .3842 L .30132 .37929 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.36656 .68871 m .39143 .71134 L .37424 .70639 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.37424 .70639 m .34626 .68331 L .36656 .68871 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.41809 .27264 m .39143 .28866 L .37424 .29361 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.34626 .31669 m .37424 .29361 L .39143 .28866 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41472 .71552 m .43597 .73074 L .41809 .72736 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41809 .72736 m .39143 .71134 L .41472 .71552 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.39143 .28866 m .41809 .27264 L .43597 .26926 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.68605 .65171 m .66077 .68043 L .64462 .68609 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.61797 .70894 m .64462 .68609 L .66077 .68043 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66077 .31957 m .68605 .34829 L .66819 .34276 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66819 .34276 m .64462 .31391 L .66077 .31957 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27676 .54216 m .28614 .58285 L .27233 .57924 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27233 .57924 m .2628 .54024 L .27676 .54216 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.30132 .37929 m .28614 .41715 L .27233 .42076 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.2628 .45976 m .27233 .42076 L .28614 .41715 L p F P
.505 .664 .505 r
s
.42 .601 .443 r
.57348 .72914 m .59764 .71354 L .61797 .70894 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.59764 .71354 m .57348 .72914 L .55369 .73211 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57348 .27086 m .59764 .28646 L .57165 .28277 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57165 .28277 m .55369 .26789 L .57348 .27086 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.28614 .41715 m .27676 .45784 L .2628 .45976 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.25958 .5 m .2628 .45976 L .27676 .45784 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.27358 .5 m .27676 .54216 L .2628 .54024 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.2628 .54024 m .25958 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.27676 .45784 m .27358 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68605 .34829 m .70681 .38173 L .68772 .37692 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68772 .37692 m .66819 .34276 L .68605 .34829 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.70681 .61827 m .68605 .65171 L .66819 .65724 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.64462 .68609 m .66819 .65724 L .68605 .65171 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.64462 .68609 m .61797 .70894 L .59764 .71354 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.61797 .29106 m .64462 .31391 L .62029 .30886 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.62029 .30886 m .59764 .28646 L .61797 .29106 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.44307 .71864 m .45741 .73324 L .43597 .73074 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.43597 .73074 m .41472 .71552 L .44307 .71864 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.41472 .28448 m .43597 .26926 L .45741 .26676 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.43597 .26926 m .41472 .28448 L .39143 .28866 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34445 .65982 m .36656 .68871 L .34626 .68331 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34626 .68331 m .32164 .65452 L .34445 .65982 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.39143 .28866 m .36656 .31129 L .34626 .31669 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.32164 .34548 m .34626 .31669 L .36656 .31129 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.55369 .73211 m .57165 .71723 L .59764 .71354 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.57165 .71723 m .55369 .73211 L .53087 .7341 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.55369 .26789 m .57165 .28277 L .54132 .28027 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.54132 .28027 m .53087 .2659 L .55369 .26789 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.72227 .58105 m .70681 .61827 L .68772 .62308 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.66819 .65724 m .68772 .62308 L .70681 .61827 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70681 .38173 m .72227 .41895 L .70237 .41539 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70237 .41539 m .68772 .37692 L .70681 .38173 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39471 .69332 m .41472 .71552 L .39143 .71134 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39143 .71134 m .36656 .68871 L .39471 .69332 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.36656 .31129 m .39143 .28866 L .41472 .28448 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.47494 .72046 m .48129 .73469 L .45741 .73324 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.45741 .73324 m .44307 .71864 L .47494 .72046 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.44307 .28136 m .45741 .26676 L .48129 .26531 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.45741 .26676 m .44307 .28136 L .41472 .28448 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.7318 .5412 m .72227 .58105 L .70237 .58461 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.68772 .62308 m .70237 .58461 L .72227 .58105 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.72227 .41895 m .7318 .4588 L .71144 .45691 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.71144 .45691 m .70237 .41539 L .72227 .41895 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.53087 .7341 m .54132 .71973 L .57165 .71723 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.54132 .71973 m .53087 .7341 L .50627 .73498 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.53087 .2659 m .54132 .28027 L .5084 .27916 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.5084 .27916 m .50627 .26502 L .53087 .2659 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.36656 .31129 m .34445 .34018 L .32164 .34548 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.30132 .37929 m .32164 .34548 L .34445 .34018 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32606 .62534 m .34445 .65982 L .32164 .65452 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32164 .65452 m .30132 .62071 L .32606 .62534 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64462 .31391 m .66819 .34276 L .64051 .33778 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64051 .33778 m .62029 .30886 L .64462 .31391 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.66819 .65724 m .64462 .68609 L .62029 .69114 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.59764 .71354 m .62029 .69114 L .64462 .68609 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.5084 .72084 m .50627 .73498 L .48129 .73469 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.48129 .73469 m .47494 .72046 L .5084 .72084 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.47494 .27954 m .48129 .26531 L .50627 .26502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.48129 .26531 m .47494 .27954 L .44307 .28136 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.7318 .4588 m .73502 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.71452 .5 m .71144 .45691 L .7318 .4588 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.73502 .5 m .7318 .5412 L .71144 .54309 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.70237 .58461 m .71144 .54309 L .7318 .5412 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.50627 .73498 m .5084 .72084 L .54132 .71973 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.50627 .26502 m .5084 .27916 L .47494 .27954 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.71144 .54309 m .71452 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.62029 .69114 m .59764 .71354 L .57165 .71723 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.59764 .28646 m .62029 .30886 L .58863 .30478 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.58863 .30478 m .57165 .28277 L .59764 .28646 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.34445 .34018 m .32606 .37466 L .30132 .37929 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.28614 .41715 m .30132 .37929 L .32606 .37466 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.31222 .58629 m .32606 .62534 L .30132 .62071 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.30132 .62071 m .28614 .58285 L .31222 .58629 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.42948 .69679 m .44307 .71864 L .41472 .71552 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.41472 .71552 m .39471 .69332 L .42948 .69679 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.39471 .30668 m .41472 .28448 L .44307 .28136 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.41472 .28448 m .39471 .30668 L .36656 .31129 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.37677 .66439 m .39471 .69332 L .36656 .68871 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.36656 .68871 m .34445 .65982 L .37677 .66439 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.34445 .34018 m .36656 .31129 L .39471 .30668 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.66819 .34276 m .68772 .37692 L .65741 .37255 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.65741 .37255 m .64051 .33778 L .66819 .34276 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.68772 .62308 m .66819 .65724 L .64051 .66222 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.62029 .69114 m .64051 .66222 L .66819 .65724 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.32606 .37466 m .31222 .41371 L .28614 .41715 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.27676 .45784 m .28614 .41715 L .31222 .41371 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.30362 .54399 m .31222 .58629 L .28614 .58285 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.28614 .58285 m .27676 .54216 L .30362 .54399 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.57165 .71723 m .58863 .69522 L .62029 .69114 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.58863 .69522 m .57165 .71723 L .54132 .71973 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.57165 .28277 m .58863 .30478 L .55125 .302 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.55125 .302 m .54132 .28027 L .57165 .28277 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.31222 .41371 m .30362 .45601 L .27676 .45784 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.27358 .5 m .27676 .45784 L .30362 .45601 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.3007 .5 m .30362 .54399 L .27676 .54216 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.27676 .54216 m .27358 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.30362 .45601 m .3007 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.4689 .69883 m .47494 .72046 L .44307 .71864 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.44307 .71864 m .42948 .69679 L .4689 .69883 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.42948 .30321 m .44307 .28136 L .47494 .27954 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.44307 .28136 m .42948 .30321 L .39471 .30668 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.64051 .66222 m .62029 .69114 L .58863 .69522 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.62029 .30886 m .64051 .33778 L .60391 .33372 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.60391 .33372 m .58863 .30478 L .62029 .30886 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.68772 .37692 m .70237 .41539 L .67017 .41214 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.67017 .41214 m .65741 .37255 L .68772 .37692 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.70237 .58461 m .68772 .62308 L .65741 .62745 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.64051 .66222 m .65741 .62745 L .68772 .62308 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.54132 .71973 m .55125 .698 L .58863 .69522 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.55125 .698 m .54132 .71973 L .5084 .72084 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.54132 .28027 m .55125 .302 L .51043 .30076 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.51043 .30076 m .5084 .27916 L .54132 .28027 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.39471 .30668 m .37677 .33561 L .34445 .34018 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.32606 .37466 m .34445 .34018 L .37677 .33561 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.36172 .62936 m .37677 .66439 L .34445 .65982 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.34445 .65982 m .32606 .62534 L .36172 .62936 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.51043 .69924 m .5084 .72084 L .47494 .72046 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.47494 .72046 m .4689 .69883 L .51043 .69924 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.4689 .30117 m .47494 .27954 L .5084 .27916 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.47494 .27954 m .4689 .30117 L .42948 .30321 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70308 .40705 m
.70337 .40511 L
s
.70165 .40287 m
.70337 .40511 L
s
.5 Mabswid
.622 .846 .63 r
.5084 .72084 m .51043 .69924 L .55125 .698 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.5084 .27916 m .51043 .30076 L .4689 .30117 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70136 .40481 m
.70165 .40287 L
s
.70136 .40481 m
.70308 .40705 L
s
.5 Mabswid
.355 .416 .306 r
.37677 .33561 m .39471 .30668 L .42948 .30321 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.41721 .66786 m .42948 .69679 L .39471 .69332 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.39471 .69332 m .37677 .66439 L .41721 .66786 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.71144 .54309 m .70237 .58461 L .67017 .58786 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.65741 .62745 m .67017 .58786 L .70237 .58461 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.70237 .41539 m .71144 .45691 L .67811 .45518 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.67811 .45518 m .67017 .41214 L .70237 .41539 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.70632 .41745 m
.71303 .44587 L
s
.5 Mabswid
.448 .568 .386 r
.71144 .45691 m .71452 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.6808 .5 m .67811 .45518 L .71144 .45691 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.71452 .5 m .71144 .54309 L .67811 .54482 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.67017 .58786 m .67811 .54482 L .71144 .54309 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.64051 .33778 m .65741 .37255 L .61675 .36896 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.61675 .36896 m .60391 .33372 L .64051 .33778 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.65741 .62745 m .64051 .66222 L .60391 .66628 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.58863 .69522 m .60391 .66628 L .64051 .66222 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.67811 .54482 m .6808 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.60391 .66628 m .58863 .69522 L .55125 .698 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.35034 .58928 m .36172 .62936 L .32606 .62534 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.32606 .62534 m .31222 .58629 L .35034 .58928 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.58863 .30478 m .60391 .33372 L .56023 .33093 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.56023 .33093 m .55125 .302 L .58863 .30478 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.37677 .33561 m .36172 .37064 L .32606 .37466 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.31222 .41371 m .32606 .37466 L .36172 .37064 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69253 .40361 m
.69504 .40798 L
s
.69504 .40798 m
.69569 .41009 L
s
.69569 .41009 m
.69574 .41415 L
s
.68821 .40105 m
.69253 .40361 L
s
.6939 .41599 m
.69574 .41415 L
s
.6995 .42874 m
.69971 .42472 L
s
.68443 .40061 m
.68821 .40105 L
s
.5 Mabswid
.652 .874 .659 r
.46342 .6699 m .4689 .69883 L .42948 .69679 L p F P
.505 .664 .505 r
s
.652 .874 .659 r
.42948 .69679 m .41721 .66786 L .46342 .6699 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.41721 .33214 m .42948 .30321 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.42948 .30321 m .41721 .33214 L .37677 .33561 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69624 .43048 m
.6995 .42874 L
s
.68803 .41747 m
.6939 .41599 L
s
.5 Mabswid
.592 .774 .593 r
.34324 .54559 m .35034 .58928 L .31222 .58629 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.31222 .58629 m .30362 .54399 L .34324 .54559 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.36172 .37064 m .35034 .41072 L .31222 .41371 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.30362 .45601 m .31222 .41371 L .35034 .41072 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68114 .40232 m
.68443 .40061 L
s
.5 Mabswid
.433 .526 .39 r
.36172 .37064 m .37677 .33561 L .41721 .33214 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.40686 .63243 m .41721 .66786 L .37677 .66439 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.37677 .66439 m .36172 .62936 L .40686 .63243 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.55125 .698 m .56023 .66907 L .60391 .66628 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.56023 .66907 m .55125 .698 L .51043 .69924 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.55125 .302 m .56023 .33093 L .51227 .32969 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.51227 .32969 m .51043 .30076 L .55125 .302 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.69233 .43015 m
.69624 .43048 L
s
.5 Mabswid
.585 .769 .551 r
.67017 .58786 m .65741 .62745 L .61675 .63104 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.60391 .66628 m .61675 .63104 L .65741 .62745 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.65741 .37255 m .67017 .41214 L .6265 .40946 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.6265 .40946 m .61675 .36896 L .65741 .37255 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68106 .40646 m
.68114 .40232 L
s
.68585 .41934 m
.68803 .41747 L
s
.5 Mabswid
.654 .876 .654 r
.51227 .67031 m .51043 .69924 L .4689 .69883 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.4689 .69883 m .46342 .6699 L .51227 .67031 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.46342 .3301 m .4689 .30117 L .51043 .30076 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.4689 .30117 m .46342 .3301 L .41721 .33214 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.35034 .41072 m .34324 .45441 L .30362 .45601 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.3007 .5 m .30362 .45601 L .34324 .45441 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.34082 .5 m .34324 .54559 L .30362 .54399 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.30362 .54399 m .3007 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6878 .42775 m
.69233 .43015 L
s
.5 Mabswid
.645 .864 .639 r
.51043 .69924 m .51227 .67031 L .56023 .66907 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.51043 .30076 m .51227 .32969 L .46342 .3301 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.34324 .45441 m .34082 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.68546 .42344 m
.68585 .41934 L
s
.68546 .42344 m
.6878 .42775 L
s
.5 Mabswid
.425 .514 .356 r
.60391 .33372 m .61675 .36896 L .56782 .36649 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.56782 .36649 m .56023 .33093 L .60391 .33372 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.61675 .63104 m .60391 .66628 L .56023 .66907 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.67811 .54482 m .67017 .58786 L .6265 .59054 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.61675 .63104 m .6265 .59054 L .67017 .58786 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.67017 .41214 m .67811 .45518 L .63259 .45374 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.63259 .45374 m .6265 .40946 L .67017 .41214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66914 .39906 m
.6765 .42902 L
s
.6652 .40083 m
.67156 .40769 L
s
.5 Mabswid
.638 .839 .635 r
.39899 .59158 m .40686 .63243 L .36172 .62936 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.36172 .62936 m .35034 .58928 L .39899 .59158 L p F P
.505 .664 .505 r
s
.433 .526 .39 r
.41721 .33214 m .40686 .36757 L .36172 .37064 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.35034 .41072 m .36172 .37064 L .40686 .36757 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66147 .3984 m
.6652 .40083 L
s
.5 Mabswid
.459 .56 .408 r
.40686 .36757 m .41721 .33214 L .46342 .3301 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.45878 .63424 m .46342 .6699 L .41721 .66786 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.41721 .66786 m .40686 .63243 L .45878 .63424 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65666 .39802 m
.66147 .3984 L
s
.5 Mabswid
.518 .658 .461 r
.67811 .45518 m .6808 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.63466 .5 m .63259 .45374 L .67811 .45518 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.6808 .5 m .67811 .54482 L .63259 .54626 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.6265 .59054 m .63259 .54626 L .67811 .54482 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65394 .39995 m
.65666 .39802 L
s
.5 Mabswid
.548 .705 .498 r
.63259 .54626 m .63466 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.56023 .66907 m .56782 .63351 L .61675 .63104 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.56023 .33093 m .56782 .36649 L .51383 .36538 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.51383 .36538 m .51227 .32969 L .56023 .33093 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.56782 .63351 m .56023 .66907 L .51227 .67031 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6539 .40637 m
.65394 .39995 L
s
.6539 .40637 m
.6584 .42798 L
s
.5 Mabswid
.621 .815 .591 r
.6265 .59054 m .61675 .63104 L .56782 .63351 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.61675 .36896 m .6265 .40946 L .57359 .40761 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.57359 .40761 m .56782 .36649 L .61675 .36896 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.39407 .54682 m .39899 .59158 L .35034 .58928 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.35034 .58928 m .34324 .54559 L .39407 .54682 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.40686 .36757 m .39899 .40842 L .35034 .41072 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.34324 .45441 m .35034 .41072 L .39899 .40842 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.45878 .36576 m .46342 .3301 L .51227 .32969 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.51383 .63462 m .51227 .67031 L .46342 .6699 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.46342 .6699 m .45878 .63424 L .51383 .63462 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.46342 .3301 m .45878 .36576 L .40686 .36757 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.51227 .67031 m .51383 .63462 L .56782 .63351 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.51227 .32969 m .51383 .36538 L .45878 .36576 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.63774 .3967 m
.64388 .42728 L
s
.5 Mabswid
.538 .678 .507 r
.39899 .40842 m .39407 .45318 L .34324 .45441 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.34082 .5 m .34324 .45441 L .39407 .45318 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.3924 .5 m .39407 .54682 L .34324 .54559 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.34324 .54559 m .34082 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.45525 .59294 m .45878 .63424 L .40686 .63243 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.40686 .63243 m .39899 .59158 L .45525 .59294 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.39899 .40842 m .40686 .36757 L .45878 .36576 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.39407 .45318 m .3924 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.63259 .54626 m .6265 .59054 L .57359 .59239 L p F P
.505 .664 .505 r
s
.621 .815 .591 r
.56782 .63351 m .57359 .59239 L .6265 .59054 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.6265 .40946 m .63259 .45374 L .57721 .45275 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.57721 .45275 m .57359 .40761 L .6265 .40946 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.62279 .39584 m
.62698 .41792 L
s
.64629 .44433 m
.64793 .44229 L
s
.64576 .44011 m
.64793 .44229 L
s
.64412 .44216 m
.64576 .44011 L
s
.64412 .44216 m
.64629 .44433 L
s
.5 Mabswid
.641 .84 .615 r
.57359 .59239 m .56782 .63351 L .51383 .63462 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.56782 .36649 m .57359 .40761 L .51502 .40678 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.51502 .40678 m .51383 .36538 L .56782 .36649 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.62599 .4244 m
.62698 .41792 L
s
.62223 .42643 m
.62599 .4244 L
s
.5 Mabswid
.65 .852 .63 r
.51502 .59322 m .51383 .63462 L .45878 .63424 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.45878 .63424 m .45525 .59294 L .51502 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.45525 .40706 m .45878 .36576 L .51383 .36538 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.45878 .36576 m .45525 .40706 L .39899 .40842 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.63259 .45374 m .63466 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.57845 .5 m .57721 .45275 L .63259 .45374 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.63466 .5 m .63259 .54626 L .57721 .54725 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.57359 .59239 m .57721 .54725 L .63259 .54626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.6008 .39482 m
.60538 .4259 L
s
.61601 .42622 m
.62223 .42643 L
s
.5 Mabswid
.555 .7 .516 r
.39407 .45318 m .39899 .40842 L .45525 .40706 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.38995 .39522 m
.3965 .42309 L
s
.5 Mabswid
.635 .825 .615 r
.45304 .54755 m .45525 .59294 L .39899 .59158 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.39899 .59158 m .39407 .54682 L .45304 .54755 L p F P
.505 .664 .505 r
s
.641 .84 .615 r
.51383 .63462 m .51502 .59322 L .57359 .59239 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.51383 .36538 m .51502 .40678 L .45525 .40706 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.57721 .54725 m .57845 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.39344 .41055 m
.41504 .40986 L
s
.61152 .4239 m
.61601 .42622 L
s
.60426 .41709 m
.61152 .4239 L
s
.57986 .39631 m
.58484 .40093 L
s
.57517 .39393 m
.57986 .39631 L
s
.58484 .40093 m
.58792 .40772 L
s
.56854 .39375 m
.57517 .39393 L
s
.58792 .40772 m
.58848 .41219 L
s
.56434 .3959 m
.56854 .39375 L
s
.5 Mabswid
.548 .69 .496 r
.57359 .40761 m .57721 .45275 L .51576 .4523 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.51576 .4523 m .51502 .40678 L .57359 .40761 L p F P
.505 .664 .505 r
s
.626 .813 .593 r
.57721 .54725 m .57359 .59239 L .51502 .59322 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.58703 .4188 m
.58848 .41219 L
s
.5 Mabswid
.555 .7 .516 r
.45525 .40706 m .45304 .45245 L .39407 .45318 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.40069 .44094 m
.40547 .43116 L
s
.40547 .43116 m
.42366 .39397 L
s
.42939 .42509 m
.43455 .37798 L
s
.3965 .42309 m
.40069 .44094 L
s
.5 Mabswid
.588 .75 .555 r
.3924 .5 m .39407 .45318 L .45304 .45245 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.45228 .5 m .45304 .54755 L .39407 .54682 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.39407 .54682 m .3924 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.56028 .4003 m
.56434 .3959 L
s
.43172 .40048 m
.43671 .39587 L
s
.43671 .39587 m
.44146 .39351 L
s
.44146 .39351 m
.44826 .39337 L
s
.58298 .42313 m
.58703 .4188 L
s
.44826 .39337 m
.45264 .39555 L
s
.55861 .40702 m
.56028 .4003 L
s
.5 Mabswid
.588 .75 .555 r
.45304 .45245 m .45228 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.45264 .39555 m
.45692 .4 L
s
.54136 .39319 m
.54372 .43607 L
s
.54372 .43607 m
.54394 .44014 L
s
.57862 .42525 m
.58298 .42313 L
s
.5 Mabswid
.558 .703 .512 r
.45304 .45245 m .45525 .40706 L .51502 .40678 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.51576 .5477 m .51502 .59322 L .45525 .59294 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.45525 .59294 m .45304 .54755 L .51576 .5477 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.55861 .40702 m
.55898 .41151 L
s
.52281 .39298 m
.5239 .4291 L
s
.5239 .4291 m
.52423 .44001 L
s
.45692 .4 m
.45882 .40674 L
s
.57169 .42511 m
.57862 .42525 L
s
.48764 .39291 m
.49468 .39289 L
s
.48289 .3952 m
.48764 .39291 L
s
.42995 .41842 m
.43423 .42279 L
s
.49468 .39289 m
.49937 .39515 L
s
.55898 .41151 m
.56185 .41827 L
s
.47803 .39977 m
.48289 .3952 L
s
.49937 .39515 m
.50412 .39969 L
s
.56686 .42281 m
.57169 .42511 L
s
.5 Mabswid
.626 .813 .593 r
.51502 .59322 m .51576 .5477 L .57721 .54725 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.51502 .40678 m .51576 .4523 L .45304 .45245 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.47542 .40657 m
.47803 .39977 L
s
.56185 .41827 m
.56686 .42281 L
s
.45855 .41125 m
.45882 .40674 L
s
.43423 .42279 m
.43876 .42494 L
s
.50412 .39969 m
.50656 .40649 L
s
.5 Mabswid
.58 .739 .534 r
.57721 .45275 m .57845 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.51602 .5 m .51576 .4523 L .57721 .45275 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.57845 .5 m .57721 .54725 L .51576 .5477 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.4558 .41802 m
.45855 .41125 L
s
.43876 .42494 m
.44587 .42483 L
s
.47526 .41109 m
.47542 .40657 L
s
.50656 .40649 m
.5066 .411 L
s
.45077 .42255 m
.4558 .41802 L
s
.44587 .42483 m
.45077 .42255 L
s
.47526 .41109 m
.47746 .41782 L
s
.50422 .41776 m
.5066 .411 L
s
.5 Mabswid
.606 .779 .566 r
.51576 .5477 m .51602 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.47746 .41782 m
.48222 .42228 L
s
.49935 .42224 m
.50422 .41776 L
s
.48222 .42228 m
.48707 .42449 L
s
.5 Mabswid
.589 .751 .55 r
.45228 .5 m .45304 .45245 L .51576 .4523 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.51602 .5 m .51576 .5477 L .45304 .54755 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.45304 .54755 m .45228 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.49443 .42448 m
.49935 .42224 L
s
.48707 .42449 m
.49443 .42448 L
s
.5 Mabswid
.589 .751 .55 r
.51576 .4523 m .51602 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>l0/>3V4P21ZH7b0;3PiP40oooo003X0;3PiPP0PJV10P0S9A`0
0`21ZH409BLN02DW7P0602DW7P04086YP@0U9ah09BLN02DW7Pl0PJV1i@2`h>H10?ooo`00hP2`h>H6
086YP@0301hQ6@21ZH40PJV100H08bDL00<0PJV102DW7P0U9ah01`0U9ah00`21ZH409BLN02DW7P06
02DW7P80PJV11`0R9A`6086YPN00/>3V0@3oool00=`0/>3V1`21ZH4401hQ6@80PJV1200S9A`00`21
ZH409BLN02DW7P0802DW7P03086YP@0U9ah09BLN00L09BLN0P21ZH47028U7080PJV10P0M8AT3086Y
PMd0/>3V0@3oool00=P0/>3V1@21ZH400`0G6a@0PJV1086YP@0501hQ6@80PJV1100S9A`S086YP@<0
8RDL0P21ZH4201dQ6@@0PJV1fP2`h>H10?ooo`00eP2`h>H4086YP@0301LK5021ZH40PJV100807R4I
3021ZH4403@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=3HX
03@f:00203@f:0T0PJV100<07B4I086YP@21ZH400`21ZH7F0;3PiP40oooo003C0;3PiP`0PJV1100_
<BD00`21ZH40=3HX03@f:00903@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02`0g
>2/00`21ZH40=3HX03@f:00803@f:003086YP@0^<2D0PJV100L0PJV1e02`h>H10?ooo`00d02`h>H9
086YP@T0;c4U00<0PJV103@f:00d=RP02@0d=RP00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0g>2/0
=cP[00`0=cP[00<0PJV103@f:00d=RP0200d=RP00`21ZH40;S0U02h`9@0302h`9@H0PJV1d@2`h>H1
0?ooo`00cP2`h>H5086YP@<09RTO00<0PJV102la9@0_<BD0200_<BD00`21ZH40=3HX03@f:00:03@f
:003086YP@0g>2/0=cP[00`0=cP[00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=3HX03@f:00903@f
:003086YP@0^<2D0;S0U00D0;S0U1P21ZH7>0;3PiP40oooo003;0;3PiPD0PJV1100V:Al2086YP@X0
;c4U00<0PJV103@f:00d=RP02P0d=RP00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0g>2/0=cP[00`0
=cP[00<0PJV103@f:00d=RP02@0d=RP2086YP@L0;S0U0P21ZH400`0V:1h0PJV1086YP@02086YPL/0
/>3V0@3oool00<T0/>3V0P21ZH400`0K7QL0PJV1086YP@0402HY7`80PJV12`0_<BD00`21ZH40=3HX
03@f:00;03@f:003086YP@0g>2/0=cP[00d0=cP[00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=3HX
03@f:00:03@f:003086YP@0^<2D0;S0U00H0;S0U00@0PJV102HX7P0V:1h09RPN0`21ZH790;3PiP40
oooo00370;3PiP80PJV10P0K7QL00`21ZH409RTO02HY7`0302HY7`03086YP@0_<BD0;c4U00X0;c4U
00<0PJV103@f:00d=RP0100d=RP]086YP@T0=3HX00<0PJV102h`9@0^<2D01P0^<2D2086YP@<09RPN
0`21ZH770;3PiP40oooo00350;3PiP80PJV10P0K7QL2086YP@@09RTO0P21ZH4502la9@l0PJV11`1:
DSX00`21ZH40CUPn04iH?P0>04iH?P03086YP@1>F3h0CUPn00h0CUPn00@0PJV104YB>`1:DS/0BU8k
2021ZH4203@f:003086YP@0^<2D0;S0U00L0;S0U0P21ZH4302HX7P<0PJV1a@2`h>H10?ooo`00``2`
h>H2086YP@<06ahG00<0PJV102HY7`0V:Al00P0V:Al9086YP@H0@DHc00<0PJV104YB>P1:DSX0301:
DSX00`21ZH40CUPn04iH?P0?04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0201:
DS/:086YP@@0;S0U0P21ZH4302HX7P<0PJV1``2`h>H10?ooo`00`@2`h>H2086YP@<06ahG0P21ZH40
0`0V:Al0PJV1086YP@03086YP@h0@DHc00<0PJV104YB>P1:DSX0301:DSX00`21ZH40CUPn04iH?P0?
04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`03
0456<`P0PJV10P0V:1h4086YPL40/>3V0@3oool00;l0/>3V0P21ZH4301/N5`D0PJV10`0b=2L00`21
ZH40@DHc0456<`0<0456<`03086YP@1:DSX0BU8j00d0BU8j00<0PJV104iH?P1>F3h03`1>F3h00`21
ZH40CUPn04iH?P0@04iH?P03086YP@1:DS/0BU8k00/0BU8k00<0PJV10456<`11AS<02P11AS<4086Y
P@0302HX7P21ZH40PJV10080PJV1_`2`h>H10?ooo`00_@2`h>H2086YP@806ahG1021ZH46038d9`03
086YP@11AS<0@DHc00`0@DHc00<0PJV104YB>P1:DSX03P1:DSX00`21ZH40CUPn04iH?P0?04iH?P03
086YP@1>F3h0CUPn0100CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`0:0456<`03
086YP@0b=2L0<S@W00L0PJV1_@2`h>H10?ooo`00^`2`h>H6086YP@0302DX7P21ZH40<S@W00L0<S@W
00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0=04YB>P03086YP@1>F3h0CUPn0140CUPn
00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0<04YB>`03086YP@11AS<0@DHc00X0@DHc
00<0PJV1038d9`0b=2L00`0b=2L5086YPK/0/>3V0@3oool00;X0/>3V0`21ZH4402DX7P03086YP@0b
=2L0<S@W00H0<S@W00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0>04YB>P03086YP@1>
F3h0CUPn0140CUPn00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0=04YB>`03086YP@11
AS<0@DHc00X0@DHc00<0PJV1038d9`0b=2L0100b=2L5086YPKT0/>3V0@3oool00;P0/>3V0P21ZH45
02DX7P80PJV1200b=2L00`21ZH40@DHc0456<`0=0456<`03086YP@1:DSX0BU8j00h0BU8j00<0PJV1
04iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A04iH?P03086YP@1:DS/0BU8k00`0BU8k00<0PJV1
0456<`11AS<02`11AS<00`21ZH40<S@W038d9`04038d9`04086YP@0T9ah092LN02@W7P80PJV1]`2`
h>H10?ooo`00]P2`h>H3086YP@D09BPN00<0PJV1038d9`0b=2L01`0b=2L00`21ZH40@DHc0456<`0=
0456<`03086YP@1:DSX0BU8j00l0BU8j00<0PJV104iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A
04iH?P03086YP@1:DS/0BU8k00d0BU8k00<0PJV10456<`11AS<02P11AS<00`21ZH40<S@W038d9`05
038d9`80PJV10`0T9ah00`21ZH40/>3V0;3PiP2d0;3PiP40oooo002e0;3PiP<0PJV11@0U:1h00`21
ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc00d0@DHc00<0PJV104YB>P1:DSX03`1:DSX00`21
ZH40CUPn04iH?P0B04iH?P03086YP@1>F3h0CUPn0180CUPn00<0PJV104YB>`1:DS/03@1:DS/00`21
ZH40@DHc0456<`0:0456<`03086YP@0b=2L0<S@W00H0<S@W00D0PJV102@W7P0T9ah092LN086YP@2e
0;3PiP40oooo002c0;3PiP<0PJV11P0U:1h00`21ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc
00h0@DHc00<0PJV104YB>P1:DSX01P1:DSXh086YP@`0BU8k00<0PJV10456<`11AS<02P11AS<00`21
ZH40<S@W038d9`06038d9`04086YP@0T9ah092LN02@W7P80PJV1/`2`h>H10?ooo`00/P2`h>H00`21
ZH4051PB086YP@0602DX7P03086YP@0b=2L0<S@W00P0<S@W00<0PJV10456<`11AS<02@11AS<>086Y
P@T0HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00B065cD003086YP@1KJdX0Ff]:
0080Ff]:2@21ZH4304YB>`03086YP@11AS<0@DHc00/0@DHc00<0PJV1038d9`0b=2L01P0b=2L00`21
ZH4092LN02@W7P0202@W7P03086YP@2`h>H0/>3V0;00/>3V0@3oool00;40/>3V00<0PJV101@H4P21
ZH401@0U:1h2086YP@X0<S@W00@0PJV10456<`11AS<0@DHc2@21ZH4405YZCP03086YP@1RM5@0HWAD
0100HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:
00X0Ff]:2021ZH4:0456<`03086YP@0b=2L0<S@W00H0<S@W00<0PJV102@W7P0T9ah00P0T9ah00`21
ZH40/>3V0;3PiP2_0;3PiP40oooo002_0;3PiP04086YP@0D618051PB086YP@D09BPN00<0PJV1038d
9`0b=2L01P0b=2L8086YP@`0FVY>00<0PJV1069dE01RM5@04@1RM5@00`21ZH40I7MD06AgE00B06Ag
E003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX03`1KJdX00`21ZH40Df1305=P@`08086Y
P@<0@DHc00<0PJV1038d9`0b=2L01P0b=2L2086YP@<092LN00<0PJV10;3PiP2`h>H0[P2`h>H10?oo
o`00[P2`h>H01021ZH4051PB01@H4P21ZH4502DX7P03086YP@0b=2L0<S@W00L0PJV10P1;ET400`21
ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0100HWAD00<0PJV106AgE01TMe@04`1TMe@00`21
ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:00l0Ff]:00<0PJV105=P@`1CH4<0201CH4<7086Y
P@L0<S@W00D0PJV102@W7P0T9ah092LN086YP@2_0;3PiP40oooo002]0;3PiP04086YP@0D6180PJV1
086YP@@09BPN1@21ZH4904]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1069dE01RM5@04@1RM5@0
0`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX0401KJdX0
0`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0PJV100D0PJV10P0b=2L01@21ZH4092LN02@W7P0T
9ah0PJV10:h0/>3V0@3oool00:/0/>3V00@0PJV101@H4P0D6180PJV10`0U:1h4086YP@`0BeI100<0
PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD069dE00A069dE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0?05][BP03086YP@1CH4<0Df1300`0Df1300<0
PJV104A<=P14C3H01@14C3H5086YP@8092LN0P21ZH6/0;3PiP40oooo002Z0;3PiP03086YP@0D6180
51PB00D0PJV10P0b=R/00`21ZH40BeI104]F@@0;04]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1
069dE01RM5@04P1RM5@00`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV1
05][BP1KJdX0401KJdX00`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0A4`f00P0A4`f0`21ZH42
02@W7P03086YP@2`h>H0/>3V0:T0/>3V0@3oool00:T0/>3V0P0D6183086YP@H0<SH[00<0PJV104]F
@@1;ET402P1;ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0180HWAD00<0PJV106Ag
E01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:0100Ff]:00<0PJV105=P
@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0PJV100<0PJV1ZP2`h>H10?oo
o`00Y`2`h>H5086YP@L0<SH[00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0?05YZCP03
086YP@1RM5@0HWAD0180HWAD00<0PJV106AgE01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003
086YP@1KJdX0Ff]:0140Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0704A<=P03
086YP@0];b@0;BlT0080;BlT0P21ZH6Y0;3PiP40oooo002V0;3PiP80PJV10P0K7aL00`21ZH40<SH[
038f:`05038f:`03086YP@1;ET40BeI100/0BeI100<0PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD
069dE00C069dE003086YP@1TMe@0I7MD01@0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:
05][BP0A05][BP03086YP@1CH4<0Df1300`0Df1300<0PJV104A<=P14C3H02014C3H00`21ZH40;BlT
02d_900302d_9080PJV1Y`2`h>H10?ooo`00Y@2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[
00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0@05YZCP03086YP@1RM5@0HWAD0180HWAD
00<0PJV106AgE01TMe@05@1TMe@00`21ZH40HG=@065cD00D065cD003086YP@1KJdX0Ff]:0140Ff]:
00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00<0;BlT
0P21ZH6V0;3PiP40oooo002T0;3PiP03086YP@0K7aL06alG00806alG00<0PJV1038f:`0b=R/0100b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00l0FVY>00<0PJV1069dE01RM5@04`1R
M5@00`21ZH40I7MD06AgE00E06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV105][BP1KJdX04P1K
JdX00`21ZH40Df1305=P@`0=05=P@`03086YP@14C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0]
;b@2086YPJD0/>3V0@3oool00:@0/>3V00D0PJV101/O5`0K7aL06alG086YP@07038f:`03086YP@1;
ET40BeI100/0BeI100<0PJV105YZCP1JJTh0401JJTh00`21ZH40HWAD069dE00C069dE003086YP@1T
Me@0I7MD01D0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0B05][BP03086YP@1C
H4<0Df1300d0Df1300<0PJV104A<=P14C3H02@14C3H00`21ZH40;BlT02d_900302d_9080PJV1Y02`
h>H10?ooo`00X`2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[00<0PJV104]F@@1;ET40301;
ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD00T0HWAD;`21ZH4<065cD003086YP@1K
JdX0Ff]:0180Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0]
;b@0;BlT00@0;BlT0P21ZH6S0;3PiP40oooo002R0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00`0FVY>4021ZH4;07F?J003086YP@1g
TFP0Mi5X01D0Mi5X00<0PJV107B=I01dSF@02@1dSF@G086YP@X0Ff]:00<0PJV105=P@`1CH4<03P1C
H4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00@0;BlT0P21ZH6R0;3PiP40oooo002Q
0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b=R/00`21ZH40BeI104]F@@0=04]F@@03086YP@1J
JTh0FVY>0080FVY>2P21ZH4406j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05@1g
TFP00`21ZH40M8eT07B=I00E07B=I003086YP@1/Pe/0K8=K00P0K8=K4021ZH4<05=P@`03086YP@14
C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2Q0;3PiP40oooo002P
0;3PiP05086YP@0K7aL06alG01/O5`21ZH40200b=R/00`21ZH40BeI104]F@@0804]F@@X0PJV13@1^
QV<00`21ZH40MHmX07F?J00D07F?J003086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05@1d
SF@00`21ZH40K8=K06b3F`0C06b3F`03086YP@1QM4l0HGA?0080HGA?2@21ZH4305=P@`03086YP@14
C3H0A4`f00T0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2P0;3PiP40oooo002P
0;3PiP04086YP@0K7aL06alG086YP@P0<SH[00@0PJV104]F@@1;ET40BeI12021ZH44065dF003086Y
P@1^QV<0KXIS0100KXIS00<0PJV107F?J01eSfP0501eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01H0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0:065dC`L0PJV1
2@14C3H00`21ZH40;BlT02d_900302d_9003086YP@0I7AH0PJV109l0/>3V0@3oool009l0/>3V00D0
PJV101/O5`0K7aL06alG086YP@06038f:`H0PJV12`1QM5P00`21ZH40KXIS06j6H`0A06j6H`03086Y
P@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086Y
P@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df93086YP@03086YP@D0A4`f
00<0PJV102d_900];b@0100];b@2086YPIl0/>3V0@3oool009h0/>3V00D0PJV101/O5`0K7aL06alG
086YP@03038f:`D0PJV1401QM5P00`21ZH40KXIS06j6H`0A06j6H`03086YP@1eSfP0MHmX01@0MHmX
00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0K8=K01<0K8=K
00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df9305=R@`0305=R@`D0PJV100<0A4`f086YP@0];b@0
1@0];b@2086YPIh0/>3V0@3oool009d0/>3V00@0PJV101/O5`0K7aL06alG1@21ZH4404UE@`03086Y
P@1QM5P0HGAH00d0HGAH00<0PJV106j6H`1^QV<04@1^QV<00`21ZH40MHmX07F?J00E07F?J003086Y
P@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05P1dSF@00`21ZH40K8=K06b3F`0D06b3F`03086Y
P@1QM4l0HGA?00l0HGA?00<0PJV105=R@`1CHT<01`1CHT<5086YP@@0;BlT0P21ZH6M0;3PiP40oooo
002L0;3PiP04086YP@0K7aL06alG01/O5`80PJV11`19ED<00`21ZH40HGAH065dF00>065dF003086Y
P@1^QV<0KXIS0140KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01L0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0?065dC`03086Y
P@1CHT<0Df9300X0Df9300<0PJV103]3<021ZH400`21ZH400`0];b@0PJV1086YP@2L0;3PiP40oooo
002L0;3PiP04086YP@0K7aL0PJV1086YP@T0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS
06j6H`0B06j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05`1gTFP00`21ZH40M8eT
07B=I00G07B=I003086YP@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df93
05=R@`0905=R@`03086YP@0k@c00>d<`00<0>d<`1021ZH6K0;3PiP40oooo002K0;3PiP<0PJV100<0
:2hV086YP@19ED<01`19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0140KXIS00<0
PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01H0M8eT00<0
PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0?065dC`03086YP@1CHT<0Df9300X0Df9300<0
PJV103]3<00k@c001@0k@c02086YPIX0/>3V0@3oool009X0/>3V0P21ZH4202P^9P03086YP@19ED<0
BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0B06j6H`03086YP@1eSfP0
MHmX01D0MHmX00<0PJV107NAJ01gTFP0601gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0
K8=K01@0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df9305=R@`0905=R@`03086YP@0k@c00
>d<`00D0>d<`0`21ZH6I0;3PiP40oooo002I0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE
@`19ED<01P19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c001@0k@c000`21ZH407b8J086YP@2H0;3PiP40oooo002I0;3PiP05086YP@0X;RH0:2hV02P^
9P21ZH402@19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c00100k@c001021ZH407b8J01lR6P21ZH6G0;3PiP40oooo002H0;3PiP05086YP@0X;RH0:2hV
02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV1
07F?J01eSfP05P1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV1
06b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV1
03]3<00k@c001@0k@c000`21ZH407b8J086YP@2G0;3PiP40oooo002G0;3PiP03086YP@0X;RH0:2hV
0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01L0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002G0;3PiP05
086YP@0X;RH0:2hV02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002F0;3PiP03
086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003
086YP@1^QV<0KXIS01@0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003
086YP@1dSF@0M8eT01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03
086YP@1CHT<0Df9300X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2E0;3PiP40
oooo002E0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH
065dF00>065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?J01eSfP02P1eSfQ9086YPA40K8=K
00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086YP@0k@c00>d<`00D0>d<`
00@0PJV101lR6P0O8QX0PJV1U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^9P0302P^9P03086Y
P@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0906j6HaP0PJV1
3023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0PJV107^HJ`1kV6/0
0`1kV6/<086YP@H0K8=K00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086Y
P@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^
9P0202P^9P03086YP@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P02P1QM5P@086YP@/0OIad00<0
PJV108>SN023XgP05P23XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0
PJV107^HJ`1kV6/03`1kV6/A086YP@T0HGA?00<0PJV105=R@`1CHT<02`1CHT<00`21ZH40>d<`03]3
<00403]3<004086YP@0O8QX07b8J086YPI<0/>3V0@3oool009<0/>3V00<0PJV102P^9P0X;RH00P0X
;RH00`21ZH40BEE304UE@`0804UE@`04086YP@1QM5P0HGAH065dF0T0PJV1101bSF/00`21ZH40OIad
07fLM00D07fLM003086YP@23XgP0Pj=h01H0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c
086QL`0H086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d0201^R5d=086YP@X0Df93
00<0PJV103]3<00k@c001@0k@c001021ZH407b8J01lR6P21ZH6B0;3PiP40oooo002B0;3PiP03086Y
P@0X;RH0:2hV00<0:2hV00<0PJV104UE@`19ED<01P19ED<6086YP@`0LXe[00<0PJV107fLM01mW7@0
501mW7@00`21ZH40Pj=h08>SN00G08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<0
6@21XG<00`21ZH40NiQ[07^HJ`0D07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0
1@21ZH4605=R@`03086YP@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40TP2`h>H10?ooo`00TP2`
h>H00`21ZH40:2hV02P^9P0202P^9P03086YP@19ED<0BEE300<0BEE31021ZH400`1LL5P0PJV107:=
J`0?07:=J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BT
M`0I08BTM`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8
G@0B06j8G@03086YP@1NLTd0GW9=00@0GW9=1@21ZH400`1CHT<0PJV103]3<00603]3<004086YP@0O
8QX07b8J086YPI40/>3V0@3oool00940/>3V00<0PJV102P^9P0X;RH00`0X;RH00`21ZH40BEE3086Y
P@03086YP@@0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23
XgP0Pj=h00X0Pj=h0P3oO`0;08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21
XG<00`21ZH40NiQ[07^HJ`0E07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02@1N
LTd5086YP@D0>d<`00<0PJV101lR6P21ZH40T@2`h>H10?ooo`00T02`h>H00`21ZH40:2hV02P^9P02
02P^9P@0PJV1201LL5P00`21ZH40LXe[07:=J`0>07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV1
08>SN023XgP02P23XgP20?mo00/0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I
086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0;
05ibC@03086YP@17ECX0AeDj00@0PJV100D0>d<`086YP@0O8QX07b8J086YP@2@0;3PiP40oooo002@
0;3PiP0302P^9P21ZH40PJV10080PJV100<0=d0g086YP@1LL5P02@1LL5P00`21ZH40LXe[07:=J`0>
07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP02P23XgP20?mo00/0Pj=h00<0PJV1
08BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV1
06j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0<05ibC@03086YP@17ECX0AeDj00<0AeDj0`21ZH42
01lR6P03086YP@2`h>H0/>3V08d0/>3V0@3oool008l0/>3V0P21ZH4403M0=`03086YP@1LL5P0G71H
00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23XgP0Pj=h
00/0Pj=h0P3oO`0;08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21XG<00`21
ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21
ZH40AeDj04ME>P0504ME>P@0PJV1S`2`h>H10?ooo`00S`2`h>H00`21ZH40=d0g03M0=`0303M0=`03
086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003
086YP@23XgP0Pj=h00/0Pj=h0P3oO`0;08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21
XG<06@21XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1N
LTd02`1NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad0PJV1086YPHh0/>3V0@3oool008h0
/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00h0
LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00;08>SN080ogl02P23XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40
KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH40
92LM02@W7@0T9af>0;3PiP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP02`23XgP20?mo00X0Pj=h00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PJ5c086QL`0J086QL`03
086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04`1^R5d00`21ZH40GW9=05ibC@0;05ibC@03
086YP@17ECX0AeDj00H0AeDj00@0PJV102@W7@0T9ad0PJV1S@2`h>H10?ooo`00S@2`h>H00`21ZH40
=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40
OIad07fLM00E07fLM003086YP@23XgP0Pj=h00L0Pj=h00@0ogl008>SN023XgP0Pj=h0P3oO`0308>S
N0040?mo0023XgP0Pj=h0?mo00<0Pj=h00<0PJV108BTM`24Y7L03@24Y7L0103oO`00Q:Ag08BTM`3o
O`0908BTM`03086YP@21XG<0PJ5c01P0PJ5c00D0ogl0086QL`21ZH40NiQ[0?mo000F07^HJ`03086Y
P@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0504ME>P04086Y
P@0T9ad092LM086YPHd0/>3V0@3oool008d0/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H
05a`F00805a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h
08>SN00808>SN0040?mo0023XgP0Pj=h08>SN0/0ogl000<0Pj=h086YP@24Y7L02`24Y7L:0?mo00H0
Q:Ag00<0PJV1086QL`21XG<00P3oO`08086QL`80ogl02P21XG<90?mo01@0NiQ[00<0PJV106j8G@1^
R5d04P1^R5d00`21ZH40GW9=05ibC@0<05ibC@03086YP@17ECX0AeDj00H0AeDj00@0PJV102@W7@0T
9ad0PJV1S02`h>H10?ooo`00S02`h>H00`21ZH40=d0g03M0=`0403M0=`03086YP@1LL5P0G71H00P0
G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00?07fLM080ogl0101mW7@00`21ZH40
Pj=h08>SN00708>SN080ogl00`23XgP<0?mo0003086YP@24Y7L0Q:Ag00T0Q:Ag303oO`0508BTM`04
086YP@21XG<0PJ5c086QL`80ogl02021XG<20?mo00P0PJ5c2`3oO`0807^HJ`80ogl0201kV6/20?mo
00H0KXQM0P3oO`0806j8G@060?mo001^R5d0KXQM0?mo001^R5d0PJV13@1NLTd00`21ZH40AeDj04ME
>P0604ME>P04086YP@0T9ad092LM086YPH`0/>3V0@3oool008`0/>3V00<0PJV103M0=`0g@3L00`0g
@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01mW7@03`1m
W7@20?mo00@0OIad00<0PJV108>SN023XgP01`23XgP00`3oO`00Pj=h08>SN00208>SN0<0ogl01`23
XgP40?mo00T0Q:Ag0`3oO`0808BTM`<0ogl01024Y7L01021ZH40PJ5c086QL`21XG<20?mo00P0PJ5c
0P3oO`07086QL`<0ogl00`21XG<01021ZH40NiQ[07^HJ`1kV6/20?mo00P0NiQ[0P3oO`0907^HJ`80
ogl01P1^R5d20?mo00H0KXQM1@3oO`000`1^R5d0PJV10?mo000705ibC@030?mo001NLTd0GW9=00<0
GW9=00<0PJV104ME>P17ECX01@17ECX01@21ZH4092LM02@W7@0T9ad0PJV108/0/>3V0@3oool008/0
/>3V00<0PJV103M0=`0g@3L0100g@3L00`21ZH40G71H05a`F00805a`F003086YP@1bSF/0LXe[00l0
LXe[00<0PJV107fLM01mW7@0401mW7@20?mo00@0OIad00<0PJV108>SN023XgP01P23XgP20?mo00<0
Pj=h0`3oO`0908>SN0@0ogl01`24Y7L30?mo00X0Q:Ag0`3oO`0308BTM`04086YP@21XG<0PJ5c086Q
L`80ogl02021XG<20?mo00H0PJ5c0`3oO`04086QL`03086YP@1kV6/0NiQ[0080NiQ[0P3oO`0707^H
J`80ogl02@1kV6/20?mo00H0KXQM0P3oO`0506j8G@X0ogl0101NLTd50?mo00<0GW9=00<0PJV104ME
>P17ECX01P17ECX01021ZH4092LM02@W7@21ZH6;0;3PiP40oooo002;0;3PiP03086YP@0g@3L0=d0g
00<0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad
0100OIad0P3oO`0407fLM003086YP@23XgP0Pj=h00H0Pj=h00<0ogl008>SN023XgP00P23XgP20?mo
00/0Pj=h0P3oO`0808BTM`80ogl03024Y7L20?mo00<0Q:Ag00@0PJV1086QL`21XG<0PJ5c0P3oO`08
086QL`80ogl01P21XG<20?mo00H0PJ5c00<0PJV107^HJ`1kV6/00P1kV6/00`3oO`00NiQ[07^HJ`05
07^HJ`80ogl02@1kV6/20?mo00H0KXQM0P3oO`0506j8G@80ogl00`1^R5d50?mo00<0GW9=203oO`00
101NLTd0PJV104ME>P3oO`0604ME>P05086YP@0T9ad092LM02@W7@21ZH40RP2`h>H10?ooo`00R`2`
h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0G71H00<0PJV107:=J`1bSF/03`1b
SF/00`21ZH40OIad07fLM00@07fLM080ogl00`1mW7@00`21ZH40Pj=h08>SN00608>SN080ogl01023
XgP20?mo00/0Pj=h0P3oO`0808BTM`80ogl03024Y7L20?mo00<0Q:Ag00@0PJV1086QL`21XG<0PJ5c
0P3oO`08086QL`80ogl01P21XG<20?mo00H0PJ5c00<0PJV107^HJ`1kV6/00P1kV6/20?mo00H0NiQ[
0P3oO`0907^HJ`80ogl01P1^R5d20?mo00D0KXQM0P3oO`0406j8G@@0ogl00`1NLTd20?mo00<0GW9=
103oO`00101NLTd0ogl00?mo003oO`0604ME>P04086YP@0T9ad092LM086YPHX0/>3V0@3oool008X0
/>3V00<0PJV103M0=`0g@3L0100g@3L00`21ZH40G71H05a`F00805a`F003086YP@1bSF/0LXe[0100
LXe[00<0PJV107fLM01mW7@04@1mW7@20?mo0080OIad00<0PJV108>SN023XgP01P23XgP00`3oO`00
Pj=h08>SN00308>SN080ogl02`23XgP20?mo00L0Q:Ag0`3oO`0308BTM`T0PJV10`3oO`06086YP@80
ogl02021ZH420?mo00H0PJ5c0P3oO`06086QL`03086YP@1kV6/0NiQ[00<0NiQ[0P3oO`0607^HJ`80
ogl0201kV6/20?mo00H0KXQM0P3oO`0506j8G@80ogl01@1^R5d40?mo0080GW9=0P3oO`0505ibC@80
ogl000@0GW9=0?mo003oO`00ogl01P17ECX01021ZH4092LM02@W7@21ZH6:0;3PiP40oooo002:0;3P
iP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=
J`03086YP@1mW7@0OIad00X0OIad2021ZH420?mo00X0PJV10P3oO`05086YP@80ogl02`21ZH420?mo
00L0PJV10P3oO`04086YP@T0S[>30P3oO`0308jcP`04086YP@2</7h0S;1n08b`OP80ogl0202</7h2
0?mo00D0PJV10`3oO`0<086YP@80ogl01@21ZH400`1kV6/0ogl00?mo000907^HJ`80ogl01P1^R5d2
0?mo00@0KXQM0`3oO`0506j8G@@0ogl000<0GW9=0?mo003oO`001@1NLTd30?mo000305ibC@3oO`00
ogl000H0AeDj00D0PJV102@W7@0T9ad092LM086YP@290;3PiP40oooo00290;3PiP03086YP@0g@3L0
=d0g00@0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0;07:=Ja40PJV12029[H4=
0?mo00H0S[>40P3oO`0;08jcQ080ogl01`2>/h<20?mo00d0S[>30P3oO`0308jcP`04086YP@2</7h0
S;1n08b`OP80ogl0202</7h20?mo00D0S;1n0P3oO`0708b`OP03086YP@26Z7L0QZQg00<0QZQg0P3o
O`0508JXM`03086YP@3oO`00ogl000T0PJV10P3oO`06086YP@80ogl00P21ZH4306j8G@80ogl01P1^
R5d20?mo00X0GW9=1@3oO`0704ME>P04086YP@0T9ad092LM086YPHT0/>3V0@3oool008T0/>3V00<0
PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[0080LXe[2P21
ZH4407nPNP03086YP@29[H40RJf10180RJf13@3oO`0608jcQ080ogl02`2>/h@30?mo00H0S[>30`3o
O`0<08jcP`<0ogl00P2>/h<01021ZH40S;1n08b`OP2</7h20?mo00P0S;1n0P3oO`0508b`OP80ogl0
1`2</7h00`21ZH40QZQg08JXM`0308JXM`<0ogl01@26Z7L20?mo00T0QZQg0P3oO`0607^JJ`80ogl0
0P1kVV/3086YP@80ogl01P21ZH420?mo0080PJV1201NLTd20?mo000305ibC@21ZH40AeDj00L0AeDj
00D0PJV102@W7@0T9ad092LM086YP@280;3PiP40oooo00280;3PiP03086YP@0g@3L0=d0g00@0=d0g
00<0PJV105a`F01LL5P01P1LL5P8086YP@h0Oj1j00<0PJV108V]P@29[H404P29[H420?mo0080RJf1
00<0PJV108jcQ02>/h@0102>/h@00`3oO`00S[>408jcQ00508jcQ080ogl02`2>/h@20?mo00L0S[>3
0`3oO`0<08jcP`80ogl00`2>/h<01021ZH40S;1n08b`OP2</7h20?mo00P0S;1n0P3oO`0508b`OP<0
ogl01P2</7h00`21ZH40QZQg08JXM`0308JXM`80ogl01P26Z7L20?mo00T0QZQg0P3oO`0607^JJ`80
ogl01@1kVV/20?mo00H0NiY[0P3oO`0206N1EPP0PJV10`3oO`000`1NLTd0PJV104ME>P0704ME>P04
086YP@0T9ad092LM086YPHP0/>3V0@3oool008P0/>3V00<0PJV103M0=`0g@3L00`0g@3L01021ZH40
G71H05a`F01LL5P6086YP@<0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0C08V]
P@80ogl000<0PJV108jcQ02>/h@01@2>/h@00`3oO`00S[>408jcQ00508jcQ080ogl02`2>/h@20?mo
00P0S[>30P3oO`0<08jcP`80ogl00`2>/h<01021ZH40S;1n08b`OP2</7h20?mo00P0S;1n0P3oO`07
08b`OP80ogl01@2</7h00`21ZH40QZQg08JXM`0308JXM`80ogl01P26Z7L20?mo00T0QZQg0P3oO`06
07^JJ`80ogl01@1kVV/20?mo00H0NiY[0`3oO`0606N1EPD0ogl01@21ZH4604ME>P05086YP@0T9ad0
92LM02@W7@21ZH40Q`2`h>H10?ooo`00Q`2`h>H01021ZH40=d0g03M0=`0g@3L7086YP@T0JhIY00<0
PJV107nPNP1oX7X03`1oX7X00`21ZH40RJf108V]P@0D08V]P@80ogl000<0PJV108jcQ02>/h@0102>
/h@20?mo00H0S[>40`3oO`0908jcQ0@0ogl0202>/h<30?mo00X0S[>30`3oO`0308jcP`04086YP@2<
/7h0S;1n08b`OP80ogl0202</7h20?mo00L0S;1n0`3oO`0408b`OP03086YP@26Z7L0QZQg0080QZQg
0`3oO`0608JXM`<0ogl02026Z7L30?mo00H0NiY[0P3oO`0507^JJ`80ogl01P1kVV/20?mo00D0Ih5F
1@3oO`0306N1EP04086YP@1AHd<0ogl00?mo00@0PJV10P17ECX01021ZH4092LM02@W7@21ZH670;3P
iP40oooo00270;3PiP@0PJV10`17F4T00`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j0100
Oj1j00<0PJV108V]P@29[H405029[H420?mo0003086YP@2>/h@0S[>400@0S[>400<0ogl008jcQ02>
/h@01P2>/h@30?mo00L0S[>4103oO`0:08jcP`<0ogl0202>/h<30?mo00@0S[>300@0PJV108b`OP2<
/7h0S;1n0P3oO`0808b`OP80ogl0202</7h30?mo00@0S;1n00@0PJV108JXM`26Z7L0QZQg0P3oO`08
08JXM`@0ogl01P26Z7L30?mo00H0NiY[0P3oO`0507^JJ`80ogl01P1kVV/20?mo00@0Ih5F0`3oO`06
06N1EP04086YP@1AHd<0ogl00?mo00@0DF=31021ZH4202@W7@03086YP@2`h>H0/>3V08@0/>3V0@3o
ool008H0/>3V0P21ZH4604MHB@03086YP@1[QVT0JhIY00T0JhIY00<0PJV107nPNP1oX7X0401oX7X0
0`21ZH40RJf108V]P@0D08V]P@80ogl000<0PJV108jcQ02>/h@00`2>/h@20?mo00P0S[>4103oO`04
08jcQ0@0ogl000<0S[>4086YP@2>/h<02P2>/h<50?mo0080S[>31@3oO`0508jcP`04086YP@2</7h0
S;1n08b`OP80ogl0202</7h20?mo00T0S;1n0`3oO`0308b`OP03086YP@26Z7L0QZQg0080ogl02@26
Z7L50?mo00D0QZQg0P3oO`000`21ZH40NiY[07^JJ`0407^JJ`80ogl01@1kVV/20?mo00H0NiY[0`3o
O`0306N1EP80ogl0201WPEH00`21ZH40ogl00?mo0006055S@`03086YP@0]=BD0PJV10080PJV1QP2`
h>H10?ooo`00QP2`h>H2086YP@D0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@
07nPNP03086YP@29[H40RJf101@0RJf10`3oO`0508jcQ0030?mo002>/h@0S[>400L0S[>42`3oO`02
08jcQ003086YP@2>/h<0S[>300X0S[>32P3oO`0608jcP`04086YP@2</7h0S;1n08b`OP80ogl0202<
/7h20?mo00X0S;1n103oO`000`2</7h0PJV10?mo00030?mo00T0QZQg0P3oO`000`26Z7L0ogl00?mo
00020?mo0080QZQg103oO`0607^JJ`80ogl01@1kVV/20?mo00H0NiY[00<0PJV10?mo003oO`000`1W
PEH20?mo00D0Ih5F0P3oO`00101WPEH0PJV10?mo003oO`07055S@`04086YP@0]=BD0;CDU02de9HH0
/>3V0@3oool008H0/>3V00<0PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086Y
P@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405@29[H420?mo00@0S[>40P3oO`0908jcQ080ogl0
00<0S[>40?mo003oO`00103oO`0408jcQ003086YP@2>/h<0S[>300`0S[>31@3oO`0908jcP`04086Y
P@2</7h0S;1n08b`OP80ogl0202</7h20?mo00/0S;1n203oO`0:08JXM`80ogl00P26Z7L80?mo0003
086YP@1kVV/0NiY[00@0NiY[0P3oO`0507^JJ`80ogl01P1kVV/00`21ZH40ogl00?mo000306N1EP<0
ogl0101WPEH20?mo000406N1EP21ZH40ogl00?mo00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@25
0;3PiP40oooo00260;3PiP03086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21
ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101D0RJf10P3oO`0408jcQ0030?mo002>/h@0S[>4
00L0S[>40P3oO`0208jcQ080ogl0202>/h@00`21ZH40S[>308jcP`0J08jcP`04086YP@2</7h0S;1n
08b`OP80ogl0202</7h20?mo00`0S;1n1@3oO`0=08JXM`80ogl00P26Z7L50?mo0080QZQg00<0PJV1
07^JJ`1kVV/0101kVV/20?mo00H0NiY[0P3oO`0507^JJ`03086YP@3oO`00ogl000@0Ih5F103oO`00
0`1WPEH0ogl00?mo00020?mo0004086YP@1AHd<0ogl00?mo00H0DF=300D0PJV102de9@0]=BD0;CDU
086YP@250;3PiP40oooo00250;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6J@03086YP@1o
X7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405@29[H420?mo00<0S[>40P3oO`0F08jcQ003086YP@2>
/h<0S[>301`0S[>300<0PJV108b`OP2</7h00`3oO`0708b`OP80ogl03`2</7h00`21ZH40QZQg08JX
M`0G08JXM`03086YP@1kVV/0NiY[00D0NiY[0P3oO`0507^JJ`80ogl01P1kVV/30?mo00@0Ih5F1`3o
O`0206N1EP03086YP@3oO`00ogl000H0DF=300D0PJV102de9@0]=BD0;CDU086YP@250;3PiP40oooo
00250;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0
PJV108V]P@29[H405P29[H420?mo00<0S[>400<0ogl008jcQ02>/h@05@2>/h@00`21ZH40S[>308jc
P`0L08jcP`03086YP@2</7h0S;1n00<0ogl01`2</7h20?mo00l0S;1n00<0PJV108JXM`26Z7L05`26
Z7L00`21ZH40NiY[07^JJ`0D07^JJ`03086YP@3oO`00Ih5F00D0Ih5F103oO`0406N1EP03086YP@3o
O`00ogl000L0DF=300@0PJV102de9@0]=BD0PJV1Q@2`h>H10?ooo`00Q@2`h>H2086YP@D0AeQ900<0
PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf10`3o
O`000`2>/h@0ogl00?mo000G08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h00P3o
O`0808b`OP80ogl03`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0
PJV106N1EP1WPEH03@1WPEH00`21ZH40ogl00?mo0007055S@`05086YP@0]=BD0;CDU02de9@21ZH40
Q02`h>H10?ooo`00Q@2`h>H00`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY00X0JhIY00<0
PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@3oO`00ogl00080ogl0602>
/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n0080ogl0202</7h30?mo00h0S;1n00<0
PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0
PJV10?mo003oO`001`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108@0/>3V0@3oool008D0/>3V00<0
PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0
PJV108V]P@29[H405P29[H401021ZH40ogl00?mo003oO`0I08jcQ003086YP@2>/h<0S[>301`0S[>3
00<0PJV108b`OP2</7h00P3oO`0808b`OP<0ogl03P2</7h00`21ZH40QZQg08JXM`0H08JXM`03086Y
P@1kVV/0NiY[00D0NiY[00<0ogl007^JJ`1kVV/02`1kVV/00`21ZH40Ih5F06N1EP0>06N1EP03086Y
P@3oO`00ogl000H0DF=300D0PJV102de9@0]=BD0;CDU086YP@240;3PiP40oooo00240;3PiP80PJV1
1P17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H40
5P29[H401021ZH40ogl00?mo003oO`0I08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2<
/7h00P3oO`0808b`OP80ogl03`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[00@0
NiY[0`3oO`0=07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV10?mo003oO`001`1AHd<01021ZH40
;CDU02de9@21ZH640;3PiP40oooo00240;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6J@03
086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405P29[H401021ZH40ogl00?mo003oO`0I08jc
Q003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h00P3oO`0808b`OP80ogl0402</7h00`21
ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[00<0NiY[1@3oO`0<07^JJ`03086YP@1WPEH0Ih5F
00d0Ih5F00<0PJV10?mo003oO`001`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108<0/>3V0@3oool0
08@0/>3V0P21ZH4504MHB@03086YP@1[QVT0JhIY00X0JhIY00<0PJV107nPNP1oX7X04@1oX7X00`21
ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0ogl001X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21
ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/0101kVV/30?mo
00d0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40ogl00?mo0007055S@`05086YP@0]=BD0;CDU
02de9@21ZH40P`2`h>H10?ooo`00Q02`h>H00`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X04@1oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg
01L0QZQg00<0PJV107^JJ`1kVV/01@1kVV/00`3oO`00NiY[07^JJ`0<07^JJ`03086YP@1WPEH0Ih5F
00h0Ih5F0P3oO`07055S@`05086YP@0]=BD0;CDU02de9@21ZH40P`2`h>H10?ooo`00P`2`h>H2086Y
P@H0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf1
01H0RJf100<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n
01`0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F
00h0Ih5F00<0PJV10?mo003oO`001`1AHd<01021ZH40;CDU02de9@21ZH630;3PiP40oooo00230;3P
iP80PJV11P17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]
P@29[H405P29[H400`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`
OP2</7h0702</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1
EP1WPEH03P1WPEH00`21ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU02de9@21ZH40PP2`h>H1
0?ooo`00P`2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21ZH40Oj1j07nPNP0A07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@03@2>/hAJ086YP@d0QZQg00<0PJV107^J
J`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300L0DF=300D0PJV102de
9@0]=BD0;CDU086YP@220;3PiP40oooo00230;3PiP0301dV8`21ZH40AeQ900@0AeQ900<0PJV106^6
J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0807nPNS80PJV13P2F_hh00`21ZH40U/2<09K0S00L09K0
S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H402`2>]H4I086YP@/0NiY[00<0PJV106N1
EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU02de9@21ZH40PP2`h>H1
0?ooo`00P`2`h>H00`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY00@0JhIY4@21ZH4908V_
QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0
S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0908BX
MR40PJV11@1AHd<01021ZH40;CDU02de9@21ZH620;3PiP40oooo00220;3PiP80PJV10`17F4T:086Y
P@H0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>
01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F1
01P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi9
0080Efi91`21ZH4202de9@03086YP@2`h>H0/>3V07l0/>3V0@3oool00880/>3V1@21ZH4305A[F@03
086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003
086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003
086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03
086YP@1GKTT0Efi900L0Efi900<0PJV103=1;021ZH400P21ZH610;3PiP40oooo00220;3PiP80PJV1
1P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00
PP2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840
/>3V0@3oool00880/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0
702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0
<d4/086YP@210;3PiP40oooo00220;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086Y
P@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086Y
P@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086Y
P@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086Y
P@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00PP2`h>H00`21ZH40E6]I05A[F@0405A[F@03086Y
P@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086Y
P@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086Y
P@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086Y
P@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00210;3PiP80PJV1
1P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00
P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840
/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01X0U[n>00<0PJV109K0S02F`8`0
7@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0
<d4/086YP@210;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086Y
P@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086Y
P@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086Y
P@24Z7H0Q:Qf01<0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086Y
P@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L0
2P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
6@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01021ZH40<d4/03=1;021ZH610;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0E6]I
00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<
00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f8
00<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R
00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00840/>3V
0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<
09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f8
09BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R
07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40
oooo00210;3PiP0302@_;@21ZH40E6]I00D0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10800/>3V0@3oool00840/>3V00<0PJV105A[F@1DJeT0101DJeT00`21ZH40MiQg
07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0E6]I
00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<
00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f8
00<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R
00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00800/>3V
0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<
09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f8
09BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R
07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40
oooo00200;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn6
00<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<
00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf
00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021
ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10800/>3V0@3oool00800/>3Vl`21ZH600;3PiP40oooo00200;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P02`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V
0@3oool00800/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta
086YP@200;3PiP40oooo00200;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H00`21ZH40GW]U05ikI@0405ikI@03086YP@20
YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2M
bYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E
`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1L
N4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V
0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta
086YP@200;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20
YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2M
bYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E
`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1L
N4l01021ZH40>4Ta03Q9<@21ZH610;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0I09G0RP03086YP@2<]7l0S;Ao01<0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0
PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0
PJV109g:UP2MbYH06P2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0
PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0
PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00840/>3V0P21
ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6
U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7
T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^N
K@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo
00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P@2`h>H10?ooo`00PP2`h>H00`21ZH40GW]U05ikI@0405ikI@03086YP@20YX80P:J200/0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0
PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H2086YP@H0GW]U00<0
PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0
PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0
PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0
PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00880/>3V0P21
ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6
U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7
T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^N
K@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo
00220;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P@2`h>H10?ooo`00PP2`h>H5086YP@<0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bd
O`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l00`21ZH40>4Ta03Q9
<@02086YPH40/>3V0@3oool00880/>3V0P21ZH4306F7KPX0PJV11P20YX800`21ZH40TKb?096lS`0A
096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L
09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D
08bdO`03086YP@1kWVd0Nii]00H0Nii]5@21ZH400`0kCc<0PJV10;3PiP200;3PiP40oooo00230;3P
iP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X01026/8X@086YP@X0TKb?00<0PJV109[6
U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7
T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao00T0S;Ao5021ZH48086X
M@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?<`0kCc<0>dlcPP2`h>H10?ooo`00P`2`h>H2086Y
P@D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0709O6Uc80PJV13`2MbYH00`21
ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X02`2E`8XI086Y
P@/0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00606>3F005086YP@0kCc<0>dlc
03]?<`21ZH40PP2`h>H10?ooo`00P`2`h>H2086YP@H0IHM^00<0PJV108J`RP26/8X02@26/8X00`21
ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid0302RdieK086Y
P@d0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@220;3PiP40oooo00230;3PiP80PJV11P1UQfh00`21
ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21
ZH40X]>M0:;CW@0K0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21
ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21
ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40PP2`h>H10?ooo`00P`2`h>H2086Y
P@H0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01`0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe
00h0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH630;3PiP40oooo00240;3P
iP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0A09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096m
Q`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0
PJV108<0/>3V0@3oool008@0/>3V0P21ZH4506F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6
U`2GaYL04@2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;C
V`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096m
Q`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?
<`0kCc<0>dlc086YP@230;3PiP40oooo00240;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0908J`
RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;C
W@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9
T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3
F005086YP@0kCc<0>dlc03]?<`21ZH40P`2`h>H10?ooo`00Q02`h>H2086YP@H0IHM^00<0PJV108J`
RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9
T@2KbI40602KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3
F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH640;3PiP40oooo00250;3PiP03086YP@1UQfh0IHM^
00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe
00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108@0/>3V0@3oool0
08D0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG
0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K
01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf7
01<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc
03]?<`21ZH40Q02`h>H10?ooo`00Q@2`h>H2086YP@D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21
ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21
ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21
ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01@21
ZH40>dlc03]?<`0kCc<0PJV108@0/>3V0@3oool008D0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:
00T0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA
01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00@0PJV103]?<`0kCc<0PJV1Q@2`h>H10?ooo`00Q@2`h>H2086YP@H0IHM^00<0PJV108J`
RP26/8X02@26/8X00`21ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid06@2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9
T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3
F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108D0/>3V0@3oool008H0/>3V00<0PJV106F7
KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?
W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@
U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086X
M@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40Q@2`h>H1
0?ooo`00QP2`h>H00`21ZH40IHM^06F7KP0406F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6
U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;C
V`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096m
Q`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?
<`0kCc<0>dlc086YP@250;3PiP40oooo00260;3PiP80PJV11@1UQfh00`21ZH40Q[2:08J`RP0:08J`
RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;C
W@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9
T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3
F004086YP@0kCc<0>dlc086YPHH0/>3V0@3oool008H0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:
00T0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA
01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00H0Hh=H00<0PJV103]?<`0kCc<00P21ZH660;3PiP40oooo00270;3PiP@0PJV10`1UQfh00`21ZH40
Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40
X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40
VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03021Z7D00`21ZH40
Hh=H06>3F00506>3F0D0PJV100<0>e8d086YP@2`h>H0Q@2`h>H10?ooo`00Q`2`h>H01021ZH40J8id
06R>M01XSW@7086YP@T0Q[2:00<0PJV109O6U`2GaYL03`2GaYL00`21ZH40WlnL09o?W00F09o?W003
086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03
086YP@2KbI40VlVA01P0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0<086XM@03
086YP@1SPeP0Hh=H00D0PJV10P1WRel01021ZH40>e8d03]B=021ZH670;3PiP40oooo00280;3PiP03
086YP@1XSW@0J8id00<0J8id00@0PJV108VgT029]i00RKN@1P21ZH4308J`RP03086YP@2GaYL0UlJG
0100UlJG00<0PJV109o?W02Oci`05@2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K
01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf7
01<0TKf700<0PJV1086XM@21Z7D02P21Z7D6086YP@H0Ih]O00D0PJV103]B=00kDS@0>e8d086YP@27
0;3PiP40oooo00280;3PiP03086YP@1XSW@0J8id00@0J8id00<0PJV108VgT029]i001P29]i08086Y
P@h0UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0I0:;CW@03086YP@2Rdi/0X]>K
01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf7
01<0TKf700<0PJV1086XM@21Z7D00P21Z7D8086YP@<0QK1l00<0PJV106N;G`1WRel01P1WRel01021
ZH40>e8d03]B=021ZH680;3PiP40oooo00290;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108Vg
T029]i002@29]i000`21ZH40VlfM09_=W@0209_=W@X0PJV1102GaYL00`21ZH40WlnL09o?W00F09o?
W003086YP@2Rdid0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@
U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL02@2A_HL?086YP@X0QK1l00<0PJV106N;
G`1WRel01P1WRel01@21ZH40>e8d03]B=00kDS@0PJV108P0/>3V0@3oool008T0/>3V00<0PJV106R>
M01XSW@0101XSW@00`21ZH40RKN@08VgT00908VgT003086YP@2KcId0VlfM00/0VlfM4@21ZH4<09o?
W003086YP@2Rdid0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@
U`03086YP@2KbI40VlVA00/0VlVA6021ZH4:09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;
G`1WRel01P1WRel01021ZH40>e8d03]B=021ZH690;3PiP40oooo002:0;3PiP03086YP@1XSW@0J8id
00<0J8id00<0PJV108VgT029]i002@29]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR
00X0XmJR=`21ZH4>0:;CV`03086YP@2Pd9L0X=2G00d0X=2G7021ZH4<09k@U`03086YP@2Ea8d0ULB=
0180ULB=00<0PJV108F`O025/7`03@25/7`00`21ZH40Ih]O06N;G`0506N;G`05086YP@0kDS@0>e8d
03]B=021ZH40R@2`h>H10?ooo`00RP2`h>H00`21ZH40J8id06R>M00406R>M003086YP@29]i00RKN@
00P0RKN@00<0PJV109_=W@2KcId0402KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS
01T0Y]ZS00<0PJV10:KJX@2VfZ40302VfZ4N086YP@h0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21
ZH40ULB=09G4S@0C09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01P1WRel01021
ZH40>e8d03]B=021ZH6:0;3PiP40oooo002;0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108Vg
T029]i002@29]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJ
X`2VfZ<06@2VfZ<00`21ZH40Y]ZQ0:KJX@0J0:KJX@03086YP@2Teid0Y=NM01/0Y=NM00<0PJV109k@
U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0C09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;
G`1WRel01P1WRel01021ZH40>e8d03]B=021ZH6:0;3PiP40oooo002;0;3PiP03086YP@1XSW@0J8id
00<0J8id00<0PJV108VgT029]i002@29]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR
01H0XmJR00<0PJV10:KJX`2VfZ<0602VfZ<00`21ZH40Y]ZQ0:KJX@0J0:KJX@03086YP@2Teid0Y=NM
01/0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l
00`0QK1l00<0PJV106N;G`1WRel01P1WRel01@21ZH40>e8d03]B=00kDS@0PJV108X0/>3V0@3oool0
08/0/>3V00<0PJV106R>M01XSW@0101XSW@00`21ZH40RKN@08VgT00808VgT003086YP@2KcId0VlfM
00l0VlfM00<0PJV10:?FXP2SeZ805P2SeZ800`21ZH40Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ
01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40W]2G09k@U`0G09k@U`03086YP@2Ea8d0ULB=
0180ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d
086YPH/0/>3V0@3oool008`0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08VgT00908Vg
T003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJX`0H0:KJ
X`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40W]2G09k@U`0F09k@
U`03086YP@2Ea8d0ULB=01<0ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O06N;G`0506N;
G`05086YP@0kDS@0>e8d03]B=021ZH40R`2`h>H10?ooo`00S02`h>H00`21ZH40J8id06R>M00406R>
M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?F
XP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CG
W@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d04`2Ea8d00`21ZH40QK1l08F`O00;08F`
O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV1S02`h>H10?ooo`00S@2`h>H00`21
ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21
ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21
ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21
ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV1S02`h>H1
0?ooo`00S@2`h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00T0RKN@00<0PJV109_=
W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJ
X@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4
S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00<08F`O003086YP@1WRel0Ih]O00D0Ih]O00@0PJV103]B
=00kDS@0PJV1S@2`h>H10?ooo`00SP2`h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00RKN@
00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS
01L0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G
01D0W]2G00<0PJV109G4S@2Ea8d04`2Ea8d00`21ZH40QK1l08F`O00;08F`O003086YP@1WRel0Ih]O
00H0Ih]O00@0PJV103]B=00kDS@0PJV1S@2`h>H10?ooo`00SP2`h>H00`21ZH40J8id06R>M00306R>
M003086YP@29]i00RKN@00T0RKN@00<0PJV109_=W@2KcId03P2KcId00`21ZH40XmJR0:?FXP0E0:?F
XP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CG
W@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00<08F`
O003086YP@1WRel0Ih]O00D0Ih]O00@0PJV103]B=00kDS@0PJV1SP2`h>H10?ooo`00S`2`h>H00`21
ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21
ZH40XmJR0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21
ZH40Y=NM0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21
ZH40QK1l08F`O00;08F`O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV1SP2`h>H1
0?ooo`00S`2`h>H2086YP@@0J8id00<0PJV108VgT029]i002029]i000`21ZH40VlfM09_=W@0?09_=
W@03086YP@2SeZ80XmJR01@0XmJR00<0PJV10:KJX`2VfZ<0602VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJ
X@03086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0B09G4
S@03086YP@25/7`0QK1l00/0QK1l00<0PJV106N;G`1WRel01@1WRel01021ZH40>e8d086YP@21ZH6?
0;3PiP40oooo002@0;3PiPD0PJV100<0J8id086YP@29]i002@29]i000`21ZH40VlfM09_=W@0>09_=
W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJ
X@03086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40ULB=09G4S@0B09G4
S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel00`1WRel4086YP@0303eH>P21ZH40/>3V
08h0/>3V0@3oool00900/>3V00<0PJV106VAM`1YTGL00P1YTGL3086YP@T0RKN@00<0PJV109_=W@2K
cId03P2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2V
fZ406@2VfZ400`21ZH40Y=NM0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2E
a8d04P2Ea8d00`21ZH40QK1l08F`O00;08F`O003086YP@1WRel0Ih]O00@0PJV100D0J8mS086YP@0m
F3X0?EPj086YP@2@0;3PiP40oooo002A0;3PiP03086YP@1YTGL0JI5g00<0JI5g1@21ZH4508VgT003
086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40Y]ZS0:KJX`0G0:KJX`03
086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40W]2G09k@U`0E09k@U`03
086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`02@25/7`5086YP@D0J8mS00<0PJV103eH>P0m
F3X0T@2`h>H10?ooo`00TP2`h>H00`21ZH40JI5g06VAM`0206VAM`03086YP@29^Y80RKZB0080RKZB
1021ZH4208VgT003086YP@2KcId0VlfM00h0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40Y]ZS
0:KJX`0G0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40W]2G
09k@U`0E09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`01025/7`5086YP@0308Fc
O`21ZH40J8mS00H0J8mS00@0PJV103eH>P0mF3X0PJV1T@2`h>H10?ooo`00TP2`h>H00`21ZH40JI5g
06VAM`0306VAM`03086YP@29^Y80RKZB00D0RKZB1`21ZH4<09_=W@03086YP@2SeZ80XmJR01@0XmJR
00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0Y=NM
00<0PJV109k@U`2Nd9L0502Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00D0PJV1
1P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV10980/>3V0@3oool009<0/>3V00<0
PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0808VjTP04086YP@2Kd:00Vm2P09_@X0T0PJV1
102KcId00`21ZH40XmJR0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS01H0Y]ZS00<0PJV10:KJX@2VfZ40
6@2VfZ400`21ZH40Y=NM0:CGW@0H0:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2Ea8d0
202Ea8d=086YP@X0QK=o00<0PJV106R?H`1XSf<01@1XSf<01021ZH40?EPj03eH>P21ZH6B0;3PiP40
oooo002D0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y801`29^Y800`21ZH40Vm2P
09_@X00:09_@X100PJV12`2SeZ800`21ZH40Y]ZS0:KJX`0F0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ
00<0PJV10:CGW@2Teid0602Teid00`21ZH40W]2G09k@U`0@09k@Ua00PJV12@2GbI400`21ZH40QK=o
08FcO`0;08FcO`03086YP@1XSf<0J8mS00@0J8mS00@0PJV103eH>P0mF3X0PJV1T`2`h>H10?ooo`00
U02`h>H00`21ZH40JI5g06VAM`0306VAM`03086YP@29^Y80RKZB00L0RKZB00<0PJV109_@X02Kd:00
3@2Kd:000`21ZH40Y=ZV0:CJYP090:CJYQP0PJV1302VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086Y
P@2Teid0Y=NM01P0Y=NM00<0PJV109k@U`2Nd9L0102Nd9L<086YP@D0X=FK00<0PJV109O9T@2GbI40
4@2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40
U02`h>H10?ooo`00U@2`h>H00`21ZH40JI5g06VAM`0206VAM`03086YP@29^Y80RKZB00L0RKZB00<0
PJV109_@X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0C0:CJYP03086YP@2XgZL0Z=jW00X0Z=jWBP21
ZH4@0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?
H`0506R?H`04086YP@0mF3X0?EPj086YPI@0/>3V0@3oool009H0/>3V00<0PJV106VAM`1YTGL00P1Y
TGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH0502T
fZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2Ufj40602U
fj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25/gl02P25
/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109D0/>3V0@3oool009L0/>3V00D0PJV1
06VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04`2T
fZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2Ufj40602U
fj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl02P25
/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3oool009L0/>3V00<0PJV1
06VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV1
0:CJYP2TfZH04`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV1
0:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV1
08FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3oool0
09P0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV1
0:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0F0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0PJV1
0:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV1
08FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109L0/>3V0@3oool0
09T0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV1
0:CJYP2TfZH04`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0PJV1
0:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV1
08FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0406R?H`04086YP@0mF3X0?EPj086YPIL0/>3V0@3o
ool009T0/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0608VjTP03086YP@2Kd:00
Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0
Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40
UlVA0100UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0
PJV109P0/>3V0@3oool009X0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00
Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0
Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40
UlVA0100UlVA00<0PJV108FcO`25/gl02@25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0
PJV109T0/>3V0@3oool009/0/>3V0P21ZH4206VAM`03086YP@29^Y80RKZB00H0RKZB00<0PJV109_@
X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SN
Y@2XgZD0602XgZD00`21ZH40YM^Q0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9
T@2GbI403`2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS0P21ZH6J0;3P
iP40oooo002L0;3PiP@0PJV12@29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV0180
Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0G0:SNY@03086YP@2Ufj40YM^Q01L0
YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0@09O9T@03086YP@25/gl0QK=o00T0
QK=o00<0PJV106R?H`1XSf<00`1XSf<4086YPI/0/>3V0@3oool009`0/>3V00<0PJV106F?M@1USgD0
0`21ZH4708VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW
0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK
0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS
086YP@03086YP@0306F>I021ZH40PJV109`0/>3V0@3oool009d0/>3V00@0PJV106F?M@1USgD0IHme
1@21ZH4408VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW
0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK
0:3EV`0D0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl01`25/gl5086YP@@0IHiT
0P21ZH6M0;3PiP40oooo002N0;3PiP05086YP@1USgD0IHme06F?M@21ZH400`25]i05086YPA00Vm2P
00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU
00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA
00<0PJV108FcO`25/gl01025/gl4086YP@0308:bP021ZH40IHiT00D0IHiT0P21ZH6N0;3PiP40oooo
002O0;3PiP05086YP@1USgD0IHme06F?M@21ZH401P25]i06086YP@/0Vm2P00<0PJV10:CJYP2TfZH0
4@2TfZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj40
5P2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`21ZH40
1021ZH4408:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6O0;3PiP40oooo002P0;3PiP04086YP@1U
SgD0IHme086YP@P0QKN@00@0PJV109S>W`2HcYl0V<jO2021ZH4409_@X003086YP@2TfZH0Y=ZV0100
Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q01H0
YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0:09O9T@L0PJV12@22/X000`21ZH40
IHiT06F>I00306F>I003086YP@0mFch0PJV109l0/>3V0@3oool00:00/>3V00D0PJV106F?M@1USgD0
IHme086YP@0808FgT003086YP@2HcYl0V<jO00P0V<jO2@21ZH4>0:CJYP03086YP@2XgZL0Z=jW01@0
Z=jW00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0E0:GKX@03086YP@2PeI/0X=FK01<0
X=FK00<0PJV109O9T@2GbI400P2GbI49086YP@<0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40
IHiT06F>I00306F>I003086YP@0mFch0PJV10:00/>3V0@3oool00:40/>3V00D0PJV106F?M@1USgD0
IHme086YP@0708FgT003086YP@2HcYl0V<jO00d0V<jO00@0PJV10:;JYP2RfZH0X]ZV2P21ZH450:CJ
YP03086YP@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05@2XgZD00`21ZH40YM^Q0:GKX@0E0:GK
X@03086YP@2PeI/0X=FK00T0X=FK3`21ZH4<09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>
I01USV@00`1USV@00`21ZH40?E/n086YP@2Q0;3PiP40oooo002R0;3PiP05086YP@1USgD0IHme06F?
M@21ZH401`25]i000`21ZH40V<jO09S>W`0<09S>W`03086YP@2RfZH0X]ZV00/0X]ZV4@21ZH4;0:SN
Y`03086YP@2XgZD0Z=jU01D0Z=jU00<0PJV10:GKX@2Ufj402P2Ufj4G086YP@T0WmJL00<0PJV109C8
TP2Db9803P2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6R0;3P
iP40oooo002S0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0<09S>
W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP02@2VgjP`086YP@/0YMfS00<0PJV109oF
W02OeY`04P2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>
I01USV@0101USV@2086YPJ<0/>3V0@3oool00:@0/>3V00D0PJV106F?M@1USgD0IHme086YP@0708Fg
T003086YP@2HcYl0V<jO00/0V<jO00<0PJV10:;JYP2RfZH0402RfZH00`21ZH40Y]nX0:KOZ00C0:KO
Z003086YP@2Wh:L0Yn2W01D0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00B09oF
W003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40IHiT06F>I00306F>
I080PJV1Y02`h>H10?ooo`00Y02`h>H00`21ZH40IHme06F?M@0206F?M@03086YP@25]i00QKN@00@0
QKN@00<0PJV109S>W`2HcYl0302HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0
Y]nX00<0PJV10:OPY`2Wh:L05@2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0180
WmJL00<0PJV109C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0
IHiT0P21ZH6U0;3PiP40oooo002U0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40
V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV0100X]ZV00<0PJV10:KOZ02VgjP04P2VgjP00`21ZH40
Yn2W0:OPY`0E0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04@2OeY`00`21ZH40
U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1USV@2086YPJH0
/>3V0@3oool00:H0/>3V0P21ZH4206F?M@03086YP@25]i00QKN@00D0QKN@00<0PJV109S>W`2HcYl0
2`2HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0PJV10:OPY`2Wh:L0
502Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0140WmJL00<0PJV109C8TP2Db980
302Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6W0;3PiP40oooo
002W0;3PiPD0PJV11`25]i000`21ZH40V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0
PJV10:KOZ02VgjP04P2VgjP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0
PJV109oFW02OeY`04@2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000L0P[:000<0
PJV106F>I01USV@00P1USV@2086YPJT0/>3V0@3oool00:T0/>3V00<0PJV105f6KP21ZH400P21ZH46
08FgT003086YP@2HcYl0V<jO00X0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ00B
0:KOZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oFW00@
09oFW003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I003
086YPJX0/>3V0@3oool00:X0/>3V00<0PJV105f6KP1MQVh01021ZH4308FgT003086YP@2HcYl0V<jO
00/0V<jO00<0PJV10:;JYP2RfZH03P2RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003086YP@2Wh:L0Yn2W
01<0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00@09oFW003086YP@2Db980U<RB
00`0U<RB00<0PJV108:bP022/X002022/X04086YP@0305j7H@21ZH40/>3V0:X0/>3V0@3oool00:/0
/>3V0P21ZH40101MQVh0PJV107^/R@1k[8T5086YP@`0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21
ZH40Y]nX0:KOZ00A0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21
ZH40WmJL09oFW00?09oFW003086YP@2Db980U<RB00`0U<RB00<0PJV108:bP022/X001P22/X04086Y
P@80GXMQ0P21ZH6/0;3PiP40oooo002]0;3PiP04086YP@1MQVh0PJV1086YP@@0Njb91@21ZH4909S>
W`03086YP@2RfZH0X]ZV00h0X]ZV00<0PJV10:KOZ02VgjP04@2VgjP00`21ZH40Yn2W0:OPY`0C0:OP
Y`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`0402OeY`00`21ZH40U<RB09C8TP0<09C8
TP03086YP@22/X00P[:000H0PJV100<0NZYk086YP@1NQf400P1NQf400`21ZH40/>3V0;3PiP2/0;3P
iP40oooo002^0;3PiP04086YP@1MQVh0GHI^086YP@D0Njb900<0PJV108o5V@2?aIT01`21ZH4209S>
W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP0402VgjP00`21ZH40Yn2W0:OPY`0C0:OP
Y`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`03`2OeY`00`21ZH40U<RB09C8TP0909C8
TPL0PJV11P1jZW/01@21ZH40GXMQ05j7H@1NQf40PJV10:l0/>3V0@3oool00:l0/>3V0P21ZH400`1M
QVh0PJV107^/R@0407^/R@03086YP@2?aIT0SlFI00H0SlFI2021ZH4<0:;JYP03086YP@2VgjP0Y]nX
0140Y]nX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL
00l0WmJL00@0PJV109C8TP2Db980U<RB2021ZH4208g2SP03086YP@1jZW/0NZYk00H0NZYk0P21ZH43
05j7H@03086YP@2`h>H0/>3V0:h0/>3V0@3oool00;40/>3V00<0PJV105f6KP21ZH401@1k[8T2086Y
P@X0SlFI00@0PJV109[CXP2Jdj80V]>R2@21ZH440:;JYP03086YP@2VgjP0Y]nX0100Y]nX00<0PJV1
0:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00X0WmJL2@21ZH49
08g2SP03086YP@1jZW/0NZYk00H0NZYk00<0PJV105j7H@1NQf400P1NQf400`21ZH40/>3V0;3PiP2_
0;3PiP40oooo002b0;3PiP03086YP@1MQVh0PJV100H0Njb900<0PJV108o5V@2?aIT0202?aIT00`21
ZH40V]>R09[CXP0909[CXPh0PJV12@2VgjP00`21ZH40Yn2W0:OPY`0B0:OPY`03086YP@2UgJ<0YMfS
0180YMfS00<0PJV109oFW02OeY`00P2OeY`9086YP@<0V=2J00<0PJV108g2SP2=`Xh02`2=`Xh00`21
ZH40NZYk07ZZN`0607ZZN`03086YP@1NQf40GXMQ0080GXMQ00<0PJV10;3PiP2`h>H0/02`h>H10?oo
o`00/`2`h>H3086YP@H0Njb900<0PJV108o5V@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0>09[CXP03
086YP@2PfZD0X=ZU00H0X=ZU>021ZH4<09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1j
ZW/01P1jZW/01021ZH40GXMQ05j7H@1NQf42086YPK<0/>3V0@3oool00;D0/>3V0`21ZH4507^/R@03
086YP@2?aIT0SlFI00L0SlFI00<0PJV109[CXP2Jdj803@2Jdj800`21ZH40X=ZU0:3JY@0?0:3JY@03
086YP@2Qfj@0XM^T0180XM^T00<0PJV109oHX@2Of:404P2Of:400`21ZH40V=2J09S@VP0=09S@VP03
086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01P1jZW/01@21ZH40GXMQ05j7H@1NQf40PJV1
0;D0/>3V0@3oool00;H0/>3V0`21ZH4507^/R@03086YP@2?aIT0SlFI00L0SlFI00<0PJV109[CXP2J
dj803@2Jdj800`21ZH40X=ZU0:3JY@0?0:3JY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109oHX@2O
f:404@2Of:400`21ZH40V=2J09S@VP0=09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1j
ZW/01@1jZW/2086YP@<0GXMQ00<0PJV10;3PiP2`h>H0]02`h>H10?ooo`00^02`h>H2086YP@D0Njb9
0P21ZH4808o5V@03086YP@2Jdj80V]>R00d0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T
0:7KY00A0:7KY003086YP@2Of:40WmRQ0140WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>
08g2SP0;08g2SP03086YP@1jZW/0NZYk00@0NZYk00@0PJV105j7H@1NQf40GXMQ0P21ZH6g0;3PiP40
oooo002j0;3PiP<0PJV1101k[8T00`21ZH40SlFI08o5V@0608o5V@03086YP@2Jdj80V]>R00`0V]>R
00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Of:40WmRQ0100WmRQ
00<0PJV109S@VP2Hd9X03@2Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0NZYk00@0NZYk
1P21ZH6h0;3PiP40oooo002k0;3PiPH0PJV100<0Njb9086YP@2?aIT01`2?aIT00`21ZH40V]>R09[C
XP0<09[CXP03086YP@2PfZD0X=ZU00d0X=ZU00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40WmRQ09oH
X@0@09oHX@03086YP@2Hd9X0V=2J00`0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk07ZZ
N`0307ZZN`<0PJV100<0DWYI086YP@21ZH40^P2`h>H10?ooo`00_@2`h>H2086YP@80JYUj1021ZH46
08o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00?
0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2SP0:
08g2SP04086YP@1jZW/0NZYk07ZZN`@0PJV100<0DWYI086YP@21ZH40_02`h>H10?ooo`00_`2`h>H2
086YP@<0JYUj1@21ZH4308o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03@2PfZD0
0`21ZH40XM^T0:7KY00?0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X02`2Hd9X0
0`21ZH40SL:>08g2SP0:08g2SPL0PJV100<0DWYI086YP@21ZH40_P2`h>H10?ooo`00`@2`h>H2086Y
P@<0JYUj0P21ZH400`1n/X/0PJV1086YP@03086YP@h0V]>R00<0PJV10:3JY@2PfZD0302PfZD00`21
ZH40XM^T0:7KY00?0:7KY003086YP@2Of:40WmRQ00l0WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21
ZH40SL:>08g2SP0308g2SPP0PJV10P1[VG42086YP@03059jF@21ZH40PJV10<00/>3V0@3oool00<<0
/>3V0P21ZH4306ZINP03086YP@1n/X/0O[:;0080O[:;2@21ZH4609[CXP03086YP@2PfZD0X=ZU00`0
X=ZU00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40WmRQ09oHX@0?09oHX@03086YP@2Hd9X0V=2J00P0
V=2J2P21ZH4407faP`80PJV10`1[VG401021ZH40DWYI086YP@21ZH720;3PiP40oooo00350;3PiP80
PJV10P1ZVGX2086YP@@0O[:;0P21ZH4508[2U@l0PJV11`2PfZD00`21ZH40XM^T0:7KY00>0:7KY003
086YP@2Of:40WmRQ00h0WmRQ00@0PJV109S@VP2Hd9X0V=2J2021ZH4208W0S`03086YP@1m/H<0OK63
00L0OK630P21ZH4306^IL@@0PJV1a02`h>H10?ooo`00aP2`h>H3086YP@80JYUj00<0PJV107jbR`1n
/X/00`1n/X/00`21ZH40R/:E08[2U@0:08[2U@03086YP@2AbYX0TLZJ00@0TLZJ;@21ZH4908W0S`03
086YP@1m/H<0OK6300L0OK6300@0PJV106^IL@1[VG40JiUa1021ZH760;3PiP40oooo00380;3PiP<0
PJV100<0JYUj086YP@21ZH40101n/X/2086YP@/0R/:E00<0PJV1097:VP2AbYX02`2AbYX00`21ZH40
TlbJ09?<VP0=09?<VP03086YP@2AbIL0TLVG00d0TLVG00<0PJV108W0S`29`8l02P29`8l00`21ZH40
OK6307faP`0607faP`80PJV10P1[VG43086YPLT0/>3V0@3oool00</0/>3V1@21ZH4407jbR`80PJV1
2P2:`YD00`21ZH40TLZJ097:VP0:097:VP03086YP@2Cc9X0TlbJ00d0TlbJ00<0PJV10979U`2AbIL0
302AbIL00`21ZH40RL2?08W0S`0908W0S`80PJV11`1m/H<2086YP@80JiUa0`21ZH7;0;3PiP40oooo
003=0;3PiPH0PJV10`1n/X/00`21ZH40R/:E08[2U@0808[2U@03086YP@2AbYX0TLZJ00X0TLZJ00<0
PJV109?<VP2Cc9X0302Cc9X00`21ZH40TLVG0979U`0;0979U`03086YP@29`8l0RL2?00T0RL2?00<0
PJV107faP`1m/H<01@1m/H<6086YPLh0/>3V0@3oool00=00/>3V2@21ZH4908[2U@03086YP@2AbYX0
TLZJ00T0TLZJ00<0PJV109?<VP2Cc9X02`2Cc9X00`21ZH40TLVG0979U`0<0979U`03086YP@29`8l0
RL2?00P0RL2?00<0PJV107faP`1m/H<00`1m/H<6086YPM40/>3V0@3oool00=<0/>3V3021ZH4408[2
U@03086YP@2AbYX0TLZJ00T0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21ZH40TLVG0979U`0;0979
U`03086YP@29`8l0RL2?00P0RL2?00<0PJV107faP`21ZH402021ZH7C0;3PiP40oooo003E0;3PiPD0
PJV100D0I99d086YP@21ZH40PJV106nQO@0;086YP@D0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21
ZH40TLVG0979U`0:0979U`03086YP@29`8l0RL2?00<0RL2?2021ZH400`1TTfl0PJV1086YP@03086Y
PMH0/>3V0@3oool00=P0/>3V1@21ZH400`1TTW@0PJV1086YP@0506nQO@80PJV10`1fZH<U086YP@80
L:5j0P21ZH4206BCK`D0PJV1f@2`h>H10?ooo`00g02`h>H7086YP@@0Kj5m0P21ZH4807JYP`03086Y
P@1h[8@0N:b400P0N:b400<0PJV107JYP@1fZH401`1fZH42086YP@L0L:5j0P21ZH4206BCK`<0PJV1
g@2`h>H10?ooo`00h@2`h>H7086YP@0306nQO@21ZH40PJV100H0MZV300<0PJV107R/Q01h[8@01`1h
[8@00`21ZH40MZV107JYP@0607JYP@80PJV11`1`XGX6086YPN00/>3V0@3oool00>P0/>3V1`21ZH43
07JYP`03086YP@1h[8@0N:b400H0N:b400<0PJV107JYP@1fZH400P1fZH4?086YPN@0/>3V0@3oool0
0>l0/>3V4P21ZH7b0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.611 .785 .577 r
.5 .46978 m .5 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.5 .5 m .5 .53022 L .53983 .53034 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.53983 .53034 m .54024 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.46017 .46966 m .45976 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.5 .5 m .5 .46978 L .46017 .46966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.5 .53022 m .5 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.5 .43989 m .5 .46978 L .53983 .46966 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.54024 .5 m .53983 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.5 .53022 m .5 .56011 L .53861 .56034 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.53861 .56034 m .53983 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.46139 .43966 m .46017 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.5 .46978 m .5 .43989 L .46139 .43966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.45976 .5 m .46017 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.5 .56011 m .5 .53022 L .46017 .53034 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.53983 .46966 m .54024 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.54024 .5 m .53983 .53034 L .57886 .53071 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.57886 .53071 m .57967 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.42114 .46929 m .42033 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.45976 .5 m .46017 .46966 L .42114 .46929 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.46017 .53034 m .45976 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.53983 .46966 m .53861 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.53861 .43966 m .53983 .46966 L .57886 .46929 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.57967 .5 m .57886 .46929 L .53983 .46966 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.53983 .53034 m .53861 .56034 L .57642 .56104 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.57642 .56104 m .57886 .53071 L .53983 .53034 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.42358 .43896 m .42114 .46929 L .46017 .46966 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.46017 .46966 m .46139 .43966 L .42358 .43896 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.42033 .5 m .42114 .53071 L .46017 .53034 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.46139 .56034 m .46017 .53034 L .42114 .53071 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.46017 .53034 m .46139 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.5 .41069 m .5 .43989 L .53861 .43966 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.46342 .41036 m .46139 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.5 .43989 m .5 .41069 L .46342 .41036 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.5 .56011 m .5 .58931 L .53658 .58964 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.53658 .58964 m .53861 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.5 .58931 m .5 .56011 L .46139 .56034 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.45907 .55964 m
.46222 .56096 L
s
.45299 .55973 m
.45907 .55964 L
s
.4675 .56492 m
.46973 .5699 L
s
.5 Mabswid
.637 .828 .611 r
.53861 .43966 m .53658 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.53658 .41036 m .53861 .43966 L .57642 .43896 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.57886 .46929 m .57642 .43896 L .53861 .43966 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.53861 .56034 m .53658 .58964 L .57234 .59063 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.57234 .59063 m .57642 .56104 L .53861 .56034 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.42766 .40937 m .42358 .43896 L .46139 .43966 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.46139 .43966 m .46342 .41036 L .42766 .40937 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.42114 .53071 m .42358 .56104 L .46139 .56034 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.46342 .58964 m .46139 .56034 L .42358 .56104 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.46139 .56034 m .46342 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.57886 .46929 m .57967 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.57967 .5 m .57886 .53071 L .61622 .53132 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.61622 .53132 m .61745 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.38378 .46868 m .38255 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.42033 .5 m .42114 .46929 L .38378 .46868 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.42114 .53071 m .42033 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.57642 .43896 m .57886 .46929 L .61622 .46868 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.61745 .5 m .61622 .46868 L .57886 .46929 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.57886 .53071 m .57642 .56104 L .61255 .56222 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.61255 .56222 m .61622 .53132 L .57886 .53071 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.38745 .43778 m .38378 .46868 L .42114 .46929 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.42114 .46929 m .42358 .43896 L .38745 .43778 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.38255 .5 m .38378 .53132 L .42114 .53071 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.42358 .56104 m .42114 .53071 L .38378 .53132 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.5 .38255 m .5 .41069 L .53658 .41036 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.5 .58931 m .5 .61745 L .53372 .61785 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.53372 .61785 m .53658 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.46628 .38215 m .46342 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.5 .41069 m .5 .38255 L .46628 .38215 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.5 .61745 m .5 .58931 L .46342 .58964 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44747 .57819 m
.44867 .5798 L
s
.45076 .58127 m
.45273 .58196 L
s
.43239 .56736 m
.43397 .57055 L
s
.44867 .5798 m
.45076 .58127 L
s
.43397 .57055 m
.43434 .57384 L
s
.5 Mabswid
.647 .846 .626 r
.53658 .41036 m .53372 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.53372 .38215 m .53658 .41036 L .57234 .40937 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.57642 .43896 m .57234 .40937 L .53658 .41036 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.53658 .58964 m .53372 .61785 L .56664 .61905 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.56664 .61905 m .57234 .59063 L .53658 .58964 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.43336 .38095 m .42766 .40937 L .46342 .41036 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.46342 .41036 m .46628 .38215 L .43336 .38095 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.42358 .56104 m .42766 .59063 L .46342 .58964 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.46628 .61785 m .46342 .58964 L .42766 .59063 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.46342 .58964 m .46628 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.57234 .40937 m .57642 .43896 L .61255 .43778 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.61622 .46868 m .61255 .43778 L .57642 .43896 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.57642 .56104 m .57234 .59063 L .60645 .59228 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.60645 .59228 m .61255 .56222 L .57642 .56104 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.39355 .40772 m .38745 .43778 L .42358 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.42358 .43896 m .42766 .40937 L .39355 .40772 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.38378 .53132 m .38745 .56222 L .42358 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.42766 .59063 m .42358 .56104 L .38745 .56222 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.57234 .40937 m .56664 .38095 L .53372 .38215 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.56664 .38095 m .57234 .40937 L .60645 .40772 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.61255 .43778 m .60645 .40772 L .57234 .40937 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.57234 .59063 m .56664 .61905 L .59792 .62104 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.59792 .62104 m .60645 .59228 L .57234 .59063 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.40208 .37896 m .39355 .40772 L .42766 .40937 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.42766 .40937 m .43336 .38095 L .40208 .37896 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.38745 .56222 m .39355 .59228 L .42766 .59063 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.43336 .61905 m .42766 .59063 L .39355 .59228 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.42766 .59063 m .43336 .61905 L .46628 .61785 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.61622 .46868 m .61745 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.61745 .5 m .61622 .53132 L .65095 .53217 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.65095 .53217 m .65259 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.5 .35589 m .5 .38255 L .53372 .38215 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.5 .61745 m .5 .64411 L .53005 .64455 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.53005 .64455 m .53372 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.34905 .46783 m .34741 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.38255 .5 m .38378 .46868 L .34905 .46783 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.38378 .53132 m .38255 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.46995 .35545 m .46628 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.5 .38255 m .5 .35589 L .46995 .35545 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.5 .64411 m .5 .61745 L .46628 .61785 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.61255 .43778 m .61622 .46868 L .65095 .46783 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.65259 .5 m .65095 .46783 L .61622 .46868 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.61622 .53132 m .61255 .56222 L .64606 .56386 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.64606 .56386 m .65095 .53217 L .61622 .53132 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.35394 .43614 m .34905 .46783 L .38378 .46868 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.38378 .46868 m .38745 .43778 L .35394 .43614 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.34741 .5 m .34905 .53217 L .38378 .53132 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.38745 .56222 m .38378 .53132 L .34905 .53217 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.53372 .38215 m .53005 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.53005 .35545 m .53372 .38215 L .56664 .38095 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.53372 .61785 m .53005 .64455 L .55932 .64585 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.55932 .64585 m .56664 .61905 L .53372 .61785 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.44068 .35415 m .43336 .38095 L .46628 .38215 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.46628 .38215 m .46995 .35545 L .44068 .35415 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.46995 .64455 m .46628 .61785 L .43336 .61905 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.46628 .61785 m .46995 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61242 .56291 m
.61315 .56333 L
s
.5 Mabswid
.628 .819 .618 r
.60645 .40772 m .61255 .43778 L .64606 .43614 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.65095 .46783 m .64606 .43614 L .61255 .43778 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.61255 .56222 m .60645 .59228 L .63794 .59458 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.63794 .59458 m .64606 .56386 L .61255 .56222 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.36206 .40542 m .35394 .43614 L .38745 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.38745 .43778 m .39355 .40772 L .36206 .40542 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.34905 .53217 m .35394 .56386 L .38745 .56222 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.39355 .59228 m .38745 .56222 L .35394 .56386 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.56664 .38095 m .55932 .35415 L .53005 .35545 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.55932 .35415 m .56664 .38095 L .59792 .37896 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.60645 .40772 m .59792 .37896 L .56664 .38095 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.56664 .61905 m .55932 .64585 L .58701 .64802 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.58701 .64802 m .59792 .62104 L .56664 .61905 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.41299 .35198 m .40208 .37896 L .43336 .38095 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.43336 .38095 m .44068 .35415 L .41299 .35198 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.39355 .59228 m .40208 .62104 L .43336 .61905 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.44068 .64585 m .43336 .61905 L .40208 .62104 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.43336 .61905 m .44068 .64585 L .46995 .64455 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.59792 .37896 m .60645 .40772 L .63794 .40542 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.64606 .43614 m .63794 .40542 L .60645 .40772 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.60645 .59228 m .59792 .62104 L .62664 .62381 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.62664 .62381 m .63794 .59458 L .60645 .59228 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.37336 .37619 m .36206 .40542 L .39355 .40772 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.39355 .40772 m .40208 .37896 L .37336 .37619 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.35394 .56386 m .36206 .59458 L .39355 .59228 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.40208 .62104 m .39355 .59228 L .36206 .59458 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.5 .33118 m .5 .35589 L .53005 .35545 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.47443 .33074 m .46995 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.5 .35589 m .5 .33118 L .47443 .33074 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.5 .64411 m .5 .66882 L .52557 .66926 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.52557 .66926 m .53005 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.5 .66882 m .5 .64411 L .46995 .64455 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.53005 .35545 m .52557 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.52557 .33074 m .53005 .35545 L .55932 .35415 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.53005 .64455 m .52557 .66926 L .5504 .67056 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.5504 .67056 m .55932 .64585 L .53005 .64455 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.4496 .32944 m .44068 .35415 L .46995 .35545 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.46995 .35545 m .47443 .33074 L .4496 .32944 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.47443 .66926 m .46995 .64455 L .44068 .64585 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.46995 .64455 m .47443 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.65095 .46783 m .65259 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.65259 .5 m .65095 .53217 L .68192 .53327 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.68192 .53327 m .68396 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.31808 .46673 m .31604 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.34741 .5 m .34905 .46783 L .31808 .46673 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.34905 .53217 m .34741 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.64606 .43614 m .65095 .46783 L .68192 .46673 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.68396 .5 m .68192 .46673 L .65095 .46783 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.65095 .53217 m .64606 .56386 L .67583 .56597 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.67583 .56597 m .68192 .53327 L .65095 .53217 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.32417 .43403 m .31808 .46673 L .34905 .46783 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.34905 .46783 m .35394 .43614 L .32417 .43403 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.31604 .5 m .31808 .53327 L .34905 .53217 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.35394 .56386 m .34905 .53217 L .31808 .53327 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35104 .56322 m
.35304 .5631 L
s
.5 Mabswid
.653 .862 .647 r
.59792 .37896 m .58701 .35198 L .55932 .35415 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.58701 .35198 m .59792 .37896 L .62664 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.63794 .40542 m .62664 .37619 L .59792 .37896 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.59792 .62104 m .58701 .64802 L .61224 .65103 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.61224 .65103 m .62664 .62381 L .59792 .62104 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.38776 .34897 m .37336 .37619 L .40208 .37896 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.40208 .37896 m .41299 .35198 L .38776 .34897 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.36206 .59458 m .37336 .62381 L .40208 .62104 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.41299 .64802 m .40208 .62104 L .37336 .62381 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.40208 .62104 m .41299 .64802 L .44068 .64585 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.55932 .35415 m .5504 .32944 L .52557 .33074 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.5504 .32944 m .55932 .35415 L .58701 .35198 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.55932 .64585 m .5504 .67056 L .57376 .67271 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.57376 .67271 m .58701 .64802 L .55932 .64585 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.42624 .32729 m .41299 .35198 L .44068 .35415 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.44068 .35415 m .4496 .32944 L .42624 .32729 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.4496 .67056 m .44068 .64585 L .41299 .64802 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.44068 .64585 m .4496 .67056 L .47443 .66926 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.63794 .40542 m .64606 .43614 L .67583 .43403 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.68192 .46673 m .67583 .43403 L .64606 .43614 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.64606 .56386 m .63794 .59458 L .66575 .59752 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.66575 .59752 m .67583 .56597 L .64606 .56386 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.33425 .40248 m .32417 .43403 L .35394 .43614 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.35394 .43614 m .36206 .40542 L .33425 .40248 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.31808 .53327 m .32417 .56597 L .35394 .56386 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.36206 .59458 m .35394 .56386 L .32417 .56597 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.62664 .37619 m .63794 .40542 L .66575 .40248 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.67583 .43403 m .66575 .40248 L .63794 .40542 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.63794 .59458 m .62664 .62381 L .65178 .62734 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.65178 .62734 m .66575 .59752 L .63794 .59458 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.34822 .37266 m .33425 .40248 L .36206 .40542 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.36206 .40542 m .37336 .37619 L .34822 .37266 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.32417 .56597 m .33425 .59752 L .36206 .59458 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.37336 .62381 m .36206 .59458 L .33425 .59752 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.5 .30894 m .5 .33118 L .52557 .33074 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.5 .66882 m .5 .69106 L .52028 .69145 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.52028 .69145 m .52557 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.47972 .30855 m .47443 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.5 .33118 m .5 .30894 L .47972 .30855 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.5 .69106 m .5 .66882 L .47443 .66926 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.52557 .33074 m .52028 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.52028 .30855 m .52557 .33074 L .5504 .32944 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.52557 .66926 m .52028 .69145 L .53992 .69261 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.53992 .69261 m .5504 .67056 L .52557 .66926 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.46008 .30739 m .4496 .32944 L .47443 .33074 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.47443 .33074 m .47972 .30855 L .46008 .30739 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.47972 .69145 m .47443 .66926 L .4496 .67056 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.47443 .66926 m .47972 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.58701 .35198 m .57376 .32729 L .5504 .32944 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.57376 .32729 m .58701 .35198 L .61224 .34897 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.62664 .37619 m .61224 .34897 L .58701 .35198 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.58701 .64802 m .57376 .67271 L .59485 .67567 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.59485 .67567 m .61224 .65103 L .58701 .64802 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.40515 .32433 m .38776 .34897 L .41299 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.41299 .35198 m .42624 .32729 L .40515 .32433 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.37336 .62381 m .38776 .65103 L .41299 .64802 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.42624 .67271 m .41299 .64802 L .38776 .65103 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.41299 .64802 m .42624 .67271 L .4496 .67056 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.61224 .34897 m .62664 .37619 L .65178 .37266 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.66575 .40248 m .65178 .37266 L .62664 .37619 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.62664 .62381 m .61224 .65103 L .63408 .65483 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.63408 .65483 m .65178 .62734 L .62664 .62381 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.36592 .34517 m .34822 .37266 L .37336 .37619 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.37336 .37619 m .38776 .34897 L .36592 .34517 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.33425 .59752 m .34822 .62734 L .37336 .62381 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.38776 .65103 m .37336 .62381 L .34822 .62734 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.5504 .32944 m .53992 .30739 L .52028 .30855 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.53992 .30739 m .5504 .32944 L .57376 .32729 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.5504 .67056 m .53992 .69261 L .55826 .69453 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.55826 .69453 m .57376 .67271 L .5504 .67056 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.44174 .30547 m .42624 .32729 L .4496 .32944 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.4496 .32944 m .46008 .30739 L .44174 .30547 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.46008 .69261 m .4496 .67056 L .42624 .67271 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.4496 .67056 m .46008 .69261 L .47972 .69145 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.68192 .46673 m .68396 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.68396 .5 m .68192 .53327 L .70779 .5346 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.70779 .5346 m .71021 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.29221 .4654 m .28979 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.31604 .5 m .31808 .46673 L .29221 .4654 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.31808 .53327 m .31604 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.67583 .43403 m .68192 .46673 L .70779 .4654 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.71021 .5 m .70779 .4654 L .68192 .46673 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.68192 .53327 m .67583 .56597 L .70057 .56852 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.70057 .56852 m .70779 .5346 L .68192 .53327 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.29943 .43148 m .29221 .4654 L .31808 .46673 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.31808 .46673 m .32417 .43403 L .29943 .43148 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.28979 .5 m .29221 .5346 L .31808 .53327 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.32417 .56597 m .31808 .53327 L .29221 .5346 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.57376 .32729 m .55826 .30547 L .53992 .30739 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.55826 .30547 m .57376 .32729 L .59485 .32433 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.61224 .34897 m .59485 .32433 L .57376 .32729 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57376 .67271 m .55826 .69453 L .57465 .69716 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57465 .69716 m .59485 .67567 L .57376 .67271 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.66575 .40248 m .67583 .43403 L .70057 .43148 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.70779 .4654 m .70057 .43148 L .67583 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.31135 .39893 m .29943 .43148 L .32417 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.32417 .43403 m .33425 .40248 L .31135 .39893 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.67583 .56597 m .66575 .59752 L .68865 .60107 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.68865 .60107 m .70057 .56852 L .67583 .56597 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.29221 .5346 m .29943 .56852 L .32417 .56597 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.33425 .59752 m .32417 .56597 L .29943 .56852 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42535 .30284 m .40515 .32433 L .42624 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42624 .32729 m .44174 .30547 L .42535 .30284 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.38776 .65103 m .40515 .67567 L .42624 .67271 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.44174 .69453 m .42624 .67271 L .40515 .67567 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.42624 .67271 m .44174 .69453 L .46008 .69261 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.59485 .32433 m .61224 .34897 L .63408 .34517 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.65178 .37266 m .63408 .34517 L .61224 .34897 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61224 .65103 m .59485 .67567 L .61287 .67939 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61287 .67939 m .63408 .65483 L .61224 .65103 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38713 .32061 m .36592 .34517 L .38776 .34897 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38776 .34897 m .40515 .32433 L .38713 .32061 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.34822 .62734 m .36592 .65483 L .38776 .65103 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.40515 .67567 m .38776 .65103 L .36592 .65483 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.5 .28979 m .5 .30894 L .52028 .30855 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.48578 .28949 m .47972 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.5 .30894 m .5 .28979 L .48578 .28949 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.5 .69106 m .5 .71021 L .51422 .71051 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51422 .71051 m .52028 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.5 .71021 m .5 .69106 L .47972 .69145 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.65178 .37266 m .66575 .40248 L .68865 .39893 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.70057 .43148 m .68865 .39893 L .66575 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.32778 .36843 m .31135 .39893 L .33425 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.33425 .40248 m .34822 .37266 L .32778 .36843 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.66575 .59752 m .65178 .62734 L .67222 .63157 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.67222 .63157 m .68865 .60107 L .66575 .59752 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.29943 .56852 m .31135 .60107 L .33425 .59752 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.34822 .62734 m .33425 .59752 L .31135 .60107 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.52028 .30855 m .51422 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.51422 .28949 m .52028 .30855 L .53992 .30739 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52028 .69145 m .51422 .71051 L .52794 .71141 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52794 .71141 m .53992 .69261 L .52028 .69145 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47206 .28859 m .46008 .30739 L .47972 .30855 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47972 .30855 m .48578 .28949 L .47206 .28859 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.48578 .71051 m .47972 .69145 L .46008 .69261 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47972 .69145 m .48578 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.53992 .30739 m .52794 .28859 L .51422 .28949 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.52794 .28859 m .53992 .30739 L .55826 .30547 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.53992 .69261 m .52794 .71141 L .54066 .71288 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.54066 .71288 m .55826 .69453 L .53992 .69261 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.45934 .28712 m .44174 .30547 L .46008 .30739 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.46008 .30739 m .47206 .28859 L .45934 .28712 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.47206 .71141 m .46008 .69261 L .44174 .69453 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.46008 .69261 m .47206 .71141 L .48578 .71051 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.63408 .34517 m .65178 .37266 L .67222 .36843 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.68865 .39893 m .67222 .36843 L .65178 .37266 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65178 .62734 m .63408 .65483 L .65156 .65935 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65156 .65935 m .67222 .63157 L .65178 .62734 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34844 .34065 m .32778 .36843 L .34822 .37266 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34822 .37266 m .36592 .34517 L .34844 .34065 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.31135 .60107 m .32778 .63157 L .34822 .62734 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.36592 .65483 m .34822 .62734 L .32778 .63157 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.59485 .32433 m .57465 .30284 L .55826 .30547 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.57465 .30284 m .59485 .32433 L .61287 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.63408 .34517 m .61287 .32061 L .59485 .32433 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.59485 .67567 m .57465 .69716 L .58844 .70043 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.58844 .70043 m .61287 .67939 L .59485 .67567 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.41156 .29957 m .38713 .32061 L .40515 .32433 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.40515 .32433 m .42535 .30284 L .41156 .29957 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.36592 .65483 m .38713 .67939 L .40515 .67567 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.42535 .69716 m .40515 .67567 L .38713 .67939 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.40515 .67567 m .42535 .69716 L .44174 .69453 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.55826 .30547 m .54066 .28712 L .52794 .28859 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.54066 .28712 m .55826 .30547 L .57465 .30284 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55826 .69453 m .54066 .71288 L .55188 .71488 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55188 .71488 m .57465 .69716 L .55826 .69453 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44812 .28512 m .42535 .30284 L .44174 .30547 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44174 .30547 m .45934 .28712 L .44812 .28512 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.45934 .71288 m .44174 .69453 L .42535 .69716 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.44174 .69453 m .45934 .71288 L .47206 .71141 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.61287 .32061 m .63408 .34517 L .65156 .34065 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.67222 .36843 m .65156 .34065 L .63408 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.37301 .31621 m .34844 .34065 L .36592 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.36592 .34517 m .38713 .32061 L .37301 .31621 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.63408 .65483 m .61287 .67939 L .62699 .68379 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.62699 .68379 m .65156 .65935 L .63408 .65483 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.32778 .63157 m .34844 .65935 L .36592 .65483 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.38713 .67939 m .36592 .65483 L .34844 .65935 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.5 .27438 m .5 .28979 L .51422 .28949 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.49256 .27421 m .48578 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.5 .28979 m .5 .27438 L .49256 .27421 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.5 .71021 m .5 .72562 L .50744 .72579 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.50744 .72579 m .51422 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.27297 .46384 m .2702 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.28979 .5 m .29221 .4654 L .27297 .46384 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.29221 .5346 m .28979 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.5 .72562 m .5 .71021 L .48578 .71051 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.70779 .4654 m .71021 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.71021 .5 m .70779 .5346 L .72703 .53616 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.72703 .53616 m .7298 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.2812 .42852 m .27297 .46384 L .29221 .4654 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.29221 .4654 m .29943 .43148 L .2812 .42852 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.2702 .5 m .27297 .53616 L .29221 .5346 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.29943 .56852 m .29221 .5346 L .27297 .53616 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.70057 .43148 m .70779 .4654 L .72703 .46384 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.7298 .5 m .72703 .46384 L .70779 .4654 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.70779 .5346 m .70057 .56852 L .7188 .57148 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.7188 .57148 m .72703 .53616 L .70779 .5346 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.57465 .30284 m .55188 .28512 L .54066 .28712 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.55188 .28512 m .57465 .30284 L .58844 .29957 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.61287 .32061 m .58844 .29957 L .57465 .30284 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.57465 .69716 m .55188 .71488 L .56116 .71734 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.56116 .71734 m .58844 .70043 L .57465 .69716 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.43884 .28266 m .41156 .29957 L .42535 .30284 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.42535 .30284 m .44812 .28512 L .43884 .28266 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.38713 .67939 m .41156 .70043 L .42535 .69716 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.44812 .71488 m .42535 .69716 L .41156 .70043 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.42535 .69716 m .44812 .71488 L .45934 .71288 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51422 .28949 m .50744 .27421 L .5 .27438 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.50744 .27421 m .51422 .28949 L .52794 .28859 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51422 .71051 m .50744 .72579 L .51458 .72629 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51458 .72629 m .52794 .71141 L .51422 .71051 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48542 .27371 m .47206 .28859 L .48578 .28949 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48578 .28949 m .49256 .27421 L .48542 .27371 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.49256 .72579 m .48578 .71051 L .47206 .71141 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.48578 .71051 m .49256 .72579 L .5 .72562 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.58844 .29957 m .61287 .32061 L .62699 .31621 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.65156 .34065 m .62699 .31621 L .61287 .32061 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.61287 .67939 m .58844 .70043 L .59898 .70426 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.59898 .70426 m .62699 .68379 L .61287 .67939 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29473 .39483 m .2812 .42852 L .29943 .43148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29943 .43148 m .31135 .39893 L .29473 .39483 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.27297 .53616 m .2812 .57148 L .29943 .56852 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.31135 .60107 m .29943 .56852 L .2812 .57148 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.40102 .29574 m .37301 .31621 L .38713 .32061 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.38713 .32061 m .41156 .29957 L .40102 .29574 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.34844 .65935 m .37301 .68379 L .38713 .67939 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.41156 .70043 m .38713 .67939 L .37301 .68379 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.68865 .39893 m .70057 .43148 L .7188 .42852 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.72703 .46384 m .7188 .42852 L .70057 .43148 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70057 .56852 m .68865 .60107 L .70527 .60517 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70527 .60517 m .7188 .57148 L .70057 .56852 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.52794 .28859 m .51458 .27371 L .50744 .27421 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.51458 .27371 m .52794 .28859 L .54066 .28712 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52794 .71141 m .51458 .72629 L .52114 .72711 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52114 .72711 m .54066 .71288 L .52794 .71141 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47886 .27289 m .45934 .28712 L .47206 .28859 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47206 .28859 m .48542 .27371 L .47886 .27289 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.48542 .72629 m .47206 .71141 L .45934 .71288 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.47206 .71141 m .48542 .72629 L .49256 .72579 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31326 .36358 m .29473 .39483 L .31135 .39893 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31135 .39893 m .32778 .36843 L .31326 .36358 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.2812 .57148 m .29473 .60517 L .31135 .60107 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.32778 .63157 m .31135 .60107 L .29473 .60517 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.67222 .36843 m .68865 .39893 L .70527 .39483 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.7188 .42852 m .70527 .39483 L .68865 .39893 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68865 .60107 m .67222 .63157 L .68674 .63642 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68674 .63642 m .70527 .60517 L .68865 .60107 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.54066 .28712 m .52114 .27289 L .51458 .27371 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.52114 .27289 m .54066 .28712 L .55188 .28512 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.54066 .71288 m .52114 .72711 L .52686 .72821 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.52686 .72821 m .55188 .71488 L .54066 .71288 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.3364 .3355 m .31326 .36358 L .32778 .36843 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.32778 .36843 m .34844 .34065 L .3364 .3355 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.29473 .60517 m .31326 .63642 L .32778 .63157 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.34844 .65935 m .32778 .63157 L .31326 .63642 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.47314 .27179 m .44812 .28512 L .45934 .28712 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.45934 .28712 m .47886 .27289 L .47314 .27179 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.47886 .72711 m .45934 .71288 L .44812 .71488 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.45934 .71288 m .47886 .72711 L .48542 .72629 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.65156 .34065 m .67222 .36843 L .68674 .36358 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.70527 .39483 m .68674 .36358 L .67222 .36843 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.67222 .63157 m .65156 .65935 L .6636 .6645 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.6636 .6645 m .68674 .63642 L .67222 .63157 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.58844 .29957 m .56116 .28266 L .55188 .28512 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.56116 .28266 m .58844 .29957 L .59898 .29574 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.62699 .31621 m .59898 .29574 L .58844 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.43196 .2798 m .40102 .29574 L .41156 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.41156 .29957 m .43884 .28266 L .43196 .2798 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.58844 .70043 m .56116 .71734 L .56804 .7202 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.56804 .7202 m .59898 .70426 L .58844 .70043 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.37301 .68379 m .40102 .70426 L .41156 .70043 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.43884 .71734 m .41156 .70043 L .40102 .70426 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.41156 .70043 m .43884 .71734 L .44812 .71488 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.36362 .31126 m .3364 .3355 L .34844 .34065 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.34844 .34065 m .37301 .31621 L .36362 .31126 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.31326 .63642 m .3364 .6645 L .34844 .65935 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.37301 .68379 m .34844 .65935 L .3364 .6645 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.62699 .31621 m .65156 .34065 L .6636 .3355 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.68674 .36358 m .6636 .3355 L .65156 .34065 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.65156 .65935 m .62699 .68379 L .63638 .68874 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.63638 .68874 m .6636 .6645 L .65156 .65935 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.55188 .28512 m .52686 .27179 L .52114 .27289 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.52686 .27179 m .55188 .28512 L .56116 .28266 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.55188 .71488 m .52686 .72821 L .53149 .72956 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.53149 .72956 m .56116 .71734 L .55188 .71488 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.46851 .27044 m .43884 .28266 L .44812 .28512 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.44812 .28512 m .47314 .27179 L .46851 .27044 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.47314 .72821 m .44812 .71488 L .43884 .71734 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.44812 .71488 m .47314 .72821 L .47886 .72711 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.39434 .29148 m .36362 .31126 L .37301 .31621 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.37301 .31621 m .40102 .29574 L .39434 .29148 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.3364 .6645 m .36362 .68874 L .37301 .68379 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.40102 .70426 m .37301 .68379 L .36362 .68874 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.59898 .29574 m .62699 .31621 L .63638 .31126 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.6636 .3355 m .63638 .31126 L .62699 .31621 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.62699 .68379 m .59898 .70426 L .60566 .70852 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.60566 .70852 m .63638 .68874 L .62699 .68379 L p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50744 .27421 m .5 .26345 L .5 .27438 L closepath p F P
.505 .664 .505 r
s
.555 .774 .586 r
.5 .27438 m .5 .26345 L .49256 .27421 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50744 .72579 L .5 .72562 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .5 .72562 L .49256 .72579 L closepath p F P
.505 .664 .505 r
s
.586 .81 .618 r
.56116 .28266 m .53149 .27044 L .52686 .27179 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.53149 .27044 m .56116 .28266 L .56804 .2798 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.59898 .29574 m .56804 .2798 L .56116 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.46519 .2689 m .43196 .2798 L .43884 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.43884 .28266 m .46851 .27044 L .46519 .2689 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.56116 .71734 m .53149 .72956 L .53481 .7311 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.53481 .7311 m .56804 .7202 L .56116 .71734 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.40102 .70426 m .43196 .7202 L .43884 .71734 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.46851 .72956 m .43884 .71734 L .43196 .7202 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.43884 .71734 m .46851 .72956 L .47314 .72821 L p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51458 .27371 m .5 .26345 L .50744 .27421 L closepath p F P
.505 .664 .505 r
s
.553 .771 .583 r
.49256 .27421 m .5 .26345 L .48542 .27371 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51458 .72629 L .50744 .72579 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .49256 .72579 L .48542 .72629 L closepath p F P
.505 .664 .505 r
s
.552 .771 .585 r
.52114 .27289 m .5 .26345 L .51458 .27371 L closepath p F P
.505 .664 .505 r
s
.549 .766 .579 r
.48542 .27371 m .5 .26345 L .47886 .27289 L closepath p F P
.505 .664 .505 r
s
.197 .204 .155 r
.5 .73655 m .52114 .72711 L .51458 .72629 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .48542 .72629 L .47886 .72711 L closepath p F P
.505 .664 .505 r
s
.524 .728 .536 r
.42783 .27666 m .39434 .29148 L .40102 .29574 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.40102 .29574 m .43196 .2798 L .42783 .27666 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.36362 .68874 m .39434 .70852 L .40102 .70426 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.43196 .7202 m .40102 .70426 L .39434 .70852 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.56804 .2798 m .59898 .29574 L .60566 .29148 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.63638 .31126 m .60566 .29148 L .59898 .29574 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.59898 .70426 m .56804 .7202 L .57217 .72334 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.57217 .72334 m .60566 .70852 L .59898 .70426 L p F P
.505 .664 .505 r
s
.548 .765 .582 r
.52686 .27179 m .5 .26345 L .52114 .27289 L closepath p F P
.505 .664 .505 r
s
.543 .759 .573 r
.47886 .27289 m .5 .26345 L .47314 .27179 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .52686 .72821 L .52114 .72711 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .47886 .72711 L .47314 .72821 L closepath p F P
.505 .664 .505 r
s
.541 .758 .578 r
.53149 .27044 m .5 .26345 L .52686 .27179 L closepath p F P
.505 .664 .505 r
s
.535 .75 .567 r
.47314 .27179 m .5 .26345 L .46851 .27044 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .53149 .72956 L .52686 .72821 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .47314 .72821 L .46851 .72956 L closepath p F P
.505 .664 .505 r
s
.279 .362 .238 r
.26206 .46211 m .25902 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.2702 .5 m .27297 .46384 L .26206 .46211 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.27297 .53616 m .2702 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.72703 .46384 m .7298 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.7298 .5 m .72703 .53616 L .73794 .53789 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.73794 .53789 m .74098 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27109 .42521 m .26206 .46211 L .27297 .46384 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27297 .46384 m .2812 .42852 L .27109 .42521 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.25902 .5 m .26206 .53789 L .27297 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.2812 .57148 m .27297 .53616 L .26206 .53789 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.7188 .42852 m .72703 .46384 L .73794 .46211 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.74098 .5 m .73794 .46211 L .72703 .46384 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72703 .53616 m .7188 .57148 L .72891 .57479 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72891 .57479 m .73794 .53789 L .72703 .53616 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.28585 .39028 m .27109 .42521 L .2812 .42852 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.2812 .42852 m .29473 .39483 L .28585 .39028 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.26206 .53789 m .27109 .57479 L .2812 .57148 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.29473 .60517 m .2812 .57148 L .27109 .57479 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.70527 .39483 m .7188 .42852 L .72891 .42521 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.73794 .46211 m .72891 .42521 L .7188 .42852 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.7188 .57148 m .70527 .60517 L .71415 .60972 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.71415 .60972 m .72891 .57479 L .7188 .57148 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.46333 .26722 m .42783 .27666 L .43196 .2798 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.43196 .2798 m .46519 .2689 L .46333 .26722 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.39434 .70852 m .42783 .72334 L .43196 .7202 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.46519 .7311 m .43196 .7202 L .42783 .72334 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.43196 .7202 m .46519 .7311 L .46851 .72956 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.56804 .2798 m .53481 .2689 L .53149 .27044 L p F P
.505 .664 .505 r
s
.544 .761 .586 r
.53481 .2689 m .56804 .2798 L .57217 .27666 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.60566 .29148 m .57217 .27666 L .56804 .2798 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.56804 .7202 m .53481 .7311 L .53667 .73278 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.53667 .73278 m .57217 .72334 L .56804 .7202 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.30594 .35823 m .28585 .39028 L .29473 .39483 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.29473 .39483 m .31326 .36358 L .30594 .35823 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.27109 .57479 m .28585 .60972 L .29473 .60517 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.31326 .63642 m .29473 .60517 L .28585 .60972 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.68674 .36358 m .70527 .39483 L .71415 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.72891 .42521 m .71415 .39028 L .70527 .39483 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.70527 .60517 m .68674 .63642 L .69406 .64177 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.69406 .64177 m .71415 .60972 L .70527 .60517 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.33081 .32987 m .30594 .35823 L .31326 .36358 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.31326 .36358 m .3364 .3355 L .33081 .32987 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.28585 .60972 m .30594 .64177 L .31326 .63642 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.3364 .6645 m .31326 .63642 L .30594 .64177 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.6636 .3355 m .68674 .36358 L .69406 .35823 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.71415 .39028 m .69406 .35823 L .68674 .36358 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.68674 .63642 m .6636 .6645 L .66919 .67013 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.66919 .67013 m .69406 .64177 L .68674 .63642 L p F P
.505 .664 .505 r
s
.533 .749 .571 r
.53481 .2689 m .5 .26345 L .53149 .27044 L closepath p F P
.505 .664 .505 r
s
.527 .74 .559 r
.46851 .27044 m .5 .26345 L .46519 .2689 L closepath p F P
.505 .664 .505 r
s
.183 .19 .145 r
.5 .73655 m .53481 .7311 L .53149 .72956 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .46851 .72956 L .46519 .7311 L closepath p F P
.505 .664 .505 r
s
.425 .593 .423 r
.35976 .30591 m .33081 .32987 L .3364 .3355 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.3364 .3355 m .36362 .31126 L .35976 .30591 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.30594 .64177 m .33081 .67013 L .3364 .6645 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.36362 .68874 m .3364 .6645 L .33081 .67013 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.63638 .31126 m .6636 .3355 L .66919 .32987 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.69406 .35823 m .66919 .32987 L .6636 .3355 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.6636 .6645 m .63638 .68874 L .64024 .69409 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.64024 .69409 m .66919 .67013 L .6636 .6645 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.39203 .28693 m .35976 .30591 L .36362 .31126 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.36362 .31126 m .39434 .29148 L .39203 .28693 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.33081 .67013 m .35976 .69409 L .36362 .68874 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.39434 .70852 m .36362 .68874 L .35976 .69409 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.60566 .29148 m .63638 .31126 L .64024 .30591 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.66919 .32987 m .64024 .30591 L .63638 .31126 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.63638 .68874 m .60566 .70852 L .60797 .71307 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.60797 .71307 m .64024 .69409 L .63638 .68874 L p F P
.505 .664 .505 r
s
.517 .728 .55 r
.46519 .2689 m .5 .26345 L .46333 .26722 L closepath p F P
.505 .664 .505 r
s
.524 .738 .564 r
.53667 .26722 m .5 .26345 L .53481 .2689 L closepath p F P
.505 .664 .505 r
s
.544 .761 .586 r
.57217 .27666 m .53667 .26722 L .53481 .2689 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42783 .72334 m .46333 .73278 L .46519 .7311 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .46519 .7311 L .46333 .73278 L closepath p F P
.505 .664 .505 r
s
.176 .185 .14 r
.5 .73655 m .53667 .73278 L .53481 .7311 L closepath p F P
.505 .664 .505 r
s
.475 .67 .494 r
.42676 .27336 m .39203 .28693 L .39434 .29148 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.39434 .29148 m .42783 .27666 L .42676 .27336 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.35976 .69409 m .39203 .71307 L .39434 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.42783 .72334 m .39434 .70852 L .39203 .71307 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.57217 .27666 m .60566 .29148 L .60797 .28693 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.64024 .30591 m .60797 .28693 L .60566 .29148 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.60566 .70852 m .57217 .72334 L .57324 .72664 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.57324 .72664 m .60797 .71307 L .60566 .70852 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.46306 .26549 m .42676 .27336 L .42783 .27666 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.42783 .27666 m .46333 .26722 L .46306 .26549 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.39203 .71307 m .42676 .72664 L .42783 .72334 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.46333 .73278 m .42783 .72334 L .42676 .72664 L p F P
.505 .664 .505 r
s
.515 .726 .562 r
.53667 .26722 m .57217 .27666 L .57324 .27336 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.60797 .28693 m .57324 .27336 L .57217 .27666 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.57217 .72334 m .53667 .73278 L .53694 .73451 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.53694 .73451 m .57324 .72664 L .57217 .72334 L p F P
.505 .664 .505 r
s
.506 .715 .541 r
.46333 .26722 m .5 .26345 L .46306 .26549 L closepath p F P
.505 .664 .505 r
s
.177 .185 .14 r
.42676 .72664 m .46306 .73451 L .46333 .73278 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .46333 .73278 L .46306 .73451 L closepath p F P
.505 .664 .505 r
s
.514 .725 .555 r
.53694 .26549 m .5 .26345 L .53667 .26722 L closepath p F P
.505 .664 .505 r
s
.515 .726 .562 r
.57324 .27336 m .53694 .26549 L .53667 .26722 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .53694 .73451 L .53667 .73278 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .53558 .73624 L .53694 .73451 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .53263 .73787 L .53558 .73624 L closepath p F P
.505 .664 .505 r
s
.149 .16 .121 r
.5 .73655 m .52817 .73933 L .53263 .73787 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .73655 m .5224 .74056 L .52817 .73933 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .51556 .74148 L .5224 .74056 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50797 .74206 L .51556 .74148 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .5 .74225 L .50797 .74206 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49203 .74206 L .5 .74225 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .48444 .74148 L .49203 .74206 L closepath p F P
.505 .664 .505 r
s
.141 .152 .116 r
.5 .73655 m .4776 .74056 L .48444 .74148 L closepath p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .73655 m .47183 .73933 L .4776 .74056 L closepath p F P
.505 .664 .505 r
s
.152 .162 .123 r
.5 .73655 m .46737 .73787 L .47183 .73933 L closepath p F P
.505 .664 .505 r
s
.159 .168 .128 r
.5 .73655 m .46442 .73624 L .46737 .73787 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .46306 .73451 L .46442 .73624 L closepath p F P
.505 .664 .505 r
s
.503 .712 .546 r
.53558 .26376 m .5 .26345 L .53694 .26549 L closepath p F P
.505 .664 .505 r
s
.496 .702 .532 r
.46306 .26549 m .5 .26345 L .46442 .26376 L closepath p F P
.505 .664 .505 r
s
.492 .698 .536 r
.53263 .26213 m .5 .26345 L .53558 .26376 L closepath p F P
.505 .664 .505 r
s
.485 .689 .523 r
.46442 .26376 m .5 .26345 L .46737 .26213 L closepath p F P
.505 .664 .505 r
s
.481 .685 .526 r
.52817 .26067 m .5 .26345 L .53263 .26213 L closepath p F P
.505 .664 .505 r
s
.475 .677 .515 r
.46737 .26213 m .5 .26345 L .47183 .26067 L closepath p F P
.505 .664 .505 r
s
.471 .673 .518 r
.5224 .25944 m .5 .26345 L .52817 .26067 L closepath p F P
.505 .664 .505 r
s
.466 .667 .508 r
.47183 .26067 m .5 .26345 L .4776 .25944 L closepath p F P
.505 .664 .505 r
s
.463 .663 .51 r
.51556 .25852 m .5 .26345 L .5224 .25944 L closepath p F P
.505 .664 .505 r
s
.459 .658 .503 r
.4776 .25944 m .5 .26345 L .48444 .25852 L closepath p F P
.505 .664 .505 r
s
.457 .656 .504 r
.50797 .25794 m .5 .26345 L .51556 .25852 L closepath p F P
.505 .664 .505 r
s
.453 .652 .5 r
.5 .25775 m .5 .26345 L .50797 .25794 L closepath p F P
.505 .664 .505 r
s
.455 .653 .499 r
.48444 .25852 m .5 .26345 L .49203 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49203 .25794 m .5 .26345 L .5 .25775 L closepath p F P
.505 .664 .505 r
s
.155 .165 .125 r
.42894 .72997 m .46442 .73624 L .46306 .73451 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.46306 .73451 m .42676 .72664 L .42894 .72997 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.42676 .27336 m .46306 .26549 L .46442 .26376 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.57324 .72664 m .53694 .73451 L .53558 .73624 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.53694 .26549 m .57324 .27336 L .57106 .27003 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.57106 .27003 m .53558 .26376 L .53694 .26549 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.3945 .71771 m .42894 .72997 L .42676 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.42676 .72664 m .39203 .71307 L .3945 .71771 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.46442 .26376 m .42894 .27003 L .42676 .27336 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.39203 .28693 m .42676 .27336 L .42894 .27003 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60797 .71307 m .57324 .72664 L .57106 .72997 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.53558 .73624 m .57106 .72997 L .57324 .72664 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.57324 .27336 m .60797 .28693 L .6055 .28229 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.6055 .28229 m .57106 .27003 L .57324 .27336 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.36207 .69962 m .3945 .71771 L .39203 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.39203 .71307 m .35976 .69409 L .36207 .69962 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.42894 .27003 m .3945 .28229 L .39203 .28693 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.35976 .30591 m .39203 .28693 L .3945 .28229 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.64024 .69409 m .60797 .71307 L .6055 .71771 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.57106 .72997 m .6055 .71771 L .60797 .71307 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.60797 .28693 m .64024 .30591 L .63793 .30038 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.63793 .30038 m .6055 .28229 L .60797 .28693 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.43439 .73316 m .46737 .73787 L .46442 .73624 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.46442 .73624 m .42894 .72997 L .43439 .73316 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.42894 .27003 m .46442 .26376 L .46737 .26213 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.57106 .72997 m .53558 .73624 L .53263 .73787 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.53558 .26376 m .57106 .27003 L .56561 .26684 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.56561 .26684 m .53263 .26213 L .53558 .26376 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.33261 .67601 m .36207 .69962 L .35976 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.35976 .69409 m .33081 .67013 L .33261 .67601 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.3945 .28229 m .36207 .30038 L .35976 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.33081 .32987 m .35976 .30591 L .36207 .30038 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.66919 .67013 m .64024 .69409 L .63793 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.6055 .71771 m .63793 .69962 L .64024 .69409 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.64024 .30591 m .66919 .32987 L .66739 .32399 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.66739 .32399 m .63793 .30038 L .64024 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.36207 .30038 m .33261 .32399 L .33081 .32987 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.30594 .35823 m .33081 .32987 L .33261 .32399 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.30703 .64742 m .33261 .67601 L .33081 .67013 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.33081 .67013 m .30594 .64177 L .30703 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.69406 .64177 m .66919 .67013 L .66739 .67601 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.63793 .69962 m .66739 .67601 L .66919 .67013 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.66919 .32987 m .69406 .35823 L .69297 .35258 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.69297 .35258 m .66739 .32399 L .66919 .32987 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.443 .73607 m .47183 .73933 L .46737 .73787 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.46737 .73787 m .43439 .73316 L .443 .73607 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.43439 .26684 m .46737 .26213 L .47183 .26067 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.46737 .26213 m .43439 .26684 L .42894 .27003 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.53263 .73787 m .56561 .73316 L .57106 .72997 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.56561 .73316 m .53263 .73787 L .52817 .73933 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.53263 .26213 m .56561 .26684 L .557 .26393 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.557 .26393 m .52817 .26067 L .53263 .26213 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.33261 .32399 m .30703 .35258 L .30594 .35823 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.28585 .39028 m .30594 .35823 L .30703 .35258 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.28616 .61456 m .30703 .64742 L .30594 .64177 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.30594 .64177 m .28585 .60972 L .28616 .61456 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.69406 .35823 m .71415 .39028 L .71384 .38544 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.71384 .38544 m .69297 .35258 L .69406 .35823 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.71415 .60972 m .69406 .64177 L .69297 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66739 .67601 m .69297 .64742 L .69406 .64177 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.27072 .57833 m .28616 .61456 L .28585 .60972 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.28585 .60972 m .27109 .57479 L .27072 .57833 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.30703 .35258 m .28616 .38544 L .28585 .39028 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.27109 .42521 m .28585 .39028 L .28616 .38544 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.72891 .57479 m .71415 .60972 L .71384 .61456 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.69297 .64742 m .71384 .61456 L .71415 .60972 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.71415 .39028 m .72891 .42521 L .72928 .42167 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.72928 .42167 m .71384 .38544 L .71415 .39028 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.40194 .72224 m .43439 .73316 L .42894 .72997 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.42894 .72997 m .3945 .71771 L .40194 .72224 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.3945 .28229 m .42894 .27003 L .43439 .26684 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.6055 .71771 m .57106 .72997 L .56561 .73316 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.57106 .27003 m .6055 .28229 L .59806 .27776 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.59806 .27776 m .56561 .26684 L .57106 .27003 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.28616 .38544 m .27072 .42167 L .27109 .42521 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.26206 .46211 m .27109 .42521 L .27072 .42167 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.26123 .53976 m .27072 .57833 L .27109 .57479 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.27109 .57479 m .26206 .53789 L .26123 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.73794 .53789 m .72891 .57479 L .72928 .57833 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.71384 .61456 m .72928 .57833 L .72891 .57479 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.72891 .42521 m .73794 .46211 L .73877 .46024 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.73877 .46024 m .72928 .42167 L .72891 .42521 L p F P
.505 .664 .505 r
s
.141 .198 .13 r
.27072 .42167 m .26123 .46024 L .26206 .46211 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.25902 .5 m .26206 .46211 L .26123 .46024 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.25803 .5 m .26123 .53976 L .26206 .53789 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.26206 .53789 m .25902 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.73794 .46211 m .74098 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.74197 .5 m .73877 .46024 L .73794 .46211 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.74098 .5 m .73794 .53789 L .73877 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.72928 .57833 m .73877 .53976 L .73794 .53789 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.26123 .46024 m .25803 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.73877 .53976 m .74197 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.45445 .73853 m .4776 .74056 L .47183 .73933 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.47183 .73933 m .443 .73607 L .45445 .73853 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.443 .26393 m .47183 .26067 L .4776 .25944 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.47183 .26067 m .443 .26393 L .43439 .26684 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.52817 .73933 m .557 .73607 L .56561 .73316 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.557 .73607 m .52817 .73933 L .5224 .74056 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.52817 .26067 m .557 .26393 L .54555 .26147 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.54555 .26147 m .5224 .25944 L .52817 .26067 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.46823 .7404 m .48444 .74148 L .4776 .74056 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.4776 .74056 m .45445 .73853 L .46823 .7404 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.45445 .26147 m .4776 .25944 L .48444 .25852 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.4776 .25944 m .45445 .26147 L .443 .26393 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.5224 .74056 m .54555 .73853 L .557 .73607 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.54555 .73853 m .5224 .74056 L .51556 .74148 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.5224 .25944 m .54555 .26147 L .53177 .2596 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.53177 .2596 m .51556 .25852 L .5224 .25944 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.43439 .26684 m .40194 .27776 L .3945 .28229 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.36207 .30038 m .3945 .28229 L .40194 .27776 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.37097 .70507 m .40194 .72224 L .3945 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.3945 .71771 m .36207 .69962 L .37097 .70507 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63793 .69962 m .6055 .71771 L .59806 .72224 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.56561 .73316 m .59806 .72224 L .6055 .71771 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.6055 .28229 m .63793 .30038 L .62903 .29493 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.62903 .29493 m .59806 .27776 L .6055 .28229 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48368 .74157 m .49203 .74206 L .48444 .74148 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48444 .74148 m .46823 .7404 L .48368 .74157 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.51556 .74148 m .53177 .7404 L .54555 .73853 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.53177 .7404 m .51556 .74148 L .50797 .74206 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.46823 .2596 m .48444 .25852 L .49203 .25794 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.48444 .25852 m .46823 .2596 L .45445 .26147 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51556 .25852 m .53177 .2596 L .51632 .25843 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51632 .25843 m .50797 .25794 L .51556 .25852 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.5 .74197 m .5 .74225 L .49203 .74206 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.49203 .74206 m .48368 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.50797 .74206 m .51632 .74157 L .53177 .7404 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.51632 .74157 m .50797 .74206 L .5 .74225 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.49203 .25794 m .48368 .25843 L .46823 .2596 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.48368 .25843 m .49203 .25794 L .5 .25775 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50797 .25794 m .51632 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.5 .25803 m .5 .25775 L .50797 .25794 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.41427 .7264 m .443 .73607 L .43439 .73316 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.43439 .73316 m .40194 .72224 L .41427 .7264 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.40194 .27776 m .43439 .26684 L .443 .26393 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .56561 .73316 L .557 .73607 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.56561 .26684 m .59806 .27776 L .58573 .2736 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.58573 .2736 m .557 .26393 L .56561 .26684 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.5 .74225 m .5 .74197 L .51632 .74157 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.5 .25775 m .5 .25803 L .48368 .25843 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.34248 .68188 m .37097 .70507 L .36207 .69962 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.36207 .69962 m .33261 .67601 L .34248 .68188 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.40194 .27776 m .37097 .29493 L .36207 .30038 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.33261 .32399 m .36207 .30038 L .37097 .29493 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.63793 .30038 m .66739 .32399 L .65752 .31812 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.65752 .31812 m .62903 .29493 L .63793 .30038 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .62903 .70507 L .63793 .69962 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.66739 .67601 m .63793 .69962 L .62903 .70507 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.43113 .72997 m .45445 .73853 L .443 .73607 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.443 .73607 m .41427 .7264 L .43113 .72997 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.443 .26393 m .41427 .2736 L .40194 .27776 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.41427 .2736 m .443 .26393 L .45445 .26147 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.557 .73607 m .58573 .7264 L .59806 .72224 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.58573 .7264 m .557 .73607 L .54555 .73853 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.557 .26393 m .58573 .2736 L .56887 .27003 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.56887 .27003 m .54555 .26147 L .557 .26393 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.31748 .65312 m .34248 .68188 L .33261 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.33261 .67601 m .30703 .64742 L .31748 .65312 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.37097 .29493 m .34248 .31812 L .33261 .32399 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.30703 .35258 m .33261 .32399 L .34248 .31812 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.69297 .64742 m .66739 .67601 L .65752 .68188 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.62903 .70507 m .65752 .68188 L .66739 .67601 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.66739 .32399 m .69297 .35258 L .68252 .34688 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.68252 .34688 m .65752 .31812 L .66739 .32399 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.38653 .71016 m .41427 .7264 L .40194 .72224 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.40194 .72224 m .37097 .70507 L .38653 .71016 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.37097 .29493 m .40194 .27776 L .41427 .2736 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.62903 .70507 m .59806 .72224 L .58573 .7264 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.59806 .27776 m .62903 .29493 L .61347 .28984 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.61347 .28984 m .58573 .2736 L .59806 .27776 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45177 .7327 m .46823 .7404 L .45445 .73853 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45445 .73853 m .43113 .72997 L .45177 .7327 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.43113 .27003 m .45445 .26147 L .46823 .2596 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.45445 .26147 m .43113 .27003 L .41427 .2736 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.34248 .31812 m .31748 .34688 L .30703 .35258 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.28616 .38544 m .30703 .35258 L .31748 .34688 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.2969 .61949 m .31748 .65312 L .30703 .64742 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.30703 .64742 m .28616 .61456 L .2969 .61949 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.54555 .73853 m .56887 .72997 L .58573 .7264 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.56887 .72997 m .54555 .73853 L .53177 .7404 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54555 .26147 m .56887 .27003 L .54823 .2673 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54823 .2673 m .53177 .2596 L .54555 .26147 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.69297 .35258 m .71384 .38544 L .7031 .38051 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.7031 .38051 m .68252 .34688 L .69297 .35258 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.71384 .61456 m .69297 .64742 L .68252 .65312 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.65752 .68188 m .68252 .65312 L .69297 .64742 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28156 .58196 m .2969 .61949 L .28616 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28616 .61456 m .27072 .57833 L .28156 .58196 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.31748 .34688 m .2969 .38051 L .28616 .38544 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.27072 .42167 m .28616 .38544 L .2969 .38051 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.72928 .57833 m .71384 .61456 L .7031 .61949 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.68252 .65312 m .7031 .61949 L .71384 .61456 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71384 .38544 m .72928 .42167 L .71844 .41804 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71844 .41804 m .7031 .38051 L .71384 .38544 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.47517 .73443 m .48368 .74157 L .46823 .7404 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.46823 .7404 m .45177 .7327 L .47517 .73443 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.45177 .2673 m .46823 .2596 L .48368 .25843 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.46823 .2596 m .45177 .2673 L .43113 .27003 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.53177 .7404 m .54823 .7327 L .56887 .72997 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53177 .2596 m .54823 .2673 L .52483 .26557 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.52483 .26557 m .51632 .25843 L .53177 .2596 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.54823 .7327 m .53177 .7404 L .51632 .74157 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.36072 .68742 m .38653 .71016 L .37097 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.37097 .70507 m .34248 .68188 L .36072 .68742 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27208 .54168 m .28156 .58196 L .27072 .57833 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27072 .57833 m .26123 .53976 L .27208 .54168 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.41427 .2736 m .38653 .28984 L .37097 .29493 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.34248 .31812 m .37097 .29493 L .38653 .28984 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.2969 .38051 m .28156 .41804 L .27072 .42167 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.26123 .46024 m .27072 .42167 L .28156 .41804 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.65752 .68188 m .62903 .70507 L .61347 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.58573 .7264 m .61347 .71016 L .62903 .70507 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.62903 .29493 m .65752 .31812 L .63928 .31258 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.63928 .31258 m .61347 .28984 L .62903 .29493 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.73877 .53976 m .72928 .57833 L .71844 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.7031 .61949 m .71844 .58196 L .72928 .57833 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72928 .42167 m .73877 .46024 L .72792 .45832 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72792 .45832 m .71844 .41804 L .72928 .42167 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.5 .73502 m .5 .74197 L .48368 .74157 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.48368 .74157 m .47517 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.51632 .74157 m .52483 .73443 L .54823 .7327 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.52483 .73443 m .51632 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.47517 .26557 m .48368 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.48368 .25843 m .47517 .26557 L .45177 .2673 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.51632 .25843 m .52483 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .26498 m .5 .25803 L .51632 .25843 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.40837 .71456 m .43113 .72997 L .41427 .7264 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.41427 .7264 m .38653 .71016 L .40837 .71456 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.38653 .28984 m .41427 .2736 L .43113 .27003 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.61347 .71016 m .58573 .7264 L .56887 .72997 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.58573 .2736 m .61347 .28984 L .59163 .28544 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.59163 .28544 m .56887 .27003 L .58573 .2736 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.28156 .41804 m .27208 .45832 L .26123 .46024 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.25803 .5 m .26123 .46024 L .27208 .45832 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26887 .5 m .27208 .54168 L .26123 .53976 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26123 .53976 m .25803 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73877 .46024 m .74197 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73113 .5 m .72792 .45832 L .73877 .46024 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.74197 .5 m .73877 .53976 L .72792 .54168 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.71844 .58196 m .72792 .54168 L .73877 .53976 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.5 .74197 m .5 .73502 L .52483 .73443 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .25803 m .5 .26498 L .47517 .26557 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.27208 .45832 m .26887 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.72792 .54168 m .73113 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.33783 .65855 m .36072 .68742 L .34248 .68188 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.34248 .68188 m .31748 .65312 L .33783 .65855 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.38653 .28984 m .36072 .31258 L .34248 .31812 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.31748 .34688 m .34248 .31812 L .36072 .31258 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.68252 .65312 m .65752 .68188 L .63928 .68742 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.61347 .71016 m .63928 .68742 L .65752 .68188 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.65752 .31812 m .68252 .34688 L .66217 .34145 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.66217 .34145 m .63928 .31258 L .65752 .31812 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43559 .71798 m .45177 .7327 L .43113 .72997 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43113 .72997 m .40837 .71456 L .43559 .71798 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.40837 .28544 m .43113 .27003 L .45177 .2673 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.43113 .27003 m .40837 .28544 L .38653 .28984 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.56887 .72997 m .59163 .71456 L .61347 .71016 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.59163 .71456 m .56887 .72997 L .54823 .7327 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56887 .27003 m .59163 .28544 L .56441 .28202 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56441 .28202 m .54823 .2673 L .56887 .27003 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38699 .69227 m .40837 .71456 L .38653 .71016 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38653 .71016 m .36072 .68742 L .38699 .69227 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.36072 .31258 m .38653 .28984 L .40837 .28544 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.63928 .68742 m .61347 .71016 L .59163 .71456 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61347 .28984 m .63928 .31258 L .61301 .30773 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61301 .30773 m .59163 .28544 L .61347 .28984 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.36072 .31258 m .33783 .34145 L .31748 .34688 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.2969 .38051 m .31748 .34688 L .33783 .34145 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31882 .62423 m .33783 .65855 L .31748 .65312 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31748 .65312 m .2969 .61949 L .31882 .62423 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68252 .34688 m .7031 .38051 L .68118 .37577 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68118 .37577 m .66217 .34145 L .68252 .34688 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.7031 .61949 m .68252 .65312 L .66217 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.63928 .68742 m .66217 .65855 L .68252 .65312 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.46675 .72014 m .47517 .73443 L .45177 .7327 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.45177 .7327 m .43559 .71798 L .46675 .72014 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.43559 .28202 m .45177 .2673 L .47517 .26557 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.45177 .2673 m .43559 .28202 L .40837 .28544 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.54823 .7327 m .56441 .71798 L .59163 .71456 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.56441 .71798 m .54823 .7327 L .52483 .73443 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.54823 .2673 m .56441 .28202 L .53325 .27986 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.53325 .27986 m .52483 .26557 L .54823 .2673 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.5 .72088 m .5 .73502 L .47517 .73443 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.47517 .73443 m .46675 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.52483 .73443 m .53325 .72014 L .56441 .71798 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.53325 .72014 m .52483 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.46675 .27986 m .47517 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.47517 .26557 m .46675 .27986 L .43559 .28202 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.52483 .26557 m .53325 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.5 .27912 m .5 .26498 L .52483 .26557 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.30454 .58546 m .31882 .62423 L .2969 .61949 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.2969 .61949 m .28156 .58196 L .30454 .58546 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.33783 .34145 m .31882 .37577 L .2969 .38051 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.28156 .41804 m .2969 .38051 L .31882 .37577 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.71844 .58196 m .7031 .61949 L .68118 .62423 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.66217 .65855 m .68118 .62423 L .7031 .61949 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.7031 .38051 m .71844 .41804 L .69546 .41454 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.69546 .41454 m .68118 .37577 L .7031 .38051 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.5 .73502 m .5 .72088 L .53325 .72014 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5 .26498 m .5 .27912 L .46675 .27986 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36786 .66334 m .38699 .69227 L .36072 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36072 .68742 m .33783 .65855 L .36786 .66334 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.40837 .28544 m .38699 .30773 L .36072 .31258 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.33783 .34145 m .36072 .31258 L .38699 .30773 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.66217 .65855 m .63928 .68742 L .61301 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.59163 .71456 m .61301 .69227 L .63928 .68742 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63928 .31258 m .66217 .34145 L .63214 .33666 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63214 .33666 m .61301 .30773 L .63928 .31258 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.38699 .30773 m .40837 .28544 L .43559 .28202 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.42026 .69605 m .43559 .71798 L .40837 .71456 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.40837 .71456 m .38699 .69227 L .42026 .69605 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.29568 .54355 m .30454 .58546 L .28156 .58196 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.28156 .58196 m .27208 .54168 L .29568 .54355 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.31882 .37577 m .30454 .41454 L .28156 .41804 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.27208 .45832 m .28156 .41804 L .30454 .41454 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.61301 .69227 m .59163 .71456 L .56441 .71798 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.59163 .28544 m .61301 .30773 L .57974 .30395 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.57974 .30395 m .56441 .28202 L .59163 .28544 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.72792 .54168 m .71844 .58196 L .69546 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.68118 .62423 m .69546 .58546 L .71844 .58196 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.71844 .41804 m .72792 .45832 L .70432 .45645 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.70432 .45645 m .69546 .41454 L .71844 .41804 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.30454 .41454 m .29568 .45645 L .27208 .45832 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.26887 .5 m .27208 .45832 L .29568 .45645 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.29268 .5 m .29568 .54355 L .27208 .54168 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.27208 .54168 m .26887 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.72792 .45832 m .73113 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.70732 .5 m .70432 .45645 L .72792 .45832 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.73113 .5 m .72792 .54168 L .70432 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.69546 .58546 m .70432 .54355 L .72792 .54168 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.29568 .45645 m .29268 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.70432 .54355 m .70732 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.45874 .69847 m .46675 .72014 L .43559 .71798 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.43559 .71798 m .42026 .69605 L .45874 .69847 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.42026 .30395 m .43559 .28202 L .46675 .27986 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.43559 .28202 m .42026 .30395 L .38699 .30773 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.56441 .71798 m .57974 .69605 L .61301 .69227 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.57974 .69605 m .56441 .71798 L .53325 .72014 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.56441 .28202 m .57974 .30395 L .54126 .30153 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.54126 .30153 m .53325 .27986 L .56441 .28202 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.38699 .30773 m .36786 .33666 L .33783 .34145 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.31882 .37577 m .33783 .34145 L .36786 .33666 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.35184 .62843 m .36786 .66334 L .33783 .65855 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.33783 .65855 m .31882 .62423 L .35184 .62843 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.66217 .34145 m .68118 .37577 L .64816 .37157 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.64816 .37157 m .63214 .33666 L .66217 .34145 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.68118 .62423 m .66217 .65855 L .63214 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.61301 .69227 m .63214 .66334 L .66217 .65855 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.40645 .66711 m .42026 .69605 L .38699 .69227 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.38699 .69227 m .36786 .66334 L .40645 .66711 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.36786 .33666 m .38699 .30773 L .42026 .30395 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.61301 .30773 m .63214 .33666 L .59355 .33289 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.59355 .33289 m .57974 .30395 L .61301 .30773 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.63214 .66334 m .61301 .69227 L .57974 .69605 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.5 .6993 m .5 .72088 L .46675 .72014 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.46675 .72014 m .45874 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.53325 .72014 m .54126 .69847 L .57974 .69605 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.54126 .69847 m .53325 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45874 .30153 m .46675 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.46675 .27986 m .45874 .30153 L .42026 .30395 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.53325 .27986 m .54126 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.5 .3007 m .5 .27912 L .53325 .27986 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.5 .72088 m .5 .6993 L .54126 .69847 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.5 .27912 m .5 .3007 L .45874 .30153 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.33974 .58859 m .35184 .62843 L .31882 .62423 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.31882 .62423 m .30454 .58546 L .33974 .58859 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.36786 .33666 m .35184 .37157 L .31882 .37577 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.30454 .41454 m .31882 .37577 L .35184 .37157 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.68118 .37577 m .69546 .41454 L .66026 .41141 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.66026 .41141 m .64816 .37157 L .68118 .37577 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.69546 .58546 m .68118 .62423 L .64816 .62843 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.63214 .66334 m .64816 .62843 L .68118 .62423 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.3322 .54522 m .33974 .58859 L .30454 .58546 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.30454 .58546 m .29568 .54355 L .3322 .54522 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.35184 .37157 m .33974 .41141 L .30454 .41454 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.29568 .45645 m .30454 .41454 L .33974 .41141 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.70432 .54355 m .69546 .58546 L .66026 .58859 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.64816 .62843 m .66026 .58859 L .69546 .58546 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.69546 .41454 m .70432 .45645 L .6678 .45478 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.6678 .45478 m .66026 .41141 L .69546 .41454 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.45149 .66953 m .45874 .69847 L .42026 .69605 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.42026 .69605 m .40645 .66711 L .45149 .66953 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.40645 .33289 m .42026 .30395 L .45874 .30153 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.42026 .30395 m .40645 .33289 L .36786 .33666 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.57974 .69605 m .59355 .66711 L .63214 .66334 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.59355 .66711 m .57974 .69605 L .54126 .69847 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.57974 .30395 m .59355 .33289 L .54851 .33047 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.54851 .33047 m .54126 .30153 L .57974 .30395 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.35184 .37157 m .36786 .33666 L .40645 .33289 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.39481 .63177 m .40645 .66711 L .36786 .66334 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.36786 .66334 m .35184 .62843 L .39481 .63177 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.63214 .33666 m .64816 .37157 L .60519 .36823 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.60519 .36823 m .59355 .33289 L .63214 .33666 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.64816 .62843 m .63214 .66334 L .59355 .66711 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.33974 .41141 m .3322 .45478 L .29568 .45645 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.29268 .5 m .29568 .45645 L .3322 .45478 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.32963 .5 m .3322 .54522 L .29568 .54355 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.29568 .54355 m .29268 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.70432 .45645 m .70732 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.67037 .5 m .6678 .45478 L .70432 .45645 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.70732 .5 m .70432 .54355 L .6678 .54522 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.66026 .58859 m .6678 .54522 L .70432 .54355 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.3322 .45478 m .32963 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.6678 .54522 m .67037 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.5 .67037 m .5 .6993 L .45874 .69847 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.45874 .69847 m .45149 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.45149 .33047 m .45874 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.45874 .30153 m .45149 .33047 L .40645 .33289 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.54126 .69847 m .54851 .66953 L .59355 .66711 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.54851 .66953 m .54126 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.54126 .30153 m .54851 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.5 .32963 m .5 .3007 L .54126 .30153 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.5 .6993 m .5 .67037 L .54851 .66953 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.5 .3007 m .5 .32963 L .45149 .33047 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.38598 .59108 m .39481 .63177 L .35184 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.35184 .62843 m .33974 .58859 L .38598 .59108 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.40645 .33289 m .39481 .36823 L .35184 .37157 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.33974 .41141 m .35184 .37157 L .39481 .36823 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.66026 .58859 m .64816 .62843 L .60519 .63177 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.59355 .66711 m .60519 .63177 L .64816 .62843 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.64816 .37157 m .66026 .41141 L .61402 .40892 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.61402 .40892 m .60519 .36823 L .64816 .37157 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.39481 .36823 m .40645 .33289 L .45149 .33047 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.44535 .63392 m .45149 .66953 L .40645 .66711 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.40645 .66711 m .39481 .63177 L .44535 .63392 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.59355 .33289 m .60519 .36823 L .55465 .36608 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.55465 .36608 m .54851 .33047 L .59355 .33289 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.60519 .63177 m .59355 .66711 L .54851 .66953 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66149 .40265 m
.66249 .40061 L
s
.6603 .39831 m
.66249 .40061 L
s
.6593 .40035 m
.6603 .39831 L
s
.6593 .40035 m
.66149 .40265 L
s
.5 Mabswid
.484 .6 .449 r
.39481 .36823 m .38598 .40892 L .33974 .41141 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.3322 .45478 m .33974 .41141 L .38598 .40892 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33347 .39883 m
.33564 .42566 L
s
.5 Mabswid
.618 .805 .609 r
.38045 .54655 m .38598 .59108 L .33974 .58859 L p F P
.505 .664 .505 r
s
.618 .805 .609 r
.33974 .58859 m .3322 .54522 L .38045 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.6678 .54522 m .66026 .58859 L .61402 .59108 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.60519 .63177 m .61402 .59108 L .66026 .58859 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.66026 .41141 m .6678 .45478 L .61955 .45345 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.61955 .45345 m .61402 .40892 L .66026 .41141 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.66419 .41347 m
.6698 .44318 L
s
.5 Mabswid
.465 .568 .41 r
.44535 .36608 m .45149 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.5 .63466 m .5 .67037 L .45149 .66953 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.45149 .66953 m .44535 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.45149 .33047 m .44535 .36608 L .39481 .36823 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.54851 .66953 m .55465 .63392 L .60519 .63177 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.54851 .33047 m .55465 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.5 .36534 m .5 .32963 L .54851 .33047 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.55465 .63392 m .54851 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.38598 .40892 m .38045 .45345 L .3322 .45478 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33419 .41359 m
.35113 .4125 L
s
.33564 .42566 m
.33704 .44288 L
s
.5 Mabswid
.567 .724 .545 r
.32963 .5 m .3322 .45478 L .38045 .45345 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.37857 .5 m .38045 .54655 L .3322 .54522 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.3322 .54522 m .32963 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.6678 .45478 m .67037 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.62143 .5 m .61955 .45345 L .6678 .45478 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.67037 .5 m .6678 .54522 L .61955 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.61402 .59108 m .61955 .54655 L .6678 .54522 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.64001 .39684 m
.64586 .39938 L
s
.64586 .39938 m
.64867 .40388 L
s
.64867 .40388 m
.64919 .40606 L
s
.64841 .41032 m
.64919 .40606 L
s
.36132 .42706 m
.37121 .38095 L
s
.5 Mabswid
.567 .724 .545 r
.38045 .45345 m .37857 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.5 .67037 m .5 .63466 L .55465 .63392 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.5 .32963 m .5 .36534 L .44535 .36608 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.61955 .54655 m .62143 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.63458 .3965 m
.64001 .39684 L
s
.34179 .43333 m
.35999 .39684 L
s
.33704 .44288 m
.34179 .43333 L
s
.64528 .4123 m
.64841 .41032 L
s
.5 Mabswid
.648 .851 .638 r
.44068 .5927 m .44535 .63392 L .39481 .63177 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.39481 .63177 m .38598 .59108 L .44068 .5927 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.38598 .40892 m .39481 .36823 L .44535 .36608 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.61402 .59108 m .60519 .63177 L .55465 .63392 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.60519 .36823 m .61402 .40892 L .55932 .4073 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.55932 .4073 m .55465 .36608 L .60519 .36823 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.65139 .4255 m
.65239 .42128 L
s
.62951 .39839 m
.63458 .3965 L
s
.63644 .414 m
.64528 .4123 L
s
.64625 .42739 m
.65139 .4255 L
s
.36578 .40301 m
.37049 .39839 L
s
.62855 .40271 m
.62951 .39839 L
s
.37049 .39839 m
.37478 .39597 L
s
.6406 .42714 m
.64625 .42739 L
s
.37478 .39597 m
.38057 .39567 L
s
.63301 .41601 m
.63644 .414 L
s
.36239 .42055 m
.36554 .42473 L
s
.38057 .39567 m
.38405 .3977 L
s
.63446 .42473 m
.6406 .42714 L
s
.63181 .42029 m
.63301 .41601 L
s
.63181 .42029 m
.63446 .42473 L
s
.36554 .42473 m
.36915 .42675 L
s
.5 Mabswid
.51 .634 .467 r
.44535 .36608 m .44068 .4073 L .38598 .40892 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.38405 .3977 m
.38721 .40196 L
s
.5 Mabswid
.552 .697 .516 r
.38045 .45345 m .38598 .40892 L .44068 .4073 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.43776 .54742 m .44068 .5927 L .38598 .59108 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.38598 .59108 m .38045 .54655 L .43776 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.61955 .54655 m .61402 .59108 L .55932 .5927 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.55465 .63392 m .55932 .5927 L .61402 .59108 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.61402 .40892 m .61955 .45345 L .56224 .45258 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.56224 .45258 m .55932 .4073 L .61402 .40892 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.61352 .39538 m
.61865 .42631 L
s
.5 Mabswid
.518 .644 .468 r
.44068 .4073 m .44535 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.5 .59326 m .5 .63466 L .44535 .63392 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.44535 .63392 m .44068 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.55465 .36608 m .55932 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.5 .40674 m .5 .36534 L .55465 .36608 L p F P
.505 .664 .505 r
s
.644 .844 .62 r
.55932 .5927 m .55465 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.36915 .42675 m
.37518 .42652 L
s
.60791 .39733 m
.61521 .40427 L
s
.38721 .40196 m
.3881 .40854 L
s
.60341 .39493 m
.60791 .39733 L
s
.59719 .39468 m
.60341 .39493 L
s
.37518 .42652 m
.37958 .4242 L
s
.3874 .41297 m
.3881 .40854 L
s
.59335 .39676 m
.59719 .39468 L
s
.38433 .41967 m
.3874 .41297 L
s
.37958 .4242 m
.38433 .41967 L
s
.5 Mabswid
.644 .844 .62 r
.5 .63466 m .5 .59326 L .55932 .5927 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.5 .36534 m .5 .40674 L .44068 .4073 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.59223 .4034 m
.59335 .39676 L
s
.41091 .39661 m
.41555 .39422 L
s
.40595 .40123 m
.41091 .39661 L
s
.41555 .39422 m
.42206 .39402 L
s
.5 Mabswid
.552 .697 .516 r
.44068 .4073 m .43776 .45258 L .38045 .45345 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.40282 .40801 m
.40595 .40123 L
s
.5 Mabswid
.586 .748 .555 r
.37857 .5 m .38045 .45345 L .43776 .45258 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.43676 .5 m .43776 .54742 L .38045 .54655 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.38045 .54655 m .37857 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.61955 .45345 m .62143 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.56324 .5 m .56224 .45258 L .61955 .45345 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.62143 .5 m .61955 .54655 L .56224 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.55932 .5927 m .56224 .54742 L .61955 .54655 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.40221 .41246 m
.40282 .40801 L
s
.59223 .4034 m
.59502 .42562 L
s
.42206 .39402 m
.42615 .39614 L
s
.40221 .41246 m
.40353 .41905 L
s
.57356 .39389 m
.57693 .42521 L
s
.5 Mabswid
.586 .748 .555 r
.43776 .45258 m .43676 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.56224 .54742 m .56324 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.42615 .39614 m
.43007 .40052 L
s
.40353 .41905 m
.40744 .42336 L
s
.43007 .40052 m
.43161 .40722 L
s
.40744 .42336 m
.41168 .42546 L
s
.5 Mabswid
.636 .826 .61 r
.5 .54772 m .5 .59326 L .44068 .5927 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.44068 .5927 m .43776 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.56224 .54742 m .55932 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.43776 .45258 m .44068 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.55932 .4073 m .56224 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.5 .45228 m .5 .40674 L .55932 .4073 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.55568 .39345 m
.55762 .41597 L
s
.41168 .42546 m
.41848 .42531 L
s
.43117 .41171 m
.43161 .40722 L
s
.42826 .41846 m
.43117 .41171 L
s
.53041 .39305 m
.53182 .4246 L
s
.41848 .42531 m
.42326 .423 L
s
.42326 .423 m
.42826 .41846 L
s
.49531 .39289 m
.50235 .39288 L
s
.49058 .39517 m
.49531 .39289 L
s
.50235 .39288 m
.50707 .39516 L
s
.48576 .39972 m
.49058 .39517 L
s
.50707 .39516 m
.51187 .39971 L
s
.5 Mabswid
.629 .817 .597 r
.5 .59326 m .5 .54772 L .56224 .54742 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.5 .40674 m .5 .45228 L .43776 .45258 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.46522 .44007 m
.4654 .436 L
s
.4654 .436 m
.46727 .39308 L
s
.44642 .42937 m
.44886 .39336 L
s
.44568 .44024 m
.44642 .42937 L
s
.55573 .42263 m
.55762 .41597 L
s
.48322 .40652 m
.48576 .39972 L
s
.51187 .39971 m
.51439 .40651 L
s
.57826 .44272 m
.58045 .44059 L
s
.57797 .43838 m
.58045 .44059 L
s
.57578 .44052 m
.57797 .43838 L
s
.57578 .44052 m
.57826 .44272 L
s
.55111 .42479 m
.55573 .42263 L
s
.48311 .41104 m
.48322 .40652 L
s
.51439 .40651 m
.51448 .41103 L
s
.54392 .42471 m
.55111 .42479 L
s
.48311 .41104 m
.48539 .41778 L
s
.51218 .41777 m
.51448 .41103 L
s
.53148 .41564 m
.53899 .42243 L
s
.5 Mabswid
.59 .753 .552 r
.43676 .5 m .43776 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.5 .5 m .5 .54772 L .43776 .54742 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.43776 .54742 m .43676 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.56224 .45258 m .56324 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.5 .5 m .5 .45228 L .56224 .45258 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.56324 .5 m .56224 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.53899 .42243 m
.54392 .42471 L
s
.48539 .41778 m
.4902 .42225 L
s
.50735 .42224 m
.51218 .41777 L
s
.4902 .42225 m
.49509 .42447 L
s
.50246 .42447 m
.50735 .42224 L
s
.5 Mabswid
.59 .753 .552 r
.5 .45228 m .5 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.5 .54772 m .5 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.49509 .42447 m
.50246 .42447 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>h0/>3V5`21ZH7^0;3PiP40oooo003V0;3PiPP0PJV10P0R9A`0
0`21ZH4092LN02@W7P0602@W7P03086YP@0U:1h09BPN00H09BPN00<0PJV102<V7@0S9Qd02021ZH7V
0;3PiP40oooo003P0;3PiPH0PJV100<0720H086YP@21ZH401P0R9A`00`21ZH4092LN02@W7P0702@W
7P03086YP@0U:1h09BPN00L09BPN00<0PJV102<V7@0S9Qd0100S9Qd2086YP@0301lR6P21ZH40PJV1
00@0PJV1h02`h>H10?ooo`00g02`h>H5086YP@@0720H0P21ZH47028U7003086YP@0T9ah092LN00P0
92LN00<0PJV102DX7P0U:1h0200U:1h00`21ZH408bHM02<V7@0502<V7@80PJV1100O8QX5086YPM`0
/>3V0@3oool00=T0/>3V1@21ZH4501`P6080PJV10`0R9A`S086YP@<08bHM0P21ZH4501lR6PD0PJV1
f@2`h>H10?ooo`00eP2`h>H2086YP@0301DI4`21ZH40PJV10080720H2`21ZH4403<d:003086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@0203Df:@/0PJV100<0
7b8J086YP@21ZH401021ZH7F0;3PiP40oooo003C0;3PiPX0PJV10`0];b@00`21ZH40<c@X03<d:009
03<d:003086YP@0f>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@09
03Df:@04086YP@0`<RH0<38V030b9PX0PJV1d`2`h>H10?ooo`00d02`h>H7086YP@P0;BlT00<0PJV1
03<d:00c=2P02@0c=2P00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0g>2/0=cP[00/0=cP[00<0PJV1
03Df:@0e=RT02@0e=RT00`21ZH40<38V030b9P06030b9PL0PJV1d02`h>H10?ooo`00c@2`h>H4086Y
P@<092HM00<0PJV102d_900];b@01`0];b@00`21ZH40<c@X03<d:00903<d:003086YP@0f>2X0=SPZ
00`0=SPZ00<0PJV103Lh:`0g>2/0300g>2/00`21ZH40=CHY03Df:@0903Df:@03086YP@0`<RH0<38V
00L0<38V00@0PJV102P[800X:b00:2/P1021ZH7=0;3PiP40oooo003:0;3PiP@0PJV1100T9Qd2086Y
P@P0;BlT0P21ZH4;03<d:003086YP@0f>2X0=SPZ00d0=SPZ00<0PJV103Lh:`0g>2/03@0g>2/00`21
ZH40=CHY03Df:@0903Df:@80PJV1200`<RH2086YP@@0:2/P1021ZH7:0;3PiP40oooo00380;3PiP@0
PJV11@0T9Qd00`21ZH40;BlT02d_900702d_9003086YP@0c=2P0<c@X00/0<c@X00<0PJV103Hh:P0f
>2X03@0f>2X00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0e=RT0=CHY00/0=CHY00<0PJV1030b9P0`
<RH01`0`<RH00`21ZH40:2/P02P[800302P[80@0PJV1b02`h>H10?ooo`00aP2`h>H4086YP@D092HM
0P21ZH4902d_9003086YP@0c=2P0<c@X00@0<c@X<@21ZH4603Df:@03086YP@0`<RH0<38V00L0<38V
0P21ZH4502P[8080PJV100<07B0H086YP@2`h>H0a@2`h>H10?ooo`00a02`h>H2086YP@0301LK5021
ZH4092HM00D092HM00<0PJV102d_900];b@01@0];b@;086YP@L0B50i00<0PJV104eG?@1=Ecd03P1=
Ecd00`21ZH40CeTn04mI?P0>04mI?P03086YP@1<E3`0C5@l00D0C5@l2`21ZH47030b9P03086YP@0X
:b00:2/P00@0:2/P00@0PJV101dP6021ZH40PJV1a02`h>H10?ooo`00`P2`h>H2086YP@0301LK5021
ZH40PJV100D092HM0P21ZH400`0];b@0PJV1086YP@05086YP@80?D8`00<0PJV104Q@>@18D3T03018
D3T00`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<
E3`00`21ZH40@dXe04=:=@07086YP@03030b9P21ZH40PJV100D0:2/P0P21ZH400`0M81P0PJV1086Y
P@320;3PiP40oooo00300;3PiPD0PJV1100T9Qd6086YP@T0?D8`00<0PJV104Q@>@18D3T03018D3T0
0`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<E3`0
0`21ZH40@dXe04=:=@0704=:=@H0PJV1100X:b05086YPL00/>3V0@3oool00;h0/>3V2`21ZH400`0`
<BD0PJV103e2<00;03e2<003086YP@18D3T0B50i00d0B50i00<0PJV104eG?@1=Ecd03`1=Ecd00`21
ZH40CeTn04mI?P0?04mI?P03086YP@1<E3`0C5@l00d0C5@l00<0PJV104=:=@13BSD02P13BSD00`21
ZH40=SPZ086YP@0:086YPKh0/>3V0@3oool00;d0/>3V1P21ZH46030a9@03086YP@0m@S00?D8`00X0
?D8`00<0PJV104Q@>@18D3T03@18D3T00`21ZH40CELm04eG?@0@04eG?@03086YP@1?FCh0CeTn0100
CeTn00<0PJV104aD?01<E3`03@1<E3`00`21ZH40@dXe04=:=@0:04=:=@03086YP@0f>2X0=SPZ00@0
=SPZ1P21ZH6m0;3PiP40oooo002k0;3PiPD0PJV1200`<BD00`21ZH40?D8`03e2<00:03e2<003086Y
P@18D3T0B50i00h0B50i00<0PJV104eG?@1=Ecd0401=Ecd00`21ZH40CeTn04mI?P0@04mI?P03086Y
P@1<E3`0C5@l00h0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0603Hh:PD0PJV1
^`2`h>H10?ooo`00^@2`h>H4086YP@03028T7021ZH40<34U00L0<34U00<0PJV103e2<00m@S002`0m
@S000`21ZH40B50i04Q@>@0=04Q@>@03086YP@1=Ecd0CELm0140CELm00<0PJV104mI?P1?FCh04@1?
FCh00`21ZH40C5@l04aD?00=04aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f
>2X00`21ZH40:2/P086YP@03086YPKT0/>3V0@3oool00;L0/>3V1021ZH42028T7003086YP@0`<BD0
<34U00H0<34U00<0PJV103e2<00m@S002`0m@S000`21ZH40B50i04Q@>@0>04Q@>@03086YP@1=Ecd0
CELm0140CELm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40C5@l04aD?00>04aD?003086YP@13BSD0
@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f>2X2086YP@0302P[8021ZH40PJV10080PJV1]`2`h>H1
0?ooo`00]@2`h>H4086YP@<08R@L00<0PJV1030a9@0`<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2
<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=Ecd04@1=Ecd00`21ZH40CeTn04mI?P0A04mI
?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh
:P03086YP@0X:b00:2/P00@0PJV1]@2`h>H10?ooo`00]02`h>H3086YP@@08R@L00<0PJV1030a9@0`
<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=
Ecd04P1=Ecd00`21ZH40CeTn04mI?P0B04mI?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13
BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh:P04086YP@0X:b00:2/P02P[80<0PJV1]02`h>H10?oo
o`00/`2`h>H00`21ZH4041@?086YP@03028T7080PJV12@0`<BD00`21ZH40?D8`03e2<00;03e2<003
086YP@18D3T0B50i00H0B50i?@21ZH4804aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f
>2X0200f>2X01@21ZH40:2/P02P[800X:b00PJV1008061/D/`2`h>H10?ooo`00/@2`h>H4086YP@<0
8R@L00<0PJV1030a9@0`<BD0200`<BD00`21ZH40?D8`03e2<00803e2<0d0PJV12@1QLU<00`21ZH40
I7ME06AgE@0B06AgE@03086YP@1SME80HgEB0180HgEB00<0PJV105e]B`1MKD/01`1MKD/=086YP@X0
@dXe00<0PJV103Hh:P0f>2X0200f>2X01021ZH40:2/P02P[800X:b02086YP@0301PK5021ZH40/>3V
0;00/>3V0@3oool00;00/>3V00<0PJV1010D3`21ZH40100R91`00`21ZH40<34U030a9@08030a9@04
086YP@0m@S00?D8`03e2<0P0PJV10`1GIT/00`21ZH40HG9C065bD`0@065bD`03086YP@1TMeD0I7ME
0180I7ME00<0PJV106=eDP1SME804P1SME800`21ZH40GFe;05e]B`0@05e]B`04086YP@1FI4D0EVA5
05ITA@P0PJV10`13BSD00`21ZH40=SPZ03Hh:P0803Hh:P80PJV10`0X:b000`21ZH4061/D086YP@2`
0;3PiP40oooo002_0;3PiP03086YP@0@50l0PJV100@08R@L00<0PJV1030a9@0`<BD01@0`<BD8086Y
P@X0EfI;00<0PJV1065bD`1QLU<0401QLU<00`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB
01<0HgEB00<0PJV105e]B`1MKD/0401MKD/00`21ZH40EVA505ITA@0805ITA@P0PJV1200f>2X01`21
ZH40:2/P02P[800X:b00PJV101PK5021ZH40[`2`h>H10?ooo`00[P2`h>H3086YP@@08R@L00<0PJV1
030a9@0`<BD01P21ZH4204I??003086YP@1GIT/0EfI;00d0EfI;00<0PJV1065bD`1QLU<0401QLU<0
0`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB01<0HgEB00<0PJV105e]B`1MKD/0401MKD/0
0`21ZH40EVA505ITA@0=05ITA@03086YP@18DSX0B58j00L0PJV10P0f>2X01021ZH40:2/P02P[800X
:b03086YPJh0/>3V0@3oool00:`0/>3V0`21ZH44028T70D0PJV12016Cc`00`21ZH40EfI;05MVB`0<
05MVB`03086YP@1QLU<0HG9C0140HG9C00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgEB06=eDP0C
06=eDP03086YP@1MKD/0GFe;0140GFe;00<0PJV105ITA@1FI4D0301FI4D00`21ZH40B58j04QB>P07
04QB>PD0PJV10`0X:b03086YPJ`0/>3V0@3oool00:/0/>3V00<0PJV1010D3`21ZH400P0R91`4086Y
P@/0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01<0I7ME00<0PJV106=eDP1SME804`1SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00d0EVA500<0PJV104QB>P18DSX02P18DSX4086YP@0402P[8021ZH4061/D086YPJ/0/>3V0@3oool0
0:X0/>3V1P21ZH4202d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21
ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=eDP1SME804`1SME800`21
ZH40GFe;05e]B`0B05e]B`03086YP@1FI4D0EVA500d0EVA500<0PJV104QB>P18DSX02@18DSX01021
ZH40<cHX03<f:00c=RP5086YPJX0/>3V0@3oool00:T0/>3V0`21ZH4602d`9P03086YP@16Cc`0ATll
00P0ATll00<0PJV105MVB`1GIT/03P1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01@0I7ME00<0PJV106=eDP1SME80501SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00h0EVA500<0PJV104QB>P18DSX02@18DSX00`21ZH40<cHX03<f:00303<f:0<0PJV1Z@2`h>H10?oo
o`00Y`2`h>H3086YP@L0;C0V00<0PJV104I??016Cc`02@16Cc`00`21ZH40EfI;05MVB`0=05MVB`03
086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgEB06=eDP0D06=eDP03
086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03@1FI4D00`21ZH40B58j04QB>P0:04QB>P03
086YP@0c=RP0<cHX00@0<cHX0`21ZH6W0;3PiP40oooo002V0;3PiP<0PJV11`0]<2H00`21ZH40ATll
04I??00904I??003086YP@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04P1QLU<00`21ZH40I7ME
06AgE@0D06AgE@03086YP@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04P1MKD/00`21ZH40EVA5
05ITA@0>05ITA@03086YP@18DSX0B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP3086YPJH0/>3V
0@3oool00:D0/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H00`21ZH40ATll04I??00904I??003086Y
P@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04`1QLU<00`21ZH40I7ME06AgE@0D06AgE@03086Y
P@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04`1MKD/00`21ZH40EVA505ITA@0>05ITA@03086Y
P@18DSX0B58j00T0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6U0;3PiP40
oooo002T0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02P16Cc`00`21ZH40
EfI;05MVB`0>05MVB`03086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD05@1TMeD00`21ZH40
HgEB06=eDP0E06=eDP03086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03P1FI4D00`21ZH40
B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1Y02`h>H10?oo
o`00X`2`h>H01021ZH405QXC01HJ4`21ZH4702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MV
B`1GIT/03P1GIT/00`21ZH40HG9C065bD`0C065bD`03086YP@1TMeD0I7ME01D0I7ME00<0PJV106=e
DP1SME805@1SME800`21ZH40GFe;05e]B`0C05e]B`03086YP@1FI4D0EVA500h0EVA500<0PJV104QB
>P18DSX02P18DSX00`21ZH40<cHX03<f:00403<f:004086YP@0O8QX07b8J086YPJ<0/>3V0@3oool0
0:80/>3V00@0PJV101HJ4`0F6Q<0PJV11`0]<2H00`21ZH40ATll04I??00904I??003086YP@1GIT/0
EfI;00l0EfI;00<0PJV1065bD`1QLU<03P1QLU<k086YPA00GFe;00<0PJV105ITA@1FI4D03`1FI4D0
0`21ZH40B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1XP2`
h>H10?ooo`00XP2`h>H00`21ZH405QXC086YP@0702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV1
05MVB`1GIT/03`1GIT/00`21ZH40HG9C065bD`03065bD``0PJV11@1dSFL00`21ZH40Mi5X07NAJ00E
07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0PJV106n6G@1_QUd00`1_QUd<086YP@D0GFe;00<0PJV1
05ITA@1FI4D03`1FI4D00`21ZH40B58j04QB>P0904QB>P03086YP@0c=RP0<cHX00D0<cHX00<0PJV1
01lR6P21ZH40XP2`h>H10?ooo`00X@2`h>H01021ZH405QXC01HJ4`21ZH4602d`9P03086YP@16Cc`0
ATll00X0ATll00<0PJV105MVB`1GIT/01P1GIT/?086YPA40M8eW00<0PJV107NAJ01gTFP05@1gTFP0
0`21ZH40MHmU07F?I@0E07F?I@03086YP@1_QUd0KhIM00l0KhIM3`21ZH4805ITA@03086YP@18DSX0
B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6Q0;3PiP40oooo002P
0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02016Cc`<086YP@T0K8=Q00<0
PJV107B=I`1dSFL04`1dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0
PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00706=gD0`0PJV12P18DSX00`21ZH40<cHX03<f
:00403<f:004086YP@0O8QX07b8J086YPJ00/>3V0@3oool009l0/>3V00@0PJV101HJ4`0F6Q<0PJV1
1`0]<2H00`21ZH40ATll04I??00304I??0D0PJV10P1LKU@00`21ZH40K8=Q06b3H@0?06b3H@03086Y
P@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40MHmU07F?I@0F07F?I@03086Y
P@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe003`1SMe000`21ZH40EfM705MWA`05086YP@H0B58j
00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6O0;3PiP40oooo002N0;3PiP04086Y
P@0F6Q<05QXC086YP@L0;C0V00<0PJV104I??021ZH401021ZH4605a^E003086YP@1/Pf40K8=Q0100
K8=Q00<0PJV107B=I`1dSFL0501dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0
MHmU00<0PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00@06=gD003086YP@1GIdL0EfM700@0
EfM71@21ZH400`18DSX0PJV103<f:00603<f:004086YP@0O8QX07b8J086YPIh0/>3V0@3oool009d0
/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H4086YP@/0G6iD00<0PJV106b3H@1/Pf40401/Pf400`21
ZH40M8eW07B=I`0D07B=I`03086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107F?I@1eSfD05P1eSfD00`21
ZH40KhIM06n6G@0D06n6G@03086YP@1SMe00HgM@0100HgM@00<0PJV105MWA`1GIdL02@1GIdL4086Y
P@H0<cHX00@0PJV101lR6P0O8QX0PJV1W@2`h>H10?ooo`00W02`h>H01@21ZH405QXC01HJ4`0F6Q<0
PJV100<0;C0V1021ZH4=05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL0501dSFL0
0`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd0501_QUd0
0`21ZH40HgM@06=gD00A06=gD003086YP@1GIdL0EfM700/0EfM71021ZH4303<f:005086YP@0O8QX0
7b8J01lR6P21ZH40W02`h>H10?ooo`00W02`h>H301HJ4`D0PJV10`11Bc`00`21ZH40G6iD05a^E00;
05a^E003086YP@1/Pf40K8=Q0100K8=Q00<0PJV107B=I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00F
07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00@
06=gD003086YP@1GIdL0EfM700/0EfM700@0PJV1049<=P12C3H0@T`f1@21ZH4201lR6P03086YP@2`
h>H0/>3V09X0/>3V0@3oool009/0/>3V0P0F6Q<3086YP@H0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0F07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00@0@T`f0`21ZH400`0O8QX0PJV10;3PiP2J
0;3PiP40oooo002J0;3PiP0401HJ4`21ZH40PJV1086YP@P0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f1021ZH6J0;3PiP40oooo002I0;3P
iP80PJV10P0Q9R000`21ZH40@D/l045;?005045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3
H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086YP@1gTFP0Mi5X01L0Mi5X00<0PJV107F?
I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0E06n6G@03086YP@1SMe00HgM@0140HgM@00<0PJV105MW
A`1GIdL02`1GIdL00`21ZH40@T`f049<=P05049<=P03086YP@0U9ah09BLN0080PJV1V@2`h>H10?oo
o`00V02`h>H01@21ZH408BHP024V800Q9R00PJV100P0@D/l00<0PJV105a^E01LKU@02`1LKU@00`21
ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP00`21
ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe000`21
ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f00D0PJV102DW7P0U9ah09BLN086YP@2H
0;3PiP40oooo002H0;3PiP04086YP@0Q9R008BHP086YP@P0@D/l00<0PJV105a^E01LKU@0301LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0<05MWA`03086YP@12C3H0@T`f00D0@T`f00D0PJV102DW7P0U9ah09BLN086Y
P@2H0;3PiP40oooo002G0;3PiP05086YP@0Q9R008BHP024V8021ZH402011Bc`00`21ZH40G6iD05a^
E00;05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL05P1dSFL00`21ZH40Mi5X07NA
J00G07NAJ003086YP@1eSfD0MHmU01L0MHmU00<0PJV106n6G@1_QUd05P1_QUd00`21ZH40HgM@06=g
D00A06=gD003086YP@1GIdL0EfM700/0EfM700<0PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW
7P0U9ah0PJV109L0/>3V0@3oool009H0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086Y
P@1LKU@0G6iD00`0G6iD00<0PJV106b3H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086Y
P@1gTFP0Mi5X01P0Mi5X00<0PJV107F?I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0F06n6G@03086Y
P@1SMe00HgM@0140HgM@00<0PJV105MWA`1GIdL0301GIdL00`21ZH40@T`f049<=P06049<=P05086Y
P@0U9ah09BLN02DW7P21ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH408BHP024V800Q9R00PJV100P0
@D/l00<0PJV105a^E01LKU@02`1LKU@00`21ZH40K8=Q06b3H@0B06b3H@03086YP@1dSFL0M8eW01D0
M8eW00<0PJV107NAJ01gTFP0601gTFP00`21ZH40MHmU07F?I@0H07F?I@03086YP@1_QUd0KhIM01D0
KhIM00<0PJV106=gD01SMe004P1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0
@T`f00D0PJV102DW7P0U9ah09BLN086YP@2F0;3PiP40oooo002E0;3PiP05086YP@0Q9R008BHP024V
8021ZH402011Bc`00`21ZH40G6iD05a^E00<05a^E003086YP@1/Pf40K8=Q0180K8=Q00<0PJV107B=
I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1eSfD0MHmU01P0MHmU00<0PJV106n6
G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0EfM700`0EfM700<0PJV1049<
=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109D0/>3V0@3oool009@0/>3V00D0PJV1024V
800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf404P1/Pf40
0`21ZH40M8eW07B=I`0:07B=Idl0PJV1301_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0
EfM700/0EfM700<0PJV1049<=P12C3H01`12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3o
ool009@0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086YP@1LKU@0G6iD00`0G6iD00<0
PJV106b3H@1/Pf403@1/Pf4B086YP@`0PZ9g00<0PJV108BTM`24Y7L06024Y7L00`21ZH40PZ9d08:R
M00H08:RM003086YP@1mVfd0OI]]00X0OI]]4P21ZH4?06=gD003086YP@1GIdL0EfM700`0EfM700<0
PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3oool009<0/>3V00D0
PJV1024V800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf40
0`1/Pf4;086YP@D0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03086Y
P@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0307:=H@/0PJV1
1@1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00L0@T`f00D0PJV102DW7P0U9ah0
9BLN086YP@2C0;3PiP40oooo002C0;3PiP04086YP@0Q9R008BHP086YP@T0@D/l00<0PJV105a^E01L
KU@02@1LKU@9086YPA00NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03
086YP@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0>07:=H@T0
PJV12`1GIdL00`21ZH40@T`f049<=P06049<=P05086YP@0U9ah09BLN02DW7P21ZH40T`2`h>H10?oo
o`00TP2`h>H01@21ZH408BHP024V800Q9R00PJV100T0@D/l00@0PJV105a^E01LKU@0G6iD2021ZH43
06j7I`03086YP@1kVG80NiUb0180NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0I
08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0B
07:=H@04086YP@1RMe00HWM@069gD0P0PJV10`1GIdL00`21ZH40@T`f049<=P07049<=P05086YP@0U
9ah09BLN02DW7P21ZH40TP2`h>H10?ooo`00T@2`h>H01@21ZH408BHP024V800Q9R00PJV100L0@D/l
1`21ZH4:06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag
08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ
07:=H@0C07:=H@03086YP@1RMe00HWM@00P0HWM@1`21ZH47049<=P05086YP@0U9ah09BLN02DW7P21
ZH40T@2`h>H10?ooo`00T@2`h>H01P21ZH408BHP024V800Q9R00PJV1045;?0H0PJV10P1DIU400`21
ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21
ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00`0HWM@00<0PJV104iN@01>GT001P21ZH400`12
C3H0PJV102DW7P0202DW7P03086YP@2`h>H0/>3V08l0/>3V0@3oool00900/>3V00@0PJV1024V800Q
9R008BHP0`21ZH4705AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG804`1kVG800`21
ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21
ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21
ZH40CUi004iN@00504iN@0<0PJV10`0U9ah00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP03
086YP@0Q9R008BHP00<0PJV12@1DIU400`21ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb00P0
NiUb0P3oO`0907^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40
PZ9d08:RM00I08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF404P1bSF400`21ZH40
HWM@069gD00=069gD003086YP@1>GT00CUi000L0CUi00`21ZH4202DW7P03086YP@2`h>H0/>3V08d0
/>3V0@3oool008l0/>3V00D08BHP086YP@21ZH40;C@^086YP@0905AVD@03086YP@1^QfL0KXMW00d0
KXMW00<0PJV107^ILP1kVG80201kVG820?mo00T0NiUb00<0PJV108:RM`22XWL05`22XWL00`21ZH40
Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05`1mVfd00`21ZH40
LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00d0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40
;S@U086YP@02086YPHl0/>3V0@3oool008h0/>3V0P21ZH4302dd;P03086YP@1DIU40E6IA00L0E6IA
00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40NiUb07^ILP0807^ILP80ogl02@1kVG800`21ZH40PZ9g
08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21ZH40OI]]
07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi0
04iN@00704iN@004086YP@0^=2D0;S@U02hd9@80PJV1SP2`h>H10?ooo`00SP2`h>H01@21ZH40;C@^
02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0807^ILP80
ogl02@1kVG800`21ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022
XW@06P22XW@00`21ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01R
Me003P1RMe000`21ZH40CUi004iN@00704iN@003086YP@0^=2D0;S@U0080;S@USP2`h>H10?ooo`00
S@2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3@1^QfL00`21ZH40NiUb07^ILP0907^ILP80ogl0201kVG800`21ZH40PZ9g08:RM`0G08:RM`03086Y
P@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022XW@06P22XW@00`21ZH40OI]]07fKK@0G07fKK@03086Y
P@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@003086Y
P@0^=2D0;S@U0080;S@U00<0PJV10;3PiP2`h>H0R`2`h>H10?ooo`00S@2`h>H01@21ZH40;C@^02dd
;P0]=2h0PJV100X0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40NiUb07^ILP0807^ILP80ogl0
2@1kVG800`21ZH40PZ9g08:RM`0:08:RM`040?mo0022XWL0PZ9g0?mo00T0PZ9g00<0PJV108BTM`24
Y7L06024Y7L0103oO`00Q:Ag086YP@3oO`0K08:RM003086YP@1mVfd0OI]]00l0OI]]0P3oO`0607fK
K@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00804iN
@005086YP@0^=2D0;S@U02hd9@21ZH40S@2`h>H10?ooo`00S02`h>H00`21ZH40;C@^02dd;P0202dd
;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0807^I
LP80ogl00P1kVG800`3oO`00NiUb0?mo000407^ILP03086YP@22XWL0PZ9g00P0PZ9g203oO`0708:R
M`03086YP@24Y7L0Q:Ag0080ogl02024Y7L20?mo00T0Q:Ag2P3oO`0:08:RM080ogl02`22XW@20?mo
00H0OI]]0P3oO`0907fKK@H0ogl00P1mVfd00`21ZH40LXeQ07:=H@0907:=H@030?mo001bSF40LXeQ
00L0LXeQ00<0PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@003086YP@0^=2D0;S@U
0080;S@U00<0PJV10;3PiP2`h>H0RP2`h>H10?ooo`00S02`h>H00`21ZH40;C@^02dd;P0202dd;P03
086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40NiUb07^ILP0507^ILP04
0?mo001kVG80NiUb07^ILPT0ogl00P1kVG800`21ZH40PZ9g08:RM`0708:RM`X0ogl01P22XWL01021
ZH40Q:Ag0?mo003oO`0808BTM`80ogl02@24Y7L<0?mo00T0PZ9d0P3oO`0;08:RM080ogl01`1mVfd2
0?mo00L0OI]]2@3oO`001021ZH40LXeQ0?mo003oO`0607:=H@H0ogl01`1bSF400`21ZH40HWM@0?mo
000=069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3P
iP2:0;3PiP40oooo002<0;3PiP05086YP@0]=2h0;C@^02dd;P21ZH402@1DIU400`21ZH40KXMW06j7
I`0>06j7I`03086YP@1kVG80NiUb00D0NiUb00@0ogl007^ILP1kVG80NiUb2P3oO`000`21ZH40PZ9g
08:RM`0708:RM`<0ogl01P22XWL30?mo00D0PZ9g00@0PJV108BTM`3oO`00ogl02024Y7L20?mo00P0
Q:Ag0`3oO`0408BTM`04086YP@22XW@0PZ9d08:RM0<0ogl02022XW@20?mo00/0PZ9d0P3oO`0707fK
K@80ogl01`1mVfd20?mo00@0OI]]103oO`000`21ZH40ogl00?mo000507:=H@X0ogl0101bSF401021
ZH40ogl00?mo003oO`0=069gD003086YP@1>GT00CUi000L0CUi000D0PJV102hd9@0^=2D0;S@U086Y
P@2<0;3PiP40oooo002;0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU401`1DIU40
0`21ZH40KXMW06j7I`0906j7I`80ogl00`1^QfL00`21ZH40NiUb07^ILP0407^ILP80ogl00`1kVG82
0?mo00H0NiUb0`3oO`0808:RM`<0ogl02022XWL30?mo00@0PZ9g00@0PJV108BTM`3oO`00ogl02024
Y7L20?mo00L0Q:Ag0`3oO`0508BTM`03086YP@22XW@0PZ9d0080PZ9d0`3oO`0708:RM080ogl02`22
XW@20?mo00L0OI]]0P3oO`0707fKK@80ogl01P1mVfd50?mo00D0LXeQ0P3oO`0407:=H@D0ogl00`1b
SF450?mo00`0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`
h>H0/>3V08T0/>3V0@3oool008/0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0:05AVD@03086YP@1^
QfL0KXMW00T0KXMW0P3oO`0206j7I`03086YP@1kVG80NiUb00D0NiUb00@0ogl007^ILP1kVG80NiUb
0P3oO`0807^ILP<0ogl01P22XWL30?mo00X0PZ9g0P3oO`0308:RM`03086YP@24Y7L0Q:Ag0080ogl0
2024Y7L20?mo00L0Q:Ag0P3oO`0608BTM`03086YP@22XW@0PZ9d00<0PZ9d0P3oO`0708:RM080ogl0
2`22XW@20?mo0003086YP@1mVfd0OI]]00@0OI]]0P3oO`0707fKK@80ogl01`1mVfd40?mo00D0LXeQ
00<0ogl007:=H@1bSF401P1bSF420?mo00<0LXeQ00<0PJV10?mo003oO`000P3oO`0<069gD003086Y
P@1>GT00CUi000P0CUi000D0PJV102hd9@0^=2D0;S@U086YP@2;0;3PiP40oooo002:0;3PiP03086Y
P@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU401`1DIU400`21ZH40KXMW06j7I`0:06j7I`80ogl0
0P1^QfL00`21ZH40NiUb07^ILP0407^ILP80ogl00`1kVG820?mo00P0NiUb0P3oO`0708:RM`80ogl0
2`22XWL20?mo00<0PZ9g00<0PJV108BTM`24Y7L00P3oO`0808BTM`80ogl01`24Y7L20?mo00H0Q:Ag
00<0PJV108:RM022XW@00`22XW@20?mo00L0PZ9d0P3oO`0;08:RM080ogl000<0PJV107fKK@1mVfd0
101mVfd20?mo00H0OI]]0`3oO`0807fKK@<0ogl01@1bSF400`3oO`00LXeQ07:=H@0607:=H@80ogl0
101bSF400`21ZH40ogl00?mo000>069gD003086YP@1>GT00CUi000L0CUi000D0PJV102hd9@0^=2D0
;S@U086YP@2;0;3PiP40oooo002:0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU40
1`1DIU400`21ZH40KXMW06j7I`0:06j7I`80ogl00P1^QfL00`21ZH40NiUb07^ILP0407^ILP030?mo
001kVG80NiUb0080NiUb0P3oO`0807^ILP80ogl01`22XWL20?mo00/0PZ9g0P3oO`0308:RM`03086Y
P@24Y7L0Q:Ag0080ogl02024Y7L20?mo000308BTM`21ZH40PJV100<0PJV10`3oO`0<086YP@<0ogl0
1P21ZH420?mo00/0PZ9d0P3oO`000`21ZH40OI]]07fKK@0407fKK@80ogl01`1mVfd20?mo00T0OI]]
0P3oO`0>07:=H@80ogl0101bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi0
00<0PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3PiP280;3PiP40oooo002:0;3PiP05086YP@0]
=2h0;C@^02dd;P21ZH402@1DIU400`21ZH40KXMW06j7I`0;06j7I`80ogl00P1^QfL00`21ZH40NiUb
07^ILP0307^ILP80ogl0101kVG820?mo00P0NiUb0P3oO`0608:RM`<0ogl00`22XWL8086YP@<0ogl0
1@21ZH420?mo00P0PJV10P3oO`000`21ZH40S[B308jdP`0308jdP`80ogl01`2>]8<00`21ZH40SK60
08faP00308faP080ogl01`2=/H020?mo00/0PJV10P3oO`07086YP@80ogl01@21ZH4207fKK@80ogl0
2@1mVfd20?mo00h0LXeQ0P3oO`0407:=H@03086YP@1RMe00HWM@00l0HWM@00<0PJV104iN@01>GT00
1`1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108X0/>3V0@3oool008T0/>3V00<0PJV102dd;P0]=2h0
0P0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00/0KXMW0P3oO`000`1^QfL0PJV1
07^ILP0407^ILP80ogl0101kVG820?mo00T0PJV10P3oO`06086YP@80ogl01021ZH4808fbQ080ogl0
0`2=/X@00`21ZH40S[B308jdP`020?mo00P0S[B30P3oO`0608jdP`80ogl01`2>]8<00`21ZH40SK60
08faP00308faP080ogl01`2=/H020?mo00/0SK600P3oO`000`21ZH40Qj]i08N[N@0408N[N@80ogl0
1@27ZgT2086YP@80ogl02@21ZH420?mo00X0PJV10`1bSF440?mo00@0LXeQ00<0PJV1069gD01RMe00
3P1RMe000`21ZH40CUi004iN@00704iN@003086YP@0^=2D0;S@U0080;S@U00<0PJV10;3PiP2`h>H0
Q`2`h>H10?ooo`00R@2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL0
1`1^QfL5086YP@/0ogl01021ZH420?mo00T0Qj^00P3oO`0508fbQ0<0ogl0302=/X@20?mo00<0SK:4
00<0PJV108jdP`2>]8<00P3oO`0808jdP`80ogl01P2>]8<30?mo00H0S[B300<0PJV108faP02=/H00
0`2=/H030?mo00H0SK600P3oO`0;08faP080ogl000<0PJV108N[N@27ZgT01027ZgT20?mo00L0Qj]i
0P3oO`0908N[N@03086YP@3oO`00ogl000P0OYi^1`3oO`0>086YP@T0HWM@00<0PJV104iN@01>GT00
1`1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108T0/>3V0@3oool008T0/>3V00D0PJV102dd;P0]=2h0
;C@^086YP@0705AVD@`0PJV1101kVgL;0?mo00D0Qj^00P3oO`0908N[P080ogl01P2=/X@20?mo00`0
SK:40P3oO`0308fbQ003086YP@2>]8<0S[B30080ogl0202>]8<20?mo00H0S[B30`3oO`0608jdP`03
086YP@2=/H00SK6000<0SK600P3oO`0708faP080ogl02`2=/H020?mo0003086YP@27ZgT0Qj]i00@0
Qj]i0P3oO`0708N[N@80ogl02@27ZgT00`21ZH40ogl00?mo000607jNKPL0ogl01`1nWVh01021ZH40
KHQL0?mo003oO`0506f8G0`0PJV11`1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108T0/>3V0@3oool0
08P0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0205AVD@H0PJV10P1TO6800`21ZH40Ni]g07^KM`0;
07^KM`<0ogl000<0Ni]g086YP@27Zh000`27Zh020?mo00D0Qj^00P3oO`0908N[P080ogl01P2=/X@2
0?mo00/0SK:40P3oO`0408fbQ003086YP@2>]8<0S[B30080ogl0202>]8<20?mo00L0S[B30P3oO`06
08jdP`03086YP@2=/H00SK6000<0SK600P3oO`0708faP0<0ogl02P2=/H030?mo00H0Qj]i0P3oO`07
08N[N@80ogl02@27ZgT00`21ZH40ogl00?mo000507jNKP@0ogl02`1nWVh01021ZH40KHQL0?mo003o
O`0>06f8G003086YP@1GK4P0Efa800H0PJV10P1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108P0/>3V
0@3oool008P0/>3V00<0PJV102dd;P0]=2h01021ZH4806AlHP03086YP@1kVgL0Ni]g00`0Ni]g0P3o
O`000`21ZH40Qj^008N[P00308N[P0030?mo0027Zh00Qj^000<0Qj^00`3oO`0808N[P080ogl01`2=
/X@20?mo00/0SK:400<0ogl008fbQ02=/X@00`2=/X@00`21ZH40S[B308jdP`020?mo00P0S[B30P3o
O`0708jdP`<0ogl01@2>]8<00`21ZH40SK6008faP00208faP0<0ogl01`2=/H040?mo00T0SK600`3o
O`0608N[N@80ogl01`27ZgT20?mo00X0Qj]i0P3oO`0507jNKP80ogl03P1nWVh00`21ZH40ogl00?mo
000>06f8G003086YP@1GK4P0Efa800H0Efa81021ZH4202hd9@03086YP@2`h>H0/>3V08H0/>3V0@3o
ool008L0/>3V00H0PJV102dd;P21ZH40PJV103]8?P21ZH4906AlHP03086YP@1kVgL0Ni]g00d0Ni]g
0P3oO`000`21ZH40Qj^008N[P00208N[P080ogl01027Zh030?mo00P0Qj^00`3oO`0708fbQ0<0ogl0
2@2=/X@20?mo00D0SK:400<0PJV108jdP`2>]8<00P3oO`0808jdP`80ogl0202>]8<30?mo00@0S[B3
00@0PJV108faP02=/H00SK600`3oO`0808faP0D0ogl0202=/H020?mo0003086YP@27ZgT0Qj]i00@0
Qj]i0P3oO`0708N[N@80ogl02P27ZgT20?mo00D0OYi^0P3oO`0>07jNKP03086YP@3oO`00ogl000l0
KHQL00<0PJV105M/B01GK4P01`1GK4P01P21ZH40=d8^086YP@21ZH40;S@U086YPHL0/>3V0@3oool0
08L0/>3V0P21ZH4203]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03@1kVgL20?mo
0003086YP@27Zh00Qj^00080Qj^000<0ogl008N[P027Zh001027Zh030?mo00H0Qj^00`3oO`0908fb
Q0<0ogl01`2=/X@20?mo00H0SK:400<0PJV108jdP`2>]8<00P3oO`0808jdP`80ogl02@2>]8<50?mo
000308jdP`21ZH40ogl000@0ogl02@2=/H020?mo000308faP03oO`00ogl000<0ogl00`2=/H040?mo
0003086YP@27ZgT0Qj]i00@0Qj]i0P3oO`0708N[N@80ogl02P27ZgT20?mo00D0OYi^0`3oO`0707jN
KP80ogl0101nWVh00`21ZH40ogl00?mo000?06f8G003086YP@1GK4P0Efa800L0Efa800@0PJV103M2
;P0g@Rh0=d8^0P21ZH670;3PiP40oooo00270;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402P1TO680
0`21ZH40Ni]g07^KM`0=07^KM`80ogl000@0PJV108N[P027Zh00Qj^00P3oO`0608N[P0D0ogl00P27
Zh040?mo0003086YP@2=/X@0SK:400P0SK:4103oO`0208fbQ0D0ogl01P2=/X@00`21ZH40S[B308jd
P`020?mo00P0S[B30P3oO`0:08jdP`X0ogl02P2=/H020?mo0080SK602P3oO`000`2=/H00PJV108N[
N@0508N[N@80ogl01`27ZgT20?mo00X0Qj]i0P3oO`0607jNKP<0ogl01P1nWVh20?mo00@0OYi^00@0
PJV106f8G03oO`00ogl03P1]R5`00`21ZH40Efa805M/B00805M/B005086YP@0g@Rh0=d8^03M2;P21
ZH40Q`2`h>H10?ooo`00QP2`h>H00`21ZH40>dPn03]8?P0203]8?P03086YP@1TO680I7aR00P0I7aR
00<0PJV107^KM`1kVgL03@1kVgL20?mo0005086YP@27Zh00Qj^008N[P03oO`001`27Zh0:0?mo0003
08N[P021ZH40SK:400X0SK:42@3oO`0708fbQ003086YP@2>]8<0S[B30080ogl0202>]8<20?mo00`0
S[B31@3oO`0>08faP080ogl00`2=/H060?mo00<0SK6000<0PJV108N[N@27ZgT01027ZgT20?mo00L0
Qj]i0P3oO`0:08N[N@80ogl01`1nWVh40?mo0080OYi^1@3oO`0307jNKP04086YP@1]R5`0ogl00?mo
00h0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V
08@0/>3V0@3oool008H0/>3V00<0PJV103]8?P0kB3h00P0kB3h00`21ZH40I7aR06AlHP0806AlHP03
086YP@1kVgL0Ni]g00h0Ni]g0P3oO`0208N[P080ogl01`27Zh020?mo000308N[P03oO`00ogl000<0
ogl00`27Zh000`21ZH40SK:408fbQ00:08fbQ0D0ogl02P2=/X@00`21ZH40S[B308jdP`020?mo00P0
S[B30P3oO`0?08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT01@27ZgT20?mo00L0
Qj]i0P3oO`0908N[N@03086YP@3oO`00ogl000L0OYi^2@3oO`0507jNKP03086YP@3oO`00ogl000h0
KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V08@0
/>3V0@3oool008H0/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0:06AlHP03086YP@1kVgL0Ni]g00l0
Ni]g0P3oO`0208N[P0030?mo0027Zh00Qj^000D0Qj^00P3oO`0:08N[P003086YP@2=/X@0SK:401P0
SK:400<0PJV108jdP`2>]8<00P3oO`0908jdP`80ogl03`2>]8<00`21ZH40SK6008faP00K08faP003
086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0201nWVh50?mo00P0OYi^00<0PJV10?mo003o
O`003`1]R5`00`21ZH40Efa805M/B00705M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`
h>H0Q02`h>H10?ooo`00QP2`h>H01@21ZH40>dPn03]8?P0kB3h0PJV100X0I7aR00<0PJV107^KM`1k
VgL03`1kVgL20?mo000308N[P03oO`00ogl00180Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40
S[B308jdP`020?mo00T0S[B30P3oO`0?08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27
ZgT06027ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@3oO`00ogl000l0KHQL00<0PJV105M/B01G
K4P0201GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108H0/>3V0@3oool008D0/>3V00<0PJV103]8?P0k
B3h00P0kB3h00`21ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g0P3oO`000`27Zh00
ogl008N[P00B08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<00P3oO`0908jdP`80
ogl03`2>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1n
WVh0501nWVh00`21ZH40ogl00?mo000?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g
@Rh00P0g@Rh00`21ZH40/>3V0;3PiP230;3PiP40oooo00250;3PiP03086YP@0kB3h0>dPn0080>dPn
00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^KM`@0ogl04`27Zh000`21ZH40SK:4
08fbQ00I08fbQ003086YP@2>]8<0S[B30080ogl0202>]8<20?mo0100S[B300<0PJV108faP02=/H00
702=/H000`21ZH40Qj]i08N[N@0508N[N@030?mo0027ZgT0Qj]i0140Qj]i00<0PJV107jNKP1nWVh0
501nWVh01021ZH40KHQL0?mo003oO`0>06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g
@Rh00P0g@Rh00`21ZH40/>3V0;3PiP230;3PiP40oooo00250;3PiP05086YP@0kB3h0>dPn03]8?P21
ZH402`1TO6800`21ZH40Ni]g07^KM`0?07^KM`<0ogl05027Zh000`21ZH40SK:408fbQ00I08fbQ003
086YP@2>]8<0S[B30080ogl0202>]8<20?mo0100S[B300<0PJV108faP02=/H00702=/H000`21ZH40
Qj]i08N[N@0408N[N@<0ogl04P27ZgT00`21ZH40OYi^07jNKP0D07jNKP04086YP@1]R5`0ogl00?mo
00h0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V
08<0/>3V0@3oool008D0/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0;06AlHP03086YP@1kVgL0Ni]g
00h0Ni]g00@0PJV10?mo003oO`00ogl05027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0
S[B30080ogl0202>]8<20?mo0100S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@03
08N[N@D0ogl04@27ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@3oO`00ogl000h0KHQL00<0PJV1
05M/B01GK4P02@1GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108D0/>3V0@3oool008@0/>3V00<0PJV1
03]8?P0kB3h00P0kB3h00`21ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV1
0?mo003oO`005@27Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B30080ogl0202>]8<2
0?mo0100S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@0408N[N@<0ogl04P27ZgT0
0`21ZH40OYi^07jNKP0E07jNKP03086YP@3oO`00ogl000l0KHQL00<0PJV105M/B01GK4P0201GK4P0
0`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V0880/>3V0@3oool008@0/>3V00<0PJV103]8
?P0kB3h00P0kB3h00`21ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g00@0PJV108N[
P03oO`00ogl05027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV1
08faP02=/H00702=/H000`21ZH40Qj]i08N[N@0508N[N@030?mo0027ZgT0Qj]i0140Qj]i00<0PJV1
07jNKP1nWVh05@1nWVh00`21ZH40ogl00?mo000?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV1
03M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP220;3PiP40oooo00240;3PiP05086YP@0kB3h0>dPn
03]8?P21ZH402`1TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV1
08fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV1
08N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E07jNKP04086YP@1]R5`0ogl00?mo00h0KHQL00<0
PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V0880/>3V0@3o
ool008@0/>3V00D0PJV103]8?P0kB3h0>dPn086YP@0;06AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0
PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00J08fbQ003086YP@2>]8<0S[B301`0S[B300<0
PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@0J08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0
PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00905M/B005086YP@0g@Rh0=d8^03M2;P21ZH40
Q02`h>H10?ooo`00P`2`h>H00`21ZH40>dPn03]8?P0203]8?P03086YP@1TO680I7aR00T0I7aR00<0
PJV107^KM`1kVgL03P1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:401X0SK:400<0
PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01X0Qj]i00<0
PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00>06f8G003086YP@1GK4P0Efa800T0Efa800<0
PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP210;3PiP40oooo00230;3PiP03086YP@0kB3h0
>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00
Qj^001D0Qj^000<0PJV108fbQ02=/X@0302=/XAK086YP@h0Qj]i00<0PJV107jNKP1nWVh05@1nWVh0
0`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh0
0`21ZH40/>3V0;3PiP210;3PiP40oooo00230;3PiP05086YP@0kB3h0>dPn03]8?P21ZH402`1TO680
0`21ZH40Ni]g07^KM`0707^KMbl0PJV13P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0
UKj901`0UKj900<0PJV1092hP`2@^8<0302@^8<_086YP@T0KHQL00<0PJV105M/B01GK4P0201GK4P0
0`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V0840/>3V0@3oool008<0/>3V100kB3h00`21
ZH40I7aR06AlHP0406AlHPl0PJV12026Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00607RHJ0l0PJV11P1GK4P01@21
ZH40=d8^03M2;P0g@Rh0PJV108<0/>3V0@3oool00880/>3V00<0PJV103]8?P0kB3h02@21ZH45072?
L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09Jo
SP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092h
P`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0305ig
CPT0PJV10P0g@Rh00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP<0PJV10P18G4h00`21ZH40
L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40
U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40
T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40
GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0PJV1PP2`h>H10?ooo`00PP2`h>H00`21ZH40B5a>
04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj9
09FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V
0;3PiP200;3PiP40oooo00220;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`
Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F
_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@
^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1N
Mdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV1
04QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1
096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV1
09FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV1
07RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV1
0;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00210;3PiP03
086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03
086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03
086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03
086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003
086YP@2`h>H0/>3V0800/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma
072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>
09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3
092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>
05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`
h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G
`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0n
CS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1
072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV1
09JoSP2F_hh06@2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1
092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV1
05igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool0
0840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@08072?L@03086YP@26Zh<0QZ^3
00l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=
01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai
01D0Qjai00<0PJV107RHJ01hV6P03P1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd
00<0?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QLCP03
086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03
086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03
086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003
086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40
oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^3
08J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=
09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai
08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd
03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00P18
G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A
^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E
_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1h
V6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`
h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV1
08J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV1
09O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV1
08N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV1
03i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>
0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;
01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj9
01d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX
00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V
07l0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03
086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03
086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03
086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03
086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P02`h>H00`21ZH40B5a>
04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj9
09FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V
0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`
Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F
_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@
^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1N
Mdh00`21ZH40?Thd03i>=00303i>=003086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV1
04QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1
096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV1
09FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV1
07RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV1
0;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3Pi_<0
PJV1P02`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H
00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@1B
K5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2H
a9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2K
b980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20
YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`
h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO009
07VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J
09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J
09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F009
06J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21
ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21
ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21
ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01i
WG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2L
bIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G
`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01V
PeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V
00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=
00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E
00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR2
00<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi
00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1i
WG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2L
bIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G
`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1V
PeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo0021
0;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?
08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M
09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E
08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@02
04=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21
ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21
ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21
ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21
ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?oo
o`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>
^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2M
biD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?
^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13
EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0DVaK
00<0PJV107VMO01iWG`0201iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD
00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB
00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00h0P:Eb
00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07l0/>3V
0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>
^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0I09c9UP03086YP@2M
biD0WL^E01d0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?
^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13
EcT0@eLi00<0@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`03
059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?
082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1o
0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21
ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21
ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21
ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21
ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1B
K5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02H
a9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2K
b980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20
YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`
h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H
00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@1B
K5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2H
a9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2K
b980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20
YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`
h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO009
07VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J
09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J
09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F009
06J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21
ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21
ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP<0PJV10P1BK5/00`21ZH40NIel07VMO00907VMO003
086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03
086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003
086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003
086YP@13EcT0@eLi00<0PJV1PP2`h>H10?ooo`00PP2`h>H00`21ZH40FGQT05UhI008086YP@H0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00@0IX=H
2021ZH4204EL?003086YP@2`h>H0/>3V0800/>3V0@3oool008<0/>3V00D0PJV105UhI01IN6@0FGQT
086YP@0507nXQ@l0PJV12@2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP07082ULPl0PJV11@1/SV400`21ZH40AE`l
04EL?00204EL?8<0/>3V0@3oool008<0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086Y
P@2D`YD0U<:E00H0U<:E<021ZH4>09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980
702Kb9800`21ZH40Ul:<09O2S00<09O2S300PJV12026[gX00`21ZH40K8iQ06b>H@0806b>H@03086Y
P@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P@2`h>H10?ooo`00P`2`h>H00`21ZH40FGQT05Uh
I00205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>
V`0E09k>V`03086YP@2RdYd0X]:M00`0X]:MF`21ZH4>09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0
PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0
PJV10;3PiP2`h>H0P@2`h>H10?ooo`00P`2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0
OjR500T0OjR500<0PJV109C2U@2D`YD03P2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0
X]:M01X0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0
W<^C01X0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0>08J_NP03086YP@1/SV40
K8iQ00T0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP210;3PiP40oooo00240;3P
iP05086YP@1IN6@0FGQT05UhI021ZH402`1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0
W/jK01@0W/jK00<0PJV10:;BW@2RdYd06P2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0
XM6H01`0XM6H00<0PJV109c;T`2Lbi<06P2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0
QZmj00l0QZmj00<0PJV106b>H@1/SV402@1/SV401@21ZH40AE`l04EL?015G3`0PJV108@0/>3V0@3o
ool008@0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0
PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0
PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0
PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0
PJV10;3PiP2`h>H0PP2`h>H10?ooo`00Q02`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0
OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0
X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0
W<^C01T0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40
K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP220;3PiP40oooo00240;3P
iP03086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2
U@03086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;C
W003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1
RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL
?003086YP@2`h>H0/>3V0880/>3V0@3oool008D0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nX
Q@03086YP@2D`YD0U<:E00h0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;B
W@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;
T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0906b>
H@05086YP@15G3`0AE`l04EL?021ZH40Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40FGQT05UhI01IN6@0
PJV100/0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0
X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0
W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40
K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP230;3PiP40oooo00250;3P
iP03086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2
U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;C
W003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1
RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL
?003086YP@2`h>H0/>3V08<0/>3V0@3oool008D0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40
OjR507nXQ@0807nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40
X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40
W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40
K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00
QP2`h>H01@21ZH40FGQT05UhI01IN6@0PJV100X0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40
W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40
XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40
QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00D0PJV104EL?015G3`0AE`l086YP@260;3P
iP40oooo00260;3PiP05086YP@1IN6@0FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?09C2
U@03086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd0602RdYd00`21ZH40X]>L0:;CW00L0:;C
W003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1
RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV401`1/SV400`21ZH40AE`l04EL?00204EL
?003086YP@2`h>H0/>3V08@0/>3V0@3oool008H0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40
OjR507nXQ@0807nXQ@03086YP@2D`YD0U<:E00h0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40
X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40
W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03P26[gX00`21ZH40
K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00
QP2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD0
3`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0
6`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0
502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP240;3PiP40oooo00270;3PiP05086YP@1IN6@0FGQT05UhI021ZH40
2P1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd0
6@2RdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<0
6@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40
201/SV401@21ZH40AE`l04EL?015G3`0PJV108L0/>3V0@3oool008L0/>3V0P21ZH4205UhI003086Y
P@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086Y
P@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086Y
P@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086Y
P@1/SV40K8iQ00L0K8iQ00@0PJV104EL?015G3`0AE`l0P21ZH670;3PiP40oooo00270;3PiP06086Y
P@1MP6/0PJV1086YP@1IN6@0PJV12@1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK
01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H
01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj
00l0QZmj00<0PJV106b>H@1/SV401`1/SV401P21ZH40AE`l086YP@21ZH40Af90086YPHL0/>3V0@3o
ool008P0/>3V00<0PJV105f0J`1MP6/01021ZH4807nXQ@03086YP@2D`YD0U<:E00h0U<:E00<0PJV1
09k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV1
0:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:00<0PJV1
08J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0606b>H@@0PJV10P17HT000`21ZH40/>3V0;3PiP26
0;3PiP40oooo00280;3PiP05086YP@1MP6/0GH1[05f0J`21ZH400P23[h/6086YP@80OjR500<0PJV1
09C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01P0X]:M00<0PJV1
0:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0PJV1
09C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00H0PJV10P1`UVP0
1@21ZH40Af9004MR@017HT00PJV108P0/>3V0@3oool008T0/>3V00D0PJV105f0J`1MP6/0GH1[086Y
P@0708>_R`/0PJV12@2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01P0X]:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0
PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0708J_NP/0PJV11`1`UVP01@21ZH40Af9004MR
@017HT00PJV108T0/>3V0@3oool008T0/>3V00D0PJV105f0J`1MP6/0GH1[086YP@0908>_R`03086Y
P@2GbI/0UlVK00H0UlVK5@21ZH4;09k>V`03086YP@2RdYd0X]:M01P0X]:M00<0PJV10:;CW02Rdi`0
6`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0PJV109C1RP2D`HX0
2@2D`HXE086YP@P0R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017HT00PJV108T0
/>3V0@3oool008T0/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086Y
P@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:402@2Qe:4I086YP@d0X]:M00<0PJV10:;CW02Rdi`0
6`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C00/0W<^C6@21ZH4;09S8T003086Y
P@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@00204MR@003086Y
P@2`h>H0/>3V08L0/>3V0@3oool008X0/>3V00D0PJV105f0J`1MP6/0GH1[086YP@0908>_R`03086Y
P@2GbI/0UlVK00l0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0;0:GIXa`0PJV1
3`2Rdi`00`21ZH40XM6H0:7AV00=0:7AV1`0PJV13@2PdYT00`21ZH40V<R@09S8T00C09S8T003086Y
P@2:]X40R[J100l0R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017HT00PJV108X0
/>3V0@3oool008X0/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086Y
P@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0H0:GIX`03086Y
P@2VfZ80Y]ZR00`0Y]ZR7`21ZH4>0:CHWP03086YP@2PdYT0X=:I01P0X=:I00<0PJV109S8T02Hb900
4`2Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0L9IX00<0PJV104MR@017HT00
0P17HT000`21ZH40/>3V0;3PiP280;3PiP40oooo002:0;3PiP03086YP@1MP6/0GH1[0080GH1[00<0
PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0>09O9V`03086YP@2Qe:40XMBQ01@0XMBQ00<0
PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0K0:KJXP03086YP@2Tf9h0Y=RN01/0Y=RN00<0
PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00D09S8T003086YP@2:]X40R[J100h0R[J100<0
PJV1072FJ01`UVP01`1`UVP01@21ZH40Af9004MR@017HT00PJV108/0/>3V0@3oool008/0/>3V00D0
PJV105f0J`1MP6/0GH1[086YP@0:08>_R`03086YP@2GbI/0UlVK00d0UlVK00<0PJV10:7DX@2Qe:40
502Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01/0Y]ZR00<0PJV10:CHWP2Tf9h0
6`2Tf9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X40
3P2:]X400`21ZH40L9IX072FJ008072FJ005086YP@17HT00Af9004MR@021ZH40R`2`h>H10?ooo`00
R`2`h>H00`21ZH40GH1[05f0J`0205f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0PJV109O9V`2GbI/0
3P2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01P0YMVS00<0PJV10:KJXP2VfZ80
6P2VfZ800`21ZH40Y=RN0:CHWP0J0:CHWP03086YP@2PdYT0X=:I01P0X=:I00<0PJV109S8T02Hb900
4`2Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0L9IX00<0PJV104MR@017HT00
0P17HT000`21ZH40/>3V0;3PiP290;3PiP40oooo002<0;3PiP05086YP@1MP6/0GH1[05f0J`21ZH40
2@23[h/00`21ZH40UlVK09O9V`0>09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<0
602UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT0
602PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP0
1`1`UVP01@21ZH40Af9004MR@017HT00PJV108`0/>3V0@3oool008`0/>3V00<0PJV105f0J`1MP6/0
0P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00d0UlVK00<0PJV10:7DX@2Qe:40
502Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:CHWP2Tf9h0
6P2Tf9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01@0V<R@00<0PJV108ZfP@2:]X40
3@2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00Af900080Af9000<0PJV10;3PiP2`h>H0
RP2`h>H10?ooo`00S02`h>H00`21ZH40GH1[05f0J`0205f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0
PJV109O9V`2GbI/03P2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01L0YMVS00<0
PJV10:KJXP2VfZ806P2VfZ800`21ZH40Y=RN0:CHWP0J0:CHWP03086YP@2PdYT0X=:I01L0X=:I00<0
PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0L9IX00<0
PJV104MR@017HT000P17HT000`21ZH40/>3V0;3PiP2:0;3PiP40oooo002=0;3PiP05086YP@1MP6/0
GH1[05f0J`21ZH402P23[h/00`21ZH40UlVK09O9V`0=09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0
PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0
PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100d0R[J100<0
PJV1072FJ01`UVP0201`UVP01@21ZH40Af9004MR@017HT00PJV108d0/>3V0@3oool008d0/>3V00<0
PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00d0UlVK00<0
PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0
PJV10:CHWP2Tf9h06P2Tf9h00`21ZH40X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0
PJV108ZfP@2:]X403@2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00Af900080Af9000<0
PJV10;3PiP2`h>H0R`2`h>H10?ooo`00SP2`h>H01@21ZH40GH1[05f0J`1MP6/0PJV100T0Pjn;00<0
PJV109O9V`2GbI/03P2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01H0YMVS00<0
PJV10:KJXP2VfZ806P2VfZ800`21ZH40Y=RN0:CHWP0J0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0
PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0L9IX00D0
PJV104MR@017HT00Af90086YP@2>0;3PiP40oooo002>0;3PiP03086YP@1MP6/0GH1[0080GH1[00<0
PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0=09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0
PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN01T0Y=RN00<0
PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100d0R[J100<0
PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@00204MR@003086YP@2`h>H0/>3V08`0/>3V0@3o
ool008l0/>3V0P21ZH4205f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0PJV109O9V`2GbI/03@2GbI/0
0`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ80
0`21ZH40Y=RN0:CHWP0I0:CHWP03086YP@2PdYT0X=:I01L0X=:I00<0PJV109S8T02Hb9004`2Hb900
0`21ZH40R[J108ZfP@0=08ZfP@03086YP@1`UVP0L9IX00L0L9IX00<0PJV104MR@017HT000P21ZH6?
0;3PiP40oooo002?0;3PiP06086YP@1NQ6d0PJV1086YP@1MP6/0PJV12@23[h/00`21ZH40UlVK09O9
V`0<09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJ
XP0I0:KJXP03086YP@2Tf9h0Y=RN01T0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8
T00B09S8T003086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP01P21ZH40Af90086Y
P@21ZH40BFM5086YPHl0/>3V0@3oool00900/>3V00<0PJV105j4K@1NQ6d01021ZH4708>_R`03086Y
P@2GbI/0UlVK00d0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086Y
P@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03086Y
P@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403@2:]X400`21ZH40L9IX072FJ005072FJ0@0PJV1
0P19IdD00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002A0;3PiP06086YP@1NQ6d0GXA]05j4K@21ZH40
Pk6=1P21ZH4208>_R`03086YP@2GbI/0UlVK00`0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40
YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40
X=:I0:3BV@0F0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X40302:]X400`21ZH40
L9IX072FJ006086YP@03076JK021ZH40BFM50080BFM500<0PJV10;3PiP2`h>H0S`2`h>H10?ooo`00
T@2`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100L0Pk6=1P21ZH4;09O9V`03086YP@2Qe:40XMBQ01<0
XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN01T0
Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100T0
R[J11P21ZH47076JK005086YP@19IdD0BFM504UWA@21ZH40T@2`h>H10?ooo`00TP2`h>H01@21ZH40
GXA]05j4K@1NQ6d0PJV100T0Pk6=00<0PJV109S<WP2Hc9h02021ZH4409O9V`03086YP@2Qe:40XMBQ
0180XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN
01T0Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00B09S8T003086YP@2:]X40R[J1
0080R[J12021ZH4208^jQ@03086YP@1aVV`0LIY/00L0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2B
0;3PiP40oooo002C0;3PiP04086YP@1NQ6d0GXA]086YP@T0Pk6=00<0PJV109S<WP2Hc9h0202Hc9h:
086YPA00XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2Tf9h0
Y=RN01P0Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00>09S8T0X0PJV12P2;^XD0
0`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40T`2`h>H10?ooo`00T`2`h>H0
1@21ZH40GXA]05j4K@1NQ6d0PJV100T0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?I
Y@030:?IY@/0PJV11@2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01P0Y]ZR00<0
PJV10:CHWP2Tf9h0602Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03086YP@2Hb900V<R@00<0V<R@2`21
ZH4509W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01`1aVV`01@21ZH40BFM504UW
A@19IdD0PJV109<0/>3V0@3oool009@0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086Y
P@2Hc9h0V<bN00`0V<bN00<0PJV10:?IY@2SfJD03@2SfJDB086YP@`0YMVS00<0PJV10:KJXP2VfZ80
602VfZ800`21ZH40Y=RN0:CHWP0H0:CHWP03086YP@2PdYT0X=:I00X0X=:I4P21ZH4?09W<U003086Y
P@2;^XD0RkZ500`0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109@0
/>3V0@3oool009@0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0908>aS@03086YP@2Hc9h0V<bN00/0
V<bN00<0PJV10:?IY@2SfJD04P2SfJD00`21ZH40YmjW0:ONY`0:0:ONYdl0PJV1302Reid00`21ZH40
VLbD09W<U00B09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01`1aVV`01@21ZH40
BFM504UWA@19IdD0PJV109@0/>3V0@3oool009D0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>a
S@03086YP@2Hc9h0V<bN00`0V<bN00<0PJV10:?IY@2SfJD04P2SfJD00`21ZH40YmjW0:ONY`0E0:ON
Y`03086YP@2XgjH0Z=nV01P0Z=nV00<0PJV10:KLXP2Vg:80602Vg:800`21ZH40X]NM0:;GW@0E0:;G
W@03086YP@2Ic9@0VLbD0180VLbD00<0PJV108^jQ@2;^XD0302;^XD00`21ZH40LIY/076JK006076J
K005086YP@19IdD0BFM504UWA@21ZH40U@2`h>H10?ooo`00UP2`h>H01@21ZH40GXA]05j4K@1NQ6d0
PJV100P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0B0:?IY@03086YP@2WgZL0
YmjW01D0YmjW00<0PJV10:SOYP2XgjH0602XgjH00`21ZH40Y]bR0:KLXP0H0:KLXP03086YP@2Reid0
X]NM01D0X]NM00<0PJV109W<U02Ic9@04P2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0
LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2F0;3PiP40oooo002F0;3PiP05086YP@1NQ6d0
GXA]05j4K@21ZH402023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0XmVU0140XmVU00<0
PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0H0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0
PJV10:;GW@2Reid05P2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500`0RkZ500<0
PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109H0/>3V0@3oool009L0/>3V00D0
PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0PJV10:?IY@2SfJD0
4@2SfJD00`21ZH40YmjW0:ONY`0F0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:KLXP2Vg:80
5`2Vg:800`21ZH40X]NM0:;GW@0F0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;^XD0
2`2;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21ZH40U`2`h>H10?ooo`00
V02`h>H01021ZH40GXA]05j4K@21ZH4808>aS@03086YP@2Hc9h0V<bN00`0V<bN00<0PJV10:?IY@2S
fJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:KLXP2V
g:805`2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;
^XD0302;^XD00`21ZH40LIY/076JK005076JK005086YP@19IdD0BFM504UWA@21ZH40V02`h>H10?oo
o`00V02`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21
ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21
ZH40Y]bR0:KLXP0G0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21
ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2H
0;3PiP40oooo002I0;3PiP80PJV10P1NQ6d00`21ZH40Pk6=08>aS@0508>aS@03086YP@2Hc9h0V<bN
00/0V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV
01L0Z=nV00<0PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD
0140VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK005076JK003086YP@19IdD0BFM5
0080PJV1V@2`h>H10?ooo`00VP2`h>H4086YP@P0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40
XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40
Y]bR0:KLXP0G0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40
RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00H0LIY/1021ZH6J0;3PiP40oooo002K0;3PiP03086Y
P@1KPV`0PJV10080PJV11P23/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU
00<0PJV10:ONY`2WgZL0502WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR
00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ5
00<0PJV1076JK01aVV`0101aVV`3086YP@0304QYB021ZH40/>3V09X0/>3V0@3oool009`0/>3V00<0
PJV105^2K01KPV`01021ZH4408>aS@03086YP@2Hc9h0V<bN00/0V<bN00<0PJV10:?IY@2SfJD0402S
fJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805P2V
g:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0100VLbD00<0PJV108^jQ@2;^XD02`2;
^XD00`21ZH40LIY/076JK002076JK0@0PJV10P18JDP00`21ZH40/>3V0;3PiP2J0;3PiP40oooo002L
0;3PiP05086YP@1KPV`0Fh9/05^2K021ZH400P1n[X/5086YP@d0V<bN00<0PJV10:?IY@2SfJD04@2S
fJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805P2V
g:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD0140VLbD00<0PJV108^jQ@2;^XD02`2;
^XD5086YP@80KYU/00D0PJV104QYB018JDP0B6U8086YP@2L0;3PiP40oooo002M0;3PiP04086YP@1K
PV`0Fh9/086YP@H0OZj;1021ZH4;09S<WP03086YP@2SfJD0XmVU0100XmVU00<0PJV10:ONY`2WgZL0
502WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV10:;GW@2Reid0
502Reid00`21ZH40VLbD09W<U00@09W<U003086YP@2;^XD0RkZ500T0RkZ51021ZH4606jIK004086Y
P@18JDP0B6U8086YPId0/>3V0@3oool009h0/>3V00@0PJV105^2K01KPV`0PJV11`1n[X/00`21ZH40
U<ZM086YP@04086YP@H0V<bN00<0PJV10:?IY@2SfJD0402SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03
086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03
086YP@2Ic9@0VLbD0100VLbD00<0PJV108^jQ@2;^XD0102;^XD5086YP@0308RiQ@21ZH40KYU/00H0
KYU/00@0PJV104QYB018JDP0PJV1WP2`h>H10?ooo`00W`2`h>H01021ZH40Fh9/05^2K021ZH4707j^
R`03086YP@2DbYd0U<ZM00<0U<ZM1@21ZH4209S<WP03086YP@2SfJD0XmVU00l0XmVU00<0PJV10:ON
Y`2WgZL0502WgZL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2Vg:80Y]bR01H0Y]bR00<0PJV10:;G
W@2Reid0502Reid00`21ZH40VLbD09W<U00?09W<U003086YP@2;^XD0RkZ500D0PJV11P28^HD00`21
ZH40KYU/06jIK00406jIK004086YP@18JDP0B6U8086YPIl0/>3V0@3oool00:00/>3V00@0PJV105^2
K01KPV`0PJV11P1n[X/00`21ZH40U<ZM09C:W@0809C:W@`0PJV12@2SfJD00`21ZH40YmjW0:ONY`0C
0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2Vg:805@2Vg:800`21ZH40X]NM0:;GW@0D
0:;GW@03086YP@2Ic9@0VLbD00L0VLbD3021ZH4:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV1
04QYB018JDP0PJV1X02`h>H10?ooo`00X@2`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2D
bYd0U<ZM00X0U<ZM00<0PJV10:3HY@2Pf:D01P2Pf:D?086YPA40YmjW00<0PJV10:SOYP2XgjH05@2X
gjH00`21ZH40Y]bR0:KLXP0E0:KLXP03086YP@2Reid0X]NM00l0X]NM3`21ZH4809S=U@03086YP@28
^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6Q0;3PiP40oooo
002R0;3PiP03086YP@1KPV`0PJV100L0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3H
Y@0?0:3HY@03086YP@2VgZP0Y]jX00<0Y]jX3021ZH450:ONY`03086YP@2XgjH0Z=nV01D0Z=nV00<0
PJV10:KLXP2Vg:805@2Vg:800`21ZH40X]NM0:;GW@030:;GW@`0PJV11@2Qf9h00`21ZH40V<fE09S=
U@0?09S=U@03086YP@28^HD0R;V500T0R;V500<0PJV106jIK01^VF`01@1^VF`00`21ZH40B6U8086Y
P@2R0;3PiP40oooo002R0;3PiP04086YP@1KPV`0Fh9/086YP@L0OZj;00<0PJV109C:W@2DbYd02@2D
bYd00`21ZH40X=RU0:3HY@0?0:3HY@03086YP@2VgZP0Y]jX00h0Y]jX>`21ZH4@0:7HWP03086YP@2H
cID0V<fE00l0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK00406jIK004086YP@18
JDP0B6U8086YPJ80/>3V0@3oool00:<0/>3V00@0PJV105^2K01KPV`0PJV11`1n[X/00`21ZH40U<ZM
09C:W@0909C:W@03086YP@2Pf:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04`2VgZP00`21ZH40Yn2W
0:OPY`0E0:OPY`03086YP@2VgZ@0Y]jT01D0Y]jT00<0PJV10:7HWP2Qf9h04`2Qf9h00`21ZH40V<fE
09S=U@0>09S=U@03086YP@28^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U8
04QYB021ZH6S0;3PiP40oooo002T0;3PiP04086YP@1KPV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2D
bYd02P2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX0180Y]jX00<0PJV10:OPY`2W
h:L05@2Wh:L00`21ZH40Y]jT0:KNY00E0:KNY003086YP@2Qf9h0XMRN0180XMRN00<0PJV109S=U@2H
cID03P2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018
JDP0PJV1Y02`h>H10?ooo`00Y@2`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2DbYd0U<ZM
00T0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00C0:KNZ003086YP@2Wh:L0Yn2W
01@0Yn2W00<0PJV10:KNY02VgZ@0502VgZ@00`21ZH40XMRN0:7HWP0C0:7HWP03086YP@2HcID0V<fE
00h0V<fE00<0PJV108RiQ@28^HD02@28^HD00`21ZH40KYU/06jIK00406jIK004086YP@18JDP0B6U8
086YPJD0/>3V0@3oool00:H0/>3V0`21ZH4707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3H
Y@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00B0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KN
Y02VgZ@0502VgZ@00`21ZH40XMRN0:7HWP0B0:7HWP03086YP@2HcID0V<fE00h0V<fE00<0PJV108Ri
Q@28^HD02P28^HD00`21ZH40KYU/06jIK00406jIK0<0PJV1YP2`h>H10?ooo`00Y`2`h>H3086YP@L0
OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0180
Y]jX00<0PJV10:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0XMRN0180
XMRN00<0PJV109S=U@2HcID03@2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0
KYU/0`21ZH6W0;3PiP40oooo002Y0;3PiP<0PJV11P1n[X/00`21ZH40U<ZM09C:W@0809C:W@03086Y
P@2Pf:D0X=RU00h0X=RU00<0PJV10:KNZ02VgZP04@2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086Y
P@2VgZ@0Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04@2Qf9h00`21ZH40V<fE09S=U@0>09S=U@03086Y
P@28^HD0R;V500T0R;V500<0PJV106jIK01^VF`00`1^VF`3086YPJT0/>3V0@3oool00:X0/>3V1@21
ZH4307j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21ZH40Y]jX0:KN
Z00A0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7H
WP0B0:7HWP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD02@28^HD01021ZH40KYU/06jI
K01^VF`5086YPJX0/>3V0@3oool00:/0/>3V00@0PJV105AkIP21ZH40M:B31@21ZH4;09C:W@03086Y
P@2Pf:D0X=RU00d0X=RU00<0PJV10:KNZ02VgZP04@2VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086Y
P@2VgZ@0Y]jT01<0Y]jT00<0PJV10:7HWP2Qf9h04@2Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086Y
P@28^HD0R;V500X0R;V51021ZH40101VTFP0PJV104AUB021ZH6[0;3PiP40oooo002/0;3PiP<0PJV1
101dY8<5086YP@P0U<ZM00<0PJV10:3HY@2Pf:D0302Pf:D00`21ZH40Y]jX0:KNZ00A0:KNZ003086Y
P@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7HWP0A0:7HWP03086Y
P@2HcID0V<fE00`0V<fE00<0PJV108RiQ@28^HD01`28^HD5086YP@<0IY5X0`21ZH6/0;3PiP40oooo
002^0;3PiP<0PJV1101dY8<00`21ZH40Rl2F08_0UP06086YP@80U<ZM00<0PJV10:3HY@2Pf:D03@2P
f:D00`21ZH40Y]jX0:KNZ00@0:KNZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2V
gZ@00`21ZH40XMRN0:7HWP0@0:7HWP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD01`21
ZH4207naP@04086YP@1VTFP0IY5X06JAJ0<0PJV1[P2`h>H10?ooo`00[`2`h>H00`21ZH40E7]V086Y
P@0407BTP`03086YP@2;`9H0Rl2F00D0Rl2F1`21ZH4;0:3HY@03086YP@2VgZP0Y]jX0100Y]jX00<0
PJV10:OPY`2Wh:L04`2Wh:L00`21ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0100XMRN00<0
PJV109S=U@2HcID02@2HcID7086YP@P0Ok6100L0PJV106JAJ01VTFP0IY5X086YP@14IDP0PJV10:l0
/>3V0@3oool00;00/>3V00<0PJV105AkIP21ZH40101dY8<00`21ZH40Rl2F08_0UP0808_0UP03086Y
P@2HdJ00V=6P00P0PJV1102Pf:D00`21ZH40Y]jX0:KNZ00@0:KNZ003086YP@2Wh:L0Yn2W0180Yn2W
00<0PJV10:KNY02VgZ@04P2VgZ@00`21ZH40XMRN0:7HWP0@0:7HWP03086YP@2HcID0V<fE0080V<fE
2021ZH420936T@03086YP@1o/H40Ok6100P0Ok610P21ZH4306JAJ003086YP@14IDP0PJV10;00/>3V
0@3oool00;40/>3V1021ZH4307BTP`03086YP@2;`9H0Rl2F00P0Rl2F00<0PJV109SAX02HdJ001`2H
dJ0>086YP@T0Y]jX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40Y]jT0:KNY00B0:KNY003086YP@2Q
f9h0XMRN00L0XMRN3P21ZH490936T@03086YP@1o/H40Ok6100P0Ok6100@0PJV106JAJ01VTFP0IY5X
1021ZH6a0;3PiP40oooo002c0;3PiP03086YP@1DNfH0PJV100<0M:B300<0PJV108_0UP2;`9H0202;
`9H00`21ZH40V=6P09SAX00;09SAX003086YP@2OfJD0WmVU00H0WmVU?@21ZH4809[BW003086YP@2@
aY40T<JA00/0T<JA00<0PJV107naP@1o/H40201o/H401`21ZH40IY5X06JAJ01VTFP0PJV104AUB021
ZH40/`2`h>H10?ooo`00]02`h>H3086YP@<0M:B30P21ZH4908_0UP03086YP@2HdJ00V=6P00X0V=6P
00<0PJV109oIY@2OfJD03`2OfJD00`21ZH40XM^U0:7KY@0B0:7KY@03086YP@2PfJ80X=VR0180X=VR
00<0PJV109[BW02JdY`03`2JdY`00`21ZH40T<JA0936T@0:0936T@03086YP@1o/H40Ok6100P0Ok61
00@0PJV106JAJ01VTFP0IY5X0`21ZH6d0;3PiP40oooo002e0;3PiP@0PJV10`1dY8<00`21ZH40Rl2F
08_0UP0708_0UP03086YP@2HdJ00V=6P00X0V=6P00<0PJV109oIY@2OfJD03`2OfJD00`21ZH40XM^U
0:7KY@0A0:7KY@03086YP@2PfJ80X=VR0140X=VR00<0PJV109[BW02JdY`03`2JdY`00`21ZH40T<JA
0936T@0:0936T@03086YP@1o/H40Ok6100P0Ok6100<0PJV106JAJ01VTFP01021ZH6e0;3PiP40oooo
002g0;3PiP@0PJV10P1dY8<00`21ZH40Rl2F08_0UP0608_0UP03086YP@2HdJ00V=6P00/0V=6P00<0
PJV109oIY@2OfJD03P2OfJD00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2PfJ80X=VR0140X=VR00<0
PJV109[BW02JdY`03P2JdY`00`21ZH40T<JA0936T@0;0936T@03086YP@1o/H40Ok6100H0Ok610P21
ZH400`1VTFP0PJV1086YP@02086YPKL0/>3V0@3oool00;T0/>3V1021ZH400`1dY8<0PJV108_0UP07
08_0UP03086YP@2HdJ00V=6P00/0V=6P00<0PJV109oIY@2OfJD03@2OfJD00`21ZH40XM^U0:7KY@0A
0:7KY@03086YP@2PfJ80X=VR0140X=VR00<0PJV109[BW02JdY`03@2JdY`00`21ZH40T<JA0936T@0;
0936T@03086YP@1o/H40Ok6100H0Ok6100<0PJV106JAJ021ZH400`21ZH6i0;3PiP40oooo002k0;3P
iPD0PJV1202;`9H00`21ZH40V=6P09SAX00:09SAX003086YP@2OfJD0WmVU00h0WmVU00<0PJV10:7K
Y@2QfjD0402QfjD00`21ZH40X=VR0:3IXP0@0:3IXP03086YP@2JdY`0V]:L00h0V]:L00<0PJV10936
T@2@aY402P2@aY400`21ZH40Ok6107naP@0607naP@D0PJV1^`2`h>H10?ooo`00_02`h>H7086YP@H0
Rl2F00<0PJV109SAX02HdJ002P2HdJ000`21ZH40WmVU09oIY@0=09oIY@03086YP@2QfjD0XM^U0100
XM^U00<0PJV10:3IXP2PfJ80402PfJ800`21ZH40V]:L09[BW00=09[BW003086YP@2@aY40T<JA00X0
T<JA00<0PJV107naP@1o/H40101o/H47086YPK`0/>3V0@3oool00;h0/>3V2`21ZH400`2;`9H0PJV1
09SAX00;09SAX003086YP@2OfJD0WmVU00d0WmVU00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40X=VR
0:3IXP0?0:3IXP03086YP@2JdY`0V]:L00d0V]:L00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok61
086YP@0:086YPKh0/>3V0@3oool00<00/>3V1@21ZH4407Z]R0H0PJV12@2HdJ000`21ZH40WmVU09oI
Y@0<09oIY@03086YP@2QfjD0XM^U00l0XM^U00<0PJV10:3IXP2PfJ803`2PfJ800`21ZH40V]:L09[B
W00<09[BW003086YP@2@aY40T<JA00L0T<JA1P21ZH44072PMPD0PJV1`02`h>H10?ooo`00`P2`h>H2
086YP@0306BBM@21ZH40PJV100D0NZf80P21ZH400`28_Y<0PJV1086YP@05086YP@80V=6P00<0PJV1
09oIY@2OfJD0302OfJD00`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2PfJ80X=VR00l0X=VR00<0PJV1
09[BW02JdY`0302JdY`00`21ZH40T<JA0936T@07086YP@03086eQP21ZH40PJV100D0L:1f0P21ZH40
0`1IPUl0PJV1086YP@320;3PiP40oooo00340;3PiP80PJV100<0I99e086YP@1j[HP01@1j[HP00`21
ZH40R;jC08RnT`0508RnT`/0PJV11`2OfJD00`21ZH40XM^U0:7KY@0>0:7KY@03086YP@2PfJ80X=VR
00h0X=VR00<0PJV109[BW02JdY`01@2JdY`;086YP@L0PKF600<0PJV1072PMP1`X7H0101`X7H01021
ZH40FH9O086YP@21ZH740;3PiP40oooo00350;3PiPD0PJV11@1j[HP2086YP@T0R;jC00<0PJV10938
V@2@b9T0102@b9Ta086YP@H0S<>A00<0PJV1086eQP21]HH01`21]HH2086YP@D0L:1f1@21ZH750;3P
iP40oooo00370;3PiPD0PJV11@1j[HP00`21ZH40R;jC08RnT`0708RnT`03086YP@2@b9T0T<RI00/0
T<RI00<0PJV109?<V`2Cc9/03@2Cc9/00`21ZH40T/ZH09;:V00=09;:V003086YP@2<`i40S<>A00/0
S<>A00<0PJV1086eQP21]HH01`21]HH00`21ZH40L:1f072PMP03072PMPD0PJV1a`2`h>H10?ooo`00
bP2`h>H4086YP@@0NZf80P21ZH4808RnT`03086YP@2@b9T0T<RI00X0T<RI00<0PJV109?<V`2Cc9/0
3@2Cc9/00`21ZH40T/ZH09;:V00=09;:V003086YP@2<`i40S<>A00X0S<>A00<0PJV1086eQP21]HH0
1P21]HH2086YP@@0L:1f1021ZH7:0;3PiP40oooo003=0;3PiP@0PJV10`1j[HP00`21ZH40R;jC08Rn
T`0608RnT`80PJV12`2@b9T00`21ZH40TlbK09?<V`0<09?<V`03086YP@2BbYP0T/ZH00`0T/ZH00<0
PJV108c3T@2<`i402@2<`i42086YP@P0PKF600@0PJV1072PMP1`X7H0L:1f1021ZH7=0;3PiP40oooo
003@0;3PiPL0PJV12028_Y<00`21ZH40T<RI0938V@090938V@03086YP@2Cc9/0TlbK00/0TlbK00<0
PJV109;:V02BbYP02`2BbYP00`21ZH40S<>A08c3T@0908c3T@03086YP@21]HH0PKF600H0PKF61`21
ZH7@0;3PiP40oooo003C0;3PiPT0PJV11028_Y<00`21ZH40T<RI0938V@090938V@03086YP@2Cc9/0
TlbK00X0TlbK00<0PJV109;:V02BbYP02P2BbYP00`21ZH40S<>A08c3T@0908c3T@03086YP@21]HH0
PKF60080PKF62@21ZH7C0;3PiP40oooo003F0;3PiQ40PJV11@2@b9T00`21ZH40TlbK09?<V`0:09?<
V`03086YP@2BbYP0T/ZH00X0T/ZH00<0PJV108c3T@2<`i400`2<`i4;086YP@0306RGLP21ZH40PJV1
00<0PJV1eP2`h>H10?ooo`00f@2`h>H5086YP@@0KIil0P21ZH4307FXPRD0PJV10`1bY7`2086YP@@0
J9Mb1@21ZH7I0;3PiP40oooo003L0;3PiPD0PJV10`1]WW`2086YP@P0MJR200<0PJV107R/Q01h[8@0
201h[8@00`21ZH40Mj^207N[PP0807N[PP03086YP@1bY7`0LZAl00H0LZAl0P21ZH4306RGLPD0PJV1
g02`h>H10?ooo`00h02`h>H8086YP@L0MJR200<0PJV107R/Q01h[8@01`1h[8@00`21ZH40Mj^207N[
PP0707N[PP03086YP@1bY7`0LZAl00D0LZAl2021ZH7P0;3PiP40oooo003V0;3PiPL0PJV10`1eZ880
0`21ZH40N:b407R/Q00607R/Q003086YP@1gZh80Mj^200H0Mj^200@0PJV107:TO01bY7`0LZAl1`21
ZH7V0;3PiP40oooo003]0;3PiQT0PJV1k@2`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.608 .781 .571 r
.47008 .46971 m .46978 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.608 .781 .571 r
.51009 .5 m .50999 .46977 L .47008 .46971 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.50999 .53023 m .51009 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.50999 .46977 m .51009 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.51009 .5 m .50999 .53023 L .5497 .53041 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.5497 .53041 m .5502 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.43078 .46941 m .43007 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.46978 .5 m .47008 .46971 L .43078 .46941 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.47008 .53029 m .46978 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.46978 .5 m .47008 .53029 L .50999 .53023 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.471 .43976 m .47008 .46971 L .50999 .46977 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.50999 .46977 m .50968 .43988 L .471 .43976 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.50968 .56012 m .50999 .53023 L .47008 .53029 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.50968 .43988 m .50999 .46977 L .5497 .46959 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.5502 .5 m .5497 .46959 L .50999 .46977 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.50999 .53023 m .50968 .56012 L .54817 .56047 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.54817 .56047 m .5497 .53041 L .50999 .53023 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.43291 .43918 m .43078 .46941 L .47008 .46971 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.47008 .46971 m .471 .43976 L .43291 .43918 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.43007 .5 m .43078 .53059 L .47008 .53029 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.471 .56024 m .47008 .53029 L .43078 .53059 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.47008 .53029 m .471 .56024 L .50968 .56012 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.5497 .46959 m .5502 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.5502 .5 m .5497 .53041 L .58839 .53084 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.58839 .53084 m .58931 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49754 .56117 m
.49989 .56015 L
s
.50945 .56012 m
.51188 .56119 L
s
.49754 .56117 m
.49348 .56468 L
s
.5 Mabswid
.625 .809 .596 r
.5497 .46959 m .54817 .43953 L .50968 .43988 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.54817 .43953 m .5497 .46959 L .58839 .46916 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.58931 .5 m .58839 .46916 L .5497 .46959 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.5497 .53041 m .54817 .56047 L .58564 .56129 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.58564 .56129 m .58839 .53084 L .5497 .53041 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.47258 .56023 m
.47504 .56127 L
s
.46476 .55958 m
.47003 .55952 L
s
.5 Mabswid
.634 .824 .605 r
.47252 .41051 m .471 .43976 L .50968 .43988 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.50968 .43988 m .50918 .41067 L .47252 .41051 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.50918 .58933 m .50968 .56012 L .471 .56024 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.50918 .41067 m .50968 .43988 L .54817 .43953 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.50968 .56012 m .50918 .58933 L .54563 .58982 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.54563 .58982 m .54817 .56047 L .50968 .56012 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.43648 .40968 m .43291 .43918 L .471 .43976 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.471 .43976 m .47252 .41051 L .43648 .40968 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.43078 .53059 m .43291 .56082 L .471 .56024 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.47252 .58949 m .471 .56024 L .43291 .56082 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.471 .56024 m .47252 .58949 L .50918 .58933 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.39291 .46886 m .39179 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.43007 .5 m .43078 .46941 L .39291 .46886 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.43078 .53059 m .43007 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.39627 .43812 m .39291 .46886 L .43078 .46941 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.43078 .46941 m .43291 .43918 L .39627 .43812 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.39179 .5 m .39291 .53114 L .43078 .53059 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.43291 .56082 m .43078 .53059 L .39291 .53114 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.54817 .43953 m .54563 .41018 L .50918 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.54563 .41018 m .54817 .43953 L .58564 .43871 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.58839 .46916 m .58564 .43871 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.54817 .56047 m .54563 .58982 L .58106 .59098 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.58106 .59098 m .58564 .56129 L .54817 .56047 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44199 .56739 m
.44341 .57033 L
s
.44341 .57033 m
.44373 .57361 L
s
.5 Mabswid
.606 .779 .582 r
.58839 .46916 m .58931 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.58931 .5 m .58839 .53084 L .62519 .53151 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.62519 .53151 m .62652 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.47466 .38233 m .47252 .41051 L .50918 .41067 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.50918 .41067 m .50846 .38253 L .47466 .38233 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.50846 .61747 m .50918 .58933 L .47252 .58949 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.50846 .38253 m .50918 .41067 L .54563 .41018 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.50918 .58933 m .50846 .61747 L .54206 .61807 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.54206 .61807 m .54563 .58982 L .50918 .58933 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.40187 .4082 m .39627 .43812 L .43291 .43918 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.43291 .43918 m .43648 .40968 L .40187 .4082 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.39291 .53114 m .39627 .56188 L .43291 .56082 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.43648 .59032 m .43291 .56082 L .39627 .56188 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.43291 .56082 m .43648 .59032 L .47252 .58949 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.58564 .43871 m .58839 .46916 L .62519 .46849 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.62652 .5 m .62519 .46849 L .58839 .46916 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.58839 .53084 m .58564 .56129 L .62122 .56259 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.62122 .56259 m .62519 .53151 L .58839 .53084 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.44147 .38133 m .43648 .40968 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.47252 .41051 m .47466 .38233 L .44147 .38133 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.47466 .61767 m .47252 .58949 L .43648 .59032 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.47252 .58949 m .47466 .61767 L .50846 .61747 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.54563 .41018 m .54206 .38193 L .50846 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.54206 .38193 m .54563 .41018 L .58106 .40902 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.58564 .43871 m .58106 .40902 L .54563 .41018 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.54563 .58982 m .54206 .61807 L .57465 .61947 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.57465 .61947 m .58106 .59098 L .54563 .58982 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.58106 .40902 m .58564 .43871 L .62122 .43741 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.62519 .46849 m .62122 .43741 L .58564 .43871 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.58564 .56129 m .58106 .59098 L .61461 .59279 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.61461 .59279 m .62122 .56259 L .58564 .56129 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.35742 .46806 m .35589 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.39179 .5 m .39291 .46886 L .35742 .46806 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.39291 .53114 m .39179 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.40969 .37953 m .40187 .4082 L .43648 .40968 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.43648 .40968 m .44147 .38133 L .40969 .37953 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.39627 .56188 m .40187 .5918 L .43648 .59032 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.44147 .61867 m .43648 .59032 L .40187 .5918 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.43648 .59032 m .44147 .61867 L .47466 .61767 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.36201 .43659 m .35742 .46806 L .39291 .46886 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.39291 .46886 m .39627 .43812 L .36201 .43659 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.35589 .5 m .35742 .53194 L .39291 .53114 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.39627 .56188 m .39291 .53114 L .35742 .53194 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.39367 .56121 m
.39533 .56115 L
s
.5 Mabswid
.652 .857 .633 r
.47742 .35564 m .47466 .38233 L .50846 .38253 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.50846 .38253 m .50754 .35586 L .47742 .35564 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.50754 .64414 m .50846 .61747 L .47466 .61767 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.50754 .35586 m .50846 .38253 L .54206 .38193 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.50846 .61747 m .50754 .64414 L .53747 .64479 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.53747 .64479 m .54206 .61807 L .50846 .61747 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.44788 .35455 m .44147 .38133 L .47466 .38233 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.47466 .38233 m .47742 .35564 L .44788 .35455 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.47742 .64436 m .47466 .61767 L .44147 .61867 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.47466 .61767 m .47742 .64436 L .50754 .64414 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.36963 .40606 m .36201 .43659 L .39627 .43812 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.39627 .43812 m .40187 .4082 L .36963 .40606 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.35742 .53194 m .36201 .56341 L .39627 .56188 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.40187 .5918 m .39627 .56188 L .36201 .56341 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.58106 .40902 m .57465 .38053 L .54206 .38193 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.57465 .38053 m .58106 .40902 L .61461 .40721 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.62122 .43741 m .61461 .40721 L .58106 .40902 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.58106 .59098 m .57465 .61947 L .60538 .62166 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.60538 .62166 m .61461 .59279 L .58106 .59098 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.53747 .35521 m .54206 .38193 L .57465 .38053 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.54206 .61807 m .53747 .64479 L .56643 .64632 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.56643 .64632 m .57465 .61947 L .54206 .61807 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.54206 .38193 m .53747 .35521 L .50754 .35586 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.62519 .46849 m .62652 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.62652 .5 m .62519 .53151 L .6591 .53242 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.6591 .53242 m .66083 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.62122 .43741 m .62519 .46849 L .6591 .46758 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.66083 .5 m .6591 .46758 L .62519 .46849 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.62519 .53151 m .62122 .56259 L .6539 .56435 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.6539 .56435 m .6591 .53242 L .62519 .53151 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.41972 .3526 m .40969 .37953 L .44147 .38133 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.44147 .38133 m .44788 .35455 L .41972 .3526 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.40187 .5918 m .40969 .62047 L .44147 .61867 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.44788 .64545 m .44147 .61867 L .40969 .62047 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.44147 .61867 m .44788 .64545 L .47742 .64436 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.38025 .37696 m .36963 .40606 L .40187 .4082 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.40187 .4082 m .40969 .37953 L .38025 .37696 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.36201 .56341 m .36963 .59394 L .40187 .5918 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.40969 .62047 m .40187 .5918 L .36963 .59394 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.61461 .40721 m .62122 .43741 L .6539 .43565 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.6591 .46758 m .6539 .43565 L .62122 .43741 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.62122 .56259 m .61461 .59279 L .64528 .59525 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.64528 .59525 m .6539 .56435 L .62122 .56259 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.57465 .38053 m .56643 .35368 L .53747 .35521 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.56643 .35368 m .57465 .38053 L .60538 .37834 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.61461 .40721 m .60538 .37834 L .57465 .38053 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.57465 .61947 m .56643 .64632 L .59358 .6487 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.59358 .6487 m .60538 .62166 L .57465 .61947 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.3254 .46703 m .32346 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.35589 .5 m .35742 .46806 L .3254 .46703 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.35742 .53194 m .35589 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.48078 .33093 m .47742 .35564 L .50754 .35586 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.50754 .35586 m .50642 .33115 L .48078 .33093 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.50642 .33115 m .50754 .35586 L .53747 .35521 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.50642 .66885 m .50754 .64414 L .47742 .64436 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.50754 .64414 m .50642 .66885 L .53187 .6695 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.53187 .6695 m .53747 .64479 L .50754 .64414 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.33119 .4346 m .3254 .46703 L .35742 .46806 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.35742 .46806 m .36201 .43659 L .33119 .4346 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.32346 .5 m .3254 .53297 L .35742 .53194 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.36201 .56341 m .35742 .53194 L .3254 .53297 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.4557 .32985 m .44788 .35455 L .47742 .35564 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.47742 .35564 m .48078 .33093 L .4557 .32985 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.48078 .66907 m .47742 .64436 L .44788 .64545 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.47742 .64436 m .48078 .66907 L .50642 .66885 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.60538 .37834 m .61461 .40721 L .64528 .40475 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.6539 .43565 m .64528 .40475 L .61461 .40721 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.61461 .59279 m .60538 .62166 L .6333 .62462 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.6333 .62462 m .64528 .59525 L .61461 .59279 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.53187 .3305 m .53747 .35521 L .56643 .35368 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.53747 .35521 m .53187 .3305 L .50642 .33115 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.53747 .64479 m .53187 .6695 L .55641 .67102 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.55641 .67102 m .56643 .64632 L .53747 .64479 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.39379 .3498 m .38025 .37696 L .40969 .37953 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.40969 .37953 m .41972 .3526 L .39379 .3498 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.36963 .59394 m .38025 .62304 L .40969 .62047 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.41972 .6474 m .40969 .62047 L .38025 .62304 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.40969 .62047 m .41972 .6474 L .44788 .64545 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.34079 .40328 m .33119 .4346 L .36201 .43659 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.36201 .43659 m .36963 .40606 L .34079 .40328 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.3254 .53297 m .33119 .5654 L .36201 .56341 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.36963 .59394 m .36201 .56341 L .33119 .5654 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.4319 .32791 m .41972 .3526 L .44788 .35455 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.44788 .35455 m .4557 .32985 L .4319 .32791 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.4557 .67015 m .44788 .64545 L .41972 .6474 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.44788 .64545 m .4557 .67015 L .48078 .66907 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.56643 .35368 m .55641 .32898 L .53187 .3305 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.55641 .32898 m .56643 .35368 L .59358 .3513 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.60538 .37834 m .59358 .3513 L .56643 .35368 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.56643 .64632 m .55641 .67102 L .57927 .67338 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.57927 .67338 m .59358 .6487 L .56643 .64632 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.35411 .37361 m .34079 .40328 L .36963 .40606 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.36963 .40606 m .38025 .37696 L .35411 .37361 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.33119 .5654 m .34079 .59672 L .36963 .59394 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.38025 .62304 m .36963 .59394 L .34079 .59672 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.6591 .46758 m .66083 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.66083 .5 m .6591 .53242 L .68892 .53358 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.68892 .53358 m .69106 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.59358 .3513 m .60538 .37834 L .6333 .37538 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.64528 .40475 m .6333 .37538 L .60538 .37834 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.60538 .62166 m .59358 .6487 L .61805 .65191 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.61805 .65191 m .6333 .62462 L .60538 .62166 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.6539 .43565 m .6591 .46758 L .68892 .46642 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.69106 .5 m .68892 .46642 L .6591 .46758 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.6591 .53242 m .6539 .56435 L .68254 .56657 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6538 .56473 m
.65486 .56551 L
s
.5 Mabswid
.522 .66 .502 r
.68254 .56657 m .68892 .53358 L .6591 .53242 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.64528 .40475 m .6539 .43565 L .68254 .43343 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.68892 .46642 m .68254 .43343 L .6539 .43565 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.6539 .56435 m .64528 .59525 L .67199 .59835 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.67199 .59835 m .68254 .56657 L .6539 .56435 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41017 .32514 m .39379 .3498 L .41972 .3526 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41972 .3526 m .4319 .32791 L .41017 .32514 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.38025 .62304 m .39379 .6502 L .41972 .6474 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.4319 .67209 m .41972 .6474 L .39379 .6502 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.41972 .6474 m .4319 .67209 L .4557 .67015 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.48475 .30872 m .48078 .33093 L .50642 .33115 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.50642 .33115 m .5051 .30892 L .48475 .30872 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.5051 .30892 m .50642 .33115 L .53187 .3305 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.5051 .69108 m .50642 .66885 L .48078 .66907 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.50642 .66885 m .5051 .69108 L .52528 .69167 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.52528 .69167 m .53187 .6695 L .50642 .66885 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.4649 .30775 m .4557 .32985 L .48078 .33093 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.48078 .33093 m .48475 .30872 L .4649 .30775 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.48475 .69128 m .48078 .66907 L .4557 .67015 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.48078 .66907 m .48475 .69128 L .5051 .69108 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.37101 .34619 m .35411 .37361 L .38025 .37696 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.38025 .37696 m .39379 .3498 L .37101 .34619 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.34079 .59672 m .35411 .62639 L .38025 .62304 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.39379 .6502 m .38025 .62304 L .35411 .62639 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.52528 .30833 m .53187 .3305 L .55641 .32898 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.53187 .3305 m .52528 .30833 L .5051 .30892 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.53187 .6695 m .52528 .69167 L .54465 .69302 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.54465 .69302 m .55641 .67102 L .53187 .6695 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.6333 .37538 m .64528 .40475 L .67199 .40165 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.68254 .43343 m .67199 .40165 L .64528 .40475 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.64528 .59525 m .6333 .62462 L .65738 .62833 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.65738 .62833 m .67199 .59835 L .64528 .59525 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.59358 .3513 m .57927 .32662 L .55641 .32898 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.57927 .32662 m .59358 .3513 L .61805 .34809 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.6333 .37538 m .61805 .34809 L .59358 .3513 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59358 .6487 m .57927 .67338 L .59968 .67653 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59968 .67653 m .61805 .65191 L .59358 .6487 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.44617 .30602 m .4319 .32791 L .4557 .32985 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.4557 .32985 m .4649 .30775 L .44617 .30602 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4649 .69225 m .4557 .67015 L .4319 .67209 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.4557 .67015 m .4649 .69225 L .48475 .69128 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.29812 .46575 m .29579 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.32346 .5 m .3254 .46703 L .29812 .46575 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.3254 .53297 m .32346 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.30507 .43216 m .29812 .46575 L .3254 .46703 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.3254 .46703 m .33119 .4346 L .30507 .43216 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.29579 .5 m .29812 .53425 L .3254 .53297 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.33119 .5654 m .3254 .53297 L .29812 .53425 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.55641 .32898 m .54465 .30698 L .52528 .30833 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.54465 .30698 m .55641 .32898 L .57927 .32662 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.55641 .67102 m .54465 .69302 L .56257 .69512 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.56257 .69512 m .57927 .67338 L .55641 .67102 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.31654 .39987 m .30507 .43216 L .33119 .4346 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.33119 .4346 m .34079 .40328 L .31654 .39987 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.29812 .53425 m .30507 .56784 L .33119 .5654 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.34079 .59672 m .33119 .5654 L .30507 .56784 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.61805 .34809 m .6333 .37538 L .65738 .37167 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.67199 .40165 m .65738 .37167 L .6333 .37538 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6333 .62462 m .61805 .65191 L .6389 .65589 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6389 .65589 m .65738 .62833 L .6333 .62462 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.3913 .3216 m .37101 .34619 L .39379 .3498 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.39379 .3498 m .41017 .32514 L .3913 .3216 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.35411 .62639 m .37101 .65381 L .39379 .6502 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.41017 .67486 m .39379 .6502 L .37101 .65381 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.39379 .6502 m .41017 .67486 L .4319 .67209 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.42923 .30356 m .41017 .32514 L .4319 .32791 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.4319 .32791 m .44617 .30602 L .42923 .30356 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.44617 .69398 m .4319 .67209 L .41017 .67486 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4319 .67209 m .44617 .69398 L .4649 .69225 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.33238 .36955 m .31654 .39987 L .34079 .40328 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.34079 .40328 m .35411 .37361 L .33238 .36955 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.30507 .56784 m .31654 .60013 L .34079 .59672 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.35411 .62639 m .34079 .59672 L .31654 .60013 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.57927 .32662 m .56257 .30488 L .54465 .30698 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.56257 .30488 m .57927 .32662 L .59968 .32347 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.61805 .34809 m .59968 .32347 L .57927 .32662 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57927 .67338 m .56257 .69512 L .57837 .69792 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57837 .69792 m .59968 .67653 L .57927 .67338 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.68892 .46642 m .69106 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.69106 .5 m .68892 .53358 L .71329 .53497 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.71329 .53497 m .7158 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.48931 .28962 m .48475 .30872 L .5051 .30892 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.5051 .30892 m .50357 .28977 L .48931 .28962 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50357 .28977 m .5051 .30892 L .52528 .30833 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.50357 .71023 m .5051 .69108 L .48475 .69128 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.5051 .69108 m .50357 .71023 L .51772 .71068 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.51772 .71068 m .52528 .69167 L .5051 .69108 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.68254 .43343 m .68892 .46642 L .71329 .46503 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.7158 .5 m .71329 .46503 L .68892 .46642 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.68892 .53358 m .68254 .56657 L .7058 .56923 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.7058 .56923 m .71329 .53497 L .68892 .53358 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.47542 .28887 m .4649 .30775 L .48475 .30872 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.48475 .30872 m .48931 .28962 L .47542 .28887 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.48931 .71038 m .48475 .69128 L .4649 .69225 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.48475 .69128 m .48931 .71038 L .50357 .71023 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.61805 .65191 m .59968 .67653 L .6168 .68043 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.6168 .68043 m .6389 .65589 L .61805 .65191 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.59968 .32347 m .61805 .34809 L .6389 .34411 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.65738 .37167 m .6389 .34411 L .61805 .34809 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35235 .34184 m .33238 .36955 L .35411 .37361 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35411 .37361 m .37101 .34619 L .35235 .34184 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.31654 .60013 m .33238 .63045 L .35411 .62639 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.37101 .65381 m .35411 .62639 L .33238 .63045 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.52528 .30833 m .51772 .28932 L .50357 .28977 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.51772 .28932 m .52528 .30833 L .54465 .30698 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.52528 .69167 m .51772 .71068 L .53123 .71173 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.53123 .71173 m .54465 .69302 L .52528 .69167 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.67199 .40165 m .68254 .43343 L .7058 .43077 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.71329 .46503 m .7058 .43077 L .68254 .43343 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.68254 .56657 m .67199 .59835 L .69345 .60204 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.69345 .60204 m .7058 .56923 L .68254 .56657 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4624 .28754 m .44617 .30602 L .4649 .30775 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4649 .30775 m .47542 .28887 L .4624 .28754 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.47542 .71113 m .4649 .69225 L .44617 .69398 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.4649 .69225 m .47542 .71113 L .48931 .71038 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41472 .30044 m .3913 .3216 L .41017 .32514 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41017 .32514 m .42923 .30356 L .41472 .30044 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.37101 .65381 m .3913 .6784 L .41017 .67486 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.42923 .69644 m .41017 .67486 L .3913 .6784 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.41017 .67486 m .42923 .69644 L .44617 .69398 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.54465 .30698 m .53123 .28827 L .51772 .28932 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.53123 .28827 m .54465 .30698 L .56257 .30488 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.65738 .37167 m .67199 .40165 L .69345 .39796 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.7058 .43077 m .69345 .39796 L .67199 .40165 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54465 .69302 m .53123 .71173 L .54362 .71333 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54362 .71333 m .56257 .69512 L .54465 .69302 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67199 .59835 m .65738 .62833 L .67646 .63273 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67646 .63273 m .69345 .60204 L .67199 .59835 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37612 .31737 m .35235 .34184 L .37101 .34619 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37101 .34619 m .3913 .3216 L .37612 .31737 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.33238 .63045 m .35235 .65816 L .37101 .65381 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.3913 .6784 m .37101 .65381 L .35235 .65816 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.45076 .28567 m .42923 .30356 L .44617 .30602 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.44617 .30602 m .4624 .28754 L .45076 .28567 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.4624 .71246 m .44617 .69398 L .42923 .69644 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.44617 .69398 m .4624 .71246 L .47542 .71113 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.59968 .32347 m .57837 .30208 L .56257 .30488 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.57837 .30208 m .59968 .32347 L .6168 .31957 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.6389 .34411 m .6168 .31957 L .59968 .32347 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59968 .67653 m .57837 .69792 L .59141 .70134 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59141 .70134 m .6168 .68043 L .59968 .67653 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.6389 .34411 m .65738 .37167 L .67646 .36727 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.69345 .39796 m .67646 .36727 L .65738 .37167 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65738 .62833 m .6389 .65589 L .65512 .66059 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65512 .66059 m .67646 .63273 L .65738 .62833 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.27706 .46425 m .27438 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.29579 .5 m .29812 .46575 L .27706 .46425 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.29812 .53425 m .29579 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.28506 .42929 m .27706 .46425 L .29812 .46575 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.29812 .46575 m .30507 .43216 L .28506 .42929 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.27438 .5 m .27706 .53575 L .29812 .53425 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.30507 .56784 m .29812 .53425 L .27706 .53575 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.56257 .30488 m .54362 .28667 L .53123 .28827 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.54362 .28667 m .56257 .30488 L .57837 .30208 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.56257 .69512 m .54362 .71333 L .5544 .71545 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.5544 .71545 m .57837 .69792 L .56257 .69512 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.29822 .3959 m .28506 .42929 L .30507 .43216 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.30507 .43216 m .31654 .39987 L .29822 .3959 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.27706 .53575 m .28506 .57071 L .30507 .56784 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.31654 .60013 m .30507 .56784 L .28506 .57071 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.6168 .31957 m .6389 .34411 L .65512 .33941 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.67646 .36727 m .65512 .33941 L .6389 .34411 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.6389 .65589 m .6168 .68043 L .62982 .68498 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.62982 .68498 m .65512 .66059 L .6389 .65589 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.44095 .28331 m .41472 .30044 L .42923 .30356 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.42923 .30356 m .45076 .28567 L .44095 .28331 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.3913 .6784 m .41472 .69956 L .42923 .69644 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.45076 .71433 m .42923 .69644 L .41472 .69956 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.42923 .69644 m .45076 .71433 L .4624 .71246 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.40332 .29675 m .37612 .31737 L .3913 .3216 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.3913 .3216 m .41472 .30044 L .40332 .29675 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.35235 .65816 m .37612 .68263 L .3913 .6784 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.41472 .69956 m .3913 .6784 L .37612 .68263 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31627 .36485 m .29822 .3959 L .31654 .39987 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31654 .39987 m .33238 .36955 L .31627 .36485 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.28506 .57071 m .29822 .6041 L .31654 .60013 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.33238 .63045 m .31654 .60013 L .29822 .6041 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.49441 .27429 m .48931 .28962 L .50357 .28977 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.50357 .28977 m .50187 .27437 L .49441 .27429 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50187 .27437 m .50357 .28977 L .51772 .28932 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.50187 .72563 m .50357 .71023 L .48931 .71038 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50357 .71023 m .50187 .72563 L .50926 .72588 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50926 .72588 m .51772 .71068 L .50357 .71023 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48716 .27387 m .47542 .28887 L .48931 .28962 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48931 .28962 m .49441 .27429 L .48716 .27387 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.49441 .72571 m .48931 .71038 L .47542 .71113 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.48931 .71038 m .49441 .72571 L .50187 .72563 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51772 .28932 m .50926 .27412 L .50187 .27437 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.50926 .27412 m .51772 .28932 L .53123 .28827 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51772 .71068 m .50926 .72588 L .51628 .72647 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51628 .72647 m .53123 .71173 L .51772 .71068 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33884 .33683 m .31627 .36485 L .33238 .36955 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33238 .36955 m .35235 .34184 L .33884 .33683 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.29822 .6041 m .31627 .63515 L .33238 .63045 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.35235 .65816 m .33238 .63045 L .31627 .63515 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.48043 .27312 m .4624 .28754 L .47542 .28887 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.47542 .28887 m .48716 .27387 L .48043 .27312 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.48716 .72613 m .47542 .71113 L .4624 .71246 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.47542 .71113 m .48716 .72613 L .49441 .72571 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.57837 .30208 m .5544 .28455 L .54362 .28667 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.5544 .28455 m .57837 .30208 L .59141 .29866 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.6168 .31957 m .59141 .29866 L .57837 .30208 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.57837 .69792 m .5544 .71545 L .56312 .71802 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.56312 .71802 m .59141 .70134 L .57837 .69792 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.53123 .28827 m .51628 .27353 L .50926 .27412 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.51628 .27353 m .53123 .28827 L .54362 .28667 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.53123 .71173 m .51628 .72647 L .52266 .72736 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.52266 .72736 m .54362 .71333 L .53123 .71173 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.59141 .29866 m .6168 .31957 L .62982 .31502 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.65512 .33941 m .62982 .31502 L .6168 .31957 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.6168 .68043 m .59141 .70134 L .60104 .70529 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.60104 .70529 m .62982 .68498 L .6168 .68043 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.47448 .27209 m .45076 .28567 L .4624 .28754 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.4624 .28754 m .48043 .27312 L .47448 .27209 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.48043 .72688 m .4624 .71246 L .45076 .71433 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.4624 .71246 m .48043 .72688 L .48716 .72613 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.71329 .46503 m .7158 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.7158 .5 m .71329 .53497 L .73061 .53658 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.73061 .53658 m .73345 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.7058 .43077 m .71329 .46503 L .73061 .46342 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.73345 .5 m .73061 .46342 L .71329 .46503 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.71329 .53497 m .7058 .56923 L .72215 .57228 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.72215 .57228 m .73061 .53658 L .71329 .53497 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.36548 .31254 m .33884 .33683 L .35235 .34184 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.35235 .34184 m .37612 .31737 L .36548 .31254 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.31627 .63515 m .33884 .66317 L .35235 .65816 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.37612 .68263 m .35235 .65816 L .33884 .66317 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.43343 .28055 m .40332 .29675 L .41472 .30044 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.41472 .30044 m .44095 .28331 L .43343 .28055 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.37612 .68263 m .40332 .70325 L .41472 .69956 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.44095 .71669 m .41472 .69956 L .40332 .70325 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.41472 .69956 m .44095 .71669 L .45076 .71433 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.69345 .39796 m .7058 .43077 L .72215 .42772 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.73061 .46342 m .72215 .42772 L .7058 .43077 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.7058 .56923 m .69345 .60204 L .70827 .60627 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.70827 .60627 m .72215 .57228 L .7058 .56923 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.54362 .28667 m .52266 .27264 L .51628 .27353 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.52266 .27264 m .54362 .28667 L .5544 .28455 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.54362 .71333 m .52266 .72736 L .52813 .72853 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.52813 .72853 m .5544 .71545 L .54362 .71333 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.69345 .60204 m .67646 .63273 L .68929 .63772 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.68929 .63772 m .70827 .60627 L .69345 .60204 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.67646 .36727 m .69345 .39796 L .70827 .39373 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.72215 .42772 m .70827 .39373 L .69345 .39796 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.46955 .2708 m .44095 .28331 L .45076 .28567 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.45076 .28567 m .47448 .27209 L .46955 .2708 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.47448 .72791 m .45076 .71433 L .44095 .71669 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.45076 .71433 m .47448 .72791 L .48043 .72688 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.39561 .29258 m .36548 .31254 L .37612 .31737 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.37612 .31737 m .40332 .29675 L .39561 .29258 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.33884 .66317 m .36548 .68746 L .37612 .68263 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.40332 .70325 m .37612 .68263 L .36548 .68746 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.65512 .33941 m .67646 .36727 L .68929 .36228 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.70827 .39373 m .68929 .36228 L .67646 .36727 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.67646 .63273 m .65512 .66059 L .66565 .66587 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.66565 .66587 m .68929 .63772 L .67646 .63273 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.59141 .29866 m .56312 .28198 L .5544 .28455 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.56312 .28198 m .59141 .29866 L .60104 .29471 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.62982 .31502 m .60104 .29471 L .59141 .29866 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.59141 .70134 m .56312 .71802 L .56935 .72096 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.56935 .72096 m .60104 .70529 L .59141 .70134 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.5544 .28455 m .52813 .27147 L .52266 .27264 L p F P
.505 .664 .505 r
s
.582 .805 .615 r
.52813 .27147 m .5544 .28455 L .56312 .28198 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.5544 .71545 m .52813 .72853 L .53245 .72993 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.53245 .72993 m .56312 .71802 L .5544 .71545 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.62982 .31502 m .65512 .33941 L .66565 .33413 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.68929 .36228 m .66565 .33413 L .65512 .33941 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.65512 .66059 m .62982 .68498 L .63789 .69005 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.63789 .69005 m .66565 .66587 L .65512 .66059 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.46589 .2693 m .43343 .28055 L .44095 .28331 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.44095 .28331 m .46955 .2708 L .46589 .2693 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.40332 .70325 m .43343 .71945 L .44095 .71669 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.46955 .7292 m .44095 .71669 L .43343 .71945 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.44095 .71669 m .46955 .7292 L .47448 .72791 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.42859 .27747 m .39561 .29258 L .40332 .29675 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.40332 .29675 m .43343 .28055 L .42859 .27747 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.36548 .68746 m .39561 .70742 L .40332 .70325 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.43343 .71945 m .40332 .70325 L .39561 .70742 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.26391 .46256 m .26093 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.27438 .5 m .27706 .46425 L .26391 .46256 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.27706 .53575 m .27438 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.556 .775 .586 r
.50187 .27437 m .5 .26345 L .49441 .27429 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50926 .27412 m .5 .26345 L .50187 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50187 .72563 L .49441 .72571 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .50926 .72588 L .50187 .72563 L closepath p F P
.505 .664 .505 r
s
.554 .772 .584 r
.49441 .27429 m .5 .26345 L .48716 .27387 L closepath p F P
.505 .664 .505 r
s
.201 .208 .158 r
.5 .73655 m .49441 .72571 L .48716 .72613 L closepath p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27276 .42606 m .26391 .46256 L .27706 .46425 L p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27706 .46425 m .28506 .42929 L .27276 .42606 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.26093 .5 m .26391 .53744 L .27706 .53575 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.28506 .57071 m .27706 .53575 L .26391 .53744 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.60104 .29471 m .62982 .31502 L .63789 .30995 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.66565 .33413 m .63789 .30995 L .62982 .31502 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.62982 .68498 m .60104 .70529 L .60667 .70964 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.60667 .70964 m .63789 .69005 L .62982 .68498 L p F P
.505 .664 .505 r
s
.554 .773 .587 r
.51628 .27353 m .5 .26345 L .50926 .27412 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51628 .72647 L .50926 .72588 L closepath p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28726 .39146 m .27276 .42606 L .28506 .42929 L p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28506 .42929 m .29822 .3959 L .28726 .39146 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.26391 .53744 m .27276 .57394 L .28506 .57071 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.29822 .6041 m .28506 .57071 L .27276 .57394 L p F P
.505 .664 .505 r
s
.55 .767 .58 r
.48716 .27387 m .5 .26345 L .48043 .27312 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48716 .72613 L .48043 .72688 L closepath p F P
.505 .664 .505 r
s
.582 .805 .615 r
.56312 .28198 m .53245 .27007 L .52813 .27147 L p F P
.505 .664 .505 r
s
.563 .782 .6 r
.53245 .27007 m .56312 .28198 L .56935 .27904 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.60104 .29471 m .56935 .27904 L .56312 .28198 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.56312 .71802 m .53245 .72993 L .53542 .73151 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.53542 .73151 m .56935 .72096 L .56312 .71802 L p F P
.505 .664 .505 r
s
.551 .769 .585 r
.52266 .27264 m .5 .26345 L .51628 .27353 L closepath p F P
.505 .664 .505 r
s
.197 .203 .154 r
.5 .73655 m .52266 .72736 L .51628 .72647 L closepath p F P
.505 .664 .505 r
s
.393 .535 .368 r
.30703 .35961 m .28726 .39146 L .29822 .3959 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.29822 .3959 m .31627 .36485 L .30703 .35961 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.27276 .57394 m .28726 .60854 L .29822 .6041 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.31627 .63515 m .29822 .6041 L .28726 .60854 L p F P
.505 .664 .505 r
s
.544 .761 .575 r
.48043 .27312 m .5 .26345 L .47448 .27209 L closepath p F P
.505 .664 .505 r
s
.197 .203 .155 r
.5 .73655 m .48043 .72688 L .47448 .72791 L closepath p F P
.505 .664 .505 r
s
.422 .581 .408 r
.33154 .33131 m .30703 .35961 L .31627 .36485 L p F P
.505 .664 .505 r
s
.422 .581 .408 r
.31627 .36485 m .33884 .33683 L .33154 .33131 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.28726 .60854 m .30703 .64039 L .31627 .63515 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.33884 .66317 m .31627 .63515 L .30703 .64039 L p F P
.505 .664 .505 r
s
.546 .764 .581 r
.52813 .27147 m .5 .26345 L .52266 .27264 L closepath p F P
.505 .664 .505 r
s
.192 .199 .152 r
.5 .73655 m .52813 .72853 L .52266 .72736 L closepath p F P
.505 .664 .505 r
s
.547 .76 .59 r
.56935 .27904 m .60104 .29471 L .60667 .29036 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.63789 .30995 m .60667 .29036 L .60104 .29471 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.60104 .70529 m .56935 .72096 L .57273 .72415 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.57273 .72415 m .60667 .70964 L .60104 .70529 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.46365 .26765 m .42859 .27747 L .43343 .28055 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.43343 .28055 m .46589 .2693 L .46365 .26765 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.39561 .70742 m .42859 .72253 L .43343 .71945 L p F P
.505 .664 .505 r
s
.2 .206 .157 r
.46589 .7307 m .43343 .71945 L .42859 .72253 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.43343 .71945 m .46589 .7307 L .46955 .7292 L p F P
.505 .664 .505 r
s
.537 .753 .568 r
.47448 .27209 m .5 .26345 L .46955 .2708 L closepath p F P
.505 .664 .505 r
s
.193 .199 .152 r
.5 .73655 m .47448 .72791 L .46955 .7292 L closepath p F P
.505 .664 .505 r
s
.448 .622 .444 r
.36017 .30728 m .33154 .33131 L .33884 .33683 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.33884 .33683 m .36548 .31254 L .36017 .30728 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.30703 .64039 m .33154 .66869 L .33884 .66317 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.36548 .68746 m .33884 .66317 L .33154 .66869 L p F P
.505 .664 .505 r
s
.539 .756 .576 r
.53245 .27007 m .5 .26345 L .52813 .27147 L closepath p F P
.505 .664 .505 r
s
.187 .194 .148 r
.5 .73655 m .53245 .72993 L .52813 .72853 L closepath p F P
.505 .664 .505 r
s
.471 .657 .477 r
.39217 .28809 m .36017 .30728 L .36548 .31254 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.36548 .31254 m .39561 .29258 L .39217 .28809 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.33154 .66869 m .36017 .69272 L .36548 .68746 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.39561 .70742 m .36548 .68746 L .36017 .69272 L p F P
.505 .664 .505 r
s
.529 .742 .561 r
.46955 .2708 m .5 .26345 L .46589 .2693 L closepath p F P
.505 .664 .505 r
s
.187 .195 .148 r
.5 .73655 m .46955 .7292 L .46589 .7307 L closepath p F P
.505 .664 .505 r
s
.563 .782 .6 r
.56935 .27904 m .53542 .26849 L .53245 .27007 L p F P
.505 .664 .505 r
s
.538 .753 .58 r
.53542 .26849 m .56935 .27904 L .57273 .27585 L p F P
.505 .664 .505 r
s
.547 .76 .59 r
.60667 .29036 m .57273 .27585 L .56935 .27904 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.56935 .72096 m .53542 .73151 L .53689 .73321 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.53689 .73321 m .57273 .72415 L .56935 .72096 L p F P
.505 .664 .505 r
s
.531 .746 .57 r
.53542 .26849 m .5 .26345 L .53245 .27007 L closepath p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .53542 .73151 L .53245 .72993 L closepath p F P
.505 .664 .505 r
s
.489 .686 .505 r
.42673 .27419 m .39217 .28809 L .39561 .29258 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.39561 .29258 m .42859 .27747 L .42673 .27419 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.36017 .69272 m .39217 .71191 L .39561 .70742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.42859 .72253 m .39561 .70742 L .39217 .71191 L p F P
.505 .664 .505 r
s
.52 .731 .553 r
.46589 .2693 m .5 .26345 L .46365 .26765 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.42859 .72253 m .46365 .73235 L .46589 .7307 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .46589 .7307 L .46365 .73235 L closepath p F P
.505 .664 .505 r
s
.301 .396 .336 r
.73061 .46342 m .73345 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73345 .5 m .73061 .53658 L .73916 .53835 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73916 .53835 m .74225 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.72215 .42772 m .73061 .46342 L .73916 .46165 L p F P
.505 .664 .505 r
s
.301 .396 .336 r
.74225 .5 m .73916 .46165 L .73061 .46342 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.73061 .53658 m .72215 .57228 L .72998 .57566 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.72998 .57566 m .73916 .53835 L .73061 .53658 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.70827 .39373 m .72215 .42772 L .72998 .42434 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.73916 .46165 m .72998 .42434 L .72215 .42772 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.72215 .57228 m .70827 .60627 L .71499 .61091 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.71499 .61091 m .72998 .57566 L .72215 .57228 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.46298 .26592 m .42673 .27419 L .42859 .27747 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.42859 .27747 m .46365 .26765 L .46298 .26592 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.39217 .71191 m .42673 .72581 L .42859 .72253 L p F P
.505 .664 .505 r
s
.182 .189 .144 r
.46365 .73235 m .42859 .72253 L .42673 .72581 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.70827 .60627 m .68929 .63772 L .69462 .64316 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.69462 .64316 m .71499 .61091 L .70827 .60627 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.68929 .36228 m .70827 .39373 L .71499 .38909 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.72998 .42434 m .71499 .38909 L .70827 .39373 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.66565 .33413 m .68929 .36228 L .69462 .35684 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.71499 .38909 m .69462 .35684 L .68929 .36228 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.68929 .63772 m .66565 .66587 L .66947 .67158 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.66947 .67158 m .69462 .64316 L .68929 .63772 L p F P
.505 .664 .505 r
s
.522 .735 .562 r
.53689 .26679 m .5 .26345 L .53542 .26849 L closepath p F P
.505 .664 .505 r
s
.538 .753 .58 r
.57273 .27585 m .53689 .26679 L .53542 .26849 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .53689 .73321 L .53542 .73151 L closepath p F P
.505 .664 .505 r
s
.461 .645 .517 r
.63789 .30995 m .66565 .33413 L .66947 .32842 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.69462 .35684 m .66947 .32842 L .66565 .33413 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.66565 .66587 m .63789 .69005 L .64026 .69546 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.64026 .69546 m .66947 .67158 L .66565 .66587 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.63789 .69005 m .60667 .70964 L .60781 .71423 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.60781 .71423 m .64026 .69546 L .63789 .69005 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.60667 .29036 m .63789 .30995 L .64026 .30454 L p F P
.505 .664 .505 r
s
.461 .645 .517 r
.66947 .32842 m .64026 .30454 L .63789 .30995 L p F P
.505 .664 .505 r
s
.509 .719 .544 r
.46365 .26765 m .5 .26345 L .46298 .26592 L closepath p F P
.505 .664 .505 r
s
.182 .189 .144 r
.42673 .72581 m .46298 .73408 L .46365 .73235 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .46365 .73235 L .46298 .73408 L closepath p F P
.505 .664 .505 r
s
.497 .701 .55 r
.57273 .27585 m .60667 .29036 L .60781 .28577 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.64026 .30454 m .60781 .28577 L .60667 .29036 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.60667 .70964 m .57273 .72415 L .573 .72747 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.573 .72747 m .60781 .71423 L .60667 .70964 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.57273 .72415 m .53689 .73321 L .53675 .73495 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.53675 .73495 m .573 .72747 L .57273 .72415 L p F P
.505 .664 .505 r
s
.507 .716 .555 r
.53689 .26679 m .57273 .27585 L .573 .27253 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.60781 .28577 m .573 .27253 L .57273 .27585 L p F P
.505 .664 .505 r
s
.511 .722 .553 r
.53675 .26505 m .5 .26345 L .53689 .26679 L closepath p F P
.505 .664 .505 r
s
.507 .716 .555 r
.573 .27253 m .53675 .26505 L .53689 .26679 L p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .53675 .73495 L .53689 .73321 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .53499 .73666 L .53675 .73495 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .53165 .73825 L .53499 .73666 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .52684 .73967 L .53165 .73825 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .52077 .74082 L .52684 .73967 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .51372 .74166 L .52077 .74082 L closepath p F P
.505 .664 .505 r
s
.136 .148 .112 r
.5 .73655 m .506 .74214 L .51372 .74166 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49799 .74224 L .506 .74214 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49008 .74195 L .49799 .74224 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48265 .74128 L .49008 .74195 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .47605 .74028 L .48265 .74128 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .47058 .73899 L .47605 .74028 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .46649 .73747 L .47058 .73899 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .46392 .73581 L .46649 .73747 L closepath p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .46298 .73408 L .46392 .73581 L closepath p F P
.505 .664 .505 r
s
.5 .709 .543 r
.53499 .26334 m .5 .26345 L .53675 .26505 L closepath p F P
.505 .664 .505 r
s
.498 .705 .534 r
.46298 .26592 m .5 .26345 L .46392 .26419 L closepath p F P
.505 .664 .505 r
s
.489 .695 .534 r
.53165 .26175 m .5 .26345 L .53499 .26334 L closepath p F P
.505 .664 .505 r
s
.487 .692 .525 r
.46392 .26419 m .5 .26345 L .46649 .26253 L closepath p F P
.505 .664 .505 r
s
.478 .682 .524 r
.52684 .26033 m .5 .26345 L .53165 .26175 L closepath p F P
.505 .664 .505 r
s
.477 .68 .517 r
.46649 .26253 m .5 .26345 L .47058 .26101 L closepath p F P
.505 .664 .505 r
s
.469 .671 .515 r
.52077 .25918 m .5 .26345 L .52684 .26033 L closepath p F P
.505 .664 .505 r
s
.468 .669 .509 r
.47058 .26101 m .5 .26345 L .47605 .25972 L closepath p F P
.505 .664 .505 r
s
.461 .661 .508 r
.51372 .25834 m .5 .26345 L .52077 .25918 L closepath p F P
.505 .664 .505 r
s
.461 .66 .504 r
.47605 .25972 m .5 .26345 L .48265 .25872 L closepath p F P
.505 .664 .505 r
s
.456 .655 .503 r
.506 .25786 m .5 .26345 L .51372 .25834 L closepath p F P
.505 .664 .505 r
s
.456 .654 .5 r
.48265 .25872 m .5 .26345 L .49008 .25805 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49799 .25776 m .5 .26345 L .506 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49008 .25805 m .5 .26345 L .49799 .25776 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.42808 .72914 m .46392 .73581 L .46298 .73408 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.46298 .73408 m .42673 .72581 L .42808 .72914 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.42673 .27419 m .46298 .26592 L .46392 .26419 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.39342 .71655 m .42808 .72914 L .42673 .72581 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.42673 .72581 m .39217 .71191 L .39342 .71655 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.46392 .26419 m .42808 .27086 L .42673 .27419 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.39217 .28809 m .42673 .27419 L .42808 .27086 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.42808 .27086 m .39342 .28345 L .39217 .28809 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.36017 .30728 m .39217 .28809 L .39342 .28345 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.36089 .69823 m .39342 .71655 L .39217 .71191 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.39217 .71191 m .36017 .69272 L .36089 .69823 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.573 .72747 m .53675 .73495 L .53499 .73666 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.53675 .26505 m .573 .27253 L .57001 .26922 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.57001 .26922 m .53499 .26334 L .53675 .26505 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.39342 .28345 m .36089 .30177 L .36017 .30728 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.33154 .33131 m .36017 .30728 L .36089 .30177 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.33142 .67453 m .36089 .69823 L .36017 .69272 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.36017 .69272 m .33154 .66869 L .33142 .67453 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.30591 .64599 m .33142 .67453 L .33154 .66869 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.33154 .66869 m .30703 .64039 L .30591 .64599 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.36089 .30177 m .33142 .32547 L .33154 .33131 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.30703 .35961 m .33154 .33131 L .33142 .32547 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.43272 .73238 m .46649 .73747 L .46392 .73581 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.46392 .73581 m .42808 .72914 L .43272 .73238 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.42808 .27086 m .46392 .26419 L .46649 .26253 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.33142 .32547 m .30591 .35401 L .30703 .35961 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.28726 .39146 m .30703 .35961 L .30591 .35401 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.28515 .61333 m .30591 .64599 L .30703 .64039 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.30703 .64039 m .28726 .60854 L .28515 .61333 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.26981 .57743 m .28515 .61333 L .28726 .60854 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.28726 .60854 m .27276 .57394 L .26981 .57743 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.30591 .35401 m .28515 .38667 L .28726 .39146 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.27276 .42606 m .28726 .39146 L .28515 .38667 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.60781 .71423 m .573 .72747 L .57001 .73078 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53499 .73666 m .57001 .73078 L .573 .72747 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.573 .27253 m .60781 .28577 L .60411 .28114 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.60411 .28114 m .57001 .26922 L .573 .27253 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.2604 .53929 m .26981 .57743 L .27276 .57394 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.27276 .57394 m .26391 .53744 L .2604 .53929 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.28515 .38667 m .26981 .42257 L .27276 .42606 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26391 .46256 m .27276 .42606 L .26981 .42257 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26981 .42257 m .2604 .46071 L .26391 .46256 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.26093 .5 m .26391 .46256 L .2604 .46071 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.25723 .5 m .2604 .53929 L .26391 .53744 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.26391 .53744 m .26093 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.2604 .46071 m .25723 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.57001 .73078 m .53499 .73666 L .53165 .73825 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.53499 .26334 m .57001 .26922 L .56374 .26608 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.56374 .26608 m .53165 .26175 L .53499 .26334 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.44056 .73538 m .47058 .73899 L .46649 .73747 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.46649 .73747 m .43272 .73238 L .44056 .73538 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.43272 .26762 m .46649 .26253 L .47058 .26101 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.46649 .26253 m .43272 .26762 L .42808 .27086 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.64026 .69546 m .60781 .71423 L .60411 .71886 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.57001 .73078 m .60411 .71886 L .60781 .71423 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.60781 .28577 m .64026 .30454 L .63633 .299 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.63633 .299 m .60411 .28114 L .60781 .28577 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.39961 .72113 m .43272 .73238 L .42808 .72914 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.42808 .72914 m .39342 .71655 L .39961 .72113 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.39342 .28345 m .42808 .27086 L .43272 .26762 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.53165 .73825 m .56374 .73392 L .57001 .73078 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.56374 .73392 m .53165 .73825 L .52684 .73967 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.53165 .26175 m .56374 .26608 L .55439 .26327 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.55439 .26327 m .52684 .26033 L .53165 .26175 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.66947 .67158 m .64026 .69546 L .63633 .701 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.60411 .71886 m .63633 .701 L .64026 .69546 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.64026 .30454 m .66947 .32842 L .6657 .32251 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.6657 .32251 m .63633 .299 L .64026 .30454 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.45134 .73796 m .47605 .74028 L .47058 .73899 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.47058 .73899 m .44056 .73538 L .45134 .73796 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.44056 .26462 m .47058 .26101 L .47605 .25972 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.47058 .26101 m .44056 .26462 L .43272 .26762 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.52684 .73967 m .55439 .73673 L .56374 .73392 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.55439 .73673 m .52684 .73967 L .52077 .74082 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.52684 .26033 m .55439 .26327 L .5423 .26094 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.5423 .26094 m .52077 .25918 L .52684 .26033 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.69462 .64316 m .66947 .67158 L .6657 .67749 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.63633 .701 m .6657 .67749 L .66947 .67158 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.66947 .32842 m .69462 .35684 L .69127 .35115 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.69127 .35115 m .6657 .32251 L .66947 .32842 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.60411 .71886 m .57001 .73078 L .56374 .73392 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.57001 .26922 m .60411 .28114 L .59543 .27668 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.59543 .27668 m .56374 .26608 L .57001 .26922 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.36811 .70373 m .39961 .72113 L .39342 .71655 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.39342 .71655 m .36089 .69823 L .36811 .70373 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.43272 .26762 m .39961 .27887 L .39342 .28345 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.36089 .30177 m .39342 .28345 L .39961 .27887 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.4646 .73999 m .48265 .74128 L .47605 .74028 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.47605 .74028 m .45134 .73796 L .4646 .73999 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.45134 .26204 m .47605 .25972 L .48265 .25872 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.47605 .25972 m .45134 .26204 L .44056 .26462 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.69462 .35684 m .71499 .38909 L .71217 .3842 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.71217 .3842 m .69127 .35115 L .69462 .35684 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.71499 .61091 m .69462 .64316 L .69127 .64885 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.6657 .67749 m .69127 .64885 L .69462 .64316 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.52077 .74082 m .5423 .73906 L .55439 .73673 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.5423 .73906 m .52077 .74082 L .51372 .74166 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52077 .25918 m .5423 .26094 L .52803 .25924 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52803 .25924 m .51372 .25834 L .52077 .25918 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.4797 .74135 m .49008 .74195 L .48265 .74128 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.48265 .74128 m .4646 .73999 L .4797 .74135 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.4646 .26001 m .48265 .25872 L .49008 .25805 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.48265 .25872 m .4646 .26001 L .45134 .26204 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.71499 .38909 m .72998 .42434 L .72767 .42076 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.72767 .42076 m .71217 .3842 L .71499 .38909 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.69127 .64885 m .71217 .6158 L .71499 .61091 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.72998 .57566 m .71499 .61091 L .71217 .6158 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.41074 .72541 m .44056 .73538 L .43272 .73238 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.43272 .73238 m .39961 .72113 L .41074 .72541 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.39961 .27887 m .43272 .26762 L .44056 .26462 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.51372 .74166 m .52803 .74076 L .5423 .73906 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.52803 .74076 m .51372 .74166 L .506 .74214 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51372 .25834 m .52803 .25924 L .51229 .25826 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51229 .25826 m .506 .25786 L .51372 .25834 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.73916 .53835 m .72998 .57566 L .72767 .57924 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.71217 .6158 m .72767 .57924 L .72998 .57566 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.72998 .42434 m .73916 .46165 L .7372 .45976 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.7372 .45976 m .72767 .42076 L .72998 .42434 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49589 .74194 m .49799 .74224 L .49008 .74195 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49008 .74195 m .4797 .74135 L .49589 .74194 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.49008 .25805 m .4797 .25865 L .4646 .26001 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.4797 .25865 m .49008 .25805 L .49799 .25776 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.33923 .68043 m .36811 .70373 L .36089 .69823 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.36089 .69823 m .33142 .67453 L .33923 .68043 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.39961 .27887 m .36811 .29627 L .36089 .30177 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33142 .32547 m .36089 .30177 L .36811 .29627 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.506 .74214 m .51229 .74174 L .52803 .74076 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.51229 .74174 m .506 .74214 L .49799 .74224 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.506 .25786 m .51229 .25826 L .49589 .25806 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49589 .25806 m .49799 .25776 L .506 .25786 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.73916 .46165 m .74225 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.74042 .5 m .7372 .45976 L .73916 .46165 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.74225 .5 m .73916 .53835 L .7372 .54024 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.72767 .57924 m .7372 .54024 L .73916 .53835 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.49799 .74224 m .49589 .74194 L .51229 .74174 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.49799 .25776 m .49589 .25806 L .4797 .25865 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.7372 .54024 m .74042 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.56374 .73392 m .59543 .72332 L .60411 .71886 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.63633 .701 m .60411 .71886 L .59543 .72332 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.60411 .28114 m .63633 .299 L .62576 .29361 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.62576 .29361 m .59543 .27668 L .60411 .28114 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.59543 .72332 m .56374 .73392 L .55439 .73673 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.56374 .26608 m .59543 .27668 L .58191 .27264 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.58191 .27264 m .55439 .26327 L .56374 .26608 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.31395 .65171 m .33923 .68043 L .33142 .67453 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.33142 .67453 m .30591 .64599 L .31395 .65171 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36811 .29627 m .33923 .31957 L .33142 .32547 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.30591 .35401 m .33142 .32547 L .33923 .31957 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.42652 .72914 m .45134 .73796 L .44056 .73538 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.44056 .73538 m .41074 .72541 L .42652 .72914 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.44056 .26462 m .41074 .27459 L .39961 .27887 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.41074 .27459 m .44056 .26462 L .45134 .26204 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.38203 .70894 m .41074 .72541 L .39961 .72113 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.39961 .72113 m .36811 .70373 L .38203 .70894 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.36811 .29627 m .39961 .27887 L .41074 .27459 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.33923 .31957 m .31395 .34829 L .30591 .35401 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.28515 .38667 m .30591 .35401 L .31395 .34829 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.29319 .61827 m .31395 .65171 L .30591 .64599 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.30591 .64599 m .28515 .61333 L .29319 .61827 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.6657 .67749 m .63633 .701 L .62576 .70639 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.59543 .72332 m .62576 .70639 L .63633 .701 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.63633 .299 m .6657 .32251 L .65374 .31669 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.65374 .31669 m .62576 .29361 L .63633 .299 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.55439 .73673 m .58191 .72736 L .59543 .72332 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.58191 .72736 m .55439 .73673 L .5423 .73906 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.55439 .26327 m .58191 .27264 L .56403 .26926 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.56403 .26926 m .5423 .26094 L .55439 .26327 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.31395 .34829 m .29319 .38173 L .28515 .38667 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.26981 .42257 m .28515 .38667 L .29319 .38173 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.27773 .58105 m .29319 .61827 L .28515 .61333 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.28515 .61333 m .26981 .57743 L .27773 .58105 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.44631 .73211 m .4646 .73999 L .45134 .73796 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.45134 .73796 m .42652 .72914 L .44631 .73211 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.42652 .27086 m .45134 .26204 L .4646 .26001 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.45134 .26204 m .42652 .27086 L .41074 .27459 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.2682 .5412 m .27773 .58105 L .26981 .57743 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.26981 .57743 m .2604 .53929 L .2682 .5412 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.29319 .38173 m .27773 .41895 L .26981 .42257 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.2604 .46071 m .26981 .42257 L .27773 .41895 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.62576 .70639 m .59543 .72332 L .58191 .72736 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.59543 .27668 m .62576 .29361 L .60857 .28866 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60857 .28866 m .58191 .27264 L .59543 .27668 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.6657 .32251 m .69127 .35115 L .67836 .34548 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.67836 .34548 m .65374 .31669 L .6657 .32251 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.69127 .64885 m .6657 .67749 L .65374 .68331 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.62576 .70639 m .65374 .68331 L .6657 .67749 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.27773 .41895 m .2682 .4588 L .2604 .46071 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.25723 .5 m .2604 .46071 L .2682 .4588 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.26498 .5 m .2682 .5412 L .2604 .53929 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.2604 .53929 m .25723 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.2682 .4588 m .26498 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.5423 .73906 m .56403 .73074 L .58191 .72736 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.56403 .73074 m .5423 .73906 L .52803 .74076 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.5423 .26094 m .56403 .26926 L .54259 .26676 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.54259 .26676 m .52803 .25924 L .5423 .26094 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.35538 .68609 m .38203 .70894 L .36811 .70373 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.36811 .70373 m .33923 .68043 L .35538 .68609 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.41074 .27459 m .38203 .29106 L .36811 .29627 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.33923 .31957 m .36811 .29627 L .38203 .29106 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.46913 .7341 m .4797 .74135 L .4646 .73999 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.4646 .73999 m .44631 .73211 L .46913 .7341 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.44631 .26789 m .4646 .26001 L .4797 .25865 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.4646 .26001 m .44631 .26789 L .42652 .27086 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.40236 .71354 m .42652 .72914 L .41074 .72541 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.41074 .72541 m .38203 .70894 L .40236 .71354 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.38203 .29106 m .41074 .27459 L .42652 .27086 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.52803 .74076 m .54259 .73324 L .56403 .73074 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.54259 .73324 m .52803 .74076 L .51229 .74174 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.52803 .25924 m .54259 .26676 L .51871 .26531 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.51871 .26531 m .51229 .25826 L .52803 .25924 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69127 .35115 m .71217 .3842 L .69868 .37929 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69868 .37929 m .67836 .34548 L .69127 .35115 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.71217 .6158 m .69127 .64885 L .67836 .65452 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.65374 .68331 m .67836 .65452 L .69127 .64885 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.49373 .73498 m .49589 .74194 L .4797 .74135 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.4797 .74135 m .46913 .7341 L .49373 .73498 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.46913 .2659 m .4797 .25865 L .49589 .25806 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.4797 .25865 m .46913 .2659 L .44631 .26789 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.51229 .74174 m .51871 .73469 L .54259 .73324 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.51871 .73469 m .51229 .74174 L .49589 .74194 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.51229 .25826 m .51871 .26531 L .49373 .26502 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.49373 .26502 m .49589 .25806 L .51229 .25826 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.49589 .74194 m .49373 .73498 L .51871 .73469 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.49589 .25806 m .49373 .26502 L .46913 .2659 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.72767 .57924 m .71217 .6158 L .69868 .62071 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.67836 .65452 m .69868 .62071 L .71217 .6158 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71217 .3842 m .72767 .42076 L .71386 .41715 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71386 .41715 m .69868 .37929 L .71217 .3842 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.65374 .68331 m .62576 .70639 L .60857 .71134 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.58191 .72736 m .60857 .71134 L .62576 .70639 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.62576 .29361 m .65374 .31669 L .63344 .31129 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.63344 .31129 m .60857 .28866 L .62576 .29361 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33181 .65724 m .35538 .68609 L .33923 .68043 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33923 .68043 m .31395 .65171 L .33181 .65724 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.38203 .29106 m .35538 .31391 L .33923 .31957 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.31395 .34829 m .33923 .31957 L .35538 .31391 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.60857 .71134 m .58191 .72736 L .56403 .73074 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58191 .27264 m .60857 .28866 L .58528 .28448 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58528 .28448 m .56403 .26926 L .58191 .27264 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.7372 .54024 m .72767 .57924 L .71386 .58285 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.69868 .62071 m .71386 .58285 L .72767 .57924 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72767 .42076 m .7372 .45976 L .72324 .45784 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72324 .45784 m .71386 .41715 L .72767 .42076 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42835 .71723 m .44631 .73211 L .42652 .72914 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42652 .72914 m .40236 .71354 L .42835 .71723 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.40236 .28646 m .42652 .27086 L .44631 .26789 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.42652 .27086 m .40236 .28646 L .38203 .29106 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.7372 .45976 m .74042 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.72642 .5 m .72324 .45784 L .7372 .45976 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.74042 .5 m .7372 .54024 L .72324 .54216 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.71386 .58285 m .72324 .54216 L .7372 .54024 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.72324 .54216 m .72642 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.35538 .31391 m .33181 .34276 L .31395 .34829 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.29319 .38173 m .31395 .34829 L .33181 .34276 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31228 .62308 m .33181 .65724 L .31395 .65171 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31395 .65171 m .29319 .61827 L .31228 .62308 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.37971 .69114 m .40236 .71354 L .38203 .70894 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.38203 .70894 m .35538 .68609 L .37971 .69114 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.35538 .31391 m .38203 .29106 L .40236 .28646 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.56403 .73074 m .58528 .71552 L .60857 .71134 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.58528 .71552 m .56403 .73074 L .54259 .73324 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.56403 .26926 m .58528 .28448 L .55693 .28136 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.55693 .28136 m .54259 .26676 L .56403 .26926 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.67836 .65452 m .65374 .68331 L .63344 .68871 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.60857 .71134 m .63344 .68871 L .65374 .68331 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65374 .31669 m .67836 .34548 L .65555 .34018 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65555 .34018 m .63344 .31129 L .65374 .31669 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.42835 .28277 m .44631 .26789 L .46913 .2659 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.45868 .71973 m .46913 .7341 L .44631 .73211 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.44631 .73211 m .42835 .71723 L .45868 .71973 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.44631 .26789 m .42835 .28277 L .40236 .28646 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29763 .58461 m .31228 .62308 L .29319 .61827 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29319 .61827 m .27773 .58105 L .29763 .58461 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.33181 .34276 m .31228 .37692 L .29319 .38173 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.27773 .41895 m .29319 .38173 L .31228 .37692 L p F P
.505 .664 .505 r
s
.519 .718 .524 r
.63344 .68871 m .60857 .71134 L .58528 .71552 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60857 .28866 m .63344 .31129 L .60529 .30668 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60529 .30668 m .58528 .28448 L .60857 .28866 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.54259 .73324 m .55693 .71864 L .58528 .71552 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.55693 .71864 m .54259 .73324 L .51871 .73469 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.54259 .26676 m .55693 .28136 L .52506 .27954 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.52506 .27954 m .51871 .26531 L .54259 .26676 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.28856 .54309 m .29763 .58461 L .27773 .58105 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.27773 .58105 m .2682 .5412 L .28856 .54309 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.31228 .37692 m .29763 .41539 L .27773 .41895 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.2682 .4588 m .27773 .41895 L .29763 .41539 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.4916 .72084 m .49373 .73498 L .46913 .7341 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.46913 .7341 m .45868 .71973 L .4916 .72084 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.45868 .28027 m .46913 .2659 L .49373 .26502 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.46913 .2659 m .45868 .28027 L .42835 .28277 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67836 .34548 m .69868 .37929 L .67394 .37466 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67394 .37466 m .65555 .34018 L .67836 .34548 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.69868 .62071 m .67836 .65452 L .65555 .65982 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.63344 .68871 m .65555 .65982 L .67836 .65452 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35949 .66222 m .37971 .69114 L .35538 .68609 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35538 .68609 m .33181 .65724 L .35949 .66222 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.40236 .28646 m .37971 .30886 L .35538 .31391 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.33181 .34276 m .35538 .31391 L .37971 .30886 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.51871 .73469 m .52506 .72046 L .55693 .71864 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.52506 .72046 m .51871 .73469 L .49373 .73498 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.29763 .41539 m .28856 .45691 L .2682 .4588 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.26498 .5 m .2682 .4588 L .28856 .45691 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.28548 .5 m .28856 .54309 L .2682 .5412 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.2682 .5412 m .26498 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.51871 .26531 m .52506 .27954 L .4916 .27916 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.4916 .27916 m .49373 .26502 L .51871 .26531 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.49373 .73498 m .4916 .72084 L .52506 .72046 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.49373 .26502 m .4916 .27916 L .45868 .28027 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.28856 .45691 m .28548 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.41137 .69522 m .42835 .71723 L .40236 .71354 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.40236 .71354 m .37971 .69114 L .41137 .69522 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.37971 .30886 m .40236 .28646 L .42835 .28277 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.71386 .58285 m .69868 .62071 L .67394 .62534 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.65555 .65982 m .67394 .62534 L .69868 .62071 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.69868 .37929 m .71386 .41715 L .68778 .41371 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.68778 .41371 m .67394 .37466 L .69868 .37929 L p F P
.505 .664 .505 r
s
.519 .718 .524 r
.58528 .71552 m .60529 .69332 L .63344 .68871 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.60529 .69332 m .58528 .71552 L .55693 .71864 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.58528 .28448 m .60529 .30668 L .57052 .30321 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.57052 .30321 m .55693 .28136 L .58528 .28448 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.65555 .65982 m .63344 .68871 L .60529 .69332 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.63344 .31129 m .65555 .34018 L .62323 .33561 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.62323 .33561 m .60529 .30668 L .63344 .31129 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.37971 .30886 m .35949 .33778 L .33181 .34276 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.31228 .37692 m .33181 .34276 L .35949 .33778 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.34259 .62745 m .35949 .66222 L .33181 .65724 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.33181 .65724 m .31228 .62308 L .34259 .62745 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.72324 .54216 m .71386 .58285 L .68778 .58629 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.67394 .62534 m .68778 .58629 L .71386 .58285 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.71386 .41715 m .72324 .45784 L .69638 .45601 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.69638 .45601 m .68778 .41371 L .71386 .41715 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.44875 .698 m .45868 .71973 L .42835 .71723 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.42835 .71723 m .41137 .69522 L .44875 .698 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.41137 .30478 m .42835 .28277 L .45868 .28027 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.42835 .28277 m .41137 .30478 L .37971 .30886 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.72324 .45784 m .72642 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.6993 .5 m .69638 .45601 L .72324 .45784 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.72642 .5 m .72324 .54216 L .69638 .54399 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.68778 .58629 m .69638 .54399 L .72324 .54216 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.69638 .54399 m .6993 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.55693 .71864 m .57052 .69679 L .60529 .69332 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.55693 .28136 m .57052 .30321 L .5311 .30117 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.5311 .30117 m .52506 .27954 L .55693 .28136 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.57052 .69679 m .55693 .71864 L .52506 .72046 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.39609 .66628 m .41137 .69522 L .37971 .69114 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.37971 .69114 m .35949 .66222 L .39609 .66628 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.35949 .33778 m .37971 .30886 L .41137 .30478 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.32983 .58786 m .34259 .62745 L .31228 .62308 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.31228 .62308 m .29763 .58461 L .32983 .58786 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.35949 .33778 m .34259 .37255 L .31228 .37692 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.29763 .41539 m .31228 .37692 L .34259 .37255 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.48957 .69924 m .4916 .72084 L .45868 .71973 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.45868 .71973 m .44875 .698 L .48957 .69924 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.44875 .302 m .45868 .28027 L .4916 .27916 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.45868 .28027 m .44875 .302 L .41137 .30478 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.65555 .34018 m .67394 .37466 L .63828 .37064 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.63828 .37064 m .62323 .33561 L .65555 .34018 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.67394 .62534 m .65555 .65982 L .62323 .66439 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.60529 .69332 m .62323 .66439 L .65555 .65982 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.52506 .72046 m .5311 .69883 L .57052 .69679 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.5311 .69883 m .52506 .72046 L .4916 .72084 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.52506 .27954 m .5311 .30117 L .48957 .30076 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.48957 .30076 m .4916 .27916 L .52506 .27954 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.4916 .72084 m .48957 .69924 L .5311 .69883 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.4916 .27916 m .48957 .30076 L .44875 .302 L p F P
.505 .664 .505 r
s
.605 .814 .594 r
.62323 .66439 m .60529 .69332 L .57052 .69679 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.60529 .30668 m .62323 .33561 L .58279 .33214 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.58279 .33214 m .57052 .30321 L .60529 .30668 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.34259 .37255 m .32983 .41214 L .29763 .41539 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.28856 .45691 m .29763 .41539 L .32983 .41214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29255 .42909 m
.29448 .40349 L
s
.5 Mabswid
.565 .74 .573 r
.32189 .54482 m .32983 .58786 L .29763 .58461 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.29763 .58461 m .28856 .54309 L .32189 .54482 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.32983 .41214 m .32189 .45518 L .28856 .45691 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29131 .44551 m
.29255 .42909 L
s
.29267 .41758 m
.30367 .41625 L
s
.5 Mabswid
.508 .649 .5 r
.28548 .5 m .28856 .45691 L .32189 .45518 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.3192 .5 m .32189 .54482 L .28856 .54309 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.28856 .54309 m .28548 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.41137 .30478 m .39609 .33372 L .35949 .33778 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.34259 .37255 m .35949 .33778 L .39609 .33372 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.38325 .63104 m .39609 .66628 L .35949 .66222 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.35949 .66222 m .34259 .62745 L .38325 .63104 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.32189 .45518 m .3192 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.43977 .66907 m .44875 .698 L .41137 .69522 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.41137 .69522 m .39609 .66628 L .43977 .66907 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.39609 .33372 m .41137 .30478 L .44875 .302 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.68778 .58629 m .67394 .62534 L .63828 .62936 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.62323 .66439 m .63828 .62936 L .67394 .62534 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.67394 .37466 m .68778 .41371 L .64966 .41072 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.64966 .41072 m .63828 .37064 L .67394 .37466 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29554 .43633 m
.31179 .40105 L
s
.29131 .44551 m
.29554 .43633 L
s
.5 Mabswid
.605 .814 .594 r
.57052 .69679 m .58279 .66786 L .62323 .66439 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.57052 .30321 m .58279 .33214 L .53658 .3301 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.53658 .3301 m .5311 .30117 L .57052 .30321 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.58279 .66786 m .57052 .69679 L .5311 .69883 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30901 .43005 m
.32211 .3855 L
s
.5 Mabswid
.542 .707 .498 r
.69638 .54399 m .68778 .58629 L .64966 .58928 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.63828 .62936 m .64966 .58928 L .68778 .58629 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.68778 .41371 m .69638 .45601 L .65676 .45441 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.65676 .45441 m .64966 .41072 L .68778 .41371 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.62323 .33561 m .63828 .37064 L .59314 .36757 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.59314 .36757 m .58279 .33214 L .62323 .33561 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.63828 .62936 m .62323 .66439 L .58279 .66786 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.48773 .67031 m .48957 .69924 L .44875 .698 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.44875 .698 m .43977 .66907 L .48773 .67031 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.43977 .33093 m .44875 .302 L .48957 .30076 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.44875 .302 m .43977 .33093 L .39609 .33372 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.3149 .40686 m
.31886 .40232 L
s
.5 Mabswid
.625 .824 .628 r
.3735 .59054 m .38325 .63104 L .34259 .62745 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.34259 .62745 m .32983 .58786 L .3735 .59054 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.39609 .33372 m .38325 .36896 L .34259 .37255 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.32983 .41214 m .34259 .37255 L .38325 .36896 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31886 .40232 m
.32225 .39989 L
s
.5 Mabswid
.636 .852 .628 r
.5311 .69883 m .53658 .6699 L .58279 .66786 L p F P
.505 .664 .505 r
s
.651 .872 .648 r
.53658 .6699 m .5311 .69883 L .48957 .69924 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.5311 .30117 m .53658 .3301 L .48773 .32969 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.48773 .32969 m .48957 .30076 L .5311 .30117 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.69638 .45601 m .6993 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.65918 .5 m .65676 .45441 L .69638 .45601 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.6993 .5 m .69638 .54399 L .65676 .54559 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.64966 .58928 m .65676 .54559 L .69638 .54399 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31042 .42378 m
.3122 .42775 L
s
.32225 .39989 m
.32648 .39948 L
s
.5 Mabswid
.651 .872 .648 r
.48957 .69924 m .48773 .67031 L .53658 .6699 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.48957 .30076 m .48773 .32969 L .43977 .33093 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.65676 .54559 m .65918 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.3122 .42775 m
.31457 .42963 L
s
.32648 .39948 m
.32875 .40136 L
s
.5 Mabswid
.449 .547 .402 r
.38325 .36896 m .39609 .33372 L .43977 .33093 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.43218 .63351 m .43977 .66907 L .39609 .66628 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.39609 .66628 m .38325 .63104 L .43218 .63351 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31457 .42963 m
.31895 .42932 L
s
.5 Mabswid
.611 .797 .605 r
.36741 .54626 m .3735 .59054 L .32983 .58786 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.32983 .58786 m .32189 .54482 L .36741 .54626 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.38325 .36896 m .3735 .40946 L .32983 .41214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32875 .40136 m
.33053 .40541 L
s
.5 Mabswid
.522 .657 .495 r
.32189 .45518 m .32983 .41214 L .3735 .40946 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31895 .42932 m
.32239 .42701 L
s
.33039 .41175 m
.33053 .40541 L
s
.5 Mabswid
.605 .795 .573 r
.64966 .58928 m .63828 .62936 L .59314 .63243 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.58279 .66786 m .59314 .63243 L .63828 .62936 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.63828 .37064 m .64966 .41072 L .60101 .40842 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.60101 .40842 m .59314 .36757 L .63828 .37064 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32239 .42701 m
.32636 .42256 L
s
.5 Mabswid
.442 .537 .376 r
.58279 .33214 m .59314 .36757 L .54122 .36576 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.54122 .36576 m .53658 .3301 L .58279 .33214 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.59314 .63243 m .58279 .66786 L .53658 .6699 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32936 .41605 m
.33039 .41175 L
s
.32636 .42256 m
.32936 .41605 L
s
.5 Mabswid
.522 .657 .495 r
.3735 .40946 m .36741 .45374 L .32189 .45518 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.3192 .5 m .32189 .45518 L .36741 .45374 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.36534 .5 m .36741 .54626 L .32189 .54482 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.32189 .54482 m .3192 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.36741 .45374 m .36534 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.43218 .36649 m .43977 .33093 L .48773 .32969 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.48617 .63462 m .48773 .67031 L .43977 .66907 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.43977 .66907 m .43218 .63351 L .48617 .63462 L p F P
.505 .664 .505 r
s
.449 .547 .402 r
.43977 .33093 m .43218 .36649 L .38325 .36896 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34494 .40431 m
.34943 .39971 L
s
.3417 .41094 m
.34494 .40431 L
s
.34073 .41527 m
.3417 .41094 L
s
.34943 .39971 m
.35342 .39728 L
s
.34073 .41527 m
.34108 .42164 L
s
.5 Mabswid
.645 .848 .637 r
.42641 .59239 m .43218 .63351 L .38325 .63104 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.38325 .63104 m .3735 .59054 L .42641 .59239 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.3735 .40946 m .38325 .36896 L .43218 .36649 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.35342 .39728 m
.35868 .39693 L
s
.5 Mabswid
.591 .768 .55 r
.65676 .54559 m .64966 .58928 L .60101 .59158 L p F P
.505 .664 .505 r
s
.605 .795 .573 r
.59314 .63243 m .60101 .59158 L .64966 .58928 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.64966 .41072 m .65676 .45441 L .60593 .45318 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.60593 .45318 m .60101 .40842 L .64966 .41072 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.53658 .6699 m .54122 .63424 L .59314 .63243 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.53658 .3301 m .54122 .36576 L .48617 .36538 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.48617 .36538 m .48773 .32969 L .53658 .3301 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.54122 .63424 m .53658 .6699 L .48773 .67031 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34108 .42164 m
.34374 .42574 L
s
.5 Mabswid
.654 .866 .64 r
.48773 .67031 m .48617 .63462 L .54122 .63424 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.48773 .32969 m .48617 .36538 L .43218 .36649 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.35868 .39693 m
.36174 .3989 L
s
.34374 .42574 m
.34692 .42771 L
s
.36174 .3989 m
.36441 .40309 L
s
.34692 .42771 m
.35239 .42745 L
s
.5 Mabswid
.541 .688 .487 r
.65676 .45441 m .65918 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.6076 .5 m .60593 .45318 L .65676 .45441 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.65918 .5 m .65676 .54559 L .60593 .54682 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.60101 .59158 m .60593 .54682 L .65676 .54559 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.60101 .59158 m .59314 .63243 L .54122 .63424 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.59314 .36757 m .60101 .40842 L .54475 .40706 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.54475 .40706 m .54122 .36576 L .59314 .36757 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.36441 .40309 m
.36491 .40959 L
s
.35239 .42745 m
.35647 .42512 L
s
.5 Mabswid
.569 .732 .521 r
.60593 .54682 m .6076 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.36407 .41397 m
.36491 .40959 L
s
.35647 .42512 m
.36099 .42061 L
s
.36099 .42061 m
.36407 .41397 L
s
.5 Mabswid
.505 .628 .464 r
.43218 .36649 m .42641 .40761 L .3735 .40946 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.36741 .45374 m .3735 .40946 L .42641 .40761 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.42279 .54725 m .42641 .59239 L .3735 .59054 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.3735 .59054 m .36741 .54626 L .42279 .54725 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.42641 .40761 m .43218 .36649 L .48617 .36538 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.48498 .59322 m .48617 .63462 L .43218 .63351 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.43218 .63351 m .42641 .59239 L .48498 .59322 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.60268 .39933 m
.60436 .39718 L
s
.6019 .39486 m
.60436 .39718 L
s
.60022 .39701 m
.6019 .39486 L
s
.5 Mabswid
.549 .692 .514 r
.42641 .40761 m .42279 .45275 L .36741 .45374 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.39083 .44116 m
.39138 .43715 L
s
.39138 .43715 m
.39714 .3949 L
s
.37385 .4416 m
.37553 .43095 L
s
.37553 .43095 m
.38109 .39564 L
s
.5 Mabswid
.583 .744 .554 r
.36534 .5 m .36741 .45374 L .42279 .45275 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.42155 .5 m .42279 .54725 L .36741 .54626 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.36741 .54626 m .36534 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.54122 .63424 m .54475 .59294 L .60101 .59158 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.54475 .59294 m .54122 .63424 L .48617 .63462 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.54122 .36576 m .54475 .40706 L .48498 .40678 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.48498 .40678 m .48617 .36538 L .54122 .36576 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.60022 .39701 m
.60268 .39933 L
s
.5 Mabswid
.617 .802 .582 r
.60593 .54682 m .60101 .59158 L .54475 .59294 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.60101 .40842 m .60593 .45318 L .54696 .45245 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.54696 .45245 m .54475 .40706 L .60101 .40842 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.48617 .63462 m .48498 .59322 L .54475 .59294 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.48617 .36538 m .48498 .40678 L .42641 .40761 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.42279 .45275 m .42155 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.60446 .41047 m
.60815 .44113 L
s
.57634 .39397 m
.58319 .39641 L
s
.58319 .39641 m
.586 .40097 L
s
.41796 .39638 m
.42264 .394 L
s
.41299 .401 m
.41796 .39638 L
s
.40989 .40778 m
.41299 .401 L
s
.42264 .394 m
.42924 .39381 L
s
.586 .40097 m
.58631 .40321 L
s
.56973 .39378 m
.57634 .39397 L
s
.58469 .40763 m
.58631 .40321 L
s
.40932 .41225 m
.40989 .40778 L
s
.42924 .39381 m
.43342 .39595 L
s
.56329 .39587 m
.56973 .39378 L
s
.40932 .41225 m
.41074 .41886 L
s
.58051 .40974 m
.58469 .40763 L
s
.5 Mabswid
.636 .827 .612 r
.48424 .5477 m .48498 .59322 L .42641 .59239 L p F P
.505 .664 .505 r
s
.636 .827 .612 r
.42641 .59239 m .42279 .54725 L .48424 .5477 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.42279 .45275 m .42641 .40761 L .48498 .40678 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.43342 .39595 m
.43745 .40035 L
s
.5 Mabswid
.571 .727 .522 r
.60593 .45318 m .6076 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.54772 .5 m .54696 .45245 L .60593 .45318 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.6076 .5 m .60593 .54682 L .54696 .54755 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.54475 .59294 m .54696 .54755 L .60593 .54682 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.56149 .40033 m
.56329 .39587 L
s
.56944 .41172 m
.58051 .40974 L
s
.41074 .41886 m
.41476 .42318 L
s
.58644 .42321 m
.58822 .41883 L
s
.43745 .40035 m
.43909 .40706 L
s
.57984 .42527 m
.58644 .42321 L
s
.5 Mabswid
.597 .768 .555 r
.54696 .54755 m .54772 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.41476 .42318 m
.41909 .42529 L
s
.56504 .41387 m
.56944 .41172 L
s
.53335 .39308 m
.53813 .39541 L
s
.52638 .39301 m
.53335 .39308 L
s
.53813 .39541 m
.54557 .40229 L
s
.5 Mabswid
.554 .699 .506 r
.54475 .40706 m .54696 .45245 L .48424 .4523 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54489 .39325 m
.54696 .42474 L
s
.5 Mabswid
.554 .699 .506 r
.48424 .4523 m .48498 .40678 L .54475 .40706 L p F P
.505 .664 .505 r
s
.632 .82 .601 r
.54696 .54755 m .54475 .59294 L .48498 .59322 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.4387 .41156 m
.43909 .40706 L
s
.5218 .39523 m
.52638 .39301 L
s
.41909 .42529 m
.42599 .42516 L
s
.57293 .42514 m
.57984 .42527 L
s
.56309 .4183 m
.56504 .41387 L
s
.43582 .41831 m
.4387 .41156 L
s
.50063 .39288 m
.50066 .42447 L
s
.51968 .40201 m
.5218 .39523 L
s
.42599 .42516 m
.43081 .42285 L
s
.56577 .42279 m
.57293 .42514 L
s
.43081 .42285 m
.43582 .41831 L
s
.5 Mabswid
.632 .82 .601 r
.48498 .59322 m .48424 .5477 L .54696 .54755 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.48498 .40678 m .48424 .4523 L .42279 .45275 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.48123 .41555 m
.48187 .39294 L
s
.45432 .42473 m
.45634 .39323 L
s
.56309 .4183 m
.56577 .42279 L
s
.51968 .40201 m
.52028 .42452 L
s
.5 Mabswid
.59 .753 .554 r
.42155 .5 m .42279 .45275 L .48424 .4523 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.48398 .5 m .48424 .5477 L .42279 .54725 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.42279 .54725 m .42155 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.45481 .41579 m
.46165 .42242 L
s
.5 Mabswid
.59 .753 .554 r
.48424 .4523 m .48398 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.47864 .42229 m
.48123 .41555 L
s
.46165 .42242 m
.4664 .42461 L
s
.4664 .42461 m
.4737 .42456 L
s
.4737 .42456 m
.47864 .42229 L
s
.5 Mabswid
.586 .747 .543 r
.54696 .45245 m .54772 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.48398 .5 m .48424 .4523 L .54696 .45245 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.54772 .5 m .54696 .54755 L .48424 .5477 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.48424 .5477 m .48398 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.50066 .43776 m
.50316 .43996 L
s
.49817 .43996 m
.50066 .43776 L
s
.50316 .43996 m
.50067 .44214 L
s
.50067 .44214 m
.49817 .43996 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003U0;3PiPl0PJV10`0T9ad0
0`21ZH409BPN02DX7P0602DX7P03086YP@0T9ad092LM00P0PJV1j02`h>H10?ooo`00h02`h>H6086Y
P@L08B@K0P21ZH4702@W7@03086YP@0U:1h09BPN00L09BPN00<0PJV102@W7@0T9ad01@0T9ad2086Y
P@03020S6`21ZH40PJV100@0PJV1hP2`h>H10?ooo`00g@2`h>H3086YP@806ahG0P21ZH47024T6`80
PJV12@0T9ad00`21ZH409BPN02DX7P0802DX7P03086YP@0T9ad092LM00H092LM0P21ZH44020S6`L0
PJV1g02`h>H10?ooo`00fP2`h>H4086YP@806ahG0P21ZH43024T6b<0PJV1100T9ad2086YP@D082<K
0P21ZH400`0J7QL0PJV1086YP@03086YPMP0/>3V0@3oool00=H0/>3V1@21ZH400`0K7QL0PJV1086Y
P@07086YP@@0<S<W00<0PJV103Hg:P0f=bX02P0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f
=bX0=SLZ0080=SLZ3021ZH401@0P8a/0PJV1086YP@21ZH406QhG0080PJV100<04QHA086YP@2`h>H0
e@2`h>H10?ooo`00e02`h>H00`21ZH404aLA086YP@05086YP@0302/]8P21ZH40<S<W00T0<S<W00<0
PJV103Hg:P0f=bX02`0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0
PJV1038c9`0b<bL00P0b<bL<086YPM<0/>3V0@3oool00=40/>3V00<0PJV101<G4@21ZH400`21ZH45
02/]8P03086YP@0b<bL0<S<W00P0<S<W00<0PJV103Hg:P0f=bX0300f=bX00`21ZH40=cP[03Lh:`0;
03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0PJV1038c9`0b<bL01`0b<bL9086YPM00/>3V0@3oool0
0<h0/>3V1P21ZH4702/]8P03086YP@0b<bL0<S<W00T0<S<W00<0PJV103Hg:P0f=bX02`0f=bX00`21
ZH40=cP[03Lh:`0<03Lh:`03086YP@0f=bX0=SLZ00X0=SLZ00<0PJV1038c9`0b<bL0200b<bL01021
ZH40:RdR02X]8P0Z;B85086YPLh0/>3V0@3oool00</0/>3V1021ZH400`0Q91/0PJV1086YP@0702/]
8P80PJV12`0b<bL00`21ZH40=SLZ03Hg:P0<03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg
:P0f=bX02P0f=bX00`21ZH40<S<W038c9`08038c9`80PJV1100Z;B85086YPL/0/>3V0@3oool00<T0
/>3V0`21ZH43024T6`03086YP@0[;B80:bdR00H0:bdR00<0PJV1038c9`0b<bL02P0b<bL00`21ZH40
=SLZ03Hg:P0=03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg:P0f=bX02`0f=bX00`21ZH40
<S<W038c9`09038c9`80PJV1100Z;B82086YP@03020S6P21ZH40PJV10<T0/>3V0@3oool00<L0/>3V
0`21ZH43024T6`80PJV1200[;B800`21ZH40<S<W038c9`07038c9bd0PJV11P0f=bX00`21ZH40<S<W
038c9`0:038c9`03086YP@0Z;B80:RdR00<0:RdR00<0PJV1020S6P0P8aX00P21ZH770;3PiP40oooo
00350;3PiP<0PJV10`0Q91/2086YP@T0:bdR00<0PJV1038c9`0b<bL02021ZH4304I==`03086YP@1<
ESd0C5Hm00h0C5Hm00<0PJV104mI?P1?FCh03P1?FCh00`21ZH40CEHm04eF?@0504eF?@l0PJV11@0b
<bL2086YP@@0:RdR0P21ZH42020S6P80PJV1a@2`h>H10?ooo`00``2`h>H00`21ZH4051PB086YP@03
024T6`80PJV1100[;B8:086YP@X0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI?P0?
04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL01016CCL9086YP@@0:RdR00@0PJV1
020S6P0P8aX082<J0P21ZH730;3PiP40oooo00310;3PiP04086YP@0D6180PJV1086YP@808B@K2021
ZH4503Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL03016CCL5086YP@0302X]8P21
ZH40PJV100<082<J0P21ZH710;3PiP40oooo002o0;3PiP05086YP@0D6180PJV1086YP@0Q91/01021
ZH4<03Xn;P03086YP@16CCL0ATdg00/0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00d0CEHm00<0PJV104I==`16CCL03016CCL01021ZH40>Sd]03Xm
;@0j?Bd5086YP@<082<J0P21ZH6o0;3PiP40oooo002m0;3PiP03086YP@0D6180PJV100@0PJV10P0/
;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd0401<
ESd00`21ZH40CeTn04mI?P0?04mI?P03086YP@1=ESd0CEHm00h0CEHm00<0PJV104I==`16CCL02`16
CCL00`21ZH40>Sd]03Xm;@0503Xm;@@0PJV10P0P8aX2086YPKd0/>3V0@3oool00;/0/>3V00<0PJV1
01@H4P21ZH400P21ZH4502`_8`03086YP@0j?Rh0>Sh^00X0>Sh^00<0PJV104I==`16CCL03016CCL0
0`21ZH40C5Hm04aF?@0@04aF?@03086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03@1=ESd0
0`21ZH40ATdg04I==`0<04I==`03086YP@0j?Bd0>Sd]00H0>Sd]00<0PJV102`^8`21ZH401@21ZH6k
0;3PiP40oooo002i0;3PiPD0PJV11P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg
00d0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI?P0A04mI?P03086YP@1=ESd0CEHm
00h0CEHm00<0PJV104I==`16CCL03016CCL00`21ZH40>Sd]03Xm;@0603Xm;@03086YP@0/;R<0;2hS
0080;2hS0`21ZH6j0;3PiP40oooo002g0;3PiP80PJV10`0M8AT00`21ZH40;2lS02`_8`0402`_8`03
086YP@0j?Rh0>Sh^00/0>Sh^00<0PJV104I==`16CCL03016CCL00`21ZH40C5Hm04aF?@0A04aF?@03
086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03P1=ESd00`21ZH40ATdg04I==`0=04I==`03
086YP@0j?Bd0>Sd]00H0>Sd]0P21ZH4502`^8`80PJV1^02`h>H10?ooo`00]P2`h>H01021ZH407B4I
01dQ6@0M8AT2086YP@H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh00`21ZH40ATdg04I==`0=04I==`03
086YP@1<ESd0C5Hm0140C5Hm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40CEHm04eF?@0?04eF?@03
086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0
PJV1]P2`h>H10?ooo`00]@2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV100P0;2lS00<0PJV103Xn;P0j
?Rh02P0j?Rh00`21ZH40ATdg04I==`0=04I==`03086YP@1<ESd0C5Hm0180C5Hm00<0PJV104mI?P1?
FCh04P1?FCh00`21ZH40CEHm04eF?@0?04eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j
?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0PJV1]@2`h>H10?ooo`00/`2`h>H2086YP@<07B4I
00<0PJV102`_8`0/;b<01P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00X0ATdg
>021ZH4804eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd0200j?Bd00`21ZH40;2hS
02`^8`0402`^8`<0PJV1/`2`h>H10?ooo`00/P2`h>H00`21ZH407B4I01dQ6@0201dQ6@03086YP@0/
;b<0;2lS00H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh01021ZH40ATdg04I==`16CCL9086YP@@0Gg1B
00<0PJV106AgE@1TMeD04P1TMeD00`21ZH40HgIC06=fD`0B06=fD`03086YP@1NKd`0GVm<00L0GVm<
3P21ZH4;04I==`03086YP@0j?Bd0>Sd]00P0>Sd]00<0PJV102`^8`0/;R<0100/;R<00`21ZH4071lH
086YP@2b0;3PiP40oooo002a0;3PiP03086YP@0M8AT07B4I00807B4I00<0PJV102`_8`0/;b<01P0/
;b<00`21ZH40>Sh^03Xn;P0803Xn;PP0PJV1301OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1S
MU<0HgIC0180HgIC00<0PJV105i_C01NKd`0401NKd`00`21ZH40F6M705QWA`0205QWA`T0PJV10`16
CCL00`21ZH40>Sd]03Xm;@0803Xm;@80PJV11@0/;R<00`21ZH4071lH086YP@2a0;3PiP40oooo002`
0;3PiP04086YP@0M8AT07B4I01dQ6@80PJV1200/;b<01021ZH40>Sh^03Xn;P0j?Rh8086YP@80E658
00<0PJV105m`DP1OL5803`1OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC0180HgIC
00<0PJV105i_C01NKd`04@1NKd`00`21ZH40F6M705QWA`0:05QWA`P0PJV1200j?Bd00`21ZH40;2hS
02`^8`0302`^8`04086YP@0L7aP0PJV1086YPJl0/>3V0@3oool00:l0/>3V00D0PJV101dQ6@0M8AT0
7B4I086YP@0702`_8`L0PJV12P1DHDP00`21ZH40Gg1B05m`DP0?05m`DP03086YP@1TMeD0I7ME01<0
I7ME00<0PJV106=fD`1SMU<04`1SMU<00`21ZH40GVm<05i_C00@05i_C003086YP@1HIdL0F6M700l0
F6M700<0PJV104eG?@1=Ecd01`21ZH4203Xm;@03086YP@0/;R<0;2hS00<0;2hS00@0PJV101`O600L
7aP0PJV1[P2`h>H10?ooo`00[P2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV10080;2lS1P21ZH400`10
AcL0PJV105AQB00=05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21
ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21
ZH40CELm04eG?@0704eG?@D0PJV1100/;R<2086YP@0301`O6021ZH40/>3V0:`0/>3V0@3oool00:`0
/>3V0P21ZH4201dQ6@D0PJV11`10AcL00`21ZH40E65805AQB00<05AQB003086YP@1OL580Gg1B00l0
Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140
GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@@0PJV10`0/;R<01021ZH40
71lH086YP@21ZH6[0;3PiP40oooo002[0;3PiP03086YP@0M8AT07B4I00<0PJV12P10AcL00`21ZH40
E65805AQB00<05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40
HgIC06=fD`0D06=fD`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21ZH40
CELm04eG?@0;04eG?@03086YP@0i?Rh0>Ch^00D0PJV10P0L7aP00`21ZH40/>3V0;3PiP2X0;3PiP40
oooo002Z0;3PiP@0PJV100<09b/Q086YP@10AcL02@10AcL00`21ZH40E65805AQB00=05AQB003086Y
P@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgIC06=fD`0D06=fD`03086Y
P@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@03086Y
P@0i?Rh0>Ch^00@0>Ch^0`21ZH400`0L7aP0PJV10;3PiP2X0;3PiP40oooo002Y0;3PiP80PJV1100W
:b400`21ZH40@4Lg0417=`070417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`DP1OL5804@1O
L5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC01@0HgIC00<0PJV105i_C01NKd`04P1N
Kd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn;P0i?Rh01@0i
?Rh5086YPJL0/>3V0@3oool00:L0/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00P0@4Lg00<0PJV1
05AQB01DHDP0301DHDP00`21ZH40Gg1B05m`DP0A05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV1
06=fD`1SMU<0501SMU<00`21ZH40GVm<05i_C00C05i_C003086YP@1HIdL0F6M700l0F6M700<0PJV1
04eG?@1=Ecd02`1=Ecd00`21ZH40>Ch^03Tn;P0503Tn;P03086YP@0T9ad092LM0080PJV1YP2`h>H1
0?ooo`00YP2`h>H2086YP@D09b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQ
B003086YP@1OL580Gg1B0140Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0E06=f
D`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL0401HIdL00`21ZH40CELm04eG?@0;04eG
?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2U0;3PiP40oooo002U0;3P
iP80PJV11@0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`
DP1OL5804P1OL5800`21ZH40I7ME06AgE@0D06AgE@03086YP@1SMU<0HgIC01D0HgIC00<0PJV105i_
C01NKd`04`1NKd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn
;P0i?Rh01@0i?Rh00`21ZH4092LM02@W7@0202@W7@03086YP@2`h>H0/>3V0:80/>3V0@3oool00:@0
/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00T0@4Lg00<0PJV105AQB01DHDP03@1DHDP00`21ZH40
Gg1B05m`DP0B05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=fD`1SMU<05@1SMU<00`21ZH40
GVm<05i_C00C05i_C003086YP@1HIdL0F6M70100F6M700<0PJV104eG?@1=Ecd02`1=Ecd00`21ZH40
>Ch^03Tn;P0503Tn;P05086YP@0T9ad092LM02@W7@21ZH40Y02`h>H10?ooo`00X`2`h>H2086YP@H0
9b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQB003086YP@1OL580Gg1B0180
Gg1B00<0PJV106AgE@1TMeD02P1TMeD_086YP@/0GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40
CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2S0;3P
iP40oooo002R0;3PiP80PJV11P0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800h0
E65800<0PJV105m`DP1OL580201OL58G086YP@/0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40
LHUP0769H0090769H100PJV13P1HIdL00`21ZH40CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0
>Ch^00D0PJV102@W7@0T9ad092LM086YP@2R0;3PiP40oooo002Q0;3PiP80PJV11P0W:b400`21ZH40
@4Lg0417=`080417=`03086YP@1DHDP0E65800X0E6584021ZH4:07:<IP03086YP@1fTFP0MY5X01D0
MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D0080
IW]D2P21ZH4405QWA`03086YP@1=Ecd0CELm00d0CELm00<0PJV103Tn;P0i?Rh01@0i?Rh01@21ZH40
92LM02@W7@0T9ad0PJV10:40/>3V0@3oool00:00/>3V00<0PJV1010D4021ZH401@0W:b400`21ZH40
@4Lg0417=`090417=`04086YP@1DHDP0E65805AQB0T0PJV1101YOel00`21ZH40LXaV07:<IP0C07:<
IP03086YP@1fTFP0MY5X01D0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00E0769
H003086YP@1VNe@0IW]D00/0IW]D2P21ZH4:04eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00D0PJV102@W
7@0T9ad092LM086YP@2P0;3PiP40oooo002O0;3PiP03086YP@0@5100PJV100D09b/Q00<0PJV10417
=`10AcL01`10AcL7086YP@`0JGmO00<0PJV107:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00F07JA
J003086YP@1fT6H0MY1V01H0MY1V00<0PJV10769H01aRF00501aRF000`21ZH40IW]D06IkE00@06Ik
E003086YP@1KK4T0Ffa90080Ffa92021ZH4304eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00@0PJV102@W
7@0T9ad0PJV1X02`h>H10?ooo`00WP2`h>H00`21ZH4041@@086YP@0602L[8@03086YP@10AcL0@4Lg
00<0@4Lg1021ZH400`1GIdl0PJV106UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JA
J01fTFP05P1fTFP00`21ZH40MY1V07J@IP0F07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106Ik
E01VNe@04@1VNe@00`21ZH40Ffa905]/B@0905]/B@H0PJV11P0i?Rh01@21ZH4092LM02@W7@0T9ad0
PJV109l0/>3V0@3oool009h0/>3V00<041@@086YP@0W:b401@0W:b400`21ZH40@4Lg086YP@04086Y
P@D0EfM?00<0PJV106UoG`1YOel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X
01H0MY5X00<0PJV107J@IP1fT6H05P1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D
0140IW]D00<0PJV105]/B@1KK4T03P1KK4T5086YP@<0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2N
0;3PiP40oooo002M0;3PiP03010D4021ZH409b/Q00<09b/Q1@21ZH4905MWC`03086YP@1YOel0JGmO
00l0JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V
01H0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00A06IkE003086YP@1KK4T0Ffa9
00d0Ffa900<0PJV104QD>`18E3/00P18E3/5086YP@<092LM00<0PJV10;3PiP2`h>H0V`2`h>H10?oo
o`00W02`h>H00`0@5100PJV102L[8@04086YP@0303Po=021ZH40EfM?00/0EfM?00<0PJV106UoG`1Y
Oel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X01L0MY5X00<0PJV107J@IP1f
T6H05P1fT6H00`21ZH40LHUP0769H00E0769H003086YP@1VNe@0IW]D0140IW]D00<0PJV105]/B@1K
K4T03P1KK4T00`21ZH40B5@k04QD>`0504QD>`80PJV10`0T9ad00`21ZH40/>3V0;3PiP2J0;3PiP40
oooo002K0;3PiP04010D4021ZH40PJV1086YP@D0>3ld00<0PJV105MWC`1GIdl02@1GIdl00`21ZH40
JGmO06UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40
MY1V07J@IP0G07J@IP03086YP@1aRF00LHUP01D0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40
Ffa905]/B@0=05]/B@03086YP@18E3/0B5@k00L0B5@k0P21ZH400`0T9ad0PJV10;3PiP2K0;3PiP40
oooo002J0;3PiP03010D4021ZH40>3ld00H0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO
06UoG`0?06UoG`03086YP@1bS6H0LXaV01@0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40MY1V
07J@IP0H07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40Ffa9
05]/B@0>05]/B@03086YP@18E3/0B5@k00H0B5@k00<0PJV102/^8`21ZH400P21ZH6K0;3PiP40oooo
002I0;3PiP<0PJV11`0h?c@00`21ZH40EfM?05MWC`0905MWC`03086YP@1YOel0JGmO0100JGmO00<0
PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0
PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900d0Ffa900<0
PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02086YPIX0/>3V0@3oool009P0/>3V00<0PJV1
01TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV1
07:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0PJV1
0769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV1
04QD>`18E3/01P18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V09L0/>3V0@3oool0
09L0/>3V00@0PJV101TN6@0I7QT0PJV11P0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109T0/>3V0@3o
ool009L0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0
Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109P0/>3V0@3o
ool009H0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0
/>3V09D0/>3V0@3oool009D0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C
06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[
;R<0PJV109L0/>3V0@3oool009D0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00D
06IkE003086YP@1KK4T0Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02
02/^8`03086YP@2`h>H0/>3V09@0/>3V0@3oool009@0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@0
0`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H03`1bS6I9
086YP@`0LHUP00<0PJV106IkE01VNe@04`1VNe@00`21ZH40Ffa905]/B@0>05]/B@03086YP@18E3/0
B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP03086YP@0I7QT0PJV100L0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO06UoG`0A06Uo
G`03086YP@1bS6H0LXaV00@0LXaV3021ZH45086PMP03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108>S
M@23XgD06@23XgD00`21ZH40OYe_07jMK`0:07jMKaP0PJV12`1VNe@00`21ZH40Ffa905]/B@0=05]/
B@03086YP@18E3/0B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3P
iP40oooo002C0;3PiP04086YP@0I7QT06AhI086YP@H0>3ld00<0PJV105MWC`1GIdl02`1GIdl00`21
ZH40JGmO06UoG`0706UoGa40PJV14@21X7H00`21ZH40Q:Ah08BTN00H08BTN003086YP@23XgD0Pj=e
01T0Pj=e00<0PJV107jMK`1nWFl05P1nWFl00`21ZH40MI5T07FAI00907FAI100PJV1301KK4T00`21
ZH40B5@k04QD>`0704QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3PiP2`h>H0TP2`h>H10?oo
o`00TP2`h>H01021ZH406AhI01TN6@21ZH4703Po=003086YP@1GIdl0EfM?00P0EfM?3@21ZH4:07VF
L003086YP@21X7H0PJ1f01D0PJ1f00<0PJV108BTN024Y7P06024Y7P00`21ZH40Pj=e08>SM@0I08>S
M@03086YP@1nWFl0OYe_01H0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0206El
D`T0PJV10`1KK4T00`21ZH40B5@k04QD>`0804QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3P
iP2`h>H0T@2`h>H10?ooo`00TP2`h>H00`21ZH406AhI086YP@0703Po=003086YP@1GIdl0EfM?00@0
EfM?1@21ZH4206R0H`03086YP@1iUW00NII`0140NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40
Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40
MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00X0IGaC1P21ZH4804QD>`03086YP@0[;R<0:bhS00<0
:bhS00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00T@2`h>H01021ZH406AhI01TN6@21ZH4703Po=003
086YP@1GIdl0PJV100@0PJV11P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0
PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01L0
OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0PJV100<0
PJV11@18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V0900/>3V0@3oool00900/>3V
00@0PJV101TN6@0I7QT0PJV11@0h?c@5086YP@/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40
PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40
OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40
E6E505AUA@0205AUA@@0PJV100<0B5@k086YP@0[;R<0100[;R<00`21ZH40/>3V0;3PiP2?0;3PiP40
oooo002@0;3PiP03086YP@0I7QT06AhI0080>3ld1021ZH4204]KB@03086YP@1XP6<0J81S00/0J81S
00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T
00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0605AUA@@0PJV1100[;R<00`21ZH40/>3V
0;3PiP2>0;3PiP40oooo002?0;3PiP03086YP@0I7QT06AhI00<0PJV11@1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40MI5T07FA
I00E07FAI003086YP@1UO5<0IGaC00h0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]086Y
P@04086YPI00/>3V0@3oool008l0/>3V00@06AhI086YP@21ZH40PJV11`1;FdT00`21ZH40J81S06R0
H`0306R0H`030?mo001XP6<0J81S00D0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086P
MP0F086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jM
K`0H07jMK`03086YP@1eTF@0MI5T01@0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AU
A@0805AUA@03086YP@0g@2d0=d0]0080=d0]0P21ZH6?0;3PiP40oooo002>0;3PiP80PJV100<092`W
086YP@1;FdT01`1;FdT00`21ZH40J81S06R0H`0206R0H`<0ogl01P1XP6<00`21ZH40NII`07VFL00B
07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I
08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0?
06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV103M0;@0g@2d0100g@2f?0;3PiP40oooo002>0;3P
iP04086YP@0T;2L092`W086YP@L0Be]900<0PJV106R0H`1XP6<00`1XP6<20?mo00L0J81S00<0PJV1
07VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01X0Q:Ah00<0PJV1
08>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV1
06ElD`1UO5<03P1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV1
0;3PiP2`h>H0S02`h>H10?ooo`00S@2`h>H01021ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0
J81S00<0J81S0P3oO`0606R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H0
0`21ZH40Q:Ah08BTN00J08BTN003086YP@23XgD0Pj=e01X0Pj=e00<0PJV107jMK`1nWFl05`1nWFl0
0`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD0
0`21ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08`0/>3V0@3oool008d0/>3V00@0PJV102@/
9`0T;2L0PJV11`1;FdT00`21ZH40J81S06R0H`0406R0H`80ogl01P1XP6<00`21ZH40NII`07VFL00B
07VFL003086YP@21X7H0PJ1f01<0PJ1f00D0ogl0086PMP21X7H0PJV10?mo000K08BTN003086YP@23
XgD0Pj=e0140Pj=e00D0ogl008>SM@23XgD0Pj=e0?mo000408>SM@03086YP@1nWFl0OYe_00X0OYe_
00<0ogl007jMK`3oO`002P1nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0IGaC00l0IGaC
00<0PJV105AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08/0/>3V
0@3oool008`0/>3V00@0PJV102@/9`0T;2L0PJV1201;FdT00`21ZH40J81S06R0H`0306R0H`<0ogl0
1P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f0140PJ1f2@3oO`0908BTN080ogl0
2`24Y7P20?mo000308BTN021ZH40Pj=e00@0Pj=e0P3oO`0:08>SM@T0ogl00P23XgD20?mo00P0OYe_
2`3oO`0607jMK`03086YP@1eTF@0ogl001D0MI5T00<0PJV106ElD`1UO5<03P1UO5<00`21ZH40E6E5
05AUA@0905AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R`2`h>H10?ooo`00S02`
h>H01021ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S00<0J81S0P3oO`0606R0H`03086Y
P@1iUW00NII`00L0NII`00<0ogl007VFL03oO`002@1iUW001021ZH40PJ1f0?mo003oO`05086PMP80
ogl02021X7H;0?mo00P0Q:Ah0P3oO`0;08BTN080ogl000<0Q:Ah086YP@23XgD01023XgD20?mo00T0
Pj=e2`3oO`000`23XgD0ogl00?mo000707jMK`d0ogl01@1nWFl01021ZH40ogl00?mo003oO`0D07FA
I003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@0403M0
;@03086YP@2`h>H0/>3V08X0/>3V0@3oool008/0/>3V00D0PJV102@/9`0T;2L092`W086YP@0704]K
B@03086YP@1XP6<0J81S00@0J81S0`3oO`000`1XP6<0ogl006R0H`0206R0H`03086YP@1iUW00NII`
00D0NII`1`3oO`0607VFL004086YP@21X7H0ogl00?mo00H0PJ1f0P3oO`08086PMP80ogl01021X7H0
0`21ZH40Q:Ah08BTN0030?mo00L0Q:Ah0P3oO`0;08BTN080ogl000<0Q:Ah086YP@23XgD01023XgD2
0?mo00T0Pj=e0P3oO`0708>SM@D0ogl01`1nWFl20?mo00T0OYe_0P3oO`0507jMK`D0ogl04`1eTF@0
0`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d0
0`21ZH40/>3V0;3PiP2:0;3PiP40oooo002;0;3PiP04086YP@0T;2L092`W086YP@P0Be]900H0PJV1
06R0H`1XP6<0J81S0?mo001XP6<80?mo000306R0H`21ZH40NII`00D0NII`2@3oO`0507VFL004086Y
P@21X7H0ogl00?mo00H0PJ1f0P3oO`07086PMP80ogl01@21X7H01021ZH40Q:Ah08BTN024Y7P30?mo
00H0Q:Ah0P3oO`0;08BTN080ogl000<0Q:Ah086YP@23XgD01023XgD20?mo00T0Pj=e0P3oO`0808>S
M@@0ogl01`1nWFl00`3oO`00OYe_07jMK`0807jMK`80ogl01@1nWFl01021ZH40ogl00?mo003oO`0D
07FAI003086YP@1UO5<0IGaC0100IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@04
03M0;@03086YP@2`h>H0/>3V08T0/>3V0@3oool008X0/>3V00D0PJV102@/9`0T;2L092`W086YP@08
04]KB@06086YP@1XP6<0J81S06R0H`3oO`00J81S2@3oO`0607VFL0<0ogl01@1iUW020?mo00D0NII`
00@0PJV1086PMP3oO`00ogl01P21X7H20?mo00L0PJ1f00<0ogl0086PMP21X7H00`21X7H00`21ZH40
Q:Ah08BTN00308BTN080ogl01P24Y7P20?mo00/0Q:Ah0P3oO`000`24Y7P0PJV108>SM@0408>SM@80
ogl02023XgD30?mo00X0Pj=e0`3oO`0607jMK`030?mo001nWFl0OYe_00P0OYe_0`3oO`0407jMK`03
086YP@1eTF@0ogl001H0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03
086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H01021ZH4092`W
02@/9`21ZH4304]KB@80ogl00`1;FdT01021ZH40J81S06R0H`1XP6<20?mo000406R0H`3oO`00ogl0
0?mo00<0J81S0P3oO`000`21ZH40NII`07VFL00307VFL0<0ogl01P1iUW030?mo00@0NII`00@0PJV1
086PMP3oO`00ogl01P21X7H20?mo00H0PJ1f0P3oO`05086PMP03086YP@24Y7P0Q:Ah00<0Q:Ah0P3o
O`0608BTN080ogl02`24Y7P20?mo000308BTN021ZH40Pj=e00@0Pj=e0P3oO`0808>SM@80ogl02`23
XgD20?mo0180OYe_0P3oO`0607jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV106ElD`1UO5<03`1U
O5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`
h>H10?ooo`00RP2`h>H01021ZH4092`W02@/9`21ZH4304]KB@80ogl00`1;FdT01@21ZH40J81S06R0
H`1XP6<0ogl00080J81S0P3oO`0406R0H`80ogl000<0PJV107VFL01iUW000`1iUW020?mo00P0NII`
0P3oO`0307VFL003086YP@21X7H0PJ1f0080ogl01P21X7H20?mo00D0PJ1f0P3oO`06086PMP03086Y
P@24Y7P0Q:Ah00<0Q:Ah0P3oO`0608BTN080ogl02`21ZH420?mo00L0PJV10P3oO`07086YP@0308>S
M@3oO`00ogl000/0Pj=e0P3oO`0B07jMK`80ogl01P1nWFl00`21ZH40MI5T07FAI00E07FAI003086Y
P@1UO5<0IGaC0100IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@0403M0;@03086Y
P@2`h>H0/>3V08P0/>3V0@3oool008T0/>3V00D0PJV102@/9`0T;2L092`W086YP@0304]KB@80ogl0
0P1;FdT01021ZH40J81S06R0H`1XP6<20?mo000406R0H`3oO`00ogl00?mo00@0J81S0P3oO`000`21
ZH40NII`07VFL00307VFL0030?mo001iUW00NII`00L0NII`0P3oO`0307VFL003086YP@21X7H0PJ1f
0080ogl01P21X7H20?mo0004086PMP21ZH40PJV1086YP@80ogl03@21ZH430?mo00D0PJV10P3oO`0;
08jdQ080ogl000<0S[B4086YP@2=/X40102=/X420?mo00L0SK:100<0PJV10?mo003oO`003021ZH40
0`3oO`00PJV1086YP@0>086YP@@0ogl04`21ZH4<07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV1
05AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08P0/>3V0@3oool0
08T0/>3V00@0PJV102@/9`0T;2L0PJV1101;FdT20?mo0080Be]900D0PJV106R0H`1XP6<0J81S0?mo
000206R0H`80ogl01@1XP6<20?mo00D0NII`0P3oO`0407VFL0D0PJV10`3oO`04086YP@80ogl01P21
ZH420?mo0080PJV10`2</H<20?mo00L0S;6300<0PJV108jdQ02>]8@00`2>]8@20?mo00H0S[B40P3o
O`0;08jdQ080ogl000<0S[B4086YP@2=/X40102=/X420?mo00P0SK:10P3oO`0;08fbP@80ogl02`29
[G/80?mo00L0RJek00<0PJV10?mo003oO`002P21XW4A086YP@d0IGaC00<0PJV105AUA@1DIDD02@1D
IDD00`21ZH40=d0]03M0;@0403M0;@03086YP@2`h>H0/>3V08L0/>3V0@3oool008P0/>3V00D0PJV1
02@/9`0T;2L092`W086YP@0404]KB@80ogl00P1;FdT00`21ZH40J81S06R0H`020?mo0080J81S0P3o
O`0306R0H`80PJV10P3oO`04086YP@80ogl01@21ZH4508FXOP80ogl00`25Z7h01021ZH40S;630?mo
003oO`0608baP`80ogl01@2</H<20?mo00L0S;6300<0PJV108jdQ02>]8@00P2>]8@30?mo00H0S[B4
0P3oO`0;08jdQ080ogl000<0S[B4086YP@2=/X40102=/X420?mo00P0SK:10P3oO`0;08fbP@80ogl0
2029[G/90?mo00T0RJek00@0PJV1086RL@3oO`00ogl05@21XW400`21ZH40LXmQ07:?H@0207:?H@X0
PJV1101UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`
h>H0Q`2`h>H10?ooo`00R02`h>H01021ZH4092`W02@/9`21ZH4504]KB@80ogl000<0Be]9086YP@1X
P6<00P1XP6<0103oO`00PJV1086YP@21ZH420?mo00<0PJV10P1gUG<20?mo00@0QJQn0P3oO`0908FX
OP<0ogl00`25Z7h01021ZH40S;630?mo003oO`0608baP`80ogl01@2</H<20?mo00L0S;6300<0PJV1
08jdQ02>]8@00P2>]8@20?mo00L0S[B40P3oO`0;08jdQ080ogl000<0S[B4086YP@2=/X40102=/X42
0?mo00P0SK:10P3oO`0;08fbP@80ogl01`29[G/50?mo00h0RJek00@0PJV1086RL@3oO`00ogl05@21
XW400`21ZH40LXmQ07:?H@0<07:?H@P0PJV1201DIDD00`21ZH40=d0]03M0;@0403M0;@03086YP@2`
h>H0/>3V08H0/>3V0@3oool008L0/>3V00D0PJV102@/9`0T;2L092`W086YP@0504]KB@P0ogl00P1g
UG<30?mo00D0MiEc0P3oO`0408FXOP80ogl02@25Z7h20?mo00@0QJQn00@0PJV108baP`3oO`00ogl0
1P2</H<20?mo00D0S;630P3oO`0708baP`03086YP@2>]8@0S[B40080S[B40P3oO`0608jdQ0<0ogl0
2`2>]8@20?mo000308jdQ021ZH40SK:100@0SK:10P3oO`0808fbP@80ogl02`2=/X420?mo00L0RJek
0P3oO`0;08V]N`030?mo0029[G/0RJek00@0RJek00<0PJV10?mo003oO`005@21XW400`21ZH40LXmQ
07:?H@0@07:?H@04086YP@1MLdd0GG==05ecC@H0PJV10`1DIDD00`21ZH40=d0]03M0;@0303M0;@03
086YP@2`h>H0/>3V08H0/>3V0@3oool008L0/>3V00@0PJV102@/9`0T;2L0PJV10P1;FdT4086YP@L0
ogl00`1gUG<20?mo00H0MiEc0P3oO`0408FXOP80ogl02@25Z7h20?mo00<0QJQn00<0PJV108baP`2<
/H<00P3oO`0608baP`80ogl01@2</H<20?mo00L0S;6300@0PJV108jdQ02>]8@0S[B40`3oO`0708jd
Q0@0ogl02@2>]8@20?mo000308jdQ021ZH40SK:100@0SK:10P3oO`0808fbP@80ogl02`2=/X420?mo
00H0RJek0`3oO`0:08V]N`<0ogl01@29[G/00`21ZH40ogl00?mo000F086RL@03086YP@1bSf40LXmQ
00l0LXmQ00<0PJV105ecC@1MLdd01`1MLdd7086YP@<0=d0]00<0PJV10;3PiP2`h>H0Q@2`h>H10?oo
o`00QP2`h>H00`21ZH4092`W02@/9`04086YP@@0Fg9K0P3oO`001@21ZH40MiEc07NEL`1gUG<0ogl0
00<0MiEc0P3oO`0507NEL`80ogl01@25Z7h20?mo00P0QJQn0`3oO`0308FXOP04086YP@2</H<0ogl0
0?mo00L0S;630P3oO`0508baP`<0ogl01@2</H<01021ZH40S[B408jdQ02>]8@30?mo00P0S[B41@3o
O`0708jdQ080ogl00P2>]8@00`21ZH40SK:108fbP@0308fbP@80ogl0202=/X420?mo00/0SK:10P3o
O`0708V]N`<0ogl02@29[G/20?mo00H0RJek00<0PJV10?mo003oO`005P21XW400`21ZH40LXmQ07:?
H@0@07:?H@03086YP@1MLdd0GG==00T0GG==00@0PJV1045>=P11CSH0@Dhf1021ZH670;3PiP40oooo
00260;3PiP<0PJV100<0;SPc086YP@1KLU/01@1KLU/20?mo0003086YP@1gUG<0MiEc0080ogl00P1g
UG<30?mo00D0MiEc00<0ogl0086YP@25Z7h01025Z7h20?mo00L0QJQn0`3oO`0408FXOP04086YP@2<
/H<0ogl00?mo00L0S;630P3oO`0508baP`@0ogl0102</H<00`21ZH40S[B408jdQ0030?mo00T0S[B4
0P3oO`000`2>]8@0ogl00?mo00020?mo00<0S[B4103oO`0208jdQ003086YP@2=/X40SK:100<0SK:1
0P3oO`0808fbP@80ogl02`2=/X420?mo00P0RJek0`3oO`0808V]N`80ogl01P29[G/00`21ZH40ogl0
0?mo000F086RL@03086YP@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02@1MLdd00`21ZH40@Dhf
045>=P04045>=P80PJV1QP2`h>H10?ooo`00QP2`h>H01021ZH40;SPc02hh<`21ZH4705]bF`80ogl0
00@0PJV107NEL`1gUG<0ogl00`1gUG<20?mo00D0MiEc0P3oO`000`21ZH40QJQn08FXOP0308FXOP<0
ogl01@25Z7h30?mo00D0QJQn00@0PJV108baP`3oO`00ogl01`2</H<20?mo00L0S;631@3oO`000`2<
/H<0PJV10?mo00030?mo00X0S[B40P3oO`0208jdQ0T0ogl00`2>]8@00`21ZH40SK:108fbP@0308fb
P@80ogl0202=/X420?mo00/0SK:10P3oO`0908V]N`@0ogl00`29[G/50?mo00H0RJek00<0PJV10?mo
003oO`005P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>
=P11CSH00`11CSH2086YPHH0/>3V0@3oool008D0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0705]b
F`80ogl000@0PJV107NEL`3oO`00ogl00`1gUG<20?mo00@0MiEc0P3oO`000`1gUG<0PJV108FXOP05
08FXOP@0ogl000<0QJQn0?mo003oO`000P3oO`0608FXOP04086YP@2</H<0ogl00?mo00H0S;630P3o
O`0908baP`T0ogl02P2>]8@20?mo00@0S[B41P3oO`0508jdQ003086YP@2=/X40SK:100<0SK:10P3o
O`0808fbP@80ogl02`2=/X400`21ZH40ogl00?mo000908V]N`X0ogl01`29[G/00`21ZH40ogl00?mo
000F086RL@03086YP@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>
=P04045>=P03086YP@2`h>H0/>3V08@0/>3V0@3oool008D0/>3V00D0PJV102hh<`0^>3<0;SPc086Y
P@0705]bF`80ogl00P1gUG<00`3oO`00MiEc07NEL`0207NEL`<0ogl00P1gUG<30?mo000307NEL`21
ZH40QJQn00H0QJQn1`3oO`0708FXOP04086YP@2</H<0ogl00?mo00H0S;630P3oO`0;08baP`D0ogl0
7@2>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek00X0RJek1P3oO`0:08V]N`04086Y
P@21XW40ogl00?mo01D0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03
086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc
02hh<`0^>3<0PJV100H0Fg9K0`3oO`000`1gUG<0ogl00?mo000307NEL`P0ogl000<0MiEc086YP@25
Z7h02025Z7h40?mo00T0QJQn00@0PJV108baP`3oO`00ogl01P2</H<20?mo00h0S;6300<0PJV108jd
Q02>]8@06`2>]8@00`21ZH40SK:108fbP@0K08fbP@03086YP@29[G/0RJek01X0RJek00@0PJV1086R
L@3oO`00ogl05@21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00T0GG==00<0PJV1
045>=P11CSH01011CSH2086YPHD0/>3V0@3oool008D0/>3V00@0PJV102hh<`0^>3<0PJV11`1KLU/2
0?mo0003086YP@1gUG<0ogl000D0MiEc1P3oO`0207NEL`03086YP@25Z7h0QJQn01<0QJQn00@0PJV1
08baP`3oO`00ogl01`2</H<20?mo00h0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fb
P@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV10?mo003oO`005@21XW400`21ZH40LXmQ07:?
H@0A07:?H@03086YP@1MLdd0GG==00T0GG==00<0PJV1045>=P11CSH01011CSH2086YPHD0/>3V0@3o
ool008@0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0705]bF`80ogl000<0PJV10?mo003oO`003@1g
UG<00`21ZH40QJQn08FXOP0C08FXOP04086YP@2</H<0ogl00?mo00L0S;630P3oO`0>08baP`03086Y
P@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X40702=/X400`21ZH40RJek08V]N`0J08V]N`03086Y
P@3oO`00ogl001H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086Y
P@11CSH0@Dhf00<0@Dhf0P21ZH650;3PiP40oooo00240;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40
1`1KLU/50?mo00d0MiEc00<0PJV108FXOP25Z7h04`25Z7h01021ZH40S;630?mo003oO`0708baP`80
ogl03P2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:100D0SK:100<0ogl008fbP@2=
/X40502=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@3oO`00ogl001H0PJ9a00<0PJV107:?H@1b
Sf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`
h>H0P`2`h>H10?ooo`00Q02`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100L0Fg9K103oO`0>07NEL`03
086YP@25Z7h0QJQn01<0QJQn00@0PJV108baP`3oO`00ogl01P2</H<30?mo00h0S;6300<0PJV108jd
Q02>]8@06`2>]8@00`21ZH40SK:108fbP@0408fbP@@0ogl0502=/X400`21ZH40RJek08V]N`0J08V]
N`03086YP@3oO`00ogl001H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ec
C@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q02`h>H01021ZH40
;SPc02hh<`21ZH4805]bF`@0ogl03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP04086YP@2</H<0ogl0
0?mo00H0S;630P3oO`0?08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X400`2=/X46
0?mo01<0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40ogl00?mo000F086RL@03086YP@1bSf40
LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P80PJV1Q02`h>H1
0?ooo`00P`2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K0`3oO`0>07NEL`03086YP@25Z7h0
QJQn01@0QJQn00@0PJV108baP`3oO`00ogl01P2</H<20?mo00h0S;6300<0PJV108jdQ02>]8@0702>
]8@00`21ZH40SK:108fbP@0408fbP@@0ogl0502=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@3o
O`00ogl001H0PJ9a00<0PJV107:?H@1bSf404@1bSf400`21ZH40GG==05ecC@0905ecC@03086YP@11
CSH0@Dhf00@0@Dhf0P21ZH640;3PiP40oooo00230;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201K
LU/30?mo00h0MiEc00<0PJV108FXOP25Z7h05025Z7h00`21ZH40ogl00?mo000708baP`80ogl03P2<
/H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:100D0SK:100<0ogl008fbP@2=/X40502=
/X400`21ZH40RJek08V]N`0J08V]N`04086YP@21XW40ogl00?mo01D0PJ9a00<0PJV107:?H@1bSf40
4@1bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0@Dhf0P21ZH640;3PiP40oooo
00230;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/30?mo00h0MiEc00<0PJV108FXOP25Z7h0
5025Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40
702=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40
4@1bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0
PP2`h>H10?ooo`00P`2`h>H01021ZH40;SPc02hh<`21ZH4905]bF`80ogl03`1gUG<00`21ZH40QJQn
08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:1
08fbP@0L08fbP@03086YP@29[G/0RJek01/0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ
07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH01011CSH2086YPH<0/>3V
0@3oool00880/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0905]bF`03086YP@1gUG<0MiEc00h0MiEc
00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0H08baP`03086YP@2>]8@0S[B401`0S[B4
00<0PJV108fbP@2=/X40702=/X400`21ZH40RJek08V]N`0K08V]N`03086YP@21XW40PJ9a01H0PJ9a
00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00@0@Dhf
0P21ZH630;3PiP40oooo00220;3PiP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc
07NEL`0>07NEL`03086YP@25Z7h0QJQn01@0QJQn00<0PJV108baP`2</H<02`2</H=J086YP@l0RJek
00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00T0GG==
00<0PJV1045>=P11CSH01011CSH2086YPH<0/>3V0@3oool00880/>3V00D0PJV102hh<`0^>3<0;SPc
086YP@0805]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV108FXOP25Z7h02@25Z7hI086YP@d0UKj=
00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z500`0T[Z5
<P21ZH4:07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH00`11CSH2086YPH<0/>3V
0@3oool00880/>3V0`0^>3<00`21ZH40Fg9K05]bF`0305]bFb40PJV12`2?]XX00`21ZH40UKj=09Fn
S@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:j
Q@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd01`1lWVdA086YP@H0GG==00<0
PJV1045>=P11CSH01011CSH00`21ZH40/>3V0;3PiP210;3PiP40oooo00210;3PiP03086YP@0^>3<0
;SPc00L0PJV1101XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV1
09FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV1
09:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV1
06EoE01UOe@0101UOe@:086YP@<0@Dhf0P21ZH620;3PiP40oooo00210;3PiP<0PJV100<0>da2086Y
P@1XQ6X0201XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109Fn
S@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:j
Q@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106Eo
E01UOe@02P1UOe@01021ZH40AeXl04MJ?017FS`5086YPH80/>3V0@3oool00840/>3V00D0PJV103]<
@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX0
0`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/0
0`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd0
0`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH620;3PiP40oooo00210;3P
iP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0
SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0
U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0
O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?003086YP@0M91X0
/>3V0840/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0
PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0
R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0
AeXl00@0AeXl00<0PJV101dT6P2`h>H0P@2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480
PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0
UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0
T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0
IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`00`21ZH407B@J0;3PiP210;3PiP40oooo00210;3P
iP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0
SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0
U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0
O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00304MJ?003086YP@0M91X0
/>3V0840/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0
PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0
R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0
AeXl00@0AeXl0P21ZH610;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X0
0`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd0
0`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD0
0`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@0
0`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480
PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0
UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0
T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0
IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00840/>3V00D0PJV103]<
@P0kC480>da2086YP@0806R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX0
0`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/0
0`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd0401lWVd0
0`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3P
iP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0
SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0
U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0
O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H1
0?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl0
0`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d0
0`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`0
0`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2
086YPH40/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0
PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0
R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0
AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X0
0`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd0
0`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD0
0`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@0
0`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480
PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0
UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0
T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0
IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00800/>3V00D0PJV103]<
@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX0
0`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/0
0`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd0
0`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00<0AeXl0P21ZH610;3PiP40oooo00200;3P
iP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0
SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0
U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0
O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P02`h>H1
0?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl0
0`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d0
0`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`0
0`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2
086YPH00/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0
PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0
R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0
AeXl00@0AeXl0P21ZH600;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X0
0`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd0
0`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD0
0`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@0
0`21ZH40AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00P02`h>Kc086YPH00/>3V0@3oool00800
/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2
T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9
T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[
M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH600;3P
iP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08Zc
RP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;
UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096k
Q@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0404aR
@@80PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108Zc
RP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;
UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096k
Q@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR
@@1<HT40101<HT42086YPH00/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076C
MP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9
UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4
SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=
G`03086YP@1<HT40C69100@0C6910P21ZH600;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04EL
C`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9
UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4
SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=
G`1^SEl02`1^SEl00`21ZH40C69104aR@@0304aR@@03086YP@0R;Ah0/>3V0800/>3V0@3oool00800
/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2
T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9
T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[
M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C69100<0PJV1028]
7P2`h>H0P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108Zc
RP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;
UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096k
Q@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR
@@1<HT40101<HT42086YPH40/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076C
MP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9
UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4
SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=
G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04EL
C`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9
UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4
SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=
G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40
AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2
T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9
T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[
M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00840
/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00d0R[>:00<0PJV109K2
T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9
T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[
M`24ZgL04024ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3P
iP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08Zc
RP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;
UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096k
Q@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0404aR
@@80PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108Zc
RP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;
UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096k
Q@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR
@@1<HT40101<HT42086YPH40/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076C
MP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9
UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4
SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=
G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04EL
C`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9
UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4
SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=
G`1^SEl02`1^SEl00`21ZH40C69104aR@@0304aR@@80PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40
AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2
T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9
T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[
M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH80/>3V0@3oool00840
/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2
T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9
T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[
M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH620;3P
iP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08Zc
RP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;
UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096k
Q@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR
@@80PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108Zc
RP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;
UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096k
Q@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR
@@1<HT40101<HT42086YPH80/>3V0@3oool00840/>3V0P21ZH4204ELC`03086YP@1aTgH0LI=f00L0
LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0
W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0
V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0
KXeO00@0PJV104aR@@1<HT40C6911@21ZH620;3PiP40oooo00210;3PiP03086YP@1=J5T0PJV101@0
PJV1202:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2M
biH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A
^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00@0KXeO2P21ZH4304iX@`80
PJV1PP2`h>H10?ooo`00PP2`h>H01021ZH40CFQI04eXF@21ZH4907RNOP03086YP@2@_I80T;fB00H0
T;fB5021ZH4;09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40
W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40
Q:]g08B[M`0808B[Ma00PJV11P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V0840
/>3V0@3oool00880/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0807RNOP03086YP@2@_I80T;fB00h0
T;fB00<0PJV109c<VP2Lc9X02@2Lc9XI086YP@d0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40
W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>00d0V<B><P21ZH4908ZdO`03086YP@1dV6P0M9QX00X0
M9QX00<0PJV104iX@`1>J4<00`1>J4<00`21ZH4093<R0;3PiP220;3PiP40oooo00220;3PiP05086Y
P@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01@0
W<bJ00<0PJV10:7BW@2QdYd02`2QdYeK086YP@h0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40
R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0M9QX00<0PJV104iX@`1>J4<0101>J4<2086YPH<0
/>3V0@3oool00880/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00h0
T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01`0
X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00K09g=U003086YP@2Ga8`0UlB<01H0
UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0
CVQ30P21ZH630;3PiP40oooo00230;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0PJV1092mTP2@
_I803P2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02R
di`0702Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01/0WLfD00<0PJV109O4S02G
a8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>
J4<0101>J4<2086YPH<0/>3V0@3oool008<0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0807RNOP03
086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03
086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003
086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00:07BHJ003
086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00P`2`h>H01@21ZH40CFQI
04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03
086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03
086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0A08ZdO`03
086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<00`1>J4<2086YPH@0/>3V0@3oool008<0/>3V
00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2L
c9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2Q
dIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:
]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH640;3PiP40
oooo00240;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40
W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40
XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40
R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<2086YPH@0
/>3V0@3oool008@0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0807RNOP03086YP@2@_I80T;fB00h0
T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0
X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0
UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0
CVQ300<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q02`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0
N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0
XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0
WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0
M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V0;3PiP230;3PiP40oooo00240;3PiP05086Y
P@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0
W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01`0
XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100
R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0304iX@`80PJV1Q@2`h>H10?ooo`00
Q@2`h>H01021ZH40CFQI04eXF@21ZH4907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2L
c9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2Q
dIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01D0UlB<00<0PJV108ZdO`2:
]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH650;3PiP40
oooo00250;3PiP05086YP@1=J5T0CFQI04eXF@21ZH40201hWWh00`21ZH40T;fB092mTP0=092mTP03
086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00K0:;CW003
086YP@2QdIT0XM6I01/0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003
086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40CVQ304iX@`0404iX@`80
PJV1Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@
_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02R
di`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02G
a8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>
J4<0101>J4<00`21ZH40/>3V0;3PiP240;3PiP40oooo00250;3PiP05086YP@1=J5T0CFQI04eXF@21
ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2Q
dYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02M
cI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01d
V6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V08@0/>3V0@3oool008H0/>3V
00@0PJV104eXF@1=J5T0PJV12@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0
W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0
XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100
R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0304iX@`80PJV1QP2`h>H10?ooo`00
QP2`h>H2086YP@80CFQI00<0PJV107RNOP1hWWh01P1hWWh00`21ZH40T;fB092mTP0=092mTP03086Y
P@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086Y
P@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086Y
P@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40CVQ304iX@`0404iX@`80PJV1
QP2`h>H10?ooo`00QP2`h>H00`21ZH40DG5P086YP@04086YP@L0N9in00<0PJV1092mTP2@_I80302@
_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702R
di`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2G
a8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00T0M9QX00@0PJV104iX@`1>J4<0CVQ3
1021ZH670;3PiP40oooo00270;3PiP04086YP@1ALF00DG5P086YP@80NjJ41@21ZH4207RNOP03086Y
P@2@_I80T;fB00`0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086Y
P@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086Y
P@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l03`2:]7l00`21ZH40M9QX07BHJ00707BHJ0L0PJV1
0`1CLD/00`21ZH40/>3V0;3PiP250;3PiP40oooo00270;3PiP05086YP@1ALF00DG5P055aH021ZH40
1P1kYX@6086YP@`0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086Y
P@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086Y
P@2Ga8`0UlB<01D0UlB<00<0PJV108ZdO`2:]7l0402:]7l01021ZH40M9QX07BHJ01dV6P6086YP@<0
N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP260;3PiP40oooo00280;3PiP04086Y
P@1ALF00DG5P086YP@P0NjJ400@0PJV109?4V02Ca9P0TlBH2021ZH44092mTP03086YP@2Lc9X0W<bJ
01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I
01X0XM6I00<0PJV109g=U02McI@06@2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao
00`0R[Ao2021ZH4807RPK`03086YP@1CLD/0Dg5;00@0Dg5;00<0PJV10;3PiP2`h>H0QP2`h>H10?oo
o`00R02`h>H01@21ZH40DG5P055aH01ALF00PJV100P0NjJ400<0PJV109?4V02Ca9P0202Ca9P?086Y
P@/0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I
01X0XM6I00<0PJV109g=U02McI@06@2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao
0080R[Ao2P21ZH4408jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=aB`1CLD/00`1CLD/00`21
ZH40/>3V0;3PiP270;3PiP40oooo00290;3PiP04086YP@1ALF00DG5P086YP@P0NjJ400<0PJV109?4
V02Ca9P0302Ca9P00`21ZH40Wm:P09oBX00809oBX1P0PJV13@2QdYd00`21ZH40X]>L0:;CW00K0:;C
W003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06@2McI@00`21ZH40UlB<09O4S00:09O4
S140PJV13@2>_8D00`21ZH40N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;00@0Dg5;00<0PJV10;3P
iP2`h>H0Q`2`h>H10?ooo`00R@2`h>H01@21ZH40DG5P055aH01ALF00PJV100L0NjJ400<0PJV109?4
V02Ca9P03@2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS00X0YMVS7021ZH4?0:;C
W003086YP@2QdIT0XM6I00`0XM6I=`21ZH4<09[;TP03086YP@2>_8D0S[b500l0S[b500<0PJV107RP
K`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08P0/>3V0@3oool008X0
/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P
0180Wm:P00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0<0:KJXQh0PJV13P2Uf9l00`21
ZH40XMBJ0:7DVP0I0:7DVP03086YP@2Jbi80V/^B01D0V/^B00<0PJV108jlQ@2>_8D0402>_8D00`21
ZH40N:1_07RPK`0807RPK`03086YP@1CLD/0Dg5;00@0Dg5;00<0PJV10;3PiP2`h>H0R02`h>H10?oo
o`00RP2`h>H01021ZH40DG5P055aH021ZH4807^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oB
X02OdZ004`2OdZ000`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01/0Y]ZR00<0PJV10:GH
W`2Uf9l06P2Uf9l00`21ZH40XMBJ0:7DVP0I0:7DVP03086YP@2Jbi80V/^B01D0V/^B00<0PJV108jl
Q@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0907RPK`03086YP@1CLD/0Dg5;00<0Dg5;00<0PJV10;3P
iP2`h>H0R@2`h>H10?ooo`00RP2`h>H01@21ZH40DG5P055aH01ALF00PJV100P0NjJ400<0PJV109?4
V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00C09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJ
XP2VfZ806`2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ01P0XMBJ00<0PJV109[;
TP2Jbi805P2Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00T0N:1_00<0PJV105=a
B`1CLD/00`1CLD/00`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP04086YP@1ALF00DG5P086Y
P@P0NjJ400<0PJV109?4V02Ca9P0302Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS
01L0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ
01P0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0@08jlQ@03086YP@1hX6l0N:1_
00P0N:1_00<0PJV105=aB`1CLD/0101CLD/00`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP05
086YP@1ALF00DG5P055aH021ZH401`1kYX@00`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P
0180Wm:P00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO
01X0YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b5
00l0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V
08X0/>3V0@3oool008`0/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00;09?4
V003086YP@2OdZ00Wm:P01<0Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJ
XP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21ZH40V/^B09[;TP0E09[;
TP03086YP@2>_8D0S[b500l0S[b500<0PJV107RPK`1hX6l0201hX6l00`21ZH40Dg5;05=aB`0405=a
B`03086YP@2`h>H0/>3V08X0/>3V0@3oool008`0/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21
ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21
ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21
ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500h0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21
ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V00@0PJV1055aH01A
LF00PJV11`1kYX@00`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GI
X`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7D
VP2Qe9X05`2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500l0S[b500<0PJV107RP
K`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08/0/>3V0@3oool008d0
/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P
0180Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO
01X0YMRO00<0PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b5
00l0S[b500<0PJV107RPK`1hX6l0201hX6l00`21ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V
08`0/>3V0@3oool008h0/>3V00@0PJV1055aH01ALF00PJV11`1kYX@00`21ZH40TlBH09?4V00<09?4
V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJ
XP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B09[;TP0E09[;
TP03086YP@2>_8D0S[b500h0S[b500<0PJV107RPK`1hX6l02@1hX6l00`21ZH40Dg5;05=aB`0305=a
B`03086YP@2`h>H0/>3V08`0/>3V0@3oool008h0/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21
ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21
ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21
ZH40V/^B09[;TP0D09[;TP03086YP@2>_8D0S[b500l0S[b500<0PJV107RPK`1hX6l0201hX6l00`21
ZH40Dg5;05=aB`0305=aB`03086YP@2`h>H0/>3V08d0/>3V0@3oool008l0/>3V0P21ZH400`1ALF00
PJV107^VQ00607^VQ003086YP@2Ca9P0TlBH00/0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40
YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40
XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40
N:1_07RPK`0807RPK`03086YP@1CLD/0Dg5;0080Dg5;0P21ZH6?0;3PiP40oooo002?0;3PiP03086Y
P@1CMF<0PJV100<0PJV11@1kYX@00`21ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P0180Wm:P
00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Uf9l0YMRO01T0YMRO
00<0PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500h0S[b5
00<0PJV107RPK`1hX6l0201hX6l00`21ZH40Dg5;086YP@03086YP@0305AfD02`h>H0/>3V08h0/>3V
0@3oool00900/>3V00D0PJV105=eH`1CMF<0PJV107^XQP04086YP@80NjJ400<0PJV109?4V02Ca9P0
2`2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01D0YMVS00<0PJV10:KJXP2VfZ80
6@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi80
502Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00L0N:1_0`21ZH4405AfD003086Y
P@2`h>H0/>3V08h0/>3V0@3oool00900/>3V00@0PJV105=eH`1CMF<0PJV11@1kZ8H5086YP@/0TlBH
00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0E0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR
00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01@0V/^B
00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0307RPK`D0PJV11@1DMU000`21ZH40/>3V
0;3PiP2?0;3PiP40oooo002A0;3PiP04086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`21ZH40
1021ZH4609?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR
0:KJXP0I0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B
09[;TP0D09[;TP03086YP@2>_8D0S[b500h0S[b500<0PJV107RPK`1hX6l01021ZH4407VTL`03086Y
P@1DMU00E7I@0080E7I@00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00TP2`h>H00`21ZH40DgES086Y
P@0707^XQP03086YP@2Dai/0U<NK00@0U<NK1@21ZH4209?4V003086YP@2OdZ00Wm:P0140Wm:P00<0
PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0
PJV10:7DVP2Qe9X05`2Qe9X00`21ZH40V/^B09[;TP0D09[;TP03086YP@2>_8D0S[b500X0S[b51`21
ZH4707VTL`03086YP@1DMU00E7I@00<0E7I@00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00TP2`h>H0
1021ZH40DgES05=eH`21ZH4707^XQP03086YP@2Dai/0U<NK00P0U<NK3@21ZH4:09oBX003086YP@2U
fJ<0YMVS01D0YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Q
e9X0XMBJ01H0XMBJ00<0PJV109[;TP2Jbi80502Jbi800`21ZH40S[b508jlQ@0208jlQ@T0PJV10`2?
_hT00`21ZH40NJAc07VTL`0807VTL`03086YP@1DMU00E7I@0080E7I@00<0PJV10;3PiP2`h>H0T@2`
h>H10?ooo`00T`2`h>H01021ZH40DgES05=eH`21ZH4607^XQP03086YP@2Dai/0U<NK00/0U<NK00<0
PJV10:7FY02QeZ@01`2QeZ@@086YPA80YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMRO0:GH
W`0I0:GHW`03086YP@2Qe9X0XMBJ01H0XMBJ00<0PJV109[;TP2Jbi802@2Jbi8@086YP@`0Skn900<0
PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V0980/>3V0@3o
ool009@0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0
XMJT0140XMJT00<0PJV10:KMY`2VgJL00`2VgJL<086YP@H0YMVS00<0PJV10:KJXP2VfZ80602VfZ80
0`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ00X0XMBJ6021ZH4;09c@UP03086YP@2?_hT0
Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0
/>3V09<0/>3V0@3oool009@0/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H00`21ZH40U<NK09C7V`0:
09C7V`03086YP@2QeZ@0XMJT0140XMJT00<0PJV10:KMY`2VgJL03P2VgJM:086YP@`0XmVN00<0PJV1
09c@UP2Ld9H04`2Ld9H00`21ZH40Skn908noR@0>08noR@03086YP@1iY7<0NJAc00L0NJAc00<0PJV1
05AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C0;3PiP40oooo002E0;3PiP03086YP@1CMF<0PJV1
00L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00A0:7FY003086YP@2VgJL0Y]fW
01@0Y]fW00<0PJV10:SOYP2XgjH0602XgjH00`21ZH40YmfS0:OMX`0I0:OMX`03086YP@2SfIh0XmVN
01D0XmVN00<0PJV109c@UP2Ld9H0502Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc
00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2D0;3PiP40oooo002E0;3PiP04
086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00@0:7F
Y003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH0602XgjH00`21ZH40YmfS0:OMX`0I0:OM
X`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04`2Ld9H00`21ZH40Skn908noR@0>08no
R@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01DMU00E7I@086YP@2G0;3PiP40oooo002F0;3P
iP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00A0:7F
Y003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40YmfS0:OMX`0H0:OM
X`03086YP@2SfIh0XmVN01H0XmVN00<0PJV109c@UP2Ld9H04`2Ld9H00`21ZH40Skn908noR@0=08no
R@03086YP@1iY7<0NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2E0;3P
iP40oooo002G0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40
XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40
YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01H0XmVN00<0PJV109c@UP2Ld9H04P2Ld9H00`21ZH40
Skn908noR@0>08noR@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01DMU00E7I@086YP@2H0;3P
iP40oooo002G0;3PiP04086YP@1CMF<0DgES086YP@H0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21
ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21
ZH40YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04`2Ld9H00`21
ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01DMU00E7I@086YP@2I
0;3PiP40oooo002H0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21
ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21
ZH40YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04P2Ld9H00`21
ZH40Skn908noR@0>08noR@03086YP@1iY7<0NJAc00H0NJAc00<0PJV105AfD01DMU000P1DMU000`21
ZH40/>3V0;3PiP2G0;3PiP40oooo002I0;3PiP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2D
ai/02@2Dai/00`21ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2X
gjH05P2XgjH00`21ZH40YmfS0:OMX`0H0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2L
d9H04P2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01D
MU00E7I@086YP@2J0;3PiP40oooo002J0;3PiP80PJV11`1kZ8H00`21ZH40U<NK09C7V`0:09C7V`03
086YP@2QeZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03
086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0B09c@UP03
086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01P1iY7<00`21ZH40E7I@05AfD002086YPI/0
/>3V0@3oool009/0/>3V1021ZH4507^XQP03086YP@2Dai/0U<NK00T0U<NK00<0PJV10:7FY02QeZ@0
402QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OMX`2WgJ<0
5`2WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT0
3@2?_hT00`21ZH40NJAc07VTL`0707VTL`@0PJV1W02`h>H10?ooo`00W02`h>H2086YP@0307JUQ021
ZH40PJV10080PJV100<0NjR6086YP@2Dai/02`2Dai/00`21ZH40XMJT0:7FY00?0:7FY003086YP@2V
gJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2S
fIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0>08noR@03086YP@1i
Y7<0NJAc00D0NJAc0`21ZH42059fDP03086YP@2`h>H0/>3V09X0/>3V0@3oool009d0/>3V0P21ZH44
07JUQ0D0PJV12@2Dai/00`21ZH40XMJT0:7FY00?0:7FY003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV1
0:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV1
09c@UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc0080NJAc1@21ZH43
059fDP03086YP@2`h>H0/>3V09/0/>3V0@3oool009h0/>3V0P21ZH4607JUQ003086YP@2@a9T0PJV1
00<0PJV11P2Dai/00`21ZH40XMJT0:7FY00?0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SO
YP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0XmVN01@0XmVN00<0PJV109c@
UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0>08noR@D0PJV10`1eXW<01@21ZH40DWIB059fDP1BMU80
PJV109h0/>3V0@3oool009h0/>3V00<0PJV1051dHP21ZH401P1fYH@00`21ZH40T<BI0934V@020934
V@D0PJV100<0U<NK086YP@2QeZ@0402QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV
01H0Z=nV00<0PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2Ld9H0W=2F
0140W=2F00<0PJV108noR@2?_hT02@2?_hT6086YP@H0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2O
0;3PiP40oooo002O0;3PiP03086YP@1@M680PJV100D0MZF400<0PJV10934V@2@a9T01`2@a9T7086Y
P@`0XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS
01H0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0@09c@UP03086YP@2?_hT0Skn9
0080Skn92021ZH4308boRP03086YP@1eXW<0MJ9c00H0MJ9c00@0PJV1059fDP1BMU80PJV1X02`h>H1
0?ooo`00X02`h>H00`21ZH40D7AR086YP@0507JUQ003086YP@2@a9T0T<BI00T0T<BI00@0PJV109kF
Y02NeZ@0W]JT2@21ZH440:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05@2XgjH0
0`21ZH40YmfS0:OMX`0E0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H0302Ld9H9
086YP@X0S;n:00<0PJV107FRL`1eXW<01P1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:00/>3V0@3o
ool00:40/>3V0P21ZH4607JUQ003086YP@2@a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@02P2NeZ@?
086YP@/0Y]fW00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmfS0:OMX`0E0:OMX`03086YP@2SfIh0
XmVN01@0XmVN00<0PJV109c@UP2Ld9H00`2Ld9H:086YP@<0V]2H00<0PJV108boRP2<_hX03@2<_hX0
0`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80DWIB059fDP21ZH40X@2`h>H10?ooo`00XP2`h>H2
086YP@H0MZF400<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00>09kFY003086YP@2UgJP0
YMfX00L0YMfX5`21ZH4<0:SOYP03086YP@2WgJ<0YmfS01D0YmfS00<0PJV10:?IWP2SfIh02@2SfIhA
086YP@d0V]2H00<0PJV108boRP2<_hX0302<_hX00`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80
DWIB059fDP21ZH40XP2`h>H10?ooo`00X`2`h>H2086YP@H0MZF400<0PJV10934V@2@a9T0202@a9T0
0`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0180YMfX00<0PJV10:OPZ02Wh:P02@2Wh:P`
086YP@/0X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0<08boRP03086YP@1eXW<0
MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2S0;3PiP40oooo002T0;3PiP80PJV11@1fYH@0
0`21ZH40T<BI0934V@090934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP04P2UgJP0
0`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2VgjD0Y]nU01D0Y]nU00<0PJV10:;JX02RfZ004`2RfZ00
0`21ZH40V]2H09[@V00@09[@V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FRL`1eXW<01@1eXW<0
1@21ZH40DWIB059fDP1BMU80PJV10:@0/>3V0@3oool00:D0/>3V0P21ZH4507JUQ003086YP@2@a9T0
T<BI00P0T<BI00<0PJV109kFY02NeZ@03@2NeZ@00`21ZH40YMfX0:GMZ00B0:GMZ003086YP@2Wh:P0
Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD05@2VgjD00`21ZH40X]ZP0:;JX00C0:;JX003086YP@2Jd9P0
V]2H00l0V]2H00<0PJV108boRP2<_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FRL`03086YP@1BMU80
DWIB0080DWIB00<0PJV10;3PiP2`h>H0XP2`h>H10?ooo`00YP2`h>H2086YP@D0MZF400<0PJV10934
V@2@a9T0202@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0140YMfX00<0PJV10:OP
Z02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0E0:KOY@03086YP@2RfZ00X]ZP0180X]ZP00<0PJV109[@
V02Jd9P0402Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0MJ9c00D0MJ9c00D0PJV1059f
DP1BMU80DWIB086YP@2U0;3PiP40oooo002W0;3PiP80PJV11@1fYH@00`21ZH40T<BI0934V@080934
V@03086YP@2NeZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP04@2UgJP00`21ZH40Yn2X0:OPZ00D0:OP
Z003086YP@2VgjD0Y]nU01@0Y]nU00<0PJV10:;JX02RfZ004`2RfZ000`21ZH40V]2H09[@V00?09[@
V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FRL`1eXW<01@1eXW<00`21ZH40DWIB059fDP02086Y
PJH0/>3V0@3oool00:T0/>3V0P21ZH4407JUQ003086YP@2@a9T0T<BI00L0T<BI00<0PJV109kFY02N
eZ@03@2NeZ@00`21ZH40YMfX0:GMZ00A0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KOY@2V
gjD0502VgjD00`21ZH40X]ZP0:;JX00B0:;JX003086YP@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<
_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FRL`D0PJV1Y`2`h>H10?ooo`00ZP2`h>H3086YP@80MZF4
00<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0100YMfX
00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0D0:KOY@03086YP@2RfZ00X]ZP0180X]ZP
00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0:08boRP03086YP@1eXW<0MJ9c00@0MJ9c
0`21ZH4204eaD:T0/>3V0@3oool00:/0/>3V00<0PJV106fKO@21ZH400`21ZH4:0934V@03086YP@2N
eZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2V
gjD0Y]nU01@0Y]nU00<0PJV10:;JX02RfZ004P2RfZ000`21ZH40V]2H09[@V00>09[@V003086YP@2<
_hX0S;n:00/0S;n:00@0PJV107FRL`1eXW<0MJ9c1021ZH4204eaD003086YP@2`h>H0/>3V0:P0/>3V
0@3oool00:`0/>3V0P21ZH4206fKO@@0PJV1202@a9T00`21ZH40W]JT09kFY00<09kFY003086YP@2U
gJP0YMfX00l0YMfX00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0C0:KOY@03086YP@2R
fZ00X]ZP0140X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0:08boRPD0PJV10P1]
VVl01021ZH40CG5@04eaD021ZH6[0;3PiP40oooo002^0;3PiP06086YP@1]Vgd0KI]m06fKO@21ZH40
Q[ZB1P21ZH420934V@03086YP@2NeZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40
Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ004@2RfZ000`21ZH40
V]2H09[@V00>09[@V003086YP@2<_hX0S;n:00L0S;n:1@21ZH4406fJK`80PJV100<0CG5@086YP@2`
h>H0[02`h>H10?ooo`00[`2`h>H01@21ZH40KI]m06fKO@1]Vgd0PJV100H0Q[ZB1`21ZH4;09kFY003
086YP@2UgJP0YMfX00l0YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0C0:KOY@03
086YP@2RfZ00X]ZP0100X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP07086YP@80
Q;N600<0PJV106fJK`1]VVl00`1]VVl01021ZH40CG5@04eaD021ZH6^0;3PiP40oooo002`0;3PiP04
086YP@1]Vgd0KI]m06fKO@80PJV12026^Y800`21ZH40U/jN09K>WP08086YP@<0W]JT00<0PJV10:GM
Z02UgJP03`2UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU0180Y]nU00<0PJV10:;J
X02RfZ004@2RfZ000`21ZH40V]2H09[@V00:09[@V0P0PJV12024]hH00`21ZH40KIY_06fJK`0306fJ
K`04086YP@1=LE00PJV1086YPJl0/>3V0@3oool00;40/>3V00<0PJV106fKO@1]Vgd00P1]Vgd00`21
ZH40Q[ZB08JjTP0608JjTP03086YP@2FcYh0U/jN00L0U/jN2@21ZH4<0:GMZ003086YP@2Wh:P0Yn2X
01<0Yn2X00<0PJV10:KOY@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX00@0:;JX003086YP@2Jd9P0V]2H
0080V]2H2@21ZH4309?:U003086YP@24]hH0Q;N600P0Q;N60P21ZH4506fJK`03086YP@1=LE00PJV1
0;40/>3V0@3oool00;80/>3V00<0PJV106fKO@1]Vgd00P1]Vgd00`21ZH40Q[ZB08JjTP0608JjTP03
086YP@2FcYh0U/jN00/0U/jN00@0PJV109kHY02Nf:@0W]RT2@21ZH440:GMZ003086YP@2Wh:P0Yn2X
0180Yn2X00<0PJV10:KOY@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX0070:;JX0h0PJV12`2CbY@00`21
ZH40Q;N608BgQP0808BgQP03086YP@1]VVl0KIY_00@0KIY_00<0PJV104eaD021ZH40/P2`h>H10?oo
o`00/`2`h>H2086YP@<0KI]m00<0PJV108JjTP26^Y801P26^Y800`21ZH40U/jN09K>WP0:09K>WP03
086YP@2Nf:@0W]RT00X0W]RT>021ZH4809cEWP03086YP@2CbY@0TlZD00d0TlZD00<0PJV108BgQP24
]hH02024]hH00`21ZH40KIY_06fJK`0406fJK`<0PJV1/`2`h>H10?ooo`00]@2`h>H01@21ZH40KI]m
06fKO@1]Vgd0PJV100P0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00=09kHY003
086YP@2QfjD0XM^U0180XM^U00<0PJV10:7JX`2QfZ<04P2QfZ<00`21ZH40W=FN09cEWP0?09cEWP03
086YP@2CbY@0TlZD00d0TlZD00<0PJV108BgQP24]hH01`24]hH00`21ZH40KIY_06fJK`0306fJK`<0
PJV1]@2`h>H10?ooo`00]P2`h>H01021ZH40KI]m06fKO@1]Vgd2086YP@H0Q[ZB00<0PJV109K>WP2F
cYh02`2FcYh00`21ZH40W]RT09kHY00=09kHY003086YP@2QfjD0XM^U0140XM^U00<0PJV10:7JX`2Q
fZ<04@2QfZ<00`21ZH40W=FN09cEWP0?09cEWP03086YP@2CbY@0TlZD00d0TlZD00<0PJV108BgQP24
]hH01`24]hH00`21ZH40KIY_06fJK`0306fJK`<0PJV1]P2`h>H10?ooo`00]`2`h>H2086YP@<0KI]m
00<0PJV108JjTP26^Y801026^Y800`21ZH40U/jN09K>WP0;09K>WP03086YP@2Nf:@0W]RT00`0W]RT
00<0PJV10:7KY@2QfjD04@2QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086YP@2LeIh0W=FN00h0W=FN
00<0PJV109?:U02CbY@03@2CbY@00`21ZH40Q;N608BgQP0608BgQP80PJV11@1]VVl2086YPKP0/>3V
0@3oool00;P0/>3V1P21ZH4608JjTP03086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@03@2N
f:@00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2QfZ<0XMZS0140XMZS00<0PJV109cEWP2LeIh03P2L
eIh00`21ZH40TlZD09?:U00<09?:U003086YP@24]hH0Q;N600H0Q;N600<0PJV106fJK`1]VVl00P1]
VVl3086YPKX0/>3V0@3oool00;X0/>3V0P21ZH40101NRFl0PJV1086YP@21ZH4508JjTP03086YP@2F
cYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Q
fZ<0XMZS0140XMZS00<0PJV109cEWP2LeIh03@2LeIh00`21ZH40TlZD09?:U00<09?:U003086YP@24
]hH0Q;N600H0Q;N600<0PJV106fJK`21ZH401@21ZH6k0;3PiP40oooo002l0;3PiP80PJV100<0GXU_
086YP@21ZH400P21ZH4308JjTP03086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@0302Nf:@0
0`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2QfZ<0XMZS00l0XMZS00<0PJV109cEWP2LeIh03P2LeIh0
0`21ZH40TlZD09?:U00;09?:U003086YP@24]hH0Q;N600D0Q;N61021ZH4205n;IP80PJV1_@2`h>H1
0?ooo`00_P2`h>H2086YP@0305j9K`21ZH40PJV100D0PJV1302FcYh00`21ZH40W]RT09kHY00;09kH
Y003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<00`21ZH40W=FN09cEWP0=09cE
WP03086YP@2CbY@0TlZD00`0TlZD00@0PJV108BgQP24]hH0Q;N61@21ZH4305n;IP80PJV1_`2`h>H1
0?ooo`00`02`h>H2086YP@0305j9K`21ZH40PJV10080MJN42021ZH4509K>WP03086YP@2Nf:@0W]RT
00`0W]RT00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XMZS0:7JX`0?0:7JX`03086YP@2LeIh0W=FN
00`0W=FN00<0PJV109?:U02CbY@0302CbY@5086YP@0307FVN`21ZH40PJV100<0Gh]V0P21ZH710;3P
iP40oooo00320;3PiP80PJV100<0GXU_086YP@1eYh@00P1eYh@2086YP@@0QK^A2P21ZH4:09kHY003
086YP@2QfjD0XM^U00l0XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<00`21ZH40W=FN09cEWP0<09cEWP03
086YP@2CbY@0TlZD00@0TlZD2@21ZH4407FVN`04086YP@1ORfH0Gh]V05n;IP80PJV1``2`h>H10?oo
o`00a02`h>H4086YP@<0MJN40P21ZH4908FkT@03086YP@2>aYP0S/JH00P0PJV10`2Nf:@00`21ZH40
XM^U0:7KY@0>0:7KY@03086YP@2QfZ<0XMZS00h0XMZS00<0PJV109cEWP2LeIh01@2LeIh?086YP@D0
Q;V:0P21ZH4407FVN`80PJV10P1ORfH2086YPLD0/>3V0@3oool00<H0/>3V1021ZH4307FWQ003086Y
P@25^i40QK^A00L0QK^A00<0PJV108k6V02>aYP01`2>aYP]086YP@H0S/FC00<0PJV108BiRP24^HX0
2P24^HX00`21ZH40MJIk07FVN`0307FVN`03086YP@1ORfH0Gh]V00<0PJV1aP2`h>H10?ooo`00b@2`
h>H3086YP@80MJN40P21ZH4808FkT@03086YP@2>aYP0S/JH00X0S/JH00<0PJV109?<V`2Cc9/03@2C
c9/00`21ZH40T/^I09;;V@0=09;;V@03086YP@2>aI<0S/FC00/0S/FC00<0PJV108BiRP24^HX02@24
^HX2086YP@@0MJIk0P21ZH40101ORfH0PJV1086YP@21ZH780;3PiP40oooo003;0;3PiP<0PJV10P1e
Yh@2086YP@L0QK^A0P21ZH4;08k6V003086YP@2Cc9/0TlbK00`0TlbK00<0PJV109;;V@2BbiT03@2B
biT00`21ZH40S/FC08k5T`0:08k5T`03086YP@24^HX0Q;V:00P0Q;V:0P21ZH4407FVN`D0PJV1b`2`
h>H10?ooo`00cP2`h>H6086YP@L0QK^A00<0PJV108k6V02>aYP02@2>aYP00`21ZH40TlbK09?<V`0;
09?<V`03086YP@2BbiT0T/^I00`0T/^I00<0PJV108k5T`2>aI<02P2>aI<00`21ZH40Q;V:08BiRP08
08BiRP04086YP@1eYW/0MJIk07FVN`H0PJV1c@2`h>H10?ooo`00d@2`h>H6086YP@D0QK^A00<0PJV1
08k6V02>aYP0202>aYP00`21ZH40TlbK09?<V`0<09?<V`03086YP@2BbiT0T/^I00/0T/^I00<0PJV1
08k5T`2>aI<02@2>aI<00`21ZH40Q;V:08BiRP0708BiRPT0PJV1d02`h>H10?ooo`00d`2`h>H9086Y
P@0308FkT@21ZH40S/JH00T0S/JH00<0PJV109?<V`2Cc9/02`2Cc9/00`21ZH40T/^I09;;V@0:09;;
V@03086YP@2>aI<0S/FC00T0S/FC00<0PJV108BiRP24^HX00P24^HX<086YPM<0/>3V0@3oool00=H0
/>3V1@21ZH400`1ZVWT0PJV1086YP@06086YP@D0S/JH00<0PJV109?<V`2Cc9/02P2Cc9/00`21ZH40
T/^I09;;V@0:09;;V@03086YP@2>aI<0S/FC00<0S/FC2`21ZH4206^KM@80PJV100<0GHUW086YP@21
ZH400`21ZH7E0;3PiP40oooo003I0;3PiPD0PJV10P1ZVWT2086YP@80LjJ19@21ZH4307>VOP80PJV1
1@1[VgD2086YP@0305f9I`21ZH40PJV100<0PJV1f02`h>H10?ooo`00g@2`h>H3086YP@80JYYi0P21
ZH4707>VP@80PJV12@1h[8@00`21ZH40N:^307R[P`0807R[P`03086YP@1cYWh0LjIn00H0LjIn0P21
ZH4406^KM@L0PJV1g02`h>H10?ooo`00h02`h>H6086YP@L0LjJ10P21ZH4707R/Q003086YP@1hZh<0
N:^300L0N:^300<0PJV107>VOP1cYWh01@1cYWh2086YP@0306^KM@21ZH40PJV100D0PJV1h@2`h>H1
0?ooo`00i02`h>H?086YP@@0N:b400<0PJV107R[P`1hZh<01P1hZh<01021ZH40LjIn07>VOP1cYWh7
086YPNP0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.603 .774 .563 r
.4405 .46951 m .43989 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.47983 .5 m .48003 .46975 L .4405 .46951 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.48003 .53025 m .47983 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.48003 .46975 m .47983 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.47983 .5 m .48003 .53025 L .51997 .53025 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.51997 .53025 m .52017 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.52017 .5 m .51997 .46975 L .48003 .46975 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.51997 .46975 m .52017 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.52017 .5 m .51997 .53025 L .5595 .53049 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.5595 .53049 m .56011 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.44233 .43937 m .4405 .46951 L .48003 .46975 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.48003 .46975 m .48064 .43983 L .44233 .43937 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.43989 .5 m .4405 .53049 L .48003 .53025 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.48064 .56017 m .48003 .53025 L .4405 .53049 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.48064 .43983 m .48003 .46975 L .51997 .46975 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.51997 .46975 m .51936 .43983 L .48064 .43983 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.48003 .53025 m .48064 .56017 L .51936 .56017 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.51936 .56017 m .51997 .53025 L .48003 .53025 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.51936 .43983 m .51997 .46975 L .5595 .46951 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.56011 .5 m .5595 .46951 L .51997 .46975 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.51997 .53025 m .51936 .56017 L .55767 .56063 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.55767 .56063 m .5595 .53049 L .51997 .53025 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50942 .56119 m
.5118 .56017 L
s
.50942 .56119 m
.5053 .56468 L
s
.47456 .55948 m
.47967 .55945 L
s
.4824 .56017 m
.48484 .56121 L
s
.52136 .56019 m
.52374 .56126 L
s
.48899 .56469 m
.48484 .56121 L
s
.47055 .56131 m
.47456 .55948 L
s
.5 Mabswid
.592 .761 .549 r
.40219 .46902 m .40117 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.43989 .5 m .4405 .46951 L .40219 .46902 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.4405 .53049 m .43989 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.5595 .46951 m .56011 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.56011 .5 m .5595 .53049 L .59781 .53098 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.59781 .53098 m .59883 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.44539 .40995 m .44233 .43937 L .48064 .43983 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.48064 .43983 m .48166 .41061 L .44539 .40995 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.4405 .53049 m .44233 .56063 L .48064 .56017 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.48166 .58939 m .48064 .56017 L .44233 .56063 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.48166 .41061 m .48064 .43983 L .51936 .43983 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.48064 .56017 m .48166 .58939 L .51834 .58939 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.48899 .56469 m
.49019 .56757 L
s
.5 Mabswid
.553 .696 .505 r
.51834 .58939 m .51936 .56017 L .48064 .56017 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50502 .59207 m
.50505 .58939 L
s
.5 Mabswid
.635 .826 .607 r
.51936 .43983 m .51834 .41061 L .48166 .41061 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.51834 .41061 m .51936 .43983 L .55767 .43937 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.5595 .46951 m .55767 .43937 L .51936 .43983 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.51936 .56017 m .51834 .58939 L .55461 .59005 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.55461 .59005 m .55767 .56063 L .51936 .56017 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.40525 .43843 m .40219 .46902 L .4405 .46951 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.4405 .46951 m .44233 .43937 L .40525 .43843 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.40117 .5 m .40219 .53098 L .4405 .53049 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.44233 .56063 m .4405 .53049 L .40219 .53098 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.55767 .43937 m .5595 .46951 L .59781 .46902 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.59883 .5 m .59781 .46902 L .5595 .46951 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.5595 .53049 m .55767 .56063 L .59475 .56157 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.59475 .56157 m .59781 .53098 L .5595 .53049 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44009 .55994 m
.44137 .55992 L
s
.55786 .56064 m
.56015 .56175 L
s
.5 Mabswid
.62 .806 .585 r
.41034 .40863 m .40525 .43843 L .44233 .43937 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.44233 .43937 m .44539 .40995 L .41034 .40863 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.40219 .53098 m .40525 .56157 L .44233 .56063 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.44539 .59005 m .44233 .56063 L .40525 .56157 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.44233 .56063 m .44539 .59005 L .48166 .58939 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.55767 .43937 m .55461 .40995 L .51834 .41061 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.55461 .40995 m .55767 .43937 L .59475 .43843 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.59781 .46902 m .59475 .43843 L .55767 .43937 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.55767 .56063 m .55461 .59005 L .58966 .59137 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.58966 .59137 m .59475 .56157 L .55767 .56063 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.44966 .38165 m .44539 .40995 L .48166 .41061 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.48166 .41061 m .48309 .38245 L .44966 .38165 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.48309 .61755 m .48166 .58939 L .44539 .59005 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.48309 .38245 m .48166 .41061 L .51834 .41061 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.51834 .41061 m .51691 .38245 L .48309 .38245 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.48166 .58939 m .48309 .61755 L .51691 .61755 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.51691 .61755 m .51834 .58939 L .48166 .58939 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.51691 .38245 m .51834 .41061 L .55461 .40995 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.51834 .58939 m .51691 .61755 L .55034 .61835 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.55034 .61835 m .55461 .59005 L .51834 .58939 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.36601 .46829 m .36459 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.40117 .5 m .40219 .46902 L .36601 .46829 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.40219 .53098 m .40117 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.59781 .46902 m .59883 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.59883 .5 m .59781 .53098 L .63399 .53171 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.63399 .53171 m .63541 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.3703 .43702 m .36601 .46829 L .40219 .46902 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.40219 .46902 m .40525 .43843 L .3703 .43702 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.36459 .5 m .36601 .53171 L .40219 .53098 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.40525 .56157 m .40219 .53098 L .36601 .53171 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.59475 .43843 m .59781 .46902 L .63399 .46829 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.63541 .5 m .63399 .46829 L .59781 .46902 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.59781 .53098 m .59475 .56157 L .6297 .56298 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.6297 .56298 m .63399 .53171 L .59781 .53098 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.41746 .38006 m .41034 .40863 L .44539 .40995 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.44539 .40995 m .44966 .38165 L .41746 .38006 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.55461 .40995 m .55034 .38165 L .51691 .38245 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.55034 .38165 m .55461 .40995 L .58966 .40863 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.59475 .43843 m .58966 .40863 L .55461 .40995 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.40525 .56157 m .41034 .59137 L .44539 .59005 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.44966 .61835 m .44539 .59005 L .41034 .59137 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.44539 .59005 m .44966 .61835 L .48309 .61755 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.55461 .59005 m .55034 .61835 L .58254 .61994 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.58254 .61994 m .58966 .59137 L .55461 .59005 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.37741 .40665 m .3703 .43702 L .40525 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.40525 .43843 m .41034 .40863 L .37741 .40665 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.36601 .53171 m .3703 .56298 L .40525 .56157 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.41034 .59137 m .40525 .56157 L .3703 .56298 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.58966 .40863 m .59475 .43843 L .6297 .43702 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.63399 .46829 m .6297 .43702 L .59475 .43843 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.59475 .56157 m .58966 .59137 L .62259 .59335 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.62259 .59335 m .6297 .56298 L .59475 .56157 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.45516 .35491 m .44966 .38165 L .48309 .38245 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.48309 .38245 m .48493 .35578 L .45516 .35491 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.48493 .64422 m .48309 .61755 L .44966 .61835 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.48493 .35578 m .48309 .38245 L .51691 .38245 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.51691 .38245 m .51507 .35578 L .48493 .35578 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.48309 .61755 m .48493 .64422 L .51507 .64422 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.51507 .64422 m .51691 .61755 L .48309 .61755 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.51507 .35578 m .51691 .38245 L .55034 .38165 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.51691 .61755 m .51507 .64422 L .54484 .64509 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.54484 .64509 m .55034 .61835 L .51691 .61755 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.38734 .37767 m .37741 .40665 L .41034 .40863 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.41034 .40863 m .41746 .38006 L .38734 .37767 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.3703 .56298 m .37741 .59335 L .41034 .59137 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.41746 .61994 m .41034 .59137 L .37741 .59335 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.41034 .59137 m .41746 .61994 L .44966 .61835 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.58966 .40863 m .58254 .38006 L .55034 .38165 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.58254 .38006 m .58966 .40863 L .62259 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.6297 .43702 m .62259 .40665 L .58966 .40863 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.58966 .59137 m .58254 .61994 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.61266 .62233 m .62259 .59335 L .58966 .59137 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.42658 .35317 m .41746 .38006 L .44966 .38165 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.44966 .38165 m .45516 .35491 L .42658 .35317 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.45516 .64509 m .44966 .61835 L .41746 .61994 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.44966 .61835 m .45516 .64509 L .48493 .64422 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.55034 .38165 m .54484 .35491 L .51507 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.54484 .35491 m .55034 .38165 L .58254 .38006 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.55034 .61835 m .54484 .64509 L .57342 .64683 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.57342 .64683 m .58254 .61994 L .55034 .61835 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.63399 .46829 m .63541 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.63541 .5 m .63399 .53171 L .66699 .53269 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.66699 .53269 m .66882 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.33301 .46731 m .33118 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.36459 .5 m .36601 .46829 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.36601 .53171 m .36459 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.6297 .43702 m .63399 .46829 L .66699 .46731 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.66882 .5 m .66699 .46731 L .63399 .46829 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.63399 .53171 m .6297 .56298 L .66149 .56486 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.66149 .56486 m .66699 .53269 L .63399 .53171 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.33851 .43514 m .33301 .46731 L .36601 .46829 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.36601 .46829 m .3703 .43702 L .33851 .43514 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.33118 .5 m .33301 .53269 L .36601 .53171 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.3703 .56298 m .36601 .53171 L .33301 .53269 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.62259 .40665 m .6297 .43702 L .66149 .43514 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.66699 .46731 m .66149 .43514 L .6297 .43702 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.6297 .56298 m .62259 .59335 L .65238 .59597 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.65238 .59597 m .66149 .56486 L .6297 .56298 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.34762 .40403 m .33851 .43514 L .3703 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.3703 .43702 m .37741 .40665 L .34762 .40403 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.33301 .53269 m .33851 .56486 L .3703 .56298 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.37741 .59335 m .3703 .56298 L .33851 .56486 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.46188 .3302 m .45516 .35491 L .48493 .35578 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.48493 .35578 m .48717 .33107 L .46188 .3302 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.48717 .33107 m .48493 .35578 L .51507 .35578 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.51507 .35578 m .51283 .33107 L .48717 .33107 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.51283 .33107 m .51507 .35578 L .54484 .35491 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.48717 .66893 m .48493 .64422 L .45516 .64509 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.48493 .64422 m .48717 .66893 L .51283 .66893 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.51283 .66893 m .51507 .64422 L .48493 .64422 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.51507 .64422 m .51283 .66893 L .53812 .6698 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.53812 .6698 m .54484 .64509 L .51507 .64422 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.40002 .35058 m .38734 .37767 L .41746 .38006 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.41746 .38006 m .42658 .35317 L .40002 .35058 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.37741 .59335 m .38734 .62233 L .41746 .61994 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.42658 .64683 m .41746 .61994 L .38734 .62233 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.41746 .61994 m .42658 .64683 L .45516 .64509 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.58254 .38006 m .57342 .35317 L .54484 .35491 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.57342 .35317 m .58254 .38006 L .61266 .37767 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.62259 .40665 m .61266 .37767 L .58254 .38006 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.58254 .61994 m .57342 .64683 L .59998 .64942 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.59998 .64942 m .61266 .62233 L .58254 .61994 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.43769 .32847 m .42658 .35317 L .45516 .35491 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.45516 .35491 m .46188 .3302 L .43769 .32847 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.54484 .35491 m .53812 .3302 L .51283 .33107 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.53812 .3302 m .54484 .35491 L .57342 .35317 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.46188 .6698 m .45516 .64509 L .42658 .64683 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.45516 .64509 m .46188 .6698 L .48717 .66893 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.54484 .64509 m .53812 .6698 L .56231 .67153 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.56231 .67153 m .57342 .64683 L .54484 .64509 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.61266 .37767 m .62259 .40665 L .65238 .40403 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.66149 .43514 m .65238 .40403 L .62259 .40665 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.62259 .59335 m .61266 .62233 L .63973 .62548 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.63973 .62548 m .65238 .59597 L .62259 .59335 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.36027 .37452 m .34762 .40403 L .37741 .40665 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.37741 .40665 m .38734 .37767 L .36027 .37452 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.33851 .56486 m .34762 .59597 L .37741 .59335 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.38734 .62233 m .37741 .59335 L .34762 .59597 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.41536 .32591 m .40002 .35058 L .42658 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.42658 .35317 m .43769 .32847 L .41536 .32591 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.38734 .62233 m .40002 .64942 L .42658 .64683 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.43769 .67153 m .42658 .64683 L .40002 .64942 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.42658 .64683 m .43769 .67153 L .46188 .6698 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.57342 .35317 m .56231 .32847 L .53812 .3302 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.56231 .32847 m .57342 .35317 L .59998 .35058 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.61266 .37767 m .59998 .35058 L .57342 .35317 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.57342 .64683 m .56231 .67153 L .58464 .67409 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.58464 .67409 m .59998 .64942 L .57342 .64683 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.59998 .35058 m .61266 .37767 L .63973 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.65238 .40403 m .63973 .37452 L .61266 .37767 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.61266 .62233 m .59998 .64942 L .62364 .65283 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.62364 .65283 m .63973 .62548 L .61266 .62233 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.37636 .34717 m .36027 .37452 L .38734 .37767 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.38734 .37767 m .40002 .35058 L .37636 .34717 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.34762 .59597 m .36027 .62548 L .38734 .62233 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.40002 .64942 m .38734 .62233 L .36027 .62548 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.66699 .46731 m .66882 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.66882 .5 m .66699 .53269 L .69558 .53391 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.69558 .53391 m .69782 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.30442 .46609 m .30218 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.33118 .5 m .33301 .46731 L .30442 .46609 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.33301 .53269 m .33118 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.46978 .30806 m .46188 .3302 L .48717 .33107 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.48717 .33107 m .48982 .30885 L .46978 .30806 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.48982 .30885 m .48717 .33107 L .51283 .33107 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.48982 .69115 m .48717 .66893 L .46188 .6698 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.51283 .33107 m .51018 .30885 L .48982 .30885 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.48717 .66893 m .48982 .69115 L .51018 .69115 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.51018 .69115 m .51283 .66893 L .48717 .66893 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.51018 .30885 m .51283 .33107 L .53812 .3302 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.51283 .66893 m .51018 .69115 L .53022 .69194 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.53022 .69194 m .53812 .6698 L .51283 .66893 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.66149 .43514 m .66699 .46731 L .69558 .46609 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.69782 .5 m .69558 .46609 L .66699 .46731 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.66699 .53269 m .66149 .56486 L .68892 .56719 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.68892 .56719 m .69558 .53391 L .66699 .53269 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.31108 .43281 m .30442 .46609 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.33301 .46731 m .33851 .43514 L .31108 .43281 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.30218 .5 m .30442 .53391 L .33301 .53269 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.33851 .56486 m .33301 .53269 L .30442 .53391 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.65238 .40403 m .66149 .43514 L .68892 .43281 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.69558 .46609 m .68892 .43281 L .66149 .43514 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.66149 .56486 m .65238 .59597 L .6779 .59922 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.6779 .59922 m .68892 .56719 L .66149 .56486 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.3221 .40078 m .31108 .43281 L .33851 .43514 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.33851 .43514 m .34762 .40403 L .3221 .40078 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.45071 .30652 m .43769 .32847 L .46188 .3302 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.46188 .3302 m .46978 .30806 L .45071 .30652 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.53812 .3302 m .53022 .30806 L .51018 .30885 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.53022 .30806 m .53812 .3302 L .56231 .32847 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.30442 .53391 m .31108 .56719 L .33851 .56486 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.34762 .59597 m .33851 .56486 L .31108 .56719 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.53812 .6698 m .53022 .69194 L .54929 .69348 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.54929 .69348 m .56231 .67153 L .53812 .6698 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.46978 .69194 m .46188 .6698 L .43769 .67153 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.46188 .6698 m .46978 .69194 L .48982 .69115 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.59998 .35058 m .58464 .32591 L .56231 .32847 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.58464 .32591 m .59998 .35058 L .62364 .34717 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.63973 .37452 m .62364 .34717 L .59998 .35058 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.59998 .64942 m .58464 .67409 L .6043 .67744 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.6043 .67744 m .62364 .65283 L .59998 .64942 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.3957 .32256 m .37636 .34717 L .40002 .35058 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.40002 .35058 m .41536 .32591 L .3957 .32256 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.36027 .62548 m .37636 .65283 L .40002 .64942 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.41536 .67409 m .40002 .64942 L .37636 .65283 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.40002 .64942 m .41536 .67409 L .43769 .67153 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.63973 .37452 m .65238 .40403 L .6779 .40078 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.68892 .43281 m .6779 .40078 L .65238 .40403 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.65238 .59597 m .63973 .62548 L .66267 .62937 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.66267 .62937 m .6779 .59922 L .65238 .59597 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.33733 .37063 m .3221 .40078 L .34762 .40403 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.34762 .40403 m .36027 .37452 L .33733 .37063 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.31108 .56719 m .3221 .59922 L .34762 .59597 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.36027 .62548 m .34762 .59597 L .3221 .59922 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43326 .30424 m .41536 .32591 L .43769 .32847 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43769 .32847 m .45071 .30652 L .43326 .30424 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.45071 .69348 m .43769 .67153 L .41536 .67409 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.43769 .67153 m .45071 .69348 L .46978 .69194 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.56231 .32847 m .54929 .30652 L .53022 .30806 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.54929 .30652 m .56231 .32847 L .58464 .32591 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56231 .67153 m .54929 .69348 L .56674 .69576 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56674 .69576 m .58464 .67409 L .56231 .67153 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.62364 .34717 m .63973 .37452 L .66267 .37063 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.6779 .40078 m .66267 .37063 L .63973 .37452 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.63973 .62548 m .62364 .65283 L .64343 .65701 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.64343 .65701 m .66267 .62937 L .63973 .62548 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.35657 .34299 m .33733 .37063 L .36027 .37452 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.36027 .37452 m .37636 .34717 L .35657 .34299 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.3221 .59922 m .33733 .62937 L .36027 .62548 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.37636 .65283 m .36027 .62548 L .33733 .62937 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.47883 .28911 m .46978 .30806 L .48982 .30885 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.48982 .30885 m .49286 .28971 L .47883 .28911 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.49286 .28971 m .48982 .30885 L .51018 .30885 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.51018 .30885 m .50714 .28971 L .49286 .28971 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50714 .28971 m .51018 .30885 L .53022 .30806 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.49286 .71029 m .48982 .69115 L .46978 .69194 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.48982 .69115 m .49286 .71029 L .50714 .71029 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.50714 .71029 m .51018 .69115 L .48982 .69115 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.51018 .69115 m .50714 .71029 L .52117 .71089 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.52117 .71089 m .53022 .69194 L .51018 .69115 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.58464 .32591 m .56674 .30424 L .54929 .30652 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.56674 .30424 m .58464 .32591 L .6043 .32256 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.62364 .34717 m .6043 .32256 L .58464 .32591 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58464 .67409 m .56674 .69576 L .58191 .69872 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58191 .69872 m .6043 .67744 L .58464 .67409 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41809 .30128 m .3957 .32256 L .41536 .32591 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41536 .32591 m .43326 .30424 L .41809 .30128 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.37636 .65283 m .3957 .67744 L .41536 .67409 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.43326 .69576 m .41536 .67409 L .3957 .67744 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.41536 .67409 m .43326 .69576 L .45071 .69348 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46555 .28792 m .45071 .30652 L .46978 .30806 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46978 .30806 m .47883 .28911 L .46555 .28792 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.53022 .30806 m .52117 .28911 L .50714 .28971 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.52117 .28911 m .53022 .30806 L .54929 .30652 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.47883 .71089 m .46978 .69194 L .45071 .69348 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.46978 .69194 m .47883 .71089 L .49286 .71029 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53022 .69194 m .52117 .71089 L .53445 .71208 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53445 .71208 m .54929 .69348 L .53022 .69194 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.6043 .32256 m .62364 .34717 L .64343 .34299 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.66267 .37063 m .64343 .34299 L .62364 .34717 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62364 .65283 m .6043 .67744 L .62048 .68151 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62048 .68151 m .64343 .65701 L .62364 .65283 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37952 .31849 m .35657 .34299 L .37636 .34717 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37636 .34717 m .3957 .32256 L .37952 .31849 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.33733 .62937 m .35657 .65701 L .37636 .65283 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.3957 .67744 m .37636 .65283 L .35657 .65701 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.69558 .46609 m .69782 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.69782 .5 m .69558 .53391 L .71834 .53535 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.71834 .53535 m .72094 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.28166 .46465 m .27906 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.30218 .5 m .30442 .46609 L .28166 .46465 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.30442 .53391 m .30218 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.68892 .43281 m .69558 .46609 L .71834 .46465 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.72094 .5 m .71834 .46465 L .69558 .46609 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.69558 .53391 m .68892 .56719 L .71059 .56996 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68908 .56721 m
.69023 .56842 L
s
.5 Mabswid
.452 .57 .444 r
.71059 .56996 m .71834 .53535 L .69558 .53391 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.28941 .43004 m .28166 .46465 L .30442 .46609 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.30442 .46609 m .31108 .43281 L .28941 .43004 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.27906 .5 m .28166 .53535 L .30442 .53391 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.31108 .56719 m .30442 .53391 L .28166 .53535 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45351 .28618 m .43326 .30424 L .45071 .30652 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45071 .30652 m .46555 .28792 L .45351 .28618 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.46555 .71208 m .45071 .69348 L .43326 .69576 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.45071 .69348 m .46555 .71208 L .47883 .71089 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.54929 .30652 m .53445 .28792 L .52117 .28911 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.53445 .28792 m .54929 .30652 L .56674 .30424 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54929 .69348 m .53445 .71208 L .54649 .71382 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54649 .71382 m .56674 .69576 L .54929 .69348 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.68892 .56719 m .6779 .59922 L .69784 .60305 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.69784 .60305 m .71059 .56996 L .68892 .56719 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.6779 .40078 m .68892 .43281 L .71059 .43004 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.71834 .46465 m .71059 .43004 L .68892 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.30216 .39695 m .28941 .43004 L .31108 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.31108 .43281 m .3221 .40078 L .30216 .39695 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.28166 .53535 m .28941 .56996 L .31108 .56719 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.3221 .59922 m .31108 .56719 L .28941 .56996 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.66267 .37063 m .6779 .40078 L .69784 .39695 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.71059 .43004 m .69784 .39695 L .6779 .40078 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6779 .59922 m .66267 .62937 L .6803 .63392 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6803 .63392 m .69784 .60305 L .6779 .59922 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3197 .36608 m .30216 .39695 L .3221 .40078 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3221 .40078 m .33733 .37063 L .3197 .36608 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.28941 .56996 m .30216 .60305 L .3221 .59922 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.33733 .62937 m .3221 .59922 L .30216 .60305 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.6043 .32256 m .58191 .30128 L .56674 .30424 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.58191 .30128 m .6043 .32256 L .62048 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.64343 .34299 m .62048 .31849 L .6043 .32256 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.6043 .67744 m .58191 .69872 L .59416 .70228 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.59416 .70228 m .62048 .68151 L .6043 .67744 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.40584 .29772 m .37952 .31849 L .3957 .32256 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.3957 .32256 m .41809 .30128 L .40584 .29772 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.35657 .65701 m .37952 .68151 L .3957 .67744 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.41809 .69872 m .3957 .67744 L .37952 .68151 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.3957 .67744 m .41809 .69872 L .43326 .69576 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.56674 .30424 m .54649 .28618 L .53445 .28792 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.54649 .28618 m .56674 .30424 L .58191 .30128 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.56674 .69576 m .54649 .71382 L .55679 .71606 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.55679 .71606 m .58191 .69872 L .56674 .69576 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.44321 .28394 m .41809 .30128 L .43326 .30424 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.43326 .30424 m .45351 .28618 L .44321 .28394 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.45351 .71382 m .43326 .69576 L .41809 .69872 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.43326 .69576 m .45351 .71382 L .46555 .71208 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.64343 .34299 m .66267 .37063 L .6803 .36608 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.69784 .39695 m .6803 .36608 L .66267 .37063 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.66267 .62937 m .64343 .65701 L .65832 .66186 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.65832 .66186 m .6803 .63392 L .66267 .62937 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.34168 .33814 m .3197 .36608 L .33733 .37063 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.33733 .37063 m .35657 .34299 L .34168 .33814 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.30216 .60305 m .3197 .63392 L .33733 .62937 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.35657 .65701 m .33733 .62937 L .3197 .63392 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.48894 .274 m .47883 .28911 L .49286 .28971 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.49286 .28971 m .49626 .27434 L .48894 .274 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.49626 .27434 m .49286 .28971 L .50714 .28971 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.50714 .28971 m .50374 .27434 L .49626 .27434 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50374 .27434 m .50714 .28971 L .52117 .28911 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.49626 .72566 m .49286 .71029 L .47883 .71089 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.49286 .71029 m .49626 .72566 L .50374 .72566 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.50374 .72566 m .50714 .71029 L .49286 .71029 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.50714 .71029 m .50374 .72566 L .51106 .726 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.51106 .726 m .52117 .71089 L .50714 .71029 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.48205 .27334 m .46555 .28792 L .47883 .28911 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.47883 .28911 m .48894 .274 L .48205 .27334 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.52117 .28911 m .51106 .274 L .50374 .27434 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.51106 .274 m .52117 .28911 L .53445 .28792 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.48894 .726 m .47883 .71089 L .46555 .71208 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.47883 .71089 m .48894 .726 L .49626 .72566 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.52117 .71089 m .51106 .726 L .51795 .72666 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.51795 .72666 m .53445 .71208 L .52117 .71089 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.62048 .31849 m .64343 .34299 L .65832 .33814 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.6803 .36608 m .65832 .33814 L .64343 .34299 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.64343 .65701 m .62048 .68151 L .63233 .6862 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.63233 .6862 m .65832 .66186 L .64343 .65701 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.36767 .3138 m .34168 .33814 L .35657 .34299 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.35657 .34299 m .37952 .31849 L .36767 .3138 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.3197 .63392 m .34168 .66186 L .35657 .65701 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.37952 .68151 m .35657 .65701 L .34168 .66186 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.47588 .27237 m .45351 .28618 L .46555 .28792 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.46555 .28792 m .48205 .27334 L .47588 .27237 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.48205 .72666 m .46555 .71208 L .45351 .71382 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.46555 .71208 m .48205 .72666 L .48894 .726 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.53445 .28792 m .51795 .27334 L .51106 .274 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.51795 .27334 m .53445 .28792 L .54649 .28618 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.53445 .71208 m .51795 .72666 L .52412 .72763 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.52412 .72763 m .54649 .71382 L .53445 .71208 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.58191 .30128 m .55679 .28394 L .54649 .28618 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.55679 .28394 m .58191 .30128 L .59416 .29772 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.62048 .31849 m .59416 .29772 L .58191 .30128 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.58191 .69872 m .55679 .71606 L .56492 .71873 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.56492 .71873 m .59416 .70228 L .58191 .69872 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.43508 .28127 m .40584 .29772 L .41809 .30128 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.41809 .30128 m .44321 .28394 L .43508 .28127 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.37952 .68151 m .40584 .70228 L .41809 .69872 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.44321 .71606 m .41809 .69872 L .40584 .70228 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.41809 .69872 m .44321 .71606 L .45351 .71382 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.59416 .29772 m .62048 .31849 L .63233 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.65832 .33814 m .63233 .3138 L .62048 .31849 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.62048 .68151 m .59416 .70228 L .60284 .70634 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.60284 .70634 m .63233 .6862 L .62048 .68151 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.39716 .29366 m .36767 .3138 L .37952 .31849 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.37952 .31849 m .40584 .29772 L .39716 .29366 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.34168 .66186 m .36767 .6862 L .37952 .68151 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.40584 .70228 m .37952 .68151 L .36767 .6862 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.54649 .28618 m .52412 .27237 L .51795 .27334 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.52412 .27237 m .54649 .28618 L .55679 .28394 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.54649 .71382 m .52412 .72763 L .52932 .72886 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.52932 .72886 m .55679 .71606 L .54649 .71382 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.47068 .27114 m .44321 .28394 L .45351 .28618 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.45351 .28618 m .47588 .27237 L .47068 .27114 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.47588 .72763 m .45351 .71382 L .44321 .71606 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.45351 .71382 m .47588 .72763 L .48205 .72666 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.71834 .46465 m .72094 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.72094 .5 m .71834 .53535 L .73364 .53701 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.73364 .53701 m .73655 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.26636 .46299 m .26345 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.27906 .5 m .28166 .46465 L .26636 .46299 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.28166 .53535 m .27906 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.71059 .43004 m .71834 .46465 L .73364 .46299 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.73655 .5 m .73364 .46299 L .71834 .46465 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.71834 .53535 m .71059 .56996 L .72498 .5731 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.72498 .5731 m .73364 .53701 L .71834 .53535 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.27502 .4269 m .26636 .46299 L .28166 .46465 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.28166 .46465 m .28941 .43004 L .27502 .4269 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.26345 .5 m .26636 .53701 L .28166 .53535 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.28941 .56996 m .28166 .53535 L .26636 .53701 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.69784 .39695 m .71059 .43004 L .72498 .4269 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.73364 .46299 m .72498 .4269 L .71059 .43004 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71059 .56996 m .69784 .60305 L .71077 .60739 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71077 .60739 m .72498 .5731 L .71059 .56996 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28923 .39261 m .27502 .4269 L .28941 .43004 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28941 .43004 m .30216 .39695 L .28923 .39261 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.26636 .53701 m .27502 .5731 L .28941 .56996 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.30216 .60305 m .28941 .56996 L .27502 .5731 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.6803 .36608 m .69784 .39695 L .71077 .39261 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.72498 .4269 m .71077 .39261 L .69784 .39695 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69784 .60305 m .6803 .63392 L .69138 .63904 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69138 .63904 m .71077 .60739 L .69784 .60305 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30862 .36096 m .28923 .39261 L .30216 .39695 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30216 .39695 m .3197 .36608 L .30862 .36096 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.27502 .5731 m .28923 .60739 L .30216 .60305 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.3197 .63392 m .30216 .60305 L .28923 .60739 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.59416 .29772 m .56492 .28127 L .55679 .28394 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.56492 .28127 m .59416 .29772 L .60284 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.63233 .3138 m .60284 .29366 L .59416 .29772 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.59416 .70228 m .56492 .71873 L .57047 .72174 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.57047 .72174 m .60284 .70634 L .59416 .70228 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.42953 .27826 m .39716 .29366 L .40584 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.40584 .29772 m .43508 .28127 L .42953 .27826 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.36767 .6862 m .39716 .70634 L .40584 .70228 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.43508 .71873 m .40584 .70228 L .39716 .70634 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.40584 .70228 m .43508 .71873 L .44321 .71606 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.55679 .28394 m .52932 .27114 L .52412 .27237 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.52932 .27114 m .55679 .28394 L .56492 .28127 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.55679 .71606 m .52932 .72886 L .53332 .73031 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.53332 .73031 m .56492 .71873 L .55679 .71606 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.46668 .26969 m .43508 .28127 L .44321 .28394 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.44321 .28394 m .47068 .27114 L .46668 .26969 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.47068 .72886 m .44321 .71606 L .43508 .71873 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.44321 .71606 m .47068 .72886 L .47588 .72763 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.65832 .33814 m .6803 .36608 L .69138 .36096 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.71077 .39261 m .69138 .36096 L .6803 .36608 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.6803 .63392 m .65832 .66186 L .66727 .66727 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.66727 .66727 m .69138 .63904 L .6803 .63392 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.33273 .33273 m .30862 .36096 L .3197 .36608 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.3197 .36608 m .34168 .33814 L .33273 .33273 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.28923 .60739 m .30862 .63904 L .3197 .63392 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.34168 .66186 m .3197 .63392 L .30862 .63904 L p F P
.505 .664 .505 r
s
.554 .773 .585 r
.49626 .27434 m .5 .26345 L .48894 .274 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50374 .27434 m .5 .26345 L .49626 .27434 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.51106 .274 m .5 .26345 L .50374 .27434 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49626 .72566 L .48894 .726 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50374 .72566 L .49626 .72566 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .51106 .726 L .50374 .72566 L closepath p F P
.505 .664 .505 r
s
.551 .769 .581 r
.48894 .274 m .5 .26345 L .48205 .27334 L closepath p F P
.505 .664 .505 r
s
.554 .773 .586 r
.51795 .27334 m .5 .26345 L .51106 .274 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48894 .726 L .48205 .72666 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .51795 .72666 L .51106 .726 L closepath p F P
.505 .664 .505 r
s
.527 .725 .572 r
.63233 .3138 m .65832 .33814 L .66727 .33273 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.69138 .36096 m .66727 .33273 L .65832 .33814 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.65832 .66186 m .63233 .6862 L .63904 .69138 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.63904 .69138 m .66727 .66727 L .65832 .66186 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.36096 .30862 m .33273 .33273 L .34168 .33814 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.34168 .33814 m .36767 .3138 L .36096 .30862 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.30862 .63904 m .33273 .66727 L .34168 .66186 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.36767 .6862 m .34168 .66186 L .33273 .66727 L p F P
.505 .664 .505 r
s
.546 .763 .576 r
.48205 .27334 m .5 .26345 L .47588 .27237 L closepath p F P
.505 .664 .505 r
s
.55 .768 .584 r
.52412 .27237 m .5 .26345 L .51795 .27334 L closepath p F P
.505 .664 .505 r
s
.198 .204 .155 r
.5 .73655 m .48205 .72666 L .47588 .72763 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .52412 .72763 L .51795 .72666 L closepath p F P
.505 .664 .505 r
s
.578 .8 .612 r
.56492 .28127 m .53332 .26969 L .52932 .27114 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.53332 .26969 m .56492 .28127 L .57047 .27826 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.60284 .29366 m .57047 .27826 L .56492 .28127 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.56492 .71873 m .53332 .73031 L .53593 .73193 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.53593 .73193 m .57047 .72174 L .56492 .71873 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.46407 .26807 m .42953 .27826 L .43508 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.43508 .28127 m .46668 .26969 L .46407 .26807 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.39716 .70634 m .42953 .72174 L .43508 .71873 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.46668 .73031 m .43508 .71873 L .42953 .72174 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.43508 .71873 m .46668 .73031 L .47068 .72886 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.60284 .29366 m .63233 .3138 L .63904 .30862 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.66727 .33273 m .63904 .30862 L .63233 .3138 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.63233 .6862 m .60284 .70634 L .60739 .71077 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.60739 .71077 m .63904 .69138 L .63233 .6862 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.39261 .28923 m .36096 .30862 L .36767 .3138 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.36767 .3138 m .39716 .29366 L .39261 .28923 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.33273 .66727 m .36096 .69138 L .36767 .6862 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.39716 .70634 m .36767 .6862 L .36096 .69138 L p F P
.505 .664 .505 r
s
.545 .762 .58 r
.52932 .27114 m .5 .26345 L .52412 .27237 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .52932 .72886 L .52412 .72763 L closepath p F P
.505 .664 .505 r
s
.539 .755 .57 r
.47588 .27237 m .5 .26345 L .47068 .27114 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .47588 .72763 L .47068 .72886 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72317 .57747 m
.72632 .57199 L
s
.5 Mabswid
.535 .747 .581 r
.57047 .27826 m .60284 .29366 L .60739 .28923 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.63904 .30862 m .60739 .28923 L .60284 .29366 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.60284 .70634 m .57047 .72174 L .5731 .72498 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.5731 .72498 m .60739 .71077 L .60284 .70634 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.4269 .27502 m .39261 .28923 L .39716 .29366 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.39716 .29366 m .42953 .27826 L .4269 .27502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.36096 .69138 m .39261 .71077 L .39716 .70634 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42953 .72174 m .39716 .70634 L .39261 .71077 L p F P
.505 .664 .505 r
s
.537 .753 .575 r
.53332 .26969 m .5 .26345 L .52932 .27114 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .53332 .73031 L .52932 .72886 L closepath p F P
.505 .664 .505 r
s
.531 .745 .563 r
.47068 .27114 m .5 .26345 L .46668 .26969 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .47068 .72886 L .46668 .73031 L closepath p F P
.505 .664 .505 r
s
.557 .776 .596 r
.57047 .27826 m .53593 .26807 L .53332 .26969 L p F P
.505 .664 .505 r
s
.53 .744 .575 r
.53593 .26807 m .57047 .27826 L .5731 .27502 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.60739 .28923 m .5731 .27502 L .57047 .27826 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57047 .72174 m .53593 .73193 L .53701 .73364 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.53701 .73364 m .5731 .72498 L .57047 .72174 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.46299 .26636 m .4269 .27502 L .42953 .27826 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.42953 .27826 m .46407 .26807 L .46299 .26636 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.39261 .71077 m .4269 .72498 L .42953 .72174 L p F P
.505 .664 .505 r
s
.187 .194 .147 r
.46407 .73193 m .42953 .72174 L .4269 .72498 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.42953 .72174 m .46407 .73193 L .46668 .73031 L p F P
.505 .664 .505 r
s
.529 .743 .568 r
.53593 .26807 m .5 .26345 L .53332 .26969 L closepath p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .53593 .73193 L .53332 .73031 L closepath p F P
.505 .664 .505 r
s
.522 .734 .555 r
.46668 .26969 m .5 .26345 L .46407 .26807 L closepath p F P
.505 .664 .505 r
s
.183 .191 .145 r
.5 .73655 m .46668 .73031 L .46407 .73193 L closepath p F P
.505 .664 .505 r
s
.519 .731 .56 r
.53701 .26636 m .5 .26345 L .53593 .26807 L closepath p F P
.505 .664 .505 r
s
.53 .744 .575 r
.5731 .27502 m .53701 .26636 L .53593 .26807 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .53701 .73364 L .53593 .73193 L closepath p F P
.505 .664 .505 r
s
.512 .722 .546 r
.46407 .26807 m .5 .26345 L .46299 .26636 L closepath p F P
.505 .664 .505 r
s
.187 .194 .147 r
.4269 .72498 m .46299 .73364 L .46407 .73193 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.5 .73655 m .46407 .73193 L .46299 .73364 L closepath p F P
.505 .664 .505 r
s
.404 .566 .463 r
.66727 .33273 m .69138 .36096 L .69463 .35543 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.69138 .36096 m .71077 .39261 L .71523 .38789 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.71523 .38789 m .69463 .35543 L .69138 .36096 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.71077 .60739 m .69138 .63904 L .69463 .64457 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.69138 .63904 m .66727 .66727 L .66927 .67305 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.66927 .67305 m .69463 .64457 L .69138 .63904 L p F P
.505 .664 .505 r
s
.508 .719 .551 r
.53647 .26462 m .5 .26345 L .53701 .26636 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .53647 .73538 L .53701 .73364 L closepath p F P
.505 .664 .505 r
s
.159 .169 .128 r
.5 .73655 m .5343 .73707 L .53647 .73538 L closepath p F P
.505 .664 .505 r
s
.152 .162 .124 r
.5 .73655 m .53058 .73863 L .5343 .73707 L closepath p F P
.505 .664 .505 r
s
.147 .157 .119 r
.5 .73655 m .52543 .73998 L .53058 .73863 L closepath p F P
.505 .664 .505 r
s
.142 .152 .116 r
.5 .73655 m .51909 .74106 L .52543 .73998 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .51184 .74182 L .51909 .74106 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50401 .7422 L .51184 .74182 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49599 .7422 L .50401 .7422 L closepath p F P
.505 .664 .505 r
s
.137 .148 .112 r
.5 .73655 m .48816 .74182 L .49599 .7422 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48091 .74106 L .48816 .74182 L closepath p F P
.505 .664 .505 r
s
.144 .154 .117 r
.5 .73655 m .47457 .73998 L .48091 .74106 L closepath p F P
.505 .664 .505 r
s
.149 .159 .121 r
.5 .73655 m .46942 .73863 L .47457 .73998 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .4657 .73707 L .46942 .73863 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .46353 .73538 L .4657 .73707 L closepath p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .46299 .73364 L .46353 .73538 L closepath p F P
.505 .664 .505 r
s
.499 .706 .548 r
.53701 .26636 m .5731 .27502 L .57256 .27169 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.5731 .27502 m .60739 .28923 L .60735 .28461 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.60735 .28461 m .57256 .27169 L .5731 .27502 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.57256 .27169 m .53647 .26462 L .53701 .26636 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.72498 .5731 m .71077 .60739 L .71523 .61211 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.69463 .64457 m .71523 .61211 L .71077 .60739 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.5731 .72498 m .53701 .73364 L .53647 .73538 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.63904 .69138 m .60739 .71077 L .60735 .71539 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.60739 .71077 m .5731 .72498 L .57256 .72831 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.57256 .72831 m .60735 .71539 L .60739 .71077 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.72498 .4269 m .73364 .46299 L .73972 .46118 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.73364 .46299 m .73655 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.74286 .5 m .73972 .46118 L .73364 .46299 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73655 .5 m .73364 .53701 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73364 .53701 m .72498 .5731 L .73041 .57654 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73041 .57654 m .73972 .53882 L .73364 .53701 L p F P
.505 .664 .505 r
s
.501 .709 .537 r
.46299 .26636 m .5 .26345 L .46353 .26462 L closepath p F P
.505 .664 .505 r
s
.477 .676 .506 r
.4269 .27502 m .46299 .26636 L .46353 .26462 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.71077 .39261 m .72498 .4269 L .73041 .42346 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.73041 .42346 m .71523 .38789 L .71077 .39261 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.66727 .66727 m .63904 .69138 L .63989 .69684 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.60735 .71539 m .63989 .69684 L .63904 .69138 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.46353 .26462 m .42744 .27169 L .4269 .27502 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.39261 .28923 m .4269 .27502 L .42744 .27169 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.60739 .28923 m .63904 .30862 L .63989 .30316 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.63989 .30316 m .60735 .28461 L .60739 .28923 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.53647 .73538 m .57256 .72831 L .5731 .72498 L p F P
.505 .664 .505 r
s
.497 .705 .541 r
.5343 .26293 m .5 .26345 L .53647 .26462 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.42744 .72831 m .46353 .73538 L .46299 .73364 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.46299 .73364 m .4269 .72498 L .42744 .72831 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.63904 .30862 m .66727 .33273 L .66927 .32695 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.66927 .32695 m .63989 .30316 L .63904 .30862 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.39265 .71539 m .42744 .72831 L .4269 .72498 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.4269 .72498 m .39261 .71077 L .39265 .71539 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.33073 .67305 m .36011 .69684 L .36096 .69138 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.36096 .69138 m .33273 .66727 L .33073 .67305 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.39261 .71077 m .36096 .69138 L .36011 .69684 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.71523 .61211 m .73041 .57654 L .72498 .5731 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73972 .53882 m .74286 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.73972 .46118 m .73041 .42346 L .72498 .4269 L p F P
.505 .664 .505 r
s
.49 .696 .528 r
.46353 .26462 m .5 .26345 L .4657 .26293 L closepath p F P
.505 .664 .505 r
s
.486 .692 .531 r
.53058 .26137 m .5 .26345 L .5343 .26293 L closepath p F P
.505 .664 .505 r
s
.447 .635 .468 r
.42744 .27169 m .39265 .28461 L .39261 .28923 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.36096 .30862 m .39261 .28923 L .39265 .28461 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.36011 .69684 m .39265 .71539 L .39261 .71077 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.63989 .69684 m .66927 .67305 L .66727 .66727 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.69463 .35543 m .66927 .32695 L .66727 .33273 L p F P
.505 .664 .505 r
s
.48 .683 .519 r
.4657 .26293 m .5 .26345 L .46942 .26137 L closepath p F P
.505 .664 .505 r
s
.476 .679 .522 r
.52543 .26002 m .5 .26345 L .53058 .26137 L closepath p F P
.505 .664 .505 r
s
.411 .585 .424 r
.39265 .28461 m .36011 .30316 L .36096 .30862 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.33273 .33273 m .36096 .30862 L .36011 .30316 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.36011 .30316 m .33073 .32695 L .33273 .33273 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.30862 .36096 m .33273 .33273 L .33073 .32695 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.30537 .64457 m .33073 .67305 L .33273 .66727 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.33273 .66727 m .30862 .63904 L .30537 .64457 L p F P
.505 .664 .505 r
s
.47 .672 .511 r
.46942 .26137 m .5 .26345 L .47457 .26002 L closepath p F P
.505 .664 .505 r
s
.467 .668 .513 r
.51909 .25894 m .5 .26345 L .52543 .26002 L closepath p F P
.505 .664 .505 r
s
.462 .662 .505 r
.47457 .26002 m .5 .26345 L .48091 .25894 L closepath p F P
.505 .664 .505 r
s
.46 .659 .507 r
.51184 .25818 m .5 .26345 L .51909 .25894 L closepath p F P
.505 .664 .505 r
s
.33 .466 .323 r
.33073 .32695 m .30537 .35543 L .30862 .36096 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.28923 .39261 m .30862 .36096 L .30537 .35543 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.28477 .61211 m .30537 .64457 L .30862 .63904 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.30862 .63904 m .28923 .60739 L .28477 .61211 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.28477 .38789 m .26959 .42346 L .27502 .4269 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.27502 .4269 m .28923 .39261 L .28477 .38789 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26636 .46299 m .27502 .4269 L .26959 .42346 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26028 .46118 m .25714 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26345 .5 m .26636 .46299 L .26028 .46118 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.26636 .53701 m .26345 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.457 .655 .501 r
.48091 .25894 m .5 .26345 L .48816 .25818 L closepath p F P
.505 .664 .505 r
s
.455 .653 .502 r
.50401 .2578 m .5 .26345 L .51184 .25818 L closepath p F P
.505 .664 .505 r
s
.173 .206 .145 r
.26028 .53882 m .26959 .57654 L .27502 .5731 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.27502 .5731 m .26636 .53701 L .26028 .53882 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.28923 .60739 m .27502 .5731 L .26959 .57654 L p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49599 .2578 m .5 .26345 L .50401 .2578 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.48816 .25818 m .5 .26345 L .49599 .2578 L closepath p F P
.505 .664 .505 r
s
.285 .401 .268 r
.30537 .35543 m .28477 .38789 L .28923 .39261 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26959 .42346 m .26028 .46118 L .26636 .46299 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.25714 .5 m .26028 .53882 L .26636 .53701 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.26959 .57654 m .28477 .61211 L .28923 .60739 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.43126 .73159 m .4657 .73707 L .46353 .73538 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.46353 .73538 m .42744 .72831 L .43126 .73159 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.42744 .27169 m .46353 .26462 L .4657 .26293 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.57256 .72831 m .53647 .73538 L .5343 .73707 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.53647 .26462 m .57256 .27169 L .56874 .26841 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.56874 .26841 m .5343 .26293 L .53647 .26462 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.43832 .73466 m .46942 .73863 L .4657 .73707 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.4657 .73707 m .43126 .73159 L .43832 .73466 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.43126 .26841 m .4657 .26293 L .46942 .26137 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.4657 .26293 m .43126 .26841 L .42744 .27169 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.5343 .73707 m .56874 .73159 L .57256 .72831 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.56874 .73159 m .5343 .73707 L .53058 .73863 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.5343 .26293 m .56874 .26841 L .56168 .26534 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.56168 .26534 m .53058 .26137 L .5343 .26293 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.39759 .72 m .43126 .73159 L .42744 .72831 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.42744 .72831 m .39265 .71539 L .39759 .72 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.39265 .28461 m .42744 .27169 L .43126 .26841 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.60735 .71539 m .57256 .72831 L .56874 .73159 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.57256 .27169 m .60735 .28461 L .60241 .28 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.60241 .28 m .56874 .26841 L .57256 .27169 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.44839 .73736 m .47457 .73998 L .46942 .73863 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.46942 .73863 m .43832 .73466 L .44839 .73736 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.43832 .26534 m .46942 .26137 L .47457 .26002 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.46942 .26137 m .43832 .26534 L .43126 .26841 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.53058 .73863 m .56168 .73466 L .56874 .73159 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.56168 .73466 m .53058 .73863 L .52543 .73998 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.53058 .26137 m .56168 .26534 L .55161 .26264 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.55161 .26264 m .52543 .26002 L .53058 .26137 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.36568 .70237 m .39759 .72 L .39265 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.39265 .71539 m .36011 .69684 L .36568 .70237 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.43126 .26841 m .39759 .28 L .39265 .28461 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.36011 .30316 m .39265 .28461 L .39759 .28 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.63989 .69684 m .60735 .71539 L .60241 .72 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56874 .73159 m .60241 .72 L .60735 .71539 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.60735 .28461 m .63989 .30316 L .63432 .29763 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.63432 .29763 m .60241 .28 L .60735 .28461 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.46108 .73954 m .48091 .74106 L .47457 .73998 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.47457 .73998 m .44839 .73736 L .46108 .73954 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.44839 .26264 m .47457 .26002 L .48091 .25894 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.47457 .26002 m .44839 .26264 L .43832 .26534 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.52543 .73998 m .55161 .73736 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.55161 .73736 m .52543 .73998 L .51909 .74106 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.52543 .26002 m .55161 .26264 L .53892 .26046 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.53892 .26046 m .51909 .25894 L .52543 .26002 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.33651 .67897 m .36568 .70237 L .36011 .69684 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.36011 .69684 m .33073 .67305 L .33651 .67897 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.39759 .28 m .36568 .29763 L .36011 .30316 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.33073 .32695 m .36011 .30316 L .36568 .29763 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.66927 .67305 m .63989 .69684 L .63432 .70237 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.60241 .72 m .63432 .70237 L .63989 .69684 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.63989 .30316 m .66927 .32695 L .66349 .32103 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.66349 .32103 m .63432 .29763 L .63989 .30316 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.40751 .72438 m .43832 .73466 L .43126 .73159 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.43126 .73159 m .39759 .72 L .40751 .72438 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.39759 .28 m .43126 .26841 L .43832 .26534 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.60241 .72 m .56874 .73159 L .56168 .73466 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.56874 .26841 m .60241 .28 L .59249 .27562 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.59249 .27562 m .56168 .26534 L .56874 .26841 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.47579 .74108 m .48816 .74182 L .48091 .74106 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.48091 .74106 m .46108 .73954 L .47579 .74108 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.46108 .26046 m .48091 .25894 L .48816 .25818 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.48091 .25894 m .46108 .26046 L .44839 .26264 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.51909 .74106 m .53892 .73954 L .55161 .73736 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.53892 .73954 m .51909 .74106 L .51184 .74182 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.51909 .25894 m .53892 .26046 L .52421 .25892 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.52421 .25892 m .51184 .25818 L .51909 .25894 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.31104 .65028 m .33651 .67897 L .33073 .67305 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.33073 .67305 m .30537 .64457 L .31104 .65028 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.36568 .29763 m .33651 .32103 L .33073 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.30537 .35543 m .33073 .32695 L .33651 .32103 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63432 .70237 m .66349 .67897 L .66927 .67305 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.69463 .64457 m .66927 .67305 L .66349 .67897 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.66927 .32695 m .69463 .35543 L .68896 .34972 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.68896 .34972 m .66349 .32103 L .66927 .32695 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.49179 .74187 m .49599 .7422 L .48816 .74182 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.48816 .74182 m .47579 .74108 L .49179 .74187 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.51184 .74182 m .52421 .74108 L .53892 .73954 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.52421 .74108 m .51184 .74182 L .50401 .7422 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.48816 .25818 m .47579 .25892 L .46108 .26046 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.47579 .25892 m .48816 .25818 L .49599 .2578 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.51184 .25818 m .52421 .25892 L .50821 .25813 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.50821 .25813 m .50401 .2578 L .51184 .25818 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.50821 .74187 m .50401 .7422 L .49599 .7422 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.49599 .7422 m .49179 .74187 L .50821 .74187 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.50401 .7422 m .50821 .74187 L .52421 .74108 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49179 .25813 m .49599 .2578 L .50401 .2578 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.49599 .2578 m .49179 .25813 L .47579 .25892 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50401 .2578 m .50821 .25813 L .49179 .25813 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33651 .32103 m .31104 .34972 L .30537 .35543 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.28477 .38789 m .30537 .35543 L .31104 .34972 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.29017 .61703 m .31104 .65028 L .30537 .64457 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.30537 .64457 m .28477 .61211 L .29017 .61703 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.69463 .35543 m .71523 .38789 L .70983 .38297 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.70983 .38297 m .68896 .34972 L .69463 .35543 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.71523 .61211 m .69463 .64457 L .68896 .65028 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.66349 .67897 m .68896 .65028 L .69463 .64457 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.42217 .72827 m .44839 .73736 L .43832 .73466 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.43832 .73466 m .40751 .72438 L .42217 .72827 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.43832 .26534 m .40751 .27562 L .39759 .28 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.40751 .27562 m .43832 .26534 L .44839 .26264 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.56168 .73466 m .59249 .72438 L .60241 .72 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.59249 .72438 m .56168 .73466 L .55161 .73736 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.56168 .26534 m .59249 .27562 L .57783 .27173 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.57783 .27173 m .55161 .26264 L .56168 .26534 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.37793 .70768 m .40751 .72438 L .39759 .72 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.39759 .72 m .36568 .70237 L .37793 .70768 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.36568 .29763 m .39759 .28 L .40751 .27562 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.63432 .70237 m .60241 .72 L .59249 .72438 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.60241 .28 m .63432 .29763 L .62207 .29232 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.62207 .29232 m .59249 .27562 L .60241 .28 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.27466 .58014 m .29017 .61703 L .28477 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.28477 .61211 m .26959 .57654 L .27466 .58014 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.31104 .34972 m .29017 .38297 L .28477 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.26959 .42346 m .28477 .38789 L .29017 .38297 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.73041 .57654 m .71523 .61211 L .70983 .61703 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.68896 .65028 m .70983 .61703 L .71523 .61211 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.71523 .38789 m .73041 .42346 L .72534 .41986 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.72534 .41986 m .70983 .38297 L .71523 .38789 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26511 .54072 m .27466 .58014 L .26959 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26959 .57654 m .26028 .53882 L .26511 .54072 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.29017 .38297 m .27466 .41986 L .26959 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.26028 .46118 m .26959 .42346 L .27466 .41986 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73041 .42346 m .73972 .46118 L .73489 .45928 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73489 .45928 m .72534 .41986 L .73041 .42346 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.73972 .53882 m .73041 .57654 L .72534 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.70983 .61703 m .72534 .58014 L .73041 .57654 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.27466 .41986 m .26511 .45928 L .26028 .46118 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.25714 .5 m .26028 .46118 L .26511 .45928 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26189 .5 m .26511 .54072 L .26028 .53882 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26028 .53882 m .25714 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73972 .46118 m .74286 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73811 .5 m .73489 .45928 L .73972 .46118 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.74286 .5 m .73972 .53882 L .73489 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.72534 .58014 m .73489 .54072 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.26511 .45928 m .26189 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.73489 .54072 m .73811 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44103 .73145 m .46108 .73954 L .44839 .73736 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44839 .73736 m .42217 .72827 L .44103 .73145 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.42217 .27173 m .44839 .26264 L .46108 .26046 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.44839 .26264 m .42217 .27173 L .40751 .27562 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.55161 .73736 m .57783 .72827 L .59249 .72438 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.57783 .72827 m .55161 .73736 L .53892 .73954 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55161 .26264 m .57783 .27173 L .55897 .26855 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55897 .26855 m .53892 .26046 L .55161 .26264 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.35056 .68472 m .37793 .70768 L .36568 .70237 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.36568 .70237 m .33651 .67897 L .35056 .68472 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.40751 .27562 m .37793 .29232 L .36568 .29763 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.33651 .32103 m .36568 .29763 L .37793 .29232 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.66349 .67897 m .63432 .70237 L .62207 .70768 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.59249 .72438 m .62207 .70768 L .63432 .70237 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.63432 .29763 m .66349 .32103 L .64944 .31528 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.64944 .31528 m .62207 .29232 L .63432 .29763 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.39671 .71247 m .42217 .72827 L .40751 .72438 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.40751 .72438 m .37793 .70768 L .39671 .71247 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.37793 .29232 m .40751 .27562 L .42217 .27173 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.62207 .70768 m .59249 .72438 L .57783 .72827 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.59249 .27562 m .62207 .29232 L .60329 .28753 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.60329 .28753 m .57783 .27173 L .59249 .27562 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.4632 .7337 m .47579 .74108 L .46108 .73954 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.46108 .73954 m .44103 .73145 L .4632 .7337 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.44103 .26855 m .46108 .26046 L .47579 .25892 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.46108 .26046 m .44103 .26855 L .42217 .27173 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.53892 .73954 m .55897 .73145 L .57783 .72827 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.55897 .73145 m .53892 .73954 L .52421 .74108 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.53892 .26046 m .55897 .26855 L .5368 .2663 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.5368 .2663 m .52421 .25892 L .53892 .26046 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.32641 .65589 m .35056 .68472 L .33651 .67897 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.33651 .67897 m .31104 .65028 L .32641 .65589 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.37793 .29232 m .35056 .31528 L .33651 .32103 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.31104 .34972 m .33651 .32103 L .35056 .31528 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.68896 .65028 m .66349 .67897 L .64944 .68472 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.62207 .70768 m .64944 .68472 L .66349 .67897 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.66349 .32103 m .68896 .34972 L .67359 .34411 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.67359 .34411 m .64944 .31528 L .66349 .32103 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.48749 .73487 m .49179 .74187 L .47579 .74108 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.47579 .74108 m .4632 .7337 L .48749 .73487 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.4632 .2663 m .47579 .25892 L .49179 .25813 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.47579 .25892 m .4632 .2663 L .44103 .26855 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.52421 .74108 m .5368 .7337 L .55897 .73145 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.5368 .7337 m .52421 .74108 L .50821 .74187 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.52421 .25892 m .5368 .2663 L .51251 .26513 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.51251 .26513 m .50821 .25813 L .52421 .25892 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.50821 .74187 m .51251 .73487 L .5368 .7337 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.51251 .73487 m .50821 .74187 L .49179 .74187 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.49179 .74187 m .48749 .73487 L .51251 .73487 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.48749 .26513 m .49179 .25813 L .50821 .25813 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.49179 .25813 m .48749 .26513 L .4632 .2663 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.50821 .25813 m .51251 .26513 L .48749 .26513 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.35056 .31528 m .32641 .34411 L .31104 .34972 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.29017 .38297 m .31104 .34972 L .32641 .34411 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.30644 .6219 m .32641 .65589 L .31104 .65028 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.31104 .65028 m .29017 .61703 L .30644 .6219 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.68896 .34972 m .70983 .38297 L .69356 .3781 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.69356 .3781 m .67359 .34411 L .68896 .34972 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.70983 .61703 m .68896 .65028 L .67359 .65589 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.64944 .68472 m .67359 .65589 L .68896 .65028 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42138 .71641 m .44103 .73145 L .42217 .72827 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42217 .72827 m .39671 .71247 L .42138 .71641 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.39671 .28753 m .42217 .27173 L .44103 .26855 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.42217 .27173 m .39671 .28753 L .37793 .29232 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.57783 .72827 m .60329 .71247 L .62207 .70768 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.60329 .71247 m .57783 .72827 L .55897 .73145 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57783 .27173 m .60329 .28753 L .57862 .28359 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57862 .28359 m .55897 .26855 L .57783 .27173 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.3729 .68995 m .39671 .71247 L .37793 .70768 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.37793 .70768 m .35056 .68472 L .3729 .68995 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.35056 .31528 m .37793 .29232 L .39671 .28753 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.64944 .68472 m .62207 .70768 L .60329 .71247 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.62207 .29232 m .64944 .31528 L .6271 .31005 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.6271 .31005 m .60329 .28753 L .62207 .29232 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.2915 .58374 m .30644 .6219 L .29017 .61703 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.29017 .61703 m .27466 .58014 L .2915 .58374 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.32641 .34411 m .30644 .3781 L .29017 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.27466 .41986 m .29017 .38297 L .30644 .3781 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.72534 .58014 m .70983 .61703 L .69356 .6219 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.67359 .65589 m .69356 .6219 L .70983 .61703 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.70983 .38297 m .72534 .41986 L .7085 .41626 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.7085 .41626 m .69356 .3781 L .70983 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.30644 .3781 m .2915 .41626 L .27466 .41986 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.26511 .45928 m .27466 .41986 L .2915 .41626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2692 .43292 m
.27447 .40862 L
s
.5 Mabswid
.435 .578 .467 r
.28225 .54263 m .2915 .58374 L .27466 .58014 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.27466 .58014 m .26511 .54072 L .28225 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.73489 .54072 m .72534 .58014 L .7085 .58374 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.69356 .6219 m .7085 .58374 L .72534 .58014 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.72534 .41986 m .73489 .45928 L .71775 .45737 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.71775 .45737 m .7085 .41626 L .72534 .41986 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.45078 .71923 m .4632 .7337 L .44103 .73145 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.44103 .73145 m .42138 .71641 L .45078 .71923 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.42138 .28359 m .44103 .26855 L .4632 .2663 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.44103 .26855 m .42138 .28359 L .39671 .28753 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.55897 .73145 m .57862 .71641 L .60329 .71247 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.57862 .71641 m .55897 .73145 L .5368 .7337 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.55897 .26855 m .57862 .28359 L .54922 .28077 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.54922 .28077 m .5368 .2663 L .55897 .26855 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.2915 .41626 m .28225 .45737 L .26511 .45928 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26582 .44848 m
.2692 .43292 L
s
.27066 .42202 m
.27551 .4206 L
s
.5 Mabswid
.37 .473 .384 r
.26189 .5 m .26511 .45928 L .28225 .45737 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.27912 .5 m .28225 .54263 L .26511 .54072 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.26511 .54072 m .26189 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.73489 .45928 m .73811 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.72088 .5 m .71775 .45737 L .73489 .45928 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.73811 .5 m .73489 .54072 L .71775 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.7085 .58374 m .71775 .54263 L .73489 .54072 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.28225 .45737 m .27912 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.71775 .54263 m .72088 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35168 .66105 m .3729 .68995 L .35056 .68472 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35056 .68472 m .32641 .65589 L .35168 .66105 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.39671 .28753 m .3729 .31005 L .35056 .31528 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.32641 .34411 m .35056 .31528 L .3729 .31005 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.67359 .65589 m .64944 .68472 L .6271 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.60329 .71247 m .6271 .68995 L .64944 .68472 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64944 .31528 m .67359 .34411 L .64832 .33895 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64832 .33895 m .6271 .31005 L .64944 .31528 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26919 .43975 m
.28221 .40601 L
s
.26582 .44848 m
.26919 .43975 L
s
.5 Mabswid
.572 .794 .605 r
.48324 .7207 m .48749 .73487 L .4632 .7337 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.4632 .7337 m .45078 .71923 L .48324 .7207 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.45078 .28077 m .4632 .2663 L .48749 .26513 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.4632 .2663 m .45078 .28077 L .42138 .28359 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.5368 .7337 m .54922 .71923 L .57862 .71641 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.54922 .71923 m .5368 .7337 L .51251 .73487 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5368 .2663 m .54922 .28077 L .51676 .2793 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.51676 .2793 m .51251 .26513 L .5368 .2663 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.40284 .69431 m .42138 .71641 L .39671 .71247 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.39671 .71247 m .3729 .68995 L .40284 .69431 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.3729 .31005 m .39671 .28753 L .42138 .28359 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.6271 .68995 m .60329 .71247 L .57862 .71641 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.60329 .28753 m .6271 .31005 L .59716 .30569 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.59716 .30569 m .57862 .28359 L .60329 .28753 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.51676 .7207 m .51251 .73487 L .48749 .73487 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.48749 .73487 m .48324 .7207 L .51676 .7207 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.48324 .2793 m .48749 .26513 L .51251 .26513 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.48749 .26513 m .48324 .2793 L .45078 .28077 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.51251 .73487 m .51676 .7207 L .54922 .71923 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.51251 .26513 m .51676 .2793 L .48324 .2793 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.3729 .31005 m .35168 .33895 L .32641 .34411 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.30644 .3781 m .32641 .34411 L .35168 .33895 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.33398 .62642 m .35168 .66105 L .32641 .65589 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.32641 .65589 m .30644 .6219 L .33398 .62642 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.67359 .34411 m .69356 .3781 L .66602 .37358 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.66602 .37358 m .64832 .33895 L .67359 .34411 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.69356 .6219 m .67359 .65589 L .64832 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.6271 .68995 m .64832 .66105 L .67359 .65589 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27612 .43363 m
.29074 .39098 L
s
.28269 .4115 m
.28558 .4071 L
s
.27769 .42766 m
.27811 .43141 L
s
.28558 .4071 m
.28786 .40472 L
s
.5 Mabswid
.613 .837 .639 r
.43899 .69745 m .45078 .71923 L .42138 .71641 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.42138 .71641 m .40284 .69431 L .43899 .69745 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.40284 .30569 m .42138 .28359 L .45078 .28077 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.42138 .28359 m .40284 .30569 L .3729 .31005 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.57862 .71641 m .59716 .69431 L .6271 .68995 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.59716 .69431 m .57862 .71641 L .54922 .71923 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.57862 .28359 m .59716 .30569 L .56101 .30255 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.56101 .30255 m .54922 .28077 L .57862 .28359 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28786 .40472 m
.29029 .40424 L
s
.27811 .43141 m
.27916 .43316 L
s
.5 Mabswid
.315 .371 .289 r
.35168 .33895 m .33398 .37358 L .30644 .3781 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.2915 .41626 m .30644 .3781 L .33398 .37358 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.32065 .58709 m .33398 .62642 L .30644 .6219 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.30644 .6219 m .2915 .58374 L .32065 .58709 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.69356 .3781 m .7085 .41626 L .67935 .41291 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.67935 .41291 m .66602 .37358 L .69356 .3781 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.7085 .58374 m .69356 .6219 L .66602 .62642 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.64832 .66105 m .66602 .62642 L .69356 .6219 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.35168 .33895 m .3729 .31005 L .40284 .30569 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.38619 .66538 m .40284 .69431 L .3729 .68995 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.3729 .68995 m .35168 .66105 L .38619 .66538 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.6271 .31005 m .64832 .33895 L .61381 .33462 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.61381 .33462 m .59716 .30569 L .6271 .31005 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.64832 .66105 m .6271 .68995 L .59716 .69431 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27916 .43316 m
.28165 .43281 L
s
.29029 .40424 m
.29127 .406 L
s
.5 Mabswid
.547 .718 .559 r
.31236 .54441 m .32065 .58709 L .2915 .58374 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.2915 .58374 m .28225 .54263 L .31236 .54441 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.33398 .37358 m .32065 .41291 L .2915 .41626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29127 .406 m
.29166 .40984 L
s
.5 Mabswid
.444 .557 .432 r
.28225 .45737 m .2915 .41626 L .32065 .41291 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28165 .43281 m
.2839 .43057 L
s
.5 Mabswid
.63 .856 .647 r
.47919 .69909 m .48324 .7207 L .45078 .71923 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.45078 .71923 m .43899 .69745 L .47919 .69909 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.43899 .30255 m .45078 .28077 L .48324 .2793 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.45078 .28077 m .43899 .30255 L .40284 .30569 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.54922 .71923 m .56101 .69745 L .59716 .69431 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.54922 .28077 m .56101 .30255 L .52081 .30091 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.52081 .30091 m .51676 .2793 L .54922 .28077 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.56101 .69745 m .54922 .71923 L .51676 .7207 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.71775 .54263 m .7085 .58374 L .67935 .58709 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.66602 .62642 m .67935 .58709 L .7085 .58374 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.7085 .41626 m .71775 .45737 L .68764 .45559 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.68764 .45559 m .67935 .41291 L .7085 .41626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29062 .41589 m
.29166 .40984 L
s
.2839 .43057 m
.28678 .42627 L
s
.28941 .42001 m
.29062 .41589 L
s
.28678 .42627 m
.28941 .42001 L
s
.5 Mabswid
.444 .557 .432 r
.32065 .41291 m .31236 .45559 L .28225 .45737 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.27912 .5 m .28225 .45737 L .31236 .45559 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.30955 .5 m .31236 .54441 L .28225 .54263 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.28225 .54263 m .27912 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.71775 .45737 m .72088 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.69045 .5 m .68764 .45559 L .71775 .45737 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.72088 .5 m .71775 .54263 L .68764 .54441 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.67935 .58709 m .68764 .54441 L .71775 .54263 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.52081 .69909 m .51676 .7207 L .48324 .7207 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.48324 .7207 m .47919 .69909 L .52081 .69909 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.51676 .7207 m .52081 .69909 L .56101 .69745 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.47919 .30091 m .48324 .2793 L .51676 .2793 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.48324 .2793 m .47919 .30091 L .43899 .30255 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.51676 .2793 m .52081 .30091 L .47919 .30091 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.31236 .45559 m .30955 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.68764 .54441 m .69045 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.40284 .30569 m .38619 .33462 L .35168 .33895 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.33398 .37358 m .35168 .33895 L .38619 .33462 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.3722 .63023 m .38619 .66538 L .35168 .66105 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.35168 .66105 m .33398 .62642 L .3722 .63023 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.64832 .33895 m .66602 .37358 L .6278 .36977 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.6278 .36977 m .61381 .33462 L .64832 .33895 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.66602 .62642 m .64832 .66105 L .61381 .66538 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.59716 .69431 m .61381 .66538 L .64832 .66105 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.42833 .66851 m .43899 .69745 L .40284 .69431 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.40284 .69431 m .38619 .66538 L .42833 .66851 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.38619 .33462 m .40284 .30569 L .43899 .30255 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.61381 .66538 m .59716 .69431 L .56101 .69745 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.59716 .30569 m .61381 .33462 L .57167 .33149 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.57167 .33149 m .56101 .30255 L .59716 .30569 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29773 .41493 m
.30073 .40851 L
s
.29654 .41908 m
.29773 .41493 L
s
.30073 .40851 m
.30432 .40402 L
s
.29599 .42516 m
.29654 .41908 L
s
.30432 .40402 m
.30732 .40161 L
s
.29599 .42516 m
.29726 .42905 L
s
.30732 .40161 m
.31089 .40116 L
s
.29726 .42905 m
.29914 .43088 L
s
.31089 .40116 m
.31268 .40299 L
s
.29914 .43088 m
.30283 .43056 L
s
.5 Mabswid
.616 .814 .622 r
.36161 .58993 m .3722 .63023 L .33398 .62642 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.33398 .62642 m .32065 .58709 L .36161 .58993 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.38619 .33462 m .3722 .36977 L .33398 .37358 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.32065 .41291 m .33398 .37358 L .3722 .36977 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.66602 .37358 m .67935 .41291 L .63839 .41007 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.63839 .41007 m .6278 .36977 L .66602 .37358 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.67935 .58709 m .66602 .62642 L .6278 .63023 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.61381 .66538 m .6278 .63023 L .66602 .62642 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31268 .40299 m
.31394 .40696 L
s
.5 Mabswid
.654 .876 .659 r
.47552 .67016 m .47919 .69909 L .43899 .69745 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.43899 .69745 m .42833 .66851 L .47552 .67016 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.42833 .33149 m .43899 .30255 L .47919 .30091 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.43899 .30255 m .42833 .33149 L .38619 .33462 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.56101 .69745 m .57167 .66851 L .61381 .66538 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.57167 .66851 m .56101 .69745 L .52081 .69909 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.56101 .30255 m .57167 .33149 L .52448 .32984 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.52448 .32984 m .52081 .30091 L .56101 .30255 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30283 .43056 m
.30585 .42826 L
s
.31345 .4132 m
.31394 .40696 L
s
.30585 .42826 m
.30944 .42386 L
s
.31233 .41743 m
.31345 .4132 L
s
.30944 .42386 m
.31233 .41743 L
s
.5 Mabswid
.442 .538 .397 r
.3722 .36977 m .38619 .33462 L .42833 .33149 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.41933 .63301 m .42833 .66851 L .38619 .66538 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.38619 .66538 m .3722 .63023 L .41933 .63301 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.61381 .33462 m .6278 .36977 L .58067 .36699 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.58067 .36699 m .57167 .33149 L .61381 .33462 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.6278 .63023 m .61381 .66538 L .57167 .66851 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.52448 .67016 m .52081 .69909 L .47919 .69909 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.47919 .69909 m .47552 .67016 L .52448 .67016 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.52081 .69909 m .52448 .67016 L .57167 .66851 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.47552 .32984 m .47919 .30091 L .52081 .30091 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.47919 .30091 m .47552 .32984 L .42833 .33149 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.52081 .30091 m .52448 .32984 L .47552 .32984 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.3722 .36977 m .36161 .41007 L .32065 .41291 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.31236 .45559 m .32065 .41291 L .36161 .41007 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.35499 .54593 m .36161 .58993 L .32065 .58709 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.32065 .58709 m .31236 .54441 L .35499 .54593 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.67935 .41291 m .68764 .45559 L .64501 .45407 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.64501 .45407 m .63839 .41007 L .67935 .41291 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.68764 .54441 m .67935 .58709 L .63839 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.6278 .63023 m .63839 .58993 L .67935 .58709 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.36161 .41007 m .35499 .45407 L .31236 .45559 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31673 .44385 m
.31907 .43357 L
s
.31907 .43357 m
.32686 .39944 L
s
.5 Mabswid
.55 .702 .533 r
.30955 .5 m .31236 .45559 L .35499 .45407 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.35274 .5 m .35499 .54593 L .31236 .54441 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.31236 .54441 m .30955 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.68764 .45559 m .69045 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.64726 .5 m .64501 .45407 L .68764 .45559 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.69045 .5 m .68764 .54441 L .64501 .54593 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.63839 .58993 m .64501 .54593 L .68764 .54441 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.35499 .45407 m .35274 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.64501 .54593 m .64726 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33025 .43933 m
.33896 .39837 L
s
.32942 .44321 m
.33025 .43933 L
s
.5 Mabswid
.462 .564 .41 r
.41933 .36699 m .42833 .33149 L .47552 .32984 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.47241 .63448 m .47552 .67016 L .42833 .66851 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.42833 .66851 m .41933 .63301 L .47241 .63448 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.42833 .33149 m .41933 .36699 L .3722 .36977 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.57167 .66851 m .58067 .63301 L .6278 .63023 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.57167 .33149 m .58067 .36699 L .52759 .36552 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.52759 .36552 m .52448 .32984 L .57167 .33149 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.58067 .63301 m .57167 .66851 L .52448 .67016 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.41249 .59201 m .41933 .63301 L .3722 .63023 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.3722 .63023 m .36161 .58993 L .41249 .59201 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.36161 .41007 m .3722 .36977 L .41933 .36699 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.63839 .58993 m .6278 .63023 L .58067 .63301 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.6278 .36977 m .63839 .41007 L .58751 .40799 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.58751 .40799 m .58067 .36699 L .6278 .36977 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.35052 .40393 m
.35507 .39932 L
s
.34727 .41058 m
.35052 .40393 L
s
.34633 .41493 m
.34727 .41058 L
s
.35507 .39932 m
.35915 .3969 L
s
.5 Mabswid
.463 .566 .405 r
.47241 .36552 m .47552 .32984 L .52448 .32984 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.52759 .63448 m .52448 .67016 L .47552 .67016 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.47552 .67016 m .47241 .63448 L .52759 .63448 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.47552 .32984 m .47241 .36552 L .41933 .36699 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.52448 .67016 m .52759 .63448 L .58067 .63301 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.52448 .32984 m .52759 .36552 L .47241 .36552 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34633 .41493 m
.34678 .42132 L
s
.35915 .3969 m
.36457 .39656 L
s
.34678 .42132 m
.34958 .42545 L
s
.5 Mabswid
.627 .817 .614 r
.4082 .54705 m .41249 .59201 L .36161 .58993 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.36161 .58993 m .35499 .54593 L .4082 .54705 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.41933 .36699 m .41249 .40799 L .36161 .41007 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.36457 .39656 m
.36774 .39854 L
s
.5 Mabswid
.544 .686 .511 r
.35499 .45407 m .36161 .41007 L .41249 .40799 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.63839 .41007 m .64501 .45407 L .5918 .45295 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.5918 .45295 m .58751 .40799 L .63839 .41007 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.64501 .54593 m .63839 .58993 L .58751 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.58067 .63301 m .58751 .59201 L .63839 .58993 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34958 .42545 m
.35288 .42743 L
s
.36774 .39854 m
.37056 .40275 L
s
.35288 .42743 m
.35851 .42718 L
s
.37056 .40275 m
.37117 .40928 L
s
.5 Mabswid
.651 .853 .636 r
.47004 .59312 m .47241 .63448 L .41933 .63301 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.41933 .63301 m .41249 .59201 L .47004 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.41249 .40799 m .41933 .36699 L .47241 .36552 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.58751 .59201 m .58067 .63301 L .52759 .63448 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.58067 .36699 m .58751 .40799 L .52996 .40688 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.52996 .40688 m .52759 .36552 L .58067 .36699 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.41249 .40799 m .4082 .45295 L .35499 .45407 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.37036 .41368 m
.37117 .40928 L
s
.35851 .42718 m
.36269 .42485 L
s
.5 Mabswid
.579 .739 .552 r
.35274 .5 m .35499 .45407 L .4082 .45295 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.40674 .5 m .4082 .54705 L .35499 .54593 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.35499 .54593 m .35274 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.64501 .45407 m .64726 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.59326 .5 m .5918 .45295 L .64501 .45407 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.64726 .5 m .64501 .54593 L .5918 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.58751 .59201 m .5918 .54705 L .64501 .54593 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.36269 .42485 m
.36728 .42033 L
s
.36728 .42033 m
.37036 .41368 L
s
.38246 .42627 m
.38754 .39533 L
s
.5 Mabswid
.579 .739 .552 r
.4082 .45295 m .40674 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.5918 .54705 m .59326 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.47004 .40688 m .47241 .36552 L .52759 .36552 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.52996 .59312 m .52759 .63448 L .47241 .63448 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.47241 .63448 m .47004 .59312 L .52996 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.47241 .36552 m .47004 .40688 L .41249 .40799 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.52759 .63448 m .52996 .59312 L .58751 .59201 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.52759 .36552 m .52996 .40688 L .47004 .40688 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.38369 .4175 m
.38905 .42388 L
s
.38905 .42388 m
.39304 .42594 L
s
.5 Mabswid
.636 .826 .614 r
.46856 .54764 m .47004 .59312 L .41249 .59201 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.41249 .59201 m .4082 .54705 L .46856 .54764 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.4082 .45295 m .41249 .40799 L .47004 .40688 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.40716 .41674 m
.41026 .3944 L
s
.5 Mabswid
.622 .808 .588 r
.5918 .54705 m .58751 .59201 L .52996 .59312 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.58751 .40799 m .5918 .45295 L .53144 .45236 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.53144 .45236 m .52996 .40688 L .58751 .40799 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.39304 .42594 m
.39955 .42576 L
s
.39955 .42576 m
.40419 .42344 L
s
.40419 .42344 m
.40716 .41674 L
s
.45236 .3933 m
.45925 .39319 L
s
.4476 .39564 m
.45236 .3933 L
s
.44471 .40246 m
.4476 .39564 L
s
.45925 .39319 m
.46373 .39538 L
s
.53165 .39306 m
.53411 .39536 L
s
.52945 .3953 m
.53165 .39306 L
s
.5 Mabswid
.557 .703 .516 r
.47004 .40688 m .46856 .45236 L .4082 .45295 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.44302 .42487 m
.44471 .40246 L
s
.4243 .42519 m
.42762 .39385 L
s
.5 Mabswid
.589 .752 .555 r
.40674 .5 m .4082 .45295 L .46856 .45236 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.46805 .5 m .46856 .54764 L .4082 .54705 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.4082 .54705 m .40674 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.5918 .45295 m .59326 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.53195 .5 m .53144 .45236 L .5918 .45295 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.59326 .5 m .5918 .54705 L .53144 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.52996 .59312 m .53144 .54764 L .5918 .54705 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.46373 .39538 m
.47038 .4021 L
s
.5319 .39759 m
.53411 .39536 L
s
.52945 .3953 m
.5319 .39759 L
s
.49656 .39288 m
.5036 .39288 L
s
.5036 .39288 m
.51068 .39517 L
s
.48948 .39517 m
.49656 .39288 L
s
.5 Mabswid
.556 .701 .509 r
.46856 .45236 m .47004 .40688 L .52996 .40688 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.53144 .54764 m .52996 .59312 L .47004 .59312 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.47004 .59312 m .46856 .54764 L .53144 .54764 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.52996 .40688 m .53144 .45236 L .46856 .45236 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.46948 .42459 m
.47083 .39304 L
s
.51313 .39971 m
.51068 .39517 L
s
.48948 .39517 m
.48703 .39971 L
s
.5 Mabswid
.589 .752 .555 r
.46856 .45236 m .46805 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.53144 .54764 m .53195 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.51318 .40198 m
.51313 .39971 L
s
.51088 .4065 m
.51318 .40198 L
s
.4208 .44057 m
.42299 .4427 L
s
.4208 .44057 m
.42328 .43836 L
s
.42328 .43836 m
.42548 .4405 L
s
.53246 .4089 m
.53363 .44006 L
s
.42299 .4427 m
.42548 .4405 L
s
.5061 .40875 m
.51088 .4065 L
s
.49404 .411 m
.5061 .40875 L
s
.48918 .41327 m
.49404 .411 L
s
.48669 .41778 m
.48918 .41327 L
s
.5111 .42225 m
.51348 .41778 L
s
.48669 .41778 m
.48906 .42225 L
s
.50377 .42447 m
.5111 .42225 L
s
.48906 .42225 m
.4964 .42447 L
s
.4964 .42447 m
.50377 .42447 L
s
.5 Mabswid
.588 .75 .547 r
.46805 .5 m .46856 .45236 L .53144 .45236 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.53195 .5 m .53144 .54764 L .46856 .54764 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.46856 .54764 m .46805 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.53144 .45236 m .53195 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?40/>3V4@21ZH7a0;3PiP40oooo003U0;3PiPd0PJV10P0S9Qd0
0`21ZH409BPN02DX7P0602DX7P04086YP@0T9ah092LN02@W7Pd0PJV1i@2`h>H10?ooo`00h@2`h>H2
086YP@0301TM5P21ZH40PJV100D07b8J0P21ZH4702<V7@03086YP@0U:1h09BPN00L09BPN00<0PJV1
02@W7P0T9ah01@0T9ah2086YP@D08B@K1@21ZH7Q0;3PiP40oooo003M0;3PiP<0PJV10P0I7AH2086Y
P@D07b8J0P21ZH4802<V7@03086YP@0U:1h09BPN00P09BPN00<0PJV102@W7P0T9ah01`0T9ah2086Y
P@D08B@K0P21ZH400`0L7aP0PJV1086YP@02086YPMd0/>3V0@3oool00=T0/>3V0`21ZH4401TM5P80
PJV10`0O8QXY086YP@<08B@K0P21ZH4201`O60D0PJV1f@2`h>H10?ooo`00eP2`h>H3086YP@D06AdF
1`21ZH400`0`<RH0PJV103Df:@0;03Df:@03086YP@0g>2/0=cP[00T0=cP[00<0PJV103Hh:P0f>2X0
2P0f>2X00`21ZH40<c@X086YP@06086YP@<071lH1@21ZH7F0;3PiP40oooo003C0;3PiP<0PJV10P0I
7AH7086YP@H0<38V00<0PJV103Df:@0e=RT02P0e=RT00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103<d:00c=2P0100c=2P7086YP@0301`O6021ZH40PJV10080PJV1d`2`
h>H10?ooo`00d02`h>H8086YP@80:2/Q0P21ZH48030b9P03086YP@0e=RT0=CHY00/0=CHY00<0PJV1
03Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0c=2P0<c@X00H0<c@X0P21ZH42
02d_8`P0PJV1d02`h>H10?ooo`00c@2`h>H5086YP@L0:2/Q00<0PJV1030b9P0`<RH01`0`<RH00`21
ZH40=CHY03Df:@0<03Df:@03086YP@0g>2/0=cP[00/0=cP[00<0PJV103Hh:P0f>2X02`0f>2X00`21
ZH40<c@X03<d:00803<d:003086YP@0];b<0;BlS00D0;BlS1@21ZH7=0;3PiP40oooo003:0;3PiP<0
PJV100<07R4I086YP@21ZH40200X:b400`21ZH40<38V030b9P08030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X00<0PJV102d_8`0];b<01P0];b<2086YP@0402<V7021ZH40PJV1086YPLX0/>3V0@3oool00<P0
/>3V0`21ZH4201hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH4:030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X0P21ZH4802d_8`03086YP@0S9Q`08bHL00<0PJV1b02`h>H10?ooo`00aP2`h>H3086YP@807R4I
0P21ZH4802P[8@03086YP@0`<RH0<38V00T0<38V00<0PJV103Df:@0e=RT01@0e=RTQ086YP@L0=SPZ
00<0PJV103<d:00c=2P02@0c=2P00`21ZH40;BlS02d_8`0602d_8`80PJV10P0S9Q`3086YPLH0/>3V
0@3oool00<@0/>3V0`21ZH4301hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH45030b9Pl0PJV1201;
E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>Ech0CULn00H0CULn3`21ZH4503<d:080PJV1200]
;b<01021ZH408bHL02<V700S9Q`3086YPL@0/>3V0@3oool00<80/>3V0`21ZH4301hQ6@80PJV11@0X
:b4;086YP@D0@dXe00<0PJV104]D?01;E3`03`1;E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>
Ech0CULn00h0CULn00<0PJV104Q@>@18D3T01018D3T;086YP@D0;BlS0P21ZH4302<V70<0PJV1`P2`
h>H10?ooo`00`02`h>H3086YP@<07R4I0P21ZH400`0X:b40PJV1086YP@04086YP@80=STZ00<0PJV1
04=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00>04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV1
04iG?P1>Ech03P1>Ech00`21ZH40B50i04Q@>@0;04Q@>@03086YP@0m@S00?D8`00H0PJV100<0;BlS
086YP@21ZH400`0S9Q`3086YPL00/>3V0@3oool00;l0/>3V0P21ZH4201hQ6@H0PJV11`0f>BX00`21
ZH40@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21
ZH40CULn04iG?P0>04iG?P03086YP@18D3T0B50i00`0B50i00<0PJV103e2<00m@S001@0m@S06086Y
P@808bHL0P21ZH6o0;3PiP40oooo002m0;3PiPH0PJV100<0:B/Q086YP@0f>BX02P0f>BX00`21ZH40
@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21ZH40
CULn04iG?P0?04iG?P03086YP@18D3T0B50i00/0B50i00<0PJV103e2<00m@S002@0m@S000`21ZH40
;c4U086YP@05086YPKd0/>3V0@3oool00;/0/>3V1021ZH4402T[8@03086YP@0f>BX0=STZ00T0=STZ
00<0PJV104=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn00l0CUTn
00<0PJV104iG?P1>Ech03`1>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m@S00?D8`00T0?D8`
00<0PJV102la9@0_<BD00P0_<BD4086YPK/0/>3V0@3oool00;T0/>3V0`21ZH4602T[8@03086YP@0f
>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>
FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m
@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD3086YPKT0/>3V0@3oool00;L0/>3V1021ZH46
02T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00A
04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0=
04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086YPKL0/>3V0@3oool0
0;H0/>3V1021ZH4602T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03@13BSD00`21
ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn0140CUTn00<0PJV104iG?P1>Ech0401>Ech00`21
ZH40B50i04Q@>@0=04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086Y
PKH0/>3V0@3oool00;D0/>3V00<0PJV101TM5P21ZH401`0Y:b400`21ZH40=STZ03Hi:P0903Hi:P03
086YP@13BSD0@dXe00d0@dXe00<0PJV104]D?01;E3`04@1;E3`00`21ZH40CUTn04iI?P0A04iI?P03
086YP@1>Ech0CULn0100CULn00<0PJV104Q@>@18D3T03P18D3T00`21ZH40?D8`03e2<00903e2<003
086YP@0_<BD0;c4U00D0;c4U00<0PJV1020S6`21ZH40]@2`h>H10?ooo`00/`2`h>H2086YP@0301TM
5P21ZH40:B/Q00H0:B/Q00<0PJV103Hi:P0f>BX02P0f>BX00`21ZH40@dXe04=:=@0904=:=DD0PJV1
2`18D3T00`21ZH40?D8`03e2<00:03e2<003086YP@0_<BD0;c4U00D0;c4U00@0PJV1020S6`21ZH40
PJV1/`2`h>H10?ooo`00/P2`h>H01021ZH406AdF01TM5P21ZH4702T[8@03086YP@0f>BX0=STZ00X0
=STZ00@0PJV104=:=@13BSD0@dXe2@21ZH4405e]D003086YP@1SMU@0HgID0140HgID00<0PJV106Ag
E01TMe@04@1TMe@00`21ZH40H75>061aCP0A061aCP03086YP@1JJDP0FVU80080FVU82@21ZH4304Q@
>@03086YP@0m@S00?D8`00X0?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S6`21ZH6b
0;3PiP40oooo002a0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0PJV103Hi:P0f>BX01`0f>BX8
086YP@`0GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0
H75>0180H75>00<0PJV105YYB01JJDP02P1JJDP8086YP@T0?D8`00<0PJV102la9@0_<BD01@0_<BD0
1021ZH4082<K020S6`21ZH6a0;3PiP40oooo002`0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0
PJV103Hi:P0f>BX02021ZH42051LA@03086YP@1MKE00GFe@00l0GFe@00<0PJV106=fE01SMU@04P1S
MU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP03`1J
JDP00`21ZH40D5a0051L@008086YP@80?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S
6`21ZH6`0;3PiP40oooo002^0;3PiP80PJV100<06AdF086YP@21ZH401P0Y:b45086YP@X0D5a500<0
PJV105e]D01MKE003P1MKE000`21ZH40HgID06=fE00B06=fE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1061aCP1PLDh04P1PLDh00`21ZH40FVU805YYB00>05YYB003086YP@1@G400D5a000P0D5a01@21
ZH4602la9@80PJV100<082<K086YP@21ZH40[P2`h>H10?ooo`00[@2`h>H01021ZH406AdF01TM5P21
ZH4402T[8@D0PJV13@1@G4D00`21ZH40GFe@05e]D00?05e]D003086YP@1SMU@0HgID0180HgID00<0
PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0B061aCP03086YP@1JJDP0FVU800l0FVU800<0
PJV1051L@01@G4002`1@G405086YP@@0;c4U00@0PJV1020S6`0P8a/0PJV1[@2`h>H10?ooo`00[02`
h>H01@21ZH406AdF01TM5P21ZH40:B/Q00@0PJV1100i?c400`21ZH40D5a5051LA@0:051LA@03086Y
P@1MKE00GFe@0100GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00C06AgE003086Y
P@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP0401JJDP00`21ZH40D5a0051L@00:051L@003086Y
P@0oAS80?dHb0080?dHb1021ZH401@0_<BD0PJV1020S6`0P8a/0PJV10:`0/>3V0@3oool00:/0/>3V
00<0PJV101TM5P21ZH400`21ZH4703To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00
3`1MKE000`21ZH40HgID06=fE00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh0
4`1PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS80
1@0oAS84086YP@03020S6`21ZH40/>3V0:X0/>3V0@3oool00:T0/>3V00<0PJV101TM5P21ZH400P21
ZH4903To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00401MKE000`21ZH40HgID06=f
E00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh04`1PLDh00`21ZH40FVU805YY
B00@05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS801`0oAS85086YPJT0/>3V0@3o
ool00:P0/>3V0`21ZH400`0Q91`0PJV103To<@0803To<@03086YP@1@G4D0D5a500/0D5a500<0PJV1
05e]D01MKE00401MKE000`21ZH40HgID06=fE00D06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1
061aCP1PLDh0501PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000`0D5a000<0PJV1
03m6<P0oAS801`0oAS800`21ZH40:B/Q086YP@02086YPJP0/>3V0@3oool00:L0/>3V0P21ZH42024T
7003086YP@0i?c40>Cla00P0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00@05e]
D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0D061a
CP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6
<P03086YP@0Y:b40:B/Q0080PJV1Y`2`h>H10?ooo`00YP2`h>H00`21ZH408B@L024T7002024T7003
086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00A05e]D003
086YP@1SMU@0HgID01<0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>061aCP0C061aCP03
086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0703m6<P03
086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y@2`h>H00`21ZH408B@L
024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@
05e]D00@05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>
061aCP0D061aCP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G400301@G4000`21ZH40?dHb
03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00Y02`
h>H00`21ZH408B@L024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1T
Me@00`21ZH40H75>061aCP0D061aCP03086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G400301@
G4000`21ZH40?dHb03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0XP2`
h>H10?ooo`00Y02`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla00<0PJV1051LA@1@G4D02`1@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID00X0HgID;`21ZH4<061aCP03086YP@1J
JDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6<P05086YP@0Y
:b40:B/Q02T[8@21ZH40Y02`h>H10?ooo`00X`2`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla
00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@05e]D00705e]D1L0PJV12`1fT6P00`21ZH40MY1W
07J@I`0E07J@I`03086YP@1bRf80LX]R00T0LX]R5`21ZH4905YYB003086YP@1@G400D5a000`0D5a0
00<0PJV103m6<P0oAS80200oAS801@21ZH40:B/Q02T[8@0Y:b40PJV10:<0/>3V0@3oool00:80/>3V
00D0PJV1024T700Q91`08B@L086YP@0:03To<@03086YP@1@G4D0D5a500X0D5a53@21ZH4:0769I@03
086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03
086YP@1YOeP0JGmH00P0JGmH3@21ZH4<051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[8@0Y
:b40:B/Q086YP@2R0;3PiP40oooo002Q0;3PiP05086YP@0Q91`08B@L024T7021ZH402P0i?c400`21
ZH40D5a5051LA@05051LA@H0PJV10P1UNU`00`21ZH40LHUU0769I@0B0769I@03086YP@1fT6P0MY1X
01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03086YP@1YOeP0JGmH
0180JGmH00<0PJV105i`C01NL4`01P21ZH47051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[
8@0Y:b40:B/Q086YP@2Q0;3PiP40oooo002P0;3PiP03086YP@0Q91`08B@L00808B@L00<0PJV103To
<@0i?c40200i?c400`21ZH40D5a5086YP@05086YP@L0IGYL00<0PJV10769I@1aRFD04P1aRFD00`21
ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01D0MY1W00<0PJV107:;HP1bRf805P1bRf800`21
ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00D0GW1<1P21ZH400`1@G400PJV103m6<P0903m6
<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00W`2`h>H00`21ZH40
8B@L024T7002024T7003086YP@0i?c40>Cla00D0>Cla1P21ZH4=06EjG003086YP@1aRFD0LHUU0180
LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01D0
LX]R00<0PJV106UoF01YOeP04P1YOeP00`21ZH40GW1<05i`C00;05i`C0H0PJV11`0oAS800`21ZH40
:B/Q02T[8@0202T[8@03086YP@2`h>H0/>3V09d0/>3V0@3oool009h0/>3V00<0PJV1024T700Q91`0
0P0Q91`00`21ZH40>Cla03To<@06086YP@80D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU
0769I@0C0769I@03086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R
07:;HP0E07:;HP03086YP@1YOeP0JGmH01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o
04iK?`06086YP@80?dHb00<0PJV102T[8@0Y:b400P0Y:b400`21ZH40/>3V0;3PiP2L0;3PiP40oooo
002N0;3PiP03086YP@0Q91`08B@L00D0PJV1201@GTT00`21ZH40IGYL06EjG00=06EjG003086YP@1a
RFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1b
Rf80LX]R01D0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`C00=05i`C003086YP@1>
Fcl0CU/o00H0CU/o1@21ZH4202T[8@03086YP@2`h>H0/>3V09`0/>3V0@3oool009d0/>3V00<0PJV1
024T7021ZH400P21ZH4;051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD04P1aRFD0
0`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf80
0`21ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl3
086YP@0302T[8@21ZH40/>3V09`0/>3V0@3oool009`0/>3V0`21ZH42030e;@03086YP@1@GTT0D5i9
00T0D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU0769I@0C0769I@03086YP@1fT6P0MY1X
01H0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH
01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY
00<0PJV1W02`h>H10?ooo`00V`2`h>H2086YP@<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00@0PJV103@i:@0d>BT0=3TY0P21ZH6K0;3P
iP40oooo002J0;3PiP03086YP@0`=Bd0<3D]00<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00=06EjG003086YP@1aRFD0LHUU01@0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00<0PJV103@i:@0d>BT00`0d>BT00`21ZH40
/>3V0;3PiP2H0;3PiP40oooo002I0;3PiP80PJV1100`=Bd00`21ZH40D5i9051NB@09051NB@03086Y
P@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086Y
P@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086Y
P@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl00`21ZH40=3TY03@i:@0203@i:@80PJV1
V@2`h>H10?ooo`00V02`h>H2086YP@@0<3D]00<0PJV1051NB@1@GTT02P1@GTT00`21ZH40IGYL06Ej
G00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05`1fT6P00`21ZH40MY1W07J@
I`0G07J@I`03086YP@1bRf80LX]R01L0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`
C00>05i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i:@0d>BT00P0d>BT2086YPIP0/>3V0@3o
ool009L0/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03P1UNU`0
0`21ZH40LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L0
0`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03P1NL4`0
0`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6G0;3PiP40oooo002G0;3P
iP80PJV1100`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769
I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;
HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK
?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i:@03086YP@0I71H0/>3V09H0/>3V0@3oool009H0
/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40
LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L00`21ZH40
LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03`1NL4`00`21ZH40
CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6F0;3PiP40oooo002E0;3PiP80PJV1
1@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0
501aRFD00`21ZH40MY1X07J@J00G07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;HP1bRf80
5`1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl0
2P1>Fcl00`21ZH40=3TY03@i:@0303@i:@03086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V0P21
ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40LHUU0769
I@0D0769I@03086YP@1fT6P0MY1X00/0MY1X=@21ZH4=07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0
PJV105i`C01NL4`03`1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21
ZH6E0;3PiP40oooo002D0;3PiP80PJV11@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0
IGYL00h0IGYL00<0PJV10769I@1aRFD02P1aRFDI086YP@`0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H0
0`21ZH40P9ma082OL@0:082OLAT0PJV1301YOeP00`21ZH40GW1<05i`C00>05i`C003086YP@1>Fcl0
CU/o00X0CU/o00<0PJV103@i:@0d>BT00`0d>BT2086YPI@0/>3V0@3oool009@0/>3V0P21ZH44030e
;@03086YP@1@GTT0D5i900X0D5i900<0PJV106EjG01UNU`02`1UNU`A086YP@/0Oiie00<0PJV108BT
N024Y7P05`24Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01L0P9ma00<0PJV107RE
J01hUFP02@1hUFPA086YP@d0GW1<00<0PJV104iK?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i
:@80PJV1U02`h>H10?ooo`00T`2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT02P1@GTT01021ZH40
IGYL06EjG01UNU`:086YP@@0MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00G08BT
N003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg405`20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0080JX9H2P21ZH4305i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i
:@0d>BT00`0d>BT2086YPI<0/>3V0@3oool00980/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900L0
D5i92021ZH4=07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06024Y7P00`21ZH40
Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP0501hUFP00`21ZH40
JX9H06Z2F00<06Z2F0P0PJV12@1>Fcl00`21ZH40=3TY03@i:@0303@i:@80PJV1TP2`h>H10?ooo`00
TP2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT01`21ZH4306=iGP03086YP@1fTFh0MY5^00l0MY5^
00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H00l0JX9H
00@0PJV105Y/B@1JK4T0FVa91`21ZH4204iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6B0;3PiP40
oooo002A0;3PiP80PJV1100`=Bd5086YP@T0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie
07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma
082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa9
05Y/B@0705Y/B@D0PJV1100d>BT2086YPI40/>3V0@3oool00900/>3V0P21ZH43030e;@80PJV100<0
@Ti1086YP@1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0
PJV108BTN024Y7P06024Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0
PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900X0FVa900@0
PJV1041;=021ZH40PJV10`0d>BT00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002@0;3PiP03086YP@0`
=Bd0PJV10080PJV10P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^00l0MY5^00<0
PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0
PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0
PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=005086YPI00/>3V0@3oool008l0/>3V0`21ZH45
049>@@03086YP@1SNEh0HgUN00X0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E
07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma082OL@0I
082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP03`1ZPUP00`21ZH40FVa905Y/B@0;
05Y/B@03086YP@10Bc@0@4/d00<0@4/d0`21ZH6?0;3PiP40oooo002?0;3PiP80PJV11P12CT400`21
ZH40HgUN06=iGP0:06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21
ZH40Q:Ah08BTN00I08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21
ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02P1JK4T00`21
ZH40@4/d041;=004041;=080PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@H0@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024
Y7P06024Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01h
UFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010
Bc@01010Bc@2086YPHh0/>3V0@3oool008h0/>3V0P21ZH400`12CT40ogl0049>@@03049>@@03086Y
P@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086Y
P@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0H082OL@03086Y
P@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086Y
P@10Bc@0@4/d00@0@4/d00<0PJV101`P602`h>H0S@2`h>H10?ooo`00S@2`h>H2086YP@04049>@@3o
O`00ogl00?mo0080@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086Y
P@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P03`24Y7P01@3oO`00Q:Ah08BTN024Y7P0ogl000@0
Q:Ah00<0PJV108BTMP24Y7H02P24Y7H01@3oO`00Q:Af08BTMP24Y7H0ogl000`0Q:Af00<0PJV10?mo
0020Wg406020Wg400`21ZH40N9EX07REJ00F07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/
B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080PJV1S@2`h>H10?ooo`00S@2`h>H2086YP@03
049>@@3oO`00ogl000<0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0?07JAKP03
0?mo0021ZH40Oiie01<0Oiie0P3oO`000`1oWWD0PJV108BTN00408BTN080ogl02@24Y7P90?mo0003
08BTN03oO`00ogl000T0Q:Af2`3oO`0908BTMP<0ogl06@20Wg400`21ZH40N9EX07REJ00E07REJ003
086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080
PJV1S@2`h>H10?ooo`00S02`h>H01021ZH406b<O086YP@12CT420?mo00<0@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0307JAKP030?mo001fTFh0MY5^00L0MY5^1@3oO`0807nNM@80
ogl02@1oWWD20?mo000307nNM@21ZH40Q:Ah00@0Q:Ah0P3oO`0808BTN0d0ogl02024Y7H=0?mo00L0
Q:Af1@3oO`0H082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40
FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d00<0PJV101`P6021ZH40S02`h>H10?ooo`00
S02`h>H2086YP@04049>@@3oO`00ogl00?mo0080@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40
ogl007JAKP0307JAKP<0ogl01P1fTFh80?mo00L0Oiie0P3oO`0907nNM@80ogl000<0Oiie086YP@24
Y7P01024Y7P20?mo00P0Q:Ah0P3oO`0708BTN0@0ogl02024Y7H20?mo00T0Q:Af0`3oO`0708BTMP<0
ogl06@20Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0140JX9H00<0PJV105Y/B@1J
K4T02`1JK4T00`21ZH40@4/d041;=004041;=080PJV1S02`h>H10?ooo`00R`2`h>H01021ZH406b<O
086YP@12CT420?mo00<0@Ti100<0PJV106=iGP1SNEh00P1SNEh00`3oO`00HgUN0?mo000606=iGP<0
ogl00`1fTFh20?mo00D0MY5^1@3oO`000`1fTFh0PJV107nNM@020?mo00L0Oiie0P3oO`0907nNM@80
ogl000<0Oiie086YP@24Y7P01024Y7P20?mo00L0Q:Ah0P3oO`0908BTN0<0ogl02024Y7H00`3oO`00
Q:Af08BTMP0908BTMP<0ogl01P24Y7H00`21ZH40ogl0082OL@0I082OL@03086YP@1hUFP0N9EX01H0
N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0
@4/d00<0PJV101`P6021ZH40R`2`h>H10?ooo`00R`2`h>H2086YP@04049>@@3oO`00ogl00?mo00<0
@Ti100<0PJV106=iGP1SNEh01P3oO`0506=iGP80ogl0101fTFh20?mo00@0MY5^103oO`0307JAKP03
086YP@1oWWD0ogl00080ogl01P1oWWD20?mo00T0Oiie0P3oO`000`1oWWD0PJV108BTN00408BTN080
ogl01P24Y7P20?mo00/0Q:Ah0`3oO`0708BTMP030?mo0024Y7H0Q:Af00T0Q:Af0`3oO`0608BTMP03
086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05P1hUFP00`21ZH40JX9H06Z2F00@06Z2F003
086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@00`21ZH40720H086YP@2;0;3PiP40
oooo002:0;3PiP04086YP@0K8al0ogl0049>@@@0ogl000@0@Ti1086YP@1SNEh0HgUN203oO`0306=i
GP03086YP@3oO`00ogl000@0MY5^0P3oO`0307JAKP<0ogl01@1fTFh00`21ZH40Oiie07nNM@020?mo
00H0Oiie0P3oO`0907nNM@80ogl000<0PJV108BTN024Y7P01024Y7P20?mo00H0Q:Ah0P3oO`0;08BT
N080ogl04`24Y7H30?mo00L0Q:Af00<0PJV1082OL@20Wg406P20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T0301JK4T00`21ZH40@4/d041;=004041;
=003086YP@0L81P0PJV108X0/>3V0@3oool008X0/>3V00<0PJV10?mo003oO`001P3oO`000`21ZH40
HgUN06=iGP020?mo00<0HgUN0P3oO`0406=iGP03086YP@3oO`00ogl000<0MY5^0`3oO`0307JAKP80
ogl01@1fTFh01021ZH40Oiie07nNM@1oWWD20?mo00D0Oiie0P3oO`0:07nNM@80ogl000<0PJV108BT
N024Y7P01024Y7P20?mo00H0Q:Ah0P3oO`0;08BTN080ogl04@24Y7H40?mo00P0Q:Af00<0PJV1082O
L@20Wg406P20Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0140JX9H00<0PJV105Y/
B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV108X0/>3V0@3oool008L0
/>3V0P3oO`000`2`h>H06b<O0?mo00060?mo0005086YP@1SNEh0HgUN06=iGP3oO`00101SNEh20?mo
00@0HgUN0`3oO`0307JAKP80ogl0101fTFh20?mo00D0MY5^00@0PJV107nNM@1oWWD0Oiie0P3oO`05
07nNM@80ogl02P21ZH420?mo00L0PJV10P3oO`06086YP@80ogl02`21ZH420?mo00h0PJV11P3oO`0c
086YP@`0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0<05Y/B@03086YP@10Bc@0
@4/d00@0@4/d0P21ZH6:0;3PiP40oooo00270;3PiP80ogl000<0PJV101/S7`3oO`000`3oO`001012
CT40ogl00?mo0021ZH4206=iGP80ogl0101SNEh20?mo00@0HgUN0P3oO`0407JAKP80ogl00`1fTFh3
0?mo000307JAKP21ZH40PJV100H0PJV10`3oO`04086YP@80ogl02P2;[h820?mo0003086YP@2>/h@0
S[>400<0S[>40P3oO`0708jcQ080ogl02`2>/h@20?mo00/0S[>21`3oO`0;08jcPP03086YP@3oO`00
ogl001X0Rjmm00<0PJV108>UM023YG@02P23YG@A086YP@h0JX9H00<0PJV105Y/B@1JK4T0301JK4T0
0`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV108T0/>3V0@3oool008L0/>3V0P3oO`000`0K
8al0ogl00?mo00030?mo0004049>@@3oO`00ogl0086YP@80HgUN00<0ogl006=iGP1SNEh00`1SNEh2
0?mo00<0HgUN00<0PJV10?mo003oO`000`1fTFh00`21ZH40ogl00?mo0003086YP@80ogl00P21ZH44
08:TO004086YP@2;[h80Rjn208^_PP80ogl01@2;[h820?mo00X0Rjn20P3oO`000`21ZH40S[>408jc
Q00308jcQ080ogl01`2>/h@20?mo00/0S[>40P3oO`0908jcPPH0ogl03P2>/h800`21ZH40ogl00?mo
000J08^_O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H00P1gU6H:086YP@D0JX9H00<0
PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV108T0/>3V0@3o
ool008L0/>3V0P3oO`000`0K8al0ogl00?mo00020?mo0080@Ti10P3oO`0206=iGP80ogl00`1SNEh2
086YP@80ogl01021ZH420?mo00<0PJV10`3oO`0308:TO080ogl01P22Y7`00`21ZH40Rjn208^_PP03
0?mo00D0Rjn20P3oO`0:08^_PP80ogl000<0PJV108jcQ02>/h@00`2>/h@20?mo00L0S[>40P3oO`0;
08jcQ080ogl0202>/h840?mo0140S[>200<0PJV10?mo003oO`006P2;[gd00`21ZH40PjEd08>UM00F
08>UM003086YP@1gU6H0MiAV00`0MiAV3@21ZH4705Y/B@03086YP@10Bc@0@4/d00@0@4/d00<0PJV1
01`P6021ZH40R02`h>H10?ooo`00Q`2`h>H20?mo000301/S7`3oO`00ogl00080ogl00P12CT420?mo
0080PJV100<0ogl0086YP@21ZH400P21ZH42076>KP80ogl00`1aSVh30?mo00<0PZAl0P3oO`0308:T
O0<0ogl01P22Y7`00`21ZH40Rjn208^_PP020?mo00H0Rjn20P3oO`0:08^_PP80ogl000<0PJV108jc
Q02>/h@00`2>/h@20?mo00L0S[>40P3oO`0;08jcQ080ogl01`2>/h830?mo00/0S[>200<0ogl008jc
PP2>/h801@2>/h800`21ZH40ogl00?mo000J08^_O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107ND
IP1gU6H04@1gU6H00`21ZH40HWYA069jD@05069jD@T0PJV11@10Bc@00`21ZH40720H086YP@280;3P
iP40oooo00270;3PiPL0ogl00P21ZH420?mo0003076>KP3oO`00ogl000D0LHi^0`3oO`03076>KP80
ogl01022Y7`20?mo00@0PZAl0P3oO`0508:TO004086YP@2;[h80Rjn208^_PP80ogl01@2;[h830?mo
00T0Rjn20P3oO`000`2;[h80PJV108jcQ00408jcQ080ogl01`2>/h@20?mo00/0S[>40P3oO`0608jc
PP<0ogl0302>/h800`3oO`00S[>208jcPP0508jcPP03086YP@3oO`00ogl001X0Rjmm00<0PJV108>U
M023YG@05`23YG@00`21ZH40MiAV07NDIP0@07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI
?021ZH400`21ZH42041;=003086YP@0L81P0PJV108L0/>3V0@3oool008L0/>3V1P3oO`02055UD`D0
ogl01P1aSVh20?mo00<0LHi^00<0PJV10?mo003oO`001022Y7`20?mo00@0PZAl0P3oO`0508:TO003
086YP@2;[h80ogl000<0ogl01@2;[h840?mo00P0Rjn200<0ogl008^_PP21ZH401P2>/h@20?mo00L0
S[>40P3oO`0;08jcQ080ogl01`2>/h830?mo00X0S[>20P3oO`0708jcPP03086YP@3oO`00ogl001/0
Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00/0
HWYA00<0PJV104UI?019FC`00`19FC`3086YP@0301`P6021ZH40/>3V08H0/>3V0@3oool008H0/>3V
1`3oO`02055UD`80ogl000<0LHi^0?mo003oO`001P1aSVh20?mo00<0LHi^00<0PJV10?mo003oO`00
1022Y7`20?mo00@0PZAl0`3oO`0408:TO003086YP@3oO`00ogl00080ogl01P2;[h850?mo00H0Rjn2
0P3oO`000`2;[h80PJV108jcQ00508jcQ080ogl01`2>/h@20?mo00/0S[>40P3oO`0808jcPPD0ogl0
0`2>/h850?mo00P0S[>200<0PJV10?mo003oO`006`2;[gd00`21ZH40PjEd08>UM00F08>UM003086Y
P@1gU6H0MiAV0140MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00404UI?0@0PJV1
QP2`h>H10?ooo`00QP2`h>H70?mo0080DFEC0P3oO`000`1aSVh0ogl00?mo0005076>KP<0ogl00`1a
SVh00`21ZH40ogl00?mo000308:TO0<0ogl01@22Y7`20?mo00@0PZAl0`3oO`0808^_PP80ogl000<0
Rjn20?mo003oO`000P3oO`0208^_PP@0ogl000<0Rjn2086YP@2>/h@01@2>/h@20?mo00L0S[>40P3o
O`0;08jcQ080ogl02@2>/h8<0?mo00P0S[>200<0PJV10?mo003oO`006`2;[gd00`21ZH40PjEd08>U
M00F08>UM003086YP@1gU6H0MiAV0140MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI
?00404UI?004086YP@0R9ad08RLM086YPHH0/>3V0@3oool008H0/>3V1P3oO`02055UD`<0ogl000<0
LHi^0?mo003oO`00101aSVh30?mo00@0LHi^0`3oO`0308:TO080ogl01P22Y7`40?mo000408:TO03o
O`00ogl00?mo00T0Rjn20P3oO`0208^_PPP0ogl00P2;[h800`21ZH40S[>408jcQ00308jcQ080ogl0
202>/h@20?mo00/0S[>40P3oO`0;08jcPPH0ogl0302>/h800`21ZH40ogl00?mo000K08^_O@03086Y
P@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04@1gU6H00`21ZH40HWYA069jD@0<069jD@03086Y
P@19FC`0BETl00D0BETl00<0PJV1028W7@0R9ad0QP2`h>H10?ooo`00Q@2`h>H00`21ZH40ogl00?mo
00040?mo0006055UD`3oO`00ogl00?mo0021ZH40LHi^0`3oO`02076>KP<0ogl0101aSVh00`21ZH40
ogl00?mo000408:TO080ogl01`22Y7`60?mo00T0Rjn20P3oO`0408^_PPD0ogl0102;[h800`21ZH40
S[>408jcQ00308jcQ080ogl0202>/h@20?mo00`0S[>400<0PJV108jcPP2>/h806`2>/h800`21ZH40
ogl00?mo000K08^_O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40
HWYA069jD@0;069jD@03086YP@19FC`0BETl00D0BETl00@0PJV1028W7@0R9ad0PJV1Q@2`h>H10?oo
o`00Q@2`h>H00`21ZH40ogl00?mo00030?mo0005055UD`3oO`00ogl00?mo0021ZH400`1aSVh60?mo
00D0LHi^00<0PJV10?mo003oO`001022Y7`20?mo00P0PZAl103oO`000`21ZH40Rjn208^_PP0F08^_
PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h80702>/h800`21ZH40ogl00?mo000K08^_
O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40HWYA069jD@0<069j
D@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV1Q@2`h>H10?ooo`00Q@2`h>H00`21
ZH40ogl00?mo00060?mo0003055UD`21ZH40LHi^00<0LHi^103oO`06076>KP03086YP@3oO`00ogl0
00<0PZAl0`3oO`0;08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>208jcPP0M08jcPP80ogl06`2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV
0180MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00404UI?004086YP@0R9ad08RLM
086YPHD0/>3V0@3oool008D0/>3V203oO`02055UD`03086YP@1aSVh0LHi^00<0LHi^00<0ogl0076>
KP1aSVh01P1aSVh30?mo00<0PZAl0P3oO`0<08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jc
Q02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP80ogl06`2;[gd00`21ZH40PjEd08>UM00G08>U
M003086YP@1gU6H0MiAV0140MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00504UI
?003086YP@0R9ad0PJV108D0/>3V0@3oool008@0/>3V00P0PJV10?mo003oO`00ogl0055UD`3oO`00
DFEC0?mo00<0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40ogl00?mo000408:TO080ogl03022
Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>400@0S[>400<0ogl008jcQ02>/h@04`2>
/h@00`21ZH40S[>208jcPP0M08jcPP80ogl06`2;[gd00`21ZH40PjEd08>UM00G08>UM003086YP@1g
U6H0MiAV0180MiAV00<0PJV1069jD@1RNU402`1RNU400`21ZH40BETl04UI?00504UI?004086YP@0R
9ad08RLM086YPH@0/>3V0@3oool008@0/>3V00@0PJV10?mo003oO`00ogl01P1AIE<00`21ZH40LHi^
076>KP0<076>KP03086YP@3oO`00ogl000@0PZAl0P3oO`0<08:TO003086YP@2;[h80Rjn201L0Rjn2
00<0PJV108jcQ02>/h@00P2>/h@40?mo01@0S[>400<0PJV108jcPP2>/h807@2>/h820?mo01/0Rjmm
00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA
00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH640;3PiP40oooo00240;3PiP@0ogl0
1P1AIE<00`21ZH40LHi^076>KP0<076>KP03086YP@3oO`00ogl000<0PZAl0`3oO`0<08:TO003086Y
P@2;[h80Rjn201L0Rjn200@0PJV108jcQ02>/h@0S[>41P3oO`0C08jcQ003086YP@2>/h80S[>201d0
S[>20P3oO`0K08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40
HWYA069jD@0<069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV1Q02`h>H10?oo
o`00Q02`h>H30?mo00L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40ogl00?mo000308:TO080
ogl03@22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>40080S[>4103oO`0D08jcQ003
086YP@2>/h80S[>201d0S[>200<0PJV10?mo003oO`006P2;[gd00`21ZH40PjEd08>UM00G08>UM003
086YP@1gU6H0MiAV0180MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00504UI?003
086YP@0R9ad0PJV108@0/>3V0@3oool008<0/>3V00@0PJV10?mo003oO`00PJV11`1AIE<00`21ZH40
LHi^076>KP0;076>KP04086YP@22Y7`0ogl00?mo00<0PZAl0P3oO`0=08:TO003086YP@2;[h80Rjn2
01H0Rjn200<0PJV108jcQ02>/h@01@2>/h@00`3oO`00S[>408jcQ00C08jcQ003086YP@2>/h80S[>2
01d0S[>200<0PJV108^_O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV
01<0MiAV00<0PJV1069jD@1RNU402`1RNU400`21ZH40BETl04UI?00504UI?004086YP@0R9ad08RLM
086YPH<0/>3V0@3oool008<0/>3V00@0PJV10?mo003oO`00PJV11P1AIE<00`21ZH40LHi^076>KP0<
076>KP03086YP@3oO`00ogl000@0PZAl0P3oO`0=08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV1
08jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV1
08>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV1
04UI?019FC`01019FC`01021ZH408RLM028W7@21ZH630;3PiP40oooo00230;3PiP<0ogl01`1AIE<0
0`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl0180PZAl00<0PJV108^_PP2;[h805`2;[h80
0`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h80S[>201d0S[>200<0PJV108^_O@2;[gd06`2;[gd0
0`21ZH40PjEd08>UM00G08>UM003086YP@1gU6H0MiAV0180MiAV00<0PJV1069jD@1RNU40301RNU40
0`21ZH40BETl04UI?00404UI?004086YP@0R9ad08RLM086YPH<0/>3V0@3oool008<0/>3V00<0PJV1
0?mo0021ZH401`1AIE<00`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl0180PZAl00<0PJV1
08^_PP2;[h805`2;[h800`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h80S[>201d0S[>200<0PJV1
08^_O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00G08>UM003086YP@1gU6H0MiAV0180MiAV00<0PJV1
069jD@1RNU40301RNU400`21ZH40BETl04UI?00504UI?003086YP@0R9ad0PJV108<0/>3V0@3oool0
0880/>3V00@0PJV102D^:`0U;R/0PJV11`1AIE<00`21ZH40LHi^076>KP0;076>KP03086YP@22Y7`0
PZAl01<0PZAl00<0PJV108^_PP2;[h805`2;[h800`21ZH40S[>408jcQ00=08jcQ3d0PJV13`2;[gd0
0`21ZH40PjEd08>UM00G08>UM003086YP@1gU6H0MiAV01<0MiAV00<0PJV1069jD@1RNU402`1RNU40
0`21ZH40BETl04UI?00504UI?004086YP@0R9ad08RLM086YPH80/>3V0@3oool00880/>3V00@0PJV1
02D^:`0U;R/0PJV11P1AIE<00`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl00T0PZAl=021
ZH4>09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0302C^hLd086YP@/0MiAV00<0
PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00404UI?004086YP@0R9ad08RLM086YPH80/>3V
0@3oool00880/>3V00<0PJV102D^:`21ZH401`1AIE<00`21ZH40LHi^076>KP05076>KQ<0PJV12P2<
/hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F
_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg802021
Xg8C086YP@L0HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH620;3PiP40oooo
00220;3PiP809Bh[00<0PJV1055UD`1AIE<00P1AIE<;086YP@L0OImk00<0PJV108bcR02</hP04`2<
/hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F
_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21
Xg800`21ZH40K8UL06b9G00506b9G0/0PJV11019FC`00`21ZH408RLM086YP@220;3PiP40oooo0021
0;3PiP03086YP@0U;R/0PJV100D0PJV10`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`01021ZH40D6E3051U@`1@ID<6086YP@03028W7@21
ZH40/>3V0800/>3V0@3oool00840/>3V0P21ZH400`0]>SH0PJV105iiHP0605iiHP03086YP@1mWg/0
OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0
U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0
S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0
D6E300D0D6E300@0PJV102Pc8`21ZH40PJV1P@2`h>H10?ooo`00P@2`h>H01021ZH40;CXf02dj=P21
ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09Bm
S@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>k
Q`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9
G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P@2`h>H10?ooo`00P@2`
h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP0
4`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`0
7@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg80
4`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0
PJV1P@2`h>H10?ooo`00P@2`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0
OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0
U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0
S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0
D6E300@0PJV102Pc8`0X<b<0PJV1P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0805iiHP03
086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03
086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03
086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003
086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P@2`h>H10?ooo`00P@2`h>H00`21ZH40
;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40
U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40
Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40
K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P@2`h>H10?ooo`00
P@2`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP0
4`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`0
7@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg80
4`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40
P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0
PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0
PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0
PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0
PJV102Pc8`21ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0
OImk00/0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0
U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0
S;=o01L0S;=o00<0PJV1086SLP21Xg804P21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0
D6E300H0D6E300<0PJV102Pc8`21ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0705ii
HP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09Bm
S@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>k
Q`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9
G003086YP@1@ID<0D6E300D0D6E300<0PJV102Pc8`21ZH40P@2`h>H10?ooo`00P02`h>H01021ZH40
;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21
ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21
ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21
ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P02`h>H1
0?ooo`00P02`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV1
08bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV1
09JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1
086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV1
02Pc8`0X<b<0PJV1P02`h>H10?ooo`00P02`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1m
Wg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F
`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2<
/gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@
ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P02`h>H10?ooo`00P02`h>H01021ZH40;CXf02dj
=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=
09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^7
09>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL
06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P02`h>H10?ooo`00
P02`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP0
4`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`0
7@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg80
4`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0
PJV1P02`h>H10?ooo`00P02`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk
00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>
00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o
00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E3
00<0PJV102Pc8`21ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1m
Wg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F
`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2<
/gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@
ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40;CXf086YP@08
05iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G
09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L
09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<
06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P02`h>H10?ooo`00P02`h>H00`21
ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21
ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21
ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21
ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P02`h>H10?oo
o`00P02`h>Kc086YPH00/>3V0@3oool00800/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf6
08F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F
09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj7
09>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e7
05A]A`0605A]A`03086YP@0]>bP0PJV10800/>3V0@3oool00800/>3V00<0PJV103Q:@`21ZH40201X
R6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2K
b9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702J
aXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301d
UVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10800/>3V0@3oool00800/>3V00<0PJV1
03Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV1
09_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV1
09[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV1
07BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10800/>3V0@3oool0
0800/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA
01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC
01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k
01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV1
0800/>3V0@3oool00800/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03
086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03
086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03
086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04
086YP@0]>bP0;C/X086YPH00/>3V0@3oool00800/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21
ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21
ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21
ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21
ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH00/>3V0@3oool00800/>3V00@0PJV103Q:
@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV1
09_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV1
09[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV1
07BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH00/>3V0@3o
ool00800/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D
_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2L
bY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28
/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]
>bP0;C/X086YPH00/>3V0@3oool00800/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf6
08F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F
09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj7
09>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e7
05A]A`0505A]A`04086YP@0]>bP0;C/X086YPH00/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40
1`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H0
5`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0
702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0
301dUVL00`21ZH40E6e705A]A`0505A]A`03086YP@0]>bP0PJV10840/>3V0@3oool00840/>3V00<0
PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0;08F]QP03086YP@2D_i40U;nA01<0U;nA00<0
PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0
PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k0180R;1k00<0
PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10840/>3V0@3o
ool00840/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40
U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0
W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0
R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0
PJV10840/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]
QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;
UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>n
Q`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]
A`03086YP@0]>bP0PJV10840/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40
QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40
WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40
Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40
E6e705A]A`0605A]A`03086YP@0]>bP0PJV10840/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40
201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H0
5`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0
6`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0
301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH40/>3V0@3oool00840/>3V
00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0
U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0
W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0
R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086Y
PH40/>3V0@3oool00840/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]
QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;
UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>n
Q`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]
A`04086YP@0]>bP0;C/X086YPH40/>3V0@3oool00840/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h0
0`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H0
0`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl0
0`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL0
0`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH40/>3V0@3oool00840/>3V0P21ZH40
0`0hBT<0PJV106R8KP0606R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i40
0`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<0
0`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/0
0`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk:021ZH40PJV1P@2`
h>H10?ooo`00P@2`h>H00`21ZH40?eM=086YP@04086YP@@0J8Q^00<0PJV108F]QP25[HH03025[HH0
0`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH0
0`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL0
0`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL00P1DKDL5
086YP@030312:`21ZH40/>3V0800/>3V0@3oool00880/>3V00<0PJV103mGC@21ZH400`1_TgL<086Y
P@L0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F
01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj7
01L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0507BFI``0PJV10`1IMTh00`21
ZH40<48[0312:`220;3PiP40oooo00220;3PiP03086YP@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<
]hl01@2<]hlB086YP@/0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03
086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03
086YP@28/7/0R;1k00T0R;1k4P21ZH4707^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`
@R/0PJV1PP2`h>H10?ooo`00PP2`h>H01021ZH40?eM=03mGC@21ZH4606nCM`03086YP@2<]hl0S;N?
00`0S;N?00<0PJV109[9V@2JbIT0202JbITd086YP@l0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21
ZH40V/J?09[6S`0=09[6Sc@0PJV12P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>
00@0FGI>00@0PJV10312:`0`@R/0PJV1PP2`h>H10?ooo`00PP2`h>H01021ZH40?eM=03mGC@21ZH47
06nCM`03086YP@2<]hl0S;N?00/0S;N?00<0PJV109[9V@2JbIT04`2JbIT00`21ZH40X=6M0:3AW@0G
0:3AW@03086YP@2Rdid0X]>M00`0X]>M?`21ZH4>09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV1
08jiP`2>^H<04`2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>00@0PJV1
0312:`0`@R/0PJV1PP2`h>H10?ooo`00P`2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0
S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0
X]>M01/0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0
VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0
FGI>00D0FGI>00<0PJV10312:`21ZH40P`2`h>H10?ooo`00P`2`h>H00`21ZH40?eM=086YP@0706nC
M`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3A
W@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0K09o>
UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^Q
K`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1P`2`h>H10?ooo`00P`2`h>H01021
ZH40?eM=03mGC@21ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04`2JbIT0
0`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX07@2RdYX0
0`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04`2>^H<0
0`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1P`2`
h>H10?ooo`00P`2`h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<]hl0S;N?00/0S;N?00<0
PJV109[9V@2JbIT04`2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0
PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0
PJV108jiP`2>^H<04`2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>00@0
PJV10312:`0`@R/0PJV1P`2`h>H10?ooo`00Q02`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<
]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2R
did0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2I
ahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1I
MTh0FGI>00D0FGI>00<0PJV10312:`21ZH40Q02`h>H10?ooo`00Q02`h>H00`21ZH40?eM=086YP@07
06nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G
0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J
09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<
07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1Q02`h>H10?ooo`00Q02`h>H0
1021ZH40?eM=03mGC@21ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2J
bIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2R
dYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>
^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1
Q02`h>H10?ooo`00Q02`h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<]hl0S;N?00/0S;N?
00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M
00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0VLN?
00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>
00@0PJV10312:`0`@R/0PJV1Q02`h>H10?ooo`00Q@2`h>H00`21ZH40?eM=086YP@0706nCM`03086Y
P@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086Y
P@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086Y
P@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086Y
P@1IMTh0FGI>00D0FGI>00<0PJV10312:`21ZH40Q@2`h>H10?ooo`00Q@2`h>H00`21ZH40?eM=086Y
P@0706nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3A
W@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>
UP0J09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^Q
K`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1Q@2`h>H10?ooo`00Q@2`
h>H01021ZH40?eM=03mGC@21ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT0
4P2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX0
702RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<0
4P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0
PJV1Q@2`h>H10?ooo`00Q@2`h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<]hl0S;N?00/0
S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0
X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0
VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0
FGI>00@0PJV10312:`0`@R/0PJV1Q@2`h>H10?ooo`00QP2`h>H00`21ZH40?eM=086YP@0706nCM`03
086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03
086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03
086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03
086YP@1IMTh0FGI>00D0FGI>00<0PJV10312:`21ZH40QP2`h>H10?ooo`00QP2`h>H00`21ZH40?eM=
086YP@0706nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M
0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF
09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_
07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1QP2`h>H10?ooo`00
QP2`h>H4086YP@H0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A09[9V@03086Y
P@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086Y
P@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0A08jiP`03086Y
P@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh4086YPHH0/>3V0@3oool008L0/>3V00@0
PJV104EQE021ZH40PJV11P1_TgL00`21ZH40S;N?08bgS`0;08bgS`03086YP@2JbIT0V/VI0140V/VI
00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J
00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30140S[V3
00<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0405UfCP80PJV100<0<4D/086YP@2`h>H0
QP2`h>H10?ooo`00Q`2`h>H01021ZH40AF5D086YP@1bVgd4086YP@80Ki=g00<0PJV108bgS`2<]hl0
302<]hl00`21ZH40V/VI09[9V@0@09[9V@03086YP@2PdId0X=6M01L0X=6M00<0PJV10:;CW@2Rdid0
6P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl0
5`2Iahl00`21ZH40S[V308jiP`0@08jiP`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0
1021ZH40101NOeH0PJV10315;021ZH670;3PiP40oooo00280;3PiP03086YP@15HE@0PJV100@0LY]m
2P21ZH4708bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M
0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?
09W7S`0F09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl01@1kXFl:086YP@@0GWmF
00<0PJV10315;021ZH40R02`h>H10?ooo`00R02`h>H00`21ZH40AF5D086YP@0607:KO@03086YP@2?
_Y@0SkjD00D0SkjD3021ZH4?09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06P2R
did00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05P2I
ahl00`21ZH40S[V308jiP`0=08jiP``0PJV11`1oZ7H00`21ZH40GWmF05ioEP0405ioEP03086YP@0`
AB`0PJV108P0/>3V0@3oool008T0/>3V00<0PJV104EQE021ZH401P1bVgd00`21ZH40SkjD08nnU00;
08nnU003086YP@2Md9l0WM2O0080WM2O2P21ZH4509[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV1
0:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV1
09W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0308jiP`X0PJV1102B`8T00`21ZH40OjQf07nXMP0;
07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40R@2`h>H10?ooo`00R@2`h>H00`21
ZH40AF5D086YP@0607:KO@03086YP@2?_Y@0SkjD00`0SkjD00<0PJV109g@W`2Md9l02`2Md9lB086Y
P@`0X=6M00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF
01X0WljF00<0PJV109W7S`2Iahl02P2IahlB086YP@d0T/2900<0PJV107nXMP1oZ7H0301oZ7H00`21
ZH40GWmF05ioEP0405ioEP03086YP@0`AB`0PJV108T0/>3V0@3oool008X0/>3V0P21ZH4607:KO@03
086YP@2?_Y@0SkjD00`0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0:0:CHXW40
PJV1302McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf00`0OjQf00<0PJV105ioEP1N
OeH0101NOeH2086YPHX0/>3V0@3oool008X0/>3V00<0PJV104EQE021ZH401P1bVgd00`21ZH40SkjD
08nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR
0:KJXP0J0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02SeI`06P2SeI`00`21ZH40WLjE
09g>U@0E09g>U@03086YP@2B`8T0T/290140T/2900<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40GWmF
05ioEP0405ioEP03086YP@0`AB`0PJV108X0/>3V0@3oool008X0/>3V00<0PJV104EQE021ZH401P1b
Vgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O0140WM2O00<0PJV10:CHXP2Tf:805@2T
f:800`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02SeI`06P2S
eI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H0301o
Z7H00`21ZH40GWmF05ioEP0405ioEP03086YP@0`AB`0PJV108X0/>3V0@3oool008/0/>3V0P21ZH47
07:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0F
0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21ZH40XmFL0:?EW00I
0:?EW003086YP@2McYD0WLjE01H0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0;
07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40R`2`h>H10?ooo`00R`2`h>H00`21
ZH40AF5D086YP@0607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21
ZH40Y=RR0:CHXP0F0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21
ZH40XmFL0:?EW00I0:?EW003086YP@2McYD0WLjE01H0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21
ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF00<0PJV10315;021ZH40R`2`h>H10?oo
o`00S02`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03
086YP@2Tf:80Y=RR01H0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMVP0:GIX00K0:GIX003
086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0A09;0R@03
086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH0101NOeH2086YPH`0/>3V0@3oool008`0/>3V
00<0PJV104EQE021ZH401P1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O
00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01/0YMVP
00<0PJV10:?EW02SeI`06@2SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/290100T/29
00<0PJV107nXMP1oZ7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP03086YP@0`AB`0PJV108`0/>3V
0@3oool008d0/>3V0P21ZH4607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402M
d9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02UfJ006`2U
fJ000`21ZH40XmFL0:?EW00I0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B
`8T00`21ZH40OjQf07nXMP0;07nXMP03086YP@1NOeH0GWmF00@0GWmF0P21ZH6=0;3PiP40oooo002=
0;3PiP80PJV11P1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV1
0:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV1
0:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0F09g>U@03086YP@2B`8T0T/290100T/2900<0PJV1
07nXMP1oZ7H02`1oZ7H00`21ZH40GWmF05ioEP0405ioEP80PJV1S@2`h>H10?ooo`00SP2`h>H2086Y
P@H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0?09g@W`03086YP@2Tf:80Y=RR
01H0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL
01P0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0@09;0R@03086YP@1oZ7H0OjQf
00/0OjQf00<0PJV105ioEP1NOeH0101NOeH2086YPHh0/>3V0@3oool008h0/>3V0P21ZH4607:KO@03
086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03
086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21ZH40XmFL0:?EW00H0:?EW003
086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP03
086YP@1NOeH0GWmF00@0GWmF0P21ZH6>0;3PiP40oooo002?0;3PiP80PJV11P1bVgd00`21ZH40SkjD
08nnU00:08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR
0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`06@2SeI`00`21ZH40WLjE
09g>U@0E09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H02P1oZ7H00`21ZH40GWmF
05ioEP0405ioEP80PJV1S`2`h>H10?ooo`00S`2`h>H3086YP@D0LY]m00<0PJV108nnU02?_Y@02P2?
_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ806@2V
fZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05@2M
cYD00`21ZH40T/2909;0R@0?09;0R@03086YP@1oZ7H0OjQf00/0OjQf00<0PJV105ioEP1NOeH00`1N
OeH3086YPHl0/>3V0@3oool00900/>3V1021ZH4307:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV1
09g@W`2Md9l03`2Md9l00`21ZH40Y=RR0:CHXP0F0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV1
0:GIX02UfJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV1
09;0R@2B`8T0402B`8T00`21ZH40OjQf07nXMP0;07nXMP04086YP@1NOeH0GWmF05ioEP80PJV100<0
Gh=J086YP@2`h>H0S`2`h>H10?ooo`00T02`h>H2086YP@80LYeo0`21ZH400`1bVgd0PJV108nnU00;
08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJXP0H
0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0E
09g>U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H02P1oZ7H00`21ZH40GWmF086YP@02
086YP@80Gh=J00<0PJV10;3PiP2`h>H0S`2`h>H10?ooo`00T@2`h>H2086YP@@0LYeo1@21ZH4908nn
U003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJ
XP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0E09g>
U@03086YP@2B`8T0T/290100T/2900<0PJV107nXMP1oZ7H01`1oZ7H5086YP@@0Gh=J0P21ZH6A0;3P
iP40oooo002B0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`07086YP@<0SkjD00<0PJV109g@W`2M
d9l03`2Md9l00`21ZH40Y=RR0:CHXP0E0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02U
fJ006@2UfJ000`21ZH40XmFL0:?EW00H0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B
`8T03`2B`8T01021ZH40OjQf07nXMP1oZ7H7086YP@80Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086Y
PI80/>3V0@3oool00980/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00L0Sl6G2021ZH4=09g@W`03
086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMVP0:GIX00I0:GIX003
086YP@2SeI`0XmFL01P0XmFL00<0PJV109g>U@2McYD0502McYD00`21ZH40T/2909;0R@0<09;0R@P0
PJV12@1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV1TP2`h>H10?ooo`00T`2`h>H2086YP@D0LYeo
00<0PJV108o1U`2?`IL02P2?`IL01021ZH40W]>R09kCXP2Ndj8:086YP@@0WM2O00<0PJV10:CHXP2T
f:805@2Tf:800`21ZH40Y]ZR0:KJXP0G0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02S
eI`05`2SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/290080T/292P21ZH4309?4S@03
086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPI<0/>3V0@3oool009@0/>3V
0P21ZH4407:MO`03086YP@2?`IL0Sl6G00X0Sl6G00<0PJV109kCXP2Ndj802`2Ndj8@086YP@`0Y=RR
00<0PJV10:KJXP2VfZ805`2VfZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01L0XmFL
00<0PJV109g>U@2McYD02P2McYD@086YP@d0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21ZH40Gh=J
05n3FP0205n3FP80PJV1U02`h>H10?ooo`00U02`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL02P2?
`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV00T0YMbV6@21ZH4=0:KJXP03086YP@2U
fJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`02`2SeI`I086YP@/0W]:I00<0PJV109?4S@2Ca8d03P2C
a8d00`21ZH40Ojaj07n/NP0:07n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6D0;3PiP40oooo002E
0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00l0W]>R00<0PJV1
0:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0:0:SOYSL0PJV1302UfZ000`21ZH40W]:I09kBV@0D
09kBV@03086YP@2Ca8d0TlB=00l0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP03
05n3FP80PJV1U@2`h>H10?ooo`00U@2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21
ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05`2XgjH00`21
ZH40YmjT0:ONY00I0:ONY003086YP@2UfZ00YMZP01L0YMZP00<0PJV109kBV@2NdYT0502NdYT00`21
ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00`1OPeX00`21
ZH40/>3V0;3PiP2D0;3PiP40oooo002F0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0908o1U`03
086YP@2Ndj80W]>R00l0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03
086YP@2WgZ@0YmjT01T0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0D09kBV@03
086YP@2Ca8d0TlB=00l0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3FP80
PJV1UP2`h>H10?ooo`00U`2`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40W]>R
09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT
0:ONY00I0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT0502NdYT00`21ZH40TlB=
09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPIL0/>3V
0@3oool009L0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803P2N
dj800`21ZH40YMbV0:GLYP0D0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@06@2W
gZ@00`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01@0W]:I00<0PJV109?4S@2Ca8d03P2C
a8d00`21ZH40Ojaj07n/NP0907n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6G0;3PiP40oooo002H
0;3PiP80PJV1101bWGl00`21ZH40Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV1
0:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV1
0:GJX02UfZ005`2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV1
07n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0205n3FP80PJV1V02`h>H10?ooo`00V@2`h>H2086Y
P@@0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV
01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP
01H0YMZP00<0PJV109kBV@2NdYT0502NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj
00T0Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPIT0/>3V0@3oool009X0/>3V00<0PJV107:MO`1b
WGl00`1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00d0W]>R00<0PJV10:GLYP2U
g:H0502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02U
fZ005P2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/NP1o
[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3FP03086YP@2`h>H0/>3V09P0/>3V0@3oool009/0/>3V
0P21ZH4307:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803P2Ndj800`21ZH40YMbV
0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP
0:GJX00F0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj
07n/NP0907n/NP04086YP@1OPeX0Gh=J05n3FP80PJV1V`2`h>H10?ooo`00W02`h>H3086YP@80LYeo
00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0=09kCXP03086YP@2Ug:H0YMbV01<0YMbV
00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0YMZP
00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0=09?4S@03086YP@1o[7X0Ojaj00T0Ojaj
00<0PJV105n3FP1OPeX00`21ZH6L0;3PiP40oooo002M0;3PiP03086YP@1^VWd0PJV10080PJV12`2?
`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV0180YMbV00<0PJV10:SOYP2XgjH05P2X
gjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT04P2N
dYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00T0Ojaj0`21ZH400`1LPe/0PJV10;3P
iP2L0;3PiP40oooo002N0;3PiP03086YP@1^VWd0KYYm00D0PJV1202?`IL00`21ZH40W]>R09kCXP0=
09kCXP03086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00G
0:ONY003086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0=
09?4S@03086YP@1o[7X0Ojaj00H0Ojaj1@21ZH4205b3F`03086YP@2`h>H0/>3V09`0/>3V0@3oool0
09h0/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^nU@06086YP@80Sl6G00<0PJV109kC
XP2Ndj803@2Ndj800`21ZH40YMbV0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:ON
Y02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4
S@2Ca8d03@2Ca8d00`21ZH40Ojaj07n/NP06086YP@80O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21
ZH40/>3V0;3PiP2L0;3PiP40oooo002O0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;
_YD01@2;_YD6086YP@d0W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV0:SOYP0E0:SOYP03
086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I09kBV@0B09kBV@03
086YP@2Ca8d0TlB=00/0TlB=1P21ZH4707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`
h>H0W@2`h>H10?ooo`00X02`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00P0RkjE
00<0PJV109_BXP21ZH401@21ZH4709kCXP03086YP@2Ug:H0YMbV0180YMbV00<0PJV10:SOYP2XgjH0
5P2XgjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT0
4P2NdYT00`21ZH40TlB=09?4S@0509?4S@H0PJV100<0TLB>086YP@1lZgX02@1lZgX00`21ZH40G8=K
05b3F`0205b3F`03086YP@2`h>H0/>3V09h0/>3V0@3oool00:40/>3V00D0PJV106jJO@1^VWd0KYYm
086YP@0:08^nU@03086YP@2KdZ80Vm:R00D0Vm:R1P21ZH4209kCXP03086YP@2Ug:H0YMbV0180YMbV
00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2UfZ00YMZP01D0YMZP
00<0PJV109kBV@2NdYT04P2NdYT00`21ZH40TlB=09?4S@06086YP@L0TLB>00<0PJV107b[NP1lZgX0
201lZgX01@21ZH40G8=K05b3F`1LPe/0PJV10:40/>3V0@3oool00:80/>3V00D0PJV106jJO@1^VWd0
KYYm086YP@0:08^nU@03086YP@2KdZ80Vm:R00X0Vm:R3@21ZH4:0:GLYP03086YP@2XgjH0Z=nV01D0
Z=nV00<0PJV10:ONY02WgZ@05@2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I00P0
W]:I3@21ZH4<0974SP03086YP@1lZgX0O:]j00P0O:]j00D0PJV105b3F`1LPe/0G8=K086YP@2R0;3P
iP40oooo002S0;3PiP05086YP@1^VWd0KYYm06jJO@21ZH402P2;_YD00`21ZH40Vm:R09_BXP0<09_B
XP03086YP@2Tg:L0Y=bW00L0Y=bW5P21ZH4<0:SOYP03086YP@2WgZ@0YmjT01D0YmjT00<0PJV10:GJ
X02UfZ002P2UfZ0F086YP@T0WM>J00<0PJV10974SP2Aa8h0302Aa8h00`21ZH40O:]j07b[NP0807b[
NP05086YP@1LPe/0G8=K05b3F`21ZH40X`2`h>H10?ooo`00Y02`h>H01@21ZH40KYYm06jJO@1^VWd0
PJV100X0RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0
Yn2X00T0Yn2X<@21ZH4;0:CKXP03086YP@2MdiX0WM>J0140WM>J00<0PJV10974SP2Aa8h02`2Aa8h0
0`21ZH40O:]j07b[NP0807b[NP05086YP@1LPe/0G8=K05b3F`21ZH40Y02`h>H10?ooo`00Y02`h>H0
0`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0RkjE00<0PJV109_BXP2KdZ80302KdZ80
0`21ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:OOYP2WgjH05@2WgjH0
0`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J0140WM>J00<0PJV10974SP2Aa8h0302Aa8h0
0`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`h>H0XP2`h>H1
0?ooo`00Y@2`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0RkjE00<0PJV109_B
XP2KdZ80302KdZ800`21ZH40Y=bW0:CLY`0@0:CLY`03086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:OO
YP2WgjH05@2WgjH00`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J0100WM>J00<0PJV10974
SP2Aa8h0302Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3P
iP2`h>H0X`2`h>H10?ooo`00YP2`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0
RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0Yn2X01<0
Yn2X00<0PJV10:OOYP2WgjH05@2WgjH00`21ZH40Y=^R0:CKXP0C0:CKXP03086YP@2MdiX0WM>J0140
WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080
G8=K00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y`2`h>H2086YP@80KYYm00<0PJV108^nU@2;_YD0
202;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P0
502Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX0
402MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00P0O:]j00<0PJV105b3F`1LPe/0
0P21ZH6W0;3PiP40oooo002X0;3PiP<0PJV100<0KYYm086YP@2;_YD0202;_YD00`21ZH40Vm:R09_B
XP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40YmnV0:OO
YP0C0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40TLB>0974
SP0<0974SP03086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`21ZH400P21ZH6X0;3PiP40oooo002Y
0;3PiPD0PJV12@2;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV1
0:OPZ02Wh:P04`2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R00<0PJV1
09gCVP2MdiX0402MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00L0O:]j0`21ZH40
0`1FO5T0PJV10;3PiP2X0;3PiP40oooo002[0;3PiP03086YP@1UTGH0PJV10080PJV1202;_YD00`21
ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02Wh:P04`2Wh:P00`21
ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21
ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00H0O:]j0`21ZH400`1FO5T0PJV10;3PiP2Z0;3P
iP40oooo002/0;3PiP03086YP@1UTGH0II5f00D0PJV11@2;_YD00`21ZH40Vm:R09_BXP0:09_BXP03
086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03
086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX0402MdiX00`21ZH40TLB>0974SP0:0974SP03
086YP@1lZgX0O:]j00<0O:]j1@21ZH4205IlF@03086YP@2`h>H0/>3V0:X0/>3V0@3oool00:d0/>3V
00@0PJV106FAMP1UTGH0PJV10`21]8h4086YP@0308^nU@21ZH40Vm:R00`0Vm:R00<0PJV10:CLY`2T
g:L03`2Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2T
fj804P2Tfj800`21ZH40WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[NP21
ZH400`21ZH4307BSMP04086YP@1FO5T0EWaI086YPJd0/>3V0@3oool00:h0/>3V0P21ZH400`1UTGH0
PJV1086YP@05086dSPH0PJV12P2KdZ800`21ZH40Y=bW0:CLY`0>0:CLY`03086YP@2Wh:P0Yn2X0180
Yn2X00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086YP@2MdiX0WM>J00h0
WM>J00<0PJV10974SP2Aa8h0202Aa8h6086YP@D0M:=f0P21ZH400`1FO5T0PJV1086YP@2^0;3PiP40
oooo002`0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`02021ZH4209_BXP03
086YP@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0A0:OOYP03
086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40TLB>0974SP08086YP@80
RKf:00<0PJV107BSMP1dXgH01@1dXgH01021ZH40EWaI05IlF@21ZH6`0;3PiP40oooo002a0;3PiP04
086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`01`2BbY`8086YP@`0Y=bW00<0PJV10:OP
Z02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0A0:OOYP03086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gC
VP2MdiX02P2MdiX8086YP@T0RKf:00<0PJV107BSMP1dXgH01@1dXgH01021ZH40EWaI05IlF@21ZH6a
0;3PiP40oooo002b0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`02P2BbY`0
1021ZH40W=JS09cFX`2LeZ<9086YP@@0Y=bW00<0PJV10:OPZ02Wh:P04@2Wh:P00`21ZH40YmnV0:OO
YP0A0:OOYP03086YP@2Tfj80Y=^R0140Y=^R00<0PJV109gCVP2MdiX00P2MdiX9086YP@<0U/fG00<0
PJV108VmRP29_HX02P29_HX00`21ZH40M:=f07BSMP0507BSMP04086YP@1FO5T0EWaI086YPK80/>3V
0@3oool00;<0/>3V0P21ZH400`1UTGH0PJV1086dSP06086dSP03086YP@2BbY`0T/ZL00X0T/ZL00<0
PJV109cFX`2LeZ<02@2LeZ=5086YP@/0U/fG00<0PJV108VmRP29_HX02P29_HX00`21ZH40M:=f07BS
MP0507BSMP04086YP@1FO5T0PJV1086YPK<0/>3V0@3oool00;D0/>3V00<0PJV106FAMP21ZH401`21
]8h00`21ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00d0W=JS00<0PJV10:7KY@2QfjD04@2Q
fjD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Neil0W]NO0100W]NO00<0PJV109K=U`2FcIL03P2F
cIL00`21ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f00D0M:=f00<0PJV105IlF@21ZH40]@2`
h>H10?ooo`00]P2`h>H01021ZH40II5f086YP@21ZH46086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0
PJV109cFX`2LeZ<03@2LeZ<00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Qfj@0XM^T0140XM^T00<0
PJV109kGW`2Neil0402Neil00`21ZH40U/fG09K=U`0=09K=U`03086YP@29_HX0RKf:00T0RKf:00<0
PJV107BSMP1dXgH0101dXgH2086YP@0305IlF@21ZH40/>3V0;D0/>3V0@3oool00;L0/>3V0P21ZH40
0`1UTGH0PJV1086dSP05086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<0302LeZ<0
0`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil0402Neil0
0`21ZH40U/fG09K=U`0=09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BSMP1dXgH0101dXgH0
1021ZH40EWaI086YP@21ZH6g0;3PiP40oooo002i0;3PiP<0PJV11P21]8h00`21ZH40T/ZL09;:W009
09;:W003086YP@2LeZ<0W=JS00`0W=JS00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40XM^T0:7KY00?
0:7KY003086YP@2Neil0W]NO0100W]NO00<0PJV109K=U`2FcIL0302FcIL00`21ZH40RKf:08VmRP09
08VmRP03086YP@1dXgH0M:=f00@0M:=f0`21ZH6i0;3PiP40oooo002k0;3PiP@0PJV11021]8h00`21
ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00/0W=JS00<0PJV10:7KY@2QfjD0402QfjD00`21
ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO00l0W]NO00<0PJV109K=U`2FcIL0302FcIL00`21
ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f0080M:=f1021ZH6k0;3PiP40oooo002m0;3PiPH0
PJV100<0PKB>086YP@2BbY`02P2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2QfjD0XM^U00l0
XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0?09kGW`03086YP@2FcIL0U/fG00/0
U/fG00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f086YP@05086YPKd0/>3V0@3oool00;h0/>3V
0`21ZH42072PO`H0PJV11`2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2QfjD0XM^U00l0XM^U
00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0>09kGW`03086YP@2FcIL0U/fG00`0U/fG
00<0PJV108VmRP29_HX01@29_HX6086YP@80II9/0`21ZH6n0;3PiP40oooo00300;3PiP<0PJV10`1`
X7l2086YP@0308:gSP21ZH40PJV100@0PJV10P2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2Q
fjD0XM^U00h0XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0>09kGW`03086YP@2F
cIL0U/fG00/0U/fG00<0PJV108VmRP29_HX01P21ZH400`1i[7l0PJV1086YP@0306FBK0<0PJV1`02`
h>H10?ooo`00`P2`h>H3086YP@<0L:1o0P21ZH4508:gSPX0PJV11P2LeZ<00`21ZH40XM^U0:7KY@0?
0:7KY@03086YP@2Qfj@0XM^T00d0XM^T00<0PJV109kGW`2Neil03P2Neil00`21ZH40U/fG09K=U`05
09K=U`X0PJV11@1i[7l2086YP@<0II9/0`21ZH720;3PiP40oooo00340;3PiP<0PJV10`1`X7l00`21
ZH40P[N>08:gSP0608:gSP80PJV1102=a9L@086YP@P0XM^U00<0PJV10:7KY02Qfj@03@2Qfj@00`21
ZH40W]NO09kGW`0609kGWa00PJV11027_Hd2086YP@P0NJao00@0PJV106FBK01UTV`0II9/0`21ZH74
0;3PiP40oooo00360;3PiP<0PJV10P1`X7l2086YP@P0P[N>00<0PJV108g4U`2=a9L02@2=a9L00`21
ZH40T/^J09;;VP0509;;VR40PJV11`2?aiD00`21ZH40Qkf=08NmS@0908NmS@03086YP@1i[7l0NJao
00H0NJao0P21ZH4206FBK0<0PJV1aP2`h>H10?ooo`00b02`h>H3086YP@80L:1o00<0PJV108:gSP22
]hh01P22]hh00`21ZH40SLBG08g4U`0908g4U`03086YP@2BbiX0T/^J00`0T/^J00<0PJV109?<VP2C
c9X03@2Cc9X00`21ZH40SlNE08o7U@0<08o7U@03086YP@27_Hd0Qkf=00T0Qkf=00<0PJV107V/O`1i
[7l01P1i[7l00`21ZH40II9/06FBK003086YPLP0/>3V0@3oool00<X0/>3V0`21ZH400`1`X7l0PJV1
086YP@0708:gSP80PJV12P2=a9L00`21ZH40T/^J09;;VP0<09;;VP03086YP@2Cc9X0TlbJ00/0TlbJ
00<0PJV108o7U@2?aiD0302?aiD00`21ZH40Qkf=08NmS@0808NmS@80PJV11`1i[7l2086YP@0406FB
K021ZH40PJV1086YPLX0/>3V0@3oool00<d0/>3V1@21ZH4708:gSP03086YP@2=a9L0SLBG00L0SLBG
00<0PJV109;;VP2BbiX0302BbiX00`21ZH40TlbJ09?<VP0;09?<VP03086YP@2?aiD0SlNE00/0SlNE
00<0PJV108NmS@27_Hd02027_Hd00`21ZH40NJao07V/O`0507V/O`D0PJV1c@2`h>H10?ooo`00d02`
h>H7086YP@<0P[N>0P21ZH4808g4U`03086YP@2BbiX0T/^J00/0T/^J00<0PJV109?<VP2Cc9X02`2C
c9X00`21ZH40SlNE08o7U@0;08o7U@03086YP@27_Hd0Qkf=00H0Qkf=0P21ZH4307V/O`L0PJV1d02`
h>H10?ooo`00d`2`h>H<086YP@H0SLBG00<0PJV109;;VP2BbiX02P2BbiX00`21ZH40TlbJ09?<VP0;
09?<VP03086YP@2?aiD0SlNE00X0SlNE00<0PJV108NmS@27_Hd01027_Hd8086YP@04066>J`21ZH40
PJV1086YPM<0/>3V0@3oool00=H0/>3V1@21ZH4206NGM`P0PJV100<0SLBG086YP@2BbiX02`2BbiX0
0`21ZH40TlbJ09?<VP0909?<VP03086YP@2?aiD0SlNE00X0SlNE00<0PJV108NmS@21ZH401`21ZH44
066>J`<0PJV1eP2`h>H10?ooo`00f@2`h>H5086YP@0306NGM`21ZH40PJV100@0LJAo:@21ZH4406fN
M`80PJV10P1QSV/4086YPMT0/>3V0@3oool00=d0/>3V1P21ZH45076TO`80PJV12@1gZh<00`21ZH40
N:b307R/P`0807R/P`03086YP@1eZ7l0MJQo00P0MJQo0P21ZH4506fNM`80PJV100@0HHi[086YP@21
ZH40PJV1g@2`h>H10?ooo`00h@2`h>H4086YP@D0LJAo0P21ZH4807N[P`03086YP@1h[8<0N:b300L0
N:b300<0PJV107FXO`1eZ7l01P1eZ7l2086YP@D0KIig1021ZH7Q0;3PiP40oooo003U0;3PiP`0PJV1
0`1gZh<00`21ZH40N:b307R/P`0607R/P`03086YP@1eZ7l0MJQo0080MJQo3021ZH7U0;3PiP40oooo
003`0;3PiQ<0PJV1l02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.605 .777 .566 r
.4503 .46959 m .4498 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.605 .777 .566 r
.48991 .5 m .49001 .46977 L .4503 .46959 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.49001 .53023 m .48991 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.49001 .46977 m .48991 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.48991 .5 m .49001 .53023 L .52992 .53029 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.52992 .53029 m .53022 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.53022 .5 m .52992 .46971 L .49001 .46977 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.52992 .46971 m .53022 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.53022 .5 m .52992 .53029 L .56922 .53059 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.56922 .53059 m .56993 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.45183 .43953 m .4503 .46959 L .49001 .46977 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.49001 .46977 m .49032 .43988 L .45183 .43953 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.4498 .5 m .4503 .53041 L .49001 .53023 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.49032 .56012 m .49001 .53023 L .4503 .53041 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.49032 .43988 m .49001 .46977 L .52992 .46971 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.49001 .53023 m .49032 .56012 L .529 .56024 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.529 .56024 m .52992 .53029 L .49001 .53023 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.52992 .46971 m .529 .43976 L .49032 .43988 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.529 .43976 m .52992 .46971 L .56922 .46941 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.56993 .5 m .56922 .46941 L .52992 .46971 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.52992 .53029 m .529 .56024 L .56709 .56082 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.56709 .56082 m .56922 .53059 L .52992 .53029 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.41161 .46916 m .41069 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.4498 .5 m .4503 .46959 L .41161 .46916 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.4503 .53041 m .4498 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49726 .56014 m
.50082 .56117 L
s
.4885 .5594 m
.48935 .5594 L
s
.48239 .56122 m
.4885 .5594 L
s
.50082 .56117 m
.50285 .56467 L
s
.51925 .56123 m
.52163 .56022 L
s
.5 Mabswid
.61 .788 .572 r
.41436 .43871 m .41161 .46916 L .4503 .46959 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.4503 .46959 m .45183 .43953 L .41436 .43871 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.41069 .5 m .41161 .53084 L .4503 .53041 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.45183 .56047 m .4503 .53041 L .41161 .53084 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.4503 .53041 m .45183 .56047 L .49032 .56012 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51925 .56123 m
.51508 .56471 L
s
.53117 .56027 m
.53352 .56135 L
s
.5 Mabswid
.631 .82 .6 r
.45437 .41018 m .45183 .43953 L .49032 .43988 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.49032 .43988 m .49082 .41067 L .45437 .41018 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.49082 .41067 m .49032 .43988 L .529 .43976 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.49082 .58933 m .49032 .56012 L .45183 .56047 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.49032 .56012 m .49082 .58933 L .52748 .58949 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.52748 .58949 m .529 .56024 L .49032 .56012 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.529 .43976 m .52748 .41051 L .49082 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.52748 .41051 m .529 .43976 L .56709 .43918 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.56922 .46941 m .56709 .43918 L .529 .43976 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.529 .56024 m .52748 .58949 L .56352 .59032 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.56352 .59032 m .56709 .56082 L .529 .56024 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.56922 .46941 m .56993 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.56993 .5 m .56922 .53059 L .60709 .53114 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.60709 .53114 m .60821 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.56709 .43918 m .56922 .46941 L .60709 .46886 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.60821 .5 m .60709 .46886 L .56922 .46941 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.56922 .53059 m .56709 .56082 L .60373 .56188 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.60373 .56188 m .60709 .53114 L .56922 .53059 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.41894 .40902 m .41436 .43871 L .45183 .43953 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.45183 .43953 m .45437 .41018 L .41894 .40902 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.41161 .53084 m .41436 .56129 L .45183 .56047 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.45437 .58982 m .45183 .56047 L .41436 .56129 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.45183 .56047 m .45437 .58982 L .49082 .58933 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.37481 .46849 m .37348 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.41069 .5 m .41161 .46916 L .37481 .46849 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.41161 .53084 m .41069 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.45794 .38193 m .45437 .41018 L .49082 .41067 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.49082 .41067 m .49154 .38253 L .45794 .38193 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.49154 .38253 m .49082 .41067 L .52748 .41051 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.49154 .61747 m .49082 .58933 L .45437 .58982 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.49082 .58933 m .49154 .61747 L .52534 .61767 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.52534 .61767 m .52748 .58949 L .49082 .58933 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.56709 .43918 m .56352 .40968 L .52748 .41051 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.56352 .40968 m .56709 .43918 L .60373 .43812 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.60709 .46886 m .60373 .43812 L .56709 .43918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.56709 .56082 m .56352 .59032 L .59813 .5918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.59813 .5918 m .60373 .56188 L .56709 .56082 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.37878 .43741 m .37481 .46849 L .41161 .46916 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.41161 .46916 m .41436 .43871 L .37878 .43741 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.37348 .5 m .37481 .53151 L .41161 .53084 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.41436 .56129 m .41161 .53084 L .37481 .53151 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.52748 .41051 m .52534 .38233 L .49154 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.52534 .38233 m .52748 .41051 L .56352 .40968 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.52748 .58949 m .52534 .61767 L .55853 .61867 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.55853 .61867 m .56352 .59032 L .52748 .58949 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.42535 .38053 m .41894 .40902 L .45437 .41018 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.45437 .41018 m .45794 .38193 L .42535 .38053 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.41436 .56129 m .41894 .59098 L .45437 .58982 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.45794 .61807 m .45437 .58982 L .41894 .59098 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.45437 .58982 m .45794 .61807 L .49154 .61747 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.38539 .40721 m .37878 .43741 L .41436 .43871 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.41436 .43871 m .41894 .40902 L .38539 .40721 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.37481 .53151 m .37878 .56259 L .41436 .56129 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.41894 .59098 m .41436 .56129 L .37878 .56259 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.60709 .46886 m .60821 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.60821 .5 m .60709 .53114 L .64258 .53194 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.64258 .53194 m .64411 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.56352 .40968 m .55853 .38133 L .52534 .38233 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.55853 .38133 m .56352 .40968 L .59813 .4082 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.60373 .43812 m .59813 .4082 L .56352 .40968 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.56352 .59032 m .55853 .61867 L .59031 .62047 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.59031 .62047 m .59813 .5918 L .56352 .59032 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.60373 .43812 m .60709 .46886 L .64258 .46806 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.64411 .5 m .64258 .46806 L .60709 .46886 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.60709 .53114 m .60373 .56188 L .63799 .56341 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.63799 .56341 m .64258 .53194 L .60709 .53114 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60438 .56191 m
.60643 .56306 L
s
.5 Mabswid
.649 .854 .629 r
.46253 .35521 m .45794 .38193 L .49154 .38253 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.49154 .38253 m .49246 .35586 L .46253 .35521 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.49246 .64414 m .49154 .61747 L .45794 .61807 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.49246 .35586 m .49154 .38253 L .52534 .38233 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.49154 .61747 m .49246 .64414 L .52258 .64436 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.52258 .64436 m .52534 .61767 L .49154 .61747 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.52534 .38233 m .52258 .35564 L .49246 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.52258 .35564 m .52534 .38233 L .55853 .38133 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.52534 .61767 m .52258 .64436 L .55212 .64545 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.55212 .64545 m .55853 .61867 L .52534 .61767 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.59813 .4082 m .60373 .43812 L .63799 .43659 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.64258 .46806 m .63799 .43659 L .60373 .43812 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.60373 .56188 m .59813 .5918 L .63037 .59394 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.63037 .59394 m .63799 .56341 L .60373 .56188 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.39462 .37834 m .38539 .40721 L .41894 .40902 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.41894 .40902 m .42535 .38053 L .39462 .37834 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.37878 .56259 m .38539 .59279 L .41894 .59098 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.42535 .61947 m .41894 .59098 L .38539 .59279 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.41894 .59098 m .42535 .61947 L .45794 .61807 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.43357 .35368 m .42535 .38053 L .45794 .38193 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.45794 .38193 m .46253 .35521 L .43357 .35368 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.46253 .64479 m .45794 .61807 L .42535 .61947 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.45794 .61807 m .46253 .64479 L .49246 .64414 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.3409 .46758 m .33917 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.37348 .5 m .37481 .46849 L .3409 .46758 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.37481 .53151 m .37348 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.3461 .43565 m .3409 .46758 L .37481 .46849 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.37481 .46849 m .37878 .43741 L .3461 .43565 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.33917 .5 m .3409 .53242 L .37481 .53151 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.37878 .56259 m .37481 .53151 L .3409 .53242 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.55853 .38133 m .55212 .35455 L .52258 .35564 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.55212 .35455 m .55853 .38133 L .59031 .37953 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.59813 .4082 m .59031 .37953 L .55853 .38133 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.55853 .61867 m .55212 .64545 L .58028 .6474 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.58028 .6474 m .59031 .62047 L .55853 .61867 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.59813 .5918 m .59031 .62047 L .61975 .62304 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.61975 .62304 m .63037 .59394 L .59813 .5918 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.59031 .37953 m .59813 .4082 L .63037 .40606 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.63799 .43659 m .63037 .40606 L .59813 .4082 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.35472 .40475 m .3461 .43565 L .37878 .43741 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.37878 .43741 m .38539 .40721 L .35472 .40475 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.3409 .53242 m .3461 .56435 L .37878 .56259 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.38539 .59279 m .37878 .56259 L .3461 .56435 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.40642 .3513 m .39462 .37834 L .42535 .38053 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.42535 .38053 m .43357 .35368 L .40642 .3513 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.38539 .59279 m .39462 .62166 L .42535 .61947 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.43357 .64632 m .42535 .61947 L .39462 .62166 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.42535 .61947 m .43357 .64632 L .46253 .64479 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.64258 .46806 m .64411 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.64411 .5 m .64258 .53194 L .6746 .53297 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.6746 .53297 m .67654 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.46813 .3305 m .46253 .35521 L .49246 .35586 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.49246 .35586 m .49358 .33115 L .46813 .3305 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.49358 .33115 m .49246 .35586 L .52258 .35564 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.49358 .66885 m .49246 .64414 L .46253 .64479 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.49246 .64414 m .49358 .66885 L .51922 .66907 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.51922 .66907 m .52258 .64436 L .49246 .64414 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.52258 .35564 m .51922 .33093 L .49358 .33115 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.51922 .33093 m .52258 .35564 L .55212 .35455 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.63799 .43659 m .64258 .46806 L .6746 .46703 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.67654 .5 m .6746 .46703 L .64258 .46806 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.64258 .53194 m .63799 .56341 L .66881 .5654 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.66881 .5654 m .6746 .53297 L .64258 .53194 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.52258 .64436 m .51922 .66907 L .5443 .67015 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.5443 .67015 m .55212 .64545 L .52258 .64436 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.3667 .37538 m .35472 .40475 L .38539 .40721 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.38539 .40721 m .39462 .37834 L .3667 .37538 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.3461 .56435 m .35472 .59525 L .38539 .59279 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.39462 .62166 m .38539 .59279 L .35472 .59525 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.44359 .32898 m .43357 .35368 L .46253 .35521 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.46253 .35521 m .46813 .3305 L .44359 .32898 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.46813 .6695 m .46253 .64479 L .43357 .64632 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.46253 .64479 m .46813 .6695 L .49358 .66885 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.59031 .37953 m .58028 .3526 L .55212 .35455 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.58028 .3526 m .59031 .37953 L .61975 .37696 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.63037 .40606 m .61975 .37696 L .59031 .37953 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.59031 .62047 m .58028 .6474 L .60621 .6502 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.60621 .6502 m .61975 .62304 L .59031 .62047 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.63037 .40606 m .63799 .43659 L .66881 .4346 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.6746 .46703 m .66881 .4346 L .63799 .43659 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.63799 .56341 m .63037 .59394 L .65921 .59672 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.65921 .59672 m .66881 .5654 L .63799 .56341 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.55212 .35455 m .5443 .32985 L .51922 .33093 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.5443 .32985 m .55212 .35455 L .58028 .3526 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.55212 .64545 m .5443 .67015 L .5681 .67209 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.5681 .67209 m .58028 .6474 L .55212 .64545 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.42073 .32662 m .40642 .3513 L .43357 .35368 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.43357 .35368 m .44359 .32898 L .42073 .32662 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.39462 .62166 m .40642 .6487 L .43357 .64632 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.44359 .67102 m .43357 .64632 L .40642 .6487 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.43357 .64632 m .44359 .67102 L .46813 .6695 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.61975 .37696 m .63037 .40606 L .65921 .40328 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.66881 .4346 m .65921 .40328 L .63037 .40606 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.63037 .59394 m .61975 .62304 L .64589 .62639 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.64589 .62639 m .65921 .59672 L .63037 .59394 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.31108 .46642 m .30894 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.33917 .5 m .3409 .46758 L .31108 .46642 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.3409 .53242 m .33917 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.38195 .34809 m .3667 .37538 L .39462 .37834 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.39462 .37834 m .40642 .3513 L .38195 .34809 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.35472 .59525 m .3667 .62462 L .39462 .62166 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.40642 .6487 m .39462 .62166 L .3667 .62462 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.31746 .43343 m .31108 .46642 L .3409 .46758 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.3409 .46758 m .3461 .43565 L .31746 .43343 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.30894 .5 m .31108 .53358 L .3409 .53242 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.3461 .56435 m .3409 .53242 L .31108 .53358 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.32801 .40165 m .31746 .43343 L .3461 .43565 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.3461 .43565 m .35472 .40475 L .32801 .40165 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.31108 .53358 m .31746 .56657 L .3461 .56435 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.35472 .59525 m .3461 .56435 L .31746 .56657 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.58028 .3526 m .5681 .32791 L .5443 .32985 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.5681 .32791 m .58028 .3526 L .60621 .3498 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.61975 .37696 m .60621 .3498 L .58028 .3526 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58028 .6474 m .5681 .67209 L .58983 .67486 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58983 .67486 m .60621 .6502 L .58028 .6474 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.47472 .30833 m .46813 .3305 L .49358 .33115 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.49358 .33115 m .4949 .30892 L .47472 .30833 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.4949 .30892 m .49358 .33115 L .51922 .33093 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.4949 .69108 m .49358 .66885 L .46813 .6695 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.49358 .66885 m .4949 .69108 L .51525 .69128 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.51525 .69128 m .51922 .66907 L .49358 .66885 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.51922 .33093 m .51525 .30872 L .4949 .30892 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.51525 .30872 m .51922 .33093 L .5443 .32985 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.51922 .66907 m .51525 .69128 L .5351 .69225 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.5351 .69225 m .5443 .67015 L .51922 .66907 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.60621 .3498 m .61975 .37696 L .64589 .37361 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.65921 .40328 m .64589 .37361 L .61975 .37696 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.61975 .62304 m .60621 .6502 L .62899 .65381 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.62899 .65381 m .64589 .62639 L .61975 .62304 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.45535 .30698 m .44359 .32898 L .46813 .3305 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.46813 .3305 m .47472 .30833 L .45535 .30698 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.47472 .69167 m .46813 .6695 L .44359 .67102 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.46813 .6695 m .47472 .69167 L .4949 .69108 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.34262 .37167 m .32801 .40165 L .35472 .40475 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.35472 .40475 m .3667 .37538 L .34262 .37167 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.31746 .56657 m .32801 .59835 L .35472 .59525 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.3667 .62462 m .35472 .59525 L .32801 .59835 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40032 .32347 m .38195 .34809 L .40642 .3513 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40642 .3513 m .42073 .32662 L .40032 .32347 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.3667 .62462 m .38195 .65191 L .40642 .6487 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.42073 .67338 m .40642 .6487 L .38195 .65191 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.40642 .6487 m .42073 .67338 L .44359 .67102 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.5443 .32985 m .5351 .30775 L .51525 .30872 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5351 .30775 m .5443 .32985 L .5681 .32791 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.5443 .67015 m .5351 .69225 L .55383 .69398 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.55383 .69398 m .5681 .67209 L .5443 .67015 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.6746 .46703 m .67654 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.67654 .5 m .6746 .53297 L .70188 .53425 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.70188 .53425 m .70421 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.66881 .4346 m .6746 .46703 L .70188 .46575 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.70421 .5 m .70188 .46575 L .6746 .46703 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.6746 .53297 m .66881 .5654 L .69493 .56784 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.69493 .56784 m .70188 .53425 L .6746 .53297 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.43743 .30488 m .42073 .32662 L .44359 .32898 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.44359 .32898 m .45535 .30698 L .43743 .30488 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.45535 .69302 m .44359 .67102 L .42073 .67338 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.44359 .67102 m .45535 .69302 L .47472 .69167 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.65921 .40328 m .66881 .4346 L .69493 .43216 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.70188 .46575 m .69493 .43216 L .66881 .4346 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.66881 .5654 m .65921 .59672 L .68346 .60013 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.68346 .60013 m .69493 .56784 L .66881 .5654 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3611 .34411 m .34262 .37167 L .3667 .37538 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3667 .37538 m .38195 .34809 L .3611 .34411 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.32801 .59835 m .34262 .62833 L .3667 .62462 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.38195 .65191 m .3667 .62462 L .34262 .62833 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.60621 .3498 m .58983 .32514 L .5681 .32791 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.58983 .32514 m .60621 .3498 L .62899 .34619 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.64589 .37361 m .62899 .34619 L .60621 .3498 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.60621 .6502 m .58983 .67486 L .6087 .6784 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.6087 .6784 m .62899 .65381 L .60621 .6502 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5681 .32791 m .55383 .30602 L .5351 .30775 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.55383 .30602 m .5681 .32791 L .58983 .32514 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.5681 .67209 m .55383 .69398 L .57077 .69644 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.57077 .69644 m .58983 .67486 L .5681 .67209 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.64589 .37361 m .65921 .40328 L .68346 .39987 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.69493 .43216 m .68346 .39987 L .65921 .40328 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.65921 .59672 m .64589 .62639 L .66762 .63045 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.66762 .63045 m .68346 .60013 L .65921 .59672 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42163 .30208 m .40032 .32347 L .42073 .32662 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42073 .32662 m .43743 .30488 L .42163 .30208 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.38195 .65191 m .40032 .67653 L .42073 .67338 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.43743 .69512 m .42073 .67338 L .40032 .67653 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.42073 .67338 m .43743 .69512 L .45535 .69302 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.28671 .46503 m .2842 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.30894 .5 m .31108 .46642 L .28671 .46503 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.31108 .53358 m .30894 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.48228 .28932 m .47472 .30833 L .4949 .30892 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.4949 .30892 m .49643 .28977 L .48228 .28932 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.49643 .28977 m .4949 .30892 L .51525 .30872 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.49643 .71023 m .4949 .69108 L .47472 .69167 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.4949 .69108 m .49643 .71023 L .51069 .71038 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51069 .71038 m .51525 .69128 L .4949 .69108 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.51525 .30872 m .51069 .28962 L .49643 .28977 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.51069 .28962 m .51525 .30872 L .5351 .30775 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.51525 .69128 m .51069 .71038 L .52458 .71113 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.52458 .71113 m .5351 .69225 L .51525 .69128 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.2942 .43077 m .28671 .46503 L .31108 .46642 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.31108 .46642 m .31746 .43343 L .2942 .43077 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.2842 .5 m .28671 .53497 L .31108 .53358 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.31746 .56657 m .31108 .53358 L .28671 .53497 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.3832 .31957 m .3611 .34411 L .38195 .34809 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.38195 .34809 m .40032 .32347 L .3832 .31957 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.34262 .62833 m .3611 .65589 L .38195 .65191 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.40032 .67653 m .38195 .65191 L .3611 .65589 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.62899 .34619 m .64589 .37361 L .66762 .36955 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.68346 .39987 m .66762 .36955 L .64589 .37361 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64589 .62639 m .62899 .65381 L .64765 .65816 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64765 .65816 m .66762 .63045 L .64589 .62639 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.46877 .28827 m .45535 .30698 L .47472 .30833 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.47472 .30833 m .48228 .28932 L .46877 .28827 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.48228 .71068 m .47472 .69167 L .45535 .69302 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47472 .69167 m .48228 .71068 L .49643 .71023 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.30655 .39796 m .2942 .43077 L .31746 .43343 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.31746 .43343 m .32801 .40165 L .30655 .39796 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.28671 .53497 m .2942 .56923 L .31746 .56657 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.32801 .59835 m .31746 .56657 L .2942 .56923 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.5351 .30775 m .52458 .28887 L .51069 .28962 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.52458 .28887 m .5351 .30775 L .55383 .30602 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5351 .69225 m .52458 .71113 L .5376 .71246 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5376 .71246 m .55383 .69398 L .5351 .69225 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.58983 .32514 m .57077 .30356 L .55383 .30602 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.57077 .30356 m .58983 .32514 L .6087 .3216 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.62899 .34619 m .6087 .3216 L .58983 .32514 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58983 .67486 m .57077 .69644 L .58528 .69956 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58528 .69956 m .6087 .6784 L .58983 .67486 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45638 .28667 m .43743 .30488 L .45535 .30698 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45535 .30698 m .46877 .28827 L .45638 .28667 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.46877 .71173 m .45535 .69302 L .43743 .69512 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.45535 .69302 m .46877 .71173 L .48228 .71068 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32354 .36727 m .30655 .39796 L .32801 .40165 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32801 .40165 m .34262 .37167 L .32354 .36727 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.2942 .56923 m .30655 .60204 L .32801 .59835 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.34262 .62833 m .32801 .59835 L .30655 .60204 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.6087 .3216 m .62899 .34619 L .64765 .34184 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.66762 .36955 m .64765 .34184 L .62899 .34619 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62899 .65381 m .6087 .6784 L .62388 .68263 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62388 .68263 m .64765 .65816 L .62899 .65381 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.55383 .30602 m .5376 .28754 L .52458 .28887 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.5376 .28754 m .55383 .30602 L .57077 .30356 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.55383 .69398 m .5376 .71246 L .54924 .71433 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.54924 .71433 m .57077 .69644 L .55383 .69398 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40859 .29866 m .3832 .31957 L .40032 .32347 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40032 .32347 m .42163 .30208 L .40859 .29866 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.3611 .65589 m .3832 .68043 L .40032 .67653 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.42163 .69792 m .40032 .67653 L .3832 .68043 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.40032 .67653 m .42163 .69792 L .43743 .69512 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34488 .33941 m .32354 .36727 L .34262 .37167 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34262 .37167 m .3611 .34411 L .34488 .33941 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.30655 .60204 m .32354 .63273 L .34262 .62833 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.3611 .65589 m .34262 .62833 L .32354 .63273 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.70188 .46575 m .70421 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.70421 .5 m .70188 .53425 L .72294 .53575 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.72294 .53575 m .72562 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.69493 .43216 m .70188 .46575 L .72294 .46425 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.72562 .5 m .72294 .46425 L .70188 .46575 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.70188 .53425 m .69493 .56784 L .71494 .57071 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.71494 .57071 m .72294 .53575 L .70188 .53425 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.4456 .28455 m .42163 .30208 L .43743 .30488 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.43743 .30488 m .45638 .28667 L .4456 .28455 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45638 .71333 m .43743 .69512 L .42163 .69792 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.43743 .69512 m .45638 .71333 L .46877 .71173 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.68346 .39987 m .69493 .43216 L .71494 .42929 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.72294 .46425 m .71494 .42929 L .69493 .43216 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.69493 .56784 m .68346 .60013 L .70178 .6041 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.70178 .6041 m .71494 .57071 L .69493 .56784 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.57077 .30356 m .54924 .28567 L .5376 .28754 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.54924 .28567 m .57077 .30356 L .58528 .30044 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.6087 .3216 m .58528 .30044 L .57077 .30356 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.37018 .31502 m .34488 .33941 L .3611 .34411 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.3611 .34411 m .3832 .31957 L .37018 .31502 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.57077 .69644 m .54924 .71433 L .55905 .71669 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.55905 .71669 m .58528 .69956 L .57077 .69644 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.32354 .63273 m .34488 .66059 L .3611 .65589 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.3832 .68043 m .3611 .65589 L .34488 .66059 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.58528 .30044 m .6087 .3216 L .62388 .31737 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.64765 .34184 m .62388 .31737 L .6087 .3216 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.6087 .6784 m .58528 .69956 L .59668 .70325 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.59668 .70325 m .62388 .68263 L .6087 .6784 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.66762 .36955 m .68346 .39987 L .70178 .3959 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.71494 .42929 m .70178 .3959 L .68346 .39987 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68346 .60013 m .66762 .63045 L .68373 .63515 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68373 .63515 m .70178 .6041 L .68346 .60013 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49074 .27412 m .48228 .28932 L .49643 .28977 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49643 .28977 m .49813 .27437 L .49074 .27412 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.49813 .27437 m .49643 .28977 L .51069 .28962 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49813 .72563 m .49643 .71023 L .48228 .71068 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49643 .71023 m .49813 .72563 L .50559 .72571 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.50559 .72571 m .51069 .71038 L .49643 .71023 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.51069 .28962 m .50559 .27429 L .49813 .27437 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.50559 .27429 m .51069 .28962 L .52458 .28887 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51069 .71038 m .50559 .72571 L .51284 .72613 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51284 .72613 m .52458 .71113 L .51069 .71038 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48372 .27353 m .46877 .28827 L .48228 .28932 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48228 .28932 m .49074 .27412 L .48372 .27353 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.49074 .72588 m .48228 .71068 L .46877 .71173 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.48228 .71068 m .49074 .72588 L .49813 .72563 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.64765 .34184 m .66762 .36955 L .68373 .36485 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.70178 .3959 m .68373 .36485 L .66762 .36955 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66762 .63045 m .64765 .65816 L .66116 .66317 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66116 .66317 m .68373 .63515 L .66762 .63045 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.52458 .28887 m .51284 .27387 L .50559 .27429 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.51284 .27387 m .52458 .28887 L .5376 .28754 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.52458 .71113 m .51284 .72613 L .51957 .72688 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.51957 .72688 m .5376 .71246 L .52458 .71113 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.43688 .28198 m .40859 .29866 L .42163 .30208 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.42163 .30208 m .4456 .28455 L .43688 .28198 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.3832 .68043 m .40859 .70134 L .42163 .69792 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.4456 .71545 m .42163 .69792 L .40859 .70134 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.42163 .69792 m .4456 .71545 L .45638 .71333 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.47734 .27264 m .45638 .28667 L .46877 .28827 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.46877 .28827 m .48372 .27353 L .47734 .27264 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.48372 .72647 m .46877 .71173 L .45638 .71333 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.46877 .71173 m .48372 .72647 L .49074 .72588 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.39896 .29471 m .37018 .31502 L .3832 .31957 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.3832 .31957 m .40859 .29866 L .39896 .29471 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.34488 .66059 m .37018 .68498 L .3832 .68043 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.40859 .70134 m .3832 .68043 L .37018 .68498 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.5376 .28754 m .51957 .27312 L .51284 .27387 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.51957 .27312 m .5376 .28754 L .54924 .28567 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.5376 .71246 m .51957 .72688 L .52552 .72791 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.52552 .72791 m .54924 .71433 L .5376 .71246 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.26939 .46342 m .26655 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.2842 .5 m .28671 .46503 L .26939 .46342 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.28671 .53497 m .2842 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.27785 .42772 m .26939 .46342 L .28671 .46503 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.28671 .46503 m .2942 .43077 L .27785 .42772 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.26655 .5 m .26939 .53658 L .28671 .53497 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.2942 .56923 m .28671 .53497 L .26939 .53658 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.62388 .31737 m .64765 .34184 L .66116 .33683 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.68373 .36485 m .66116 .33683 L .64765 .34184 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.64765 .65816 m .62388 .68263 L .63452 .68746 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.63452 .68746 m .66116 .66317 L .64765 .65816 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.58528 .30044 m .55905 .28331 L .54924 .28567 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.55905 .28331 m .58528 .30044 L .59668 .29675 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.62388 .31737 m .59668 .29675 L .58528 .30044 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.58528 .69956 m .55905 .71669 L .56657 .71945 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.56657 .71945 m .59668 .70325 L .58528 .69956 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.29173 .39373 m .27785 .42772 L .2942 .43077 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.2942 .43077 m .30655 .39796 L .29173 .39373 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.26939 .53658 m .27785 .57228 L .2942 .56923 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.30655 .60204 m .2942 .56923 L .27785 .57228 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.47187 .27147 m .4456 .28455 L .45638 .28667 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.45638 .28667 m .47734 .27264 L .47187 .27147 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.47734 .72736 m .45638 .71333 L .4456 .71545 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.45638 .71333 m .47734 .72736 L .48372 .72647 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.31071 .36228 m .29173 .39373 L .30655 .39796 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.30655 .39796 m .32354 .36727 L .31071 .36228 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.27785 .57228 m .29173 .60627 L .30655 .60204 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.32354 .63273 m .30655 .60204 L .29173 .60627 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.54924 .28567 m .52552 .27209 L .51957 .27312 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.52552 .27209 m .54924 .28567 L .55905 .28331 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.54924 .71433 m .52552 .72791 L .53045 .7292 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.53045 .7292 m .55905 .71669 L .54924 .71433 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.59668 .29675 m .62388 .31737 L .63452 .31254 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.66116 .33683 m .63452 .31254 L .62388 .31737 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.62388 .68263 m .59668 .70325 L .60439 .70742 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.60439 .70742 m .63452 .68746 L .62388 .68263 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.33435 .33413 m .31071 .36228 L .32354 .36727 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.32354 .36727 m .34488 .33941 L .33435 .33413 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.29173 .60627 m .31071 .63772 L .32354 .63273 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.34488 .66059 m .32354 .63273 L .31071 .63772 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.43065 .27904 m .39896 .29471 L .40859 .29866 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.40859 .29866 m .43688 .28198 L .43065 .27904 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.37018 .68498 m .39896 .70529 L .40859 .70134 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.43688 .71802 m .40859 .70134 L .39896 .70529 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.40859 .70134 m .43688 .71802 L .4456 .71545 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71519 .5696 m
.71544 .56964 L
s
.5 Mabswid
.566 .783 .584 r
.46755 .27007 m .43688 .28198 L .4456 .28455 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.4456 .28455 m .47187 .27147 L .46755 .27007 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.47187 .72853 m .4456 .71545 L .43688 .71802 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.4456 .71545 m .47187 .72853 L .47734 .72736 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70512 .59563 m
.70582 .59579 L
s
.5 Mabswid
.489 .672 .482 r
.36211 .30995 m .33435 .33413 L .34488 .33941 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.34488 .33941 m .37018 .31502 L .36211 .30995 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.31071 .63772 m .33435 .66587 L .34488 .66059 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.37018 .68498 m .34488 .66059 L .33435 .66587 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.55905 .28331 m .53045 .2708 L .52552 .27209 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.53045 .2708 m .55905 .28331 L .56657 .28055 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.59668 .29675 m .56657 .28055 L .55905 .28331 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.55905 .71669 m .53045 .7292 L .53411 .7307 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.53411 .7307 m .56657 .71945 L .55905 .71669 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.56657 .28055 m .59668 .29675 L .60439 .29258 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.63452 .31254 m .60439 .29258 L .59668 .29675 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.59668 .70325 m .56657 .71945 L .57141 .72253 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.57141 .72253 m .60439 .70742 L .59668 .70325 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.72294 .46425 m .72562 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.72562 .5 m .72294 .53575 L .73609 .53744 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.73609 .53744 m .73907 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.555 .774 .585 r
.49813 .27437 m .5 .26345 L .49074 .27412 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50559 .27429 m .5 .26345 L .49813 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49813 .72563 L .49074 .72588 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50559 .72571 L .49813 .72563 L closepath p F P
.505 .664 .505 r
s
.415 .55 .447 r
.71494 .42929 m .72294 .46425 L .73609 .46256 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.73907 .5 m .73609 .46256 L .72294 .46425 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72294 .53575 m .71494 .57071 L .72724 .57394 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71611 .57101 m
.7166 .57203 L
s
.5 Mabswid
.312 .389 .32 r
.72724 .57394 m .73609 .53744 L .72294 .53575 L p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51284 .27387 m .5 .26345 L .50559 .27429 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .51284 .72613 L .50559 .72571 L closepath p F P
.505 .664 .505 r
s
.246 .271 .196 r
.33435 .66587 m .36211 .69005 L .37018 .68498 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.39896 .70529 m .37018 .68498 L .36211 .69005 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.39333 .29036 m .36211 .30995 L .37018 .31502 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.37018 .31502 m .39896 .29471 L .39333 .29036 L p F P
.505 .664 .505 r
s
.552 .77 .582 r
.49074 .27412 m .5 .26345 L .48372 .27353 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .49074 .72588 L .48372 .72647 L closepath p F P
.505 .664 .505 r
s
.444 .597 .482 r
.70178 .3959 m .71494 .42929 L .72724 .42606 L p F P
.505 .664 .505 r
s
.415 .55 .447 r
.73609 .46256 m .72724 .42606 L .71494 .42929 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71494 .57071 m .70178 .6041 L .71274 .60854 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71274 .60854 m .72724 .57394 L .71494 .57071 L p F P
.505 .664 .505 r
s
.553 .772 .586 r
.51957 .27312 m .5 .26345 L .51284 .27387 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .51957 .72688 L .51284 .72613 L closepath p F P
.505 .664 .505 r
s
.544 .757 .564 r
.46458 .26849 m .43065 .27904 L .43688 .28198 L p F P
.505 .664 .505 r
s
.544 .757 .564 r
.43688 .28198 m .46755 .27007 L .46458 .26849 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.39896 .70529 m .43065 .72096 L .43688 .71802 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.46755 .72993 m .43688 .71802 L .43065 .72096 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.43688 .71802 m .46755 .72993 L .47187 .72853 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.68373 .36485 m .70178 .3959 L .71274 .39146 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.72724 .42606 m .71274 .39146 L .70178 .3959 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.70178 .6041 m .68373 .63515 L .69297 .64039 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.69297 .64039 m .71274 .60854 L .70178 .6041 L p F P
.505 .664 .505 r
s
.547 .764 .578 r
.48372 .27353 m .5 .26345 L .47734 .27264 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .48372 .72647 L .47734 .72736 L closepath p F P
.505 .664 .505 r
s
.549 .767 .583 r
.52552 .27209 m .5 .26345 L .51957 .27312 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .52552 .72791 L .51957 .72688 L closepath p F P
.505 .664 .505 r
s
.491 .673 .537 r
.66116 .33683 m .68373 .36485 L .69297 .35961 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.71274 .39146 m .69297 .35961 L .68373 .36485 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.68373 .63515 m .66116 .66317 L .66846 .66869 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.66846 .66869 m .69297 .64039 L .68373 .63515 L p F P
.505 .664 .505 r
s
.541 .757 .572 r
.47734 .27264 m .5 .26345 L .47187 .27147 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .47734 .72736 L .47187 .72853 L closepath p F P
.505 .664 .505 r
s
.513 .715 .527 r
.42727 .27585 m .39333 .29036 L .39896 .29471 L p F P
.505 .664 .505 r
s
.513 .715 .527 r
.39896 .29471 m .43065 .27904 L .42727 .27585 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.36211 .69005 m .39333 .70964 L .39896 .70529 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.43065 .72096 m .39896 .70529 L .39333 .70964 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.56657 .28055 m .53411 .2693 L .53045 .2708 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.53411 .2693 m .56657 .28055 L .57141 .27747 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.60439 .29258 m .57141 .27747 L .56657 .28055 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.56657 .71945 m .53411 .7307 L .53635 .73235 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.53635 .73235 m .57141 .72253 L .56657 .71945 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.63452 .31254 m .66116 .33683 L .66846 .33131 L p F P
.505 .664 .505 r
s
.491 .673 .537 r
.69297 .35961 m .66846 .33131 L .66116 .33683 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.66116 .66317 m .63452 .68746 L .63983 .69272 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.63983 .69272 m .66846 .66869 L .66116 .66317 L p F P
.505 .664 .505 r
s
.543 .76 .579 r
.53045 .2708 m .5 .26345 L .52552 .27209 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .53045 .7292 L .52552 .72791 L closepath p F P
.505 .664 .505 r
s
.533 .748 .565 r
.47187 .27147 m .5 .26345 L .46755 .27007 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .47187 .72853 L .46755 .72993 L closepath p F P
.505 .664 .505 r
s
.518 .721 .567 r
.60439 .29258 m .63452 .31254 L .63983 .30728 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.66846 .33131 m .63983 .30728 L .63452 .31254 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.63452 .68746 m .60439 .70742 L .60783 .71191 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60783 .71191 m .63983 .69272 L .63452 .68746 L p F P
.505 .664 .505 r
s
.535 .751 .573 r
.53411 .2693 m .5 .26345 L .53045 .2708 L closepath p F P
.505 .664 .505 r
s
.184 .192 .146 r
.5 .73655 m .53411 .7307 L .53045 .7292 L closepath p F P
.505 .664 .505 r
s
.517 .725 .541 r
.46311 .26679 m .42727 .27585 L .43065 .27904 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.43065 .27904 m .46458 .26849 L .46311 .26679 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.39333 .70964 m .42727 .72415 L .43065 .72096 L p F P
.505 .664 .505 r
s
.191 .198 .151 r
.46458 .73151 m .43065 .72096 L .42727 .72415 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.43065 .72096 m .46458 .73151 L .46755 .72993 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.57141 .27747 m .60439 .29258 L .60783 .28809 L p F P
.505 .664 .505 r
s
.518 .721 .567 r
.63983 .30728 m .60783 .28809 L .60439 .29258 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60439 .70742 m .57141 .72253 L .57327 .72581 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57327 .72581 m .60783 .71191 L .60439 .70742 L p F P
.505 .664 .505 r
s
.524 .737 .557 r
.46755 .27007 m .5 .26345 L .46458 .26849 L closepath p F P
.505 .664 .505 r
s
.185 .192 .146 r
.5 .73655 m .46755 .72993 L .46458 .73151 L closepath p F P
.505 .664 .505 r
s
.526 .74 .566 r
.53635 .26765 m .5 .26345 L .53411 .2693 L closepath p F P
.505 .664 .505 r
s
.551 .768 .591 r
.57141 .27747 m .53635 .26765 L .53411 .2693 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .53635 .73235 L .53411 .7307 L closepath p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26084 .46165 m .25775 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26655 .5 m .26939 .46342 L .26084 .46165 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.26939 .53658 m .26655 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.27002 .42434 m .26084 .46165 L .26939 .46342 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.26939 .46342 m .27785 .42772 L .27002 .42434 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.25775 .5 m .26084 .53835 L .26939 .53658 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.27785 .57228 m .26939 .53658 L .26084 .53835 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.28501 .38909 m .27002 .42434 L .27785 .42772 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.27785 .42772 m .29173 .39373 L .28501 .38909 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.26084 .53835 m .27002 .57566 L .27785 .57228 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.29173 .60627 m .27785 .57228 L .27002 .57566 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57141 .72253 m .53635 .73235 L .53702 .73408 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.53702 .73408 m .57327 .72581 L .57141 .72253 L p F P
.505 .664 .505 r
s
.523 .735 .568 r
.53635 .26765 m .57141 .27747 L .57327 .27419 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.60783 .28809 m .57327 .27419 L .57141 .27747 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.30538 .35684 m .28501 .38909 L .29173 .39373 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.29173 .39373 m .31071 .36228 L .30538 .35684 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.27002 .57566 m .28501 .61091 L .29173 .60627 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.31071 .63772 m .29173 .60627 L .28501 .61091 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.33053 .32842 m .30538 .35684 L .31071 .36228 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.31071 .36228 m .33435 .33413 L .33053 .32842 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.28501 .61091 m .30538 .64316 L .31071 .63772 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.33435 .66587 m .31071 .63772 L .30538 .64316 L p F P
.505 .664 .505 r
s
.514 .725 .548 r
.46458 .26849 m .5 .26345 L .46311 .26679 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.42727 .72415 m .46311 .73321 L .46458 .73151 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .46458 .73151 L .46311 .73321 L closepath p F P
.505 .664 .505 r
s
.171 .179 .137 r
.30538 .64316 m .33053 .67158 L .33435 .66587 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.36211 .69005 m .33435 .66587 L .33053 .67158 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.35974 .30454 m .33053 .32842 L .33435 .33413 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.33435 .33413 m .36211 .30995 L .35974 .30454 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.39219 .28577 m .35974 .30454 L .36211 .30995 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.36211 .30995 m .39333 .29036 L .39219 .28577 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.33053 .67158 m .35974 .69546 L .36211 .69005 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39333 .70964 m .36211 .69005 L .35974 .69546 L p F P
.505 .664 .505 r
s
.516 .728 .557 r
.53702 .26592 m .5 .26345 L .53635 .26765 L closepath p F P
.505 .664 .505 r
s
.523 .735 .568 r
.57327 .27419 m .53702 .26592 L .53635 .26765 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .53702 .73408 L .53635 .73235 L closepath p F P
.505 .664 .505 r
s
.461 .653 .481 r
.427 .27253 m .39219 .28577 L .39333 .29036 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.39333 .29036 m .42727 .27585 L .427 .27253 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.35974 .69546 m .39219 .71423 L .39333 .70964 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.42727 .72415 m .39333 .70964 L .39219 .71423 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.46325 .26505 m .427 .27253 L .42727 .27585 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.42727 .27585 m .46311 .26679 L .46325 .26505 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39219 .71423 m .427 .72747 L .42727 .72415 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.46311 .73321 m .42727 .72415 L .427 .72747 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71775 .59657 m
.71972 .59422 L
s
.5 Mabswid
.504 .712 .539 r
.46311 .26679 m .5 .26345 L .46325 .26505 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.427 .72747 m .46325 .73495 L .46311 .73321 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .46311 .73321 L .46325 .73495 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .53608 .73581 L .53702 .73408 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .53351 .73747 L .53608 .73581 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .52942 .73899 L .53351 .73747 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .52395 .74028 L .52942 .73899 L closepath p F P
.505 .664 .505 r
s
.141 .151 .115 r
.5 .73655 m .51735 .74128 L .52395 .74028 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50992 .74195 L .51735 .74128 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50201 .74224 L .50992 .74195 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .494 .74214 L .50201 .74224 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .48628 .74166 L .494 .74214 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .47923 .74082 L .48628 .74166 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .47316 .73967 L .47923 .74082 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .46835 .73825 L .47316 .73967 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .46501 .73666 L .46835 .73825 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .46325 .73495 L .46501 .73666 L closepath p F P
.505 .664 .505 r
s
.506 .715 .548 r
.53608 .26419 m .5 .26345 L .53702 .26592 L closepath p F P
.505 .664 .505 r
s
.494 .702 .539 r
.53351 .26253 m .5 .26345 L .53608 .26419 L closepath p F P
.505 .664 .505 r
s
.493 .699 .53 r
.46325 .26505 m .5 .26345 L .46501 .26334 L closepath p F P
.505 .664 .505 r
s
.483 .689 .529 r
.52942 .26101 m .5 .26345 L .53351 .26253 L closepath p F P
.505 .664 .505 r
s
.482 .686 .521 r
.46501 .26334 m .5 .26345 L .46835 .26175 L closepath p F P
.505 .664 .505 r
s
.473 .676 .52 r
.52395 .25972 m .5 .26345 L .52942 .26101 L closepath p F P
.505 .664 .505 r
s
.472 .674 .513 r
.46835 .26175 m .5 .26345 L .47316 .26033 L closepath p F P
.505 .664 .505 r
s
.465 .666 .512 r
.51735 .25872 m .5 .26345 L .52395 .25972 L closepath p F P
.505 .664 .505 r
s
.464 .664 .506 r
.47316 .26033 m .5 .26345 L .47923 .25918 L closepath p F P
.505 .664 .505 r
s
.458 .658 .505 r
.50992 .25805 m .5 .26345 L .51735 .25872 L closepath p F P
.505 .664 .505 r
s
.458 .657 .502 r
.47923 .25918 m .5 .26345 L .48628 .25834 L closepath p F P
.505 .664 .505 r
s
.454 .652 .501 r
.50201 .25776 m .5 .26345 L .50992 .25805 L closepath p F P
.505 .664 .505 r
s
.454 .652 .499 r
.48628 .25834 m .5 .26345 L .494 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.494 .25786 m .5 .26345 L .50201 .25776 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71972 .59422 m
.72253 .58888 L
s
.5 Mabswid
.15 .16 .122 r
.57327 .72581 m .53702 .73408 L .53608 .73581 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.53702 .26592 m .57327 .27419 L .57192 .27086 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.57192 .27086 m .53608 .26419 L .53702 .26592 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71781 .59974 m
.7203 .5934 L
s
.7203 .5934 m
.72843 .57265 L
s
.5 Mabswid
.136 .147 .112 r
.60783 .71191 m .57327 .72581 L .57192 .72914 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.53608 .73581 m .57192 .72914 L .57327 .72581 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.57327 .27419 m .60783 .28809 L .60658 .28345 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.60658 .28345 m .57192 .27086 L .57327 .27419 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.60783 .28809 m .63983 .30728 L .63911 .30177 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.63911 .30177 m .60658 .28345 L .60783 .28809 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.63983 .69272 m .60783 .71191 L .60658 .71655 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.57192 .72914 m .60658 .71655 L .60783 .71191 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.42999 .73078 m .46501 .73666 L .46325 .73495 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.46325 .73495 m .427 .72747 L .42999 .73078 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.427 .27253 m .46325 .26505 L .46501 .26334 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.63983 .30728 m .66846 .33131 L .66858 .32547 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.66858 .32547 m .63911 .30177 L .63983 .30728 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.66846 .66869 m .63983 .69272 L .63911 .69823 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.60658 .71655 m .63911 .69823 L .63983 .69272 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.69297 .64039 m .66846 .66869 L .66858 .67453 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.63911 .69823 m .66858 .67453 L .66846 .66869 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.66846 .33131 m .69297 .35961 L .69409 .35401 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.69409 .35401 m .66858 .32547 L .66846 .33131 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.57192 .72914 m .53608 .73581 L .53351 .73747 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.53608 .26419 m .57192 .27086 L .56728 .26762 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.56728 .26762 m .53351 .26253 L .53608 .26419 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.69297 .35961 m .71274 .39146 L .71485 .38667 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.71485 .38667 m .69409 .35401 L .69297 .35961 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.71274 .60854 m .69297 .64039 L .69409 .64599 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.66858 .67453 m .69409 .64599 L .69297 .64039 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.71274 .39146 m .72724 .42606 L .73019 .42257 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.73019 .42257 m .71485 .38667 L .71274 .39146 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.72724 .57394 m .71274 .60854 L .71485 .61333 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.69409 .64599 m .71485 .61333 L .71274 .60854 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.39589 .71886 m .42999 .73078 L .427 .72747 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.427 .72747 m .39219 .71423 L .39589 .71886 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.46501 .26334 m .42999 .26922 L .427 .27253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.39219 .28577 m .427 .27253 L .42999 .26922 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.72724 .42606 m .73609 .46256 L .7396 .46071 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.7396 .46071 m .73019 .42257 L .72724 .42606 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73609 .53744 m .72724 .57394 L .73019 .57743 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.71485 .61333 m .73019 .57743 L .72724 .57394 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.73609 .46256 m .73907 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.74277 .5 m .7396 .46071 L .73609 .46256 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.73907 .5 m .73609 .53744 L .7396 .53929 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73019 .57743 m .7396 .53929 L .73609 .53744 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.7396 .53929 m .74277 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.43626 .73392 m .46835 .73825 L .46501 .73666 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.46501 .73666 m .42999 .73078 L .43626 .73392 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.42999 .26922 m .46501 .26334 L .46835 .26175 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71557 .61422 m
.7214 .59799 L
s
.5 Mabswid
.119 .131 .1 r
.36367 .701 m .39589 .71886 L .39219 .71423 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.39219 .71423 m .35974 .69546 L .36367 .701 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.42999 .26922 m .39589 .28114 L .39219 .28577 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.35974 .30454 m .39219 .28577 L .39589 .28114 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.53351 .73747 m .56728 .73238 L .57192 .72914 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56728 .73238 m .53351 .73747 L .52942 .73899 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.53351 .26253 m .56728 .26762 L .55944 .26462 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.55944 .26462 m .52942 .26101 L .53351 .26253 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.57192 .27086 m .60658 .28345 L .60039 .27887 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.60039 .27887 m .56728 .26762 L .57192 .27086 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.60658 .71655 m .57192 .72914 L .56728 .73238 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.44561 .73673 m .47316 .73967 L .46835 .73825 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.46835 .73825 m .43626 .73392 L .44561 .73673 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.43626 .26608 m .46835 .26175 L .47316 .26033 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.46835 .26175 m .43626 .26608 L .42999 .26922 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72606 .58842 m
.72775 .59057 L
s
.5 Mabswid
.342 .499 .362 r
.39589 .28114 m .36367 .299 L .35974 .30454 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.33053 .32842 m .35974 .30454 L .36367 .299 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.3343 .67749 m .36367 .701 L .35974 .69546 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.35974 .69546 m .33053 .67158 L .3343 .67749 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.52942 .73899 m .55944 .73538 L .56728 .73238 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.55944 .73538 m .52942 .73899 L .52395 .74028 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.52942 .26101 m .55944 .26462 L .54866 .26204 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.54866 .26204 m .52395 .25972 L .52942 .26101 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.30873 .64885 m .3343 .67749 L .33053 .67158 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.33053 .67158 m .30538 .64316 L .30873 .64885 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.36367 .299 m .3343 .32251 L .33053 .32842 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.30538 .35684 m .33053 .32842 L .3343 .32251 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.4577 .73906 m .47923 .74082 L .47316 .73967 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.47316 .73967 m .44561 .73673 L .4577 .73906 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.44561 .26327 m .47316 .26033 L .47923 .25918 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.47316 .26033 m .44561 .26327 L .43626 .26608 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.40457 .72332 m .43626 .73392 L .42999 .73078 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.42999 .73078 m .39589 .71886 L .40457 .72332 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.39589 .28114 m .42999 .26922 L .43626 .26608 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.63911 .69823 m .60658 .71655 L .60039 .72113 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.56728 .73238 m .60039 .72113 L .60658 .71655 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.60658 .28345 m .63911 .30177 L .63189 .29627 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.63189 .29627 m .60039 .27887 L .60658 .28345 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.52395 .74028 m .54866 .73796 L .55944 .73538 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.54866 .73796 m .52395 .74028 L .51735 .74128 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.52395 .25972 m .54866 .26204 L .5354 .26001 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.5354 .26001 m .51735 .25872 L .52395 .25972 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.3343 .32251 m .30873 .35115 L .30538 .35684 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.28501 .38909 m .30538 .35684 L .30873 .35115 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.28783 .6158 m .30873 .64885 L .30538 .64316 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.30538 .64316 m .28501 .61091 L .28783 .6158 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47197 .74076 m .48628 .74166 L .47923 .74082 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47923 .74082 m .4577 .73906 L .47197 .74076 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.4577 .26094 m .47923 .25918 L .48628 .25834 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.47923 .25918 m .4577 .26094 L .44561 .26327 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71557 .61422 m
.72487 .59421 L
s
.72487 .59421 m
.73319 .5763 L
s
.5 Mabswid
.232 .325 .291 r
.27233 .57924 m .28783 .6158 L .28501 .61091 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.28501 .61091 m .27002 .57566 L .27233 .57924 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.30873 .35115 m .28783 .3842 L .28501 .38909 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.27002 .42434 m .28501 .38909 L .28783 .3842 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.51735 .74128 m .5354 .73999 L .54866 .73796 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.5354 .73999 m .51735 .74128 L .50992 .74195 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.51735 .25872 m .5354 .26001 L .5203 .25865 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.5203 .25865 m .50992 .25805 L .51735 .25872 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.60039 .72113 m .56728 .73238 L .55944 .73538 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.56728 .26762 m .60039 .27887 L .58926 .27459 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.58926 .27459 m .55944 .26462 L .56728 .26762 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48771 .74174 m .494 .74214 L .48628 .74166 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48628 .74166 m .47197 .74076 L .48771 .74174 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.48628 .25834 m .47197 .25924 L .4577 .26094 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.47197 .25924 m .48628 .25834 L .494 .25786 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.28783 .3842 m .27233 .42076 L .27002 .42434 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.26084 .46165 m .27002 .42434 L .27233 .42076 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26467 .43676 m
.27235 .41372 L
s
.5 Mabswid
.204 .281 .258 r
.2628 .54024 m .27233 .57924 L .27002 .57566 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.27002 .57566 m .26084 .53835 L .2628 .54024 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.50992 .74195 m .5203 .74135 L .5354 .73999 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.5203 .74135 m .50992 .74195 L .50201 .74224 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50992 .25805 m .5203 .25865 L .50411 .25806 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50411 .25806 m .50201 .25776 L .50992 .25805 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.60039 .72113 m .63189 .70373 L .63911 .69823 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.66858 .67453 m .63911 .69823 L .63189 .70373 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.63911 .30177 m .66858 .32547 L .66077 .31957 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66077 .31957 m .63189 .29627 L .63911 .30177 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.27233 .42076 m .2628 .45976 L .26084 .46165 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.25977 .45148 m
.26467 .43676 L
s
.2664 .42507 m
.26715 .42645 L
s
.5 Mabswid
.141 .185 .177 r
.25775 .5 m .26084 .46165 L .2628 .45976 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.25958 .5 m .2628 .54024 L .26084 .53835 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.26084 .53835 m .25775 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.50411 .74194 m .50201 .74224 L .494 .74214 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.494 .74214 m .48771 .74174 L .50411 .74194 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.48771 .25826 m .494 .25786 L .50201 .25776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.494 .25786 m .48771 .25826 L .47197 .25924 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.50201 .74224 m .50411 .74194 L .5203 .74135 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.50201 .25776 m .50411 .25806 L .48771 .25826 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.2628 .45976 m .25958 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.37424 .70639 m .40457 .72332 L .39589 .71886 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.39589 .71886 m .36367 .701 L .37424 .70639 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.43626 .26608 m .40457 .27668 L .39589 .28114 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36367 .299 m .39589 .28114 L .40457 .27668 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.41809 .72736 m .44561 .73673 L .43626 .73392 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.43626 .73392 m .40457 .72332 L .41809 .72736 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.40457 .27668 m .43626 .26608 L .44561 .26327 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26214 .44322 m
.27133 .41118 L
s
.25977 .45148 m
.26214 .44322 L
s
.5 Mabswid
.241 .356 .243 r
.69409 .64599 m .66858 .67453 L .66077 .68043 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.63189 .70373 m .66077 .68043 L .66858 .67453 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.66858 .32547 m .69409 .35401 L .68605 .34829 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.68605 .34829 m .66077 .31957 L .66858 .32547 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.55944 .73538 m .58926 .72541 L .60039 .72113 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.58926 .72541 m .55944 .73538 L .54866 .73796 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.55944 .26462 m .58926 .27459 L .57348 .27086 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.57348 .27086 m .54866 .26204 L .55944 .26462 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.63189 .70373 m .60039 .72113 L .58926 .72541 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.60039 .27887 m .63189 .29627 L .61797 .29106 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.61797 .29106 m .58926 .27459 L .60039 .27887 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.69409 .35401 m .71485 .38667 L .70681 .38173 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.70681 .38173 m .68605 .34829 L .69409 .35401 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.71485 .61333 m .69409 .64599 L .68605 .65171 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.66077 .68043 m .68605 .65171 L .69409 .64599 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.34626 .68331 m .37424 .70639 L .36367 .701 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.36367 .701 m .3343 .67749 L .34626 .68331 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.40457 .27668 m .37424 .29361 L .36367 .299 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.3343 .32251 m .36367 .299 L .37424 .29361 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.43597 .73074 m .4577 .73906 L .44561 .73673 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.44561 .73673 m .41809 .72736 L .43597 .73074 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.41809 .27264 m .44561 .26327 L .4577 .26094 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.44561 .26327 m .41809 .27264 L .40457 .27668 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.73019 .57743 m .71485 .61333 L .70681 .61827 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.68605 .65171 m .70681 .61827 L .71485 .61333 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.71485 .38667 m .73019 .42257 L .72227 .41895 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.72227 .41895 m .70681 .38173 L .71485 .38667 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.54866 .73796 m .57348 .72914 L .58926 .72541 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.57348 .72914 m .54866 .73796 L .5354 .73999 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.54866 .26204 m .57348 .27086 L .55369 .26789 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.55369 .26789 m .5354 .26001 L .54866 .26204 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.7396 .53929 m .73019 .57743 L .72227 .58105 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.70681 .61827 m .72227 .58105 L .73019 .57743 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.73019 .42257 m .7396 .46071 L .7318 .4588 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.7318 .4588 m .72227 .41895 L .73019 .42257 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.39143 .71134 m .41809 .72736 L .40457 .72332 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.40457 .72332 m .37424 .70639 L .39143 .71134 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.37424 .29361 m .40457 .27668 L .41809 .27264 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.32164 .65452 m .34626 .68331 L .3343 .67749 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.3343 .67749 m .30873 .64885 L .32164 .65452 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.37424 .29361 m .34626 .31669 L .3343 .32251 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.30873 .35115 m .3343 .32251 L .34626 .31669 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.7396 .46071 m .74277 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.73502 .5 m .7318 .4588 L .7396 .46071 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.74277 .5 m .7396 .53929 L .7318 .5412 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.72227 .58105 m .7318 .5412 L .7396 .53929 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26295 .43739 m
.27761 .39678 L
s
.5 Mabswid
.221 .289 .192 r
.7318 .5412 m .73502 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.45741 .73324 m .47197 .74076 L .4577 .73906 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.4577 .73906 m .43597 .73074 L .45741 .73324 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.43597 .26926 m .4577 .26094 L .47197 .25924 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.4577 .26094 m .43597 .26926 L .41809 .27264 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26952 .41637 m
.27127 .41217 L
s
.5 Mabswid
.37 .529 .38 r
.66077 .68043 m .63189 .70373 L .61797 .70894 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.58926 .72541 m .61797 .70894 L .63189 .70373 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.63189 .29627 m .66077 .31957 L .64462 .31391 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.64462 .31391 m .61797 .29106 L .63189 .29627 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26374 .43527 m
.26452 .43173 L
s
.5 Mabswid
.394 .575 .434 r
.5354 .73999 m .55369 .73211 L .57348 .72914 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.55369 .73211 m .5354 .73999 L .5203 .74135 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5354 .26001 m .55369 .26789 L .53087 .2659 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.53087 .2659 m .5203 .25865 L .5354 .26001 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27127 .41217 m
.27239 .40988 L
s
.5 Mabswid
.42 .601 .443 r
.61797 .70894 m .58926 .72541 L .57348 .72914 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.58926 .27459 m .61797 .29106 L .59764 .28646 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.59764 .28646 m .57348 .27086 L .58926 .27459 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26358 .43692 m
.26374 .43527 L
s
.5 Mabswid
.463 .664 .513 r
.48129 .73469 m .48771 .74174 L .47197 .74076 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.47197 .74076 m .45741 .73324 L .48129 .73469 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.45741 .26676 m .47197 .25924 L .48771 .25826 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.47197 .25924 m .45741 .26676 L .43597 .26926 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.34626 .31669 m .32164 .34548 L .30873 .35115 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.28783 .3842 m .30873 .35115 L .32164 .34548 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30132 .62071 m .32164 .65452 L .30873 .64885 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30873 .64885 m .28783 .6158 L .30132 .62071 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27239 .40988 m
.27307 .4094 L
s
.5 Mabswid
.438 .63 .477 r
.5203 .74135 m .53087 .7341 L .55369 .73211 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.53087 .7341 m .5203 .74135 L .50411 .74194 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.5203 .25865 m .53087 .2659 L .50627 .26502 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.50627 .26502 m .50411 .25806 L .5203 .25865 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26358 .43692 m
.26424 .43657 L
s
.5 Mabswid
.472 .674 .517 r
.50627 .73498 m .50411 .74194 L .48771 .74174 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.48771 .74174 m .48129 .73469 L .50627 .73498 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.48129 .26531 m .48771 .25826 L .50411 .25806 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.48771 .25826 m .48129 .26531 L .45741 .26676 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.50411 .74194 m .50627 .73498 L .53087 .7341 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.50411 .25806 m .50627 .26502 L .48129 .26531 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28614 .58285 m .30132 .62071 L .28783 .6158 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28783 .6158 m .27233 .57924 L .28614 .58285 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.32164 .34548 m .30132 .37929 L .28783 .3842 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.27233 .42076 m .28783 .3842 L .30132 .37929 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27286 .41105 m
.27307 .4094 L
s
.5 Mabswid
.481 .675 .536 r
.36656 .68871 m .39143 .71134 L .37424 .70639 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.37424 .70639 m .34626 .68331 L .36656 .68871 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.41809 .27264 m .39143 .28866 L .37424 .29361 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.34626 .31669 m .37424 .29361 L .39143 .28866 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41472 .71552 m .43597 .73074 L .41809 .72736 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41809 .72736 m .39143 .71134 L .41472 .71552 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.39143 .28866 m .41809 .27264 L .43597 .26926 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.68605 .65171 m .66077 .68043 L .64462 .68609 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.61797 .70894 m .64462 .68609 L .66077 .68043 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66077 .31957 m .68605 .34829 L .66819 .34276 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66819 .34276 m .64462 .31391 L .66077 .31957 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26424 .43657 m
.26528 .43442 L
s
.5 Mabswid
.216 .253 .216 r
.30132 .37929 m .28614 .41715 L .27233 .42076 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27201 .41468 m
.27286 .41105 L
s
.5 Mabswid
.278 .344 .287 r
.2628 .45976 m .27233 .42076 L .28614 .41715 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27676 .54216 m .28614 .58285 L .27233 .57924 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27233 .57924 m .2628 .54024 L .27676 .54216 L p F P
.505 .664 .505 r
s
.42 .601 .443 r
.57348 .72914 m .59764 .71354 L .61797 .70894 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.59764 .71354 m .57348 .72914 L .55369 .73211 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57348 .27086 m .59764 .28646 L .57165 .28277 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57165 .28277 m .55369 .26789 L .57348 .27086 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.28614 .41715 m .27676 .45784 L .2628 .45976 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2703 .42044 m
.27201 .41468 L
s
.26528 .43442 m
.26696 .43032 L
s
.5 Mabswid
.329 .42 .348 r
.25958 .5 m .2628 .45976 L .27676 .45784 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.27358 .5 m .27676 .54216 L .2628 .54024 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.2628 .54024 m .25958 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26696 .43032 m
.26904 .42436 L
s
.26904 .42436 m
.2703 .42044 L
s
.5 Mabswid
.329 .42 .348 r
.27676 .45784 m .27358 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68605 .34829 m .70681 .38173 L .68772 .37692 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68772 .37692 m .66819 .34276 L .68605 .34829 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.70681 .61827 m .68605 .65171 L .66819 .65724 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.64462 .68609 m .66819 .65724 L .68605 .65171 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.64462 .68609 m .61797 .70894 L .59764 .71354 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.61797 .29106 m .64462 .31391 L .62029 .30886 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.62029 .30886 m .59764 .28646 L .61797 .29106 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.44307 .71864 m .45741 .73324 L .43597 .73074 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.43597 .73074 m .41472 .71552 L .44307 .71864 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.41472 .28448 m .43597 .26926 L .45741 .26676 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.43597 .26926 m .41472 .28448 L .39143 .28866 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34445 .65982 m .36656 .68871 L .34626 .68331 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34626 .68331 m .32164 .65452 L .34445 .65982 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.39143 .28866 m .36656 .31129 L .34626 .31669 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.32164 .34548 m .34626 .31669 L .36656 .31129 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.72227 .58105 m .70681 .61827 L .68772 .62308 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.66819 .65724 m .68772 .62308 L .70681 .61827 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.55369 .73211 m .57165 .71723 L .59764 .71354 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.57165 .71723 m .55369 .73211 L .53087 .7341 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70681 .38173 m .72227 .41895 L .70237 .41539 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70237 .41539 m .68772 .37692 L .70681 .38173 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.55369 .26789 m .57165 .28277 L .54132 .28027 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.54132 .28027 m .53087 .2659 L .55369 .26789 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27314 .41943 m
.27566 .4133 L
s
.27188 .42339 m
.27314 .41943 L
s
.27061 .42916 m
.27188 .42339 L
s
.27566 .4133 m
.27813 .40896 L
s
.5 Mabswid
.559 .772 .601 r
.39471 .69332 m .41472 .71552 L .39143 .71134 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39143 .71134 m .36656 .68871 L .39471 .69332 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.36656 .31129 m .39143 .28866 L .41472 .28448 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27056 .43283 m
.27061 .42916 L
s
.27813 .40896 m
.27998 .40662 L
s
.5 Mabswid
.569 .79 .603 r
.47494 .72046 m .48129 .73469 L .45741 .73324 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.45741 .73324 m .44307 .71864 L .47494 .72046 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.44307 .28136 m .45741 .26676 L .48129 .26531 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.45741 .26676 m .44307 .28136 L .41472 .28448 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.72227 .41895 m .7318 .4588 L .71144 .45691 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.71144 .45691 m .70237 .41539 L .72227 .41895 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.7318 .5412 m .72227 .58105 L .70237 .58461 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.68772 .62308 m .70237 .58461 L .72227 .58105 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27998 .40662 m
.28175 .40613 L
s
.27056 .43283 m
.27115 .43455 L
s
.5 Mabswid
.539 .752 .561 r
.53087 .7341 m .54132 .71973 L .57165 .71723 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.54132 .71973 m .53087 .7341 L .50627 .73498 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.53087 .2659 m .54132 .28027 L .5084 .27916 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.5084 .27916 m .50627 .26502 L .53087 .2659 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.36656 .31129 m .34445 .34018 L .32164 .34548 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.30132 .37929 m .32164 .34548 L .34445 .34018 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32606 .62534 m .34445 .65982 L .32164 .65452 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32164 .65452 m .30132 .62071 L .32606 .62534 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.66819 .65724 m .64462 .68609 L .62029 .69114 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.59764 .71354 m .62029 .69114 L .64462 .68609 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64462 .31391 m .66819 .34276 L .64051 .33778 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64051 .33778 m .62029 .30886 L .64462 .31391 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.5084 .72084 m .50627 .73498 L .48129 .73469 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.48129 .73469 m .47494 .72046 L .5084 .72084 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.47494 .27954 m .48129 .26531 L .50627 .26502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.48129 .26531 m .47494 .27954 L .44307 .28136 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.7318 .4588 m .73502 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.71452 .5 m .71144 .45691 L .7318 .4588 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.73502 .5 m .7318 .5412 L .71144 .54309 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.70237 .58461 m .71144 .54309 L .7318 .5412 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27115 .43455 m
.27294 .43419 L
s
.5 Mabswid
.567 .786 .59 r
.50627 .73498 m .5084 .72084 L .54132 .71973 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.50627 .26502 m .5084 .27916 L .47494 .27954 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.71144 .54309 m .71452 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.62029 .69114 m .59764 .71354 L .57165 .71723 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.59764 .28646 m .62029 .30886 L .58863 .30478 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.58863 .30478 m .57165 .28277 L .59764 .28646 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28175 .40613 m
.28227 .40785 L
s
.28217 .41161 m
.28227 .40785 L
s
.27294 .43419 m
.27474 .43198 L
s
.5 Mabswid
.538 .718 .564 r
.31222 .58629 m .32606 .62534 L .30132 .62071 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.30132 .62071 m .28614 .58285 L .31222 .58629 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.34445 .34018 m .32606 .37466 L .30132 .37929 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.28614 .41715 m .30132 .37929 L .32606 .37466 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27474 .43198 m
.27717 .42775 L
s
.28086 .41755 m
.28217 .41161 L
s
.5 Mabswid
.605 .828 .634 r
.42948 .69679 m .44307 .71864 L .41472 .71552 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.41472 .71552 m .39471 .69332 L .42948 .69679 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.39471 .30668 m .41472 .28448 L .44307 .28136 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.41472 .28448 m .39471 .30668 L .36656 .31129 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27717 .42775 m
.27961 .4216 L
s
.27961 .4216 m
.28086 .41755 L
s
.5 Mabswid
.595 .808 .625 r
.37677 .66439 m .39471 .69332 L .36656 .68871 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.36656 .68871 m .34445 .65982 L .37677 .66439 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.34445 .34018 m .36656 .31129 L .39471 .30668 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.66819 .34276 m .68772 .37692 L .65741 .37255 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.65741 .37255 m .64051 .33778 L .66819 .34276 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.68772 .62308 m .66819 .65724 L .64051 .66222 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.62029 .69114 m .64051 .66222 L .66819 .65724 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.30362 .54399 m .31222 .58629 L .28614 .58285 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.28614 .58285 m .27676 .54216 L .30362 .54399 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.32606 .37466 m .31222 .41371 L .28614 .41715 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.27676 .45784 m .28614 .41715 L .31222 .41371 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.57165 .71723 m .58863 .69522 L .62029 .69114 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.58863 .69522 m .57165 .71723 L .54132 .71973 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.57165 .28277 m .58863 .30478 L .55125 .302 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.55125 .302 m .54132 .28027 L .57165 .28277 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.31222 .41371 m .30362 .45601 L .27676 .45784 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27887 .44665 m
.28156 .43685 L
s
.28156 .43685 m
.29052 .4042 L
s
.5 Mabswid
.465 .594 .465 r
.27358 .5 m .27676 .45784 L .30362 .45601 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.3007 .5 m .30362 .54399 L .27676 .54216 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.27676 .54216 m .27358 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.30362 .45601 m .3007 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.4689 .69883 m .47494 .72046 L .44307 .71864 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.44307 .71864 m .42948 .69679 L .4689 .69883 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.42948 .30321 m .44307 .28136 L .47494 .27954 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.44307 .28136 m .42948 .30321 L .39471 .30668 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.62029 .30886 m .64051 .33778 L .60391 .33372 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.60391 .33372 m .58863 .30478 L .62029 .30886 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.64051 .66222 m .62029 .69114 L .58863 .69522 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.68772 .37692 m .70237 .41539 L .67017 .41214 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.67017 .41214 m .65741 .37255 L .68772 .37692 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.70237 .58461 m .68772 .62308 L .65741 .62745 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.64051 .66222 m .65741 .62745 L .68772 .62308 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.54132 .71973 m .55125 .698 L .58863 .69522 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.55125 .698 m .54132 .71973 L .5084 .72084 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.54132 .28027 m .55125 .302 L .51043 .30076 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.51043 .30076 m .5084 .27916 L .54132 .28027 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.39471 .30668 m .37677 .33561 L .34445 .34018 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.32606 .37466 m .34445 .34018 L .37677 .33561 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.36172 .62936 m .37677 .66439 L .34445 .65982 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.34445 .65982 m .32606 .62534 L .36172 .62936 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.51043 .69924 m .5084 .72084 L .47494 .72046 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.47494 .72046 m .4689 .69883 L .51043 .69924 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.4689 .30117 m .47494 .27954 L .5084 .27916 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.47494 .27954 m .4689 .30117 L .42948 .30321 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28747 .44221 m
.29788 .40294 L
s
.28649 .44591 m
.28747 .44221 L
s
.5 Mabswid
.622 .846 .63 r
.5084 .72084 m .51043 .69924 L .55125 .698 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.5084 .27916 m .51043 .30076 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.37677 .33561 m .39471 .30668 L .42948 .30321 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.41721 .66786 m .42948 .69679 L .39471 .69332 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.39471 .69332 m .37677 .66439 L .41721 .66786 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.71144 .54309 m .70237 .58461 L .67017 .58786 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.65741 .62745 m .67017 .58786 L .70237 .58461 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.70237 .41539 m .71144 .45691 L .67811 .45518 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.67811 .45518 m .67017 .41214 L .70237 .41539 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.71144 .45691 m .71452 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.6808 .5 m .67811 .45518 L .71144 .45691 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.71452 .5 m .71144 .54309 L .67811 .54482 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.67017 .58786 m .67811 .54482 L .71144 .54309 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.64051 .33778 m .65741 .37255 L .61675 .36896 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.61675 .36896 m .60391 .33372 L .64051 .33778 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.65741 .62745 m .64051 .66222 L .60391 .66628 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.58863 .69522 m .60391 .66628 L .64051 .66222 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.67811 .54482 m .6808 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.37677 .33561 m .36172 .37064 L .32606 .37466 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.31222 .41371 m .32606 .37466 L .36172 .37064 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.35034 .58928 m .36172 .62936 L .32606 .62534 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.32606 .62534 m .31222 .58629 L .35034 .58928 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.60391 .66628 m .58863 .69522 L .55125 .698 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.58863 .30478 m .60391 .33372 L .56023 .33093 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.56023 .33093 m .55125 .302 L .58863 .30478 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30137 .41448 m
.30441 .40805 L
s
.3002 .41866 m
.30137 .41448 L
s
.30441 .40805 m
.30811 .40353 L
s
.29974 .42477 m
.3002 .41866 L
s
.30811 .40353 m
.31121 .40112 L
s
.29974 .42477 m
.30115 .42868 L
s
.5 Mabswid
.652 .874 .659 r
.46342 .6699 m .4689 .69883 L .42948 .69679 L p F P
.505 .664 .505 r
s
.652 .874 .659 r
.42948 .69679 m .41721 .66786 L .46342 .6699 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.41721 .33214 m .42948 .30321 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.42948 .30321 m .41721 .33214 L .37677 .33561 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30115 .42868 m
.30317 .43053 L
s
.5 Mabswid
.592 .774 .593 r
.34324 .54559 m .35034 .58928 L .31222 .58629 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.31222 .58629 m .30362 .54399 L .34324 .54559 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.36172 .37064 m .35034 .41072 L .31222 .41371 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31121 .40112 m
.31497 .40068 L
s
.5 Mabswid
.498 .627 .477 r
.30362 .45601 m .31222 .41371 L .35034 .41072 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31497 .40068 m
.3169 .40252 L
s
.5 Mabswid
.433 .526 .39 r
.36172 .37064 m .37677 .33561 L .41721 .33214 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.40686 .63243 m .41721 .66786 L .37677 .66439 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.37677 .66439 m .36172 .62936 L .40686 .63243 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30317 .43053 m
.30705 .4302 L
s
.5 Mabswid
.622 .836 .613 r
.55125 .698 m .56023 .66907 L .60391 .66628 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.56023 .66907 m .55125 .698 L .51043 .69924 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.55125 .302 m .56023 .33093 L .51227 .32969 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.51227 .32969 m .51043 .30076 L .55125 .302 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.3169 .40252 m
.3183 .40652 L
s
.5 Mabswid
.585 .769 .551 r
.67017 .58786 m .65741 .62745 L .61675 .63104 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.60391 .66628 m .61675 .63104 L .65741 .62745 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.65741 .37255 m .67017 .41214 L .6265 .40946 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.6265 .40946 m .61675 .36896 L .65741 .37255 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.35034 .41072 m .34324 .45441 L .30362 .45601 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30705 .4302 m
.31019 .42791 L
s
.5 Mabswid
.538 .687 .524 r
.3007 .5 m .30362 .45601 L .34324 .45441 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.34082 .5 m .34324 .54559 L .30362 .54399 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.30362 .54399 m .3007 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.51227 .67031 m .51043 .69924 L .4689 .69883 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.4689 .69883 m .46342 .6699 L .51227 .67031 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.46342 .3301 m .4689 .30117 L .51043 .30076 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.4689 .30117 m .46342 .3301 L .41721 .33214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31791 .41279 m
.3183 .40652 L
s
.5 Mabswid
.645 .864 .639 r
.51043 .69924 m .51227 .67031 L .56023 .66907 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.51043 .30076 m .51227 .32969 L .46342 .3301 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.34324 .45441 m .34082 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31019 .42791 m
.31389 .42349 L
s
.31681 .41704 m
.31791 .41279 L
s
.31389 .42349 m
.31681 .41704 L
s
.5 Mabswid
.425 .514 .356 r
.60391 .33372 m .61675 .36896 L .56782 .36649 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.56782 .36649 m .56023 .33093 L .60391 .33372 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.61675 .63104 m .60391 .66628 L .56023 .66907 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32433 .42897 m
.33166 .39899 L
s
.5 Mabswid
.57 .742 .528 r
.67811 .54482 m .67017 .58786 L .6265 .59054 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.61675 .63104 m .6265 .59054 L .67017 .58786 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.67017 .41214 m .67811 .45518 L .63259 .45374 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.63259 .45374 m .6265 .40946 L .67017 .41214 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.39899 .59158 m .40686 .63243 L .36172 .62936 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.36172 .62936 m .35034 .58928 L .39899 .59158 L p F P
.505 .664 .505 r
s
.433 .526 .39 r
.41721 .33214 m .40686 .36757 L .36172 .37064 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.35034 .41072 m .36172 .37064 L .40686 .36757 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.40686 .36757 m .41721 .33214 L .46342 .3301 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.45878 .63424 m .46342 .6699 L .41721 .66786 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.41721 .66786 m .40686 .63243 L .45878 .63424 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32611 .42048 m
.32949 .42655 L
s
.5 Mabswid
.518 .658 .461 r
.67811 .45518 m .6808 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.63466 .5 m .63259 .45374 L .67811 .45518 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.6808 .5 m .67811 .54482 L .63259 .54626 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.6265 .59054 m .63259 .54626 L .67811 .54482 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32949 .42655 m
.33233 .42848 L
s
.5 Mabswid
.548 .705 .498 r
.63259 .54626 m .63466 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.56023 .66907 m .56782 .63351 L .61675 .63104 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.56023 .33093 m .56782 .36649 L .51383 .36538 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.51383 .36538 m .51227 .32969 L .56023 .33093 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.56782 .63351 m .56023 .66907 L .51227 .67031 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33233 .42848 m
.33735 .4282 L
s
.5 Mabswid
.621 .815 .591 r
.6265 .59054 m .61675 .63104 L .56782 .63351 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.61675 .36896 m .6265 .40946 L .57359 .40761 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.57359 .40761 m .56782 .36649 L .61675 .36896 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.39407 .54682 m .39899 .59158 L .35034 .58928 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.35034 .58928 m .34324 .54559 L .39407 .54682 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.40686 .36757 m .39899 .40842 L .35034 .41072 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.34324 .45441 m .35034 .41072 L .39899 .40842 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34416 .41933 m
.34921 .39758 L
s
.5 Mabswid
.465 .568 .408 r
.45878 .36576 m .46342 .3301 L .51227 .32969 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.51383 .63462 m .51227 .67031 L .46342 .6699 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.46342 .6699 m .45878 .63424 L .51383 .63462 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.46342 .3301 m .45878 .36576 L .40686 .36757 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33735 .4282 m
.34118 .42588 L
s
.34118 .42588 m
.34416 .41933 L
s
.5 Mabswid
.648 .859 .632 r
.51227 .67031 m .51383 .63462 L .56782 .63351 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.51227 .32969 m .51383 .36538 L .45878 .36576 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.39899 .40842 m .39407 .45318 L .34324 .45441 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.35712 .42724 m
.36323 .39664 L
s
.5 Mabswid
.574 .732 .549 r
.34082 .5 m .34324 .45441 L .39407 .45318 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.3924 .5 m .39407 .54682 L .34324 .54559 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.34324 .54559 m .34082 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.45525 .59294 m .45878 .63424 L .40686 .63243 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.40686 .63243 m .39899 .59158 L .45525 .59294 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.39899 .40842 m .40686 .36757 L .45878 .36576 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.39407 .45318 m .3924 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.63259 .54626 m .6265 .59054 L .57359 .59239 L p F P
.505 .664 .505 r
s
.621 .815 .591 r
.56782 .63351 m .57359 .59239 L .6265 .59054 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.6265 .40946 m .63259 .45374 L .57721 .45275 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.57721 .45275 m .57359 .40761 L .6265 .40946 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.37971 .39791 m
.3841 .39549 L
s
.37643 .40465 m
.37971 .39791 L
s
.35308 .44225 m
.35473 .4443 L
s
.35308 .44225 m
.35526 .44007 L
s
.35526 .44007 m
.35691 .44212 L
s
.3841 .39549 m
.39008 .39521 L
s
.37275 .42661 m
.37643 .40465 L
s
.35473 .4443 m
.35691 .44212 L
s
.5 Mabswid
.641 .84 .615 r
.57359 .59239 m .56782 .63351 L .51383 .63462 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.56782 .36649 m .57359 .40761 L .51502 .40678 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.51502 .40678 m .51383 .36538 L .56782 .36649 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.39008 .39521 m
.39373 .39726 L
s
.39373 .39726 m
.39882 .40371 L
s
.5 Mabswid
.517 .644 .466 r
.45525 .40706 m .45878 .36576 L .51383 .36538 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.51502 .59322 m .51383 .63462 L .45878 .63424 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.45878 .63424 m .45525 .59294 L .51502 .59322 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.45878 .36576 m .45525 .40706 L .39899 .40842 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.63259 .45374 m .63466 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.57845 .5 m .57721 .45275 L .63259 .45374 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.63466 .5 m .63259 .54626 L .57721 .54725 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.57359 .59239 m .57721 .54725 L .63259 .54626 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.45304 .54755 m .45525 .59294 L .39899 .59158 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.39899 .59158 m .39407 .54682 L .45304 .54755 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.39407 .45318 m .39899 .40842 L .45525 .40706 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.39578 .42587 m
.40031 .39477 L
s
.5 Mabswid
.641 .84 .615 r
.51383 .63462 m .51502 .59322 L .57359 .59239 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.51383 .36538 m .51502 .40678 L .45525 .40706 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.57721 .54725 m .57845 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.41415 .40097 m
.41695 .39641 L
s
.41695 .39641 m
.42381 .39396 L
s
.42381 .39396 m
.43042 .39378 L
s
.43042 .39378 m
.43686 .39587 L
s
.5 Mabswid
.626 .813 .593 r
.57721 .54725 m .57359 .59239 L .51502 .59322 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.57359 .40761 m .57721 .45275 L .51576 .4523 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.51576 .4523 m .51502 .40678 L .57359 .40761 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.45525 .40706 m .45304 .45245 L .39407 .45318 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.3924 .5 m .39407 .45318 L .45304 .45245 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.45228 .5 m .45304 .54755 L .39407 .54682 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.39407 .54682 m .3924 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.43686 .39587 m
.43866 .40033 L
s
.41466 .41432 m
.41938 .41198 L
s
.41193 .41883 m
.41466 .41432 L
s
.41193 .41883 m
.41371 .42321 L
s
.41938 .41198 m
.43093 .40947 L
s
.43844 .40258 m
.43866 .40033 L
s
.41371 .42321 m
.42031 .42527 L
s
.5 Mabswid
.588 .75 .555 r
.45304 .45245 m .45228 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.43572 .40713 m
.43844 .40258 L
s
.45756 .39321 m
.45971 .39544 L
s
.45509 .39551 m
.45756 .39321 L
s
.43093 .40947 m
.43572 .40713 L
s
.45509 .39551 m
.45723 .39774 L
s
.45723 .39774 m
.45971 .39544 L
s
.5 Mabswid
.558 .703 .512 r
.45304 .45245 m .45525 .40706 L .51502 .40678 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.51576 .5477 m .51502 .59322 L .45525 .59294 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.45525 .59294 m .45304 .54755 L .51576 .5477 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.42031 .42527 m
.42722 .42513 L
s
.42722 .42513 m
.43438 .42279 L
s
.5 Mabswid
.626 .813 .593 r
.51502 .59322 m .51576 .5477 L .57721 .54725 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.51502 .40678 m .51576 .4523 L .45304 .45245 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.43438 .42279 m
.43707 .41829 L
s
.45492 .44015 m
.45648 .40903 L
s
.5 Mabswid
.58 .739 .534 r
.57721 .45275 m .57845 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.51602 .5 m .51576 .4523 L .57721 .45275 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.57845 .5 m .57721 .54725 L .51576 .5477 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.51576 .5477 m .51602 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.45228 .5 m .45304 .45245 L .51576 .4523 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.51602 .5 m .51576 .5477 L .45304 .54755 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.45304 .54755 m .45228 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.51576 .4523 m .51602 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>l0/>3V4P21ZH7b0;3PiP40oooo003X0;3PiPP0PJV10P0S9A`0
0`21ZH409BLN02DW7P0602DW7P04086YP@0U9ah09BLN02DW7Pl0PJV1i@2`h>H10?ooo`00hP2`h>H6
086YP@0301hQ6@21ZH40PJV100H08bDL00<0PJV102DW7P0U9ah01`0U9ah00`21ZH409BLN02DW7P06
02DW7P80PJV11`0R9A`6086YPN00/>3V0@3oool00=`0/>3V1`21ZH4401hQ6@80PJV1200S9A`00`21
ZH409BLN02DW7P0802DW7P03086YP@0U9ah09BLN00L09BLN0P21ZH47028U7080PJV10P0M8AT3086Y
PMd0/>3V0@3oool00=P0/>3V1@21ZH400`0G6a@0PJV1086YP@0501hQ6@80PJV1100S9A`S086YP@<0
8RDL0P21ZH4201dQ6@@0PJV1fP2`h>H10?ooo`00eP2`h>H4086YP@0301LK5021ZH40PJV100807R4I
3021ZH4403@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=3HX
03@f:00203@f:0T0PJV100<07B4I086YP@21ZH400`21ZH7F0;3PiP40oooo003C0;3PiP`0PJV1100_
<BD00`21ZH40=3HX03@f:00903@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02`0g
>2/00`21ZH40=3HX03@f:00803@f:003086YP@0^<2D0PJV100L0PJV1e02`h>H10?ooo`00d02`h>H9
086YP@T0;c4U00<0PJV103@f:00d=RP02@0d=RP00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0g>2/0
=cP[00`0=cP[00<0PJV103@f:00d=RP0200d=RP00`21ZH40;S0U02h`9@0302h`9@H0PJV1d@2`h>H1
0?ooo`00cP2`h>H5086YP@<09RTO00<0PJV102la9@0_<BD0200_<BD00`21ZH40=3HX03@f:00:03@f
:003086YP@0g>2/0=cP[00`0=cP[00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=3HX03@f:00903@f
:003086YP@0^<2D0;S0U00D0;S0U1P21ZH7>0;3PiP40oooo003;0;3PiPD0PJV1100V:Al2086YP@X0
;c4U00<0PJV103@f:00d=RP02P0d=RP00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0g>2/0=cP[00`0
=cP[00<0PJV103@f:00d=RP02@0d=RP2086YP@L0;S0U0P21ZH400`0V:1h0PJV1086YP@02086YPL/0
/>3V0@3oool00<T0/>3V0P21ZH400`0K7QL0PJV1086YP@0402HY7`80PJV12`0_<BD00`21ZH40=3HX
03@f:00;03@f:003086YP@0g>2/0=cP[00d0=cP[00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=3HX
03@f:00:03@f:003086YP@0^<2D0;S0U00H0;S0U00@0PJV102HX7P0V:1h09RPN0`21ZH790;3PiP40
oooo00370;3PiP80PJV10P0K7QL00`21ZH409RTO02HY7`0302HY7`03086YP@0_<BD0;c4U00X0;c4U
00<0PJV103@f:00d=RP0100d=RP]086YP@T0=3HX00<0PJV102h`9@0^<2D01P0^<2D2086YP@<09RPN
0`21ZH770;3PiP40oooo00350;3PiP80PJV10P0K7QL2086YP@@09RTO0P21ZH4502la9@l0PJV11`1:
DSX00`21ZH40CUPn04iH?P0>04iH?P03086YP@1>F3h0CUPn00h0CUPn00@0PJV104YB>`1:DS/0BU8k
2021ZH4203@f:003086YP@0^<2D0;S0U00L0;S0U0P21ZH4302HX7P<0PJV1a@2`h>H10?ooo`00``2`
h>H2086YP@<06ahG00<0PJV102HY7`0V:Al00P0V:Al9086YP@H0@DHc00<0PJV104YB>P1:DSX0301:
DSX00`21ZH40CUPn04iH?P0?04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0201:
DS/:086YP@@0;S0U0P21ZH4302HX7P<0PJV1``2`h>H10?ooo`00`@2`h>H2086YP@<06ahG0P21ZH40
0`0V:Al0PJV1086YP@03086YP@h0@DHc00<0PJV104YB>P1:DSX0301:DSX00`21ZH40CUPn04iH?P0?
04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`03
0456<`P0PJV10P0V:1h4086YPL40/>3V0@3oool00;l0/>3V0P21ZH4301/N5`D0PJV10`0b=2L00`21
ZH40@DHc0456<`0<0456<`03086YP@1:DSX0BU8j00d0BU8j00<0PJV104iH?P1>F3h03`1>F3h00`21
ZH40CUPn04iH?P0@04iH?P03086YP@1:DS/0BU8k00/0BU8k00<0PJV10456<`11AS<02P11AS<4086Y
P@0302HX7P21ZH40PJV10080PJV1_`2`h>H10?ooo`00_@2`h>H2086YP@806ahG1021ZH46038d9`03
086YP@11AS<0@DHc00`0@DHc00<0PJV104YB>P1:DSX03P1:DSX00`21ZH40CUPn04iH?P0?04iH?P03
086YP@1>F3h0CUPn0100CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`0:0456<`03
086YP@0b=2L0<S@W00L0PJV1_@2`h>H10?ooo`00^`2`h>H6086YP@0302DX7P21ZH40<S@W00L0<S@W
00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0=04YB>P03086YP@1>F3h0CUPn0140CUPn
00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0<04YB>`03086YP@11AS<0@DHc00X0@DHc
00<0PJV1038d9`0b=2L00`0b=2L5086YPK/0/>3V0@3oool00;X0/>3V0`21ZH4402DX7P03086YP@0b
=2L0<S@W00H0<S@W00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0>04YB>P03086YP@1>
F3h0CUPn0140CUPn00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0=04YB>`03086YP@11
AS<0@DHc00X0@DHc00<0PJV1038d9`0b=2L0100b=2L5086YPKT0/>3V0@3oool00;P0/>3V0P21ZH45
02DX7P80PJV1200b=2L00`21ZH40@DHc0456<`0=0456<`03086YP@1:DSX0BU8j00h0BU8j00<0PJV1
04iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A04iH?P03086YP@1:DS/0BU8k00`0BU8k00<0PJV1
0456<`11AS<02`11AS<00`21ZH40<S@W038d9`04038d9`04086YP@0T9ah092LN02@W7P80PJV1]`2`
h>H10?ooo`00]P2`h>H3086YP@D09BPN00<0PJV1038d9`0b=2L01`0b=2L00`21ZH40@DHc0456<`0=
0456<`03086YP@1:DSX0BU8j00l0BU8j00<0PJV104iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A
04iH?P03086YP@1:DS/0BU8k00d0BU8k00<0PJV10456<`11AS<02P11AS<00`21ZH40<S@W038d9`05
038d9`80PJV10`0T9ah00`21ZH40/>3V0;3PiP2d0;3PiP40oooo002e0;3PiP<0PJV11@0U:1h00`21
ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc00d0@DHc00<0PJV104YB>P1:DSX03`1:DSX00`21
ZH40CUPn04iH?P0B04iH?P03086YP@1>F3h0CUPn0180CUPn00<0PJV104YB>`1:DS/03@1:DS/00`21
ZH40@DHc0456<`0:0456<`03086YP@0b=2L0<S@W00H0<S@W00D0PJV102@W7P0T9ah092LN086YP@2e
0;3PiP40oooo002c0;3PiP<0PJV11P0U:1h00`21ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc
00h0@DHc00<0PJV104YB>P1:DSX01P1:DSXh086YP@`0BU8k00<0PJV10456<`11AS<02P11AS<00`21
ZH40<S@W038d9`06038d9`04086YP@0T9ah092LN02@W7P80PJV1/`2`h>H10?ooo`00/P2`h>H00`21
ZH4051PB086YP@0602DX7P03086YP@0b=2L0<S@W00P0<S@W00<0PJV10456<`11AS<02@11AS<>086Y
P@T0HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00B065cD003086YP@1KJdX0Ff]:
0080Ff]:2@21ZH4304YB>`03086YP@11AS<0@DHc00/0@DHc00<0PJV1038d9`0b=2L01P0b=2L00`21
ZH4092LN02@W7P0202@W7P03086YP@2`h>H0/>3V0;00/>3V0@3oool00;40/>3V00<0PJV101@H4P21
ZH401@0U:1h2086YP@X0<S@W00@0PJV10456<`11AS<0@DHc2@21ZH4405YZCP03086YP@1RM5@0HWAD
0100HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:
00X0Ff]:2021ZH4:0456<`03086YP@0b=2L0<S@W00H0<S@W00<0PJV102@W7P0T9ah00P0T9ah00`21
ZH40/>3V0;3PiP2_0;3PiP40oooo002_0;3PiP04086YP@0D618051PB086YP@D09BPN00<0PJV1038d
9`0b=2L01P0b=2L8086YP@`0FVY>00<0PJV1069dE01RM5@04@1RM5@00`21ZH40I7MD06AgE00B06Ag
E003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX03`1KJdX00`21ZH40Df1305=P@`08086Y
P@<0@DHc00<0PJV1038d9`0b=2L01P0b=2L2086YP@<092LN00<0PJV10;3PiP2`h>H0[P2`h>H10?oo
o`00[P2`h>H01021ZH4051PB01@H4P21ZH4502DX7P03086YP@0b=2L0<S@W00L0PJV10P1;ET400`21
ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0100HWAD00<0PJV106AgE01TMe@04`1TMe@00`21
ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:00l0Ff]:00<0PJV105=P@`1CH4<0201CH4<7086Y
P@L0<S@W00D0PJV102@W7P0T9ah092LN086YP@2_0;3PiP40oooo002]0;3PiP04086YP@0D6180PJV1
086YP@@09BPN1@21ZH4904]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1069dE01RM5@04@1RM5@0
0`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX0401KJdX0
0`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0PJV100D0PJV10P0b=2L01@21ZH4092LN02@W7P0T
9ah0PJV10:h0/>3V0@3oool00:/0/>3V00@0PJV101@H4P0D6180PJV10`0U:1h4086YP@`0BeI100<0
PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD069dE00A069dE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0?05][BP03086YP@1CH4<0Df1300`0Df1300<0
PJV104A<=P14C3H01@14C3H5086YP@8092LN0P21ZH6/0;3PiP40oooo002Z0;3PiP03086YP@0D6180
51PB00D0PJV10P0b=R/00`21ZH40BeI104]F@@0;04]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1
069dE01RM5@04P1RM5@00`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV1
05][BP1KJdX0401KJdX00`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0A4`f00P0A4`f0`21ZH42
02@W7P03086YP@2`h>H0/>3V0:T0/>3V0@3oool00:T0/>3V0P0D6183086YP@H0<SH[00<0PJV104]F
@@1;ET402P1;ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0180HWAD00<0PJV106Ag
E01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:0100Ff]:00<0PJV105=P
@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0PJV100<0PJV1ZP2`h>H10?oo
o`00Y`2`h>H5086YP@L0<SH[00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0?05YZCP03
086YP@1RM5@0HWAD0180HWAD00<0PJV106AgE01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003
086YP@1KJdX0Ff]:0140Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0704A<=P03
086YP@0];b@0;BlT0080;BlT0P21ZH6Y0;3PiP40oooo002V0;3PiP80PJV10P0K7aL00`21ZH40<SH[
038f:`05038f:`03086YP@1;ET40BeI100/0BeI100<0PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD
069dE00C069dE003086YP@1TMe@0I7MD01@0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:
05][BP0A05][BP03086YP@1CH4<0Df1300`0Df1300<0PJV104A<=P14C3H02014C3H00`21ZH40;BlT
02d_900302d_9080PJV1Y`2`h>H10?ooo`00Y@2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[
00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0@05YZCP03086YP@1RM5@0HWAD0180HWAD
00<0PJV106AgE01TMe@05@1TMe@00`21ZH40HG=@065cD00D065cD003086YP@1KJdX0Ff]:0140Ff]:
00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00<0;BlT
0P21ZH6V0;3PiP40oooo002T0;3PiP03086YP@0K7aL06alG00806alG00<0PJV1038f:`0b=R/0100b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00l0FVY>00<0PJV1069dE01RM5@04`1R
M5@00`21ZH40I7MD06AgE00E06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV105][BP1KJdX04P1K
JdX00`21ZH40Df1305=P@`0=05=P@`03086YP@14C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0]
;b@2086YPJD0/>3V0@3oool00:@0/>3V00D0PJV101/O5`0K7aL06alG086YP@07038f:`03086YP@1;
ET40BeI100/0BeI100<0PJV105YZCP1JJTh0401JJTh00`21ZH40HWAD069dE00C069dE003086YP@1T
Me@0I7MD01D0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0B05][BP03086YP@1C
H4<0Df1300d0Df1300<0PJV104A<=P14C3H02@14C3H00`21ZH40;BlT02d_900302d_9080PJV1Y02`
h>H10?ooo`00X`2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[00<0PJV104]F@@1;ET40301;
ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD00T0HWAD;`21ZH4<065cD003086YP@1K
JdX0Ff]:0180Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0]
;b@0;BlT00@0;BlT0P21ZH6S0;3PiP40oooo002R0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00`0FVY>4021ZH4;07F?J003086YP@1g
TFP0Mi5X01D0Mi5X00<0PJV107B=I01dSF@02@1dSF@G086YP@X0Ff]:00<0PJV105=P@`1CH4<03P1C
H4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00@0;BlT0P21ZH6R0;3PiP40oooo002Q
0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b=R/00`21ZH40BeI104]F@@0=04]F@@03086YP@1J
JTh0FVY>0080FVY>2P21ZH4406j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05@1g
TFP00`21ZH40M8eT07B=I00E07B=I003086YP@1/Pe/0K8=K00P0K8=K4021ZH4<05=P@`03086YP@14
C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2Q0;3PiP40oooo002P
0;3PiP05086YP@0K7aL06alG01/O5`21ZH40200b=R/00`21ZH40BeI104]F@@0804]F@@X0PJV13@1^
QV<00`21ZH40MHmX07F?J00D07F?J003086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05@1d
SF@00`21ZH40K8=K06b3F`0C06b3F`03086YP@1QM4l0HGA?0080HGA?2@21ZH4305=P@`03086YP@14
C3H0A4`f00T0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2P0;3PiP40oooo002P
0;3PiP04086YP@0K7aL06alG086YP@P0<SH[00@0PJV104]F@@1;ET40BeI12021ZH44065dF003086Y
P@1^QV<0KXIS0100KXIS00<0PJV107F?J01eSfP0501eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01H0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0:065dC`L0PJV1
2@14C3H00`21ZH40;BlT02d_900302d_9003086YP@0I7AH0PJV109l0/>3V0@3oool009l0/>3V00D0
PJV101/O5`0K7aL06alG086YP@06038f:`H0PJV12`1QM5P00`21ZH40KXIS06j6H`0A06j6H`03086Y
P@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086Y
P@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df93086YP@03086YP@D0A4`f
00<0PJV102d_900];b@0100];b@2086YPIl0/>3V0@3oool009h0/>3V00D0PJV101/O5`0K7aL06alG
086YP@03038f:`D0PJV1401QM5P00`21ZH40KXIS06j6H`0A06j6H`03086YP@1eSfP0MHmX01@0MHmX
00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0K8=K01<0K8=K
00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df9305=R@`0305=R@`D0PJV100<0A4`f086YP@0];b@0
1@0];b@2086YPIh0/>3V0@3oool009d0/>3V00@0PJV101/O5`0K7aL06alG1@21ZH4404UE@`03086Y
P@1QM5P0HGAH00d0HGAH00<0PJV106j6H`1^QV<04@1^QV<00`21ZH40MHmX07F?J00E07F?J003086Y
P@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05P1dSF@00`21ZH40K8=K06b3F`0D06b3F`03086Y
P@1QM4l0HGA?00l0HGA?00<0PJV105=R@`1CHT<01`1CHT<5086YP@@0;BlT0P21ZH6M0;3PiP40oooo
002L0;3PiP04086YP@0K7aL06alG01/O5`80PJV11`19ED<00`21ZH40HGAH065dF00>065dF003086Y
P@1^QV<0KXIS0140KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01L0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0?065dC`03086Y
P@1CHT<0Df9300X0Df9300<0PJV103]3<021ZH400`21ZH400`0];b@0PJV1086YP@2L0;3PiP40oooo
002L0;3PiP04086YP@0K7aL0PJV1086YP@T0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS
06j6H`0B06j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05`1gTFP00`21ZH40M8eT
07B=I00G07B=I003086YP@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df93
05=R@`0905=R@`03086YP@0k@c00>d<`00<0>d<`1021ZH6K0;3PiP40oooo002K0;3PiP<0PJV100<0
:2hV086YP@19ED<01`19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0140KXIS00<0
PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01H0M8eT00<0
PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0?065dC`03086YP@1CHT<0Df9300X0Df9300<0
PJV103]3<00k@c001@0k@c02086YPIX0/>3V0@3oool009X0/>3V0P21ZH4202P^9P03086YP@19ED<0
BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0B06j6H`03086YP@1eSfP0
MHmX01D0MHmX00<0PJV107NAJ01gTFP0601gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0
K8=K01@0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df9305=R@`0905=R@`03086YP@0k@c00
>d<`00D0>d<`0`21ZH6I0;3PiP40oooo002I0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE
@`19ED<01P19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c001@0k@c000`21ZH407b8J086YP@2H0;3PiP40oooo002I0;3PiP05086YP@0X;RH0:2hV02P^
9P21ZH402@19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c00100k@c001021ZH407b8J01lR6P21ZH6G0;3PiP40oooo002H0;3PiP05086YP@0X;RH0:2hV
02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV1
07F?J01eSfP05P1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV1
06b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV1
03]3<00k@c001@0k@c000`21ZH407b8J086YP@2G0;3PiP40oooo002G0;3PiP03086YP@0X;RH0:2hV
0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01L0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002G0;3PiP05
086YP@0X;RH0:2hV02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002F0;3PiP03
086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003
086YP@1^QV<0KXIS01@0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003
086YP@1dSF@0M8eT01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03
086YP@1CHT<0Df9300X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2E0;3PiP40
oooo002E0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH
065dF00>065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?J01eSfP02P1eSfQ9086YPA40K8=K
00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086YP@0k@c00>d<`00D0>d<`
00@0PJV101lR6P0O8QX0PJV1U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^9P0302P^9P03086Y
P@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0906j6HaP0PJV1
3023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0PJV107^HJ`1kV6/0
0`1kV6/<086YP@H0K8=K00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086Y
P@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^
9P0202P^9P03086YP@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P02P1QM5P@086YP@/0OIad00<0
PJV108>SN023XgP05P23XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0
PJV107^HJ`1kV6/03`1kV6/A086YP@T0HGA?00<0PJV105=R@`1CHT<02`1CHT<00`21ZH40>d<`03]3
<00403]3<004086YP@0O8QX07b8J086YPI<0/>3V0@3oool009<0/>3V00<0PJV102P^9P0X;RH00P0X
;RH00`21ZH40BEE304UE@`0804UE@`04086YP@1QM5P0HGAH065dF0T0PJV1101bSF/00`21ZH40OIad
07fLM00D07fLM003086YP@23XgP0Pj=h01H0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c
086QL`0H086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d0201^R5d=086YP@X0Df93
00<0PJV103]3<00k@c001@0k@c001021ZH407b8J01lR6P21ZH6B0;3PiP40oooo002B0;3PiP03086Y
P@0X;RH0:2hV00<0:2hV00<0PJV104UE@`19ED<01P19ED<6086YP@`0LXe[00<0PJV107fLM01mW7@0
501mW7@00`21ZH40Pj=h08>SN00G08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<0
6@21XG<00`21ZH40NiQ[07^HJ`0D07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0
1@21ZH4605=R@`03086YP@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40TP2`h>H10?ooo`00TP2`
h>H00`21ZH40:2hV02P^9P0202P^9P03086YP@19ED<0BEE300<0BEE31021ZH400`1LL5P0PJV107:=
J`0?07:=J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BT
M`0I08BTM`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8
G@0B06j8G@03086YP@1NLTd0GW9=00@0GW9=1@21ZH400`1CHT<0PJV103]3<00603]3<004086YP@0O
8QX07b8J086YPI40/>3V0@3oool00940/>3V00<0PJV102P^9P0X;RH00`0X;RH00`21ZH40BEE3086Y
P@03086YP@@0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23
XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I086QL`03086YP@1k
V6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0905ibC@D0PJV11@0k
@c000`21ZH407b8J086YP@2A0;3PiP40oooo002@0;3PiP03086YP@0X;RH0:2hV0080:2hV1021ZH48
05a`F003086YP@1bSF/0LXe[00h0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00G
08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21XG<00`21ZH40NiQ[07^HJ`0E
07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21ZH40AeDj04ME>P04
086YP@0503]3<021ZH407b8J01lR6P21ZH40T02`h>H10?ooo`00T02`h>H00`0X;RH0PJV1086YP@02
086YP@0303M0=`21ZH40G71H00T0G71H00<0PJV107:=J`1bSF/03P1bSF/00`21ZH40OIad07fLM00E
07fLM003086YP@23XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I
086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0<
05ibC@03086YP@17ECX0AeDj00<0AeDj0`21ZH4201lR6P03086YP@2`h>H0/>3V08d0/>3V0@3oool0
08l0/>3V0P21ZH4403M0=`03086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21
ZH40OIad07fLM00D07fLM003086YP@23XgP0Pj=h01P0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21
ZH40PJ5c086QL`0I086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21
ZH40GW9=05ibC@0;05ibC@03086YP@17ECX0AeDj00D0AeDj1021ZH6?0;3PiP40oooo002?0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03
086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM086YP@21ZH6>0;3P
iP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40
LXe[07:=J`0>07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40
KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH40
92LM02@W7@0T9af>0;3PiP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05@1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03086YP@0g@3L0=d0g00<0
=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0
OIad00<0PJV108>SN023XgP01`23XgP0103oO`00Pj=h08>SN03oO`0<08>SN003086YP@3oO`00Q:Ag
01X0Q:Ag00<0PJV1086QL`21XG<06P21XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM
0180KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0504ME>P04086YP@0T9ad092LM
086YPHd0/>3V0@3oool008X0/>3V00@0ogl00;3PiP2`h>H0PJV11@0g@3L00`21ZH40G71H05a`F008
05a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01mW7@0301mW7@0103oO`00OIad07fLM03o
O`0307fLM080ogl000<0PJV108>SN023XgP01@23XgP:0?mo00T0Pj=h0`3oO`0J08BTM`03086YP@21
XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03086YP@1N
LTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM02@W7@21ZH6<0;3PiP40oooo
00290;3PiP<0ogl000<0PJV103M0=`0g@3L0100g@3L00`21ZH40G71H05a`F00805a`F003086YP@1b
SF/0LXe[00d0LXe[00<0ogl007:=J`21ZH400`1mW7@20?mo00L0OIad203oO`00101mW7@0ogl00?mo
0021ZH4608>SN0`0ogl01`23XgP50?mo01T0Q:Ag00<0PJV1086QL`21XG<06P21XG<00`21ZH40NiQ[
07^HJ`0F07^HJ`03086YP@1^R5d0KXQM01<0KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21ZH40AeDj
04ME>P0604ME>P04086YP@0T9ad092LM086YPH`0/>3V0@3oool008T0/>3V0P3oO`000`2`h>H0PJV1
03M0=`0403M0=`03086YP@1LL5P0G71H00P0G71H00<0ogl0086YP@1bSF/01@1bSF/00`3oO`00LXe[
07:=J`0507:=J`<0ogl000@0PJV107fLM01mW7@0OIad0P3oO`0607fLM0`0ogl000<0PJV108>SN023
XgP01023XgP20?mo00P0Pj=h0P3oO`0808>SN0<0ogl06P24Y7L00`21ZH40PJ5c086QL`0J086QL`03
086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04`1^R5d00`21ZH40GW9=05ibC@0<05ibC@03
086YP@17ECX0AeDj00D0AeDj00D0PJV102@W7@0T9ad092LM086YP@2;0;3PiP40oooo00290;3PiP80
ogl000<0PJV103M0=`0g@3L0100g@3L00`21ZH40G71H05a`F00605a`F0@0ogl01@1bSF/30?mo00H0
LXe[0P3oO`000`21ZH40OIad07fLM00207fLM080ogl01P1mW7@20?mo00H0OIad103oO`000`21ZH40
Pj=h08>SN00308>SN080ogl02@23XgP20?mo00P0Pj=h00<0PJV10?mo0024Y7L06P24Y7L00`21ZH40
PJ5c086QL`0J086QL`03086YP@1kV6/0NiQ[01L0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40
GW9=05ibC@0<05ibC@03086YP@17ECX0AeDj00H0AeDj00@0PJV102@W7@0T9ad0PJV1R`2`h>H10?oo
o`00R02`h>H30?mo0003086YP@0g@3L0=d0g0080=d0g00D0ogl0086YP@1LL5P0G71H0?mo000405a`
F0L0ogl0101bSF/20?mo00L0LXe[0P3oO`000`21ZH40OIad07fLM00207fLM080ogl01@1mW7@20?mo
00P0OIad0`3oO`000`21ZH40Pj=h08>SN00308>SN0030?mo0023XgP0Pj=h00P0Pj=h0`3oO`0708>S
N003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21XG<06`21XG<00`21ZH40NiQ[07^HJ`0F07^H
J`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME
>P05086YP@0T9ad092LM02@W7@21ZH40RP2`h>H10?ooo`00R02`h>H20?mo00030;3PiP3oO`00=d0g
0080=d0g0`3oO`00101LL5P0ogl00?mo003oO`0205a`F0@0ogl000<0G71H0?mo003oO`001@1bSF/2
0?mo00L0LXe[0P3oO`000`21ZH40OIad07fLM00207fLM080ogl0101mW7@20?mo00X0OIad0`3oO`05
08>SN0030?mo0023XgP0Pj=h00P0Pj=h0P3oO`0808>SN003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1
086QL`21XG<06`21XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM01<0KXQM00<0PJV1
05ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPHX0/>3V0@3o
ool008P0/>3V1@3oO`0203M0=`80ogl000@0PJV105a`F03oO`00ogl00P1LL5P30?mo0080G71H00<0
PJV10?mo003oO`001@1bSF/20?mo00H0LXe[0`3oO`000`21ZH40OIad07fLM00207fLM080ogl0101m
W7@20?mo00X0OIad0P3oO`0A08>SN080ogl02023XgP00`21ZH40Q:Ag08BTM`0<08BTMad0PJV13`21
XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM01<0KXQM00<0PJV105ibC@1NLTd0301N
LTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPHX0/>3V0@3oool008L0/>3V1P3o
O`0203M0=`80ogl00P1LL5P20?mo000405a`F03oO`00ogl00?mo00<0G71H00<0PJV10?mo003oO`00
101bSF/30?mo00H0LXe[0P3oO`000`21ZH40OIad07fLM00207fLM080ogl01@1mW7@20?mo00X0PJV1
0P3oO`0?086YP@@0ogl05`21ZH4>08jcP`03086YP@2</7h0S;1n00`0S;1n7021ZH4=07^HJ`03086Y
P@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd03@1NLTd00`21ZH40AeDj04ME>P0504ME>P05086Y
P@0T9ad092LM02@W7@21ZH40R@2`h>H10?ooo`00QP2`h>H30?mo0004086YP@3oO`00ogl00?mo0080
=d0g0P3oO`0205a`F080ogl000<0G71H0?mo003oO`00101LL5P00`21ZH40ogl00?mo000407:=J`80
ogl01@1bSF/2086YP@80ogl01@21ZH420?mo00D0PJV10P3oO`0908V]P@80ogl000<0PJV108jcQ02>
/h@01`2>/h@90?mo00P0S[>40P3oO`0L08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26
Z7L02P26Z7LH086YP@/0KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04
086YP@0T9ad092LM086YPHT0/>3V0@3oool008H0/>3V1`3oO`001@0g@3L0ogl00?mo003oO`00G71H
00<0ogl000<0G71H0?mo003oO`000`1LL5P01@21ZH40LXe[0?mo003oO`00LXe[00<0PJV10P3oO`05
086YP@0507nPNP3oO`00ogl00?mo0021ZH401029[H420?mo00D0RJf10P3oO`0908V]P@80ogl000<0
PJV108jcQ02>/h@0102>/h@:0?mo00X0S[>40P3oO`0L08jcP`03086YP@2</7h0S;1n01/0S;1n00<0
PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0807^JJ`l0PJV12`1NLTd00`21ZH40AeDj04ME
>P0604ME>P05086YP@0T9ad092LM02@W7@21ZH40R02`h>H10?ooo`00QP2`h>H70?mo000303M0=`3o
O`00ogl00080G71H0P3oO`00101LL5P0ogl00?mo003oO`05086YP@80ogl000<0PJV107nPNP1oX7X0
0`3oO`0607nPNP80ogl000<0Oj1j086YP@29[H400`29[H420?mo00D0RJf10P3oO`0908V]P@80ogl0
00<0PJV108jcQ02>/h@00`2>/h@50?mo0100S[>40P3oO`0L08jcP`03086YP@2</7h0S;1n01/0S;1n
00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`04086YP@1WPEH0Ih5F06N1EPP0
PJV1101NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPHP0/>3V0@3oool008H0
/>3V103oO`00100g@3L0ogl00?mo000g@3L20?mo0080G71H0P3oO`001021ZH40ogl00?mo0021ZH43
06^6J@04086YP@1oX7X0ogl00?mo00<0Oj1j0P3oO`0707nPNP80ogl000<0Oj1j086YP@29[H400`29
[H420?mo00D0RJf10P3oO`0908V]P@80ogl01P2>/h@20?mo00/0S[>400<0ogl008jcQ02>/h@01@2>
/h@20?mo01`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1k
VV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH02@1WPEH7086YP@H0AeDj00D0PJV102@W7@0T9ad092LM
086YP@270;3PiP40oooo00250;3PiPD0ogl000@0=d0g0?mo003oO`00PJV10P3oO`02086YP@@0ogl0
1@1[QVT01021ZH40Oj1j0?mo003oO`0307nPNP80ogl01`1oX7X20?mo0003086YP@29[H40RJf10080
RJf10P3oO`0608V]P@80ogl02@29[H420?mo00D0S[>40`3oO`0:08jcQ0<0ogl01P2>/h@20?mo01`0
S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0
NiY[00<0PJV106N1EP1WPEH0301WPEH00`21ZH40DF=3055S@`05086YP@80AeDj00@0PJV102@W7@0T
9ad0PJV1Q`2`h>H10?ooo`00Q@2`h>H50?mo0003086YP@3oO`00ogl000<0ogl000<0JhIY0?mo003o
O`000`3oO`0406^6J@03086YP@1oX7X0Oj1j0080ogl00`1oX7X20?mo00H0Oj1j0`3oO`000`21ZH40
RJf108V]P@0208V]P@80ogl01P29[H420?mo00T0RJf10P3oO`0608jcQ080ogl02@2>/h@30?mo00L0
S[>40P3oO`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40
NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00`0Ih5F00<0PJV1055S@`1AHd<01@1AHd<4086YP@80
92LM00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`h>H40?mo000304MHB@3oO`00ogl000<0ogl0
0P1[QVT20?mo000306^6J@3oO`00ogl000@0JhIY00@0PJV107nPNP3oO`00ogl00`1oX7X30?mo00H0
Oj1j0P3oO`000`1oX7X0PJV108V]P@0308V]P@80ogl01P29[H420?mo00T0RJf10P3oO`0608jcQ080
ogl01`2>/h@40?mo00P0S[>40P3oO`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26
Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1A
Hd<01P1AHd<00`21ZH40;CDU086YP@02086YPHH0/>3V0@3oool008@0/>3V103oO`0204MHB@80ogl0
00<0AeQ90?mo003oO`000P1[QVT20?mo000306^6J@3oO`00ogl000@0JhIY00@0PJV10?mo003oO`00
ogl00`1oX7X40?mo00D0Oj1j0P3oO`000`1oX7X0PJV108V]P@0308V]P@80ogl01P29[H420?mo00T0
RJf10P3oO`0608jcQ0D0ogl00`2>/h@40?mo00T0S[>40P3oO`0L08jcP`03086YP@2</7h0S;1n01`0
S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0
Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021ZH40;CDU02de9@0]=BF60;3PiP40oooo00230;3PiPD0
ogl00P17F4T20?mo000404MHB@3oO`00ogl006^6J@<0ogl000@0JhIY0?mo003oO`00ogl00`1[QVT3
0?mo00@0Oj1j1@3oO`0207nPNP@0ogl000<0Oj1j086YP@29[H400`29[H420?mo00H0RJf10P3oO`08
08V]P@80ogl000<0PJV108jcQ02>/h@01@2>/h@90?mo00/0S[>40P3oO`0L08jcP`03086YP@2</7h0
S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0
Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108D0/>3V0@3o
ool008<0/>3V1@3oO`000`17F4T0ogl00?mo00040?mo000306^6J@3oO`00ogl000<0JhIY0`3oO`00
101[QVT0ogl00?mo003oO`0507nPNP80ogl000<0Oj1j0?mo003oO`001@3oO`0207nPNP04086YP@29
[H40RJf108V]P@80ogl01P29[H420?mo00T0RJf10P3oO`000`21ZH40S[>408jcQ00708jcQ0H0ogl0
302>/h@20?mo01`0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JXM`03086Y
P@1kVV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S@`05086Y
P@0]=BD0;CDU02de9@21ZH40Q@2`h>H10?ooo`00Q02`h>H40?mo000404MHB@3oO`00ogl004MHB@80
ogl00P1[QVT20?mo00@0JhIY1@3oO`0507nPNP<0ogl000<0Oj1j0?mo003oO`000`3oO`0407nPNP04
086YP@29[H40RJf108V]P@80ogl04`29[H400`21ZH40S[>408jcQ00I08jcQ080ogl07@2>/h<00`21
ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21
ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300H0DF=300D0PJV102de9@0]=BD0;CDU086YP@25
0;3PiP40oooo00220;3PiPT0ogl000<0AeQ90?mo003oO`000P1[QVT20?mo00@0JhIY103oO`0707nP
NP030?mo001oX7X0Oj1j00P0Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jc
Q080ogl07@2>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^J
J`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300L0DF=300@0PJV102de
9@0]=BD0PJV1Q@2`h>H10?ooo`00PP2`h>H80?mo0080AeQ90P3oO`00101[QVT0ogl00?mo003oO`07
06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J
08jcQ080ogl07@2>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01P0QZQg00<0PJV1
07^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300L0DF=300D0PJV1
02de9@0]=BD0;CDU086YP@240;3PiP40oooo00220;3PiP<0ogl000@0PJV10?mo003oO`00ogl00P17
F4T30?mo000306^6J@3oO`00ogl000P0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]
P@0F08V]P@03086YP@2>/h@0S[>401X0S[>40P3oO`0M08jcP`03086YP@2</7h0S;1n01/0S;1n00<0
PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0
PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108@0/>3V0@3oool00880/>3V0`3o
O`000`21ZH40AeQ904MHB@0304MHB@80ogl00P1[QVT20?mo00P0JhIY00<0PJV107nPNP1oX7X0401o
X7X00`21ZH40RJf108V]P@0208V]P@030?mo0029[H40RJf10140RJf100<0PJV108jcQ02>/h@06P2>
/h@20?mo01d0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1k
VV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]
=BD0;CDU02de9@21ZH40Q02`h>H10?ooo`00PP2`h>H30?mo0003086YP@17F4T0AeQ900<0AeQ90P3o
O`0206^6J@80ogl0201[QVT00`21ZH40Oj1j07nPNP0@07nPNP04086YP@29[H40RJf108V]P@<0ogl0
4P29[H400`21ZH40S[>408jcQ00J08jcQ080ogl07@2>/h<00`21ZH40S;1n08b`OP0K08b`OP03086Y
P@26Z7L0QZQg01P0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086Y
P@1AHd<0DF=300L0DF=300@0PJV102de9@0]=BD0PJV1Q02`h>H10?ooo`00PP2`h>H30?mo0003086Y
P@17F4T0AeQ900<0AeQ90P3oO`00101[QVT0ogl00?mo003oO`0706^6J@03086YP@1oX7X0Oj1j0140
Oj1j00<0PJV108V]P@29[H401@3oO`0A08V]P@03086YP@2>/h@0S[>401X0S[>40P3oO`0M08jcP`03
086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0D07^JJ`03
086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV1
08<0/>3V0@3oool00840/>3V0`3oO`02086YP@D0AeQ90P3oO`000`1[QVT0ogl00?mo000806^6J@03
086YP@1oX7X0Oj1j0140Oj1j00@0PJV108V]P@29[H40RJf10`3oO`0B08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg
01L0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@230;3PiP40oooo00210;3PiP<0ogl000<0PJV104MH
B@17F4T01017F4T20?mo000306^6J@3oO`00JhIY00P0JhIY00<0PJV107nPNP1oX7X04@1oX7X00`21
ZH40RJf108V]P@0208V]P@030?mo0029[H40RJf10140RJf100<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21
ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S@`1AHd<01P1AHd<01@21
ZH40;CDU02de9@0]=BD0PJV108<0/>3V0@3oool00840/>3V0P3oO`02086YP@D0AeQ90P3oO`0206^6
J@030?mo001[QVT0JhIY00L0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]
P@03086YP@2>/h@0S[>401/0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0L08b`
OP03086YP@26Z7L0QZQg01P0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0>06N1
EP03086YP@1AHd<0DF=300L0DF=300@0PJV102de9@0]=BD0PJV1P`2`h>H10?ooo`00P@2`h>H20?mo
0080PJV11P17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]
P@29[H405P29[H400`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`
OP2</7h0702</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1
EP1WPEH03P1WPEH00`21ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU02de9@21ZH40PP2`h>H1
0?ooo`00P02`h>H30?mo0080PJV11P17F4T00`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j
0140Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00=08jcQ5X0PJV13@26Z7L00`21
ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21
ZH40;CDU02de9@0]=BD0PJV10880/>3V0@3oool00840/>3V00@0ogl00;3PiP0M9R<0PJV11@17F4T0
0`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j00P0Oj1j<P21ZH4>09JoSP03086YP@2F`8`0
U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0;08jePAT0PJV12`1kVV/0
0`21ZH40Ih5F06N1EP0>06N1EP03086YP@1AHd<0DF=300H0DF=300D0PJV102de9@0]=BD0;CDU086Y
P@220;3PiP40oooo00230;3PiP03086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT0101[QVTA
086YP@T0RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0
U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0
Q:Qf00T0Q:Qf8@21ZH45055S@`04086YP@0]=BD0;CDU086YPH80/>3V0@3oool00880/>3V0P21ZH43
04MHB@X0PJV11P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV1
09JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV1
08jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV1
05M^B@1GKTT00P1GKTT7086YP@80;CDU00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00PP2`h>H5086Y
P@<0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<
01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f8
01`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R
00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT00`21ZH40<d4/086YP@02086YPH40/>3V0@3oool00880
/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40
T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40
U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40
LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3P
iP40oooo00220;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140
RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0
U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0
Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1
;021ZH40P@2`h>H10?ooo`00PP2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40
RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40
U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40
Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40
<d4/03=1;00c@B`0PJV10840/>3V0@3oool00880/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0
MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0
U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0
S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0
Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00220;3PiP03086YP@1DJeT0E6]I00@0
E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0
T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0
U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0
LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840/>3V0@3oool00840
/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40
T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40
U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40
LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3P
iP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140
RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0
U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0
Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1
;021ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40
RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40
U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40
Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40
<d4/03=1;00c@B`0PJV10840/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0
MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0
U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0
S[F100<0PJV108BXMP24Z7H04`24Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0
Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40
MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40
U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40
S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40
Efi905M^B@0705M^B@04086YP@0c@B`0<d4/086YPH40/>3V0@3oool00840/>3V0P21ZH4605A[F@03
086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003
086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003
086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03
086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40oooo00210;3PiP80
PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B
^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D
_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1b
TF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?oo
o`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03
086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003
086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03
086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV1
0800/>3V0@3oool00840/>3V00<092l]086YP@1DJeT01@1DJeT00`21ZH40MiQg07NHM`0:07NHM`03
086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03
086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03
086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05
086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P@2`h>H00`21ZH40E6]I05A[F@0405A[F@03
086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003
086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003
086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03
086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40oooo00200;3PiP80
PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B
^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D
_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1b
TF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?oo
o`00P02`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03
086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003
086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03
086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV1
0800/>3V0@3oool00800/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29
[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F
`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24
Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c
@B`0<d4/086YP@200;3PiP40oooo00200;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03
086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03
086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03
086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05
086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P02`h>Kc086YPH00/>3V0@3oool00800/>3V
0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE
09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@
09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]
07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40
oooo00200;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?
00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD
00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao
00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21
ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?
096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD
09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao
08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta
03Q9<@0hBC40PJV10800/>3V0@3oool00800/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J2
00<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF
00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:
00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?
00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP03086YP@1NNfD0GW]U00@0GW]U
00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE
00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@
00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]
00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V0@3oool00840/>3V
0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE
09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@
09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]
07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40
oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?
00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD
00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao
00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21
ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?
096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD
09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao
08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta
03Q9<@0hBC40PJV10800/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J2
00<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF
00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:
00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?
00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2
082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF
09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:
09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?
05ahC`0705ahC`04086YP@0hBC40>4Ta086YPH40/>3V0@3oool00840/>3V0P21ZH4605ikI@03086Y
P@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086Y
P@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086Y
P@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l04`2<]7l00`21ZH40Nii]07^NK@0>07^NK@03086Y
P@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00210;3PiP80PJV1
1P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD0
5P2JaYD00`21ZH40WLZF09g:UP0J09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00
702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd0
3P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00
P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086Y
P@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086Y
P@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086Y
P@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840
/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l0
4@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0
702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0
502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40
>4Ta086YP@210;3PiP40oooo00220;3PiP03086YP@1NNfD0GW]U00@0GW]U00<0PJV1082VPP20YX80
2`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH0
6`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0
602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l0
1`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00880/>3V0P21ZH4605ikI@03086Y
P@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086Y
P@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086Y
P@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086Y
P@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiP80PJV1
1P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD0
5P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00
702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd0
3P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00
PP2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086Y
P@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086Y
P@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086Y
P@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840
/>3V0@3oool00880/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l0
4@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0
702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0
502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40
>4Ta086YP@210;3PiP40oooo00220;3PiPD0PJV10`1NNfD00`21ZH40P:J2082VPP0:082VPP03086Y
P@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086Y
P@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086Y
P@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`03086Y
P@0hBC40>4Ta0080PJV1P@2`h>H10?ooo`00PP2`h>H2086YP@<0IHM^2P21ZH46082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd01P1kWVdE086YP@0303]?<`21ZH40/>3V0800/>3V0@3o
ool008<0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0408J`RQ00PJV12P2A_8l0
0`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@0
0`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l02@2<]7lD
086YP@P0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`0kCc>20;3PiP40oooo0023
0;3PiP80PJV11@1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG00L0UlJG<P21ZH4?
09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0;
09G0RQT0PJV12`2A_HL00`21ZH40PJQe086XM@0>086XM@03086YP@1SPeP0Hh=H00H0Hh=H00D0PJV1
03]?<`0kCc<0>dlc086YP@220;3PiP40oooo00230;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP09
08J`RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0<
0:;CWE/0PJV13@2KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV1
06>3F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV10880/>3V0@3oool008<0/>3V0P21ZH46
06F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F
09o?W003086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L
0:3@U`03086YP@2KbI40VlVA01P0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0>
086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@220;3PiP40oooo0023
0;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV1
09o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV1
0:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1
086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00706>3F004086YP@0kCc<0>dlc086YPH<0/>3V0@3o
ool008@0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0
UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0
X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0
TKf701@0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00606>3F005086YP@0kCc<0
>dlc03]?<`21ZH40P`2`h>H10?ooo`00Q02`h>H2086YP@D0IHM^00<0PJV108J`RP26/8X02P26/8X0
0`21ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI40
0`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP0
1@21ZH40>dlc03]?<`0kCc<0PJV108<0/>3V0@3oool008@0/>3V0P21ZH4606F7KP03086YP@26/8X0
Q[2:00T0Q[2:00<0PJV109O6U`2GaYL04@2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0
X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40
VlVA01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0
Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@230;3PiP40oooo00240;3PiP80PJV11P1UQfh0
0`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L0
0`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D0
0`21ZH40Hh=H06>3F00706>3F004086YP@0kCc<0>dlc086YPH@0/>3V0@3oool008D0/>3V00<0PJV1
06F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV1
09o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV1
0:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1
086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00606>3F005086YP@0kCc<0>dlc03]?<`21ZH40Q02`
h>H10?ooo`00Q@2`h>H00`21ZH40IHM^06F7KP0406F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV1
09O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV1
0:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01P0VlVA00<0PJV1
096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV1
03]?<`0kCc<0>dlc086YP@240;3PiP40oooo00250;3PiP80PJV11@1UQfh00`21ZH40Q[2:08J`RP0:
08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J
0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H
09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F007
06>3F005086YP@0kCc<0>dlc03]?<`21ZH40Q02`h>H10?ooo`00Q@2`h>H2086YP@H0IHM^00<0PJV1
08J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV1
0:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV1
09_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV1
06>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH650;3PiP40oooo00250;3PiP80PJV11P1UQfh0
0`21ZH40Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`0
0`21ZH40X]>M0:;CW@0I0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L0
0`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D0
0`21ZH40Hh=H06>3F00606>3F005086YP@0kCc<0>dlc03]?<`21ZH40Q@2`h>H10?ooo`00QP2`h>H0
0`21ZH40IHM^06F7KP0406F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL0
0`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/0
0`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL0
0`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086Y
P@250;3PiP40oooo00260;3PiP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X02P26/8X0
0`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI40
0`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP0
1@21ZH40>dlc03]?<`0kCc<0PJV108D0/>3V0@3oool008H0/>3V0P21ZH4506F7KP03086YP@26/8X0
Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0
X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40
VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0
Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0PJV1000000250;3PiP40oooo00260;3PiP80PJV11P1UQfh0
0`21ZH40Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L0
0`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D0
0`21ZH40Hh=H06>3F00606>3F003086YP@0kCc<0>dlc0080PJV100<000000;3PiP2`h>H0P`2`h>H1
0?ooo`00Q`2`h>H4086YP@<0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0J0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00`0PJQe00<0PJV106>3F01SPeP01@1SPeP5086YP@0303]B=021ZH40/>3V
08D0/>3V0@3oool008L0/>3V00@0PJV106R>M01XSW@0J8id1`21ZH4908J`RP03086YP@2GaYL0UlJG
00l0UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K
01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf7
01<0TKf700<0PJV1086XM@21Z7D03021Z7D00`21ZH40Hh=H06>3F005086YP@80Ih]O00D0PJV103]B
=00kDS@0PJV1000000260;3PiP40oooo00280;3PiP03086YP@1XSW@0J8id00<0J8id00@0PJV108Vg
T029]i00RKN@1P21ZH4308J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05@2Oci`0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L0
0`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D02P21Z7D6
086YP@H0Ih]O00D0PJV103]B=00kDS@0>e8d086YP@270;3PiP40oooo00280;3PiP03086YP@1XSW@0
J8id00@0J8id00<0PJV108VgT029]i001P29]i08086YP@h0UlJG00<0PJV109o?W02Oci`05P2Oci`0
0`21ZH40X]>M0:;CW@0I0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L0
0`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D00P21Z7D8
086YP@<0QK1l00<0PJV106N;G`1WRel01P1WRel01@21ZH40>e8d03]B=021ZH40000008L0/>3V0@3o
ool008T0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08VgT00908VgT003086YP@2KcId0
VlfM0080VlfM2P21ZH4409O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06@2Rdid0
0`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI405`2KbI40
0`21ZH40TKf7096mQ`09096mQ`l0PJV12P25/7`00`21ZH40Ih]O06N;G`0606N;G`06086YP@0kDS@0
>e8d03]B=021ZH400000Q`2`h>H10?ooo`00R@2`h>H00`21ZH40J8id06R>M00406R>M003086YP@29
]i00RKN@00T0RKN@00<0PJV109_=W@2KcId02`2KcIdA086YP@`0WlnL00<0PJV10:;CW@2Rdid06@2R
did00`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI402`2K
bI4H086YP@X0ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O06N;G`0606N;G`04086YP@0k
DS@0>e8d086YP@<00000QP2`h>H10?ooo`00RP2`h>H00`21ZH40J8id06R>M00306R>M003086YP@29
]i00RKN@00T0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0:0:?FXSL0PJV13P2R
di/00`21ZH40X=2G0:3@U`0=0:3@Ua`0PJV1302Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25
/7`0QK1l00d0QK1l00<0PJV106N;G`1WRel01@1WRel01@21ZH40>e8d03]B=00kDS@0PJV100800000
Q`2`h>H10?ooo`00RP2`h>H00`21ZH40J8id06R>M00406R>M003086YP@29]i00RKN@00P0RKN@00<0
PJV109_=W@2KcId0402KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01T0Y]ZS00<0
PJV10:KJX@2VfZ40302VfZ4N086YP@h0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4
S@0C09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01P1WRel01021ZH40>e8d03]B
=021ZH42000008P0/>3V0@3oool008/0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08Vg
T00908VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJ
X`0I0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06`2Teid00`21ZH40W]2G09k@
U`0F09k@U`03086YP@2Ea8d0ULB=01<0ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O06N;
G`0606N;G`05086YP@0kDS@0>e8d086YP@000000R@2`h>H10?ooo`00R`2`h>H00`21ZH40J8id06R>
M00306R>M003086YP@29]i00RKN@00T0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?F
XP0F0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CG
W@0K0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`
O00<08F`O003086YP@1WRel0Ih]O00H0Ih]O00H0PJV103]B=00kDS@0>e8d086YP@0000290;3PiP40
oooo002;0;3PiP03086YP@1XSW@0J8id00@0J8id00<0PJV108VgT029]i002029]i000`21ZH40VlfM
09_=W@0?09_=W@03086YP@2SeZ80XmJR01H0XmJR00<0PJV10:KJX`2VfZ<0602VfZ<00`21ZH40Y]ZQ
0:KJX@0J0:KJX@03086YP@2Teid0Y=NM01X0Y=NM00<0PJV109k@U`2Nd9L05`2Nd9L00`21ZH40ULB=
09G4S@0B09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01P1WRel01@21ZH40>e8d
03]B=021ZH40000008X0/>3V0@3oool008`0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@
08VgT00908VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS
0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40W]2G
09k@U`0F09k@U`03086YP@2Ea8d0ULB=01<0ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40Ih]O
06N;G`0506N;G`06086YP@0kDS@0>e8d03]B=021ZH400000RP2`h>H10?ooo`00S02`h>H00`21ZH40
J8id06R>M00406R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40
XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40
Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01H0W]2G00<0PJV109G4S@2Ea8d04`2Ea8d00`21ZH40
QK1l08F`O00;08F`O003086YP@1WRel0Ih]O00H0Ih]O00@0PJV103]B=00kDS@0PJV10P00002:0;3P
iP40oooo002=0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i002029]i000`21ZH40
VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2VfZ<0602VfZ<00`21ZH40
Y]ZQ0:KJX@0J0:KJX@03086YP@2Teid0Y=NM01X0Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40
ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01P1WRel01@21ZH40
>e8d03]B=021ZH40000008/0/>3V0@3oool008d0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40
RKN@08VgT00908VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40
Y]ZS0:KJX`0G0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40
W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`03025/7`00`21ZH40
Ih]O06N;G`0506N;G`04086YP@0kDS@0>e8d086YP@800000R`2`h>H10?ooo`00SP2`h>H00`21ZH40
J8id06R>M00306R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40
XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40
Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2Ea8d04`2Ea8d00`21ZH40
QK1l08F`O00;08F`O003086YP@1WRel0Ih]O00H0Ih]O00D0PJV103]B=00kDS@0PJV10000002<0;3P
iP40oooo002>0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i002@29]i000`21ZH40
VlfM09_=W@0>09_=W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40
Y]ZQ0:KJX@0J0:KJX@03086YP@2Teid0Y=NM01X0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40
ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00`0QK1l00<0PJV106N;G`1WRel01@1WRel01021ZH40
>e8d03]B=021ZH42000008`0/>3V0@3oool008l0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40
RKN@08VgT00808VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40
Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40
W]2G09k@U`0F09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`02`25/7`00`21ZH40
Ih]O06N;G`0606N;G`04086YP@0kDS@0>e8d086YP@800000S02`h>H10?ooo`00S`2`h>H2086YP@@0
J8id00<0PJV108VgT029]i002029]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR01@0
XmJR00<0PJV10:KJX`2VfZ<0602VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0
Y=NM00<0PJV109k@U`2Nd9L05P2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00/0
QK1l00<0PJV106N;G`1WRel01@1WRel01P21ZH40>e8d086YP@21ZH40/>3V000008d0/>3V0@3oool0
0900/>3V1@21ZH400`1XSW@0PJV108VgT00908VgT003086YP@2KcId0VlfM00h0VlfM00<0PJV10:?F
XP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJX`0G0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CG
W@2Teid06@2Teid00`21ZH40W]2G09k@U`0E09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`
O025/7`03025/7`00`21ZH40Ih]O06N;G`0306N;G`@0PJV100<0?EPj086YP@2`h>H0SP2`h>H10?oo
o`00T02`h>H00`21ZH40JI5g06VAM`0206VAM`<0PJV12@29]i000`21ZH40VlfM09_=W@0>09_=W@03
086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03
086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40ULB=09G4S@0B09G4S@03
086YP@25/7`0QK1l00/0QK1l00<0PJV106N;G`1WRel01021ZH401@1XSf<0PJV103eH>P0mF3X0PJV1
0900/>3V0@3oool00940/>3V00<0PJV106VAM`1YTGL00`1YTGL5086YP@D0RKN@00<0PJV109_=W@2K
cId03`2KcId00`21ZH40XmJR0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS00<0PJV10:KJX@2V
fZ406@2VfZ400`21ZH40Y=NM0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G01D0W]2G00<0PJV109G4S@2E
a8d04P2Ea8d00`21ZH40QK1l08F`O00908F`O0D0PJV11@1XSf<00`21ZH40?EPj03eH>P2A0;3PiP40
oooo002B0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y800P29^Y84086YP@80RKN@
00<0PJV109_=W@2KcId03P2KcId00`21ZH40XmJR0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS01L0Y]ZS
00<0PJV10:KJX@2VfZ406@2VfZ400`21ZH40Y=NM0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G01D0W]2G
00<0PJV109G4S@2Ea8d04P2Ea8d00`21ZH40QK1l08F`O00408F`O0D0PJV100<0QK=o086YP@1XSf<0
1P1XSf<01021ZH40?EPj03eH>P21ZH6A0;3PiP40oooo002B0;3PiP03086YP@1YTGL0JI5g00<0JI5g
00<0PJV108VjTP29^Y801@29^Y87086YP@`0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40Y]ZS
0:KJX`0G0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40W]2G
09k@U`0D09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025/7`01@21ZH4608FcO`03086Y
P@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40TP2`h>H10?ooo`00T`2`h>H00`21ZH40JI5g06VA
M`0206VAM`03086YP@29^Y80RKZB00P0RKZB00@0PJV109_@X02Kd:00Vm2P2@21ZH4409_=W@03086Y
P@2SeZ80XmJR01@0XmJR00<0PJV10:KJX`2VfZ<05P2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086Y
P@2Teid0Y=NM01P0Y=NM00<0PJV109k@U`2Nd9L05@2Nd9L00`21ZH40ULB=09G4S@0809G4S@d0PJV1
2P25/gl00`21ZH40J8mS06R?H`0506R?H`04086YP@0mF3X0?EPj086YPI80/>3V0@3oool009@0/>3V
00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00X0Vm2P
4021ZH4;0:?FXP03086YP@2VfZ<0Y]ZS01H0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21ZH40Y=NM
0:CGW@0H0:CGW@03086YP@2Nd9L0W]2G0100W]2G4021ZH4909O9T@03086YP@25/gl0QK=o00/0QK=o
00<0PJV106R?H`1XSf<0101XSf<01021ZH40?EPj03eH>P21ZH6C0;3PiP40oooo002D0;3PiP03086Y
P@1YTGL0JI5g00<0JI5g00<0PJV108VjTP29^Y801`29^Y800`21ZH40Vm2P09_@X00=09_@X003086Y
P@2TfZH0Y=ZV00T0Y=ZV6021ZH4<0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid0
602Teid00`21ZH40W]2G09k@U`0409k@U``0PJV11@2PeI/00`21ZH40UlVA09O9T@0A09O9T@03086Y
P@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21ZH40?EPj086YP@2D0;3PiP40oooo
002E0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y801`29^Y800`21ZH40Vm2P09_@
X00>09_@X003086YP@2TfZH0Y=ZV01<0Y=ZV00<0PJV10:SNY`2XgZL02P2XgZM:086YPA00X=FK00<0
PJV109O9T@2GbI404@2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS00@0
PJV103eH>P0mF3X0PJV1U02`h>H10?ooo`00UP2`h>H00`21ZH40JI5g06VAM`0206VAM`03086YP@29
^Y80RKZB00L0RKZB00<0PJV109_@X02Kd:003@2Kd:000`21ZH40Y=ZV0:CJYP0D0:CJYP03086YP@2X
gZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD06@2XgZD00`21ZH40YM^Q0:GKX@0H0:GKX@03086YP@2P
eI/0X=FK01@0X=FK00<0PJV109O9T@2GbI404@2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1X
Sf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40U@2`h>H10?ooo`00U`2`h>H01@21ZH40JI5g06VAM`1Y
TGL0PJV100T0RKZB00<0PJV109_@X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0C0:CJYP03086YP@2X
gZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD06@2XgZD00`21ZH40YM^Q0:GKX@0H0:GKX@03086YP@2P
eI/0X=FK01@0X=FK00<0PJV109O9T@2GbI40402GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1X
Sf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40UP2`h>H10?ooo`00U`2`h>H00`21ZH40JI5g06VAM`02
06VAM`03086YP@29^Y80RKZB00L0RKZB00<0PJV109_@X02Kd:003@2Kd:000`21ZH40Y=ZV0:CJYP0C
0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD06@2XgZD00`21ZH40YM^Q0:GKX@0G
0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI404@2GbI400`21ZH40QK=o08FcO`0:
08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40UP2`h>H10?ooo`00V02`h>H01@21
ZH40JI5g06VAM`1YTGL0PJV100T0RKZB00<0PJV109_@X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0B
0:CJYP03086YP@2XgZL0Z=jW01H0Z=jW00<0PJV10:SNY@2XgZD0602XgZD00`21ZH40YM^Q0:GKX@0G
0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI40402GbI400`21ZH40QK=o08FcO`0:
08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40U`2`h>H10?ooo`00V@2`h>H01@21
ZH40JI5g06VAM`1YTGL0PJV100T0RKZB00<0PJV109_@X02Kd:003@2Kd:000`21ZH40Y=ZV0:CJYP0C
0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD0602XgZD00`21ZH40YM^Q0:GKX@0G
0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI40402GbI400`21ZH40QK=o08FcO`0:
08FcO`03086YP@1XSf<0J8mS00@0J8mS00@0PJV103eH>P0mF3X0PJV1U`2`h>H10?ooo`00V@2`h>H0
0`21ZH40JI5g06VAM`0206VAM`03086YP@29^Y80RKZB00H0RKZB00<0PJV109_@X02Kd:003P2Kd:00
0`21ZH40Y=ZV0:CJYP0B0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD0602XgZD0
0`21ZH40YM^Q0:GKX@0G0:GKX@03086YP@2PeI/0X=FK01<0X=FK00<0PJV109O9T@2GbI40402GbI40
0`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40V02`h>H1
0?ooo`00VP2`h>H01@21ZH40JI5g06VAM`1YTGL0PJV100T0RKZB00<0PJV109_@X02Kd:003@2Kd:00
0`21ZH40Y=ZV0:CJYP0B0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD0602XgZD0
0`21ZH40YM^Q0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI40402GbI40
0`21ZH40QK=o08FcO`0908FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40V@2`h>H1
0?ooo`00V`2`h>H2086YP@80JI5g00<0PJV108VjTP29^Y801P29^Y800`21ZH40Vm2P09_@X00>09_@
X003086YP@2TfZH0Y=ZV0140Y=ZV00<0PJV10:SNY`2XgZL05@2XgZL00`21ZH40Z=jU0:SNY@0H0:SN
Y@03086YP@2Ufj40YM^Q01H0YM^Q00<0PJV10:3EV`2PeI/0502PeI/00`21ZH40UlVA09O9T@0?09O9
T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<01@1XSf<2086YPIX0/>3V0@3oool009`0
/>3V1021ZH4908VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40
Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01L0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40
X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl02@25/gl00`21ZH40
J8mS06R?H`0306R?H`@0PJV1V`2`h>H10?ooo`00W02`h>H00`21ZH40IHme06F?M@03086YP@L0RKZB
00<0PJV109_@X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW
00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0G0:GKX@03086YP@2PeI/0X=FK01<0X=FK
00<0PJV109O9T@2GbI403`2GbI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0PJV100<0PJV1
00<0IHiT086YP@21ZH40W02`h>H10?ooo`00W@2`h>H01021ZH40IHme06F?M@1USgD5086YP@@0RKZB
00<0PJV109_@X02Kd:003@2Kd:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW
00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01@0X=FK
00<0PJV109O9T@2GbI403`2GbI400`21ZH40QK=o08FcO`0708FcO`D0PJV1101USV@2086YPId0/>3V
0@3oool009h0/>3V00D0PJV106F?M@1USgD0IHme086YP@0308FgT0D0PJV1402Kd:000`21ZH40Y=ZV
0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q
0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01<0X=FK00<0PJV109O9T@2GbI403`2GbI400`21ZH40QK=o
08FcO`0408FcO`@0PJV100<0P[:0086YP@1USV@01@1USV@2086YPIh0/>3V0@3oool009l0/>3V00D0
PJV106F?M@1USgD0IHme086YP@0608FgT0H0PJV12`2Kd:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086Y
P@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0F0:GKX@03086Y
P@2PeI/0X=FK01<0X=FK00<0PJV109O9T@2GbI403`2GbI400`21ZH40QK=o086YP@04086YP@@0P[:0
00<0PJV106F>I01USV@0101USV@2086YPIl0/>3V0@3oool00:00/>3V00@0PJV106F?M@1USgD0PJV1
2025]i001021ZH40V<jO09S>W`2HcYl8086YP@@0Vm2P00<0PJV10:CJYP2TfZH0402TfZH00`21ZH40
Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40
X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00X0UlVA1`21ZH4908:bP003086YP@1USV@0IHiT00<0
IHiT00<0PJV103eK?P21ZH40W`2`h>H10?ooo`00X02`h>H01@21ZH40IHme06F?M@1USgD0PJV100P0
QKN@00<0PJV109S>W`2HcYl0202HcYl9086YP@h0Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40
Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q01D0YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40
UlVA09O9T@0209O9T@T0PJV10`2Db9800`21ZH40P[:008:bP00908:bP003086YP@1USV@0IHiT00<0
IHiT00<0PJV103eK?P21ZH40X02`h>H10?ooo`00X@2`h>H01@21ZH40IHme06F?M@1USgD0PJV100L0
QKN@00<0PJV109S>W`2HcYl03@2HcYl01021ZH40X]ZV0:;JYP2RfZH:086YP@D0Y=ZV00<0PJV10:SN
Y`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0E0:SNY@03086YP@2Ufj40YM^Q01D0YM^Q00<0PJV10:3E
V`2PeI/02@2PeI/?086YP@`0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I00306F>
I003086YP@0mFch0PJV10:40/>3V0@3oool00:80/>3V00D0PJV106F?M@1USgD0IHme086YP@0708Fg
T003086YP@2HcYl0V<jO00`0V<jO00<0PJV10:;JYP2RfZH02`2RfZHA086YP@/0Z=jW00<0PJV10:SN
Y@2XgZD05@2XgZD00`21ZH40YM^Q0:GKX@0:0:GKXAL0PJV12@2OeY`00`21ZH40U<RB09C8TP0>09C8
TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@0101USV@2086YPJ80/>3V0@3oool00:<0
/>3V00D0PJV106F?M@1USgD0IHme086YP@0708FgT003086YP@2HcYl0V<jO00`0V<jO00<0PJV10:;J
YP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ0090:KOZ300PJV12`2UgJ<00`21ZH40WmJL09oFW00B09oF
W003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I00406F>
I080PJV1X`2`h>H10?ooo`00Y02`h>H01@21ZH40IHme06F?M@1USgD0PJV100L0QKN@00<0PJV109S>
W`2HcYl02`2HcYl00`21ZH40X]ZV0:;JYP0@0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0PJV10:OP
Y`2Wh:L05@2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0180WmJL00<0PJV109C8
TP2Db9803@2Db9800`21ZH40P[:008:bP00908:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6T0;3P
iP40oooo002T0;3PiP03086YP@1USgD0IHme0080IHme00<0PJV108FgT025]i001025]i000`21ZH40
V<jO09S>W`0<09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP04`2VgjP00`21ZH40
Yn2W0:OPY`0E0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04P2OeY`00`21ZH40
U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1USV@2086YPJD0
/>3V0@3oool00:D0/>3V00D0PJV106F?M@1USgD0IHme086YP@0708FgT003086YP@2HcYl0V<jO00/0
V<jO00<0PJV10:;JYP2RfZH0402RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003086YP@2Wh:L0Yn2W01D0
Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00A09oFW003086YP@2Db980U<RB00d0
U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I00306F>I080PJV1YP2`h>H10?ooo`00
YP2`h>H2086YP@80IHme00<0PJV108FgT025]i001@25]i000`21ZH40V<jO09S>W`0;09S>W`03086Y
P@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP04`2VgjP00`21ZH40Yn2W0:OPY`0D0:OPY`03086Y
P@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04@2OeY`00`21ZH40U<RB09C8TP0<09C8TP03086Y
P@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1USV@2086YPJL0/>3V0@3oool00:L0/>3V1@21
ZH4708FgT003086YP@2HcYl0V<jO00/0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KO
Z00B0:KOZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oF
W00A09oFW003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X001`22/X000`21ZH40IHiT06F>
I00206F>I080PJV1Z@2`h>H10?ooo`00Z@2`h>H00`21ZH40GHI^086YP@02086YP@H0QKN@00<0PJV1
09S>W`2HcYl02P2HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX0180Y]nX00<0PJV1
0:OPY`2Wh:L0502Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL0100WmJL00<0PJV1
09C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0PJV1ZP2`h>H1
0?ooo`00ZP2`h>H00`21ZH40GHI^05f6KP04086YP@<0QKN@00<0PJV109S>W`2HcYl02`2HcYl00`21
ZH40X]ZV0:;JYP0>0:;JYP03086YP@2VgjP0Y]nX0180Y]nX00<0PJV10:OPY`2Wh:L04`2Wh:L00`21
ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0100WmJL00<0PJV109C8TP2Db980302Db9800`21
ZH40P[:008:bP00808:bP0@0PJV100<0GXMQ086YP@2`h>H0ZP2`h>H10?ooo`00Z`2`h>H2086YP@04
05f6KP21ZH40Njb907^/R@D0PJV1302HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX
0140Y]nX00<0PJV10:OPY`2Wh:L04`2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL
00l0WmJL00<0PJV109C8TP2Db980302Db9800`21ZH40P[:008:bP00608:bP0@0PJV10P1NQf42086Y
PJ`0/>3V0@3oool00:d0/>3V00@0PJV105f6KP21ZH40PJV1101k[8T5086YP@T0V<jO00<0PJV10:;J
YP2RfZH03P2RfZH00`21ZH40Y]nX0:KOZ00A0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:GM
X`2UgJ<04`2UgJ<00`21ZH40WmJL09oFW00@09oFW003086YP@2Db980U<RB00`0U<RB00<0PJV108:b
P022/X001P21ZH400`1jZW/0PJV105j7H@0205j7H@03086YP@2`h>H0/>3V0:`0/>3V0@3oool00:h0
/>3V00@0PJV105f6KP1MQVh0PJV11@1k[8T00`21ZH40SlFI08o5V@07086YP@80V<jO00<0PJV10:;J
YP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ00@0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:GM
X`2UgJ<04`2UgJ<00`21ZH40WmJL09oFW00?09oFW003086YP@2Db980U<RB00T0U<RB1`21ZH4607ZZ
N`05086YP@1NQf40GXMQ05j7H@21ZH40[`2`h>H10?ooo`00[`2`h>H2086YP@0305f6KP21ZH40Njb9
00@0Njb900<0PJV108o5V@2?aIT01P2?aIT8086YP@`0X]ZV00<0PJV10:KOZ02VgjP04@2VgjP00`21
ZH40Yn2W0:OPY`0B0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`03`2OeY`01021
ZH40U<RB09C8TP2Db988086YP@80SL:>00<0PJV107ZZN`1jZW/01P1jZW/2086YP@<0GXMQ00<0PJV1
0;3PiP2`h>H0[P2`h>H10?ooo`00/@2`h>H00`21ZH40GHI^086YP@0507^/R@80PJV12P2?aIT01021
ZH40V]>R09[CXP2Jdj89086YP@@0X]ZV00<0PJV10:KOZ02VgjP0402VgjP00`21ZH40Yn2W0:OPY`0B
0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`02P2OeY`9086YP@T0SL:>00<0PJV1
07ZZN`1jZW/01P1jZW/00`21ZH40GXMQ05j7H@0205j7H@03086YP@2`h>H0/>3V0:l0/>3V0@3oool0
0;80/>3V00<0PJV105f6KP21ZH401P1k[8T00`21ZH40SlFI08o5V@0808o5V@03086YP@2Jdj80V]>R
00T0V]>R3P21ZH490:KOZ003086YP@2Wh:L0Yn2W0180Yn2W00<0PJV10:GMX`2UgJ<04P2UgJ<00`21
ZH40WmJL09oFW00209oFW0T0PJV10`2Hd9X00`21ZH40SL:>08g2SP0;08g2SP03086YP@1jZW/0NZYk
00H0NZYk00<0PJV105j7H@1NQf400P1NQf400`21ZH40/>3V0;3PiP2`0;3PiP40oooo002c0;3PiP<0
PJV11P1k[8T00`21ZH40SlFI08o5V@0708o5V@03086YP@2Jdj80V]>R00h0V]>R00<0PJV10:3JY@2P
fZD01P2PfZDh086YP@`0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk07ZZN`0607ZZN`04
086YP@1NQf40GXMQ05j7H@80PJV1/`2`h>H10?ooo`00]@2`h>H3086YP@D0Njb900<0PJV108o5V@2?
aIT01`2?aIT00`21ZH40V]>R09[CXP0=09[CXP03086YP@2PfZD0X=ZU00l0X=ZU00<0PJV10:7KY02Q
fj@04P2Qfj@00`21ZH40WmRQ09oHX@0B09oHX@03086YP@2Hd9X0V=2J00d0V=2J00<0PJV108g2SP2=
`Xh02P2=`Xh00`21ZH40NZYk07ZZN`0607ZZN`05086YP@1NQf40GXMQ05j7H@21ZH40]@2`h>H10?oo
o`00]P2`h>H3086YP@D0Njb900<0PJV108o5V@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0=09[CXP03
086YP@2PfZD0X=ZU00l0X=ZU00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40WmRQ09oHX@0A09oHX@03
086YP@2Hd9X0V=2J00d0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk07ZZN`0507ZZN`80
PJV10`1NQf400`21ZH40/>3V0;3PiP2d0;3PiP40oooo002h0;3PiP80PJV11@1k[8T2086YP@P0SlFI
00<0PJV109[CXP2Jdj803@2Jdj800`21ZH40X=ZU0:3JY@0>0:3JY@03086YP@2Qfj@0XM^T0140XM^T
00<0PJV109oHX@2Of:404@2Of:400`21ZH40V=2J09S@VP0<09S@VP03086YP@2=`Xh0SL:>00/0SL:>
00<0PJV107ZZN`1jZW/0101jZW/01021ZH40GXMQ05j7H@1NQf42086YPKL0/>3V0@3oool00;X0/>3V
0`21ZH4407^/R@03086YP@2?aIT0SlFI00H0SlFI00<0PJV109[CXP2Jdj80302Jdj800`21ZH40X=ZU
0:3JY@0>0:3JY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109oHX@2Of:40402Of:400`21ZH40V=2J
09S@VP0=09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/0101jZW/6086YPKP0/>3V
0@3oool00;/0/>3V1P21ZH400`1k[8T0PJV108o5V@0708o5V@03086YP@2Jdj80V]>R00`0V]>R00<0
PJV10:3JY@2PfZD03@2PfZD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0
PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0NZYk00<0NZYk0`21
ZH400`1BNUT0PJV1086YP@2j0;3PiP40oooo002m0;3PiP80PJV10P1ZVGX4086YP@H0SlFI00<0PJV1
09[CXP2Jdj80302Jdj800`21ZH40X=ZU0:3JY@0>0:3JY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV1
09oHX@2Of:40402Of:400`21ZH40V=2J09S@VP0<09S@VP03086YP@2=`Xh0SL:>00X0SL:>00@0PJV1
07ZZN`1jZW/0NZYk1021ZH400`1BNUT0PJV1086YP@2l0;3PiP40oooo002o0;3PiP80PJV10`1ZVGX5
086YP@<0SlFI00<0PJV109[CXP2Jdj80302Jdj800`21ZH40X=ZU0:3JY@0=0:3JY@03086YP@2Qfj@0
XM^T00l0XM^T00<0PJV109oHX@2Of:40402Of:400`21ZH40V=2J09S@VP0;09S@VP03086YP@2=`Xh0
SL:>00X0SL:>1`21ZH400`1BNUT0PJV1086YP@2n0;3PiP40oooo00310;3PiP80PJV10`1ZVGX2086Y
P@0307jbR`21ZH40PJV100<0PJV13P2Jdj800`21ZH40X=ZU0:3JY@0<0:3JY@03086YP@2Qfj@0XM^T
00l0XM^T00<0PJV109oHX@2Of:403`2Of:400`21ZH40V=2J09S@VP0<09S@VP03086YP@2=`Xh0SL:>
00<0SL:>2021ZH4206^IL@80PJV100<0DWYI086YP@21ZH40`02`h>H10?ooo`00``2`h>H2086YP@<0
JYUj00<0PJV107jbR`1n/X/00P1n/X/9086YP@H0V]>R00<0PJV10:3JY@2PfZD0302PfZD00`21ZH40
XM^T0:7KY00?0:7KY003086YP@2Of:40WmRQ00l0WmRQ00<0PJV109S@VP2Hd9X0202Hd9X:086YP@@0
OK630P21ZH4306^IL@04086YP@1BNUT0PJV1086YPL80/>3V0@3oool00<D0/>3V0P21ZH4206ZINP80
PJV1101n/X/2086YP@D0R/:E3`21ZH470:3JY@03086YP@2Qfj@0XM^T00h0XM^T00<0PJV109oHX@2O
f:403P2Of:401021ZH40V=2J09S@VP2Hd9X8086YP@80RL2?00<0PJV107faP`1m/H<01`1m/H<2086Y
P@<0JiUa1021ZH740;3PiP40oooo00360;3PiP<0PJV10P1ZVGX00`21ZH40O[:;07jbR`0307jbR`03
086YP@2:`YD0R/:E00X0R/:E00<0PJV1097:VP2AbYX0102AbYX]086YP@T0RL2?00<0PJV107faP`1m
/H<01`1m/H<01021ZH40JiUa06^IL@1[VG44086YPLH0/>3V0@3oool00<P0/>3V0`21ZH400`1ZVGX0
PJV1086YP@0407jbR`80PJV12`2:`YD00`21ZH40TLZJ097:VP0;097:VP03086YP@2Cc9X0TlbJ00d0
TlbJ00<0PJV10979U`2AbIL03@2AbIL00`21ZH40RL2?08W0S`0:08W0S`03086YP@1m/H<0OK6300H0
OK630P21ZH4206^IL@<0PJV1b@2`h>H10?ooo`00b`2`h>H5086YP@@0O[:;0P21ZH4:08[2U@03086Y
P@2AbYX0TLZJ00X0TLZJ00<0PJV109?<VP2Cc9X03@2Cc9X00`21ZH40TLVG0979U`0<0979U`03086Y
P@29`8l0RL2?00T0RL2?0P21ZH4707faP`80PJV10P1[VG43086YPL/0/>3V0@3oool00<d0/>3V1P21
ZH4307jbR`03086YP@2:`YD0R/:E00P0R/:E00<0PJV1097:VP2AbYX02P2AbYX00`21ZH40TlbJ09?<
VP0<09?<VP03086YP@2AbIL0TLVG00/0TLVG00<0PJV108W0S`29`8l02@29`8l00`21ZH40OK6307fa
P`0507faP`H0PJV1cP2`h>H10?ooo`00d02`h>H9086YP@T0R/:E00<0PJV1097:VP2AbYX02@2AbYX0
0`21ZH40TlbJ09?<VP0;09?<VP03086YP@2AbIL0TLVG00`0TLVG00<0PJV108W0S`29`8l02029`8l0
0`21ZH40OK6307faP`0307faP`H0PJV1d@2`h>H10?ooo`00d`2`h>H<086YP@@0R/:E00<0PJV1097:
VP2AbYX02@2AbYX00`21ZH40TlbJ09?<VP0:09?<VP03086YP@2AbIL0TLVG00/0TLVG00<0PJV108W0
S`29`8l02029`8l00`21ZH40OK63086YP@08086YPM<0/>3V0@3oool00=D0/>3V1@21ZH401@1TTW@0
PJV1086YP@21ZH40Kj5m00/0PJV11@2AbYX00`21ZH40TlbJ09?<VP0:09?<VP03086YP@2AbIL0TLVG
00X0TLVG00<0PJV108W0S`29`8l00`29`8l8086YP@0306BCK`21ZH40PJV100<0PJV1eP2`h>H10?oo
o`00f02`h>H5086YP@0306BBM021ZH40PJV100D0Kj5m0P21ZH4307JYPbD0PJV10P1`XGX2086YP@80
I9=_1@21ZH7I0;3PiP40oooo003L0;3PiPL0PJV1101_XGd2086YP@P0MZV300<0PJV107R/Q01h[8@0
201h[8@00`21ZH40MZV107JYP@0707JYP@80PJV11`1`XGX2086YP@80I9=_0`21ZH7M0;3PiP40oooo
003Q0;3PiPL0PJV100<0Kj5m086YP@21ZH401P1fZH<00`21ZH40N:b407R/Q00707R/Q003086YP@1f
ZH40MZV100H0MZV10P21ZH47072QNPH0PJV1h02`h>H10?ooo`00j02`h>H7086YP@<0MZV300<0PJV1
07R/Q01h[8@01P1h[8@00`21ZH40MZV107JYP@0207JYP@l0PJV1i02`h>H10?ooo`00k`2`h>HB086Y
PO80/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.606 .779 .568 r
.46017 .46966 m .45976 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.5 .5 m .5 .46978 L .46017 .46966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.5 .53022 m .5 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.5 .46978 m .5 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.5 .5 m .5 .53022 L .53983 .53034 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.53983 .53034 m .54024 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.46139 .43966 m .46017 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.5 .46978 m .5 .43989 L .46139 .43966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.45976 .5 m .46017 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.5 .56011 m .5 .53022 L .46017 .53034 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.5 .43989 m .5 .46978 L .53983 .46966 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.54024 .5 m .53983 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.5 .53022 m .5 .56011 L .53861 .56034 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.53861 .56034 m .53983 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.42114 .46929 m .42033 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.45976 .5 m .46017 .46966 L .42114 .46929 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.46017 .53034 m .45976 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.53983 .46966 m .54024 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.54024 .5 m .53983 .53034 L .57886 .53071 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.57886 .53071 m .57967 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.42358 .43896 m .42114 .46929 L .46017 .46966 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.46017 .46966 m .46139 .43966 L .42358 .43896 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.42033 .5 m .42114 .53071 L .46017 .53034 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.46139 .56034 m .46017 .53034 L .42114 .53071 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.46017 .53034 m .46139 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.53983 .46966 m .53861 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.53861 .43966 m .53983 .46966 L .57886 .46929 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.57967 .5 m .57886 .46929 L .53983 .46966 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.53983 .53034 m .53861 .56034 L .57642 .56104 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.57642 .56104 m .57886 .53071 L .53983 .53034 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51065 .56119 m
.51183 .56018 L
s
.51361 .56019 m
.51475 .56121 L
s
.51065 .56119 m
.51267 .56296 L
s
.51267 .56296 m
.51475 .56121 L
s
.5 Mabswid
.633 .822 .603 r
.46342 .41036 m .46139 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.5 .43989 m .5 .41069 L .46342 .41036 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.5 .41069 m .5 .43989 L .53861 .43966 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.5 .58931 m .5 .56011 L .46139 .56034 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.5 .56011 m .5 .58931 L .53658 .58964 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.53658 .58964 m .53861 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51198 .5921 m
.51205 .58942 L
s
.5 Mabswid
.625 .813 .592 r
.42766 .40937 m .42358 .43896 L .46139 .43966 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.46139 .43966 m .46342 .41036 L .42766 .40937 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.53861 .43966 m .53658 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.53658 .41036 m .53861 .43966 L .57642 .43896 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.57886 .46929 m .57642 .43896 L .53861 .43966 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.42114 .53071 m .42358 .56104 L .46139 .56034 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.46342 .58964 m .46139 .56034 L .42358 .56104 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.46139 .56034 m .46342 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.53861 .56034 m .53658 .58964 L .57234 .59063 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.57234 .59063 m .57642 .56104 L .53861 .56034 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.38378 .46868 m .38255 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.42033 .5 m .42114 .46929 L .38378 .46868 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.42114 .53071 m .42033 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.57886 .46929 m .57967 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.57967 .5 m .57886 .53071 L .61622 .53132 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.61622 .53132 m .61745 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.57642 .43896 m .57886 .46929 L .61622 .46868 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.61745 .5 m .61622 .46868 L .57886 .46929 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.57886 .53071 m .57642 .56104 L .61255 .56222 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.61255 .56222 m .61622 .53132 L .57886 .53071 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.38745 .43778 m .38378 .46868 L .42114 .46929 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.42114 .46929 m .42358 .43896 L .38745 .43778 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.38255 .5 m .38378 .53132 L .42114 .53071 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.42358 .56104 m .42114 .53071 L .38378 .53132 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.46628 .38215 m .46342 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.5 .41069 m .5 .38255 L .46628 .38215 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.5 .38255 m .5 .41069 L .53658 .41036 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.5 .61745 m .5 .58931 L .46342 .58964 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.5 .58931 m .5 .61745 L .53372 .61785 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.53372 .61785 m .53658 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.43336 .38095 m .42766 .40937 L .46342 .41036 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.46342 .41036 m .46628 .38215 L .43336 .38095 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.53658 .41036 m .53372 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.53372 .38215 m .53658 .41036 L .57234 .40937 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.57642 .43896 m .57234 .40937 L .53658 .41036 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.42358 .56104 m .42766 .59063 L .46342 .58964 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.46628 .61785 m .46342 .58964 L .42766 .59063 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.46342 .58964 m .46628 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.53658 .58964 m .53372 .61785 L .56664 .61905 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.56664 .61905 m .57234 .59063 L .53658 .58964 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.57234 .40937 m .57642 .43896 L .61255 .43778 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.61622 .46868 m .61255 .43778 L .57642 .43896 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.57642 .56104 m .57234 .59063 L .60645 .59228 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.60645 .59228 m .61255 .56222 L .57642 .56104 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.39355 .40772 m .38745 .43778 L .42358 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.42358 .43896 m .42766 .40937 L .39355 .40772 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.38378 .53132 m .38745 .56222 L .42358 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.42766 .59063 m .42358 .56104 L .38745 .56222 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.57234 .40937 m .56664 .38095 L .53372 .38215 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.56664 .38095 m .57234 .40937 L .60645 .40772 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.61255 .43778 m .60645 .40772 L .57234 .40937 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.57234 .59063 m .56664 .61905 L .59792 .62104 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.59792 .62104 m .60645 .59228 L .57234 .59063 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.40208 .37896 m .39355 .40772 L .42766 .40937 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.42766 .40937 m .43336 .38095 L .40208 .37896 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.38745 .56222 m .39355 .59228 L .42766 .59063 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.43336 .61905 m .42766 .59063 L .39355 .59228 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.42766 .59063 m .43336 .61905 L .46628 .61785 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.46995 .35545 m .46628 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.5 .38255 m .5 .35589 L .46995 .35545 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.5 .64411 m .5 .61745 L .46628 .61785 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.5 .35589 m .5 .38255 L .53372 .38215 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.5 .61745 m .5 .64411 L .53005 .64455 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.53005 .64455 m .53372 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.61622 .46868 m .61745 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.61745 .5 m .61622 .53132 L .65095 .53217 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.65095 .53217 m .65259 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.34905 .46783 m .34741 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.38255 .5 m .38378 .46868 L .34905 .46783 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.38378 .53132 m .38255 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.61255 .43778 m .61622 .46868 L .65095 .46783 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.65259 .5 m .65095 .46783 L .61622 .46868 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.61622 .53132 m .61255 .56222 L .64606 .56386 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.64606 .56386 m .65095 .53217 L .61622 .53132 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.35394 .43614 m .34905 .46783 L .38378 .46868 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.38378 .46868 m .38745 .43778 L .35394 .43614 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.34741 .5 m .34905 .53217 L .38378 .53132 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.38745 .56222 m .38378 .53132 L .34905 .53217 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.44068 .35415 m .43336 .38095 L .46628 .38215 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.46628 .38215 m .46995 .35545 L .44068 .35415 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.46995 .64455 m .46628 .61785 L .43336 .61905 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.46628 .61785 m .46995 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.53372 .38215 m .53005 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.53005 .35545 m .53372 .38215 L .56664 .38095 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.53372 .61785 m .53005 .64455 L .55932 .64585 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.55932 .64585 m .56664 .61905 L .53372 .61785 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.61255 .56222 m .60645 .59228 L .63794 .59458 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.63794 .59458 m .64606 .56386 L .61255 .56222 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.60645 .40772 m .61255 .43778 L .64606 .43614 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.65095 .46783 m .64606 .43614 L .61255 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.36206 .40542 m .35394 .43614 L .38745 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.38745 .43778 m .39355 .40772 L .36206 .40542 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.34905 .53217 m .35394 .56386 L .38745 .56222 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.39355 .59228 m .38745 .56222 L .35394 .56386 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.56664 .38095 m .55932 .35415 L .53005 .35545 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.55932 .35415 m .56664 .38095 L .59792 .37896 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.60645 .40772 m .59792 .37896 L .56664 .38095 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.56664 .61905 m .55932 .64585 L .58701 .64802 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.58701 .64802 m .59792 .62104 L .56664 .61905 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.41299 .35198 m .40208 .37896 L .43336 .38095 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.43336 .38095 m .44068 .35415 L .41299 .35198 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.39355 .59228 m .40208 .62104 L .43336 .61905 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.44068 .64585 m .43336 .61905 L .40208 .62104 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.43336 .61905 m .44068 .64585 L .46995 .64455 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.59792 .37896 m .60645 .40772 L .63794 .40542 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.64606 .43614 m .63794 .40542 L .60645 .40772 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.60645 .59228 m .59792 .62104 L .62664 .62381 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.62664 .62381 m .63794 .59458 L .60645 .59228 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.37336 .37619 m .36206 .40542 L .39355 .40772 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.39355 .40772 m .40208 .37896 L .37336 .37619 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.35394 .56386 m .36206 .59458 L .39355 .59228 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.40208 .62104 m .39355 .59228 L .36206 .59458 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.47443 .33074 m .46995 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.5 .35589 m .5 .33118 L .47443 .33074 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.5 .33118 m .5 .35589 L .53005 .35545 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.5 .66882 m .5 .64411 L .46995 .64455 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.5 .64411 m .5 .66882 L .52557 .66926 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.52557 .66926 m .53005 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.4496 .32944 m .44068 .35415 L .46995 .35545 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.46995 .35545 m .47443 .33074 L .4496 .32944 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.53005 .35545 m .52557 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.52557 .33074 m .53005 .35545 L .55932 .35415 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.47443 .66926 m .46995 .64455 L .44068 .64585 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.46995 .64455 m .47443 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.53005 .64455 m .52557 .66926 L .5504 .67056 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.5504 .67056 m .55932 .64585 L .53005 .64455 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.65095 .46783 m .65259 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.65259 .5 m .65095 .53217 L .68192 .53327 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.68192 .53327 m .68396 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.31808 .46673 m .31604 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.34741 .5 m .34905 .46783 L .31808 .46673 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.34905 .53217 m .34741 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.64606 .43614 m .65095 .46783 L .68192 .46673 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.68396 .5 m .68192 .46673 L .65095 .46783 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.65095 .53217 m .64606 .56386 L .67583 .56597 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.67583 .56597 m .68192 .53327 L .65095 .53217 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.32417 .43403 m .31808 .46673 L .34905 .46783 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.34905 .46783 m .35394 .43614 L .32417 .43403 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.31604 .5 m .31808 .53327 L .34905 .53217 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.35394 .56386 m .34905 .53217 L .31808 .53327 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.38776 .34897 m .37336 .37619 L .40208 .37896 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.40208 .37896 m .41299 .35198 L .38776 .34897 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.36206 .59458 m .37336 .62381 L .40208 .62104 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.41299 .64802 m .40208 .62104 L .37336 .62381 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.40208 .62104 m .41299 .64802 L .44068 .64585 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.59792 .37896 m .58701 .35198 L .55932 .35415 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.58701 .35198 m .59792 .37896 L .62664 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.63794 .40542 m .62664 .37619 L .59792 .37896 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.59792 .62104 m .58701 .64802 L .61224 .65103 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.61224 .65103 m .62664 .62381 L .59792 .62104 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.55932 .35415 m .5504 .32944 L .52557 .33074 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.5504 .32944 m .55932 .35415 L .58701 .35198 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.55932 .64585 m .5504 .67056 L .57376 .67271 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.57376 .67271 m .58701 .64802 L .55932 .64585 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.42624 .32729 m .41299 .35198 L .44068 .35415 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.44068 .35415 m .4496 .32944 L .42624 .32729 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.4496 .67056 m .44068 .64585 L .41299 .64802 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.44068 .64585 m .4496 .67056 L .47443 .66926 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.63794 .40542 m .64606 .43614 L .67583 .43403 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.68192 .46673 m .67583 .43403 L .64606 .43614 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.64606 .56386 m .63794 .59458 L .66575 .59752 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.66575 .59752 m .67583 .56597 L .64606 .56386 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.33425 .40248 m .32417 .43403 L .35394 .43614 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.35394 .43614 m .36206 .40542 L .33425 .40248 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.31808 .53327 m .32417 .56597 L .35394 .56386 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.36206 .59458 m .35394 .56386 L .32417 .56597 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.62664 .37619 m .63794 .40542 L .66575 .40248 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.67583 .43403 m .66575 .40248 L .63794 .40542 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.63794 .59458 m .62664 .62381 L .65178 .62734 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.65178 .62734 m .66575 .59752 L .63794 .59458 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.34822 .37266 m .33425 .40248 L .36206 .40542 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.36206 .40542 m .37336 .37619 L .34822 .37266 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.32417 .56597 m .33425 .59752 L .36206 .59458 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.37336 .62381 m .36206 .59458 L .33425 .59752 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.47972 .30855 m .47443 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.5 .33118 m .5 .30894 L .47972 .30855 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.5 .30894 m .5 .33118 L .52557 .33074 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.5 .69106 m .5 .66882 L .47443 .66926 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.5 .66882 m .5 .69106 L .52028 .69145 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.52028 .69145 m .52557 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.46008 .30739 m .4496 .32944 L .47443 .33074 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.47443 .33074 m .47972 .30855 L .46008 .30739 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.52557 .33074 m .52028 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.52028 .30855 m .52557 .33074 L .5504 .32944 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.52557 .66926 m .52028 .69145 L .53992 .69261 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.53992 .69261 m .5504 .67056 L .52557 .66926 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.47972 .69145 m .47443 .66926 L .4496 .67056 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.47443 .66926 m .47972 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.58701 .35198 m .57376 .32729 L .5504 .32944 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.57376 .32729 m .58701 .35198 L .61224 .34897 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.62664 .37619 m .61224 .34897 L .58701 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.40515 .32433 m .38776 .34897 L .41299 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.41299 .35198 m .42624 .32729 L .40515 .32433 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.58701 .64802 m .57376 .67271 L .59485 .67567 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.59485 .67567 m .61224 .65103 L .58701 .64802 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.37336 .62381 m .38776 .65103 L .41299 .64802 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.42624 .67271 m .41299 .64802 L .38776 .65103 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.41299 .64802 m .42624 .67271 L .4496 .67056 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.61224 .34897 m .62664 .37619 L .65178 .37266 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.66575 .40248 m .65178 .37266 L .62664 .37619 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.62664 .62381 m .61224 .65103 L .63408 .65483 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.63408 .65483 m .65178 .62734 L .62664 .62381 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.36592 .34517 m .34822 .37266 L .37336 .37619 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.37336 .37619 m .38776 .34897 L .36592 .34517 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.33425 .59752 m .34822 .62734 L .37336 .62381 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.38776 .65103 m .37336 .62381 L .34822 .62734 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.5504 .32944 m .53992 .30739 L .52028 .30855 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.53992 .30739 m .5504 .32944 L .57376 .32729 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.44174 .30547 m .42624 .32729 L .4496 .32944 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.4496 .32944 m .46008 .30739 L .44174 .30547 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.5504 .67056 m .53992 .69261 L .55826 .69453 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.55826 .69453 m .57376 .67271 L .5504 .67056 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.46008 .69261 m .4496 .67056 L .42624 .67271 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.4496 .67056 m .46008 .69261 L .47972 .69145 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.68192 .46673 m .68396 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.68396 .5 m .68192 .53327 L .70779 .5346 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.70779 .5346 m .71021 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.29221 .4654 m .28979 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.31604 .5 m .31808 .46673 L .29221 .4654 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.31808 .53327 m .31604 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.67583 .43403 m .68192 .46673 L .70779 .4654 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.71021 .5 m .70779 .4654 L .68192 .46673 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.68192 .53327 m .67583 .56597 L .70057 .56852 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.70057 .56852 m .70779 .5346 L .68192 .53327 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.29943 .43148 m .29221 .4654 L .31808 .46673 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.31808 .46673 m .32417 .43403 L .29943 .43148 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.28979 .5 m .29221 .5346 L .31808 .53327 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.32417 .56597 m .31808 .53327 L .29221 .5346 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.57376 .32729 m .55826 .30547 L .53992 .30739 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.55826 .30547 m .57376 .32729 L .59485 .32433 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.61224 .34897 m .59485 .32433 L .57376 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42535 .30284 m .40515 .32433 L .42624 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42624 .32729 m .44174 .30547 L .42535 .30284 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57376 .67271 m .55826 .69453 L .57465 .69716 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57465 .69716 m .59485 .67567 L .57376 .67271 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.66575 .40248 m .67583 .43403 L .70057 .43148 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.70779 .4654 m .70057 .43148 L .67583 .43403 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.67583 .56597 m .66575 .59752 L .68865 .60107 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.68865 .60107 m .70057 .56852 L .67583 .56597 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.38776 .65103 m .40515 .67567 L .42624 .67271 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.44174 .69453 m .42624 .67271 L .40515 .67567 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.42624 .67271 m .44174 .69453 L .46008 .69261 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.31135 .39893 m .29943 .43148 L .32417 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.32417 .43403 m .33425 .40248 L .31135 .39893 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.29221 .5346 m .29943 .56852 L .32417 .56597 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.33425 .59752 m .32417 .56597 L .29943 .56852 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.59485 .32433 m .61224 .34897 L .63408 .34517 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.65178 .37266 m .63408 .34517 L .61224 .34897 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61224 .65103 m .59485 .67567 L .61287 .67939 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61287 .67939 m .63408 .65483 L .61224 .65103 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38713 .32061 m .36592 .34517 L .38776 .34897 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38776 .34897 m .40515 .32433 L .38713 .32061 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.34822 .62734 m .36592 .65483 L .38776 .65103 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.40515 .67567 m .38776 .65103 L .36592 .65483 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.48578 .28949 m .47972 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.5 .30894 m .5 .28979 L .48578 .28949 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.5 .28979 m .5 .30894 L .52028 .30855 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.5 .71021 m .5 .69106 L .47972 .69145 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.5 .69106 m .5 .71021 L .51422 .71051 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51422 .71051 m .52028 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.65178 .37266 m .66575 .40248 L .68865 .39893 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.70057 .43148 m .68865 .39893 L .66575 .40248 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.66575 .59752 m .65178 .62734 L .67222 .63157 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.67222 .63157 m .68865 .60107 L .66575 .59752 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.32778 .36843 m .31135 .39893 L .33425 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.33425 .40248 m .34822 .37266 L .32778 .36843 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.29943 .56852 m .31135 .60107 L .33425 .59752 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.34822 .62734 m .33425 .59752 L .31135 .60107 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47206 .28859 m .46008 .30739 L .47972 .30855 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47972 .30855 m .48578 .28949 L .47206 .28859 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.52028 .30855 m .51422 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.51422 .28949 m .52028 .30855 L .53992 .30739 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.48578 .71051 m .47972 .69145 L .46008 .69261 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47972 .69145 m .48578 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52028 .69145 m .51422 .71051 L .52794 .71141 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52794 .71141 m .53992 .69261 L .52028 .69145 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.53992 .30739 m .52794 .28859 L .51422 .28949 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.52794 .28859 m .53992 .30739 L .55826 .30547 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.45934 .28712 m .44174 .30547 L .46008 .30739 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.46008 .30739 m .47206 .28859 L .45934 .28712 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.53992 .69261 m .52794 .71141 L .54066 .71288 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.54066 .71288 m .55826 .69453 L .53992 .69261 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.47206 .71141 m .46008 .69261 L .44174 .69453 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.46008 .69261 m .47206 .71141 L .48578 .71051 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.63408 .34517 m .65178 .37266 L .67222 .36843 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.68865 .39893 m .67222 .36843 L .65178 .37266 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65178 .62734 m .63408 .65483 L .65156 .65935 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65156 .65935 m .67222 .63157 L .65178 .62734 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34844 .34065 m .32778 .36843 L .34822 .37266 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34822 .37266 m .36592 .34517 L .34844 .34065 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.31135 .60107 m .32778 .63157 L .34822 .62734 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.36592 .65483 m .34822 .62734 L .32778 .63157 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.59485 .32433 m .57465 .30284 L .55826 .30547 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.57465 .30284 m .59485 .32433 L .61287 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.63408 .34517 m .61287 .32061 L .59485 .32433 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.59485 .67567 m .57465 .69716 L .58844 .70043 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.58844 .70043 m .61287 .67939 L .59485 .67567 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.41156 .29957 m .38713 .32061 L .40515 .32433 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.40515 .32433 m .42535 .30284 L .41156 .29957 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.36592 .65483 m .38713 .67939 L .40515 .67567 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.42535 .69716 m .40515 .67567 L .38713 .67939 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.40515 .67567 m .42535 .69716 L .44174 .69453 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.55826 .30547 m .54066 .28712 L .52794 .28859 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.54066 .28712 m .55826 .30547 L .57465 .30284 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44812 .28512 m .42535 .30284 L .44174 .30547 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44174 .30547 m .45934 .28712 L .44812 .28512 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55826 .69453 m .54066 .71288 L .55188 .71488 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55188 .71488 m .57465 .69716 L .55826 .69453 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.45934 .71288 m .44174 .69453 L .42535 .69716 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.44174 .69453 m .45934 .71288 L .47206 .71141 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.61287 .32061 m .63408 .34517 L .65156 .34065 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.67222 .36843 m .65156 .34065 L .63408 .34517 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.63408 .65483 m .61287 .67939 L .62699 .68379 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.62699 .68379 m .65156 .65935 L .63408 .65483 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.37301 .31621 m .34844 .34065 L .36592 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.36592 .34517 m .38713 .32061 L .37301 .31621 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.32778 .63157 m .34844 .65935 L .36592 .65483 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.38713 .67939 m .36592 .65483 L .34844 .65935 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.70779 .4654 m .71021 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.71021 .5 m .70779 .5346 L .72703 .53616 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.72703 .53616 m .7298 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.49256 .27421 m .48578 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.5 .28979 m .5 .27438 L .49256 .27421 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.5 .27438 m .5 .28979 L .51422 .28949 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.5 .72562 m .5 .71021 L .48578 .71051 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.5 .71021 m .5 .72562 L .50744 .72579 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.50744 .72579 m .51422 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.27297 .46384 m .2702 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.28979 .5 m .29221 .4654 L .27297 .46384 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.29221 .5346 m .28979 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.70057 .43148 m .70779 .4654 L .72703 .46384 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.7298 .5 m .72703 .46384 L .70779 .4654 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.70779 .5346 m .70057 .56852 L .7188 .57148 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.7188 .57148 m .72703 .53616 L .70779 .5346 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.2812 .42852 m .27297 .46384 L .29221 .4654 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.29221 .4654 m .29943 .43148 L .2812 .42852 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.2702 .5 m .27297 .53616 L .29221 .5346 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.29943 .56852 m .29221 .5346 L .27297 .53616 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.57465 .30284 m .55188 .28512 L .54066 .28712 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.55188 .28512 m .57465 .30284 L .58844 .29957 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.61287 .32061 m .58844 .29957 L .57465 .30284 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.57465 .69716 m .55188 .71488 L .56116 .71734 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.56116 .71734 m .58844 .70043 L .57465 .69716 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.43884 .28266 m .41156 .29957 L .42535 .30284 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.42535 .30284 m .44812 .28512 L .43884 .28266 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.38713 .67939 m .41156 .70043 L .42535 .69716 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.44812 .71488 m .42535 .69716 L .41156 .70043 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.42535 .69716 m .44812 .71488 L .45934 .71288 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48542 .27371 m .47206 .28859 L .48578 .28949 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48578 .28949 m .49256 .27421 L .48542 .27371 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51422 .28949 m .50744 .27421 L .5 .27438 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.50744 .27421 m .51422 .28949 L .52794 .28859 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.49256 .72579 m .48578 .71051 L .47206 .71141 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.48578 .71051 m .49256 .72579 L .5 .72562 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51422 .71051 m .50744 .72579 L .51458 .72629 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51458 .72629 m .52794 .71141 L .51422 .71051 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.68865 .39893 m .70057 .43148 L .7188 .42852 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.72703 .46384 m .7188 .42852 L .70057 .43148 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70057 .56852 m .68865 .60107 L .70527 .60517 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70527 .60517 m .7188 .57148 L .70057 .56852 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.58844 .29957 m .61287 .32061 L .62699 .31621 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.65156 .34065 m .62699 .31621 L .61287 .32061 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.61287 .67939 m .58844 .70043 L .59898 .70426 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.59898 .70426 m .62699 .68379 L .61287 .67939 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29473 .39483 m .2812 .42852 L .29943 .43148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29943 .43148 m .31135 .39893 L .29473 .39483 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.27297 .53616 m .2812 .57148 L .29943 .56852 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.31135 .60107 m .29943 .56852 L .2812 .57148 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.40102 .29574 m .37301 .31621 L .38713 .32061 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.38713 .32061 m .41156 .29957 L .40102 .29574 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.34844 .65935 m .37301 .68379 L .38713 .67939 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.41156 .70043 m .38713 .67939 L .37301 .68379 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.52794 .28859 m .51458 .27371 L .50744 .27421 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.51458 .27371 m .52794 .28859 L .54066 .28712 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47886 .27289 m .45934 .28712 L .47206 .28859 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47206 .28859 m .48542 .27371 L .47886 .27289 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52794 .71141 m .51458 .72629 L .52114 .72711 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52114 .72711 m .54066 .71288 L .52794 .71141 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.48542 .72629 m .47206 .71141 L .45934 .71288 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.47206 .71141 m .48542 .72629 L .49256 .72579 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.67222 .36843 m .68865 .39893 L .70527 .39483 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.7188 .42852 m .70527 .39483 L .68865 .39893 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68865 .60107 m .67222 .63157 L .68674 .63642 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68674 .63642 m .70527 .60517 L .68865 .60107 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31326 .36358 m .29473 .39483 L .31135 .39893 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31135 .39893 m .32778 .36843 L .31326 .36358 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.2812 .57148 m .29473 .60517 L .31135 .60107 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.32778 .63157 m .31135 .60107 L .29473 .60517 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.65156 .34065 m .67222 .36843 L .68674 .36358 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.70527 .39483 m .68674 .36358 L .67222 .36843 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.67222 .63157 m .65156 .65935 L .6636 .6645 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.6636 .6645 m .68674 .63642 L .67222 .63157 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.54066 .28712 m .52114 .27289 L .51458 .27371 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.52114 .27289 m .54066 .28712 L .55188 .28512 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.47314 .27179 m .44812 .28512 L .45934 .28712 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.45934 .28712 m .47886 .27289 L .47314 .27179 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.54066 .71288 m .52114 .72711 L .52686 .72821 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.52686 .72821 m .55188 .71488 L .54066 .71288 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.47886 .72711 m .45934 .71288 L .44812 .71488 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.45934 .71288 m .47886 .72711 L .48542 .72629 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.3364 .3355 m .31326 .36358 L .32778 .36843 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.32778 .36843 m .34844 .34065 L .3364 .3355 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.29473 .60517 m .31326 .63642 L .32778 .63157 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.34844 .65935 m .32778 .63157 L .31326 .63642 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.58844 .29957 m .56116 .28266 L .55188 .28512 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.56116 .28266 m .58844 .29957 L .59898 .29574 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.62699 .31621 m .59898 .29574 L .58844 .29957 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.58844 .70043 m .56116 .71734 L .56804 .7202 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.56804 .7202 m .59898 .70426 L .58844 .70043 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.43196 .2798 m .40102 .29574 L .41156 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.41156 .29957 m .43884 .28266 L .43196 .2798 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.37301 .68379 m .40102 .70426 L .41156 .70043 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.43884 .71734 m .41156 .70043 L .40102 .70426 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.41156 .70043 m .43884 .71734 L .44812 .71488 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.62699 .31621 m .65156 .34065 L .6636 .3355 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.68674 .36358 m .6636 .3355 L .65156 .34065 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.65156 .65935 m .62699 .68379 L .63638 .68874 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.63638 .68874 m .6636 .6645 L .65156 .65935 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.36362 .31126 m .3364 .3355 L .34844 .34065 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.34844 .34065 m .37301 .31621 L .36362 .31126 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.31326 .63642 m .3364 .6645 L .34844 .65935 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.37301 .68379 m .34844 .65935 L .3364 .6645 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.55188 .28512 m .52686 .27179 L .52114 .27289 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.52686 .27179 m .55188 .28512 L .56116 .28266 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.55188 .71488 m .52686 .72821 L .53149 .72956 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.53149 .72956 m .56116 .71734 L .55188 .71488 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.46851 .27044 m .43884 .28266 L .44812 .28512 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.44812 .28512 m .47314 .27179 L .46851 .27044 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.47314 .72821 m .44812 .71488 L .43884 .71734 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.44812 .71488 m .47314 .72821 L .47886 .72711 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.59898 .29574 m .62699 .31621 L .63638 .31126 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.6636 .3355 m .63638 .31126 L .62699 .31621 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.62699 .68379 m .59898 .70426 L .60566 .70852 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.60566 .70852 m .63638 .68874 L .62699 .68379 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.39434 .29148 m .36362 .31126 L .37301 .31621 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.37301 .31621 m .40102 .29574 L .39434 .29148 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.3364 .6645 m .36362 .68874 L .37301 .68379 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.40102 .70426 m .37301 .68379 L .36362 .68874 L p F P
.505 .664 .505 r
s
.555 .774 .586 r
.5 .27438 m .5 .26345 L .49256 .27421 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50744 .27421 m .5 .26345 L .5 .27438 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .5 .72562 L .49256 .72579 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50744 .72579 L .5 .72562 L closepath p F P
.505 .664 .505 r
s
.586 .81 .618 r
.56116 .28266 m .53149 .27044 L .52686 .27179 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.53149 .27044 m .56116 .28266 L .56804 .2798 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.59898 .29574 m .56804 .2798 L .56116 .28266 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.56116 .71734 m .53149 .72956 L .53481 .7311 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.53481 .7311 m .56804 .7202 L .56116 .71734 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.46519 .2689 m .43196 .2798 L .43884 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.43884 .28266 m .46851 .27044 L .46519 .2689 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.40102 .70426 m .43196 .7202 L .43884 .71734 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.46851 .72956 m .43884 .71734 L .43196 .7202 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.43884 .71734 m .46851 .72956 L .47314 .72821 L p F P
.505 .664 .505 r
s
.553 .771 .583 r
.49256 .27421 m .5 .26345 L .48542 .27371 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51458 .27371 m .5 .26345 L .50744 .27421 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .49256 .72579 L .48542 .72629 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51458 .72629 L .50744 .72579 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70873 .59655 m
.70972 .59681 L
s
.5 Mabswid
.552 .771 .585 r
.52114 .27289 m .5 .26345 L .51458 .27371 L closepath p F P
.505 .664 .505 r
s
.549 .766 .579 r
.48542 .27371 m .5 .26345 L .47886 .27289 L closepath p F P
.505 .664 .505 r
s
.197 .204 .155 r
.5 .73655 m .52114 .72711 L .51458 .72629 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .48542 .72629 L .47886 .72711 L closepath p F P
.505 .664 .505 r
s
.557 .772 .598 r
.56804 .2798 m .59898 .29574 L .60566 .29148 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.63638 .31126 m .60566 .29148 L .59898 .29574 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.59898 .70426 m .56804 .7202 L .57217 .72334 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.57217 .72334 m .60566 .70852 L .59898 .70426 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.42783 .27666 m .39434 .29148 L .40102 .29574 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.40102 .29574 m .43196 .2798 L .42783 .27666 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.36362 .68874 m .39434 .70852 L .40102 .70426 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.43196 .7202 m .40102 .70426 L .39434 .70852 L p F P
.505 .664 .505 r
s
.548 .765 .582 r
.52686 .27179 m .5 .26345 L .52114 .27289 L closepath p F P
.505 .664 .505 r
s
.543 .759 .573 r
.47886 .27289 m .5 .26345 L .47314 .27179 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .52686 .72821 L .52114 .72711 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .47886 .72711 L .47314 .72821 L closepath p F P
.505 .664 .505 r
s
.541 .758 .578 r
.53149 .27044 m .5 .26345 L .52686 .27179 L closepath p F P
.505 .664 .505 r
s
.535 .75 .567 r
.47314 .27179 m .5 .26345 L .46851 .27044 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .53149 .72956 L .52686 .72821 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .47314 .72821 L .46851 .72956 L closepath p F P
.505 .664 .505 r
s
.344 .45 .374 r
.72703 .46384 m .7298 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.7298 .5 m .72703 .53616 L .73794 .53789 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.73794 .53789 m .74098 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.26206 .46211 m .25902 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.2702 .5 m .27297 .46384 L .26206 .46211 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.27297 .53616 m .2702 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.7188 .42852 m .72703 .46384 L .73794 .46211 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.74098 .5 m .73794 .46211 L .72703 .46384 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72703 .53616 m .7188 .57148 L .72891 .57479 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72891 .57479 m .73794 .53789 L .72703 .53616 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27109 .42521 m .26206 .46211 L .27297 .46384 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27297 .46384 m .2812 .42852 L .27109 .42521 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.25902 .5 m .26206 .53789 L .27297 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.2812 .57148 m .27297 .53616 L .26206 .53789 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.70527 .39483 m .7188 .42852 L .72891 .42521 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.73794 .46211 m .72891 .42521 L .7188 .42852 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.7188 .57148 m .70527 .60517 L .71415 .60972 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.71415 .60972 m .72891 .57479 L .7188 .57148 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.28585 .39028 m .27109 .42521 L .2812 .42852 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.2812 .42852 m .29473 .39483 L .28585 .39028 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.26206 .53789 m .27109 .57479 L .2812 .57148 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.29473 .60517 m .2812 .57148 L .27109 .57479 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.56804 .2798 m .53481 .2689 L .53149 .27044 L p F P
.505 .664 .505 r
s
.544 .761 .586 r
.53481 .2689 m .56804 .2798 L .57217 .27666 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.60566 .29148 m .57217 .27666 L .56804 .2798 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.56804 .7202 m .53481 .7311 L .53667 .73278 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.53667 .73278 m .57217 .72334 L .56804 .7202 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.46333 .26722 m .42783 .27666 L .43196 .2798 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.43196 .2798 m .46519 .2689 L .46333 .26722 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.39434 .70852 m .42783 .72334 L .43196 .7202 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.46519 .7311 m .43196 .7202 L .42783 .72334 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.43196 .7202 m .46519 .7311 L .46851 .72956 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.68674 .36358 m .70527 .39483 L .71415 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.72891 .42521 m .71415 .39028 L .70527 .39483 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.70527 .60517 m .68674 .63642 L .69406 .64177 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.69406 .64177 m .71415 .60972 L .70527 .60517 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.27109 .57479 m .28585 .60972 L .29473 .60517 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.31326 .63642 m .29473 .60517 L .28585 .60972 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.30594 .35823 m .28585 .39028 L .29473 .39483 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.29473 .39483 m .31326 .36358 L .30594 .35823 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.6636 .3355 m .68674 .36358 L .69406 .35823 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.71415 .39028 m .69406 .35823 L .68674 .36358 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.68674 .63642 m .6636 .6645 L .66919 .67013 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.66919 .67013 m .69406 .64177 L .68674 .63642 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.33081 .32987 m .30594 .35823 L .31326 .36358 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.31326 .36358 m .3364 .3355 L .33081 .32987 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.28585 .60972 m .30594 .64177 L .31326 .63642 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.3364 .6645 m .31326 .63642 L .30594 .64177 L p F P
.505 .664 .505 r
s
.533 .749 .571 r
.53481 .2689 m .5 .26345 L .53149 .27044 L closepath p F P
.505 .664 .505 r
s
.527 .74 .559 r
.46851 .27044 m .5 .26345 L .46519 .2689 L closepath p F P
.505 .664 .505 r
s
.183 .19 .145 r
.5 .73655 m .53481 .7311 L .53149 .72956 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .46851 .72956 L .46519 .7311 L closepath p F P
.505 .664 .505 r
s
.485 .675 .538 r
.63638 .31126 m .6636 .3355 L .66919 .32987 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.69406 .35823 m .66919 .32987 L .6636 .3355 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.6636 .6645 m .63638 .68874 L .64024 .69409 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.64024 .69409 m .66919 .67013 L .6636 .6645 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.30594 .64177 m .33081 .67013 L .3364 .6645 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.36362 .68874 m .3364 .6645 L .33081 .67013 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.35976 .30591 m .33081 .32987 L .3364 .3355 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.3364 .3355 m .36362 .31126 L .35976 .30591 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.60566 .29148 m .63638 .31126 L .64024 .30591 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.66919 .32987 m .64024 .30591 L .63638 .31126 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.63638 .68874 m .60566 .70852 L .60797 .71307 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.60797 .71307 m .64024 .69409 L .63638 .68874 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.39203 .28693 m .35976 .30591 L .36362 .31126 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.36362 .31126 m .39434 .29148 L .39203 .28693 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.33081 .67013 m .35976 .69409 L .36362 .68874 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.39434 .70852 m .36362 .68874 L .35976 .69409 L p F P
.505 .664 .505 r
s
.524 .738 .564 r
.53667 .26722 m .5 .26345 L .53481 .2689 L closepath p F P
.505 .664 .505 r
s
.544 .761 .586 r
.57217 .27666 m .53667 .26722 L .53481 .2689 L p F P
.505 .664 .505 r
s
.176 .185 .14 r
.5 .73655 m .53667 .73278 L .53481 .7311 L closepath p F P
.505 .664 .505 r
s
.517 .728 .55 r
.46519 .2689 m .5 .26345 L .46333 .26722 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42783 .72334 m .46333 .73278 L .46519 .7311 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .46519 .7311 L .46333 .73278 L closepath p F P
.505 .664 .505 r
s
.511 .718 .561 r
.57217 .27666 m .60566 .29148 L .60797 .28693 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.64024 .30591 m .60797 .28693 L .60566 .29148 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.60566 .70852 m .57217 .72334 L .57324 .72664 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.57324 .72664 m .60797 .71307 L .60566 .70852 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.35976 .69409 m .39203 .71307 L .39434 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.42783 .72334 m .39434 .70852 L .39203 .71307 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.42676 .27336 m .39203 .28693 L .39434 .29148 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.39434 .29148 m .42783 .27666 L .42676 .27336 L p F P
.505 .664 .505 r
s
.515 .726 .562 r
.53667 .26722 m .57217 .27666 L .57324 .27336 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.60797 .28693 m .57324 .27336 L .57217 .27666 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.57217 .72334 m .53667 .73278 L .53694 .73451 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.53694 .73451 m .57324 .72664 L .57217 .72334 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.39203 .71307 m .42676 .72664 L .42783 .72334 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.46333 .73278 m .42783 .72334 L .42676 .72664 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.46306 .26549 m .42676 .27336 L .42783 .27666 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.42783 .27666 m .46333 .26722 L .46306 .26549 L p F P
.505 .664 .505 r
s
.514 .725 .555 r
.53694 .26549 m .5 .26345 L .53667 .26722 L closepath p F P
.505 .664 .505 r
s
.515 .726 .562 r
.57324 .27336 m .53694 .26549 L .53667 .26722 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .53694 .73451 L .53667 .73278 L closepath p F P
.505 .664 .505 r
s
.506 .715 .541 r
.46333 .26722 m .5 .26345 L .46306 .26549 L closepath p F P
.505 .664 .505 r
s
.177 .185 .14 r
.42676 .72664 m .46306 .73451 L .46333 .73278 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .46333 .73278 L .46306 .73451 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .53558 .73624 L .53694 .73451 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .53263 .73787 L .53558 .73624 L closepath p F P
.505 .664 .505 r
s
.149 .16 .121 r
.5 .73655 m .52817 .73933 L .53263 .73787 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .73655 m .5224 .74056 L .52817 .73933 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .51556 .74148 L .5224 .74056 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50797 .74206 L .51556 .74148 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .5 .74225 L .50797 .74206 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49203 .74206 L .5 .74225 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .48444 .74148 L .49203 .74206 L closepath p F P
.505 .664 .505 r
s
.141 .152 .116 r
.5 .73655 m .4776 .74056 L .48444 .74148 L closepath p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .73655 m .47183 .73933 L .4776 .74056 L closepath p F P
.505 .664 .505 r
s
.152 .162 .123 r
.5 .73655 m .46737 .73787 L .47183 .73933 L closepath p F P
.505 .664 .505 r
s
.159 .168 .128 r
.5 .73655 m .46442 .73624 L .46737 .73787 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .46306 .73451 L .46442 .73624 L closepath p F P
.505 .664 .505 r
s
.503 .712 .546 r
.53558 .26376 m .5 .26345 L .53694 .26549 L closepath p F P
.505 .664 .505 r
s
.492 .698 .536 r
.53263 .26213 m .5 .26345 L .53558 .26376 L closepath p F P
.505 .664 .505 r
s
.496 .702 .532 r
.46306 .26549 m .5 .26345 L .46442 .26376 L closepath p F P
.505 .664 .505 r
s
.481 .685 .526 r
.52817 .26067 m .5 .26345 L .53263 .26213 L closepath p F P
.505 .664 .505 r
s
.485 .689 .523 r
.46442 .26376 m .5 .26345 L .46737 .26213 L closepath p F P
.505 .664 .505 r
s
.471 .673 .518 r
.5224 .25944 m .5 .26345 L .52817 .26067 L closepath p F P
.505 .664 .505 r
s
.475 .677 .515 r
.46737 .26213 m .5 .26345 L .47183 .26067 L closepath p F P
.505 .664 .505 r
s
.466 .667 .508 r
.47183 .26067 m .5 .26345 L .4776 .25944 L closepath p F P
.505 .664 .505 r
s
.463 .663 .51 r
.51556 .25852 m .5 .26345 L .5224 .25944 L closepath p F P
.505 .664 .505 r
s
.459 .658 .503 r
.4776 .25944 m .5 .26345 L .48444 .25852 L closepath p F P
.505 .664 .505 r
s
.457 .656 .504 r
.50797 .25794 m .5 .26345 L .51556 .25852 L closepath p F P
.505 .664 .505 r
s
.455 .653 .499 r
.48444 .25852 m .5 .26345 L .49203 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .652 .5 r
.5 .25775 m .5 .26345 L .50797 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49203 .25794 m .5 .26345 L .5 .25775 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.57324 .72664 m .53694 .73451 L .53558 .73624 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.53694 .26549 m .57324 .27336 L .57106 .27003 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.57106 .27003 m .53558 .26376 L .53694 .26549 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.42676 .27336 m .46306 .26549 L .46442 .26376 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.42894 .72997 m .46442 .73624 L .46306 .73451 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.46306 .73451 m .42676 .72664 L .42894 .72997 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.274 .41833 m
.2742 .41707 L
s
.26719 .439 m
.26818 .43709 L
s
0 0 0 r
.71898 .5983 m
.719 .60039 L
s
.72916 .5738 m
.72975 .57314 L
s
.5 Mabswid
.126 .138 .105 r
.60797 .71307 m .57324 .72664 L .57106 .72997 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.53558 .73624 m .57106 .72997 L .57324 .72664 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.57324 .27336 m .60797 .28693 L .6055 .28229 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.6055 .28229 m .57106 .27003 L .57324 .27336 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.3945 .71771 m .42894 .72997 L .42676 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.42676 .72664 m .39203 .71307 L .3945 .71771 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.46442 .26376 m .42894 .27003 L .42676 .27336 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.39203 .28693 m .42676 .27336 L .42894 .27003 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2742 .41707 m
.27427 .41491 L
s
.26603 .44057 m
.26719 .439 L
s
0 0 0 r
.719 .60039 m
.72006 .60109 L
s
.72975 .57314 m
.73094 .57368 L
s
.5 Mabswid
.108 .121 .092 r
.64024 .69409 m .60797 .71307 L .6055 .71771 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.57106 .72997 m .6055 .71771 L .60797 .71307 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.60797 .28693 m .64024 .30591 L .63793 .30038 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.63793 .30038 m .6055 .28229 L .60797 .28693 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.36207 .69962 m .3945 .71771 L .39203 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.39203 .71307 m .35976 .69409 L .36207 .69962 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.42894 .27003 m .3945 .28229 L .39203 .28693 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.35976 .30591 m .39203 .28693 L .3945 .28229 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.57106 .72997 m .53558 .73624 L .53263 .73787 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.53558 .26376 m .57106 .27003 L .56561 .26684 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.56561 .26684 m .53263 .26213 L .53558 .26376 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.43439 .73316 m .46737 .73787 L .46442 .73624 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.46442 .73624 m .42894 .72997 L .43439 .73316 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.42894 .27003 m .46442 .26376 L .46737 .26213 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27342 .41445 m
.27427 .41491 L
s
.26511 .44023 m
.26603 .44057 L
s
.5 Mabswid
.376 .54 .443 r
.64024 .30591 m .66919 .32987 L .66739 .32399 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.66739 .32399 m .63793 .30038 L .64024 .30591 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.66919 .67013 m .64024 .69409 L .63793 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.6055 .71771 m .63793 .69962 L .64024 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.33261 .67601 m .36207 .69962 L .35976 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.35976 .69409 m .33081 .67013 L .33261 .67601 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.3945 .28229 m .36207 .30038 L .35976 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.33081 .32987 m .35976 .30591 L .36207 .30038 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27221 .41602 m
.27342 .41445 L
s
.5 Mabswid
.332 .476 .399 r
.66919 .32987 m .69406 .35823 L .69297 .35258 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.69297 .35258 m .66739 .32399 L .66919 .32987 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.69406 .64177 m .66919 .67013 L .66739 .67601 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.63793 .69962 m .66739 .67601 L .66919 .67013 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.36207 .30038 m .33261 .32399 L .33081 .32987 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.30594 .35823 m .33081 .32987 L .33261 .32399 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.30703 .64742 m .33261 .67601 L .33081 .67013 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.33081 .67013 m .30594 .64177 L .30703 .64742 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26505 .4382 m
.26511 .44023 L
s
.5 Mabswid
.11 .123 .094 r
.443 .73607 m .47183 .73933 L .46737 .73787 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.46737 .73787 m .43439 .73316 L .443 .73607 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.53263 .73787 m .56561 .73316 L .57106 .72997 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.56561 .73316 m .53263 .73787 L .52817 .73933 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.43439 .26684 m .46737 .26213 L .47183 .26067 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.46737 .26213 m .43439 .26684 L .42894 .27003 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.53263 .26213 m .56561 .26684 L .557 .26393 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.557 .26393 m .52817 .26067 L .53263 .26213 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73087 .57622 m
.73094 .57368 L
s
.5 Mabswid
.285 .408 .351 r
.69406 .35823 m .71415 .39028 L .71384 .38544 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.71384 .38544 m .69297 .35258 L .69406 .35823 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.71415 .60972 m .69406 .64177 L .69297 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66739 .67601 m .69297 .64742 L .69406 .64177 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.33261 .32399 m .30703 .35258 L .30594 .35823 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.28585 .39028 m .30594 .35823 L .30703 .35258 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.28616 .61456 m .30703 .64742 L .30594 .64177 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.30594 .64177 m .28585 .60972 L .28616 .61456 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.72891 .57479 m .71415 .60972 L .71384 .61456 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72006 .60109 m
.72146 .5998 L
s
.5 Mabswid
.075 .096 .079 r
.69297 .64742 m .71384 .61456 L .71415 .60972 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.71415 .39028 m .72891 .42521 L .72928 .42167 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.72928 .42167 m .71384 .38544 L .71415 .39028 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.30703 .35258 m .28616 .38544 L .28585 .39028 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.27109 .42521 m .28585 .39028 L .28616 .38544 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.27072 .57833 m .28616 .61456 L .28585 .60972 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.28585 .60972 m .27109 .57479 L .27072 .57833 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.6055 .71771 m .57106 .72997 L .56561 .73316 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.57106 .27003 m .6055 .28229 L .59806 .27776 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.59806 .27776 m .56561 .26684 L .57106 .27003 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.40194 .72224 m .43439 .73316 L .42894 .72997 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.42894 .72997 m .3945 .71771 L .40194 .72224 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.3945 .28229 m .42894 .27003 L .43439 .26684 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.72891 .42521 m .73794 .46211 L .73877 .46024 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.73877 .46024 m .72928 .42167 L .72891 .42521 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.73794 .53789 m .72891 .57479 L .72928 .57833 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.71384 .61456 m .72928 .57833 L .72891 .57479 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72146 .5998 m
.72359 .59664 L
s
.5 Mabswid
.093 .108 .082 r
.26123 .53976 m .27072 .57833 L .27109 .57479 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.27109 .57479 m .26206 .53789 L .26123 .53976 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.28616 .38544 m .27072 .42167 L .27109 .42521 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27038 .41948 m
.27221 .41602 L
s
.5 Mabswid
.141 .198 .13 r
.26206 .46211 m .27109 .42521 L .27072 .42167 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.73794 .46211 m .74098 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.74197 .5 m .73877 .46024 L .73794 .46211 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.74098 .5 m .73794 .53789 L .73877 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.72928 .57833 m .73877 .53976 L .73794 .53789 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72992 .58087 m
.73087 .57622 L
s
.5 Mabswid
.141 .198 .13 r
.27072 .42167 m .26123 .46024 L .26206 .46211 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26505 .4382 m
.26559 .43433 L
s
.5 Mabswid
.12 .16 .109 r
.25902 .5 m .26206 .46211 L .26123 .46024 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.25803 .5 m .26123 .53976 L .26206 .53789 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.26206 .53789 m .25902 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.73877 .53976 m .74197 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.26123 .46024 m .25803 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.45445 .73853 m .4776 .74056 L .47183 .73933 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.47183 .73933 m .443 .73607 L .45445 .73853 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.52817 .73933 m .557 .73607 L .56561 .73316 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.557 .73607 m .52817 .73933 L .5224 .74056 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.443 .26393 m .47183 .26067 L .4776 .25944 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.47183 .26067 m .443 .26393 L .43439 .26684 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.52817 .26067 m .557 .26393 L .54555 .26147 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.54555 .26147 m .5224 .25944 L .52817 .26067 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26824 .42496 m
.27038 .41948 L
s
.26559 .43433 m
.26704 .42867 L
s
.26704 .42867 m
.26824 .42496 L
s
0 0 0 r
.72359 .59664 m
.72623 .59119 L
s
.72782 .58724 m
.72992 .58087 L
s
.5 Mabswid
.072 .089 .067 r
.46823 .7404 m .48444 .74148 L .4776 .74056 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.4776 .74056 m .45445 .73853 L .46823 .7404 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.5224 .74056 m .54555 .73853 L .557 .73607 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.54555 .73853 m .5224 .74056 L .51556 .74148 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.45445 .26147 m .4776 .25944 L .48444 .25852 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.4776 .25944 m .45445 .26147 L .443 .26393 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.5224 .25944 m .54555 .26147 L .53177 .2596 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.53177 .2596 m .51556 .25852 L .5224 .25944 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72623 .59119 m
.72782 .58724 L
s
.5 Mabswid
.32 .474 .391 r
.6055 .28229 m .63793 .30038 L .62903 .29493 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.62903 .29493 m .59806 .27776 L .6055 .28229 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63793 .69962 m .6055 .71771 L .59806 .72224 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.56561 .73316 m .59806 .72224 L .6055 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.37097 .70507 m .40194 .72224 L .3945 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.3945 .71771 m .36207 .69962 L .37097 .70507 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.43439 .26684 m .40194 .27776 L .3945 .28229 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.36207 .30038 m .3945 .28229 L .40194 .27776 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48368 .74157 m .49203 .74206 L .48444 .74148 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48444 .74148 m .46823 .7404 L .48368 .74157 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.46823 .2596 m .48444 .25852 L .49203 .25794 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.48444 .25852 m .46823 .2596 L .45445 .26147 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.51556 .74148 m .53177 .7404 L .54555 .73853 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.53177 .7404 m .51556 .74148 L .50797 .74206 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51556 .25852 m .53177 .2596 L .51632 .25843 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51632 .25843 m .50797 .25794 L .51556 .25852 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.5 .74197 m .5 .74225 L .49203 .74206 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.49203 .74206 m .48368 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.50797 .74206 m .51632 .74157 L .53177 .7404 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.51632 .74157 m .50797 .74206 L .5 .74225 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.49203 .25794 m .48368 .25843 L .46823 .2596 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.48368 .25843 m .49203 .25794 L .5 .25775 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50797 .25794 m .51632 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.5 .25803 m .5 .25775 L .50797 .25794 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.41427 .7264 m .443 .73607 L .43439 .73316 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.43439 .73316 m .40194 .72224 L .41427 .7264 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.40194 .27776 m .43439 .26684 L .443 .26393 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .56561 .73316 L .557 .73607 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.56561 .26684 m .59806 .27776 L .58573 .2736 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.58573 .2736 m .557 .26393 L .56561 .26684 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.5 .74225 m .5 .74197 L .51632 .74157 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.5 .25775 m .5 .25803 L .48368 .25843 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26725 .42398 m
.26915 .41815 L
s
.26603 .42774 m
.26725 .42398 L
s
.26425 .43321 m
.26603 .42774 L
s
0 0 0 r
.72189 .60348 m
.7219 .60421 L
s
1 .5 0 r
.26915 .41815 m
.27048 .41402 L
s
.26309 .43668 m
.26425 .43321 L
s
.5 Mabswid
.056 .074 .056 r
.59806 .72224 m .62903 .70507 L .63793 .69962 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.66739 .67601 m .63793 .69962 L .62903 .70507 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.63793 .30038 m .66739 .32399 L .65752 .31812 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.65752 .31812 m .62903 .29493 L .63793 .30038 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.34248 .68188 m .37097 .70507 L .36207 .69962 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.36207 .69962 m .33261 .67601 L .34248 .68188 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.40194 .27776 m .37097 .29493 L .36207 .30038 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.33261 .32399 m .36207 .30038 L .37097 .29493 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27048 .41402 m
.2712 .41178 L
s
.26254 .4383 m
.26309 .43668 L
s
0 0 0 r
.7219 .60421 m
.72263 .6029 L
s
1 .5 0 r
.2712 .41178 m
.27128 .4113 L
s
.5 Mabswid
.378 .556 .442 r
.43113 .72997 m .45445 .73853 L .443 .73607 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.443 .73607 m .41427 .7264 L .43113 .72997 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.443 .26393 m .41427 .2736 L .40194 .27776 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.41427 .2736 m .443 .26393 L .45445 .26147 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.557 .73607 m .58573 .7264 L .59806 .72224 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.58573 .7264 m .557 .73607 L .54555 .73853 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.557 .26393 m .58573 .2736 L .56887 .27003 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.56887 .27003 m .54555 .26147 L .557 .26393 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26254 .4383 m
.26258 .43795 L
s
.5 Mabswid
.284 .411 .284 r
.69297 .64742 m .66739 .67601 L .65752 .68188 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.62903 .70507 m .65752 .68188 L .66739 .67601 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.66739 .32399 m .69297 .35258 L .68252 .34688 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.68252 .34688 m .65752 .31812 L .66739 .32399 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.31748 .65312 m .34248 .68188 L .33261 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.33261 .67601 m .30703 .64742 L .31748 .65312 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.37097 .29493 m .34248 .31812 L .33261 .32399 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.30703 .35258 m .33261 .32399 L .34248 .31812 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72263 .6029 m
.72409 .59966 L
s
.5 Mabswid
.394 .571 .46 r
.38653 .71016 m .41427 .7264 L .40194 .72224 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.40194 .72224 m .37097 .70507 L .38653 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.62903 .70507 m .59806 .72224 L .58573 .7264 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.37097 .29493 m .40194 .27776 L .41427 .2736 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.59806 .27776 m .62903 .29493 L .61347 .28984 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.61347 .28984 m .58573 .2736 L .59806 .27776 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27067 .41292 m
.27128 .4113 L
s
.26258 .43795 m
.26319 .43584 L
s
.27067 .41292 m
.26943 .41649 L
s
0 0 0 r
.72409 .59966 m
.72644 .59407 L
s
.5 Mabswid
.146 .156 .119 r
.69297 .35258 m .71384 .38544 L .7031 .38051 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.7031 .38051 m .68252 .34688 L .69297 .35258 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.71384 .61456 m .69297 .64742 L .68252 .65312 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.65752 .68188 m .68252 .65312 L .69297 .64742 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.34248 .31812 m .31748 .34688 L .30703 .35258 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.28616 .38544 m .30703 .35258 L .31748 .34688 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.2969 .61949 m .31748 .65312 L .30703 .64742 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.30703 .64742 m .28616 .61456 L .2969 .61949 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45177 .7327 m .46823 .7404 L .45445 .73853 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45445 .73853 m .43113 .72997 L .45177 .7327 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.43113 .27003 m .45445 .26147 L .46823 .2596 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.45445 .26147 m .43113 .27003 L .41427 .2736 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.54555 .73853 m .56887 .72997 L .58573 .7264 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.56887 .72997 m .54555 .73853 L .53177 .7404 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54555 .26147 m .56887 .27003 L .54823 .2673 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54823 .2673 m .53177 .2596 L .54555 .26147 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26319 .43584 m
.26443 .43183 L
s
0 0 0 r
.72136 .60544 m
.72403 .5988 L
s
.72403 .5988 m
.7328 .57701 L
s
1 .5 0 r
.26753 .42214 m
.26943 .41649 L
s
.26443 .43183 m
.26628 .42598 L
s
.26628 .42598 m
.26753 .42214 L
s
.5 Mabswid
.181 .205 .148 r
.71384 .38544 m .72928 .42167 L .71844 .41804 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71844 .41804 m .7031 .38051 L .71384 .38544 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.72928 .57833 m .71384 .61456 L .7031 .61949 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.68252 .65312 m .7031 .61949 L .71384 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28156 .58196 m .2969 .61949 L .28616 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28616 .61456 m .27072 .57833 L .28156 .58196 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.31748 .34688 m .2969 .38051 L .28616 .38544 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.27072 .42167 m .28616 .38544 L .2969 .38051 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.47517 .73443 m .48368 .74157 L .46823 .7404 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.46823 .7404 m .45177 .7327 L .47517 .73443 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.45177 .2673 m .46823 .2596 L .48368 .25843 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.46823 .2596 m .45177 .2673 L .43113 .27003 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.53177 .7404 m .54823 .7327 L .56887 .72997 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.54823 .7327 m .53177 .7404 L .51632 .74157 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53177 .2596 m .54823 .2673 L .52483 .26557 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.52483 .26557 m .51632 .25843 L .53177 .2596 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72928 .42167 m .73877 .46024 L .72792 .45832 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72792 .45832 m .71844 .41804 L .72928 .42167 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.73877 .53976 m .72928 .57833 L .71844 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.7031 .61949 m .71844 .58196 L .72928 .57833 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.36072 .68742 m .38653 .71016 L .37097 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.37097 .70507 m .34248 .68188 L .36072 .68742 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27208 .54168 m .28156 .58196 L .27072 .57833 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27072 .57833 m .26123 .53976 L .27208 .54168 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.41427 .2736 m .38653 .28984 L .37097 .29493 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.34248 .31812 m .37097 .29493 L .38653 .28984 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.2969 .38051 m .28156 .41804 L .27072 .42167 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.26123 .46024 m .27072 .42167 L .28156 .41804 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.65752 .68188 m .62903 .70507 L .61347 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.58573 .7264 m .61347 .71016 L .62903 .70507 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.62903 .29493 m .65752 .31812 L .63928 .31258 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.63928 .31258 m .61347 .28984 L .62903 .29493 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.5 .73502 m .5 .74197 L .48368 .74157 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.48368 .74157 m .47517 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.51632 .74157 m .52483 .73443 L .54823 .7327 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.52483 .73443 m .51632 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.47517 .26557 m .48368 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.48368 .25843 m .47517 .26557 L .45177 .2673 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.51632 .25843 m .52483 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .26498 m .5 .25803 L .51632 .25843 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.40837 .71456 m .43113 .72997 L .41427 .7264 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.41427 .7264 m .38653 .71016 L .40837 .71456 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.38653 .28984 m .41427 .2736 L .43113 .27003 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.61347 .71016 m .58573 .7264 L .56887 .72997 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.58573 .2736 m .61347 .28984 L .59163 .28544 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.59163 .28544 m .56887 .27003 L .58573 .2736 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73877 .46024 m .74197 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73113 .5 m .72792 .45832 L .73877 .46024 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.74197 .5 m .73877 .53976 L .72792 .54168 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.71844 .58196 m .72792 .54168 L .73877 .53976 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.28156 .41804 m .27208 .45832 L .26123 .46024 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.25803 .5 m .26123 .46024 L .27208 .45832 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26887 .5 m .27208 .54168 L .26123 .53976 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26123 .53976 m .25803 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7109 .62056 m
.72074 .60051 L
s
.72272 .59647 m
.7319 .57777 L
s
.72074 .60051 m
.72272 .59647 L
s
.5 Mabswid
.262 .34 .224 r
.72792 .54168 m .73113 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.27208 .45832 m .26887 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.5 .74197 m .5 .73502 L .52483 .73443 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .25803 m .5 .26498 L .47517 .26557 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26398 .44039 m
.27314 .40935 L
s
.26124 .44967 m
.26398 .44039 L
s
0 0 0 r
.71987 .59585 m
.72532 .59362 L
s
.5 Mabswid
.494 .682 .543 r
.33783 .65855 m .36072 .68742 L .34248 .68188 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.34248 .68188 m .31748 .65312 L .33783 .65855 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.38653 .28984 m .36072 .31258 L .34248 .31812 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.31748 .34688 m .34248 .31812 L .36072 .31258 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.68252 .65312 m .65752 .68188 L .63928 .68742 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.61347 .71016 m .63928 .68742 L .65752 .68188 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.65752 .31812 m .68252 .34688 L .66217 .34145 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.66217 .34145 m .63928 .31258 L .65752 .31812 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7109 .62056 m
.71674 .60163 L
s
.71674 .60163 m
.71736 .59963 L
s
.5 Mabswid
.532 .746 .577 r
.43559 .71798 m .45177 .7327 L .43113 .72997 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43113 .72997 m .40837 .71456 L .43559 .71798 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.40837 .28544 m .43113 .27003 L .45177 .2673 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.43113 .27003 m .40837 .28544 L .38653 .28984 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.56887 .72997 m .59163 .71456 L .61347 .71016 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.59163 .71456 m .56887 .72997 L .54823 .7327 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56887 .27003 m .59163 .28544 L .56441 .28202 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56441 .28202 m .54823 .2673 L .56887 .27003 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26487 .44539 m
.27578 .40805 L
s
.26384 .44891 m
.26487 .44539 L
s
.5 Mabswid
.543 .752 .588 r
.38699 .69227 m .40837 .71456 L .38653 .71016 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38653 .71016 m .36072 .68742 L .38699 .69227 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.36072 .31258 m .38653 .28984 L .40837 .28544 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.63928 .68742 m .61347 .71016 L .59163 .71456 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61347 .28984 m .63928 .31258 L .61301 .30773 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61301 .30773 m .59163 .28544 L .61347 .28984 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.36072 .31258 m .33783 .34145 L .31748 .34688 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.2969 .38051 m .31748 .34688 L .33783 .34145 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31882 .62423 m .33783 .65855 L .31748 .65312 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31748 .65312 m .2969 .61949 L .31882 .62423 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68252 .34688 m .7031 .38051 L .68118 .37577 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68118 .37577 m .66217 .34145 L .68252 .34688 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.7031 .61949 m .68252 .65312 L .66217 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.63928 .68742 m .66217 .65855 L .68252 .65312 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.46675 .72014 m .47517 .73443 L .45177 .7327 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.45177 .7327 m .43559 .71798 L .46675 .72014 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.43559 .28202 m .45177 .2673 L .47517 .26557 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.45177 .2673 m .43559 .28202 L .40837 .28544 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.54823 .7327 m .56441 .71798 L .59163 .71456 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.56441 .71798 m .54823 .7327 L .52483 .73443 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.54823 .2673 m .56441 .28202 L .53325 .27986 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.53325 .27986 m .52483 .26557 L .54823 .2673 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27478 .41896 m
.27735 .41279 L
s
.27352 .42294 m
.27478 .41896 L
s
.27231 .42874 m
.27352 .42294 L
s
.27735 .41279 m
.27995 .40844 L
s
.27231 .42874 m
.27239 .43243 L
s
.5 Mabswid
.576 .798 .606 r
.5 .72088 m .5 .73502 L .47517 .73443 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.47517 .73443 m .46675 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.46675 .27986 m .47517 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.47517 .26557 m .46675 .27986 L .43559 .28202 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.52483 .73443 m .53325 .72014 L .56441 .71798 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.53325 .72014 m .52483 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.52483 .26557 m .53325 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.5 .27912 m .5 .26498 L .52483 .26557 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.30454 .58546 m .31882 .62423 L .2969 .61949 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.2969 .61949 m .28156 .58196 L .30454 .58546 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.33783 .34145 m .31882 .37577 L .2969 .38051 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.28156 .41804 m .2969 .38051 L .31882 .37577 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.71844 .58196 m .7031 .61949 L .68118 .62423 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71736 .59963 m
.72316 .58083 L
s
.5 Mabswid
.443 .603 .422 r
.66217 .65855 m .68118 .62423 L .7031 .61949 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.7031 .38051 m .71844 .41804 L .69546 .41454 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.69546 .41454 m .68118 .37577 L .7031 .38051 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27995 .40844 m
.28191 .40609 L
s
.5 Mabswid
.571 .791 .595 r
.5 .73502 m .5 .72088 L .53325 .72014 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5 .26498 m .5 .27912 L .46675 .27986 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27239 .43243 m
.27311 .43416 L
s
.5 Mabswid
.188 .195 .148 r
.40837 .28544 m .38699 .30773 L .36072 .31258 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.33783 .34145 m .36072 .31258 L .38699 .30773 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36786 .66334 m .38699 .69227 L .36072 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36072 .68742 m .33783 .65855 L .36786 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.66217 .65855 m .63928 .68742 L .61301 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.59163 .71456 m .61301 .69227 L .63928 .68742 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63928 .31258 m .66217 .34145 L .63214 .33666 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63214 .33666 m .61301 .30773 L .63928 .31258 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.29568 .54355 m .30454 .58546 L .28156 .58196 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.28156 .58196 m .27208 .54168 L .29568 .54355 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.31882 .37577 m .30454 .41454 L .28156 .41804 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28191 .40609 m
.28387 .4056 L
s
.5 Mabswid
.391 .488 .386 r
.27208 .45832 m .28156 .41804 L .30454 .41454 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.71844 .41804 m .72792 .45832 L .70432 .45645 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.70432 .45645 m .69546 .41454 L .71844 .41804 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.72792 .54168 m .71844 .58196 L .69546 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.68118 .62423 m .69546 .58546 L .71844 .58196 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.38699 .30773 m .40837 .28544 L .43559 .28202 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.42026 .69605 m .43559 .71798 L .40837 .71456 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.40837 .71456 m .38699 .69227 L .42026 .69605 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.61301 .69227 m .59163 .71456 L .56441 .71798 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.59163 .28544 m .61301 .30773 L .57974 .30395 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.57974 .30395 m .56441 .28202 L .59163 .28544 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28387 .4056 m
.28451 .40733 L
s
.5 Mabswid
.391 .488 .386 r
.30454 .41454 m .29568 .45645 L .27208 .45832 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27311 .43416 m
.27509 .43381 L
s
.5 Mabswid
.438 .56 .442 r
.26887 .5 m .27208 .45832 L .29568 .45645 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.29268 .5 m .29568 .54355 L .27208 .54168 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.27208 .54168 m .26887 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.72792 .45832 m .73113 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.70732 .5 m .70432 .45645 L .72792 .45832 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.73113 .5 m .72792 .54168 L .70432 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.69546 .58546 m .70432 .54355 L .72792 .54168 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28451 .40733 m
.28455 .41111 L
s
.27509 .43381 m
.27701 .43158 L
s
.5 Mabswid
.438 .56 .442 r
.29568 .45645 m .29268 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.70432 .54355 m .70732 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27701 .43158 m
.27957 .42734 L
s
.28331 .41709 m
.28455 .41111 L
s
.27957 .42734 m
.28207 .42115 L
s
.28207 .42115 m
.28331 .41709 L
s
.5 Mabswid
.283 .314 .225 r
.42026 .30395 m .43559 .28202 L .46675 .27986 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.45874 .69847 m .46675 .72014 L .43559 .71798 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.43559 .71798 m .42026 .69605 L .45874 .69847 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.43559 .28202 m .42026 .30395 L .38699 .30773 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.56441 .71798 m .57974 .69605 L .61301 .69227 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.57974 .69605 m .56441 .71798 L .53325 .72014 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.56441 .28202 m .57974 .30395 L .54126 .30153 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.54126 .30153 m .53325 .27986 L .56441 .28202 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.38699 .30773 m .36786 .33666 L .33783 .34145 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.31882 .37577 m .33783 .34145 L .36786 .33666 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.35184 .62843 m .36786 .66334 L .33783 .65855 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.33783 .65855 m .31882 .62423 L .35184 .62843 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.66217 .34145 m .68118 .37577 L .64816 .37157 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.64816 .37157 m .63214 .33666 L .66217 .34145 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.68118 .62423 m .66217 .65855 L .63214 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.61301 .69227 m .63214 .66334 L .66217 .65855 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28481 .4324 m
.29338 .40368 L
s
.5 Mabswid
.627 .846 .647 r
.40645 .66711 m .42026 .69605 L .38699 .69227 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.38699 .69227 m .36786 .66334 L .40645 .66711 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.36786 .33666 m .38699 .30773 L .42026 .30395 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.63214 .66334 m .61301 .69227 L .57974 .69605 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.61301 .30773 m .63214 .33666 L .59355 .33289 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.59355 .33289 m .57974 .30395 L .61301 .30773 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28689 .42429 m
.28818 .43003 L
s
.5 Mabswid
.304 .342 .242 r
.45874 .30153 m .46675 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.5 .6993 m .5 .72088 L .46675 .72014 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.46675 .72014 m .45874 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.46675 .27986 m .45874 .30153 L .42026 .30395 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.53325 .72014 m .54126 .69847 L .57974 .69605 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.54126 .69847 m .53325 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.53325 .27986 m .54126 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.5 .3007 m .5 .27912 L .53325 .27986 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.5 .72088 m .5 .6993 L .54126 .69847 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.5 .27912 m .5 .3007 L .45874 .30153 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28818 .43003 m
.28971 .43183 L
s
.5 Mabswid
.593 .786 .606 r
.33974 .58859 m .35184 .62843 L .31882 .62423 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.31882 .62423 m .30454 .58546 L .33974 .58859 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.36786 .33666 m .35184 .37157 L .31882 .37577 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.30454 .41454 m .31882 .37577 L .35184 .37157 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.69546 .58546 m .68118 .62423 L .64816 .62843 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.63214 .66334 m .64816 .62843 L .68118 .62423 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.68118 .37577 m .69546 .41454 L .66026 .41141 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.66026 .41141 m .64816 .37157 L .68118 .37577 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28971 .43183 m
.29289 .43149 L
s
.29289 .43149 m
.29559 .42922 L
s
.5 Mabswid
.58 .759 .584 r
.3322 .54522 m .33974 .58859 L .30454 .58546 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.30454 .58546 m .29568 .54355 L .3322 .54522 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.35184 .37157 m .33974 .41141 L .30454 .41454 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.29568 .45645 m .30454 .41454 L .33974 .41141 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29825 .42291 m
.3045 .40198 L
s
.5 Mabswid
.525 .685 .48 r
.70432 .54355 m .69546 .58546 L .66026 .58859 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.64816 .62843 m .66026 .58859 L .69546 .58546 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.69546 .41454 m .70432 .45645 L .6678 .45478 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.6678 .45478 m .66026 .41141 L .69546 .41454 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29559 .42922 m
.29825 .42291 L
s
.5 Mabswid
.649 .871 .658 r
.45149 .66953 m .45874 .69847 L .42026 .69605 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.42026 .69605 m .40645 .66711 L .45149 .66953 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.40645 .33289 m .42026 .30395 L .45874 .30153 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.42026 .30395 m .40645 .33289 L .36786 .33666 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.57974 .69605 m .59355 .66711 L .63214 .66334 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.59355 .66711 m .57974 .69605 L .54126 .69847 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.57974 .30395 m .59355 .33289 L .54851 .33047 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.54851 .33047 m .54126 .30153 L .57974 .30395 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.35184 .37157 m .36786 .33666 L .40645 .33289 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.39481 .63177 m .40645 .66711 L .36786 .66334 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.36786 .66334 m .35184 .62843 L .39481 .63177 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.63214 .33666 m .64816 .37157 L .60519 .36823 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.60519 .36823 m .59355 .33289 L .63214 .33666 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.64816 .62843 m .63214 .66334 L .59355 .66711 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.33974 .41141 m .3322 .45478 L .29568 .45645 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.29268 .5 m .29568 .45645 L .3322 .45478 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.32963 .5 m .3322 .54522 L .29568 .54355 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.29568 .54355 m .29268 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.70432 .45645 m .70732 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.67037 .5 m .6678 .45478 L .70432 .45645 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.70732 .5 m .70432 .54355 L .6678 .54522 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.66026 .58859 m .6678 .54522 L .70432 .54355 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.3322 .45478 m .32963 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.6678 .54522 m .67037 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30608 .43028 m
.31404 .40079 L
s
.5 Mabswid
.655 .877 .656 r
.5 .67037 m .5 .6993 L .45874 .69847 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.45874 .69847 m .45149 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.45149 .33047 m .45874 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.45874 .30153 m .45149 .33047 L .40645 .33289 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.54126 .69847 m .54851 .66953 L .59355 .66711 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.54851 .66953 m .54126 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.54126 .30153 m .54851 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.5 .32963 m .5 .3007 L .54126 .30153 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.302 .44473 m
.30297 .44666 L
s
.302 .44473 m
.30366 .44261 L
s
.30366 .44261 m
.30464 .44456 L
s
.30297 .44666 m
.30464 .44456 L
s
.5 Mabswid
.649 .868 .644 r
.5 .6993 m .5 .67037 L .54851 .66953 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.5 .3007 m .5 .32963 L .45149 .33047 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32554 .40165 m
.32909 .39923 L
s
.32227 .40823 m
.32554 .40165 L
s
.31718 .42944 m
.32227 .40823 L
s
.5 Mabswid
.632 .832 .632 r
.38598 .59108 m .39481 .63177 L .35184 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.35184 .62843 m .33974 .58859 L .38598 .59108 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.40645 .33289 m .39481 .36823 L .35184 .37157 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.33974 .41141 m .35184 .37157 L .39481 .36823 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.66026 .58859 m .64816 .62843 L .60519 .63177 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.59355 .66711 m .60519 .63177 L .64816 .62843 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.64816 .37157 m .66026 .41141 L .61402 .40892 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.61402 .40892 m .60519 .36823 L .64816 .37157 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32909 .39923 m
.33358 .39882 L
s
.5 Mabswid
.454 .554 .406 r
.39481 .36823 m .40645 .33289 L .45149 .33047 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.44535 .63392 m .45149 .66953 L .40645 .66711 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.40645 .66711 m .39481 .63177 L .44535 .63392 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.59355 .33289 m .60519 .36823 L .55465 .36608 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.55465 .36608 m .54851 .33047 L .59355 .33289 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.60519 .63177 m .59355 .66711 L .54851 .66953 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33358 .39882 m
.33604 .40073 L
s
.33604 .40073 m
.33911 .40686 L
s
.5 Mabswid
.484 .6 .449 r
.39481 .36823 m .38598 .40892 L .33974 .41141 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.3322 .45478 m .33974 .41141 L .38598 .40892 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33443 .42836 m
.3414 .39817 L
s
.5 Mabswid
.618 .805 .609 r
.38045 .54655 m .38598 .59108 L .33974 .58859 L p F P
.505 .664 .505 r
s
.618 .805 .609 r
.33974 .58859 m .3322 .54522 L .38045 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.6678 .54522 m .66026 .58859 L .61402 .59108 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.60519 .63177 m .61402 .59108 L .66026 .58859 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.66026 .41141 m .6678 .45478 L .61955 .45345 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.61955 .45345 m .61402 .40892 L .66026 .41141 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.44535 .36608 m .45149 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.5 .63466 m .5 .67037 L .45149 .66953 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.45149 .66953 m .44535 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.45149 .33047 m .44535 .36608 L .39481 .36823 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.54851 .66953 m .55465 .63392 L .60519 .63177 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.54851 .33047 m .55465 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.5 .36534 m .5 .32963 L .54851 .33047 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.55465 .63392 m .54851 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.38598 .40892 m .38045 .45345 L .3322 .45478 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.32963 .5 m .3322 .45478 L .38045 .45345 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.37857 .5 m .38045 .54655 L .3322 .54522 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.3322 .54522 m .32963 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.6678 .45478 m .67037 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.62143 .5 m .61955 .45345 L .6678 .45478 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.67037 .5 m .6678 .54522 L .61955 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.61402 .59108 m .61955 .54655 L .6678 .54522 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.35144 .40387 m
.35426 .39938 L
s
.35426 .39938 m
.3601 .39683 L
s
.5 Mabswid
.567 .724 .545 r
.38045 .45345 m .37857 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.5 .67037 m .5 .63466 L .55465 .63392 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.5 .32963 m .5 .36534 L .44535 .36608 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.61955 .54655 m .62143 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.3601 .39683 m
.36554 .3965 L
s
.5 Mabswid
.51 .634 .467 r
.38598 .40892 m .39481 .36823 L .44535 .36608 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.44068 .5927 m .44535 .63392 L .39481 .63177 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.39481 .63177 m .38598 .59108 L .44068 .5927 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.61402 .59108 m .60519 .63177 L .55465 .63392 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.60519 .36823 m .61402 .40892 L .55932 .4073 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.55932 .4073 m .55465 .36608 L .60519 .36823 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34773 .42127 m
.35035 .41684 L
s
.34773 .42127 m
.34873 .42549 L
s
.35035 .41684 m
.3544 .41447 L
s
.36554 .3965 m
.37062 .39838 L
s
.3544 .41447 m
.36411 .4118 L
s
.34873 .42549 m
.35387 .42738 L
s
.37062 .39838 m
.37158 .4027 L
s
.35387 .42738 m
.35953 .42713 L
s
.36411 .4118 m
.36834 .40941 L
s
.37113 .40491 m
.37158 .4027 L
s
.36834 .40941 m
.37113 .40491 L
s
.35953 .42713 m
.36567 .42473 L
s
.36567 .42473 m
.36832 .42029 L
s
.38617 .3976 m
.38861 .39528 L
s
.5 Mabswid
.633 .824 .615 r
.43776 .54742 m .44068 .5927 L .38598 .59108 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.38598 .59108 m .38045 .54655 L .43776 .54742 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.44535 .36608 m .44068 .4073 L .38598 .40892 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.38861 .39528 m
.3902 .39741 L
s
.38617 .3976 m
.38776 .39973 L
s
.5 Mabswid
.552 .697 .516 r
.38045 .45345 m .38598 .40892 L .44068 .4073 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.61402 .40892 m .61955 .45345 L .56224 .45258 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.56224 .45258 m .55932 .4073 L .61402 .40892 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.61955 .54655 m .61402 .59108 L .55932 .5927 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.55465 .63392 m .55932 .5927 L .61402 .59108 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.38776 .39973 m
.3902 .39741 L
s
.5 Mabswid
.651 .853 .633 r
.5 .59326 m .5 .63466 L .44535 .63392 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.44535 .63392 m .44068 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.44068 .4073 m .44535 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.644 .844 .62 r
.55932 .5927 m .55465 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.55465 .36608 m .55932 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.5 .40674 m .5 .36534 L .55465 .36608 L p F P
.505 .664 .505 r
s
.644 .844 .62 r
.5 .63466 m .5 .59326 L .55932 .5927 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.5 .36534 m .5 .40674 L .44068 .4073 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.44068 .4073 m .43776 .45258 L .38045 .45345 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.3818 .44138 m
.38582 .41083 L
s
.5 Mabswid
.586 .748 .555 r
.37857 .5 m .38045 .45345 L .43776 .45258 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.43676 .5 m .43776 .54742 L .38045 .54655 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.38045 .54655 m .37857 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.61955 .45345 m .62143 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.56324 .5 m .56224 .45258 L .61955 .45345 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.62143 .5 m .61955 .54655 L .56224 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.55932 .5927 m .56224 .54742 L .61955 .54655 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.43776 .45258 m .43676 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.56224 .54742 m .56324 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.5 .54772 m .5 .59326 L .44068 .5927 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.44068 .5927 m .43776 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.43776 .45258 m .44068 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.55932 .4073 m .56224 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.5 .45228 m .5 .40674 L .55932 .4073 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.56224 .54742 m .55932 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.5 .59326 m .5 .54772 L .56224 .54742 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.5 .40674 m .5 .45228 L .43776 .45258 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.43676 .5 m .43776 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.5 .5 m .5 .54772 L .43776 .54742 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.43776 .54742 m .43676 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.56224 .45258 m .56324 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.5 .5 m .5 .45228 L .56224 .45258 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.56324 .5 m .56224 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.5 .45228 m .5 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.5 .54772 m .5 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>h0/>3V5`21ZH7^0;3PiP40oooo003V0;3PiPP0PJV10P0R9A`0
0`21ZH4092LN02@W7P0602@W7P03086YP@0U:1h09BPN00H09BPN00<0PJV102<V7@0S9Qd02021ZH7V
0;3PiP40oooo003P0;3PiPH0PJV100<0720H086YP@21ZH401P0R9A`00`21ZH4092LN02@W7P0702@W
7P03086YP@0U:1h09BPN00L09BPN00<0PJV102<V7@0S9Qd0100S9Qd2086YP@0301lR6P21ZH40PJV1
00@0PJV1h02`h>H10?ooo`00g02`h>H5086YP@@0720H0P21ZH47028U7003086YP@0T9ah092LN00P0
92LN00<0PJV102DX7P0U:1h0200U:1h00`21ZH408bHM02<V7@0502<V7@80PJV1100O8QX5086YPM`0
/>3V0@3oool00=T0/>3V1@21ZH4501`P6080PJV10`0R9A`S086YP@<08bHM0P21ZH4501lR6PD0PJV1
f@2`h>H10?ooo`00eP2`h>H2086YP@0301DI4`21ZH40PJV10080720H2`21ZH4403<d:003086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@0203Df:@/0PJV100<0
7b8J086YP@21ZH401021ZH7F0;3PiP40oooo003C0;3PiPX0PJV10`0];b@00`21ZH40<c@X03<d:009
03<d:003086YP@0f>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@09
03Df:@04086YP@0`<RH0<38V030b9PX0PJV1d`2`h>H10?ooo`00d02`h>H7086YP@P0;BlT00<0PJV1
03<d:00c=2P02@0c=2P00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0g>2/0=cP[00/0=cP[00<0PJV1
03Df:@0e=RT02@0e=RT00`21ZH40<38V030b9P06030b9PL0PJV1d02`h>H10?ooo`00c@2`h>H4086Y
P@<092HM00<0PJV102d_900];b@01`0];b@00`21ZH40<c@X03<d:00903<d:003086YP@0f>2X0=SPZ
00`0=SPZ00<0PJV103Lh:`0g>2/0300g>2/00`21ZH40=CHY03Df:@0903Df:@03086YP@0`<RH0<38V
00L0<38V00@0PJV102P[800X:b00:2/P1021ZH7=0;3PiP40oooo003:0;3PiP@0PJV1100T9Qd2086Y
P@P0;BlT0P21ZH4;03<d:003086YP@0f>2X0=SPZ00d0=SPZ00<0PJV103Lh:`0g>2/03@0g>2/00`21
ZH40=CHY03Df:@0903Df:@80PJV1200`<RH2086YP@@0:2/P1021ZH7:0;3PiP40oooo00380;3PiP@0
PJV11@0T9Qd00`21ZH40;BlT02d_900702d_9003086YP@0c=2P0<c@X00/0<c@X00<0PJV103Hh:P0f
>2X03@0f>2X00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0e=RT0=CHY00/0=CHY00<0PJV1030b9P0`
<RH01`0`<RH00`21ZH40:2/P02P[800302P[80@0PJV1b02`h>H10?ooo`00aP2`h>H4086YP@D092HM
0P21ZH4902d_9003086YP@0c=2P0<c@X00@0<c@X<@21ZH4603Df:@03086YP@0`<RH0<38V00L0<38V
0P21ZH4502P[8080PJV100<07B0H086YP@2`h>H0a@2`h>H10?ooo`00a02`h>H2086YP@0301LK5021
ZH4092HM00D092HM00<0PJV102d_900];b@01@0];b@;086YP@L0B50i00<0PJV104eG?@1=Ecd03P1=
Ecd00`21ZH40CeTn04mI?P0>04mI?P03086YP@1<E3`0C5@l00D0C5@l2`21ZH47030b9P03086YP@0X
:b00:2/P00@0:2/P00@0PJV101dP6021ZH40PJV1a02`h>H10?ooo`00`P2`h>H2086YP@0301LK5021
ZH40PJV100D092HM0P21ZH400`0];b@0PJV1086YP@05086YP@80?D8`00<0PJV104Q@>@18D3T03018
D3T00`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<
E3`00`21ZH40@dXe04=:=@07086YP@03030b9P21ZH40PJV100D0:2/P0P21ZH400`0M81P0PJV1086Y
P@320;3PiP40oooo00300;3PiPD0PJV1100T9Qd6086YP@T0?D8`00<0PJV104Q@>@18D3T03018D3T0
0`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<E3`0
0`21ZH40@dXe04=:=@0704=:=@H0PJV1100X:b05086YPL00/>3V0@3oool00;h0/>3V2`21ZH400`0`
<BD0PJV103e2<00;03e2<003086YP@18D3T0B50i00d0B50i00<0PJV104eG?@1=Ecd03`1=Ecd00`21
ZH40CeTn04mI?P0?04mI?P03086YP@1<E3`0C5@l00d0C5@l00<0PJV104=:=@13BSD02P13BSD00`21
ZH40=SPZ086YP@0:086YPKh0/>3V0@3oool00;d0/>3V1P21ZH46030a9@03086YP@0m@S00?D8`00X0
?D8`00<0PJV104Q@>@18D3T03@18D3T00`21ZH40CELm04eG?@0@04eG?@03086YP@1?FCh0CeTn0100
CeTn00<0PJV104aD?01<E3`03@1<E3`00`21ZH40@dXe04=:=@0:04=:=@03086YP@0f>2X0=SPZ00@0
=SPZ1P21ZH6m0;3PiP40oooo002k0;3PiPD0PJV1200`<BD00`21ZH40?D8`03e2<00:03e2<003086Y
P@18D3T0B50i00h0B50i00<0PJV104eG?@1=Ecd0401=Ecd00`21ZH40CeTn04mI?P0@04mI?P03086Y
P@1<E3`0C5@l00h0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0603Hh:PD0PJV1
^`2`h>H10?ooo`00^@2`h>H4086YP@03028T7021ZH40<34U00L0<34U00<0PJV103e2<00m@S002`0m
@S000`21ZH40B50i04Q@>@0=04Q@>@03086YP@1=Ecd0CELm0140CELm00<0PJV104mI?P1?FCh04@1?
FCh00`21ZH40C5@l04aD?00=04aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f
>2X00`21ZH40:2/P086YP@03086YPKT0/>3V0@3oool00;L0/>3V1021ZH42028T7003086YP@0`<BD0
<34U00H0<34U00<0PJV103e2<00m@S002`0m@S000`21ZH40B50i04Q@>@0>04Q@>@03086YP@1=Ecd0
CELm0140CELm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40C5@l04aD?00>04aD?003086YP@13BSD0
@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f>2X2086YP@0302P[8021ZH40PJV10080PJV1]`2`h>H1
0?ooo`00]@2`h>H4086YP@<08R@L00<0PJV1030a9@0`<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2
<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=Ecd04@1=Ecd00`21ZH40CeTn04mI?P0A04mI
?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh
:P03086YP@0X:b00:2/P00@0PJV1]@2`h>H10?ooo`00]02`h>H3086YP@@08R@L00<0PJV1030a9@0`
<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=
Ecd04P1=Ecd00`21ZH40CeTn04mI?P0B04mI?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13
BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh:P04086YP@0X:b00:2/P02P[80<0PJV1]02`h>H10?oo
o`00/`2`h>H00`21ZH4041@?086YP@03028T7080PJV12@0`<BD00`21ZH40?D8`03e2<00;03e2<003
086YP@18D3T0B50i00H0B50i?@21ZH4804aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f
>2X0200f>2X01@21ZH40:2/P02P[800X:b00PJV1008061/D/`2`h>H10?ooo`00/@2`h>H4086YP@<0
8R@L00<0PJV1030a9@0`<BD0200`<BD00`21ZH40?D8`03e2<00803e2<0d0PJV12@1QLU<00`21ZH40
I7ME06AgE@0B06AgE@03086YP@1SME80HgEB0180HgEB00<0PJV105e]B`1MKD/01`1MKD/=086YP@X0
@dXe00<0PJV103Hh:P0f>2X0200f>2X01021ZH40:2/P02P[800X:b02086YP@0301PK5021ZH40/>3V
0;00/>3V0@3oool00;00/>3V00<0PJV1010D3`21ZH40100R91`00`21ZH40<34U030a9@08030a9@04
086YP@0m@S00?D8`03e2<0P0PJV10`1GIT/00`21ZH40HG9C065bD`0@065bD`03086YP@1TMeD0I7ME
0180I7ME00<0PJV106=eDP1SME804P1SME800`21ZH40GFe;05e]B`0@05e]B`04086YP@1FI4D0EVA5
05ITA@P0PJV10`13BSD00`21ZH40=SPZ03Hh:P0803Hh:P80PJV10`0X:b000`21ZH4061/D086YP@2`
0;3PiP40oooo002_0;3PiP03086YP@0@50l0PJV100@08R@L00<0PJV1030a9@0`<BD01@0`<BD8086Y
P@X0EfI;00<0PJV1065bD`1QLU<0401QLU<00`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB
01<0HgEB00<0PJV105e]B`1MKD/0401MKD/00`21ZH40EVA505ITA@0805ITA@P0PJV1200f>2X01`21
ZH40:2/P02P[800X:b00PJV101PK5021ZH40[`2`h>H10?ooo`00[P2`h>H3086YP@@08R@L00<0PJV1
030a9@0`<BD01P21ZH4204I??003086YP@1GIT/0EfI;00d0EfI;00<0PJV1065bD`1QLU<0401QLU<0
0`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB01<0HgEB00<0PJV105e]B`1MKD/0401MKD/0
0`21ZH40EVA505ITA@0=05ITA@03086YP@18DSX0B58j00L0PJV10P0f>2X01021ZH40:2/P02P[800X
:b03086YPJh0/>3V0@3oool00:`0/>3V0`21ZH44028T70D0PJV12016Cc`00`21ZH40EfI;05MVB`0<
05MVB`03086YP@1QLU<0HG9C0140HG9C00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgEB06=eDP0C
06=eDP03086YP@1MKD/0GFe;0140GFe;00<0PJV105ITA@1FI4D0301FI4D00`21ZH40B58j04QB>P07
04QB>PD0PJV10`0X:b03086YPJ`0/>3V0@3oool00:/0/>3V00<0PJV1010D3`21ZH400P0R91`4086Y
P@/0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01<0I7ME00<0PJV106=eDP1SME804`1SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00d0EVA500<0PJV104QB>P18DSX02P18DSX4086YP@0402P[8021ZH4061/D086YPJ/0/>3V0@3oool0
0:X0/>3V1P21ZH4202d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21
ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=eDP1SME804`1SME800`21
ZH40GFe;05e]B`0B05e]B`03086YP@1FI4D0EVA500d0EVA500<0PJV104QB>P18DSX02@18DSX01021
ZH40<cHX03<f:00c=RP5086YPJX0/>3V0@3oool00:T0/>3V0`21ZH4602d`9P03086YP@16Cc`0ATll
00P0ATll00<0PJV105MVB`1GIT/03P1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01@0I7ME00<0PJV106=eDP1SME80501SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00h0EVA500<0PJV104QB>P18DSX02@18DSX00`21ZH40<cHX03<f:00303<f:0<0PJV1Z@2`h>H10?oo
o`00Y`2`h>H3086YP@L0;C0V00<0PJV104I??016Cc`02@16Cc`00`21ZH40EfI;05MVB`0=05MVB`03
086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgEB06=eDP0D06=eDP03
086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03@1FI4D00`21ZH40B58j04QB>P0:04QB>P03
086YP@0c=RP0<cHX00@0<cHX0`21ZH6W0;3PiP40oooo002V0;3PiP<0PJV11`0]<2H00`21ZH40ATll
04I??00904I??003086YP@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04P1QLU<00`21ZH40I7ME
06AgE@0D06AgE@03086YP@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04P1MKD/00`21ZH40EVA5
05ITA@0>05ITA@03086YP@18DSX0B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP3086YPJH0/>3V
0@3oool00:D0/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H00`21ZH40ATll04I??00904I??003086Y
P@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04`1QLU<00`21ZH40I7ME06AgE@0D06AgE@03086Y
P@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04`1MKD/00`21ZH40EVA505ITA@0>05ITA@03086Y
P@18DSX0B58j00T0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6U0;3PiP40
oooo002T0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02P16Cc`00`21ZH40
EfI;05MVB`0>05MVB`03086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD05@1TMeD00`21ZH40
HgEB06=eDP0E06=eDP03086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03P1FI4D00`21ZH40
B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1Y02`h>H10?oo
o`00X`2`h>H01021ZH405QXC01HJ4`21ZH4702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MV
B`1GIT/03P1GIT/00`21ZH40HG9C065bD`0C065bD`03086YP@1TMeD0I7ME01D0I7ME00<0PJV106=e
DP1SME805@1SME800`21ZH40GFe;05e]B`0C05e]B`03086YP@1FI4D0EVA500h0EVA500<0PJV104QB
>P18DSX02P18DSX00`21ZH40<cHX03<f:00403<f:004086YP@0O8QX07b8J086YPJ<0/>3V0@3oool0
0:80/>3V00@0PJV101HJ4`0F6Q<0PJV11`0]<2H00`21ZH40ATll04I??00904I??003086YP@1GIT/0
EfI;00l0EfI;00<0PJV1065bD`1QLU<03P1QLU<k086YPA00GFe;00<0PJV105ITA@1FI4D03`1FI4D0
0`21ZH40B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1XP2`
h>H10?ooo`00XP2`h>H00`21ZH405QXC086YP@0702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV1
05MVB`1GIT/03`1GIT/00`21ZH40HG9C065bD`03065bD``0PJV11@1dSFL00`21ZH40Mi5X07NAJ00E
07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0PJV106n6G@1_QUd00`1_QUd<086YP@D0GFe;00<0PJV1
05ITA@1FI4D03`1FI4D00`21ZH40B58j04QB>P0904QB>P03086YP@0c=RP0<cHX00D0<cHX00<0PJV1
01lR6P21ZH40XP2`h>H10?ooo`00X@2`h>H01021ZH405QXC01HJ4`21ZH4602d`9P03086YP@16Cc`0
ATll00X0ATll00<0PJV105MVB`1GIT/01P1GIT/?086YPA40M8eW00<0PJV107NAJ01gTFP05@1gTFP0
0`21ZH40MHmU07F?I@0E07F?I@03086YP@1_QUd0KhIM00l0KhIM3`21ZH4805ITA@03086YP@18DSX0
B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6Q0;3PiP40oooo002P
0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02016Cc`<086YP@T0K8=Q00<0
PJV107B=I`1dSFL04`1dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0
PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00706=gD0`0PJV12P18DSX00`21ZH40<cHX03<f
:00403<f:004086YP@0O8QX07b8J086YPJ00/>3V0@3oool009l0/>3V00@0PJV101HJ4`0F6Q<0PJV1
1`0]<2H00`21ZH40ATll04I??00304I??0D0PJV10P1LKU@00`21ZH40K8=Q06b3H@0?06b3H@03086Y
P@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40MHmU07F?I@0F07F?I@03086Y
P@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe003`1SMe000`21ZH40EfM705MWA`05086YP@H0B58j
00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6O0;3PiP40oooo002N0;3PiP04086Y
P@0F6Q<05QXC086YP@L0;C0V00<0PJV104I??021ZH401021ZH4605a^E003086YP@1/Pf40K8=Q0100
K8=Q00<0PJV107B=I`1dSFL0501dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0
MHmU00<0PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00@06=gD003086YP@1GIdL0EfM700@0
EfM71@21ZH400`18DSX0PJV103<f:00603<f:004086YP@0O8QX07b8J086YPIh0/>3V0@3oool009d0
/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H4086YP@/0G6iD00<0PJV106b3H@1/Pf40401/Pf400`21
ZH40M8eW07B=I`0D07B=I`03086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107F?I@1eSfD05P1eSfD00`21
ZH40KhIM06n6G@0D06n6G@03086YP@1SMe00HgM@0100HgM@00<0PJV105MWA`1GIdL02@1GIdL4086Y
P@H0<cHX00@0PJV101lR6P0O8QX0PJV1W@2`h>H10?ooo`00W02`h>H01@21ZH405QXC01HJ4`0F6Q<0
PJV100<0;C0V1021ZH4=05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL0501dSFL0
0`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd0501_QUd0
0`21ZH40HgM@06=gD00A06=gD003086YP@1GIdL0EfM700/0EfM71021ZH4303<f:005086YP@0O8QX0
7b8J01lR6P21ZH40W02`h>H10?ooo`00W02`h>H301HJ4`D0PJV10`11Bc`00`21ZH40G6iD05a^E00;
05a^E003086YP@1/Pf40K8=Q0100K8=Q00<0PJV107B=I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00F
07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00@
06=gD003086YP@1GIdL0EfM700/0EfM700@0PJV1049<=P12C3H0@T`f1@21ZH4201lR6P03086YP@2`
h>H0/>3V09X0/>3V0@3oool009/0/>3V0P0F6Q<3086YP@H0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0F07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00@0@T`f0`21ZH400`0O8QX0PJV10;3PiP2J
0;3PiP40oooo002J0;3PiP0401HJ4`21ZH40PJV1086YP@P0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f1021ZH6J0;3PiP40oooo002I0;3P
iP80PJV10P0Q9R000`21ZH40@D/l045;?005045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3
H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086YP@1gTFP0Mi5X01L0Mi5X00<0PJV107F?
I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0E06n6G@03086YP@1SMe00HgM@0140HgM@00<0PJV105MW
A`1GIdL02`1GIdL00`21ZH40@T`f049<=P05049<=P03086YP@0U9ah09BLN0080PJV1V@2`h>H10?oo
o`00V02`h>H01@21ZH408BHP024V800Q9R00PJV100P0@D/l00<0PJV105a^E01LKU@02`1LKU@00`21
ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP00`21
ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe000`21
ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f00D0PJV102DW7P0U9ah09BLN086YP@2H
0;3PiP40oooo002H0;3PiP04086YP@0Q9R008BHP086YP@P0@D/l00<0PJV105a^E01LKU@0301LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0<05MWA`03086YP@12C3H0@T`f00D0@T`f00D0PJV102DW7P0U9ah09BLN086Y
P@2H0;3PiP40oooo002G0;3PiP05086YP@0Q9R008BHP024V8021ZH402011Bc`00`21ZH40G6iD05a^
E00;05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL05P1dSFL00`21ZH40Mi5X07NA
J00G07NAJ003086YP@1eSfD0MHmU01L0MHmU00<0PJV106n6G@1_QUd05P1_QUd00`21ZH40HgM@06=g
D00A06=gD003086YP@1GIdL0EfM700/0EfM700<0PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW
7P0U9ah0PJV109L0/>3V0@3oool009H0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086Y
P@1LKU@0G6iD00`0G6iD00<0PJV106b3H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086Y
P@1gTFP0Mi5X01P0Mi5X00<0PJV107F?I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0F06n6G@03086Y
P@1SMe00HgM@0140HgM@00<0PJV105MWA`1GIdL0301GIdL00`21ZH40@T`f049<=P06049<=P05086Y
P@0U9ah09BLN02DW7P21ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH408BHP024V800Q9R00PJV100P0
@D/l00<0PJV105a^E01LKU@02`1LKU@00`21ZH40K8=Q06b3H@0B06b3H@03086YP@1dSFL0M8eW01D0
M8eW00<0PJV107NAJ01gTFP0601gTFP00`21ZH40MHmU07F?I@0H07F?I@03086YP@1_QUd0KhIM01D0
KhIM00<0PJV106=gD01SMe004P1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0
@T`f00D0PJV102DW7P0U9ah09BLN086YP@2F0;3PiP40oooo002E0;3PiP05086YP@0Q9R008BHP024V
8021ZH402011Bc`00`21ZH40G6iD05a^E00<05a^E003086YP@1/Pf40K8=Q0180K8=Q00<0PJV107B=
I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1eSfD0MHmU01P0MHmU00<0PJV106n6
G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0EfM700`0EfM700<0PJV1049<
=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109D0/>3V0@3oool009@0/>3V00D0PJV1024V
800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf404P1/Pf40
0`21ZH40M8eW07B=I`0:07B=Idl0PJV1301_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0
EfM700/0EfM700<0PJV1049<=P12C3H01`12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3o
ool009@0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086YP@1LKU@0G6iD00`0G6iD00<0
PJV106b3H@1/Pf403@1/Pf4B086YP@`0PZ9g00<0PJV108BTM`24Y7L06024Y7L00`21ZH40PZ9d08:R
M00H08:RM003086YP@1mVfd0OI]]00X0OI]]4P21ZH4?06=gD003086YP@1GIdL0EfM700`0EfM700<0
PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3oool009<0/>3V00D0
PJV1024V800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf40
0`1/Pf4;086YP@D0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03086Y
P@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0307:=H@/0PJV1
1@1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00L0@T`f00D0PJV102DW7P0U9ah0
9BLN086YP@2C0;3PiP40oooo002C0;3PiP04086YP@0Q9R008BHP086YP@T0@D/l00<0PJV105a^E01L
KU@02@1LKU@9086YPA00NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03
086YP@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0>07:=H@T0
PJV12`1GIdL00`21ZH40@T`f049<=P06049<=P05086YP@0U9ah09BLN02DW7P21ZH40T`2`h>H10?oo
o`00TP2`h>H01@21ZH408BHP024V800Q9R00PJV100T0@D/l00@0PJV105a^E01LKU@0G6iD2021ZH43
06j7I`03086YP@1kVG80NiUb0180NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0I
08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0B
07:=H@04086YP@1RMe00HWM@069gD0P0PJV10`1GIdL00`21ZH40@T`f049<=P07049<=P05086YP@0U
9ah09BLN02DW7P21ZH40TP2`h>H10?ooo`00T@2`h>H01@21ZH408BHP024V800Q9R00PJV100L0@D/l
1`21ZH4:06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag
08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ
07:=H@0C07:=H@03086YP@1RMe00HWM@00P0HWM@1`21ZH47049<=P05086YP@0U9ah09BLN02DW7P21
ZH40T@2`h>H10?ooo`00T@2`h>H01P21ZH408BHP024V800Q9R00PJV1045;?0H0PJV10P1DIU400`21
ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21
ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00`0HWM@00<0PJV104iN@01>GT001P21ZH400`12
C3H0PJV102DW7P0202DW7P03086YP@2`h>H0/>3V08l0/>3V0@3oool00900/>3V00@0PJV1024V800Q
9R008BHP0`21ZH4705AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG804`1kVG800`21
ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21
ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21
ZH40CUi004iN@00504iN@0<0PJV10`0U9ah00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP03
086YP@0Q9R008BHP00<0PJV12@1DIU400`21ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0
NiUb00<0PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0
PZ9d00<0PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0B07:=H@03086YP@1RMe00HWM@00d0
HWM@00<0PJV104iN@01>GT001`1>GT03086YP@809BLN00<0PJV10;3PiP2`h>H0S@2`h>H10?ooo`00
S`2`h>H01@0Q9R00PJV1086YP@0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40
NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40
PZ9d08:RM00I08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF404`1bSF400`21ZH40
HWM@069gD00=069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@21ZH400P21ZH6?0;3PiP40
oooo002>0;3PiP80PJV10`0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00d0KXMW
00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag
00<0PJV108:RM022XW@06@22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ
00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@004086YP@0^=2D0;S@U02hd9@80
PJV1SP2`h>H10?ooo`00SP2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^
QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01H0PZ9g00<0PJV108BTM`24
Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01H0OI]]00<0PJV107:=H@1b
SF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^
=2D00P0^=2F>0;3PiP40oooo002=0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU40
1`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL0
5`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0PJV107fKK@1mVfd0
5`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00d0HWM@00<0PJV104iN@01>GT00
1`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V00D0
PJV102dd;P0]=2h0;C@^086YP@0:05AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG80
4`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022XW@0
6P22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe00
3@1RMe000`21ZH40CUi004iN@00804iN@005086YP@0^=2D0;S@U02hd9@21ZH40S@2`h>H10?ooo`00
S02`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3P1^QfL00`21ZH40NiUb07^ILP0707^ILP030?mo001kVG80NiUb00P0NiUb00<0ogl0086YP@22XWL0
6022XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0PJV107fKK@1mVfd0
5`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT00
1`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08X0/>3V0@3oool008`0/>3V00<0
PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00`0KXMW00<0
ogl0086YP@1kVG801P1kVG860?mo00L0NiUb0`3oO`0I08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0
PJV108:RM022XW@06P22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01@0LXeQ00<0
PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@003086YP@0^=2D0;S@U0080;S@U00<0
PJV10;3PiP2`h>H0RP2`h>H10?ooo`00S02`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100T0E6IA00<0
PJV106j7I`3oO`001`1^QfL01@3oO`00KXMW06j7I`3oO`00KXMW00<0ogl0101kVG8:0?mo00D0NiUb
1@3oO`0H08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022XW@06P22XW@00`21ZH40OI]]
07fKK@0H07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003P1RMe000`21ZH40CUi0
04iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40S02`h>H10?ooo`00R`2`h>H00`21ZH40;C@^
02dd;P0202dd;P03086YP@1DIU40E6IA00@0E6IA00@0ogl005AVD@1DIU40PJV10`3oO`0406j7I`H0
ogl000@0KXMW0?mo003oO`00PJV10`1kVG850?mo00@0NiUb0P3oO`0607^ILP<0ogl06@22XWL00`21
ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0PJV107fKK@1mVfd0601mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21
ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08T0/>3V0@3oool008/0/>3V00D0PJV102dd;P0]
=2h0;C@^086YP@0205AVD@040?mo001DIU40E6IA05AVD@<0ogl000@0E6IA086YP@3oO`00ogl0101^
QfL:0?mo00@0NiUb0P3oO`0707^ILP80ogl01`1kVG800`3oO`00PZ9g08:RM`0G08:RM`03086YP@24
Y7L0Q:Ag01/0Q:Ag00<0PJV108:RM022XW@06`22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1b
SF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00804iN@005086YP@0^
=2D0;S@U02hd9@21ZH40R`2`h>H10?ooo`00RP2`h>H00`21ZH40;C@^0?mo000202dd;P03086YP@1D
IU40ogl00080ogl00P1DIU420?mo000305AVD@21ZH40KXMW0080ogl0101^QfL20?mo00D0KXMW0`3o
O`0407^ILP030?mo001kVG80NiUb00H0NiUb0P3oO`0707^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0
PJV108BTM`24Y7L06`24Y7L00`21ZH40PZ9d08:RM00K08:RM003086YP@1mVfd0OI]]01L0OI]]00<0
PJV107:=H@1bSF40501bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000D0
PJV102hd9@0^=2D0;S@U086YP@2;0;3PiP40oooo00290;3PiP030?mo0021ZH40ogl00080ogl000<0
;C@^086YP@1DIU400P3oO`0305AVD@80ogl000<0E6IA086YP@1^QfL00P3oO`0306j7I`80ogl01P1^
QfL30?mo00@0NiUb00<0ogl007^ILP1kVG801P1kVG830?mo00D0NiUb00<0PJV108:RM`22XWL06022
XWL00`21ZH40Q:Ag08BTM`0=08BTMad0PJV13`22XW@00`21ZH40OI]]07fKK@0H07fKK@03086YP@1b
SF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@003086YP@0^
=2D0;S@U0080;S@U00<0PJV10;3PiP2`h>H0R02`h>H10?ooo`00R02`h>H60?mo0003086YP@1DIU40
E6IA0080ogl00`1DIU420?mo0003086YP@1^QfL0ogl00080ogl00`1^QfL20?mo00H0KXMW0P3oO`00
0`21ZH40NiUb07^ILP0:07^ILP<0ogl01P1kVG800`21ZH40PZ9g08:RM`0;08:RMad0PJV13P2>]8<0
0`21ZH40SK6008faP00<08faP1d0PJV13@1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00
HWM@00l0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108X0/>3V0@3o
ool008L0/>3V1`3oO`000`21ZH40E6IA0?mo00020?mo0080E6IA0`3oO`001021ZH40KXMW0?mo003o
O`0306j7I`80ogl01`1^QfL20?mo00/0NiUb103oO`0E086YP@d0SK:400<0PJV108jdP`2>]8<06`2>
]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i00/0Qj]i6@21ZH4;07:=H@03086YP@1R
Me00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`
h>H0/>3V08L0/>3V0@3oool008D0/>3V2@3oO`0205AVD@80ogl00`1DIU420?mo0003086YP@1^QfL0
KXMW0080ogl00`1^QfL20?mo00H0PJV10`3oO`06086YP@P0ogl01`27Zh020?mo01X0SK:400<0PJV1
08jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0PJV1
07jNKP1nWVh02@1nWVhD086YP@T0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd9@0^
=2D0PJV108T0/>3V0@3oool008D0/>3V1P3oO`000`0]=2h0ogl00?mo000205AVD@80ogl00`1DIU42
0?mo0080PJV10`3oO`03086YP@80ogl01P1kVgL20?mo0003086YP@27Zh00Qj^000<0Qj^01`3oO`09
08N[P080ogl06P2=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV1
08N[N@27ZgT06027ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00H0KHQL3021ZH47
04iN@005086YP@0^=2D0;S@U02hd9@21ZH40R@2`h>H10?ooo`00Q@2`h>H60?mo000502dd;P3oO`00
ogl005AVD@21ZH400P3oO`02086YP@<0ogl000@0PJV107^KM`3oO`00ogl0101kVgL20?mo00H0Ni]g
0P3oO`000`21ZH40Qj^008N[P00208N[P0<0ogl03P27Zh020?mo01X0SK:400<0PJV108jdP`2>]8<0
6`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0PJV107jNKP1nWVh0
501nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800H0PJV10P1>GT001@21ZH40;S@U
02hd9@0^=2D0PJV108P0/>3V0@3oool008D0/>3V1P3oO`001021ZH40ogl00?mo0021ZH430?mo0080
I7aR0P3oO`000`1TO680PJV107^KM`020?mo00@0Ni]g0P3oO`0607^KM`80ogl01027Zh030?mo00L0
Qj^000<0ogl008N[P027Zh001@27Zh020?mo01X0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40
SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40
KHQL06f8G00>06f8G003086YP@1GK4P0Efa800H0Efa81021ZH4202hd9@03086YP@2`h>H0/>3V08H0
/>3V0@3oool008D0/>3V1P3oO`00100kB3h0ogl00?mo001TO6820?mo00<0I7aR0P3oO`000`21ZH40
Ni]g07^KM`020?mo00<0Ni]g0P3oO`0607^KM`<0ogl01027Zh020?mo00P0Qj^000<0ogl008N[P027
Zh001@27Zh020?mo01X0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003
086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8G003
086YP@1GK4P0Efa800L0Efa800H0PJV103M2;P21ZH40PJV102hd9@21ZH670;3PiP40oooo00240;3P
iPH0ogl000D0>dPn0?mo003oO`00ogl006AlHP020?mo00<0I7aR0P3oO`000`21ZH40Ni]g0?mo0002
0?mo00<0Ni]g0P3oO`0607^KM`80ogl000<0PJV108N[P027Zh000P27Zh000`3oO`00Qj^008N[P006
08N[P080ogl01`27Zh020?mo01X0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K
08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?
06f8G003086YP@1GK4P0Efa800L0Efa800@0PJV103M2;P0g@Rh0=d8^0P21ZH670;3PiP40oooo0024
0;3PiPD0ogl00P0kB3h20?mo000406AlHP3oO`00ogl00?mo0080I7aR0`3oO`001021ZH40Ni]g0?mo
003oO`0407^KM`80ogl01P1kVgL20?mo0003086YP@27Zh00Qj^00080Qj^00P3oO`0508N[P0@0ogl0
1`27Zh020?mo01X0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086Y
P@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8G003086Y
P@1GK4P0Efa800P0Efa800D0PJV103M2;P0g@Rh0=d8^086YP@270;3PiP40oooo00230;3PiPH0ogl0
0P0kB3h20?mo000406AlHP3oO`00ogl00?mo0080I7aR0P3oO`000`1TO680PJV107^KM`020?mo00@0
Ni]g0P3oO`0607^KM`80ogl000<0PJV108N[P027Zh000P27Zh040?mo0080Qj^0103oO`0808N[P080
ogl06P2=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27
ZgT06@27ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01G
K4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V08@0/>3V0@3oool008<0/>3V
1@3oO`0203]8?P<0ogl000<0I7aR0?mo003oO`000`1TO6820?mo000306AlHP21ZH40Ni]g0080ogl0
101kVgL20?mo00D0Ni]g0`3oO`0608N[P0L0ogl02@27Zh020?mo01/0SK:400<0PJV108jdP`2>]8<0
6`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0
5@1nWVh00`21ZH40KHQL06f8G00>06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh0
0P0g@Rh00`21ZH40/>3V0;3PiP240;3PiP40oooo00230;3PiPD0ogl00P0kB3h20?mo0080I7aR0`3o
O`001P1TO680ogl00?mo003oO`00PJV107^KM`<0ogl00`1kVgL20?mo00L0Ni]g00<0ogl0086YP@27
Zh001P27Zh050?mo00X0Qj^00P3oO`0J08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=
/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]
R5`03`1]R5`00`21ZH40Efa805M/B00705M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`
h>H0Q02`h>H10?ooo`00PP2`h>H:0?mo000306AlHP3oO`00ogl000D0ogl000D0I7aR086YP@1kVgL0
Ni]g0?mo000407^KM`80ogl0201kVgL00`21ZH40Qj^008N[P00D08N[P080ogl06P2=/X@00`21ZH40
S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06027ZgT00`21ZH40
OYi^07jNKP0E07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P01@21ZH40
=d8^03M2;P0g@Rh0PJV108H0/>3V0@3oool00880/>3V2@3oO`0306AlHPD0ogl00P1TO6800`21ZH40
Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^00P3oO`0J08fbQ003086YP@2>]8<0S[B301`0
S[B300<0PJV108faP02=/H00702=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01@0
OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00805M/B003086YP@0g@Rh0=d8^0080
=d8^00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00PP2`h>H80?mo0003086YP@1TO680I7aR00P0I7aR
00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P080ogl06P2=/X@00`21ZH40S[B3
08jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^
07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^
03M2;P0203M2;P03086YP@2`h>H0/>3V08<0/>3V0@3oool00840/>3V1P3oO`0203]8?P03086YP@1T
O680I7aR00T0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P080ogl06P2=
/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27
ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201G
K4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0/>3V08<0/>3V0@3oool00840/>3V1@3oO`03
03]8?P03086YP@1TO680I7aR00T0I7aR00<0PJV107^KM`3oO`003P1kVgL00`21ZH40Qj^008N[P00E
08N[P080ogl06P2=/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV1
08N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@1]R5`0KHQL00h0KHQL00<0PJV1
05M/B01GK4P02@1GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108D0/>3V0@3oool00880/>3V103oO`03
03]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`3oO`000P3oO`0=07^KM`03086YP@27Zh00
Qj^001D0Qj^00P3oO`0J08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H00
0`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]R5`0
0`21ZH40Efa805M/B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0PP2`h>H1
0?ooo`00PP2`h>H40?mo00<0>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40ogl00?mo00030?mo
00`0Ni]g00<0PJV108N[P027Zh005027Zh020?mo01/0SK:400<0PJV108jdP`2>]8<0702>]8<00`21
ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21
ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21
ZH40/>3V0;3PiP220;3PiP40oooo00220;3PiP@0ogl00P0kB3h00`21ZH40I7aR06AlHP0906AlHP03
086YP@1kVgL0ogl00080ogl03@1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:401T0
SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0
Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0
Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP220;3PiP40oooo00220;3PiP<0ogl0
0`0kB3h00`21ZH40I7aR06AlHP0906AlHP04086YP@1kVgL0Ni]g0?mo00h0Ni]g00<0PJV108N[P027
Zh005027Zh000`21ZH40SK:408fbQ00J08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=
/H00702=/H000`21ZH40Qj]i08N[N@0J08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]
R5`03`1]R5`00`21ZH40Efa805M/B00905M/B005086YP@0g@Rh0=d8^03M2;P21ZH40Q02`h>H10?oo
o`00PP2`h>H20?mo00@0>dPn00<0PJV106AlHP1TO6802@1TO6800`21ZH40Ni]g07^KM`0>07^KM`03
086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06P2=/X@00`21ZH40S[B308jdP`0L08jdP`03
086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06P27ZgT00`21ZH40OYi^07jNKP0E07jNKP03
086YP@1]R5`0KHQL00h0KHQL00<0PJV105M/B01GK4P02@1GK4P00`21ZH40=d8^03M2;P0203M2;P03
086YP@2`h>H0/>3V0840/>3V0@3oool00840/>3V0`3oO`0403]8?P03086YP@1TO680I7aR00P0I7aR
00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:400`0SK:4
F`21ZH4>08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa8
05M/B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0P@2`h>H10?ooo`00P`2`
h>H01@21ZH40>dPn03]8?P0kB3h0PJV100/0I7aR00<0PJV107^KM`1kVgL01`1kVgL_086YP@h0U[n>
00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R300`0T;R3
;`21ZH4906f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V
0;3PiP210;3PiP40oooo00230;3PiP@0>dPn00<0PJV106AlHP1TO680101TO68?086YP@P0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0
PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P01P1hV6P?086YP@H0Efa800D0PJV103M2;P0g@Rh0=d8^086YP@230;3PiP40oooo
00220;3PiP03086YP@0kB3h0>dPn00T0PJV11@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A
^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E
_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1h
V6P0N9QX00l0N9QX00<0PJV105igCP1NMdh00`1NMdh9086YP@80=d8^00<0PJV10;3PiP2`h>H0P02`
h>H10?ooo`00PP2`h>H3086YP@80B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?
08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L
09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E
08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=003
086YPH80/>3V0@3oool00880/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?
L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09Jo
SP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092h
P`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905ig
CP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40
B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40
TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40
N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40
/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg40
2@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh0
6P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<0
6P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh0
2@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0
PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0
PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0
PJV10;3PiP2`h>H0P02`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40
L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0
U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0
T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0
GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00210;3P
iP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[
P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0
S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/
N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>
=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40
L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40
U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40
T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40
GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00
P@2`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<0
3`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01T0U[n>00<0PJV109O0S@2G`8d0
7@2G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T0
5@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@0
0`0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0
PJV1072?L@1`Sg40201`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0
PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0
PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00h0N9QX00<0
PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003086YP@2`h>H0/>3V07l0/>3V0@3o
ool00840/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0
QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0
Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0
Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0
?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QL
CP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096i
R`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09Fn
R@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RH
J003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3P
iP40oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40
QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40
Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40
Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40
?Thd03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h0
0P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/0
5@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT0
7@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P0
3`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0
O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0
PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0
PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0
PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0
PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00200;3PiP03086YP@18G4h0
B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0
TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0
UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0
N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0
/>3V07l0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?
L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09Jo
SP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092h
P`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905ig
CP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40
B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40
TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40
UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40
N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40
/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg40
2@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh0
6P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<0
6P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh0
2@1NMdh00`21ZH40?Thd03i>=00303i>=003086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0
PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0
PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0
PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>Kc086YPH00/>3V0@3oool00800/>3V00<0PJV1059/
F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4
U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8
TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082U
LP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3P
iP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0
NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0
W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0
Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0
IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086Y
P@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086Y
P@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086Y
P@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086Y
P@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086Y
P@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VM
O00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9
UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2
S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3
F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H0
0`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d0
0`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD0
0`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^880
0`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT0
0`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VM
O01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9
UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2
S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3
F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840
/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0
S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0
WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0
SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080
@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086Y
P@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086Y
P@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086Y
P@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086Y
P@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo
00210;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jh
S@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;
U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nh
PP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G
>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/0
0`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@0
0`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb980
0`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG80
0`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H1
0?ooo`00P@2`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00P0NIel00<0PJV108jh
S@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;
U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nh
PP2?^8805@2?^8800`21ZH40P:Eb082ULP0>082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G
>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0
DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0
V<BD00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01`0
VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0
P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07l0
/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086Y
P@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086Y
P@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086Y
P@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086Y
P@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/
F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4
U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8
TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082U
LP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3P
iP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`0
0`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH0
0`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`0
0`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP0
0`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV1059/
F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4
U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8
TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082U
LP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3P
iP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0
NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0
W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0
Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0
IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086Y
P@1BK5/0DVaK0080DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086Y
P@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086Y
P@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086Y
P@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086Y
P@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VM
O00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9
UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2
S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3
F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H3
086YP@80DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0
V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980
VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80
P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@03086YPH80/>3V0@3oool0
0880/>3V00<0PJV105UhI01IN6@02021ZH4607VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4
U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8
TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082U
LP20YG803`20YG800`21ZH40IX=H06J3F00406J3F0P0PJV10P15G3`00`21ZH40/>3V0;3PiP200;3P
iP40oooo00230;3PiP05086YP@1IN6@0FGQT05UhI021ZH401@1oZ8D?086YP@T0S[R=00<0PJV109S4
U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8
TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082U
LP20YG801`20YG8?086YP@D0K8iQ00<0PJV104EL?015G3`00P15G3b30;3PiP40oooo00230;3PiP05
086YP@1IN6@0FGQT05UhI021ZH402`1oZ8D00`21ZH40U<:E09C2U@0609C2UC00PJV13P2LbIH00`21
ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G`X`0302G`X``086Y
P@P0QZmj00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V
0840/>3V0@3oool008<0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03
086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0<0:;BWE/0
PJV13P2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/
SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0840/>3V0@3oool008<0/>3V
00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0907nXQ@03086YP@2D`YD0U<:E00h0U<:E
00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0J0:;BW@03086YP@2Rdi`0X]>L01`0X]>L
00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0J09c;T`03086YP@2D`HX0U<6:01D0U<6:
00<0PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0906b>H@03086YP@15G3`0AE`l0080AE`l
00<0PJV10;3PiP2`h>H0P@2`h>H10?ooo`00Q02`h>H01@21ZH40FGQT05UhI01IN6@0PJV100/0OjR5
00<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01X0X]:M
00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01X0W<^C
00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00T0K8iQ
00D0PJV104EL?015G3`0AE`l086YP@240;3PiP40oooo00240;3PiP05086YP@1IN6@0FGQT05UhI021
ZH402`1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2R
dYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2L
bi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/
SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0880/>3V0@3oool008@0/>3V
00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0U<:E00l0U<:E
00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L
00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:
00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l
00<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00Q02`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1o
Z8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2R
dYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2L
bi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/
SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP220;3PiP40oooo0025
0;3PiP05086YP@1IN6@0FGQT05UhI021ZH402`1oZ8D00`21ZH40U<:E09C2U@0>09C2U@03086YP@2N
cY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2Q
dIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26
[gX0QZmj00h0QZmj00<0PJV106b>H@1/SV402@1/SV401@21ZH40AE`l04EL?015G3`0PJV108D0/>3V
0@3oool008D0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00l0U<:E
00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L
00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:
00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l
00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q@2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1o
Z8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2R
dYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2L
bi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/
SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP230;3PiP40oooo0025
0;3PiP03086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?
09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L
0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D
09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?002
04EL?003086YP@2`h>H0/>3V08<0/>3V0@3oool008H0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0:
07nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I
0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0H
09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@08
06b>H@05086YP@15G3`0AE`l04EL?021ZH40QP2`h>H10?ooo`00QP2`h>H01@21ZH40FGQT05UhI01I
N6@0PJV100X0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2R
dYd0X]:M01P0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2L
bi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/
SV40K8iQ00L0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH40/>3V0;3PiP240;3PiP40oooo0026
0;3PiP03086YP@1IN6@0FGQT0080FGQT00<0PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0>
09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K
0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E
09C1RP03086YP@26[gX0QZmj00h0QZmj00<0PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?002
04EL?003086YP@000000/>3V08@0/>3V0@3oool008H0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21
ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21
ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21
ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21
ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10000002`h>H0Q02`h>H10?oo
o`00Q`2`h>H01@21ZH40FGQT05UhI01IN6@0PJV100X0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21
ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21
ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21
ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00D0PJV104EL?015G3`0AE`l086YP@03
000008@0/>3V0@3oool008L0/>3V0P21ZH4205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2
U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;C
W02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1
RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00L0K8iQ00@0PJV104EL
?0000000AE`l0P21ZH42000008D0/>3V0@3oool008L0/>3V00H0PJV105f0J`21ZH40PJV105UhI021
ZH4907nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;B
W@0I0:;BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;
T`0I09c;T`03086YP@2D`HX0U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>
H@0706b>H@06086YP@000000000000000017HT00PJV10P0000250;3PiP40oooo00280;3PiP03086Y
P@1MP6/0GH1[00@0PJV1201oZ8D00`21ZH40U<:E09C2U@0>09C2U@03086YP@2NcY/0W/jK01@0W/jK
00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H
00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00h0QZmj
00<0PJV106b>H@1/SV401P1/SV43086YP@80000000<0Af90086YP@0000000P0000250;3PiP40oooo
00280;3PiP05086YP@1MP6/0GH1[05f0J`21ZH400P23[h/6086YP@80OjR500<0PJV109C2U@2D`YD0
3`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01P0X]:M00<0PJV10:;CW02Rdi`0
6`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C00<0PJV109C1RP2D`HX0
502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00H0PJV10P1`UVP01@21ZH400000
00000017HT00PJV100800000QP2`h>H10?ooo`00R@2`h>H01@21ZH40GH1[05f0J`1MP6/0PJV100L0
Pjn;2`21ZH4909C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd0602RdYd00`21ZH40
X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<0602Lbi<00`21ZH40
U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00L0QZmj2`21ZH47072FJ005086YP@00000000000000
0021ZH400`0000260;3PiP40oooo00290;3PiP05086YP@1MP6/0GH1[05f0J`21ZH402@23[h/00`21
ZH40UlVK09O9V`0609O9VaD0PJV12`2NcY/00`21ZH40X]:M0:;BW@0H0:;BW@03086YP@2Rdi`0X]>L
01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0H09c;T`03086YP@2D`HX0U<6:
00T0U<6:5@21ZH4808ZfP@03086YP@1`UVP0L9IX00L0L9IX00D0PJV1000000000000Af90086YP@03
000008H0/>3V0@3oool008T0/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_
R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:402@2Qe:4I086YP@d0X]:M00<0PJV10:;C
W02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C00/0W<^C6@21ZH4;09S8
T003086YP@2:]X40R[J100h0R[J100<0PJV1072FJ01`UVP01`1`UVP01@21ZH40Af90000000000000
Af9000<00000Q`2`h>H10?ooo`00RP2`h>H01@21ZH40GH1[05f0J`1MP6/0PJV100T0Pjn;00<0PJV1
09O9V`2GbI/03`2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS00/0YMVS7021ZH4?
0:;CW003086YP@2QdIP0XM6H00d0XM6H7021ZH4=0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV1
08ZfP@2:]X403`2:]X400`21ZH40L9IX072FJ007072FJ005086YP@17HT00000000000021ZH400`00
00270;3PiP40oooo002:0;3PiP03086YP@1MP6/0GH1[0080GH1[00<0PJV108>_R`23[h/01`23[h/0
0`21ZH40UlVK09O9V`0>09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<0602UfJ<0
0`21ZH40Y]ZR0:KJXP0<0:KJXQl0PJV13P2Tf9h00`21ZH40X=:I0:3BV@0H0:3BV@03086YP@2Hb900
V<R@01<0V<R@00<0PJV108ZfP@2:]X403P2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00
000000H00000Q`2`h>H10?ooo`00RP2`h>H00`21ZH40GH1[05f0J`0205f0J`03086YP@23[h/0Pjn;
00L0Pjn;00<0PJV109O9V`2GbI/03P2GbI/00`21ZH40XMBQ0:7DX@0D0:7DX@03086YP@2UfJ<0YMVS
01L0YMVS00<0PJV10:KJXP2VfZ806`2VfZ800`21ZH40Y=RN0:CHWP0K0:CHWP03086YP@2PdYT0X=:I
01L0X=:I00<0PJV109S8T02Hb900502Hb9000`21ZH40R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX
00L0L9IX00<0PJV104MR@00000001@0000280;3PiP40oooo002;0;3PiP05086YP@1MP6/0GH1[05f0
J`21ZH402P23[h/00`21ZH40UlVK09O9V`0=09O9V`03086YP@2Qe:40XMBQ01@0XMBQ00<0PJV10:GI
X`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0K0:KJXP03086YP@2Tf9h0Y=RN01/0Y=RN00<0PJV10:3B
V@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J100h0R[J100<0PJV1072F
J01`UVP0201`UVP00`21ZH40Af9000000005000008P0/>3V0@3oool008/0/>3V00<0PJV105f0J`1M
P6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Q
e:404`2Qe:400`21ZH40YMVS0:GIX`0H0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:CHWP2T
f9h06P2Tf9h00`21ZH40X=:I0:3BV@0H0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:
]X403P2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00000000H00000R02`h>H10?ooo`00
S02`h>H01@21ZH40GH1[05f0J`1MP6/0PJV100T0Pjn;00<0PJV109O9V`2GbI/03P2GbI/00`21ZH40
XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01P0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40
Y=RN0:CHWP0J0:CHWP03086YP@2PdYT0X=:I01P0X=:I00<0PJV109S8T02Hb9004`2Hb9000`21ZH40
R[J108ZfP@0>08ZfP@03086YP@1`UVP0L9IX00L0L9IX00<0PJV104MR@00000001@0000290;3PiP40
oooo002<0;3PiP03086YP@1MP6/0GH1[0080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK
09O9V`0=09O9V`03086YP@2Qe:40XMBQ01@0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR
0:KJXP0J0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@
09S8T00D09S8T003086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af90
04MR@005000008X0/>3V0@3oool008`0/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_
R`0708>_R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GI
X`0G0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:CHWP2Tf9h06P2Tf9h00`21ZH40X=:I0:3B
V@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403P2:]X400`21ZH40L9IX072F
J007072FJ003086YP@17HT00Af9000D00000RP2`h>H10?ooo`00S@2`h>H01@21ZH40GH1[05f0J`1M
P6/0PJV100X0Pjn;00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2U
fJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40Y=RN0:CHWP0J0:CHWP03086YP@2P
dYT0X=:I01L0X=:I00<0PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0=08ZfP@03086YP@1`
UVP0L9IX00P0L9IX00<0PJV104MR@00000000P0000000`2`h>H000000;3PiP2:0;3PiP40oooo002=
0;3PiP03086YP@1MP6/0GH1[0080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0=
09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0J
0:KJXP03086YP@2Tf9h0Y=RN01X0Y=RN00<0PJV10:3BV@2PdYT05`2PdYT00`21ZH40V<R@09S8T00C
09S8T003086YP@2:]X40R[J100d0R[J100<0PJV1072FJ01`UVP01`1`UVP00`21ZH40Af9004MR@003
000008d0/>3V0@3oool008h0/>3V00D0PJV105f0J`1MP6/0GH1[086YP@0908>_R`03086YP@2GbI/0
UlVK00h0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80
Y]ZR01X0Y]ZR00<0PJV10:CHWP2Tf9h06P2Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03086YP@2Hb900
V<R@01<0V<R@00<0PJV108ZfP@2:]X403P2:]X400`21ZH40L9IX072FJ007072FJ003086YP@17HT00
Af9000800000SP2`h>H10?ooo`00SP2`h>H00`21ZH40GH1[05f0J`0205f0J`03086YP@23[h/0Pjn;
00L0Pjn;00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS
01L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40Y=RN0:CHWP0I0:CHWP03086YP@2PdYT0X=:I
01L0X=:I00<0PJV109S8T02Hb9004`2Hb9000`21ZH40R[J108ZfP@0=08ZfP@03086YP@1`UVP0L9IX
00L0L9IX00<0PJV104MR@017HT000`00002>0;3PiP40oooo002?0;3PiP80PJV10P1MP6/00`21ZH40
Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00d0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40
YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40
X=:I0:3BV@0G0:3BV@03086YP@2Hb900V<R@01<0V<R@00<0PJV108ZfP@2:]X403@2:]X400`21ZH40
L9IX072FJ007072FJ003086YP@17HT00Af9000800000S`2`h>H10?ooo`00S`2`h>H01P21ZH40GXA]
086YP@21ZH40GH1[086YP@T0Pjn;00<0PJV109O9V`2GbI/0302GbI/00`21ZH40XMBQ0:7DX@0C0:7D
X@03086YP@2UfJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40Y=RN0:CHWP0I0:CH
WP03086YP@2PdYT0X=:I01L0X=:I00<0PJV109S8T02Hb9004P2Hb9000`21ZH40R[J108ZfP@0=08Zf
P@03086YP@1`UVP0L9IX00L0L9IX00@0PJV104MR@021ZH40PJV10P00002?0;3PiP40oooo002@0;3P
iP03086YP@1NQ6d0GXA]00@0PJV11`23[h/00`21ZH40UlVK09O9V`0=09O9V`03086YP@2Qe:40XMBQ
01<0XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN
01T0Y=RN00<0PJV10:3BV@2PdYT05P2PdYT00`21ZH40V<R@09S8T00C09S8T003086YP@2:]X40R[J1
00d0R[J100<0PJV1072FJ01`UVP01@1`UVP4086YP@0404UWA@0000000000000008l0/>3V0@3oool0
0940/>3V00H0PJV105j4K@1NQ6d0GXA]086YP@23/Hd6086YP@80Pjn;00<0PJV109O9V`2GbI/0302G
bI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806@2V
fZ800`21ZH40Y=RN0:CHWP0I0:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8T02Hb9004`2H
b9000`21ZH40R[J108ZfP@0<08ZfP@03086YP@1`UVP0L9IX00H0PJV100<0LIY/086YP@19IdD00P19
IdD00`21ZH4000000;3PiP2?0;3PiP40oooo002A0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH401`23
/Hd6086YP@/0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2V
fZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03086YP@2H
b900V<R@01<0V<R@00<0PJV108ZfP@2:]X402@2:]X46086YP@L0LIY/00D0PJV104UWA@19IdD0BFM5
086YP@2A0;3PiP40oooo002B0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402@23/Hd00`21ZH40V<bN
09S<WP08086YP@@0UlVK00<0PJV10:7DX@2Qe:404P2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086Y
P@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h06@2Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03086Y
P@2Hb900V<R@0180V<R@00<0PJV108ZfP@2:]X400P2:]X48086YP@80RkZ500<0PJV1076JK01aVV`0
1`1aVV`01@21ZH40BFM504UWA@19IdD0PJV10980/>3V0@3oool009<0/>3V00@0PJV105j4K@1NQ6d0
PJV12@23/Hd00`21ZH40V<bN09S<WP0809S<WPX0PJV1402Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03
086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:CHWP2Tf9h0602Tf9h00`21ZH40X=:I0:3BV@0F0:3BV@03
086YP@2Hb900V<R@00h0V<R@2P21ZH4:08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19
IdD0BFM5086YP@2C0;3PiP40oooo002C0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402@23/Hd00`21
ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU00<0XmVU2`21ZH450:7DX@03086YP@2UfJ<0YMVS
01H0YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40Y=RN0:CHWP0H0:CHWP03086YP@2PdYT0X=:I
01H0X=:I00<0PJV109S8T02Hb9000`2Hb90;086YP@D0VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21
ZH40LIY/076JK007076JK005086YP@19IdD0BFM504UWA@21ZH40T`2`h>H10?ooo`00U02`h>H01@21
ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h0302Hc9h00`21ZH40XmVU0:?IY@0=
0:?IYA80PJV1302UfJ<00`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2Tf9h0Y=RN01P0Y=RN00<0PJV1
0:3BV@2PdYT02P2PdYTB086YP@l0VLbD00<0PJV108^jQ@2;^XD0302;^XD00`21ZH40LIY/076JK006
076JK005086YP@19IdD0BFM504UWA@21ZH40U02`h>H10?ooo`00U02`h>H01@21ZH40GXA]05j4K@1N
Q6d0PJV100T0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0B0:?IY@03086YP@2W
gZL0YmjW00X0YmjWC`21ZH4<0:;GW@03086YP@2Ic9@0VLbD0180VLbD00<0PJV108^jQ@2;^XD02`2;
^XD00`21ZH40LIY/076JK007076JK005086YP@19IdD0BFM504UWA@21ZH40U02`h>H10?ooo`00U@2`
h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2Hc9h0302Hc9h00`21ZH40XmVU
0:?IY@0B0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SOYP2XgjH0602XgjH00`21ZH40Y]bR
0:KLXP0H0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04P2Ic9@00`21ZH40RkZ5
08^jQ@0<08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2E0;3PiP40
oooo002F0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402023/Hd00`21ZH40V<bN09S<WP0;09S<WP03
086YP@2SfJD0XmVU0180XmVU00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0H0:SOYP03
086YP@2Vg:80Y]bR01P0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00B09W<U003
086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19IdD0PJV1
09H0/>3V0@3oool009H0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN
00`0V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV
01P0Z=nV00<0PJV10:KLXP2Vg:805`2Vg:800`21ZH40X]NM0:;GW@0F0:;GW@03086YP@2Ic9@0VLbD
0140VLbD00<0PJV108^jQ@2;^XD0302;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM5
04UWA@21ZH40UP2`h>H10?ooo`00U`2`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV1
09S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01H0YmjW00<0PJV1
0:SOYP2XgjH05`2XgjH00`21ZH40Y]bR0:KLXP0G0:KLXP03086YP@2Reid0X]NM01H0X]NM00<0PJV1
09W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV1
04UWA@19IdD0BFM5086YP@2G0;3PiP40oooo002H0;3PiP04086YP@1NQ6d0GXA]086YP@P0Pk6=00<0
PJV109S<WP2Hc9h0302Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0
PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR0:KLXP0G0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0
PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0<08^jQ@03086YP@1aVV`0LIY/00D0LIY/00D0
PJV104UWA@19IdD0BFM5086YP@2H0;3PiP40oooo002H0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH40
2023/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL0
5@2WgZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid0
5@2Reid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`0
1P1aVV`01@21ZH40BFM504UWA@19IdD0PJV109P0/>3V0@3oool009T0/>3V0P21ZH4205j4K@03086Y
P@23/Hd0Pk6=00D0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086Y
P@2WgZL0YmjW01D0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR0:KLXP0G0:KLXP03086Y
P@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086Y
P@1aVV`0LIY/00D0LIY/00<0PJV104UWA@19IdD00P21ZH6I0;3PiP40oooo002J0;3PiP@0PJV12023
/Hd00`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL0502W
gZL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid0502R
eid00`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01P1a
VV`4086YPIX0/>3V0@3oool009/0/>3V00<0PJV105^2K021ZH400P21ZH4608>aS@03086YP@2Hc9h0
V<bN00/0V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0
Z=nV01L0Z=nV00<0PJV10:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0
VLbD0140VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK004076JK0<0PJV100<0B6U8
086YP@2`h>H0VP2`h>H10?ooo`00W02`h>H00`21ZH40Fh9/05^2K004086YP@@0Pk6=00<0PJV109S<
WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0@0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SO
YP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<
U02Ic9@0402Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/0080LIY/1021ZH4204QY
B003086YP@2`h>H0/>3V09X0/>3V0@3oool009`0/>3V00D0PJV105^2K01KPV`0Fh9/086YP@0207j^
R`D0PJV13@2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SO
YP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<
U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@D0PJV10P1^VF`01@21ZH40B6U804QYB018JDP0
PJV109`0/>3V0@3oool009d0/>3V00@0PJV105^2K01KPV`0PJV11P1n[X/4086YP@/0V<bN00<0PJV1
0:?IY@2SfJD0402SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV1
0:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD0100VLbD00<0PJV1
08^jQ@2;^XD02@2;^XD4086YP@H0KYU/00@0PJV104QYB018JDP0PJV1W@2`h>H10?ooo`00WP2`h>H0
1021ZH40Fh9/05^2K021ZH4707j^R`03086YP@2DbYd0PJV100@0PJV11P2Hc9h00`21ZH40XmVU0:?I
Y@0@0:?IY@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KL
XP0F0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@0402Ic9@00`21ZH40RkZ508^j
Q@0408^jQ@D0PJV100<0R;V5086YP@1^VF`01P1^VF`01021ZH40B6U804QYB021ZH6N0;3PiP40oooo
002O0;3PiP04086YP@1KPV`0Fh9/086YP@L0OZj;00<0PJV109C:W@2DbYd00`2DbYd5086YP@80V<bN
00<0PJV10:?IY@2SfJD03`2SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV
00<0PJV10:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD00l0VLbD
00<0PJV108^jQ@2;^XD01@21ZH4608RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0
PJV1W`2`h>H10?ooo`00X02`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2DbYd0U<ZM00P0
U<ZM3021ZH490:?IY@03086YP@2WgZL0YmjW01<0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40
Y]bR0:KLXP0E0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@01`2Ic9@<086YP@X0
R;V500<0PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6P0;3PiP40oooo002Q0;3PiP04
086YP@1KPV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2DbYd02P2DbYd00`21ZH40X=RU0:3HY@060:3H
Y@l0PJV14@2WgZL00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2Vg:80Y]bR01D0Y]bR00<0PJV10:;G
W@2Reid03`2Reid?086YP@P0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK00406jI
K004086YP@18JDP0B6U8086YPJ40/>3V0@3oool00:80/>3V00<0PJV105^2K021ZH401`1n[X/00`21
ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU00l0X=RU00<0PJV10:KNZ02VgZP00`2VgZP<086Y
P@D0YmjW00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40Y]bR0:KLXP0E0:KLXP03086YP@2Reid0X]NM
00<0X]NM3021ZH450:7HWP03086YP@2HcID0V<fE00l0V<fE00<0PJV108RiQ@28^HD02@28^HD00`21
ZH40KYU/06jIK00506jIK003086YP@18JDP0PJV10:80/>3V0@3oool00:80/>3V00@0PJV105^2K01K
PV`0PJV11`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU00l0X=RU00<0PJV10:KN
Z02VgZP03P2VgZPk086YPA00XMRN00<0PJV109S=U@2HcID03`2HcID00`21ZH40R;V508RiQ@0:08Ri
Q@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1XP2`h>H10?ooo`00X`2`h>H01021
ZH40Fh9/05^2K021ZH4707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D0
0`21ZH40Y]jX0:KNZ00C0:KNZ003086YP@2Wh:L0Yn2W01D0Yn2W00<0PJV10:KNY02VgZ@05@2VgZ@0
0`21ZH40XMRN0:7HWP0C0:7HWP03086YP@2HcID0V<fE00h0V<fE00<0PJV108RiQ@28^HD02P28^HD0
0`21ZH40KYU/06jIK00406jIK004086YP@18JDP0B6U8086YPJ<0/>3V0@3oool00:@0/>3V00@0PJV1
05^2K01KPV`0PJV11P1n[X/00`21ZH40U<ZM09C:W@0:09C:W@03086YP@2Pf:D0X=RU00h0X=RU00<0
PJV10:KNZ02VgZP04P2VgZP00`21ZH40Yn2W0:OPY`0E0:OPY`03086YP@2VgZ@0Y]jT01D0Y]jT00<0
PJV10:7HWP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0>09S=U@03086YP@28^HD0R;V500X0R;V500<0
PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6T0;3PiP40oooo002U0;3PiP04086YP@1K
PV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086Y
P@2VgZP0Y]jX01<0Y]jX00<0PJV10:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086Y
P@2Qf9h0XMRN01<0XMRN00<0PJV109S=U@2HcID03P2HcID00`21ZH40R;V508RiQ@0908RiQ@03086Y
P@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1Y@2`h>H10?ooo`00YP2`h>H3086YP@L0OZj;
00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX0180Y]jX
00<0PJV10:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0XMRN0180XMRN
00<0PJV109S=U@2HcID03P2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/
0`21ZH6V0;3PiP40oooo002W0;3PiP<0PJV11`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2P
f:D0X=RU00d0X=RU00<0PJV10:KNZ02VgZP04P2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2V
gZ@0Y]jT01@0Y]jT00<0PJV10:7HWP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28
^HD0R;V500X0R;V500<0PJV106jIK01^VF`0101^VF`3086YPJL0/>3V0@3oool00:T0/>3V0`21ZH46
07j^R`03086YP@2DbYd0U<ZM00P0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00A
0:KNZ003086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@0502VgZ@00`21ZH40XMRN0:7HWP0A
0:7HWP03086YP@2HcID0V<fE00h0V<fE00<0PJV108RiQ@28^HD02@28^HD00`21ZH40KYU/06jIK003
06jIK0<0PJV1Z@2`h>H10?ooo`00ZP2`h>H5086YP@<0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21
ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L0502Wh:L00`21
ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0180XMRN00<0PJV109S=U@2HcID03@2HcID00`21
ZH40R;V508RiQ@0908RiQ@04086YP@1^VF`0KYU/06jIK0D0PJV1ZP2`h>H10?ooo`00Z`2`h>H01021
ZH40E7]V086YP@1dY8<5086YP@/0U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21ZH40Y]jX0:KNZ00A
0:KNZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7HWP0A
0:7HWP03086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD02P28^HD4086YP@0406JAJ021ZH40
A6E8086YPJ/0/>3V0@3oool00:`0/>3V0`21ZH4407BTP`D0PJV1202DbYd00`21ZH40X=RU0:3HY@0<
0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L04`2Wh:L00`21ZH40Y]jT0:KNY00C
0:KNY003086YP@2Qf9h0XMRN0140XMRN00<0PJV109S=U@2HcID0302HcID00`21ZH40R;V508RiQ@07
08RiQ@D0PJV10`1VTFP3086YPJ`0/>3V0@3oool00:h0/>3V0`21ZH4407BTP`03086YP@2;`9H0Rl2F
00H0PJV10P2DbYd00`21ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0100Y]jX00<0PJV10:OP
Y`2Wh:L04`2Wh:L00`21ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0100XMRN00<0PJV109S=
U@2HcID03@2HcID00`21ZH40R;V508RiQ@07086YP@80Ok6100@0PJV106JAJ01VTFP0IY5X0`21ZH6^
0;3PiP40oooo002_0;3PiP03086YP@1DNfH0PJV100@0M:B300<0PJV108_0UP2;`9H01@2;`9H7086Y
P@/0X=RU00<0PJV10:KNZ02VgZP0402VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2VgZ@0Y]jT
01<0Y]jT00<0PJV10:7HWP2Qf9h0402Qf9h00`21ZH40V<fE09S=U@0909S=U@L0PJV1201o/H401`21
ZH40IY5X06JAJ01VTFP0PJV104AUB021ZH40[`2`h>H10?ooo`00/02`h>H00`21ZH40E7]V086YP@04
07BTP`03086YP@2;`9H0Rl2F00P0Rl2F00<0PJV109SAX02HdJ002021ZH440:3HY@03086YP@2VgZP0
Y]jX0100Y]jX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40Y]jT0:KNY00B0:KNY003086YP@2Qf9h0
XMRN0100XMRN00<0PJV109S=U@2HcID00P2HcID8086YP@80T<JA00<0PJV107naP@1o/H40201o/H42
086YP@<0IY5X00<0PJV104AUB021ZH40/02`h>H10?ooo`00/@2`h>H4086YP@<0M:B300<0PJV108_0
UP2;`9H0202;`9H00`21ZH40V=6P09SAX00709SAX0h0PJV12@2VgZP00`21ZH40Yn2W0:OPY`0B0:OP
Y`03086YP@2VgZ@0Y]jT0180Y]jT00<0PJV10:7HWP2Qf9h01`2Qf9h>086YP@T0T<JA00<0PJV107na
P@1o/H40201o/H401021ZH40IY5X06JAJ01VTFP4086YPK40/>3V0@3oool00;<0/>3V00<0PJV105Ak
IP21ZH400`1dY8<00`21ZH40Rl2F08_0UP0808_0UP03086YP@2HdJ00V=6P00/0V=6P00<0PJV109oI
Y@2OfJD01P2OfJDm086YP@P0V]:L00<0PJV10936T@2@aY402`2@aY400`21ZH40Ok6107naP@0807na
P@07086YP@1VTFP0IY5X06JAJ021ZH40A6E8086YP@2c0;3PiP40oooo002d0;3PiP<0PJV10`1dY8<2
086YP@T0Rl2F00<0PJV109SAX02HdJ002P2HdJ000`21ZH40WmVU09oIY@0?09oIY@03086YP@2QfjD0
XM^U0180XM^U00<0PJV10:3IXP2PfJ804P2PfJ800`21ZH40V]:L09[BW00?09[BW003086YP@2@aY40
T<JA00X0T<JA00<0PJV107naP@1o/H40201o/H401021ZH40IY5X06JAJ01VTFP3086YPK@0/>3V0@3o
ool00;D0/>3V1021ZH4307BTP`03086YP@2;`9H0Rl2F00L0Rl2F00<0PJV109SAX02HdJ002P2HdJ00
0`21ZH40WmVU09oIY@0?09oIY@03086YP@2QfjD0XM^U0140XM^U00<0PJV10:3IXP2PfJ804@2PfJ80
0`21ZH40V]:L09[BW00?09[BW003086YP@2@aY40T<JA00X0T<JA00<0PJV107naP@1o/H40201o/H40
0`21ZH40IY5X06JAJ004086YPKD0/>3V0@3oool00;L0/>3V1021ZH4207BTP`03086YP@2;`9H0Rl2F
00H0Rl2F00<0PJV109SAX02HdJ002`2HdJ000`21ZH40WmVU09oIY@0>09oIY@03086YP@2QfjD0XM^U
0140XM^U00<0PJV10:3IXP2PfJ804@2PfJ800`21ZH40V]:L09[BW00>09[BW003086YP@2@aY40T<JA
00/0T<JA00<0PJV107naP@1o/H401P1o/H42086YP@0306JAJ021ZH40PJV10080PJV1]`2`h>H10?oo
o`00^@2`h>H4086YP@0307BTP`21ZH40Rl2F00L0Rl2F00<0PJV109SAX02HdJ002`2HdJ000`21ZH40
WmVU09oIY@0=09oIY@03086YP@2QfjD0XM^U0140XM^U00<0PJV10:3IXP2PfJ804@2PfJ800`21ZH40
V]:L09[BW00=09[BW003086YP@2@aY40T<JA00/0T<JA00<0PJV107naP@1o/H401P1o/H400`21ZH40
IY5X086YP@03086YPKT0/>3V0@3oool00;/0/>3V1@21ZH4808_0UP03086YP@2HdJ00V=6P00X0V=6P
00<0PJV109oIY@2OfJD03P2OfJD00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2PfJ80X=VR0100X=VR
00<0PJV109[BW02JdY`03P2JdY`00`21ZH40T<JA0936T@0:0936T@03086YP@1o/H40Ok6100H0Ok61
1@21ZH6k0;3PiP40oooo002l0;3PiPL0PJV11P2;`9H00`21ZH40V=6P09SAX00:09SAX003086YP@2O
fJD0WmVU00d0WmVU00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40X=VR0:3IXP0@0:3IXP03086YP@2J
dY`0V]:L00d0V]:L00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok6107naP@0407naP@L0PJV1_02`
h>H10?ooo`00_P2`h>H;086YP@0308_0UP21ZH40V=6P00/0V=6P00<0PJV109oIY@2OfJD03@2OfJD0
0`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2PfJ80X=VR00l0X=VR00<0PJV109[BW02JdY`03@2JdY`0
0`21ZH40T<JA0936T@0:0936T@03086YP@1o/H40PJV100X0PJV1_P2`h>H10?ooo`00`02`h>H5086Y
P@@0NZf81P21ZH4909SAX003086YP@2OfJD0WmVU00`0WmVU00<0PJV10:7KY@2QfjD03`2QfjD00`21
ZH40X=VR0:3IXP0?0:3IXP03086YP@2JdY`0V]:L00`0V]:L00<0PJV10936T@2@aY401`2@aY46086Y
P@@0L:1f1@21ZH700;3PiP40oooo00320;3PiP80PJV100<0I99e086YP@21ZH401@1j[HP2086YP@03
08RnT`21ZH40PJV100D0PJV10P2HdJ000`21ZH40WmVU09oIY@0<09oIY@03086YP@2QfjD0XM^U00l0
XM^U00<0PJV10:3IXP2PfJ803`2PfJ800`21ZH40V]:L09[BW00<09[BW003086YP@2@aY40T<JA00L0
PJV100<0PKF6086YP@21ZH401@1`X7H2086YP@0305V2G`21ZH40PJV10<80/>3V0@3oool00<@0/>3V
0P21ZH400`1TTWD0PJV107Z]R00507Z]R003086YP@28_Y<0R;jC00D0R;jC2`21ZH4709oIY@03086Y
P@2QfjD0XM^U00h0XM^U00<0PJV10:3IXP2PfJ803P2PfJ800`21ZH40V]:L09[BW00509[BW0/0PJV1
1`21]HH00`21ZH40L:1f072PMP04072PMP04086YP@1IPUl0PJV1086YPL@0/>3V0@3oool00<D0/>3V
1@21ZH4507Z]R080PJV12@28_Y<00`21ZH40T<RI0938V@040938VC40PJV11P2<`i400`21ZH40PKF6
086eQP07086eQP80PJV11@1`X7H5086YPLD0/>3V0@3oool00<L0/>3V1@21ZH4507Z]R003086YP@28
_Y<0R;jC00L0R;jC00<0PJV10938V@2@b9T02`2@b9T00`21ZH40TlbK09?<V`0=09?<V`03086YP@2B
bYP0T/ZH00d0T/ZH00<0PJV108c3T@2<`i402`2<`i400`21ZH40PKF6086eQP07086eQP03086YP@1`
X7H0L:1f00<0L:1f1@21ZH770;3PiP40oooo003:0;3PiP@0PJV1101j[HP2086YP@P0R;jC00<0PJV1
0938V@2@b9T02P2@b9T00`21ZH40TlbK09?<V`0=09?<V`03086YP@2BbYP0T/ZH00d0T/ZH00<0PJV1
08c3T@2<`i402P2<`i400`21ZH40PKF6086eQP06086eQP80PJV1101`X7H4086YPLX0/>3V0@3oool0
0<d0/>3V1021ZH4307Z]R003086YP@28_Y<0R;jC00H0R;jC0P21ZH4;0938V@03086YP@2Cc9/0TlbK
00`0TlbK00<0PJV109;:V02BbYP0302BbYP00`21ZH40S<>A08c3T@0908c3T@80PJV12021]HH01021
ZH40L:1f072PMP1`X7H4086YPLd0/>3V0@3oool00=00/>3V1`21ZH4808RnT`03086YP@2@b9T0T<RI
00T0T<RI00<0PJV109?<V`2Cc9/02`2Cc9/00`21ZH40T/ZH09;:V00;09;:V003086YP@2<`i40S<>A
00T0S<>A00<0PJV1086eQP21]HH01P21]HH7086YPM00/>3V0@3oool00=<0/>3V2@21ZH4408RnT`03
086YP@2@b9T0T<RI00T0T<RI00<0PJV109?<V`2Cc9/02P2Cc9/00`21ZH40T/ZH09;:V00:09;:V003
086YP@2<`i40S<>A00T0S<>A00<0PJV1086eQP21]HH00P21]HH9086YPM<0/>3V0@3oool00=H0/>3V
4@21ZH450938V@03086YP@2Cc9/0TlbK00X0TlbK00<0PJV109;:V02BbYP02P2BbYP00`21ZH40S<>A
08c3T@0308c3T@/0PJV100<0J9Mb086YP@21ZH400`21ZH7F0;3PiP40oooo003I0;3PiPD0PJV1101]
WW`2086YP@<0MJR29@21ZH4307:TO080PJV1101XUg85086YPMT0/>3V0@3oool00=`0/>3V1@21ZH43
06fNO080PJV1201eZ8800`21ZH40N:b407R/Q00807R/Q003086YP@1gZh80Mj^200P0Mj^200<0PJV1
07:TO01bY7`01P1bY7`2086YP@<0J9Mb1@21ZH7L0;3PiP40oooo003P0;3PiPP0PJV11`1eZ8800`21
ZH40N:b407R/Q00707R/Q003086YP@1gZh80Mj^200L0Mj^200<0PJV107:TO01bY7`01@1bY7`8086Y
PN00/>3V0@3oool00>H0/>3V1`21ZH4307FXPP03086YP@1h[8@0N:b400H0N:b400<0PJV107N[PP1g
Zh801P1gZh801021ZH40LZAl07:TO01bY7`7086YPNH0/>3V0@3oool00>d0/>3V6@21ZH7]0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.608 .781 .571 r
.47008 .46971 m .46978 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.608 .781 .571 r
.51009 .5 m .50999 .46977 L .47008 .46971 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.50999 .53023 m .51009 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.50999 .46977 m .51009 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.51009 .5 m .50999 .53023 L .5497 .53041 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.5497 .53041 m .5502 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.43078 .46941 m .43007 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.46978 .5 m .47008 .46971 L .43078 .46941 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.47008 .53029 m .46978 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.46978 .5 m .47008 .53029 L .50999 .53023 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.471 .43976 m .47008 .46971 L .50999 .46977 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.50999 .46977 m .50968 .43988 L .471 .43976 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.50968 .56012 m .50999 .53023 L .47008 .53029 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.50968 .43988 m .50999 .46977 L .5497 .46959 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.5502 .5 m .5497 .46959 L .50999 .46977 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.50999 .53023 m .50968 .56012 L .54817 .56047 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.54817 .56047 m .5497 .53041 L .50999 .53023 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.43291 .43918 m .43078 .46941 L .47008 .46971 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.47008 .46971 m .471 .43976 L .43291 .43918 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.43007 .5 m .43078 .53059 L .47008 .53029 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.471 .56024 m .47008 .53029 L .43078 .53059 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.47008 .53029 m .471 .56024 L .50968 .56012 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.5497 .46959 m .5502 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.5502 .5 m .5497 .53041 L .58839 .53084 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.58839 .53084 m .58931 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.5497 .46959 m .54817 .43953 L .50968 .43988 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.54817 .43953 m .5497 .46959 L .58839 .46916 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.58931 .5 m .58839 .46916 L .5497 .46959 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.5497 .53041 m .54817 .56047 L .58564 .56129 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.58564 .56129 m .58839 .53084 L .5497 .53041 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.47252 .41051 m .471 .43976 L .50968 .43988 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.50968 .43988 m .50918 .41067 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.50918 .41067 m .50968 .43988 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.50918 .58933 m .50968 .56012 L .471 .56024 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.50968 .56012 m .50918 .58933 L .54563 .58982 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.54563 .58982 m .54817 .56047 L .50968 .56012 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.43648 .40968 m .43291 .43918 L .471 .43976 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.471 .43976 m .47252 .41051 L .43648 .40968 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.43078 .53059 m .43291 .56082 L .471 .56024 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.47252 .58949 m .471 .56024 L .43291 .56082 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.471 .56024 m .47252 .58949 L .50918 .58933 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.39291 .46886 m .39179 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.43007 .5 m .43078 .46941 L .39291 .46886 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.43078 .53059 m .43007 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.39627 .43812 m .39291 .46886 L .43078 .46941 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.43078 .46941 m .43291 .43918 L .39627 .43812 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.39179 .5 m .39291 .53114 L .43078 .53059 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.43291 .56082 m .43078 .53059 L .39291 .53114 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.54817 .43953 m .54563 .41018 L .50918 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.54563 .41018 m .54817 .43953 L .58564 .43871 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.58839 .46916 m .58564 .43871 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.54817 .56047 m .54563 .58982 L .58106 .59098 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.58106 .59098 m .58564 .56129 L .54817 .56047 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.58839 .46916 m .58931 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.58931 .5 m .58839 .53084 L .62519 .53151 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.62519 .53151 m .62652 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.47466 .38233 m .47252 .41051 L .50918 .41067 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.50918 .41067 m .50846 .38253 L .47466 .38233 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.50846 .38253 m .50918 .41067 L .54563 .41018 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.50846 .61747 m .50918 .58933 L .47252 .58949 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.50918 .58933 m .50846 .61747 L .54206 .61807 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.54206 .61807 m .54563 .58982 L .50918 .58933 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.40187 .4082 m .39627 .43812 L .43291 .43918 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.43291 .43918 m .43648 .40968 L .40187 .4082 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.39291 .53114 m .39627 .56188 L .43291 .56082 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.43648 .59032 m .43291 .56082 L .39627 .56188 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.43291 .56082 m .43648 .59032 L .47252 .58949 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.44147 .38133 m .43648 .40968 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.47252 .41051 m .47466 .38233 L .44147 .38133 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.58564 .43871 m .58839 .46916 L .62519 .46849 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.62652 .5 m .62519 .46849 L .58839 .46916 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.58839 .53084 m .58564 .56129 L .62122 .56259 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.62122 .56259 m .62519 .53151 L .58839 .53084 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.47466 .61767 m .47252 .58949 L .43648 .59032 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.47252 .58949 m .47466 .61767 L .50846 .61747 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.54563 .41018 m .54206 .38193 L .50846 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.54206 .38193 m .54563 .41018 L .58106 .40902 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.58564 .43871 m .58106 .40902 L .54563 .41018 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.54563 .58982 m .54206 .61807 L .57465 .61947 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.57465 .61947 m .58106 .59098 L .54563 .58982 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.58106 .40902 m .58564 .43871 L .62122 .43741 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.62519 .46849 m .62122 .43741 L .58564 .43871 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.58564 .56129 m .58106 .59098 L .61461 .59279 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.61461 .59279 m .62122 .56259 L .58564 .56129 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.35742 .46806 m .35589 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.39179 .5 m .39291 .46886 L .35742 .46806 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.39291 .53114 m .39179 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.39627 .56188 m .40187 .5918 L .43648 .59032 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.44147 .61867 m .43648 .59032 L .40187 .5918 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.43648 .59032 m .44147 .61867 L .47466 .61767 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.40969 .37953 m .40187 .4082 L .43648 .40968 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.43648 .40968 m .44147 .38133 L .40969 .37953 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.36201 .43659 m .35742 .46806 L .39291 .46886 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.39291 .46886 m .39627 .43812 L .36201 .43659 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.35589 .5 m .35742 .53194 L .39291 .53114 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.39627 .56188 m .39291 .53114 L .35742 .53194 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.47742 .35564 m .47466 .38233 L .50846 .38253 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.50846 .38253 m .50754 .35586 L .47742 .35564 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.50754 .64414 m .50846 .61747 L .47466 .61767 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.50754 .35586 m .50846 .38253 L .54206 .38193 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.50846 .61747 m .50754 .64414 L .53747 .64479 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.53747 .64479 m .54206 .61807 L .50846 .61747 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.44788 .35455 m .44147 .38133 L .47466 .38233 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.47466 .38233 m .47742 .35564 L .44788 .35455 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.47742 .64436 m .47466 .61767 L .44147 .61867 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.47466 .61767 m .47742 .64436 L .50754 .64414 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.36963 .40606 m .36201 .43659 L .39627 .43812 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.39627 .43812 m .40187 .4082 L .36963 .40606 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.35742 .53194 m .36201 .56341 L .39627 .56188 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.40187 .5918 m .39627 .56188 L .36201 .56341 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.58106 .40902 m .57465 .38053 L .54206 .38193 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.57465 .38053 m .58106 .40902 L .61461 .40721 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.62122 .43741 m .61461 .40721 L .58106 .40902 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.58106 .59098 m .57465 .61947 L .60538 .62166 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.60538 .62166 m .61461 .59279 L .58106 .59098 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.54206 .38193 m .53747 .35521 L .50754 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.53747 .35521 m .54206 .38193 L .57465 .38053 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.54206 .61807 m .53747 .64479 L .56643 .64632 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.56643 .64632 m .57465 .61947 L .54206 .61807 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.62519 .46849 m .62652 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.62652 .5 m .62519 .53151 L .6591 .53242 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.6591 .53242 m .66083 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.62122 .43741 m .62519 .46849 L .6591 .46758 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.66083 .5 m .6591 .46758 L .62519 .46849 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.62519 .53151 m .62122 .56259 L .6539 .56435 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.6539 .56435 m .6591 .53242 L .62519 .53151 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.41972 .3526 m .40969 .37953 L .44147 .38133 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.44147 .38133 m .44788 .35455 L .41972 .3526 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.40187 .5918 m .40969 .62047 L .44147 .61867 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.44788 .64545 m .44147 .61867 L .40969 .62047 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.44147 .61867 m .44788 .64545 L .47742 .64436 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.38025 .37696 m .36963 .40606 L .40187 .4082 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.40187 .4082 m .40969 .37953 L .38025 .37696 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.36201 .56341 m .36963 .59394 L .40187 .5918 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.40969 .62047 m .40187 .5918 L .36963 .59394 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.61461 .40721 m .62122 .43741 L .6539 .43565 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.6591 .46758 m .6539 .43565 L .62122 .43741 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.62122 .56259 m .61461 .59279 L .64528 .59525 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.64528 .59525 m .6539 .56435 L .62122 .56259 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.57465 .38053 m .56643 .35368 L .53747 .35521 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.56643 .35368 m .57465 .38053 L .60538 .37834 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.61461 .40721 m .60538 .37834 L .57465 .38053 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.57465 .61947 m .56643 .64632 L .59358 .6487 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.59358 .6487 m .60538 .62166 L .57465 .61947 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.3254 .46703 m .32346 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.35589 .5 m .35742 .46806 L .3254 .46703 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.35742 .53194 m .35589 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.48078 .33093 m .47742 .35564 L .50754 .35586 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.50754 .35586 m .50642 .33115 L .48078 .33093 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.50642 .33115 m .50754 .35586 L .53747 .35521 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.50642 .66885 m .50754 .64414 L .47742 .64436 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.50754 .64414 m .50642 .66885 L .53187 .6695 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.53187 .6695 m .53747 .64479 L .50754 .64414 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.4557 .32985 m .44788 .35455 L .47742 .35564 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.47742 .35564 m .48078 .33093 L .4557 .32985 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.48078 .66907 m .47742 .64436 L .44788 .64545 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.47742 .64436 m .48078 .66907 L .50642 .66885 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.33119 .4346 m .3254 .46703 L .35742 .46806 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.35742 .46806 m .36201 .43659 L .33119 .4346 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.32346 .5 m .3254 .53297 L .35742 .53194 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.36201 .56341 m .35742 .53194 L .3254 .53297 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.60538 .37834 m .61461 .40721 L .64528 .40475 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.6539 .43565 m .64528 .40475 L .61461 .40721 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.61461 .59279 m .60538 .62166 L .6333 .62462 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.6333 .62462 m .64528 .59525 L .61461 .59279 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.53747 .35521 m .53187 .3305 L .50642 .33115 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.53187 .3305 m .53747 .35521 L .56643 .35368 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.53747 .64479 m .53187 .6695 L .55641 .67102 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.55641 .67102 m .56643 .64632 L .53747 .64479 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.39379 .3498 m .38025 .37696 L .40969 .37953 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.40969 .37953 m .41972 .3526 L .39379 .3498 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.36963 .59394 m .38025 .62304 L .40969 .62047 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.41972 .6474 m .40969 .62047 L .38025 .62304 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.40969 .62047 m .41972 .6474 L .44788 .64545 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.34079 .40328 m .33119 .4346 L .36201 .43659 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.36201 .43659 m .36963 .40606 L .34079 .40328 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.3254 .53297 m .33119 .5654 L .36201 .56341 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.36963 .59394 m .36201 .56341 L .33119 .5654 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.4319 .32791 m .41972 .3526 L .44788 .35455 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.44788 .35455 m .4557 .32985 L .4319 .32791 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.4557 .67015 m .44788 .64545 L .41972 .6474 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.44788 .64545 m .4557 .67015 L .48078 .66907 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.56643 .35368 m .55641 .32898 L .53187 .3305 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.55641 .32898 m .56643 .35368 L .59358 .3513 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.60538 .37834 m .59358 .3513 L .56643 .35368 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.56643 .64632 m .55641 .67102 L .57927 .67338 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.57927 .67338 m .59358 .6487 L .56643 .64632 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.35411 .37361 m .34079 .40328 L .36963 .40606 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.36963 .40606 m .38025 .37696 L .35411 .37361 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.33119 .5654 m .34079 .59672 L .36963 .59394 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.38025 .62304 m .36963 .59394 L .34079 .59672 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.6591 .46758 m .66083 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.66083 .5 m .6591 .53242 L .68892 .53358 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.68892 .53358 m .69106 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.59358 .3513 m .60538 .37834 L .6333 .37538 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.64528 .40475 m .6333 .37538 L .60538 .37834 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.60538 .62166 m .59358 .6487 L .61805 .65191 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.61805 .65191 m .6333 .62462 L .60538 .62166 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.6539 .43565 m .6591 .46758 L .68892 .46642 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.69106 .5 m .68892 .46642 L .6591 .46758 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.6591 .53242 m .6539 .56435 L .68254 .56657 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.68254 .56657 m .68892 .53358 L .6591 .53242 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.64528 .40475 m .6539 .43565 L .68254 .43343 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.68892 .46642 m .68254 .43343 L .6539 .43565 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.6539 .56435 m .64528 .59525 L .67199 .59835 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.67199 .59835 m .68254 .56657 L .6539 .56435 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41017 .32514 m .39379 .3498 L .41972 .3526 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41972 .3526 m .4319 .32791 L .41017 .32514 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.38025 .62304 m .39379 .6502 L .41972 .6474 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.4319 .67209 m .41972 .6474 L .39379 .6502 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.41972 .6474 m .4319 .67209 L .4557 .67015 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.48475 .30872 m .48078 .33093 L .50642 .33115 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.50642 .33115 m .5051 .30892 L .48475 .30872 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.5051 .30892 m .50642 .33115 L .53187 .3305 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.5051 .69108 m .50642 .66885 L .48078 .66907 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.50642 .66885 m .5051 .69108 L .52528 .69167 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.52528 .69167 m .53187 .6695 L .50642 .66885 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.4649 .30775 m .4557 .32985 L .48078 .33093 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.48078 .33093 m .48475 .30872 L .4649 .30775 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.48475 .69128 m .48078 .66907 L .4557 .67015 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.48078 .66907 m .48475 .69128 L .5051 .69108 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.37101 .34619 m .35411 .37361 L .38025 .37696 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.38025 .37696 m .39379 .3498 L .37101 .34619 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.34079 .59672 m .35411 .62639 L .38025 .62304 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.39379 .6502 m .38025 .62304 L .35411 .62639 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.53187 .3305 m .52528 .30833 L .5051 .30892 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.52528 .30833 m .53187 .3305 L .55641 .32898 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.53187 .6695 m .52528 .69167 L .54465 .69302 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.54465 .69302 m .55641 .67102 L .53187 .6695 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.6333 .37538 m .64528 .40475 L .67199 .40165 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.68254 .43343 m .67199 .40165 L .64528 .40475 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.64528 .59525 m .6333 .62462 L .65738 .62833 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.65738 .62833 m .67199 .59835 L .64528 .59525 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.59358 .3513 m .57927 .32662 L .55641 .32898 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.57927 .32662 m .59358 .3513 L .61805 .34809 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.6333 .37538 m .61805 .34809 L .59358 .3513 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59358 .6487 m .57927 .67338 L .59968 .67653 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59968 .67653 m .61805 .65191 L .59358 .6487 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.44617 .30602 m .4319 .32791 L .4557 .32985 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.4557 .32985 m .4649 .30775 L .44617 .30602 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4649 .69225 m .4557 .67015 L .4319 .67209 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.4557 .67015 m .4649 .69225 L .48475 .69128 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.29812 .46575 m .29579 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.32346 .5 m .3254 .46703 L .29812 .46575 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.3254 .53297 m .32346 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.30507 .43216 m .29812 .46575 L .3254 .46703 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.3254 .46703 m .33119 .4346 L .30507 .43216 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.29579 .5 m .29812 .53425 L .3254 .53297 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.33119 .5654 m .3254 .53297 L .29812 .53425 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.55641 .32898 m .54465 .30698 L .52528 .30833 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.54465 .30698 m .55641 .32898 L .57927 .32662 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.55641 .67102 m .54465 .69302 L .56257 .69512 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.56257 .69512 m .57927 .67338 L .55641 .67102 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.31654 .39987 m .30507 .43216 L .33119 .4346 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.33119 .4346 m .34079 .40328 L .31654 .39987 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.29812 .53425 m .30507 .56784 L .33119 .5654 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.34079 .59672 m .33119 .5654 L .30507 .56784 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.61805 .34809 m .6333 .37538 L .65738 .37167 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.67199 .40165 m .65738 .37167 L .6333 .37538 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6333 .62462 m .61805 .65191 L .6389 .65589 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6389 .65589 m .65738 .62833 L .6333 .62462 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.3913 .3216 m .37101 .34619 L .39379 .3498 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.39379 .3498 m .41017 .32514 L .3913 .3216 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.35411 .62639 m .37101 .65381 L .39379 .6502 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.41017 .67486 m .39379 .6502 L .37101 .65381 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.39379 .6502 m .41017 .67486 L .4319 .67209 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.42923 .30356 m .41017 .32514 L .4319 .32791 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.4319 .32791 m .44617 .30602 L .42923 .30356 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.44617 .69398 m .4319 .67209 L .41017 .67486 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4319 .67209 m .44617 .69398 L .4649 .69225 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.33238 .36955 m .31654 .39987 L .34079 .40328 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.34079 .40328 m .35411 .37361 L .33238 .36955 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.30507 .56784 m .31654 .60013 L .34079 .59672 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.35411 .62639 m .34079 .59672 L .31654 .60013 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.57927 .32662 m .56257 .30488 L .54465 .30698 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.56257 .30488 m .57927 .32662 L .59968 .32347 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.61805 .34809 m .59968 .32347 L .57927 .32662 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57927 .67338 m .56257 .69512 L .57837 .69792 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57837 .69792 m .59968 .67653 L .57927 .67338 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.68892 .46642 m .69106 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.69106 .5 m .68892 .53358 L .71329 .53497 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.71329 .53497 m .7158 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.48931 .28962 m .48475 .30872 L .5051 .30892 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.5051 .30892 m .50357 .28977 L .48931 .28962 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50357 .28977 m .5051 .30892 L .52528 .30833 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.50357 .71023 m .5051 .69108 L .48475 .69128 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.5051 .69108 m .50357 .71023 L .51772 .71068 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.51772 .71068 m .52528 .69167 L .5051 .69108 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.47542 .28887 m .4649 .30775 L .48475 .30872 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.48475 .30872 m .48931 .28962 L .47542 .28887 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.68254 .43343 m .68892 .46642 L .71329 .46503 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.7158 .5 m .71329 .46503 L .68892 .46642 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.68892 .53358 m .68254 .56657 L .7058 .56923 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.7058 .56923 m .71329 .53497 L .68892 .53358 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.48931 .71038 m .48475 .69128 L .4649 .69225 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.48475 .69128 m .48931 .71038 L .50357 .71023 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.59968 .32347 m .61805 .34809 L .6389 .34411 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.65738 .37167 m .6389 .34411 L .61805 .34809 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.61805 .65191 m .59968 .67653 L .6168 .68043 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.6168 .68043 m .6389 .65589 L .61805 .65191 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35235 .34184 m .33238 .36955 L .35411 .37361 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35411 .37361 m .37101 .34619 L .35235 .34184 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.31654 .60013 m .33238 .63045 L .35411 .62639 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.37101 .65381 m .35411 .62639 L .33238 .63045 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.52528 .30833 m .51772 .28932 L .50357 .28977 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.51772 .28932 m .52528 .30833 L .54465 .30698 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.52528 .69167 m .51772 .71068 L .53123 .71173 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.53123 .71173 m .54465 .69302 L .52528 .69167 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.67199 .40165 m .68254 .43343 L .7058 .43077 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.71329 .46503 m .7058 .43077 L .68254 .43343 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.68254 .56657 m .67199 .59835 L .69345 .60204 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.69345 .60204 m .7058 .56923 L .68254 .56657 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4624 .28754 m .44617 .30602 L .4649 .30775 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4649 .30775 m .47542 .28887 L .4624 .28754 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.47542 .71113 m .4649 .69225 L .44617 .69398 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.4649 .69225 m .47542 .71113 L .48931 .71038 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41472 .30044 m .3913 .3216 L .41017 .32514 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41017 .32514 m .42923 .30356 L .41472 .30044 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.37101 .65381 m .3913 .6784 L .41017 .67486 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.42923 .69644 m .41017 .67486 L .3913 .6784 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.41017 .67486 m .42923 .69644 L .44617 .69398 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.54465 .30698 m .53123 .28827 L .51772 .28932 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.53123 .28827 m .54465 .30698 L .56257 .30488 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.65738 .37167 m .67199 .40165 L .69345 .39796 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.7058 .43077 m .69345 .39796 L .67199 .40165 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67199 .59835 m .65738 .62833 L .67646 .63273 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67646 .63273 m .69345 .60204 L .67199 .59835 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54465 .69302 m .53123 .71173 L .54362 .71333 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54362 .71333 m .56257 .69512 L .54465 .69302 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37612 .31737 m .35235 .34184 L .37101 .34619 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37101 .34619 m .3913 .3216 L .37612 .31737 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.33238 .63045 m .35235 .65816 L .37101 .65381 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.3913 .6784 m .37101 .65381 L .35235 .65816 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.45076 .28567 m .42923 .30356 L .44617 .30602 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.44617 .30602 m .4624 .28754 L .45076 .28567 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.4624 .71246 m .44617 .69398 L .42923 .69644 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.44617 .69398 m .4624 .71246 L .47542 .71113 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.59968 .32347 m .57837 .30208 L .56257 .30488 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.57837 .30208 m .59968 .32347 L .6168 .31957 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.6389 .34411 m .6168 .31957 L .59968 .32347 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59968 .67653 m .57837 .69792 L .59141 .70134 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59141 .70134 m .6168 .68043 L .59968 .67653 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.6389 .34411 m .65738 .37167 L .67646 .36727 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.69345 .39796 m .67646 .36727 L .65738 .37167 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65738 .62833 m .6389 .65589 L .65512 .66059 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65512 .66059 m .67646 .63273 L .65738 .62833 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.27706 .46425 m .27438 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.29579 .5 m .29812 .46575 L .27706 .46425 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.29812 .53425 m .29579 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.28506 .42929 m .27706 .46425 L .29812 .46575 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.29812 .46575 m .30507 .43216 L .28506 .42929 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.27438 .5 m .27706 .53575 L .29812 .53425 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.30507 .56784 m .29812 .53425 L .27706 .53575 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.56257 .30488 m .54362 .28667 L .53123 .28827 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.54362 .28667 m .56257 .30488 L .57837 .30208 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.56257 .69512 m .54362 .71333 L .5544 .71545 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.5544 .71545 m .57837 .69792 L .56257 .69512 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.29822 .3959 m .28506 .42929 L .30507 .43216 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.30507 .43216 m .31654 .39987 L .29822 .3959 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.27706 .53575 m .28506 .57071 L .30507 .56784 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.31654 .60013 m .30507 .56784 L .28506 .57071 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.6168 .31957 m .6389 .34411 L .65512 .33941 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.67646 .36727 m .65512 .33941 L .6389 .34411 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.6389 .65589 m .6168 .68043 L .62982 .68498 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.62982 .68498 m .65512 .66059 L .6389 .65589 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.44095 .28331 m .41472 .30044 L .42923 .30356 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.42923 .30356 m .45076 .28567 L .44095 .28331 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.3913 .6784 m .41472 .69956 L .42923 .69644 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.45076 .71433 m .42923 .69644 L .41472 .69956 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.42923 .69644 m .45076 .71433 L .4624 .71246 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.35235 .65816 m .37612 .68263 L .3913 .6784 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.41472 .69956 m .3913 .6784 L .37612 .68263 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.40332 .29675 m .37612 .31737 L .3913 .3216 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.3913 .3216 m .41472 .30044 L .40332 .29675 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31627 .36485 m .29822 .3959 L .31654 .39987 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31654 .39987 m .33238 .36955 L .31627 .36485 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.28506 .57071 m .29822 .6041 L .31654 .60013 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.33238 .63045 m .31654 .60013 L .29822 .6041 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.49441 .27429 m .48931 .28962 L .50357 .28977 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.50357 .28977 m .50187 .27437 L .49441 .27429 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50187 .27437 m .50357 .28977 L .51772 .28932 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.50187 .72563 m .50357 .71023 L .48931 .71038 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50357 .71023 m .50187 .72563 L .50926 .72588 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50926 .72588 m .51772 .71068 L .50357 .71023 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48716 .27387 m .47542 .28887 L .48931 .28962 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48931 .28962 m .49441 .27429 L .48716 .27387 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.49441 .72571 m .48931 .71038 L .47542 .71113 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.48931 .71038 m .49441 .72571 L .50187 .72563 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51772 .28932 m .50926 .27412 L .50187 .27437 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.50926 .27412 m .51772 .28932 L .53123 .28827 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51772 .71068 m .50926 .72588 L .51628 .72647 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51628 .72647 m .53123 .71173 L .51772 .71068 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33884 .33683 m .31627 .36485 L .33238 .36955 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33238 .36955 m .35235 .34184 L .33884 .33683 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.29822 .6041 m .31627 .63515 L .33238 .63045 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.35235 .65816 m .33238 .63045 L .31627 .63515 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.48043 .27312 m .4624 .28754 L .47542 .28887 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.47542 .28887 m .48716 .27387 L .48043 .27312 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.48716 .72613 m .47542 .71113 L .4624 .71246 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.47542 .71113 m .48716 .72613 L .49441 .72571 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69654 .59384 m
.69687 .5939 L
s
.5 Mabswid
.626 .852 .647 r
.57837 .30208 m .5544 .28455 L .54362 .28667 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.5544 .28455 m .57837 .30208 L .59141 .29866 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.6168 .31957 m .59141 .29866 L .57837 .30208 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.57837 .69792 m .5544 .71545 L .56312 .71802 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.56312 .71802 m .59141 .70134 L .57837 .69792 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.53123 .28827 m .51628 .27353 L .50926 .27412 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.51628 .27353 m .53123 .28827 L .54362 .28667 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.53123 .71173 m .51628 .72647 L .52266 .72736 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.52266 .72736 m .54362 .71333 L .53123 .71173 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.59141 .29866 m .6168 .31957 L .62982 .31502 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.65512 .33941 m .62982 .31502 L .6168 .31957 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.6168 .68043 m .59141 .70134 L .60104 .70529 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.60104 .70529 m .62982 .68498 L .6168 .68043 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.47448 .27209 m .45076 .28567 L .4624 .28754 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.4624 .28754 m .48043 .27312 L .47448 .27209 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.48043 .72688 m .4624 .71246 L .45076 .71433 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.4624 .71246 m .48043 .72688 L .48716 .72613 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.71329 .46503 m .7158 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.7158 .5 m .71329 .53497 L .73061 .53658 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.73061 .53658 m .73345 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.7058 .43077 m .71329 .46503 L .73061 .46342 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.73345 .5 m .73061 .46342 L .71329 .46503 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.71329 .53497 m .7058 .56923 L .72215 .57228 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.72215 .57228 m .73061 .53658 L .71329 .53497 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.36548 .31254 m .33884 .33683 L .35235 .34184 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.35235 .34184 m .37612 .31737 L .36548 .31254 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.31627 .63515 m .33884 .66317 L .35235 .65816 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.37612 .68263 m .35235 .65816 L .33884 .66317 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.43343 .28055 m .40332 .29675 L .41472 .30044 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.41472 .30044 m .44095 .28331 L .43343 .28055 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.37612 .68263 m .40332 .70325 L .41472 .69956 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.44095 .71669 m .41472 .69956 L .40332 .70325 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.41472 .69956 m .44095 .71669 L .45076 .71433 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.69345 .39796 m .7058 .43077 L .72215 .42772 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.73061 .46342 m .72215 .42772 L .7058 .43077 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.7058 .56923 m .69345 .60204 L .70827 .60627 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.70827 .60627 m .72215 .57228 L .7058 .56923 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.54362 .28667 m .52266 .27264 L .51628 .27353 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.52266 .27264 m .54362 .28667 L .5544 .28455 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.54362 .71333 m .52266 .72736 L .52813 .72853 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.52813 .72853 m .5544 .71545 L .54362 .71333 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.67646 .36727 m .69345 .39796 L .70827 .39373 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.72215 .42772 m .70827 .39373 L .69345 .39796 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.69345 .60204 m .67646 .63273 L .68929 .63772 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.68929 .63772 m .70827 .60627 L .69345 .60204 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.46955 .2708 m .44095 .28331 L .45076 .28567 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.45076 .28567 m .47448 .27209 L .46955 .2708 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.47448 .72791 m .45076 .71433 L .44095 .71669 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.45076 .71433 m .47448 .72791 L .48043 .72688 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.39561 .29258 m .36548 .31254 L .37612 .31737 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.37612 .31737 m .40332 .29675 L .39561 .29258 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.33884 .66317 m .36548 .68746 L .37612 .68263 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.40332 .70325 m .37612 .68263 L .36548 .68746 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.65512 .33941 m .67646 .36727 L .68929 .36228 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.70827 .39373 m .68929 .36228 L .67646 .36727 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.67646 .63273 m .65512 .66059 L .66565 .66587 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.66565 .66587 m .68929 .63772 L .67646 .63273 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.59141 .29866 m .56312 .28198 L .5544 .28455 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.56312 .28198 m .59141 .29866 L .60104 .29471 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.62982 .31502 m .60104 .29471 L .59141 .29866 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.59141 .70134 m .56312 .71802 L .56935 .72096 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.56935 .72096 m .60104 .70529 L .59141 .70134 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28126 .44357 m
.28178 .44363 L
s
.28858 .41906 m
.28906 .41915 L
s
.5 Mabswid
.597 .822 .625 r
.5544 .28455 m .52813 .27147 L .52266 .27264 L p F P
.505 .664 .505 r
s
.582 .805 .615 r
.52813 .27147 m .5544 .28455 L .56312 .28198 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.5544 .71545 m .52813 .72853 L .53245 .72993 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.53245 .72993 m .56312 .71802 L .5544 .71545 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.62982 .31502 m .65512 .33941 L .66565 .33413 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.68929 .36228 m .66565 .33413 L .65512 .33941 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.65512 .66059 m .62982 .68498 L .63789 .69005 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.63789 .69005 m .66565 .66587 L .65512 .66059 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28028 .44166 m
.28126 .44357 L
s
.28661 .42058 m
.28858 .41906 L
s
.5 Mabswid
.555 .771 .575 r
.46589 .2693 m .43343 .28055 L .44095 .28331 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.44095 .28331 m .46955 .2708 L .46589 .2693 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.40332 .70325 m .43343 .71945 L .44095 .71669 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.46955 .7292 m .44095 .71669 L .43343 .71945 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.44095 .71669 m .46955 .7292 L .47448 .72791 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.42859 .27747 m .39561 .29258 L .40332 .29675 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.40332 .29675 m .43343 .28055 L .42859 .27747 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.36548 .68746 m .39561 .70742 L .40332 .70325 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.43343 .71945 m .40332 .70325 L .39561 .70742 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.26391 .46256 m .26093 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.27438 .5 m .27706 .46425 L .26391 .46256 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.27706 .53575 m .27438 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.556 .775 .586 r
.50187 .27437 m .5 .26345 L .49441 .27429 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50926 .27412 m .5 .26345 L .50187 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50187 .72563 L .49441 .72571 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .50926 .72588 L .50187 .72563 L closepath p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27276 .42606 m .26391 .46256 L .27706 .46425 L p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27706 .46425 m .28506 .42929 L .27276 .42606 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.26093 .5 m .26391 .53744 L .27706 .53575 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.28506 .57071 m .27706 .53575 L .26391 .53744 L p F P
.505 .664 .505 r
s
.554 .772 .584 r
.49441 .27429 m .5 .26345 L .48716 .27387 L closepath p F P
.505 .664 .505 r
s
.201 .208 .158 r
.5 .73655 m .49441 .72571 L .48716 .72613 L closepath p F P
.505 .664 .505 r
s
.549 .758 .592 r
.60104 .29471 m .62982 .31502 L .63789 .30995 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.66565 .33413 m .63789 .30995 L .62982 .31502 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.62982 .68498 m .60104 .70529 L .60667 .70964 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.60667 .70964 m .63789 .69005 L .62982 .68498 L p F P
.505 .664 .505 r
s
.554 .773 .587 r
.51628 .27353 m .5 .26345 L .50926 .27412 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51628 .72647 L .50926 .72588 L closepath p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28726 .39146 m .27276 .42606 L .28506 .42929 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28548 .42206 m
.28661 .42058 L
s
.5 Mabswid
.361 .485 .326 r
.28506 .42929 m .29822 .3959 L .28726 .39146 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.26391 .53744 m .27276 .57394 L .28506 .57071 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.29822 .6041 m .28506 .57071 L .27276 .57394 L p F P
.505 .664 .505 r
s
.55 .767 .58 r
.48716 .27387 m .5 .26345 L .48043 .27312 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48716 .72613 L .48043 .72688 L closepath p F P
.505 .664 .505 r
s
.582 .805 .615 r
.56312 .28198 m .53245 .27007 L .52813 .27147 L p F P
.505 .664 .505 r
s
.563 .782 .6 r
.53245 .27007 m .56312 .28198 L .56935 .27904 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.60104 .29471 m .56935 .27904 L .56312 .28198 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.56312 .71802 m .53245 .72993 L .53542 .73151 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.53542 .73151 m .56935 .72096 L .56312 .71802 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.30703 .35961 m .28726 .39146 L .29822 .3959 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.29822 .3959 m .31627 .36485 L .30703 .35961 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.27276 .57394 m .28726 .60854 L .29822 .6041 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.31627 .63515 m .29822 .6041 L .28726 .60854 L p F P
.505 .664 .505 r
s
.551 .769 .585 r
.52266 .27264 m .5 .26345 L .51628 .27353 L closepath p F P
.505 .664 .505 r
s
.197 .203 .154 r
.5 .73655 m .52266 .72736 L .51628 .72647 L closepath p F P
.505 .664 .505 r
s
.544 .761 .575 r
.48043 .27312 m .5 .26345 L .47448 .27209 L closepath p F P
.505 .664 .505 r
s
.197 .203 .155 r
.5 .73655 m .48043 .72688 L .47448 .72791 L closepath p F P
.505 .664 .505 r
s
.422 .581 .408 r
.33154 .33131 m .30703 .35961 L .31627 .36485 L p F P
.505 .664 .505 r
s
.422 .581 .408 r
.31627 .36485 m .33884 .33683 L .33154 .33131 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.28726 .60854 m .30703 .64039 L .31627 .63515 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.33884 .66317 m .31627 .63515 L .30703 .64039 L p F P
.505 .664 .505 r
s
.546 .764 .581 r
.52813 .27147 m .5 .26345 L .52266 .27264 L closepath p F P
.505 .664 .505 r
s
.192 .199 .152 r
.5 .73655 m .52813 .72853 L .52266 .72736 L closepath p F P
.505 .664 .505 r
s
.547 .76 .59 r
.56935 .27904 m .60104 .29471 L .60667 .29036 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.63789 .30995 m .60667 .29036 L .60104 .29471 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.60104 .70529 m .56935 .72096 L .57273 .72415 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.57273 .72415 m .60667 .70964 L .60104 .70529 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.46365 .26765 m .42859 .27747 L .43343 .28055 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.43343 .28055 m .46589 .2693 L .46365 .26765 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.39561 .70742 m .42859 .72253 L .43343 .71945 L p F P
.505 .664 .505 r
s
.2 .206 .157 r
.46589 .7307 m .43343 .71945 L .42859 .72253 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.43343 .71945 m .46589 .7307 L .46955 .7292 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.36017 .30728 m .33154 .33131 L .33884 .33683 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.33884 .33683 m .36548 .31254 L .36017 .30728 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.30703 .64039 m .33154 .66869 L .33884 .66317 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.36548 .68746 m .33884 .66317 L .33154 .66869 L p F P
.505 .664 .505 r
s
.537 .753 .568 r
.47448 .27209 m .5 .26345 L .46955 .2708 L closepath p F P
.505 .664 .505 r
s
.193 .199 .152 r
.5 .73655 m .47448 .72791 L .46955 .7292 L closepath p F P
.505 .664 .505 r
s
.539 .756 .576 r
.53245 .27007 m .5 .26345 L .52813 .27147 L closepath p F P
.505 .664 .505 r
s
.187 .194 .148 r
.5 .73655 m .53245 .72993 L .52813 .72853 L closepath p F P
.505 .664 .505 r
s
.471 .657 .477 r
.39217 .28809 m .36017 .30728 L .36548 .31254 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.36548 .31254 m .39561 .29258 L .39217 .28809 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.33154 .66869 m .36017 .69272 L .36548 .68746 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.39561 .70742 m .36548 .68746 L .36017 .69272 L p F P
.505 .664 .505 r
s
.529 .742 .561 r
.46955 .2708 m .5 .26345 L .46589 .2693 L closepath p F P
.505 .664 .505 r
s
.187 .195 .148 r
.5 .73655 m .46955 .7292 L .46589 .7307 L closepath p F P
.505 .664 .505 r
s
.563 .782 .6 r
.56935 .27904 m .53542 .26849 L .53245 .27007 L p F P
.505 .664 .505 r
s
.538 .753 .58 r
.53542 .26849 m .56935 .27904 L .57273 .27585 L p F P
.505 .664 .505 r
s
.547 .76 .59 r
.60667 .29036 m .57273 .27585 L .56935 .27904 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.56935 .72096 m .53542 .73151 L .53689 .73321 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.53689 .73321 m .57273 .72415 L .56935 .72096 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.42673 .27419 m .39217 .28809 L .39561 .29258 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.39561 .29258 m .42859 .27747 L .42673 .27419 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.36017 .69272 m .39217 .71191 L .39561 .70742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.42859 .72253 m .39561 .70742 L .39217 .71191 L p F P
.505 .664 .505 r
s
.531 .746 .57 r
.53542 .26849 m .5 .26345 L .53245 .27007 L closepath p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .53542 .73151 L .53245 .72993 L closepath p F P
.505 .664 .505 r
s
.52 .731 .553 r
.46589 .2693 m .5 .26345 L .46365 .26765 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.42859 .72253 m .46365 .73235 L .46589 .7307 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .46589 .7307 L .46365 .73235 L closepath p F P
.505 .664 .505 r
s
.301 .396 .336 r
.73061 .46342 m .73345 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73345 .5 m .73061 .53658 L .73916 .53835 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73916 .53835 m .74225 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.72215 .42772 m .73061 .46342 L .73916 .46165 L p F P
.505 .664 .505 r
s
.301 .396 .336 r
.74225 .5 m .73916 .46165 L .73061 .46342 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.73061 .53658 m .72215 .57228 L .72998 .57566 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.72998 .57566 m .73916 .53835 L .73061 .53658 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.70827 .39373 m .72215 .42772 L .72998 .42434 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.73916 .46165 m .72998 .42434 L .72215 .42772 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.72215 .57228 m .70827 .60627 L .71499 .61091 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.71499 .61091 m .72998 .57566 L .72215 .57228 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.46298 .26592 m .42673 .27419 L .42859 .27747 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.42859 .27747 m .46365 .26765 L .46298 .26592 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.39217 .71191 m .42673 .72581 L .42859 .72253 L p F P
.505 .664 .505 r
s
.182 .189 .144 r
.46365 .73235 m .42859 .72253 L .42673 .72581 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.68929 .36228 m .70827 .39373 L .71499 .38909 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.72998 .42434 m .71499 .38909 L .70827 .39373 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.70827 .60627 m .68929 .63772 L .69462 .64316 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.69462 .64316 m .71499 .61091 L .70827 .60627 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.66565 .33413 m .68929 .36228 L .69462 .35684 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.71499 .38909 m .69462 .35684 L .68929 .36228 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.68929 .63772 m .66565 .66587 L .66947 .67158 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.66947 .67158 m .69462 .64316 L .68929 .63772 L p F P
.505 .664 .505 r
s
.522 .735 .562 r
.53689 .26679 m .5 .26345 L .53542 .26849 L closepath p F P
.505 .664 .505 r
s
.538 .753 .58 r
.57273 .27585 m .53689 .26679 L .53542 .26849 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .53689 .73321 L .53542 .73151 L closepath p F P
.505 .664 .505 r
s
.461 .645 .517 r
.63789 .30995 m .66565 .33413 L .66947 .32842 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.69462 .35684 m .66947 .32842 L .66565 .33413 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.66565 .66587 m .63789 .69005 L .64026 .69546 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.64026 .69546 m .66947 .67158 L .66565 .66587 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.60667 .29036 m .63789 .30995 L .64026 .30454 L p F P
.505 .664 .505 r
s
.461 .645 .517 r
.66947 .32842 m .64026 .30454 L .63789 .30995 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.63789 .69005 m .60667 .70964 L .60781 .71423 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.60781 .71423 m .64026 .69546 L .63789 .69005 L p F P
.505 .664 .505 r
s
.509 .719 .544 r
.46365 .26765 m .5 .26345 L .46298 .26592 L closepath p F P
.505 .664 .505 r
s
.182 .189 .144 r
.42673 .72581 m .46298 .73408 L .46365 .73235 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .46365 .73235 L .46298 .73408 L closepath p F P
.505 .664 .505 r
s
.497 .701 .55 r
.57273 .27585 m .60667 .29036 L .60781 .28577 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.64026 .30454 m .60781 .28577 L .60667 .29036 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.60667 .70964 m .57273 .72415 L .573 .72747 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.573 .72747 m .60781 .71423 L .60667 .70964 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26906 .43953 m
.26926 .44049 L
s
.27594 .41777 m
.27646 .41725 L
s
.5 Mabswid
.161 .17 .129 r
.57273 .72415 m .53689 .73321 L .53675 .73495 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.53675 .73495 m .573 .72747 L .57273 .72415 L p F P
.505 .664 .505 r
s
.507 .716 .555 r
.53689 .26679 m .57273 .27585 L .573 .27253 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.60781 .28577 m .573 .27253 L .57273 .27585 L p F P
.505 .664 .505 r
s
.511 .722 .553 r
.53675 .26505 m .5 .26345 L .53689 .26679 L closepath p F P
.505 .664 .505 r
s
.507 .716 .555 r
.573 .27253 m .53675 .26505 L .53689 .26679 L p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .53675 .73495 L .53689 .73321 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26906 .43953 m
.26921 .43573 L
s
.27383 .42117 m
.27594 .41777 L
s
.5 Mabswid
.161 .17 .129 r
.5 .73655 m .53499 .73666 L .53675 .73495 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .53165 .73825 L .53499 .73666 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .52684 .73967 L .53165 .73825 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .52077 .74082 L .52684 .73967 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .51372 .74166 L .52077 .74082 L closepath p F P
.505 .664 .505 r
s
.136 .148 .112 r
.5 .73655 m .506 .74214 L .51372 .74166 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49799 .74224 L .506 .74214 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49008 .74195 L .49799 .74224 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48265 .74128 L .49008 .74195 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .47605 .74028 L .48265 .74128 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .47058 .73899 L .47605 .74028 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .46649 .73747 L .47058 .73899 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .46392 .73581 L .46649 .73747 L closepath p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .46298 .73408 L .46392 .73581 L closepath p F P
.505 .664 .505 r
s
.5 .709 .543 r
.53499 .26334 m .5 .26345 L .53675 .26505 L closepath p F P
.505 .664 .505 r
s
.498 .705 .534 r
.46298 .26592 m .5 .26345 L .46392 .26419 L closepath p F P
.505 .664 .505 r
s
.489 .695 .534 r
.53165 .26175 m .5 .26345 L .53499 .26334 L closepath p F P
.505 .664 .505 r
s
.487 .692 .525 r
.46392 .26419 m .5 .26345 L .46649 .26253 L closepath p F P
.505 .664 .505 r
s
.478 .682 .524 r
.52684 .26033 m .5 .26345 L .53165 .26175 L closepath p F P
.505 .664 .505 r
s
.477 .68 .517 r
.46649 .26253 m .5 .26345 L .47058 .26101 L closepath p F P
.505 .664 .505 r
s
.469 .671 .515 r
.52077 .25918 m .5 .26345 L .52684 .26033 L closepath p F P
.505 .664 .505 r
s
.468 .669 .509 r
.47058 .26101 m .5 .26345 L .47605 .25972 L closepath p F P
.505 .664 .505 r
s
.461 .661 .508 r
.51372 .25834 m .5 .26345 L .52077 .25918 L closepath p F P
.505 .664 .505 r
s
.461 .66 .504 r
.47605 .25972 m .5 .26345 L .48265 .25872 L closepath p F P
.505 .664 .505 r
s
.456 .655 .503 r
.506 .25786 m .5 .26345 L .51372 .25834 L closepath p F P
.505 .664 .505 r
s
.456 .654 .5 r
.48265 .25872 m .5 .26345 L .49008 .25805 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49799 .25776 m .5 .26345 L .506 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49008 .25805 m .5 .26345 L .49799 .25776 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.42808 .72914 m .46392 .73581 L .46298 .73408 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.46298 .73408 m .42673 .72581 L .42808 .72914 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.42673 .27419 m .46298 .26592 L .46392 .26419 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27158 .42655 m
.27383 .42117 L
s
.26921 .43573 m
.27042 .43019 L
s
.5 Mabswid
.153 .163 .124 r
.39342 .71655 m .42808 .72914 L .42673 .72581 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.42673 .72581 m .39217 .71191 L .39342 .71655 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.46392 .26419 m .42808 .27086 L .42673 .27419 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.39217 .28809 m .42673 .27419 L .42808 .27086 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27042 .43019 m
.27158 .42655 L
s
.5 Mabswid
.431 .616 .455 r
.42808 .27086 m .39342 .28345 L .39217 .28809 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.36017 .30728 m .39217 .28809 L .39342 .28345 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.36089 .69823 m .39342 .71655 L .39217 .71191 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.39217 .71191 m .36017 .69272 L .36089 .69823 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.573 .72747 m .53675 .73495 L .53499 .73666 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.53675 .26505 m .573 .27253 L .57001 .26922 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.57001 .26922 m .53499 .26334 L .53675 .26505 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.33142 .67453 m .36089 .69823 L .36017 .69272 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.36017 .69272 m .33154 .66869 L .33142 .67453 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.39342 .28345 m .36089 .30177 L .36017 .30728 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.33154 .33131 m .36017 .30728 L .36089 .30177 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.36089 .30177 m .33142 .32547 L .33154 .33131 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.30703 .35961 m .33154 .33131 L .33142 .32547 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.30591 .64599 m .33142 .67453 L .33154 .66869 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.33154 .66869 m .30703 .64039 L .30591 .64599 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.43272 .73238 m .46649 .73747 L .46392 .73581 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.46392 .73581 m .42808 .72914 L .43272 .73238 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.42808 .27086 m .46392 .26419 L .46649 .26253 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.33142 .32547 m .30591 .35401 L .30703 .35961 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.28726 .39146 m .30703 .35961 L .30591 .35401 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.28515 .61333 m .30591 .64599 L .30703 .64039 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.30703 .64039 m .28726 .60854 L .28515 .61333 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.26981 .57743 m .28515 .61333 L .28726 .60854 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.28726 .60854 m .27276 .57394 L .26981 .57743 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.30591 .35401 m .28515 .38667 L .28726 .39146 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.27276 .42606 m .28726 .39146 L .28515 .38667 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.573 .27253 m .60781 .28577 L .60411 .28114 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.60411 .28114 m .57001 .26922 L .573 .27253 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.60781 .71423 m .573 .72747 L .57001 .73078 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53499 .73666 m .57001 .73078 L .573 .72747 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.28515 .38667 m .26981 .42257 L .27276 .42606 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26391 .46256 m .27276 .42606 L .26981 .42257 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.2604 .53929 m .26981 .57743 L .27276 .57394 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.27276 .57394 m .26391 .53744 L .2604 .53929 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26981 .42257 m .2604 .46071 L .26391 .46256 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.26093 .5 m .26391 .46256 L .2604 .46071 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.25723 .5 m .2604 .53929 L .26391 .53744 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.26391 .53744 m .26093 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.2604 .46071 m .25723 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.57001 .73078 m .53499 .73666 L .53165 .73825 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.53499 .26334 m .57001 .26922 L .56374 .26608 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.56374 .26608 m .53165 .26175 L .53499 .26334 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72289 .59362 m
.72721 .58218 L
s
.72081 .59929 m
.72289 .59362 L
s
.5 Mabswid
.094 .109 .083 r
.64026 .69546 m .60781 .71423 L .60411 .71886 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.57001 .73078 m .60411 .71886 L .60781 .71423 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.60781 .28577 m .64026 .30454 L .63633 .299 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.63633 .299 m .60411 .28114 L .60781 .28577 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.44056 .73538 m .47058 .73899 L .46649 .73747 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.46649 .73747 m .43272 .73238 L .44056 .73538 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.43272 .26762 m .46649 .26253 L .47058 .26101 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.46649 .26253 m .43272 .26762 L .42808 .27086 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72058 .60152 m
.72081 .59929 L
s
1 .5 0 r
.26216 .45262 m
.26369 .44738 L
s
.5 Mabswid
.114 .127 .097 r
.39961 .72113 m .43272 .73238 L .42808 .72914 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.42808 .72914 m .39342 .71655 L .39961 .72113 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.39342 .28345 m .42808 .27086 L .43272 .26762 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.53165 .73825 m .56374 .73392 L .57001 .73078 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.56374 .73392 m .53165 .73825 L .52684 .73967 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.53165 .26175 m .56374 .26608 L .55439 .26327 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.55439 .26327 m .52684 .26033 L .53165 .26175 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.66947 .67158 m .64026 .69546 L .63633 .701 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.60411 .71886 m .63633 .701 L .64026 .69546 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.64026 .30454 m .66947 .32842 L .6657 .32251 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.6657 .32251 m .63633 .299 L .64026 .30454 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72058 .60152 m
.72127 .60223 L
s
.5 Mabswid
.094 .109 .083 r
.45134 .73796 m .47605 .74028 L .47058 .73899 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.47058 .73899 m .44056 .73538 L .45134 .73796 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.44056 .26462 m .47058 .26101 L .47605 .25972 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.47058 .26101 m .44056 .26462 L .43272 .26762 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.69462 .64316 m .66947 .67158 L .6657 .67749 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.63633 .701 m .6657 .67749 L .66947 .67158 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.66947 .32842 m .69462 .35684 L .69127 .35115 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.69127 .35115 m .6657 .32251 L .66947 .32842 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.52684 .73967 m .55439 .73673 L .56374 .73392 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.55439 .73673 m .52684 .73967 L .52077 .74082 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.52684 .26033 m .55439 .26327 L .5423 .26094 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.5423 .26094 m .52077 .25918 L .52684 .26033 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.60411 .71886 m .57001 .73078 L .56374 .73392 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.57001 .26922 m .60411 .28114 L .59543 .27668 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.59543 .27668 m .56374 .26608 L .57001 .26922 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.36811 .70373 m .39961 .72113 L .39342 .71655 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.39342 .71655 m .36089 .69823 L .36811 .70373 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.43272 .26762 m .39961 .27887 L .39342 .28345 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.36089 .30177 m .39342 .28345 L .39961 .27887 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.4646 .73999 m .48265 .74128 L .47605 .74028 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.47605 .74028 m .45134 .73796 L .4646 .73999 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.45134 .26204 m .47605 .25972 L .48265 .25872 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.47605 .25972 m .45134 .26204 L .44056 .26462 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.69462 .35684 m .71499 .38909 L .71217 .3842 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.71217 .3842 m .69127 .35115 L .69462 .35684 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.71499 .61091 m .69462 .64316 L .69127 .64885 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.6657 .67749 m .69127 .64885 L .69462 .64316 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.52077 .74082 m .5423 .73906 L .55439 .73673 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.5423 .73906 m .52077 .74082 L .51372 .74166 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52077 .25918 m .5423 .26094 L .52803 .25924 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52803 .25924 m .51372 .25834 L .52077 .25918 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26033 .45189 m
.26132 .44857 L
s
.26132 .44857 m
.27178 .41316 L
s
.5 Mabswid
.058 .077 .06 r
.69127 .64885 m .71217 .6158 L .71499 .61091 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.72998 .57566 m .71499 .61091 L .71217 .6158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72127 .60223 m
.72243 .60093 L
s
.5 Mabswid
.086 .102 .077 r
.71499 .38909 m .72998 .42434 L .72767 .42076 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.72767 .42076 m .71217 .3842 L .71499 .38909 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.4797 .74135 m .49008 .74195 L .48265 .74128 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.48265 .74128 m .4646 .73999 L .4797 .74135 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.4646 .26001 m .48265 .25872 L .49008 .25805 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.48265 .25872 m .4646 .26001 L .45134 .26204 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.41074 .72541 m .44056 .73538 L .43272 .73238 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.43272 .73238 m .39961 .72113 L .41074 .72541 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.39961 .27887 m .43272 .26762 L .44056 .26462 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.51372 .74166 m .52803 .74076 L .5423 .73906 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.52803 .74076 m .51372 .74166 L .506 .74214 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51372 .25834 m .52803 .25924 L .51229 .25826 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51229 .25826 m .506 .25786 L .51372 .25834 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.73916 .53835 m .72998 .57566 L .72767 .57924 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.71217 .6158 m .72767 .57924 L .72998 .57566 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72243 .60093 m
.72523 .5961 L
s
.5 Mabswid
.095 .11 .083 r
.72998 .42434 m .73916 .46165 L .7372 .45976 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.7372 .45976 m .72767 .42076 L .72998 .42434 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49589 .74194 m .49799 .74224 L .49008 .74195 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49008 .74195 m .4797 .74135 L .49589 .74194 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.49008 .25805 m .4797 .25865 L .4646 .26001 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.4797 .25865 m .49008 .25805 L .49799 .25776 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.33923 .68043 m .36811 .70373 L .36089 .69823 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.36089 .69823 m .33142 .67453 L .33923 .68043 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.39961 .27887 m .36811 .29627 L .36089 .30177 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33142 .32547 m .36089 .30177 L .36811 .29627 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.73916 .46165 m .74225 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.74042 .5 m .7372 .45976 L .73916 .46165 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.74225 .5 m .73916 .53835 L .7372 .54024 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.72767 .57924 m .7372 .54024 L .73916 .53835 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.506 .74214 m .51229 .74174 L .52803 .74076 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.51229 .74174 m .506 .74214 L .49799 .74224 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.506 .25786 m .51229 .25826 L .49589 .25806 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49589 .25806 m .49799 .25776 L .506 .25786 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.49799 .74224 m .49589 .74194 L .51229 .74174 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.49799 .25776 m .49589 .25806 L .4797 .25865 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.7372 .54024 m .74042 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.56374 .73392 m .59543 .72332 L .60411 .71886 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.63633 .701 m .60411 .71886 L .59543 .72332 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.60411 .28114 m .63633 .299 L .62576 .29361 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.62576 .29361 m .59543 .27668 L .60411 .28114 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72551 .59298 m
.73311 .57547 L
s
.71588 .61516 m
.72551 .59298 L
s
.5 Mabswid
.298 .451 .339 r
.59543 .72332 m .56374 .73392 L .55439 .73673 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.56374 .26608 m .59543 .27668 L .58191 .27264 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.58191 .27264 m .55439 .26327 L .56374 .26608 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.31395 .65171 m .33923 .68043 L .33142 .67453 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.33142 .67453 m .30591 .64599 L .31395 .65171 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36811 .29627 m .33923 .31957 L .33142 .32547 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.30591 .35401 m .33142 .32547 L .33923 .31957 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.42652 .72914 m .45134 .73796 L .44056 .73538 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.44056 .73538 m .41074 .72541 L .42652 .72914 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.44056 .26462 m .41074 .27459 L .39961 .27887 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.41074 .27459 m .44056 .26462 L .45134 .26204 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26705 .42352 m
.26902 .41766 L
s
.26582 .4273 m
.26705 .42352 L
s
.26409 .4328 m
.26582 .4273 L
s
.26902 .41766 m
.27047 .41351 L
s
.26303 .43629 m
.26409 .4328 L
s
.5 Mabswid
.369 .539 .437 r
.38203 .70894 m .41074 .72541 L .39961 .72113 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.39961 .72113 m .36811 .70373 L .38203 .70894 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.36811 .29627 m .39961 .27887 L .41074 .27459 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.33923 .31957 m .31395 .34829 L .30591 .35401 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.28515 .38667 m .30591 .35401 L .31395 .34829 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.29319 .61827 m .31395 .65171 L .30591 .64599 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.30591 .64599 m .28515 .61333 L .29319 .61827 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.6657 .67749 m .63633 .701 L .62576 .70639 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.59543 .72332 m .62576 .70639 L .63633 .701 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.63633 .299 m .6657 .32251 L .65374 .31669 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.65374 .31669 m .62576 .29361 L .63633 .299 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27047 .41351 m
.2713 .41125 L
s
.5 Mabswid
.298 .451 .339 r
.55439 .73673 m .58191 .72736 L .59543 .72332 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.58191 .72736 m .55439 .73673 L .5423 .73906 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.55439 .26327 m .58191 .27264 L .56403 .26926 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.56403 .26926 m .5423 .26094 L .55439 .26327 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26259 .43792 m
.26303 .43629 L
s
.5 Mabswid
.32 .443 .376 r
.27773 .58105 m .29319 .61827 L .28515 .61333 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.28515 .61333 m .26981 .57743 L .27773 .58105 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.31395 .34829 m .29319 .38173 L .28515 .38667 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.26981 .42257 m .28515 .38667 L .29319 .38173 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.44631 .73211 m .4646 .73999 L .45134 .73796 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.45134 .73796 m .42652 .72914 L .44631 .73211 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.42652 .27086 m .45134 .26204 L .4646 .26001 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.45134 .26204 m .42652 .27086 L .41074 .27459 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72207 .60382 m
.72411 .59962 L
s
.5 Mabswid
.303 .41 .35 r
.2682 .5412 m .27773 .58105 L .26981 .57743 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.26981 .57743 m .2604 .53929 L .2682 .5412 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.29319 .38173 m .27773 .41895 L .26981 .42257 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2713 .41125 m
.27155 .41077 L
s
.5 Mabswid
.182 .22 .201 r
.2604 .46071 m .26981 .42257 L .27773 .41895 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.62576 .70639 m .59543 .72332 L .58191 .72736 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.59543 .27668 m .62576 .29361 L .60857 .28866 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60857 .28866 m .58191 .27264 L .59543 .27668 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7319 .57943 m
.73066 .58344 L
s
1 .5 0 r
.27104 .4124 m
.27155 .41077 L
s
.5 Mabswid
.143 .153 .117 r
.6657 .32251 m .69127 .35115 L .67836 .34548 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.67836 .34548 m .65374 .31669 L .6657 .32251 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.69127 .64885 m .6657 .67749 L .65374 .68331 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.62576 .70639 m .65374 .68331 L .6657 .67749 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.27773 .41895 m .2682 .4588 L .2604 .46071 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26259 .43792 m
.2628 .43757 L
s
.5 Mabswid
.233 .297 .261 r
.25723 .5 m .2604 .46071 L .2682 .4588 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.26498 .5 m .2682 .5412 L .2604 .53929 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.2604 .53929 m .25723 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.2682 .4588 m .26498 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.5423 .73906 m .56403 .73074 L .58191 .72736 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.56403 .73074 m .5423 .73906 L .52803 .74076 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.5423 .26094 m .56403 .26926 L .54259 .26676 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.54259 .26676 m .52803 .25924 L .5423 .26094 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2628 .43757 m
.26353 .43545 L
s
0 0 0 r
.72074 .60613 m
.72207 .60382 L
s
.5 Mabswid
.427 .607 .489 r
.35538 .68609 m .38203 .70894 L .36811 .70373 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.36811 .70373 m .33923 .68043 L .35538 .68609 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.41074 .27459 m .38203 .29106 L .36811 .29627 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.33923 .31957 m .36811 .29627 L .38203 .29106 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2699 .41599 m
.27104 .4124 L
s
0 0 0 r
.7319 .57943 m
.73222 .57755 L
s
.5 Mabswid
.452 .65 .505 r
.46913 .7341 m .4797 .74135 L .4646 .73999 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.4646 .73999 m .44631 .73211 L .46913 .7341 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.44631 .26789 m .4646 .26001 L .4797 .25865 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.4646 .26001 m .44631 .26789 L .42652 .27086 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26353 .43545 m
.26489 .43141 L
s
0 0 0 r
.71981 .60688 m
.72074 .60613 L
s
1 .5 0 r
.26806 .42167 m
.2699 .41599 L
s
.5 Mabswid
.458 .653 .516 r
.40236 .71354 m .42652 .72914 L .41074 .72541 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.41074 .72541 m .38203 .70894 L .40236 .71354 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.38203 .29106 m .41074 .27459 L .42652 .27086 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.52803 .74076 m .54259 .73324 L .56403 .73074 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.54259 .73324 m .52803 .74076 L .51229 .74174 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.52803 .25924 m .54259 .26676 L .51871 .26531 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.51871 .26531 m .51229 .25826 L .52803 .25924 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69127 .35115 m .71217 .3842 L .69868 .37929 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69868 .37929 m .67836 .34548 L .69127 .35115 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.71217 .6158 m .69127 .64885 L .67836 .65452 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.65374 .68331 m .67836 .65452 L .69127 .64885 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26489 .43141 m
.2668 .42553 L
s
0 0 0 r
.73133 .57812 m
.73222 .57755 L
s
1 .5 0 r
.2668 .42553 m
.26806 .42167 L
s
.5 Mabswid
.47 .672 .517 r
.49373 .73498 m .49589 .74194 L .4797 .74135 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.4797 .74135 m .46913 .7341 L .49373 .73498 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.46913 .2659 m .4797 .25865 L .49589 .25806 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.4797 .25865 m .46913 .2659 L .44631 .26789 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.51229 .74174 m .51871 .73469 L .54259 .73324 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.51871 .73469 m .51229 .74174 L .49589 .74194 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.51229 .25826 m .51871 .26531 L .49373 .26502 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.49373 .26502 m .49589 .25806 L .51229 .25826 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.49589 .74194 m .49373 .73498 L .51871 .73469 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.49589 .25806 m .49373 .26502 L .46913 .2659 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.72767 .57924 m .71217 .6158 L .69868 .62071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71981 .60688 m
.71991 .60553 L
s
.5 Mabswid
.332 .462 .315 r
.67836 .65452 m .69868 .62071 L .71217 .6158 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71217 .3842 m .72767 .42076 L .71386 .41715 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71386 .41715 m .69868 .37929 L .71217 .3842 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.65374 .68331 m .62576 .70639 L .60857 .71134 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.58191 .72736 m .60857 .71134 L .62576 .70639 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.62576 .29361 m .65374 .31669 L .63344 .31129 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.63344 .31129 m .60857 .28866 L .62576 .29361 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33181 .65724 m .35538 .68609 L .33923 .68043 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33923 .68043 m .31395 .65171 L .33181 .65724 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.38203 .29106 m .35538 .31391 L .33923 .31957 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.31395 .34829 m .33923 .31957 L .35538 .31391 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.60857 .71134 m .58191 .72736 L .56403 .73074 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58191 .27264 m .60857 .28866 L .58528 .28448 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58528 .28448 m .56403 .26926 L .58191 .27264 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26523 .43615 m
.27408 .40882 L
s
.5 Mabswid
.254 .308 .211 r
.72767 .42076 m .7372 .45976 L .72324 .45784 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72324 .45784 m .71386 .41715 L .72767 .42076 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.7372 .54024 m .72767 .57924 L .71386 .58285 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72982 .5808 m
.73133 .57812 L
s
.5 Mabswid
.326 .443 .295 r
.69868 .62071 m .71386 .58285 L .72767 .57924 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71991 .60553 m
.72074 .60223 L
s
1 .5 0 r
.26676 .43387 m
.26737 .42845 L
s
0 0 0 r
.72074 .60223 m
.72279 .59652 L
s
.5 Mabswid
.521 .731 .568 r
.42835 .71723 m .44631 .73211 L .42652 .72914 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42652 .72914 m .40236 .71354 L .42835 .71723 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.40236 .28646 m .42652 .27086 L .44631 .26789 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.42652 .27086 m .40236 .28646 L .38203 .29106 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.7372 .45976 m .74042 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.72642 .5 m .72324 .45784 L .7372 .45976 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.74042 .5 m .7372 .54024 L .72324 .54216 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.71386 .58285 m .72324 .54216 L .7372 .54024 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72737 .58569 m
.72982 .5808 L
s
.5 Mabswid
.298 .386 .254 r
.72324 .54216 m .72642 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72445 .59238 m
.72737 .58569 L
s
.72279 .59652 m
.72445 .59238 L
s
.5 Mabswid
.155 .168 .131 r
.35538 .31391 m .33181 .34276 L .31395 .34829 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.29319 .38173 m .31395 .34829 L .33181 .34276 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31228 .62308 m .33181 .65724 L .31395 .65171 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31395 .65171 m .29319 .61827 L .31228 .62308 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.37971 .69114 m .40236 .71354 L .38203 .70894 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.38203 .70894 m .35538 .68609 L .37971 .69114 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.35538 .31391 m .38203 .29106 L .40236 .28646 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26676 .43387 m
.26703 .43555 L
s
.5 Mabswid
.459 .651 .481 r
.56403 .73074 m .58528 .71552 L .60857 .71134 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.58528 .71552 m .56403 .73074 L .54259 .73324 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.56403 .26926 m .58528 .28448 L .55693 .28136 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.55693 .28136 m .54259 .26676 L .56403 .26926 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.67836 .65452 m .65374 .68331 L .63344 .68871 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.60857 .71134 m .63344 .68871 L .65374 .68331 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65374 .31669 m .67836 .34548 L .65555 .34018 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65555 .34018 m .63344 .31129 L .65374 .31669 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26703 .43555 m
.26833 .4352 L
s
0 0 0 r
.71261 .61011 m
.71474 .60936 L
s
.5 Mabswid
.483 .649 .519 r
.29763 .58461 m .31228 .62308 L .29319 .61827 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29319 .61827 m .27773 .58105 L .29763 .58461 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.33181 .34276 m .31228 .37692 L .29319 .38173 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.27773 .41895 m .29319 .38173 L .31228 .37692 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.45868 .71973 m .46913 .7341 L .44631 .73211 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.44631 .73211 m .42835 .71723 L .45868 .71973 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.42835 .28277 m .44631 .26789 L .46913 .2659 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.44631 .26789 m .42835 .28277 L .40236 .28646 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26833 .4352 m
.2698 .43301 L
s
.5 Mabswid
.519 .718 .524 r
.63344 .68871 m .60857 .71134 L .58528 .71552 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60857 .28866 m .63344 .31129 L .60529 .30668 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60529 .30668 m .58528 .28448 L .60857 .28866 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27195 .427 m
.27865 .40702 L
s
.5 Mabswid
.518 .725 .54 r
.54259 .73324 m .55693 .71864 L .58528 .71552 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.55693 .71864 m .54259 .73324 L .51871 .73469 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.54259 .26676 m .55693 .28136 L .52506 .27954 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.52506 .27954 m .51871 .26531 L .54259 .26676 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2698 .43301 m
.27195 .427 L
s
0 0 0 r
.71189 .60872 m
.71261 .61011 L
s
.5 Mabswid
.47 .621 .496 r
.28856 .54309 m .29763 .58461 L .27773 .58105 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.27773 .58105 m .2682 .5412 L .28856 .54309 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.31228 .37692 m .29763 .41539 L .27773 .41895 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.2682 .4588 m .27773 .41895 L .29763 .41539 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.4916 .72084 m .49373 .73498 L .46913 .7341 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.46913 .7341 m .45868 .71973 L .4916 .72084 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.45868 .28027 m .46913 .2659 L .49373 .26502 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.46913 .2659 m .45868 .28027 L .42835 .28277 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67836 .34548 m .69868 .37929 L .67394 .37466 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67394 .37466 m .65555 .34018 L .67836 .34548 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.69868 .62071 m .67836 .65452 L .65555 .65982 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.63344 .68871 m .65555 .65982 L .67836 .65452 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35949 .66222 m .37971 .69114 L .35538 .68609 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35538 .68609 m .33181 .65724 L .35949 .66222 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.40236 .28646 m .37971 .30886 L .35538 .31391 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.33181 .34276 m .35538 .31391 L .37971 .30886 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71188 .60532 m
.71189 .60872 L
s
.5 Mabswid
.358 .446 .358 r
.29763 .41539 m .28856 .45691 L .2682 .4588 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.26498 .5 m .2682 .4588 L .28856 .45691 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.28548 .5 m .28856 .54309 L .2682 .5412 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.2682 .5412 m .26498 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.51871 .73469 m .52506 .72046 L .55693 .71864 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.52506 .72046 m .51871 .73469 L .49373 .73498 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.51871 .26531 m .52506 .27954 L .4916 .27916 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.4916 .27916 m .49373 .26502 L .51871 .26531 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.49373 .73498 m .4916 .72084 L .52506 .72046 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.49373 .26502 m .4916 .27916 L .45868 .28027 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.28856 .45691 m .28548 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.41137 .69522 m .42835 .71723 L .40236 .71354 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.40236 .71354 m .37971 .69114 L .41137 .69522 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.37971 .30886 m .40236 .28646 L .42835 .28277 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71188 .60532 m
.71347 .59946 L
s
.70842 .61134 m
.71108 .6044 L
s
1 .5 0 r
.27459 .43389 m
.28337 .40572 L
s
.5 Mabswid
.331 .398 .271 r
.69868 .37929 m .71386 .41715 L .68778 .41371 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.68778 .41371 m .67394 .37466 L .69868 .37929 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.71386 .58285 m .69868 .62071 L .67394 .62534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71108 .6044 m
.71982 .58156 L
s
.5 Mabswid
.473 .641 .451 r
.65555 .65982 m .67394 .62534 L .69868 .62071 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27086 .44764 m
.27116 .44947 L
s
.27086 .44764 m
.27192 .44562 L
s
.5 Mabswid
.519 .718 .524 r
.58528 .71552 m .60529 .69332 L .63344 .68871 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.60529 .69332 m .58528 .71552 L .55693 .71864 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.58528 .28448 m .60529 .30668 L .57052 .30321 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.57052 .30321 m .55693 .28136 L .58528 .28448 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27192 .44562 m
.27222 .44745 L
s
.27116 .44947 m
.27222 .44745 L
s
.5 Mabswid
.301 .343 .241 r
.63344 .31129 m .65555 .34018 L .62323 .33561 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.62323 .33561 m .60529 .30668 L .63344 .31129 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.65555 .65982 m .63344 .68871 L .60529 .69332 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.37971 .30886 m .35949 .33778 L .33181 .34276 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.31228 .37692 m .33181 .34276 L .35949 .33778 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.34259 .62745 m .35949 .66222 L .33181 .65724 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.33181 .65724 m .31228 .62308 L .34259 .62745 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.71386 .41715 m .72324 .45784 L .69638 .45601 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.69638 .45601 m .68778 .41371 L .71386 .41715 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.72324 .54216 m .71386 .58285 L .68778 .58629 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.67394 .62534 m .68778 .58629 L .71386 .58285 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.44875 .698 m .45868 .71973 L .42835 .71723 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.42835 .71723 m .41137 .69522 L .44875 .698 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.41137 .30478 m .42835 .28277 L .45868 .28027 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.42835 .28277 m .41137 .30478 L .37971 .30886 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70989 .59218 m
.71578 .58231 L
s
.68925 .62683 m
.70164 .60603 L
s
.70164 .60603 m
.70989 .59218 L
s
1 .5 0 r
.28644 .41267 m
.28938 .40634 L
s
.28063 .43295 m
.28644 .41267 L
s
.28938 .40634 m
.29183 .40396 L
s
.5 Mabswid
.395 .499 .332 r
.72324 .45784 m .72642 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.6993 .5 m .69638 .45601 L .72324 .45784 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.72642 .5 m .72324 .54216 L .69638 .54399 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.68778 .58629 m .69638 .54399 L .72324 .54216 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.69638 .54399 m .6993 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69361 .60101 m
.70696 .59889 L
s
1 .5 0 r
.29183 .40396 m
.29454 .40348 L
s
.5 Mabswid
.577 .79 .582 r
.55693 .71864 m .57052 .69679 L .60529 .69332 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.55693 .28136 m .57052 .30321 L .5311 .30117 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.5311 .30117 m .52506 .27954 L .55693 .28136 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.57052 .69679 m .55693 .71864 L .52506 .72046 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.39609 .66628 m .41137 .69522 L .37971 .69114 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.37971 .69114 m .35949 .66222 L .39609 .66628 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.35949 .33778 m .37971 .30886 L .41137 .30478 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68925 .62683 m
.69153 .60703 L
s
.69177 .60493 m
.69404 .58522 L
s
.69153 .60703 m
.69177 .60493 L
s
.5 Mabswid
.578 .767 .595 r
.32983 .58786 m .34259 .62745 L .31228 .62308 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.31228 .62308 m .29763 .58461 L .32983 .58786 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.35949 .33778 m .34259 .37255 L .31228 .37692 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.29763 .41539 m .31228 .37692 L .34259 .37255 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29454 .40348 m
.29571 .40526 L
s
.5 Mabswid
.631 .858 .647 r
.48957 .69924 m .4916 .72084 L .45868 .71973 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.45868 .71973 m .44875 .698 L .48957 .69924 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.44875 .302 m .45868 .28027 L .4916 .27916 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.45868 .28027 m .44875 .302 L .41137 .30478 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.65555 .34018 m .67394 .37466 L .63828 .37064 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.63828 .37064 m .62323 .33561 L .65555 .34018 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.67394 .62534 m .65555 .65982 L .62323 .66439 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.60529 .69332 m .62323 .66439 L .65555 .65982 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29571 .40526 m
.29666 .41107 L
s
.5 Mabswid
.612 .833 .618 r
.52506 .72046 m .5311 .69883 L .57052 .69679 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.5311 .69883 m .52506 .72046 L .4916 .72084 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.52506 .27954 m .5311 .30117 L .48957 .30076 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.48957 .30076 m .4916 .27916 L .52506 .27954 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.4916 .72084 m .48957 .69924 L .5311 .69883 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.4916 .27916 m .48957 .30076 L .44875 .302 L p F P
.505 .664 .505 r
s
.605 .814 .594 r
.62323 .66439 m .60529 .69332 L .57052 .69679 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.60529 .30668 m .62323 .33561 L .58279 .33214 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.58279 .33214 m .57052 .30321 L .60529 .30668 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.34259 .37255 m .32983 .41214 L .29763 .41539 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.28856 .45691 m .29763 .41539 L .32983 .41214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29103 .43169 m
.29943 .4027 L
s
.5 Mabswid
.565 .74 .573 r
.32189 .54482 m .32983 .58786 L .29763 .58461 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.29763 .58461 m .28856 .54309 L .32189 .54482 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.32983 .41214 m .32189 .45518 L .28856 .45691 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.28548 .5 m .28856 .45691 L .32189 .45518 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.3192 .5 m .32189 .54482 L .28856 .54309 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.28856 .54309 m .28548 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.41137 .30478 m .39609 .33372 L .35949 .33778 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.34259 .37255 m .35949 .33778 L .39609 .33372 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.38325 .63104 m .39609 .66628 L .35949 .66222 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.35949 .66222 m .34259 .62745 L .38325 .63104 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.32189 .45518 m .3192 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.43977 .66907 m .44875 .698 L .41137 .69522 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.41137 .69522 m .39609 .66628 L .43977 .66907 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.39609 .33372 m .41137 .30478 L .44875 .302 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.68778 .58629 m .67394 .62534 L .63828 .62936 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.62323 .66439 m .63828 .62936 L .67394 .62534 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.67394 .37466 m .68778 .41371 L .64966 .41072 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.64966 .41072 m .63828 .37064 L .67394 .37466 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30503 .40797 m
.30755 .4036 L
s
.30755 .4036 m
.31187 .40104 L
s
.30037 .42471 m
.30262 .42043 L
s
.30037 .42471 m
.30058 .42873 L
s
.30262 .42043 m
.30562 .41808 L
s
.31187 .40104 m
.31566 .4006 L
s
.5 Mabswid
.605 .814 .594 r
.57052 .69679 m .58279 .66786 L .62323 .66439 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.58279 .66786 m .57052 .69679 L .5311 .69883 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.57052 .30321 m .58279 .33214 L .53658 .3301 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.53658 .3301 m .5311 .30117 L .57052 .30321 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30058 .42873 m
.30385 .43047 L
s
.30562 .41808 m
.31261 .41535 L
s
.5 Mabswid
.542 .707 .498 r
.69638 .54399 m .68778 .58629 L .64966 .58928 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.63828 .62936 m .64966 .58928 L .68778 .58629 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.68778 .41371 m .69638 .45601 L .65676 .45441 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.65676 .45441 m .64966 .41072 L .68778 .41371 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31566 .4006 m
.31895 .40231 L
s
.5 Mabswid
.402 .484 .33 r
.62323 .33561 m .63828 .37064 L .59314 .36757 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.59314 .36757 m .58279 .33214 L .62323 .33561 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.63828 .62936 m .62323 .66439 L .58279 .66786 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.48773 .67031 m .48957 .69924 L .44875 .698 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.44875 .698 m .43977 .66907 L .48773 .67031 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.43977 .33093 m .44875 .302 L .48957 .30076 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.44875 .302 m .43977 .33093 L .39609 .33372 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30385 .43047 m
.30776 .43015 L
s
.5 Mabswid
.625 .824 .628 r
.3735 .59054 m .38325 .63104 L .34259 .62745 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.34259 .62745 m .32983 .58786 L .3735 .59054 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.39609 .33372 m .38325 .36896 L .34259 .37255 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.32983 .41214 m .34259 .37255 L .38325 .36896 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31895 .40231 m
.31903 .40645 L
s
.31261 .41535 m
.31588 .41297 L
s
.5 Mabswid
.488 .619 .429 r
.69638 .45601 m .6993 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.65918 .5 m .65676 .45441 L .69638 .45601 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.6993 .5 m .69638 .54399 L .65676 .54559 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.64966 .58928 m .65676 .54559 L .69638 .54399 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.5311 .69883 m .53658 .6699 L .58279 .66786 L p F P
.505 .664 .505 r
s
.651 .872 .648 r
.53658 .6699 m .5311 .69883 L .48957 .69924 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.5311 .30117 m .53658 .3301 L .48773 .32969 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.48773 .32969 m .48957 .30076 L .5311 .30117 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30776 .43015 m
.31229 .42774 L
s
.31843 .40858 m
.31903 .40645 L
s
.31588 .41297 m
.31843 .40858 L
s
.5 Mabswid
.651 .872 .648 r
.48957 .69924 m .48773 .67031 L .53658 .6699 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.48957 .30076 m .48773 .32969 L .43977 .33093 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.65676 .54559 m .65918 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31229 .42774 m
.31463 .42343 L
s
.5 Mabswid
.449 .547 .402 r
.38325 .36896 m .39609 .33372 L .43977 .33093 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.43218 .63351 m .43977 .66907 L .39609 .66628 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.39609 .66628 m .38325 .63104 L .43218 .63351 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33033 .40122 m
.33246 .39892 L
s
.5 Mabswid
.611 .797 .605 r
.36741 .54626 m .3735 .59054 L .32983 .58786 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.32983 .58786 m .32189 .54482 L .36741 .54626 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.38325 .36896 m .3735 .40946 L .32983 .41214 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33246 .39892 m
.33336 .40095 L
s
.33033 .40122 m
.33123 .40324 L
s
.5 Mabswid
.522 .657 .495 r
.32189 .45518 m .32983 .41214 L .3735 .40946 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33123 .40324 m
.33336 .40095 L
s
.5 Mabswid
.46 .568 .394 r
.63828 .37064 m .64966 .41072 L .60101 .40842 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.60101 .40842 m .59314 .36757 L .63828 .37064 L p F P
.505 .664 .505 r
s
.605 .795 .573 r
.64966 .58928 m .63828 .62936 L .59314 .63243 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.58279 .66786 m .59314 .63243 L .63828 .62936 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.58279 .33214 m .59314 .36757 L .54122 .36576 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.54122 .36576 m .53658 .3301 L .58279 .33214 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.59314 .63243 m .58279 .66786 L .53658 .6699 L p F P
.505 .664 .505 r
s
.522 .657 .495 r
.3735 .40946 m .36741 .45374 L .32189 .45518 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.32261 .44354 m
.32842 .41401 L
s
.5 Mabswid
.559 .714 .54 r
.3192 .5 m .32189 .45518 L .36741 .45374 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.36534 .5 m .36741 .54626 L .32189 .54482 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.32189 .54482 m .3192 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.36741 .45374 m .36534 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.43218 .36649 m .43977 .33093 L .48773 .32969 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.48617 .63462 m .48773 .67031 L .43977 .66907 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.43977 .66907 m .43218 .63351 L .48617 .63462 L p F P
.505 .664 .505 r
s
.449 .547 .402 r
.43977 .33093 m .43218 .36649 L .38325 .36896 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.3735 .40946 m .38325 .36896 L .43218 .36649 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.42641 .59239 m .43218 .63351 L .38325 .63104 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.38325 .63104 m .3735 .59054 L .42641 .59239 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.65676 .54559 m .64966 .58928 L .60101 .59158 L p F P
.505 .664 .505 r
s
.605 .795 .573 r
.59314 .63243 m .60101 .59158 L .64966 .58928 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.64966 .41072 m .65676 .45441 L .60593 .45318 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.60593 .45318 m .60101 .40842 L .64966 .41072 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.53658 .6699 m .54122 .63424 L .59314 .63243 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.53658 .3301 m .54122 .36576 L .48617 .36538 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.48617 .36538 m .48773 .32969 L .53658 .3301 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.54122 .63424 m .53658 .6699 L .48773 .67031 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.48773 .67031 m .48617 .63462 L .54122 .63424 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.48773 .32969 m .48617 .36538 L .43218 .36649 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.65676 .45441 m .65918 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.6076 .5 m .60593 .45318 L .65676 .45441 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.65918 .5 m .65676 .54559 L .60593 .54682 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.60101 .59158 m .60593 .54682 L .65676 .54559 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.60101 .59158 m .59314 .63243 L .54122 .63424 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.59314 .36757 m .60101 .40842 L .54475 .40706 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.54475 .40706 m .54122 .36576 L .59314 .36757 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.60593 .54682 m .6076 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.42279 .54725 m .42641 .59239 L .3735 .59054 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.3735 .59054 m .36741 .54626 L .42279 .54725 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.43218 .36649 m .42641 .40761 L .3735 .40946 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.36741 .45374 m .3735 .40946 L .42641 .40761 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.48498 .59322 m .48617 .63462 L .43218 .63351 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.43218 .63351 m .42641 .59239 L .48498 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.42641 .40761 m .43218 .36649 L .48617 .36538 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.42641 .40761 m .42279 .45275 L .36741 .45374 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.36534 .5 m .36741 .45374 L .42279 .45275 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.42155 .5 m .42279 .54725 L .36741 .54626 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.36741 .54626 m .36534 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.54122 .63424 m .54475 .59294 L .60101 .59158 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.54122 .36576 m .54475 .40706 L .48498 .40678 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.48498 .40678 m .48617 .36538 L .54122 .36576 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.54475 .59294 m .54122 .63424 L .48617 .63462 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.60101 .40842 m .60593 .45318 L .54696 .45245 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.54696 .45245 m .54475 .40706 L .60101 .40842 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.60593 .54682 m .60101 .59158 L .54475 .59294 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.48617 .63462 m .48498 .59322 L .54475 .59294 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.48617 .36538 m .48498 .40678 L .42641 .40761 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.42279 .45275 m .42155 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
.636 .827 .612 r
.48424 .5477 m .48498 .59322 L .42641 .59239 L p F P
.505 .664 .505 r
s
.636 .827 .612 r
.42641 .59239 m .42279 .54725 L .48424 .5477 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.42279 .45275 m .42641 .40761 L .48498 .40678 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.60593 .45318 m .6076 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.54772 .5 m .54696 .45245 L .60593 .45318 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.6076 .5 m .60593 .54682 L .54696 .54755 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.54475 .59294 m .54696 .54755 L .60593 .54682 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.54696 .54755 m .54772 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.632 .82 .601 r
.54696 .54755 m .54475 .59294 L .48498 .59322 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.54475 .40706 m .54696 .45245 L .48424 .4523 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.48424 .4523 m .48498 .40678 L .54475 .40706 L p F P
.505 .664 .505 r
s
.632 .82 .601 r
.48498 .59322 m .48424 .5477 L .54696 .54755 L p F P
.505 .664 .505 r
s
.558 .704 .516 r
.48498 .40678 m .48424 .4523 L .42279 .45275 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.42155 .5 m .42279 .45275 L .48424 .4523 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.48398 .5 m .48424 .5477 L .42279 .54725 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.42279 .54725 m .42155 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.48424 .4523 m .48398 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.54696 .45245 m .54772 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.48398 .5 m .48424 .4523 L .54696 .45245 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.54772 .5 m .54696 .54755 L .48424 .5477 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.48424 .5477 m .48398 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003U0;3PiPl0PJV10`0T9ad0
0`21ZH409BPN02DX7P0602DX7P03086YP@0T9ad092LM00P0PJV1j02`h>H10?ooo`00h02`h>H6086Y
P@L08B@K0P21ZH4702@W7@03086YP@0U:1h09BPN00L09BPN00<0PJV102@W7@0T9ad01@0T9ad2086Y
P@03020S6`21ZH40PJV100@0PJV1hP2`h>H10?ooo`00g@2`h>H3086YP@806ahG0P21ZH47024T6`80
PJV12@0T9ad00`21ZH409BPN02DX7P0802DX7P03086YP@0T9ad092LM00H092LM0P21ZH44020S6`L0
PJV1g02`h>H10?ooo`00fP2`h>H4086YP@806ahG0P21ZH43024T6b<0PJV1100T9ad2086YP@D082<K
0P21ZH400`0J7QL0PJV1086YP@03086YPMP0/>3V0@3oool00=H0/>3V1@21ZH400`0K7QL0PJV1086Y
P@07086YP@@0<S<W00<0PJV103Hg:P0f=bX02P0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f
=bX0=SLZ0080=SLZ3021ZH401@0P8a/0PJV1086YP@21ZH406QhG0080PJV100<04QHA086YP@2`h>H0
e@2`h>H10?ooo`00e02`h>H00`21ZH404aLA086YP@05086YP@0302/]8P21ZH40<S<W00T0<S<W00<0
PJV103Hg:P0f=bX02`0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0
PJV1038c9`0b<bL00P0b<bL<086YPM<0/>3V0@3oool00=40/>3V00<0PJV101<G4@21ZH400`21ZH45
02/]8P03086YP@0b<bL0<S<W00P0<S<W00<0PJV103Hg:P0f=bX0300f=bX00`21ZH40=cP[03Lh:`0;
03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0PJV1038c9`0b<bL01`0b<bL9086YPM00/>3V0@3oool0
0<h0/>3V1P21ZH4702/]8P03086YP@0b<bL0<S<W00T0<S<W00<0PJV103Hg:P0f=bX02`0f=bX00`21
ZH40=cP[03Lh:`0<03Lh:`03086YP@0f=bX0=SLZ00X0=SLZ00<0PJV1038c9`0b<bL0200b<bL01021
ZH40:RdR02X]8P0Z;B85086YPLh0/>3V0@3oool00</0/>3V1021ZH400`0Q91/0PJV1086YP@0702/]
8P80PJV12`0b<bL00`21ZH40=SLZ03Hg:P0<03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg
:P0f=bX02P0f=bX00`21ZH40<S<W038c9`08038c9`80PJV1100Z;B85086YPL/0/>3V0@3oool00<T0
/>3V0`21ZH43024T6`03086YP@0[;B80:bdR00H0:bdR00<0PJV1038c9`0b<bL02P0b<bL00`21ZH40
=SLZ03Hg:P0=03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg:P0f=bX02`0f=bX00`21ZH40
<S<W038c9`09038c9`80PJV1100Z;B82086YP@03020S6P21ZH40PJV10<T0/>3V0@3oool00<L0/>3V
0`21ZH43024T6`80PJV1200[;B800`21ZH40<S<W038c9`07038c9bd0PJV11P0f=bX00`21ZH40<S<W
038c9`0:038c9`03086YP@0Z;B80:RdR00<0:RdR00<0PJV1020S6P0P8aX00P21ZH770;3PiP40oooo
00350;3PiP<0PJV10`0Q91/2086YP@T0:bdR00<0PJV1038c9`0b<bL02021ZH4304I==`03086YP@1<
ESd0C5Hm00h0C5Hm00<0PJV104mI?P1?FCh03P1?FCh00`21ZH40CEHm04eF?@0504eF?@l0PJV11@0b
<bL2086YP@@0:RdR0P21ZH42020S6P80PJV1a@2`h>H10?ooo`00``2`h>H00`21ZH4051PB086YP@03
024T6`80PJV1100[;B8:086YP@X0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI?P0?
04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL01016CCL9086YP@@0:RdR00@0PJV1
020S6P0P8aX082<J0P21ZH730;3PiP40oooo00310;3PiP04086YP@0D6180PJV1086YP@808B@K2021
ZH4503Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL03016CCL5086YP@0302X]8P21
ZH40PJV100<082<J0P21ZH710;3PiP40oooo002o0;3PiP05086YP@0D6180PJV1086YP@0Q91/01021
ZH4<03Xn;P03086YP@16CCL0ATdg00/0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00d0CEHm00<0PJV104I==`16CCL03016CCL01021ZH40>Sd]03Xm
;@0j?Bd5086YP@<082<J0P21ZH6o0;3PiP40oooo002m0;3PiP03086YP@0D6180PJV100@0PJV10P0/
;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd0401<
ESd00`21ZH40CeTn04mI?P0?04mI?P03086YP@1=ESd0CEHm00h0CEHm00<0PJV104I==`16CCL02`16
CCL00`21ZH40>Sd]03Xm;@0503Xm;@@0PJV10P0P8aX2086YPKd0/>3V0@3oool00;/0/>3V00<0PJV1
01@H4P21ZH400P21ZH4502`_8`03086YP@0j?Rh0>Sh^00X0>Sh^00<0PJV104I==`16CCL03016CCL0
0`21ZH40C5Hm04aF?@0@04aF?@03086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03@1=ESd0
0`21ZH40ATdg04I==`0<04I==`03086YP@0j?Bd0>Sd]00H0>Sd]00<0PJV102`^8`21ZH401@21ZH6k
0;3PiP40oooo002i0;3PiPD0PJV11P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg
00d0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI?P0A04mI?P03086YP@1=ESd0CEHm
00h0CEHm00<0PJV104I==`16CCL03016CCL00`21ZH40>Sd]03Xm;@0603Xm;@03086YP@0/;R<0;2hS
0080;2hS0`21ZH6j0;3PiP40oooo002g0;3PiP80PJV10`0M8AT00`21ZH40;2lS02`_8`0402`_8`03
086YP@0j?Rh0>Sh^00/0>Sh^00<0PJV104I==`16CCL03016CCL00`21ZH40C5Hm04aF?@0A04aF?@03
086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03P1=ESd00`21ZH40ATdg04I==`0=04I==`03
086YP@0j?Bd0>Sd]00H0>Sd]0P21ZH4502`^8`80PJV1^02`h>H10?ooo`00]P2`h>H01021ZH407B4I
01dQ6@0M8AT2086YP@H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh00`21ZH40ATdg04I==`0=04I==`03
086YP@1<ESd0C5Hm0140C5Hm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40CEHm04eF?@0?04eF?@03
086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0
PJV1]P2`h>H10?ooo`00]@2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV100P0;2lS00<0PJV103Xn;P0j
?Rh02P0j?Rh00`21ZH40ATdg04I==`0=04I==`03086YP@1<ESd0C5Hm0180C5Hm00<0PJV104mI?P1?
FCh04P1?FCh00`21ZH40CEHm04eF?@0?04eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j
?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0PJV1]@2`h>H10?ooo`00/`2`h>H2086YP@<07B4I
00<0PJV102`_8`0/;b<01P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00X0ATdg
>021ZH4804eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd0200j?Bd00`21ZH40;2hS
02`^8`0402`^8`<0PJV1/`2`h>H10?ooo`00/P2`h>H00`21ZH407B4I01dQ6@0201dQ6@03086YP@0/
;b<0;2lS00H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh01021ZH40ATdg04I==`16CCL9086YP@@0Gg1B
00<0PJV106AgE@1TMeD04P1TMeD00`21ZH40HgIC06=fD`0B06=fD`03086YP@1NKd`0GVm<00L0GVm<
3P21ZH4;04I==`03086YP@0j?Bd0>Sd]00P0>Sd]00<0PJV102`^8`0/;R<0100/;R<00`21ZH4071lH
086YP@2b0;3PiP40oooo002a0;3PiP03086YP@0M8AT07B4I00807B4I00<0PJV102`_8`0/;b<01P0/
;b<00`21ZH40>Sh^03Xn;P0803Xn;PP0PJV1301OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1S
MU<0HgIC0180HgIC00<0PJV105i_C01NKd`0401NKd`00`21ZH40F6M705QWA`0205QWA`T0PJV10`16
CCL00`21ZH40>Sd]03Xm;@0803Xm;@80PJV11@0/;R<00`21ZH4071lH086YP@2a0;3PiP40oooo002`
0;3PiP04086YP@0M8AT07B4I01dQ6@80PJV1200/;b<01021ZH40>Sh^03Xn;P0j?Rh8086YP@80E658
00<0PJV105m`DP1OL5803`1OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC0180HgIC
00<0PJV105i_C01NKd`04@1NKd`00`21ZH40F6M705QWA`0:05QWA`P0PJV1200j?Bd00`21ZH40;2hS
02`^8`0302`^8`04086YP@0L7aP0PJV1086YPJl0/>3V0@3oool00:l0/>3V00D0PJV101dQ6@0M8AT0
7B4I086YP@0702`_8`L0PJV12P1DHDP00`21ZH40Gg1B05m`DP0?05m`DP03086YP@1TMeD0I7ME01<0
I7ME00<0PJV106=fD`1SMU<04`1SMU<00`21ZH40GVm<05i_C00@05i_C003086YP@1HIdL0F6M700l0
F6M700<0PJV104eG?@1=Ecd01`21ZH4203Xm;@03086YP@0/;R<0;2hS00<0;2hS00@0PJV101`O600L
7aP0PJV1[P2`h>H10?ooo`00[P2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV10080;2lS1P21ZH400`10
AcL0PJV105AQB00=05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21
ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21
ZH40CELm04eG?@0704eG?@D0PJV1100/;R<2086YP@0301`O6021ZH40/>3V0:`0/>3V0@3oool00:`0
/>3V0P21ZH4201dQ6@D0PJV11`10AcL00`21ZH40E65805AQB00<05AQB003086YP@1OL580Gg1B00l0
Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140
GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@@0PJV10`0/;R<01021ZH40
71lH086YP@21ZH6[0;3PiP40oooo002[0;3PiP03086YP@0M8AT07B4I00<0PJV12P10AcL00`21ZH40
E65805AQB00<05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40
HgIC06=fD`0D06=fD`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21ZH40
CELm04eG?@0;04eG?@03086YP@0i?Rh0>Ch^00D0PJV10P0L7aP00`21ZH40/>3V0;3PiP2X0;3PiP40
oooo002Z0;3PiP@0PJV100<09b/Q086YP@10AcL02@10AcL00`21ZH40E65805AQB00=05AQB003086Y
P@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgIC06=fD`0D06=fD`03086Y
P@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@03086Y
P@0i?Rh0>Ch^00@0>Ch^0`21ZH400`0L7aP0PJV10;3PiP2X0;3PiP40oooo002Y0;3PiP80PJV1100W
:b400`21ZH40@4Lg0417=`070417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`DP1OL5804@1O
L5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC01@0HgIC00<0PJV105i_C01NKd`04P1N
Kd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn;P0i?Rh01@0i
?Rh5086YPJL0/>3V0@3oool00:L0/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00P0@4Lg00<0PJV1
05AQB01DHDP0301DHDP00`21ZH40Gg1B05m`DP0A05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV1
06=fD`1SMU<0501SMU<00`21ZH40GVm<05i_C00C05i_C003086YP@1HIdL0F6M700l0F6M700<0PJV1
04eG?@1=Ecd02`1=Ecd00`21ZH40>Ch^03Tn;P0503Tn;P03086YP@0T9ad092LM0080PJV1YP2`h>H1
0?ooo`00YP2`h>H2086YP@D09b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQ
B003086YP@1OL580Gg1B0140Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0E06=f
D`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL0401HIdL00`21ZH40CELm04eG?@0;04eG
?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2U0;3PiP40oooo002U0;3P
iP80PJV11@0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`
DP1OL5804P1OL5800`21ZH40I7ME06AgE@0D06AgE@03086YP@1SMU<0HgIC01D0HgIC00<0PJV105i_
C01NKd`04`1NKd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn
;P0i?Rh01@0i?Rh00`21ZH4092LM02@W7@0202@W7@03086YP@2`h>H0/>3V0:80/>3V0@3oool00:@0
/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00T0@4Lg00<0PJV105AQB01DHDP03@1DHDP00`21ZH40
Gg1B05m`DP0B05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=fD`1SMU<05@1SMU<00`21ZH40
GVm<05i_C00C05i_C003086YP@1HIdL0F6M70100F6M700<0PJV104eG?@1=Ecd02`1=Ecd00`21ZH40
>Ch^03Tn;P0503Tn;P05086YP@0T9ad092LM02@W7@21ZH40Y02`h>H10?ooo`00X`2`h>H2086YP@H0
9b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQB003086YP@1OL580Gg1B0180
Gg1B00<0PJV106AgE@1TMeD02P1TMeD_086YP@/0GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40
CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2S0;3P
iP40oooo002R0;3PiP80PJV11P0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800h0
E65800<0PJV105m`DP1OL580201OL58G086YP@/0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40
LHUP0769H0090769H100PJV13P1HIdL00`21ZH40CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0
>Ch^00D0PJV102@W7@0T9ad092LM086YP@2R0;3PiP40oooo002Q0;3PiP80PJV11P0W:b400`21ZH40
@4Lg0417=`080417=`03086YP@1DHDP0E65800X0E6584021ZH4:07:<IP03086YP@1fTFP0MY5X01D0
MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D0080
IW]D2P21ZH4405QWA`03086YP@1=Ecd0CELm00d0CELm00<0PJV103Tn;P0i?Rh01@0i?Rh01@21ZH40
92LM02@W7@0T9ad0PJV10:40/>3V0@3oool00:00/>3V00<0PJV1010D4021ZH401@0W:b400`21ZH40
@4Lg0417=`090417=`04086YP@1DHDP0E65805AQB0T0PJV1101YOel00`21ZH40LXaV07:<IP0C07:<
IP03086YP@1fTFP0MY5X01D0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00E0769
H003086YP@1VNe@0IW]D00/0IW]D2P21ZH4:04eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00D0PJV102@W
7@0T9ad092LM086YP@2P0;3PiP40oooo002O0;3PiP03086YP@0@5100PJV100D09b/Q00<0PJV10417
=`10AcL01`10AcL7086YP@`0JGmO00<0PJV107:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00F07JA
J003086YP@1fT6H0MY1V01H0MY1V00<0PJV10769H01aRF00501aRF000`21ZH40IW]D06IkE00@06Ik
E003086YP@1KK4T0Ffa90080Ffa92021ZH4304eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00@0PJV102@W
7@0T9ad0PJV1X02`h>H10?ooo`00WP2`h>H00`21ZH4041@@086YP@0602L[8@03086YP@10AcL0@4Lg
00<0@4Lg1021ZH400`1GIdl0PJV106UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JA
J01fTFP05P1fTFP00`21ZH40MY1V07J@IP0F07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106Ik
E01VNe@04@1VNe@00`21ZH40Ffa905]/B@0905]/B@H0PJV11P0i?Rh01@21ZH4092LM02@W7@0T9ad0
PJV109l0/>3V0@3oool009h0/>3V00<041@@086YP@0W:b401@0W:b400`21ZH40@4Lg086YP@04086Y
P@D0EfM?00<0PJV106UoG`1YOel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X
01H0MY5X00<0PJV107J@IP1fT6H05P1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D
0140IW]D00<0PJV105]/B@1KK4T03P1KK4T5086YP@<0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2N
0;3PiP40oooo002M0;3PiP03010D4021ZH409b/Q00<09b/Q1@21ZH4905MWC`03086YP@1YOel0JGmO
00l0JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V
01H0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00A06IkE003086YP@1KK4T0Ffa9
00d0Ffa900<0PJV104QD>`18E3/00P18E3/5086YP@<092LM00<0PJV10;3PiP2`h>H0V`2`h>H10?oo
o`00W02`h>H00`0@5100PJV102L[8@04086YP@0303Po=021ZH40EfM?00/0EfM?00<0PJV106UoG`1Y
Oel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X01L0MY5X00<0PJV107J@IP1f
T6H05P1fT6H00`21ZH40LHUP0769H00E0769H003086YP@1VNe@0IW]D0140IW]D00<0PJV105]/B@1K
K4T03P1KK4T00`21ZH40B5@k04QD>`0504QD>`80PJV10`0T9ad00`21ZH40/>3V0;3PiP2J0;3PiP40
oooo002K0;3PiP04010D4021ZH40PJV1086YP@D0>3ld00<0PJV105MWC`1GIdl02@1GIdl00`21ZH40
JGmO06UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40
MY1V07J@IP0G07J@IP03086YP@1aRF00LHUP01D0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40
Ffa905]/B@0=05]/B@03086YP@18E3/0B5@k00L0B5@k0P21ZH400`0T9ad0PJV10;3PiP2K0;3PiP40
oooo002J0;3PiP03010D4021ZH40>3ld00H0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO
06UoG`0?06UoG`03086YP@1bS6H0LXaV01@0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40MY1V
07J@IP0H07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40Ffa9
05]/B@0>05]/B@03086YP@18E3/0B5@k00H0B5@k00<0PJV102/^8`21ZH400P21ZH6K0;3PiP40oooo
002I0;3PiP<0PJV11`0h?c@00`21ZH40EfM?05MWC`0905MWC`03086YP@1YOel0JGmO0100JGmO00<0
PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0
PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900d0Ffa900<0
PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02086YPIX0/>3V0@3oool009P0/>3V00<0PJV1
01TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV1
07:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0PJV1
0769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV1
04QD>`18E3/01P18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V09L0/>3V0@3oool0
09L0/>3V00@0PJV101TN6@0I7QT0PJV11P0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109T0/>3V0@3o
ool009L0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0
Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109P0/>3V0@3o
ool009H0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0
/>3V09D0/>3V0@3oool009D0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C
06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[
;R<0PJV109L0/>3V0@3oool009D0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00D
06IkE003086YP@1KK4T0Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02
02/^8`03086YP@2`h>H0/>3V09@0/>3V0@3oool009@0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@0
0`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H03`1bS6I9
086YP@`0LHUP00<0PJV106IkE01VNe@04`1VNe@00`21ZH40Ffa905]/B@0>05]/B@03086YP@18E3/0
B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP03086YP@0I7QT0PJV100L0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO06UoG`0A06Uo
G`03086YP@1bS6H0LXaV00@0LXaV3021ZH45086PMP03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108>S
M@23XgD06@23XgD00`21ZH40OYe_07jMK`0:07jMKaP0PJV12`1VNe@00`21ZH40Ffa905]/B@0=05]/
B@03086YP@18E3/0B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3P
iP40oooo002C0;3PiP04086YP@0I7QT06AhI086YP@H0>3ld00<0PJV105MWC`1GIdl02`1GIdl00`21
ZH40JGmO06UoG`0706UoGa40PJV14@21X7H00`21ZH40Q:Ah08BTN00H08BTN003086YP@23XgD0Pj=e
01T0Pj=e00<0PJV107jMK`1nWFl05P1nWFl00`21ZH40MI5T07FAI00907FAI100PJV1301KK4T00`21
ZH40B5@k04QD>`0704QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3PiP2`h>H0TP2`h>H10?oo
o`00TP2`h>H01021ZH406AhI01TN6@21ZH4703Po=003086YP@1GIdl0EfM?00P0EfM?3@21ZH4:07VF
L003086YP@21X7H0PJ1f01D0PJ1f00<0PJV108BTN024Y7P06024Y7P00`21ZH40Pj=e08>SM@0I08>S
M@03086YP@1nWFl0OYe_01H0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0206El
D`T0PJV10`1KK4T00`21ZH40B5@k04QD>`0804QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3P
iP2`h>H0T@2`h>H10?ooo`00TP2`h>H00`21ZH406AhI086YP@0703Po=003086YP@1GIdl0EfM?00@0
EfM?1@21ZH4206R0H`03086YP@1iUW00NII`0140NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40
Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40
MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00X0IGaC1P21ZH4804QD>`03086YP@0[;R<0:bhS00<0
:bhS00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00T@2`h>H01021ZH406AhI01TN6@21ZH4703Po=003
086YP@1GIdl0PJV100@0PJV11P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0
PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01L0
OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0PJV100<0
PJV11@18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V0900/>3V0@3oool00900/>3V
00@0PJV101TN6@0I7QT0PJV11@0h?c@5086YP@/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40
PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40
OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40
E6E505AUA@0205AUA@@0PJV100<0B5@k086YP@0[;R<0100[;R<00`21ZH40/>3V0;3PiP2?0;3PiP40
oooo002@0;3PiP03086YP@0I7QT06AhI0080>3ld1021ZH4204]KB@03086YP@1XP6<0J81S00/0J81S
00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T
00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0605AUA@@0PJV1100[;R<00`21ZH40/>3V
0;3PiP2>0;3PiP40oooo002?0;3PiP03086YP@0I7QT06AhI00<0PJV11@1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40MI5T07FA
I00E07FAI003086YP@1UO5<0IGaC00h0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]086Y
P@04086YPI00/>3V0@3oool008l0/>3V00@06AhI086YP@21ZH40PJV11`1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FA
I00D07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0
;@0203M0;@80PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@0302@/9`21ZH40Be]900L0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2f?0;3PiP40oooo002>0;3PiP04086YP@0T;2L092`W086YP@L0Be]900<0PJV1
06R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV1
03M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3PiP04086YP@0T;2L092`W
086YP@P0Be]900<0PJV106R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0
PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0
OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0
E6E500P0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3P
iP04086YP@0T;2L092`W086YP@L0Be]900<0PJV106R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B
07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J
08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?
06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2;
0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1XP6<0301XP6<0
0`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P0
0`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV107FAI01eTF@05@1eTF@0
0`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d0
0`21ZH40/>3V0;3PiP2;0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00C07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002;0;3PiP05086YP@0T;2L092`W
02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0306R0H`030?mo001XP6<0J81S00D0J81S00<0ogl0
086YP@1iUW004`1iUW000`21ZH40PJ1f086PMP0G086PMP03086YP@24Y7P0Q:Ah01X0Q:Ah00<0PJV1
08>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0H07jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV1
06ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV1
0;3PiP2`h>H0RP2`h>H10?ooo`00R`2`h>H01021ZH4092`W02@/9`21ZH4604]KB@030?mo001;FdT0
PJV100<0J81S1@3oO`0406R0H`<0ogl0501iUW000`21ZH40PJ1f086PMP0G086PMP03086YP@24Y7P0
Q:Ah01X0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0H07jMK`03086YP@1eTF@0
MI5T01D0MI5T00<0PJV106ElD`1UO5<0401UO5<00`21ZH40E6E505AUA@0805AUA@03086YP@0g@2d0
=d0]00@0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H01@21ZH4092`W02@/9`0T;2L0
PJV10080Be]90P3oO`001P1;FdT0ogl00?mo003oO`00PJV106R0H`P0ogl00P1XP6<50?mo01<0NII`
00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BTN00K08BTN003086YP@23XgD0Pj=e01X0Pj=e
00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00F07FAI003086YP@1UO5<0IGaC00l0IGaC
00<0PJV105AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08T0/>3V
0@3oool008X0/>3V00@0PJV102@/9`0T;2L0ogl00P1;FdT60?mo0003086YP@1XP6<0ogl000<0ogl0
0P1XP6<20?mo00@0J81S0`3oO`0D07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P0
6`24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01T0OYe_00<0PJV107FAI01eTF@0
5@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d0
0`0g@2d00`21ZH40/>3V0;3PiP290;3PiP40oooo00280;3PiP030?mo002`h>H0PJV100/0ogl000@0
PJV106R0H`3oO`00ogl0101XP6<30?mo00@0J81S00<0ogl007VFL01iUW004P1iUW000`21ZH40PJ1f
086PMP0G086PMP03086YP@24Y7P0Q:Ah00d0Q:Ah7@21ZH4>08>SM@03086YP@1nWFl0OYe_01T0OYe_
00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0@06ElD`03086YP@1DIDD0E6E500P0E6E5
00<0PJV103M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP280;3PiP40oooo00270;3PiPL0ogl000<0
Be]90?mo003oO`000P1;FdT30?mo0080J81S00<0ogl006R0H`1XP6<00P1XP6<30?mo00D0J81S00<0
PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0;086PMQ`0PJV13P2>]8@00`21ZH40SK:108fb
P@0<08fbPCL0PJV1301eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500T0E6E500<0
PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP280;3PiP40oooo00260;3PiP<0ogl000<0PJV1
0?mo003oO`00103oO`0304]KB@<0ogl00P1XP6<00`3oO`00J81S06R0H`0206R0H`80ogl01@1XP6<0
0`21ZH40NII`07VFL00907VFL1P0PJV1302</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06@29[G/00`21ZH40PJ9a086RL@0:086RLA40PJV13@1UO5<0
0`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0=d0]00@0=d0]00<0PJV10;3PiP2`h>H0Q`2`h>H1
0?ooo`00QP2`h>H:0?mo00<0Be]90`3oO`0706R0H`80ogl00P1XP6<?086YP@X0QJQn00<0PJV108ba
P`2</H<05`2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV108V]
N`29[G/06@29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0080LXmQ2P21ZH4406El
D`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP270;3P
iP40oooo00250;3PiPX0ogl0101;FdT20?mo00@0J81S0P21ZH440?mo0080PJV100@0MiEc0?mo003o
O`00PJV15@25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV108fb
P@2=/X406P2=/X400`21ZH40RJek08V]N`0I08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?
H@1bSf40301bSf48086YP@P0E6E500<0PJV103M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP260;3P
iP40oooo00250;3PiP<0ogl000<092`W0?mo003oO`00103oO`0304]KB@<0ogl00`21ZH460?mo00@0
MiEc0P3oO`000`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV108jdQ02>
]8@06`2>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21
XW405@21XW400`21ZH40LXmQ07:?H@0@07:?H@04086YP@1MLdd0GG==05ecC@H0PJV10`1DIDD00`21
ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08H0/>3V0@3oool008D0/>3V2P3oO`03086YP@80
ogl000<0PJV107NEL`1gUG<01@3oO`0607NEL`80ogl05@25Z7h00`21ZH40S;6308baP`0H08baP`03
086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03
086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf403`1bSf400`21ZH40GG==05ecC@0705ecC@L0
PJV10`0g@2d00`21ZH40/>3V0;3PiP250;3PiP40oooo00250;3PiPX0ogl00`1KLU/20?mo0080MiEc
0`3oO`0907NEL`80ogl05@25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B4
00<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a
00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0905ecC@04086YP@11CSH0@Dhf045>=P@0
PJV1Q`2`h>H10?ooo`00Q02`h>H80?mo000305]bF`3oO`00ogl000<0Fg9K0P3oO`00101gUG<0ogl0
0?mo003oO`0507NEL`030?mo001gUG<0MiEc0080MiEc0P3oO`0E08FXOP03086YP@2</H<0S;6301L0
S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek01X0
RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00T0
GG==00<0PJV1045>=P11CSH01011CSH2086YPHH0/>3V0@3oool008@0/>3V1@3oO`000`21ZH40ogl0
0?mo00020?mo00<0Fg9K1P3oO`0507NEL`<0ogl00P1gUG<20?mo0003086YP@25Z7h0QJQn01<0QJQn
00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:101X0SK:1
00<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0100LXmQ
00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P03045>=P80PJV1QP2`h>H10?ooo`00Q02`
h>H50?mo0003086YP@3oO`00ogl00080ogl00`1KLU/20?mo0003086YP@3oO`00ogl000D0MiEc0`3o
O`0307NEL`80ogl000<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>
]8@0S[B401`0S[B400<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21
XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11
CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q02`h>H:0?mo00<0Fg9K0P3oO`00
0`1gUG<0ogl00?mo00020?mo000307NEL`3oO`00ogl00080ogl0101gUG<20?mo0003086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P03086YP@2`h>H0
/>3V08@0/>3V0@3oool008<0/>3V1@3oO`00100^>3<0ogl00?mo001KLU/20?mo00<0Fg9K0P3oO`00
0`1gUG<0ogl00?mo00060?mo00D0MiEc0P3oO`0F08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0K08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00T0GG==00<0PJV1
045>=P11CSH01011CSH2086YPHD0/>3V0@3oool00880/>3V1P3oO`001021ZH40ogl00?mo001KLU/2
0?mo0080Fg9K0`3oO`0307NEL`@0ogl01`1gUG<20?mo01D0QJQn00<0PJV108baP`2</H<0602</H<0
0`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/0
0`21ZH40PJ9a086RL@0E086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV105ecC@1MLdd02@1MLdd0
0`21ZH40@Dhf045>=P04045>=P80PJV1Q@2`h>H10?ooo`00PP2`h>H;0?mo00@0Fg9K00<0ogl0086Y
P@1gUG<03@1gUG<20?mo01D0QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jd
Q003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086R
L@03086YP@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P03045>
=P80PJV1Q@2`h>H10?ooo`00PP2`h>H50?mo000402hh<`21ZH40ogl005]bF`80ogl0101KLU/00`21
ZH40MiEc07NEL`0<07NEL`80ogl000<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0H08ba
P`03086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=/X40702=/X400`21ZH40RJek08V]N`0J08V]
N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ec
C@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00P@2`h>H50?mo0080
;SPc00<0PJV105]bF`1KLU/01P1KLU/00`21ZH40MiEc07NEL`0<07NEL`80ogl000<0PJV108FXOP25
Z7h04`25Z7h00`21ZH40S;6308baP`0H08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV108fbP@2=
/X40702=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1b
Sf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`
h>H0P`2`h>H10?ooo`00P@2`h>H30?mo0004086YP@0^>3<0;SPc086YP@T0Fg9K00<0PJV107NEL`1g
UG<0301gUG<20?mo01H0QJQn00<0PJV108baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jdQ003
086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03
086YP@1bSf40LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P80
PJV1Q02`h>H10?ooo`00PP2`h>H00`3oO`00PJV102hh<`0202hh<`03086YP@1KLU/0Fg9K00L0Fg9K
00<0PJV107NEL`1gUG<0301gUG<20?mo01H0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B4
08jdQ00L08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a
086RL@0F086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV105ecC@1MLdd02@1MLdd00`21ZH40@Dhf
045>=P04045>=P80PJV1Q02`h>H10?ooo`00PP2`h>H00`3oO`00PJV102hh<`0202hh<`03086YP@1K
LU/0Fg9K00H0Fg9K00<0PJV107NEL`1gUG<03@1gUG<20?mo01H0QJQn00<0PJV108baP`2</H<05`2<
/H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV108V]N`29[G/06P29
[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV105ecC@1MLdd02P1M
Ldd00`21ZH40@Dhf045>=P03045>=P80PJV1Q02`h>H10?ooo`00PP2`h>H0103oO`00PJV102hh<`0^
>3<20?mo00P0Fg9K00<0PJV107NEL`1gUG<0301gUG<20?mo0003086YP@25Z7h0QJQn01@0QJQn00<0
PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:101`0SK:100<0
PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0140LXmQ00<0
PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P03086YP@2`h>H0/>3V0880/>3V0@3o
ool00840/>3V0P3oO`000`21ZH40;SPc02hh<`020?mo00P0Fg9K00<0PJV107NEL`1gUG<03P1gUG<0
0`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jdQ02>]8@0702>]8@0
0`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01/0RJek00<0PJV1086RL@21XW405P21XW40
0`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH01011CSH2
086YPH<0/>3V0@3oool00840/>3V00<0ogl0086YP@0^>3<00P0^>3<20?mo00P0Fg9K00<0PJV107NE
L`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jd
Q02>]8@0702>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01/0RJek00<0PJV1086R
L@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>
=P11CSH01011CSH2086YPH<0/>3V0@3oool00840/>3V00<0ogl0086YP@0^>3<00P0^>3<20?mo00L0
Fg9K00<0PJV107NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0S;6300/0
S;63FP21ZH4?08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf404@1bSf400`21ZH40
GG==05ecC@0905ecC@03086YP@11CSH0@Dhf00@0@Dhf0P21ZH630;3PiP40oooo00210;3PiP030?mo
0021ZH40;SPc0080;SPc00<0PJV105]bF`1KLU/01P1KLU/00`21ZH40MiEc07NEL`0>07NEL`03086Y
P@25Z7h0QJQn00T0QJQn6@21ZH4=09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0
702F_h/00`21ZH40T[Z509:jQ@0<09:jQC80PJV12P1bSf400`21ZH40GG==05ecC@0:05ecC@03086Y
P@11CSH0@Dhf00<0@Dhf0P21ZH630;3PiP40oooo00220;3PiP<0;SPc00<0PJV105]bF`1KLU/00`1K
LU/Q086YP@/0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F
_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1l
WVd0O9i]00L0O9i]4@21ZH4605ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0P@2`
h>H10?ooo`00P@2`h>H00`21ZH40;SPc02hh<`07086YP@@0J8AZ00<0PJV108:VO`22YWl03P22YWl0
0`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d0
0`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`0
0`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00@0IGmD2P21ZH43045>=P80PJV1PP2`h>H1
0?ooo`00P@2`h>H3086YP@0303]<@P21ZH40J8AZ00P0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21
ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21
ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21
ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00@0PJV104MJ?017FS`0AeXl1@21ZH62
0;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>
08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L
09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F
08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?004
04MJ?080PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV1
08:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV1
09O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV1
08Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV1
04MJ?017FS`01017FS`00`21ZH407B@J0;3PiP210;3PiP40oooo00210;3PiP05086YP@0kC480>da2
03]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV1
09FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV1
09:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV1
06EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?003086YP@0M91X0/>3V0840/>3V0@3oool0
0840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV1
08nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV1
09JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV1
07bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl00<0PJV1
01dT6P2`h>H0P@2`h>H10?ooo`00P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV1
08:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV1
09O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV1
08Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV1
04MJ?017FS`00`17FS`00`21ZH407B@J0;3PiP210;3PiP40oooo00210;3PiP05086YP@0kC480>da2
03]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV1
09FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV1
09:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV1
06EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P@2`h>H01@21
ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D
08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L
09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A
07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool0
0840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV1
08nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV1
09JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV1
07bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH61
0;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH40201XQ6X00`21ZH40PZIo08:VO`0>
08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L
09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F
08Z`O003086YP@1lWVd0O9i]0100O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?004
04MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV1
08:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV1
09O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV1
08Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV1
04MJ?017FS`01017FS`2086YPH40/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@09
06R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I
09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K
09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:
06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da2
03]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV1
09FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV1
09:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV1
06EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21
ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D
08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M
09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A
07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool0
0800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV1
08nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV1
09JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV1
07bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH61
0;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>
08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L
09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F
08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?003
04MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV1
08:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV1
09O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV1
08Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV1
04MJ?017FS`01017FS`2086YPH00/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@09
06R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I
09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K
09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;
06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH600;3PiP40oooo00200;3PiP05086YP@0kC480>da2
03]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV1
09FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV1
09:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV1
06EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00P02`h>H01@21
ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D
08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M
09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A
07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH00/>3V0@3oool0
0800/>3Vl`21ZH600;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21
ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21
ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21
ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21
ZH40C69104aR@@0404aR@@80PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV1
00T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF
01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>
01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO
00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH00/>3V0@3oool00800/>3V00D0PJV104ELC`15
G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21
ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21
ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21
ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH600;3PiP40oooo00200;3PiP05
086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C
01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC
01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g
0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P02`h>H10?oo
o`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21
ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21
ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21
ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT400`1<HT400`21
ZH408RdN0;3PiP200;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21
ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21
ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21
ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21
ZH40C69104aR@@0404aR@@03086YP@0R;Ah0/>3V0800/>3V0@3oool00800/>3V00D0PJV104ELC`15
G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21
ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21
ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21
ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00200;3PiP05
086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C
01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC
01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g
0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?oo
o`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21
ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21
ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21
ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086Y
PH40/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:
00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F
01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^5
01H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C691
00@0C6910P21ZH610;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21
ZH40R[>:08ZcRP0=08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21
ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21
ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0100Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21
ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV1
00T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF
01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>
01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO
00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00840/>3V00D0PJV104ELC`15
G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21
ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21
ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21
ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00210;3PiP05
086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C
01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC
01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g
0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?oo
o`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21
ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21
ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21
ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT400`1<HT42086Y
PH80/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:
00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F
01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^5
01H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C691
00@0C6910P21ZH620;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21
ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21
ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21
ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21
ZH40C69104aR@@0404aR@@80PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV1
00T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF
01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>
01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO
00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH80/>3V0@3oool00840/>3V00D0PJV104ELC`15
G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21
ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21
ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21
ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH620;3PiP40oooo00210;3PiP80
PJV10P15G4l00`21ZH40LI=f076CMP07076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F
`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2L
bI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24
ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`04086YP@1<HT40C69104aR@@D0PJV1PP2`h>H10?oo
o`00P@2`h>H00`21ZH40CFQI086YP@0D086YP@P0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40
W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40
V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40
KXeO06j=G`0406j=G`X0PJV10`1>J4<2086YPH80/>3V0@3oool00880/>3V00@0PJV104eXF@1=J5T0
PJV12@1hWWh00`21ZH40T;fB092mTP06092mTQ@0PJV12`2F`Y<00`21ZH40W<VF09c9UP0H09c9UP03
086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03
086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL02024ZgL@086YP@H0M9QX00<0PJV104iX@`1>
J4<0101>J4<00`21ZH40/>3V0;3PiP210;3PiP40oooo00220;3PiP05086YP@1=J5T0CFQI04eXF@21
ZH40201hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ00T0W<bJ6@21ZH4=09c9UP03
086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0=09S4SS80
PJV12@2:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300<0CVQ300<0PJV102@c8P2`
h>H0PP2`h>H10?ooo`00PP2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@
_I803@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M00/0XM:MF`21ZH4>09g=U003
086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003
086YP@1>J4<0CVQ300@0CVQ30P21ZH630;3PiP40oooo00220;3PiP05086YP@1=J5T0CFQI04eXF@21
ZH402@1hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2Q
dYd0602QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02M
cI@06`2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01d
V6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`80PJV1P`2`h>H10?ooo`00P`2`h>H01021ZH40CFQI
04eXF@21ZH4907RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40
XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40
WLfD09g=U00K09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40
M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH630;3PiP40oooo00230;3PiP05086Y
P@1=J5T0CFQI04eXF@21ZH40201hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01@0
W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0
XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0140
R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V0880
/>3V0@3oool008<0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0
T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0
X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0
UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300<0
CVQ30P21ZH640;3PiP40oooo00230;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40
T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40
X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40
UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40
CVQ304iX@`0404iX@`80PJV1Q02`h>H10?ooo`00Q02`h>H01021ZH40CFQI04eXF@21ZH4907RNOP03
086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03
086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003
086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003
086YP@1>J4<0CVQ300@0CVQ30P21ZH640;3PiP40oooo00240;3PiP05086YP@1=J5T0CFQI04eXF@21
ZH40201hWWh00`21ZH40T;fB092mTP0>092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2Q
dYd0602QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02M
cI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01d
V6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@2`h>H0/>3V08<0/>3V0@3oool008@0/>3V
00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2L
c9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2Q
dIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:
]7l0402:]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`
h>H0P`2`h>H10?ooo`00Q02`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@
_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02R
di`06`2Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02G
a8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>
J4<00`1>J4<2086YPHD0/>3V0@3oool008D0/>3V00@0PJV104eXF@1=J5T0PJV12@1hWWh00`21ZH40
T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40
X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40
UlB<09O4S00E09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1dV6P00`21ZH40
CVQ304iX@`0404iX@`80PJV1Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100P0
N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01L0
XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0K0:7AV@03086YP@2McI@0WLfD01X0
WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0
M9QX00<0PJV104iX@`1>J4<0101>J4<2086YPHD0/>3V0@3oool008D0/>3V00D0PJV104eXF@1=J5T0
CFQI086YP@0907RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40
XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40
WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40
M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00
Q@2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40
W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40
XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40
R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40
00000;3PiP240;3PiP40oooo00260;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0PJV1092mTP2@
_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02R
di`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02G
a8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>
J4<00`1>J4<01021ZH4000000000000000240;3PiP40oooo00260;3PiP80PJV10P1=J5T00`21ZH40
N9in07RNOP0607RNOP03086YP@2@_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40
XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40
WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40
M9QX07BHJ00907BHJ003086YP@1>J4<0CVQ300@0CVQ30`0000250;3PiP40oooo00260;3PiP03086Y
P@1ALF00PJV100@0PJV11`1hWWh00`21ZH40T;fB092mTP0<092mTP03086YP@2Lc9X0W<bJ01<0W<bJ
00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIT0XM6I01X0XM6I
00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao
00<0PJV107BHJ01dV6P02@1dV6P01021ZH40000004iX@`000004086YP@800000Q@2`h>H10?ooo`00
Q`2`h>H01021ZH40DG5P055aH021ZH4207^VQ0D0PJV10P1hWWh00`21ZH40T;fB092mTP0<092mTP03
086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L0:;CW00K0:;CW003
086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003
086YP@2:]7l0R[Ao00l0R[Ao00<0PJV107BHJ01dV6P01`1dV6P4086YP@0300000021ZH40000000<0
Dg5;0`0000250;3PiP40oooo00270;3PiP05086YP@1ALF00DG5P055aH021ZH401P1kYX@6086YP@`0
T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01/0
X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01D0
UlB<00<0PJV108ZdO`2:]7l0402:]7l01021ZH40M9QX07BHJ01dV6P6086YP@<0N:1_1000000205=a
B`<00000QP2`h>H10?ooo`00R02`h>H01021ZH40DG5P055aH021ZH4807^VQ004086YP@2Ca9P0TlBH
09?4V0P0PJV1102@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV1
0:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01T0WLfD00<0PJV1
09O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0<08ZdO`L0PJV10P00000707RPK`80000000@0Dg5;
0000001CLD/0Dg5;100000260;3PiP40oooo00280;3PiP05086YP@1ALF00DG5P055aH021ZH40201k
YX@00`21ZH40TlBH09?4V00809?4V0l0PJV12`2Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2R
di`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00I09g=U003086YP@2G
a8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l00P2:]7l:086YP@@0S[b500@0PJV107RPK`0000000000
201hX6l010000000Dg5;00000000000205=aB`<00000Q`2`h>H10?ooo`00R@2`h>H01021ZH40DG5P
055aH021ZH4807^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ00202OdZ0H086YP@d0
XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01T0
WLfD00<0PJV109O4S02Ga8`02P2Ga8`A086YP@d0S[b500<0PJV107RPK`1hX6l00P00000707RPK`80
000000<0Dg5;0000001CLD/00P1CLD/3000008L0/>3V0@3oool008T0/>3V00D0PJV1055aH01ALF00
DG5P086YP@0707^VQ003086YP@2Ca9P0TlBH00d0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40
YMVS0:GIX`0:0:GIXa`0PJV13`2Rdi`00`21ZH40XM6I0:7AV@0<0:7AVCL0PJV1302Jbi800`21ZH40
S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_008000001`1hX6l010000000Dg5;00000000000205=a
B`@00000Q`2`h>H10?ooo`00RP2`h>H01021ZH40DG5P055aH021ZH4807^VQ003086YP@2Ca9P0TlBH
00`0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR
00`0Y]ZR7P21ZH4>0:GHW`03086YP@2Qe9X0XMBJ01T0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21
ZH40S[b508jlQ@0@08jlQ@03086YP@1hX6l0N:1_008000001P1hX6l20000000305=aB`000000Dg5;
0080Dg5;0`0000280;3PiP40oooo002:0;3PiP04086YP@1ALF00DG5P086YP@P0NjJ400<0PJV109?4
V02Ca9P0302Ca9P00`21ZH40Wm:P09oBX00C09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJ
XP2VfZ806`2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ01T0XMBJ00<0PJV109[;
TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0?08jlQ@04086YP@1hX6l0N:1_07RPK`8000001@1hX6l2
00000080Dg5;00<0000005=aB`1CLD/00`0000290;3PiP40oooo002:0;3PiP05086YP@1ALF00DG5P
055aH021ZH40201kYX@00`21ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P01<0Wm:P00<0PJV1
0:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0K0:KJXP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV1
0:7DVP2Qe9X0602Qe9X00`21ZH40V/^B09[;TP0F09[;TP03086YP@2>_8D0S[b500l0S[b500@0PJV1
07RPK`1hX6l0N:1_2@0000000`1CLD/000000000000205=aB`<00000R@2`h>H10?ooo`00R`2`h>H0
1021ZH40DG5P055aH021ZH4807^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ004P2O
dZ000`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:GHW`2Uf9l06P2U
f9l00`21ZH40XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B01D0V/^B00<0PJV108jlQ@2>_8D0402>
_8D01021ZH40N:1_07RPK`1hX6l800000080Dg5;0`000000101CLD/000000000000000290;3PiP40
oooo002;0;3PiP05086YP@1ALF00DG5P055aH021ZH401`1kYX@00`21ZH40TlBH09?4V00<09?4V003
086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03
086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21ZH40V/^B09[;TP0E09[;TP03
086YP@2>_8D0S[b500l0S[b500<0PJV107RPK`1hX6l00P1hX6l2000000@0N:1_00<00000086YP@1C
LD/00`0000000`1CLD/0000000000002000008T0/>3V0@3oool008`0/>3V00@0PJV1055aH01ALF00
PJV1201kYX@00`21ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P01<0Wm:P00<0PJV10:GIX`2U
fJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Q
e9X0602Qe9X00`21ZH40V/^B09[;TP0E09[;TP03086YP@2>_8D0S[b500l0S[b500@0PJV107RPK`1h
X6l0N:1_0P00000407RPK`80000000<0Dg5;0000000000000P0000000`1CLD/00000000000020000
08T0/>3V0@3oool008`0/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00<09?4
V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJ
XP03086YP@2Uf9l0YMRO01X0YMRO00<0PJV10:7DVP2Qe9X0602Qe9X00`21ZH40V/^B09[;TP0E09[;
TP03086YP@2>_8D0S[b500h0S[b500<0PJV107RPK`1hX6l00P1hX6l2000000@0N:1_00<00000086Y
P@1CLD/02000002:0;3PiP40oooo002=0;3PiP04086YP@1ALF00DG5P086YP@L0NjJ400<0PJV109?4
V02Ca9P0302Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJ
XP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;
TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_0080N:1_0P00000307RP
K`80000000<0PJV105=aB`0000000P000000101CLD/0000000000000002;0;3PiP40oooo002=0;3P
iP04086YP@1ALF00DG5P086YP@P0NjJ400<0PJV109?4V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00B
09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J
0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0?
08jlQ@03086YP@1hX6l0N:1_0080N:1_0P00000207RPK`80000000<0PJV105=aB`1CLD/010000000
0`2`h>H000000;3PiP2;0;3PiP40oooo002>0;3PiP04086YP@1ALF00DG5P086YP@L0NjJ400<0PJV1
09?4V02Ca9P0302Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01D0YMVS00<0PJV1
0:KJXP2VfZ806P2VfZ800`21ZH40YMRO0:GHW`0J0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV1
09[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0>08jlQ@03086YP@1hX6l0N:1_00<0N:1_0P000002
07RPK`040000001hX6l0PJV105=aB`L00000S02`h>H10?ooo`00SP2`h>H01021ZH40DG5P055aH021
ZH4807^VQ003086YP@2Ca9P0TlBH00/0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GI
X`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7D
VP0H0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RP
K`0307RPK`80000000@0N:1_000000000000PJV10`1CLD/01@000000Dg5;086YP@2`h>H0000008d0
/>3V0@3oool008l0/>3V0P21ZH400`1ALF00PJV107^VQ00607^VQ003086YP@2Ca9P0TlBH00/0TlBH
00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR
00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0H0:7DVP03086YP@2Jbi80V/^B01@0V/^B
00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0207RPK`80000000D0N:1_000000000000
N:1_086YP@0405=aB`80PJV100<0/>3V0000002`h>H0S02`h>H10?ooo`00S`2`h>H00`21ZH40DgES
086YP@03086YP@D0NjJ400<0PJV109?4V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086Y
P@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086Y
P@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi805@2Jbi800`21ZH40S[b508jlQ@0>08jlQ@03086Y
P@1hX6l0N:1_00<0N:1_100000000`1hX6l0PJV105=aB`04086YP@0305AfD02`h>H0/>3V08h0/>3V
0@3oool00900/>3V00D0PJV105=eH`1CMF<0PJV107^XQP04086YP@80NjJ400<0PJV109?4V02Ca9P0
2`2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01D0YMVS00<0PJV10:KJXP2VfZ80
6@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi80
502Jbi800`21ZH40S[b508jlQ@0?08jlQ@03086YP@1hX6l0N:1_00<0N:1_0`000000101hX6l0PJV1
086YP@21ZH4405AfD003086YP@2`h>H0/>3V08h0/>3V0@3oool00900/>3V00@0PJV105=eH`1CMF<0
PJV11@1kZ8H5086YP@/0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0E0:GIX`03
086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ0:7DVP0G0:7DVP03
086YP@2Jbi80V/^B01@0V/^B00<0PJV108jlQ@2>_8D03`2>_8D00`21ZH40N:1_07RPK`0307RPK`<0
00000P21ZH4505AfD003086YP@2`h>H0/>3V08l0/>3V0@3oool00940/>3V00@0PJV105=eH`1CMF<0
PJV11`1kZ8H00`21ZH40U<NK086YP@04086YP@H0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40
YMVS0:GIX`0E0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40
XMBJ0:7DVP0G0:7DVP03086YP@2Jbi80V/^B01@0V/^B00<0PJV108jlQ@2>_8D03P2>_8D00`21ZH40
N:1_07RPK`04086YP@8000000P1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V0900
/>3V0@3oool00980/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0409C7V`D0PJV1
0P2Ca9P00`21ZH40Wm:P09oBX00A09oBX003086YP@2UfJ<0YMVS01D0YMVS00<0PJV10:KJXP2VfZ80
6@2VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01L0XMBJ00<0PJV109[;TP2Jbi80
502Jbi800`21ZH40S[b508jlQ@0:08jlQ@L0PJV1101iY7<20000000307VTL`21ZH40E7I@00@0E7I@
00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00TP2`h>H01021ZH40DgES05=eH`21ZH4707^XQP03086Y
P@2Dai/0U<NK00P0U<NK3@21ZH4:09oBX003086YP@2UfJ<0YMVS01D0YMVS00<0PJV10:KJXP2VfZ80
602VfZ800`21ZH40YMRO0:GHW`0I0:GHW`03086YP@2Qe9X0XMBJ01H0XMBJ00<0PJV109[;TP2Jbi80
502Jbi800`21ZH40S[b508jlQ@0208jlQ@T0PJV10`2?_hT00`21ZH40NJAc07VTL`0407VTL`800000
0P1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V0940/>3V0@3oool009<0/>3V00@0
PJV105=eH`1CMF<0PJV11P1kZ8H00`21ZH40U<NK09C7V`0;09C7V`03086YP@2QeZ@0XMJT00L0XMJT
4021ZH4B0:GIX`03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l00`21ZH40XMBJ
0:7DVP0F0:7DVP03086YP@2Jbi80V/^B00T0V/^B4021ZH4<08noR@03086YP@1iY7<0NJAc00L0NJAc
00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2B0;3PiP40oooo002D0;3PiP03086YP@1C
MF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00A0:7FY003086YP@2V
gJL0Y]fW00<0Y]fW3021ZH460:GIX`03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GHW`2Uf9l06@2U
f9l00`21ZH40XMBJ0:7DVP0:0:7DVQP0PJV12`2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1i
Y7<0NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D
0;3PiP04086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7F
Y00A0:7FY003086YP@2VgJL0Y]fW00h0Y]fWBP21ZH4<0:?IWP03086YP@2Ld9H0W=2F01<0W=2F00<0
PJV108noR@2?_hT03P2?_hT00`21ZH40NJAc07VTL`0707VTL`03086YP@1DMU00E7I@0080E7I@00<0
PJV10;3PiP2`h>H0T`2`h>H10?ooo`00U@2`h>H00`21ZH40DgES086YP@0707^XQP03086YP@2Dai/0
U<NK00X0U<NK00<0PJV10:7FY02QeZ@04@2QeZ@00`21ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0
Z=nV01P0Z=nV00<0PJV10:OMX`2WgJ<06@2WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0
W=2F01@0W=2F00<0PJV108noR@2?_hT03@2?_hT00`21ZH40NJAc07VTL`0707VTL`03086YP@1DMU00
E7I@0080E7I@00<0PJV10;3PiP2`h>H0U02`h>H10?ooo`00U@2`h>H01021ZH40DgES05=eH`21ZH47
07^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@0402QeZ@00`21ZH40Y]fW0:KMY`0D
0:KMY`03086YP@2XgjH0Z=nV01P0Z=nV00<0PJV10:OMX`2WgJ<06@2WgJ<00`21ZH40XmVN0:?IWP0E
0:?IWP03086YP@2Ld9H0W=2F01<0W=2F00<0PJV108noR@2?_hT03P2?_hT00`21ZH40NJAc07VTL`07
07VTL`05086YP@1DMU00E7I@05AfD021ZH40U`2`h>H10?ooo`00UP2`h>H00`21ZH40DgES086YP@07
07^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@04@2QeZ@00`21ZH40Y]fW0:KMY`0D
0:KMY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<00`21ZH40XmVN0:?IWP0F
0:?IWP03086YP@2Ld9H0W=2F01<0W=2F00<0PJV108noR@2?_hT03@2?_hT00`21ZH40NJAc07VTL`07
07VTL`03086YP@1DMU00E7I@0080E7I@00<0PJV10;3PiP2`h>H0U@2`h>H10?ooo`00U`2`h>H00`21
ZH40DgES086YP@0707^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@0402QeZ@00`21
ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<00`21
ZH40XmVN0:?IWP0F0:?IWP03086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT03P2?_hT00`21
ZH40NJAc07VTL`0707VTL`05086YP@1DMU00E7I@05AfD021ZH40V02`h>H10?ooo`00U`2`h>H01021
ZH40DgES05=eH`21ZH4607^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@0402QeZ@0
0`21ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<0
0`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F01<0W=2F00<0PJV108noR@2?_hT03@2?_hT0
0`21ZH40NJAc07VTL`0707VTL`05086YP@1DMU00E7I@05AfD021ZH40V@2`h>H10?ooo`00V02`h>H0
0`21ZH40DgES086YP@0707^XQP03086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@0402QeZ@0
0`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<0
0`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT03P2?_hT0
0`21ZH40NJAc07VTL`0607VTL`03086YP@1DMU00E7I@0080E7I@00<0PJV10;3PiP2`h>H0U`2`h>H1
0?ooo`00V@2`h>H00`21ZH40DgES086YP@0707^XQP03086YP@2Dai/0U<NK00T0U<NK00<0PJV10:7F
Y02QeZ@0402QeZ@00`21ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OM
X`2WgJ<0602WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F0180W=2F00<0PJV108no
R@2?_hT03@2?_hT00`21ZH40NJAc07VTL`0707VTL`05086YP@1DMU00E7I@05AfD021ZH40VP2`h>H1
0?ooo`00VP2`h>H2086YP@L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00?0:7F
Y003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0H0:OM
X`03086YP@2SfIh0XmVN01@0XmVN00<0PJV109c@UP2Ld9H04P2Ld9H00`21ZH40Skn908noR@0>08no
R@03086YP@1iY7<0NJAc00H0NJAc00<0PJV105AfD01DMU000P21ZH6K0;3PiP40oooo002K0;3PiP@0
PJV11@1kZ8H00`21ZH40U<NK09C7V`0909C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2V
gJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01L0YmfS00<0PJV10:?IWP2S
fIh05@2SfIh00`21ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1i
Y7<01`1iY7<4086YPI`0/>3V0@3oool009`0/>3V0P21ZH400`1fYH@0PJV1086YP@02086YP@0307^X
QP21ZH40U<NK00/0U<NK00<0PJV10:7FY02QeZ@03`2QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086Y
P@2XgjH0Z=nV01L0Z=nV00<0PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086Y
P@2Ld9H0W=2F0140W=2F00<0PJV108noR@2?_hT03P2?_hT00`21ZH40NJAc07VTL`0507VTL`<0PJV1
0P1BMU800`21ZH40/>3V0;3PiP2J0;3PiP40oooo002M0;3PiP80PJV1101fYH@5086YP@T0U<NK00<0
PJV10:7FY02QeZ@03`2QeZ@00`21ZH40Y]fW0:KMY`0D0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0
PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F0140W=2F00<0
PJV108noR@2?_hT03@2?_hT00`21ZH40NJAc07VTL`0207VTL`D0PJV10`1BMU800`21ZH40/>3V0;3P
iP2K0;3PiP40oooo002N0;3PiP80PJV11P1fYH@00`21ZH40T<BI086YP@03086YP@H0U<NK00<0PJV1
0:7FY02QeZ@03`2QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV1
0:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2Ld9H0W=2F0140W=2F00<0PJV1
08noR@2?_hT03P2?_hT5086YP@<0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2N0;3PiP40oooo002N
0;3PiP03086YP@1@M680PJV100H0MZF400<0PJV10934V@2@a9T00P2@a9T5086YP@0309C7V`21ZH40
XMJT0100XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0
YmfS01H0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?_hT0
Skn900T0Skn91P21ZH4607FRL`05086YP@1BMU80DWIB059fDP21ZH40W`2`h>H10?ooo`00W`2`h>H0
0`21ZH40D7AR086YP@0507JUQ003086YP@2@a9T0T<BI00L0T<BI1`21ZH4<0:7FY003086YP@2VgJL0
Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0
XmVN01@0XmVN00<0PJV109c@UP2Ld9H0402Ld9H00`21ZH40Skn908noR@0208noR@P0PJV10`2<_hX0
0`21ZH40MJ9c07FRL`0607FRL`04086YP@1BMU80DWIB086YPJ00/>3V0@3oool00:00/>3V00<0PJV1
051dHP21ZH401@1fYH@00`21ZH40T<BI0934V@090934V@04086YP@2NeZ@0W]JT09kFY0T0PJV1102Q
eZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:OMX`2WgJ<05@2W
gJ<00`21ZH40XmVN0:?IWP0E0:?IWP03086YP@2Ld9H0W=2F00`0W=2F2@21ZH4:08boRP03086YP@1e
XW<0MJ9c00H0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2P0;3PiP40oooo002Q0;3PiP80PJV11P1f
YH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00X0W]JT3`21ZH4;0:KMY`03086YP@2X
gjH0Z=nV01D0Z=nV00<0PJV10:OMX`2WgJ<05@2WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2L
d9H0W=2F00<0W=2F2P21ZH4309[@V003086YP@2<_hX0S;n:00d0S;n:00<0PJV107FRL`1eXW<01@1e
XW<01@21ZH40DWIB059fDP1BMU80PJV10:40/>3V0@3oool00:80/>3V0P21ZH4607JUQ003086YP@2@
a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@03P2NeZ@00`21ZH40YMfX0:GMZ0070:GMZ1L0PJV1302X
gjH00`21ZH40YmfS0:OMX`0E0:OMX`03086YP@2SfIh0XmVN00T0XmVN4@21ZH4=09[@V003086YP@2<
_hX0S;n:00`0S;n:00<0PJV107FRL`1eXW<01@1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:80/>3V
0@3oool00:<0/>3V0P21ZH4607JUQ003086YP@2@a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@03@2N
eZ@00`21ZH40YMfX0:GMZ00B0:GMZ003086YP@2Wh:P0Yn2X00T0Yn2X<021ZH4;0:;JX003086YP@2J
d9P0V]2H00l0V]2H00<0PJV108boRP2<_hX0302<_hX00`21ZH40MJ9c07FRL`0507FRL`05086YP@1B
MU80DWIB059fDP21ZH40X`2`h>H10?ooo`00Y02`h>H2086YP@D0MZF400<0PJV10934V@2@a9T02@2@
a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0180YMfX00<0PJV10:OPZ02Wh:P0502W
h:P00`21ZH40Y]nU0:KOY@0E0:KOY@03086YP@2RfZ00X]ZP01<0X]ZP00<0PJV109[@V02Jd9P0402J
d9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB
086YP@2T0;3PiP40oooo002U0;3PiP80PJV11@1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2N
eZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP04P2UgJP00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2V
gjD0Y]nU01D0Y]nU00<0PJV10:;JX02RfZ004`2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<
_hX0S;n:00/0S;n:00<0PJV107FRL`1eXW<01@1eXW<00`21ZH40DWIB059fDP02059fDP03086YP@2`
h>H0/>3V0:80/>3V0@3oool00:H0/>3V0P21ZH4507JUQ003086YP@2@a9T0T<BI00P0T<BI00<0PJV1
09kFY02NeZ@03@2NeZ@00`21ZH40YMfX0:GMZ00A0:GMZ003086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV1
0:KOY@2VgjD05@2VgjD00`21ZH40X]ZP0:;JX00B0:;JX003086YP@2Jd9P0V]2H0100V]2H00<0PJV1
08boRP2<_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80DWIB059fDP21ZH40Y@2`
h>H10?ooo`00Y`2`h>H2086YP@D0MZF400<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00<
09kFY003086YP@2UgJP0YMfX0140YMfX00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0D
0:KOY@03086YP@2RfZ00X]ZP01<0X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0;
08boRP03086YP@1eXW<0MJ9c00D0MJ9c00<0PJV1059fDP1BMU800P21ZH6V0;3PiP40oooo002Y0;3P
iP80PJV1101fYH@00`21ZH40T<BI0934V@070934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GM
Z02UgJP04@2UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU01@0Y]nU00<0PJV10:;J
X02RfZ004P2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FR
L`1eXW<01@1eXW<5086YPJL0/>3V0@3oool00:X0/>3V0`21ZH4207JUQ003086YP@2@a9T0T<BI00P0
T<BI00<0PJV109kFY02NeZ@03@2NeZ@00`21ZH40YMfX0:GMZ00@0:GMZ003086YP@2Wh:P0Yn2X01<0
Yn2X00<0PJV10:KOY@2VgjD0502VgjD00`21ZH40X]ZP0:;JX00B0:;JX003086YP@2Jd9P0V]2H00l0
V]2H00<0PJV108boRP2<_hX02P2<_hX00`21ZH40MJ9c07FRL`0407FRL`<0PJV10P1=LE2Y0;3PiP40
oooo002[0;3PiP03086YP@1]Vgd0PJV100<0PJV12P2@a9T00`21ZH40W]JT09kFY00<09kFY003086Y
P@2UgJP0YMfX0100YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0D0:KOY@03086Y
P@2RfZ00X]ZP0180X]ZP00<0PJV109[@V02Jd9P03P2Jd9P00`21ZH40S;n:08boRP0;08boRP04086Y
P@1eXW<0MJ9c07FRL`@0PJV10P1=LE000`21ZH40/>3V0;3PiP2X0;3PiP40oooo002/0;3PiP80PJV1
0P1]Vgd4086YP@P0T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40YMfX0:GMZ00?0:GMZ003086Y
P@2Wh:P0Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD04`2VgjD00`21ZH40X]ZP0:;JX00A0:;JX003086Y
P@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<_hX02P2<_hX5086YP@80KIY_00@0PJV104eaD01=LE00
PJV1Z`2`h>H10?ooo`00[P2`h>H01P21ZH40KI]m06fKO@1]Vgd0PJV108JjTPH0PJV10P2@a9T00`21
ZH40W]JT09kFY00<09kFY003086YP@2UgJP0YMfX0100YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21
ZH40Y]nU0:KOY@0C0:KOY@03086YP@2RfZ00X]ZP0140X]ZP00<0PJV109[@V02Jd9P03P2Jd9P00`21
ZH40S;n:08boRP0708boRPD0PJV1101]VVl2086YP@0304eaD021ZH40/>3V0:`0/>3V0@3oool00:l0
/>3V00D0PJV106fKO@1]Vgd0KI]m086YP@0608JjTPL0PJV12`2NeZ@00`21ZH40YMfX0:GMZ00?0:GM
Z003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD04`2VgjD00`21ZH40X]ZP0:;JX00@0:;J
X003086YP@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<_hX01`21ZH4208BgQP03086YP@1]VVl0KIY_
00<0KIY_00@0PJV104eaD01=LE00PJV1[P2`h>H10?ooo`00/02`h>H01021ZH40KI]m06fKO@1]Vgd2
086YP@P0Q[ZB00<0PJV109K>WP2FcYh02021ZH4309kFY003086YP@2UgJP0YMfX00l0YMfX00<0PJV1
0:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0B0:KOY@03086YP@2RfZ00X]ZP0140X]ZP00<0PJV1
09[@V02Jd9P02P2Jd9P8086YP@P0Q;N600<0PJV106fJK`1]VVl00`1]VVl01021ZH40CG5@086YP@21
ZH6_0;3PiP40oooo002a0;3PiP03086YP@1]Vgd0KI]m0080KI]m00<0PJV108JjTP26^Y801P26^Y80
0`21ZH40U/jN09K>WP0709K>WPT0PJV1302UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0
Y]nU0180Y]nU00<0PJV10:;JX02RfZ00402RfZ000`21ZH40V]2H09[@V00209[@V0T0PJV10`2CbY@0
0`21ZH40Q;N608BgQP0808BgQP80PJV11@1]VVl00`21ZH40CG5@086YP@2a0;3PiP40oooo002b0;3P
iP03086YP@1]Vgd0KI]m0080KI]m00<0PJV108JjTP26^Y801P26^Y800`21ZH40U/jN09K>WP0;09K>
WP04086YP@2Nf:@0W]RT09kHY0T0PJV1102UgJP00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2VgjD0
Y]nU0180Y]nU00<0PJV10:;JX02RfZ001`2RfZ0>086YP@/0TlZD00<0PJV108BgQP24]hH02024]hH0
0`21ZH40KIY_06fJK`0406fJK`03086YP@1=LE00PJV10;80/>3V0@3oool00;<0/>3V0P21ZH4306fK
O@03086YP@26^Y80Q[ZB00H0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00:09kH
Y3P0PJV1202LeIh00`21ZH40TlZD09?:U00=09?:U003086YP@24]hH0Q;N600P0Q;N600<0PJV106fJ
K`1]VVl0101]VVl3086YPK<0/>3V0@3oool00;D0/>3V00D0PJV106fKO@1]Vgd0KI]m086YP@0808Jj
TP03086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@03@2Nf:@00`21ZH40XM^U0:7KY@0B0:7K
Y@03086YP@2QfZ<0XMZS0180XMZS00<0PJV109cEWP2LeIh03`2LeIh00`21ZH40TlZD09?:U00=09?:
U003086YP@24]hH0Q;N600L0Q;N600<0PJV106fJK`1]VVl00`1]VVl3086YPKD0/>3V0@3oool00;H0
/>3V00@0PJV106fKO@1]Vgd0KI]m0P21ZH4608JjTP03086YP@2FcYh0U/jN00/0U/jN00<0PJV109kH
Y02Nf:@03@2Nf:@00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2QfZ<0XMZS0140XMZS00<0PJV109cE
WP2LeIh03`2LeIh00`21ZH40TlZD09?:U00=09?:U003086YP@24]hH0Q;N600L0Q;N600<0PJV106fJ
K`1]VVl00`1]VVl3086YPKH0/>3V0@3oool00;L0/>3V0P21ZH4306fKO@03086YP@26^Y80Q[ZB00@0
Q[ZB00<0PJV109K>WP2FcYh02`2FcYh00`21ZH40W]RT09kHY00<09kHY003086YP@2QfjD0XM^U0140
XM^U00<0PJV10:7JX`2QfZ<04@2QfZ<00`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00d0
TlZD00<0PJV108BgQP24]hH01P24]hH2086YP@D0KIY_0P21ZH6h0;3PiP40oooo002h0;3PiPH0PJV1
1P26^Y800`21ZH40U/jN09K>WP0:09K>WP03086YP@2Nf:@0W]RT00d0W]RT00<0PJV10:7KY@2QfjD0
402QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086YP@2LeIh0W=FN00h0W=FN00<0PJV109?:U02CbY@0
302CbY@00`21ZH40Q;N608BgQP0608BgQP03086YP@1]VVl0KIY_0080KIY_0`21ZH6j0;3PiP40oooo
002j0;3PiP80PJV100@0GXU_086YP@21ZH40PJV11@26^Y800`21ZH40U/jN09K>WP0:09K>WP03086Y
P@2Nf:@0W]RT00`0W]RT00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086Y
P@2LeIh0W=FN00d0W=FN00<0PJV109?:U02CbY@0302CbY@00`21ZH40Q;N608BgQP0608BgQP03086Y
P@1]VVl0PJV100D0PJV1^`2`h>H10?ooo`00_02`h>H2086YP@0305j9K`21ZH40PJV10080PJV10`26
^Y800`21ZH40U/jN09K>WP0:09K>WP03086YP@2Nf:@0W]RT00`0W]RT00<0PJV10:7KY@2QfjD0402Q
fjD00`21ZH40XMZS0:7JX`0?0:7JX`03086YP@2LeIh0W=FN00h0W=FN00<0PJV109?:U02CbY@02`2C
bY@00`21ZH40Q;N608BgQP0508BgQP@0PJV10P1ORfH2086YPKd0/>3V0@3oool00;h0/>3V0P21ZH40
0`1NRFl0PJV1086YP@05086YP@`0U/jN00<0PJV109kHY02Nf:@02`2Nf:@00`21ZH40XM^U0:7KY@0@
0:7KY@03086YP@2QfZ<0XMZS00l0XMZS00<0PJV109cEWP2LeIh03@2LeIh00`21ZH40TlZD09?:U00<
09?:U004086YP@24]hH0Q;N608BgQPD0PJV10`1ORfH2086YPKl0/>3V0@3oool00<00/>3V0P21ZH40
0`1NRFl0PJV1086YP@0207FWQ0P0PJV11@2FcYh00`21ZH40W]RT09kHY00<09kHY003086YP@2QfjD0
XM^U00l0XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<00`21ZH40W=FN09cEWP0<09cEWP03086YP@2CbY@0
TlZD00`0TlZD1@21ZH400`1eYW/0PJV1086YP@0305n;IP80PJV1`@2`h>H10?ooo`00`P2`h>H2086Y
P@0305j9K`21ZH40MJN40080MJN40P21ZH4408FkT@X0PJV12P2Nf:@00`21ZH40XM^U0:7KY@0?0:7K
Y@03086YP@2QfZ<0XMZS00l0XMZS00<0PJV109cEWP2LeIh0302LeIh00`21ZH40TlZD09?:U00409?:
U0T0PJV1101eYW/01021ZH40Gh]V05n;IP1ORfH2086YPL<0/>3V0@3oool00<@0/>3V1021ZH4307FW
Q080PJV12@25^i400`21ZH40S/JH08k6V008086YP@<0W]RT00<0PJV10:7KY@2QfjD03P2QfjD00`21
ZH40XMZS0:7JX`0>0:7JX`03086YP@2LeIh0W=FN00D0W=FN3`21ZH4508BiRP80PJV1101eYW/2086Y
P@80Gh]V0P21ZH750;3PiP40oooo00360;3PiP@0PJV10`1eYh@00`21ZH40QK^A08FkT@0708FkT@03
086YP@2>aYP0S/JH00L0S/JH;@21ZH4608k5T`03086YP@24^HX0Q;V:00X0Q;V:00<0PJV107FVN`1e
YW/00`1eYW/00`21ZH40Gh]V05n;IP03086YPLH0/>3V0@3oool00<T0/>3V0`21ZH4207FWQ080PJV1
2025^i400`21ZH40S/JH08k6V00:08k6V003086YP@2Cc9/0TlbK00d0TlbK00<0PJV109;;V@2BbiT0
3@2BbiT00`21ZH40S/FC08k5T`0;08k5T`03086YP@24^HX0Q;V:00T0Q;V:0P21ZH4407FVN`80PJV1
00@0Gh]V086YP@21ZH40PJV1b02`h>H10?ooo`00b`2`h>H3086YP@80MJN40P21ZH4708FkT@80PJV1
2`2>aYP00`21ZH40TlbK09?<V`0<09?<V`03086YP@2BbiT0T/^I00d0T/^I00<0PJV108k5T`2>aI<0
2P2>aI<00`21ZH40Q;V:08BiRP0808BiRP80PJV1101eYW/5086YPL/0/>3V0@3oool00<h0/>3V1P21
ZH4708FkT@03086YP@2>aYP0S/JH00T0S/JH00<0PJV109?<V`2Cc9/02`2Cc9/00`21ZH40T/^I09;;
V@0<09;;V@03086YP@2>aI<0S/FC00X0S/FC00<0PJV108BiRP24^HX02024^HX01021ZH40MJIk07FV
N`1eYW/6086YPLd0/>3V0@3oool00=40/>3V1P21ZH4508FkT@03086YP@2>aYP0S/JH00P0S/JH00<0
PJV109?<V`2Cc9/0302Cc9/00`21ZH40T/^I09;;V@0;09;;V@03086YP@2>aI<0S/FC00T0S/FC00<0
PJV108BiRP24^HX01`24^HX9086YPM00/>3V0@3oool00=<0/>3V2@21ZH400`25^i40PJV108k6V009
08k6V003086YP@2Cc9/0TlbK00/0TlbK00<0PJV109;;V@2BbiT02P2BbiT00`21ZH40S/FC08k5T`09
08k5T`03086YP@24^HX0Q;V:0080Q;V:3021ZH7C0;3PiP40oooo003F0;3PiPD0PJV100<0JYYi086Y
P@21ZH401P21ZH4508k6V003086YP@2Cc9/0TlbK00X0TlbK00<0PJV109;;V@2BbiT02P2BbiT00`21
ZH40S/FC08k5T`0308k5T`/0PJV10P1[VgD2086YP@0305f9I`21ZH40PJV100<0PJV1e@2`h>H10?oo
o`00f@2`h>H5086YP@80JYYi0P21ZH4207>VPBD0PJV10`1cYWh2086YP@D0Ji]e0P21ZH400`1MRFL0
PJV1086YP@03086YPMP0/>3V0@3oool00=d0/>3V0`21ZH4206ZJN@80PJV11`1cYX42086YP@T0N:b4
00<0PJV107R[P`1hZh<0201hZh<00`21ZH40LjIn07>VOP0607>VOP80PJV1101[VgD7086YPM`0/>3V
0@3oool00>00/>3V1P21ZH4707>VP@80PJV11`1h[8@00`21ZH40N:^307R[P`0707R[P`03086YP@1c
YWh0LjIn00D0LjIn0P21ZH400`1[VgD0PJV1086YP@05086YPN40/>3V0@3oool00>@0/>3V3`21ZH44
07R/Q003086YP@1hZh<0N:^300H0N:^300@0PJV107>VOP1cYWh0LjIn1`21ZH7X0;3PiP40oooo003b
0;3PiQ80PJV1k`2`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.603 .774 .563 r
.4405 .46951 m .43989 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.47983 .5 m .48003 .46975 L .4405 .46951 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.48003 .53025 m .47983 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.48003 .46975 m .47983 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.52017 .5 m .51997 .46975 L .48003 .46975 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.47983 .5 m .48003 .53025 L .51997 .53025 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.51997 .53025 m .52017 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.51997 .46975 m .52017 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.52017 .5 m .51997 .53025 L .5595 .53049 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.5595 .53049 m .56011 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.44233 .43937 m .4405 .46951 L .48003 .46975 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.48003 .46975 m .48064 .43983 L .44233 .43937 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.43989 .5 m .4405 .53049 L .48003 .53025 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.48064 .56017 m .48003 .53025 L .4405 .53049 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.48064 .43983 m .48003 .46975 L .51997 .46975 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.51997 .46975 m .51936 .43983 L .48064 .43983 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.48003 .53025 m .48064 .56017 L .51936 .56017 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.51936 .56017 m .51997 .53025 L .48003 .53025 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.51936 .43983 m .51997 .46975 L .5595 .46951 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.56011 .5 m .5595 .46951 L .51997 .46975 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.51997 .53025 m .51936 .56017 L .55767 .56063 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.55767 .56063 m .5595 .53049 L .51997 .53025 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.40219 .46902 m .40117 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.43989 .5 m .4405 .46951 L .40219 .46902 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.4405 .53049 m .43989 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.5595 .46951 m .56011 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.56011 .5 m .5595 .53049 L .59781 .53098 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.59781 .53098 m .59883 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.44539 .40995 m .44233 .43937 L .48064 .43983 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.48064 .43983 m .48166 .41061 L .44539 .40995 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.48166 .41061 m .48064 .43983 L .51936 .43983 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.51936 .43983 m .51834 .41061 L .48166 .41061 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.51834 .41061 m .51936 .43983 L .55767 .43937 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.5595 .46951 m .55767 .43937 L .51936 .43983 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.4405 .53049 m .44233 .56063 L .48064 .56017 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.48166 .58939 m .48064 .56017 L .44233 .56063 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.48064 .56017 m .48166 .58939 L .51834 .58939 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.51834 .58939 m .51936 .56017 L .48064 .56017 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.51936 .56017 m .51834 .58939 L .55461 .59005 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.55461 .59005 m .55767 .56063 L .51936 .56017 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.40525 .43843 m .40219 .46902 L .4405 .46951 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.4405 .46951 m .44233 .43937 L .40525 .43843 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.40117 .5 m .40219 .53098 L .4405 .53049 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.44233 .56063 m .4405 .53049 L .40219 .53098 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.55767 .43937 m .5595 .46951 L .59781 .46902 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.59883 .5 m .59781 .46902 L .5595 .46951 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.5595 .53049 m .55767 .56063 L .59475 .56157 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.59475 .56157 m .59781 .53098 L .5595 .53049 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.41034 .40863 m .40525 .43843 L .44233 .43937 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.44233 .43937 m .44539 .40995 L .41034 .40863 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.40219 .53098 m .40525 .56157 L .44233 .56063 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.44539 .59005 m .44233 .56063 L .40525 .56157 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.44233 .56063 m .44539 .59005 L .48166 .58939 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.55767 .43937 m .55461 .40995 L .51834 .41061 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.55461 .40995 m .55767 .43937 L .59475 .43843 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.59781 .46902 m .59475 .43843 L .55767 .43937 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.55767 .56063 m .55461 .59005 L .58966 .59137 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.58966 .59137 m .59475 .56157 L .55767 .56063 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.44966 .38165 m .44539 .40995 L .48166 .41061 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.48166 .41061 m .48309 .38245 L .44966 .38165 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.48309 .61755 m .48166 .58939 L .44539 .59005 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.48309 .38245 m .48166 .41061 L .51834 .41061 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.51834 .41061 m .51691 .38245 L .48309 .38245 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.48166 .58939 m .48309 .61755 L .51691 .61755 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.51691 .61755 m .51834 .58939 L .48166 .58939 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.51691 .38245 m .51834 .41061 L .55461 .40995 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.51834 .58939 m .51691 .61755 L .55034 .61835 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.55034 .61835 m .55461 .59005 L .51834 .58939 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.59781 .46902 m .59883 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.59883 .5 m .59781 .53098 L .63399 .53171 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.63399 .53171 m .63541 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.36601 .46829 m .36459 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.40117 .5 m .40219 .46902 L .36601 .46829 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.40219 .53098 m .40117 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.59475 .43843 m .59781 .46902 L .63399 .46829 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.63541 .5 m .63399 .46829 L .59781 .46902 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.59781 .53098 m .59475 .56157 L .6297 .56298 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.6297 .56298 m .63399 .53171 L .59781 .53098 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.3703 .43702 m .36601 .46829 L .40219 .46902 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.40219 .46902 m .40525 .43843 L .3703 .43702 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.36459 .5 m .36601 .53171 L .40219 .53098 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.40525 .56157 m .40219 .53098 L .36601 .53171 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.40525 .56157 m .41034 .59137 L .44539 .59005 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.44966 .61835 m .44539 .59005 L .41034 .59137 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.44539 .59005 m .44966 .61835 L .48309 .61755 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.55461 .59005 m .55034 .61835 L .58254 .61994 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.58254 .61994 m .58966 .59137 L .55461 .59005 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.41746 .38006 m .41034 .40863 L .44539 .40995 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.44539 .40995 m .44966 .38165 L .41746 .38006 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.55461 .40995 m .55034 .38165 L .51691 .38245 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.55034 .38165 m .55461 .40995 L .58966 .40863 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.59475 .43843 m .58966 .40863 L .55461 .40995 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.58966 .40863 m .59475 .43843 L .6297 .43702 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.63399 .46829 m .6297 .43702 L .59475 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.37741 .40665 m .3703 .43702 L .40525 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.40525 .43843 m .41034 .40863 L .37741 .40665 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.59475 .56157 m .58966 .59137 L .62259 .59335 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.62259 .59335 m .6297 .56298 L .59475 .56157 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.36601 .53171 m .3703 .56298 L .40525 .56157 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.41034 .59137 m .40525 .56157 L .3703 .56298 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.45516 .35491 m .44966 .38165 L .48309 .38245 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.48309 .38245 m .48493 .35578 L .45516 .35491 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.48493 .64422 m .48309 .61755 L .44966 .61835 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.48493 .35578 m .48309 .38245 L .51691 .38245 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.51691 .38245 m .51507 .35578 L .48493 .35578 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.48309 .61755 m .48493 .64422 L .51507 .64422 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.51507 .64422 m .51691 .61755 L .48309 .61755 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.51507 .35578 m .51691 .38245 L .55034 .38165 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.51691 .61755 m .51507 .64422 L .54484 .64509 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.54484 .64509 m .55034 .61835 L .51691 .61755 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.38734 .37767 m .37741 .40665 L .41034 .40863 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.41034 .40863 m .41746 .38006 L .38734 .37767 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.58966 .40863 m .58254 .38006 L .55034 .38165 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.58254 .38006 m .58966 .40863 L .62259 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.6297 .43702 m .62259 .40665 L .58966 .40863 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.58966 .59137 m .58254 .61994 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.61266 .62233 m .62259 .59335 L .58966 .59137 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.3703 .56298 m .37741 .59335 L .41034 .59137 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.41746 .61994 m .41034 .59137 L .37741 .59335 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.41034 .59137 m .41746 .61994 L .44966 .61835 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.42658 .35317 m .41746 .38006 L .44966 .38165 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.44966 .38165 m .45516 .35491 L .42658 .35317 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.45516 .64509 m .44966 .61835 L .41746 .61994 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.44966 .61835 m .45516 .64509 L .48493 .64422 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.55034 .38165 m .54484 .35491 L .51507 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.54484 .35491 m .55034 .38165 L .58254 .38006 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.55034 .61835 m .54484 .64509 L .57342 .64683 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.57342 .64683 m .58254 .61994 L .55034 .61835 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.33301 .46731 m .33118 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.36459 .5 m .36601 .46829 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.36601 .53171 m .36459 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.63399 .46829 m .63541 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.63541 .5 m .63399 .53171 L .66699 .53269 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.66699 .53269 m .66882 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.33851 .43514 m .33301 .46731 L .36601 .46829 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.36601 .46829 m .3703 .43702 L .33851 .43514 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.33118 .5 m .33301 .53269 L .36601 .53171 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.3703 .56298 m .36601 .53171 L .33301 .53269 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.6297 .43702 m .63399 .46829 L .66699 .46731 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.66882 .5 m .66699 .46731 L .63399 .46829 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.63399 .53171 m .6297 .56298 L .66149 .56486 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.66149 .56486 m .66699 .53269 L .63399 .53171 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.34762 .40403 m .33851 .43514 L .3703 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.3703 .43702 m .37741 .40665 L .34762 .40403 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.33301 .53269 m .33851 .56486 L .3703 .56298 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.37741 .59335 m .3703 .56298 L .33851 .56486 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.62259 .40665 m .6297 .43702 L .66149 .43514 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.66699 .46731 m .66149 .43514 L .6297 .43702 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.6297 .56298 m .62259 .59335 L .65238 .59597 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.65238 .59597 m .66149 .56486 L .6297 .56298 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.46188 .3302 m .45516 .35491 L .48493 .35578 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.48493 .35578 m .48717 .33107 L .46188 .3302 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.48717 .33107 m .48493 .35578 L .51507 .35578 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.51507 .35578 m .51283 .33107 L .48717 .33107 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.51283 .33107 m .51507 .35578 L .54484 .35491 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.48717 .66893 m .48493 .64422 L .45516 .64509 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.48493 .64422 m .48717 .66893 L .51283 .66893 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.51283 .66893 m .51507 .64422 L .48493 .64422 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.51507 .64422 m .51283 .66893 L .53812 .6698 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.53812 .6698 m .54484 .64509 L .51507 .64422 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.40002 .35058 m .38734 .37767 L .41746 .38006 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.41746 .38006 m .42658 .35317 L .40002 .35058 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.37741 .59335 m .38734 .62233 L .41746 .61994 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.42658 .64683 m .41746 .61994 L .38734 .62233 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.41746 .61994 m .42658 .64683 L .45516 .64509 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.58254 .38006 m .57342 .35317 L .54484 .35491 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.57342 .35317 m .58254 .38006 L .61266 .37767 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.62259 .40665 m .61266 .37767 L .58254 .38006 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.58254 .61994 m .57342 .64683 L .59998 .64942 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.59998 .64942 m .61266 .62233 L .58254 .61994 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.43769 .32847 m .42658 .35317 L .45516 .35491 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.45516 .35491 m .46188 .3302 L .43769 .32847 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.54484 .35491 m .53812 .3302 L .51283 .33107 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.53812 .3302 m .54484 .35491 L .57342 .35317 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.46188 .6698 m .45516 .64509 L .42658 .64683 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.45516 .64509 m .46188 .6698 L .48717 .66893 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.54484 .64509 m .53812 .6698 L .56231 .67153 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.56231 .67153 m .57342 .64683 L .54484 .64509 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.36027 .37452 m .34762 .40403 L .37741 .40665 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.37741 .40665 m .38734 .37767 L .36027 .37452 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.33851 .56486 m .34762 .59597 L .37741 .59335 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.38734 .62233 m .37741 .59335 L .34762 .59597 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.61266 .37767 m .62259 .40665 L .65238 .40403 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.66149 .43514 m .65238 .40403 L .62259 .40665 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.62259 .59335 m .61266 .62233 L .63973 .62548 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.63973 .62548 m .65238 .59597 L .62259 .59335 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.57342 .35317 m .56231 .32847 L .53812 .3302 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.56231 .32847 m .57342 .35317 L .59998 .35058 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.61266 .37767 m .59998 .35058 L .57342 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.41536 .32591 m .40002 .35058 L .42658 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.42658 .35317 m .43769 .32847 L .41536 .32591 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.38734 .62233 m .40002 .64942 L .42658 .64683 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.43769 .67153 m .42658 .64683 L .40002 .64942 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.42658 .64683 m .43769 .67153 L .46188 .6698 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.57342 .64683 m .56231 .67153 L .58464 .67409 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.58464 .67409 m .59998 .64942 L .57342 .64683 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.37636 .34717 m .36027 .37452 L .38734 .37767 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.38734 .37767 m .40002 .35058 L .37636 .34717 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.34762 .59597 m .36027 .62548 L .38734 .62233 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.40002 .64942 m .38734 .62233 L .36027 .62548 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.59998 .35058 m .61266 .37767 L .63973 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.65238 .40403 m .63973 .37452 L .61266 .37767 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.61266 .62233 m .59998 .64942 L .62364 .65283 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.62364 .65283 m .63973 .62548 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.30442 .46609 m .30218 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.33118 .5 m .33301 .46731 L .30442 .46609 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.33301 .53269 m .33118 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.66699 .46731 m .66882 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.66882 .5 m .66699 .53269 L .69558 .53391 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.69558 .53391 m .69782 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.46978 .30806 m .46188 .3302 L .48717 .33107 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.48717 .33107 m .48982 .30885 L .46978 .30806 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.48982 .30885 m .48717 .33107 L .51283 .33107 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.51283 .33107 m .51018 .30885 L .48982 .30885 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.51018 .30885 m .51283 .33107 L .53812 .3302 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.48982 .69115 m .48717 .66893 L .46188 .6698 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.48717 .66893 m .48982 .69115 L .51018 .69115 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.51018 .69115 m .51283 .66893 L .48717 .66893 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.51283 .66893 m .51018 .69115 L .53022 .69194 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.53022 .69194 m .53812 .6698 L .51283 .66893 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.31108 .43281 m .30442 .46609 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.33301 .46731 m .33851 .43514 L .31108 .43281 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.30218 .5 m .30442 .53391 L .33301 .53269 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.33851 .56486 m .33301 .53269 L .30442 .53391 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.66149 .43514 m .66699 .46731 L .69558 .46609 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.69782 .5 m .69558 .46609 L .66699 .46731 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.66699 .53269 m .66149 .56486 L .68892 .56719 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.68892 .56719 m .69558 .53391 L .66699 .53269 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.3221 .40078 m .31108 .43281 L .33851 .43514 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.33851 .43514 m .34762 .40403 L .3221 .40078 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.30442 .53391 m .31108 .56719 L .33851 .56486 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.34762 .59597 m .33851 .56486 L .31108 .56719 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.45071 .30652 m .43769 .32847 L .46188 .3302 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.46188 .3302 m .46978 .30806 L .45071 .30652 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.46978 .69194 m .46188 .6698 L .43769 .67153 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.46188 .6698 m .46978 .69194 L .48982 .69115 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.53812 .3302 m .53022 .30806 L .51018 .30885 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.53022 .30806 m .53812 .3302 L .56231 .32847 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.53812 .6698 m .53022 .69194 L .54929 .69348 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.54929 .69348 m .56231 .67153 L .53812 .6698 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.65238 .40403 m .66149 .43514 L .68892 .43281 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.69558 .46609 m .68892 .43281 L .66149 .43514 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.66149 .56486 m .65238 .59597 L .6779 .59922 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.6779 .59922 m .68892 .56719 L .66149 .56486 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.3957 .32256 m .37636 .34717 L .40002 .35058 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.40002 .35058 m .41536 .32591 L .3957 .32256 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.36027 .62548 m .37636 .65283 L .40002 .64942 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.41536 .67409 m .40002 .64942 L .37636 .65283 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.40002 .64942 m .41536 .67409 L .43769 .67153 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.59998 .35058 m .58464 .32591 L .56231 .32847 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.58464 .32591 m .59998 .35058 L .62364 .34717 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.63973 .37452 m .62364 .34717 L .59998 .35058 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.59998 .64942 m .58464 .67409 L .6043 .67744 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.6043 .67744 m .62364 .65283 L .59998 .64942 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.33733 .37063 m .3221 .40078 L .34762 .40403 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.34762 .40403 m .36027 .37452 L .33733 .37063 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.31108 .56719 m .3221 .59922 L .34762 .59597 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.36027 .62548 m .34762 .59597 L .3221 .59922 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.63973 .37452 m .65238 .40403 L .6779 .40078 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.68892 .43281 m .6779 .40078 L .65238 .40403 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.65238 .59597 m .63973 .62548 L .66267 .62937 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.66267 .62937 m .6779 .59922 L .65238 .59597 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.56231 .32847 m .54929 .30652 L .53022 .30806 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.54929 .30652 m .56231 .32847 L .58464 .32591 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43326 .30424 m .41536 .32591 L .43769 .32847 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43769 .32847 m .45071 .30652 L .43326 .30424 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.45071 .69348 m .43769 .67153 L .41536 .67409 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.43769 .67153 m .45071 .69348 L .46978 .69194 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56231 .67153 m .54929 .69348 L .56674 .69576 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56674 .69576 m .58464 .67409 L .56231 .67153 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.35657 .34299 m .33733 .37063 L .36027 .37452 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.36027 .37452 m .37636 .34717 L .35657 .34299 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.3221 .59922 m .33733 .62937 L .36027 .62548 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.37636 .65283 m .36027 .62548 L .33733 .62937 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.62364 .34717 m .63973 .37452 L .66267 .37063 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.6779 .40078 m .66267 .37063 L .63973 .37452 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.63973 .62548 m .62364 .65283 L .64343 .65701 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.64343 .65701 m .66267 .62937 L .63973 .62548 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.47883 .28911 m .46978 .30806 L .48982 .30885 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.48982 .30885 m .49286 .28971 L .47883 .28911 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.49286 .28971 m .48982 .30885 L .51018 .30885 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.51018 .30885 m .50714 .28971 L .49286 .28971 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50714 .28971 m .51018 .30885 L .53022 .30806 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.49286 .71029 m .48982 .69115 L .46978 .69194 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.48982 .69115 m .49286 .71029 L .50714 .71029 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.50714 .71029 m .51018 .69115 L .48982 .69115 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.51018 .69115 m .50714 .71029 L .52117 .71089 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.52117 .71089 m .53022 .69194 L .51018 .69115 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41809 .30128 m .3957 .32256 L .41536 .32591 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41536 .32591 m .43326 .30424 L .41809 .30128 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.37636 .65283 m .3957 .67744 L .41536 .67409 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.43326 .69576 m .41536 .67409 L .3957 .67744 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.41536 .67409 m .43326 .69576 L .45071 .69348 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.58464 .32591 m .56674 .30424 L .54929 .30652 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.56674 .30424 m .58464 .32591 L .6043 .32256 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.62364 .34717 m .6043 .32256 L .58464 .32591 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58464 .67409 m .56674 .69576 L .58191 .69872 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58191 .69872 m .6043 .67744 L .58464 .67409 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46555 .28792 m .45071 .30652 L .46978 .30806 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46978 .30806 m .47883 .28911 L .46555 .28792 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.47883 .71089 m .46978 .69194 L .45071 .69348 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.46978 .69194 m .47883 .71089 L .49286 .71029 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.53022 .30806 m .52117 .28911 L .50714 .28971 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.52117 .28911 m .53022 .30806 L .54929 .30652 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53022 .69194 m .52117 .71089 L .53445 .71208 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53445 .71208 m .54929 .69348 L .53022 .69194 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30764 .44461 m
.30853 .44555 L
s
.5 Mabswid
.582 .783 .566 r
.37952 .31849 m .35657 .34299 L .37636 .34717 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37636 .34717 m .3957 .32256 L .37952 .31849 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.33733 .62937 m .35657 .65701 L .37636 .65283 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.3957 .67744 m .37636 .65283 L .35657 .65701 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.6043 .32256 m .62364 .34717 L .64343 .34299 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.66267 .37063 m .64343 .34299 L .62364 .34717 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62364 .65283 m .6043 .67744 L .62048 .68151 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62048 .68151 m .64343 .65701 L .62364 .65283 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.31291 .4245 m
.31421 .42372 L
s
.5 Mabswid
.443 .57 .388 r
.28166 .46465 m .27906 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.30218 .5 m .30442 .46609 L .28166 .46465 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.30442 .53391 m .30218 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.69558 .46609 m .69782 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.69782 .5 m .69558 .53391 L .71834 .53535 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.71834 .53535 m .72094 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.28941 .43004 m .28166 .46465 L .30442 .46609 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.30442 .46609 m .31108 .43281 L .28941 .43004 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.27906 .5 m .28166 .53535 L .30442 .53391 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.31108 .56719 m .30442 .53391 L .28166 .53535 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.68892 .43281 m .69558 .46609 L .71834 .46465 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.72094 .5 m .71834 .46465 L .69558 .46609 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.69558 .53391 m .68892 .56719 L .71059 .56996 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.71059 .56996 m .71834 .53535 L .69558 .53391 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45351 .28618 m .43326 .30424 L .45071 .30652 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45071 .30652 m .46555 .28792 L .45351 .28618 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.54929 .30652 m .53445 .28792 L .52117 .28911 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.53445 .28792 m .54929 .30652 L .56674 .30424 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.46555 .71208 m .45071 .69348 L .43326 .69576 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.45071 .69348 m .46555 .71208 L .47883 .71089 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54929 .69348 m .53445 .71208 L .54649 .71382 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54649 .71382 m .56674 .69576 L .54929 .69348 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.30216 .39695 m .28941 .43004 L .31108 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.31108 .43281 m .3221 .40078 L .30216 .39695 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.28166 .53535 m .28941 .56996 L .31108 .56719 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.3221 .59922 m .31108 .56719 L .28941 .56996 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.6779 .40078 m .68892 .43281 L .71059 .43004 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.71834 .46465 m .71059 .43004 L .68892 .43281 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.68892 .56719 m .6779 .59922 L .69784 .60305 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.69784 .60305 m .71059 .56996 L .68892 .56719 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3197 .36608 m .30216 .39695 L .3221 .40078 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3221 .40078 m .33733 .37063 L .3197 .36608 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.28941 .56996 m .30216 .60305 L .3221 .59922 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.33733 .62937 m .3221 .59922 L .30216 .60305 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.66267 .37063 m .6779 .40078 L .69784 .39695 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.71059 .43004 m .69784 .39695 L .6779 .40078 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6779 .59922 m .66267 .62937 L .6803 .63392 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6803 .63392 m .69784 .60305 L .6779 .59922 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.40584 .29772 m .37952 .31849 L .3957 .32256 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.3957 .32256 m .41809 .30128 L .40584 .29772 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.35657 .65701 m .37952 .68151 L .3957 .67744 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.41809 .69872 m .3957 .67744 L .37952 .68151 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.3957 .67744 m .41809 .69872 L .43326 .69576 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.6043 .32256 m .58191 .30128 L .56674 .30424 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.58191 .30128 m .6043 .32256 L .62048 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.64343 .34299 m .62048 .31849 L .6043 .32256 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.6043 .67744 m .58191 .69872 L .59416 .70228 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.59416 .70228 m .62048 .68151 L .6043 .67744 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.44321 .28394 m .41809 .30128 L .43326 .30424 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.43326 .30424 m .45351 .28618 L .44321 .28394 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.56674 .30424 m .54649 .28618 L .53445 .28792 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.54649 .28618 m .56674 .30424 L .58191 .30128 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.45351 .71382 m .43326 .69576 L .41809 .69872 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.43326 .69576 m .45351 .71382 L .46555 .71208 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.56674 .69576 m .54649 .71382 L .55679 .71606 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.55679 .71606 m .58191 .69872 L .56674 .69576 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.34168 .33814 m .3197 .36608 L .33733 .37063 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.33733 .37063 m .35657 .34299 L .34168 .33814 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.30216 .60305 m .3197 .63392 L .33733 .62937 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.35657 .65701 m .33733 .62937 L .3197 .63392 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.64343 .34299 m .66267 .37063 L .6803 .36608 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.69784 .39695 m .6803 .36608 L .66267 .37063 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.66267 .62937 m .64343 .65701 L .65832 .66186 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.65832 .66186 m .6803 .63392 L .66267 .62937 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.48894 .274 m .47883 .28911 L .49286 .28971 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.49286 .28971 m .49626 .27434 L .48894 .274 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.49626 .27434 m .49286 .28971 L .50714 .28971 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.50714 .28971 m .50374 .27434 L .49626 .27434 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50374 .27434 m .50714 .28971 L .52117 .28911 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.49626 .72566 m .49286 .71029 L .47883 .71089 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.49286 .71029 m .49626 .72566 L .50374 .72566 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.50374 .72566 m .50714 .71029 L .49286 .71029 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.50714 .71029 m .50374 .72566 L .51106 .726 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.51106 .726 m .52117 .71089 L .50714 .71029 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.48205 .27334 m .46555 .28792 L .47883 .28911 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.47883 .28911 m .48894 .274 L .48205 .27334 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.52117 .28911 m .51106 .274 L .50374 .27434 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.51106 .274 m .52117 .28911 L .53445 .28792 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.48894 .726 m .47883 .71089 L .46555 .71208 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.47883 .71089 m .48894 .726 L .49626 .72566 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.52117 .71089 m .51106 .726 L .51795 .72666 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.51795 .72666 m .53445 .71208 L .52117 .71089 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.36767 .3138 m .34168 .33814 L .35657 .34299 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.35657 .34299 m .37952 .31849 L .36767 .3138 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.3197 .63392 m .34168 .66186 L .35657 .65701 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.37952 .68151 m .35657 .65701 L .34168 .66186 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.62048 .31849 m .64343 .34299 L .65832 .33814 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.6803 .36608 m .65832 .33814 L .64343 .34299 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.64343 .65701 m .62048 .68151 L .63233 .6862 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.63233 .6862 m .65832 .66186 L .64343 .65701 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.47588 .27237 m .45351 .28618 L .46555 .28792 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.46555 .28792 m .48205 .27334 L .47588 .27237 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.53445 .28792 m .51795 .27334 L .51106 .274 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.51795 .27334 m .53445 .28792 L .54649 .28618 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.48205 .72666 m .46555 .71208 L .45351 .71382 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.46555 .71208 m .48205 .72666 L .48894 .726 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.53445 .71208 m .51795 .72666 L .52412 .72763 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.52412 .72763 m .54649 .71382 L .53445 .71208 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.43508 .28127 m .40584 .29772 L .41809 .30128 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.41809 .30128 m .44321 .28394 L .43508 .28127 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.37952 .68151 m .40584 .70228 L .41809 .69872 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.44321 .71606 m .41809 .69872 L .40584 .70228 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.41809 .69872 m .44321 .71606 L .45351 .71382 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.58191 .30128 m .55679 .28394 L .54649 .28618 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.55679 .28394 m .58191 .30128 L .59416 .29772 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.62048 .31849 m .59416 .29772 L .58191 .30128 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.58191 .69872 m .55679 .71606 L .56492 .71873 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.56492 .71873 m .59416 .70228 L .58191 .69872 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71083 .5689 m
.71198 .56907 L
s
.5 Mabswid
.544 .745 .543 r
.39716 .29366 m .36767 .3138 L .37952 .31849 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.37952 .31849 m .40584 .29772 L .39716 .29366 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.34168 .66186 m .36767 .6862 L .37952 .68151 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.40584 .70228 m .37952 .68151 L .36767 .6862 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.59416 .29772 m .62048 .31849 L .63233 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.65832 .33814 m .63233 .3138 L .62048 .31849 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.62048 .68151 m .59416 .70228 L .60284 .70634 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.60284 .70634 m .63233 .6862 L .62048 .68151 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70104 .59473 m
.7026 .59505 L
s
.5 Mabswid
.579 .799 .596 r
.47068 .27114 m .44321 .28394 L .45351 .28618 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.45351 .28618 m .47588 .27237 L .47068 .27114 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.54649 .28618 m .52412 .27237 L .51795 .27334 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.52412 .27237 m .54649 .28618 L .55679 .28394 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.47588 .72763 m .45351 .71382 L .44321 .71606 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.45351 .71382 m .47588 .72763 L .48205 .72666 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.54649 .71382 m .52412 .72763 L .52932 .72886 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.52932 .72886 m .55679 .71606 L .54649 .71382 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.26636 .46299 m .26345 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.27906 .5 m .28166 .46465 L .26636 .46299 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.28166 .53535 m .27906 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.71834 .46465 m .72094 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.72094 .5 m .71834 .53535 L .73364 .53701 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.73364 .53701 m .73655 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.27502 .4269 m .26636 .46299 L .28166 .46465 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.28166 .46465 m .28941 .43004 L .27502 .4269 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.26345 .5 m .26636 .53701 L .28166 .53535 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.28941 .56996 m .28166 .53535 L .26636 .53701 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.71059 .43004 m .71834 .46465 L .73364 .46299 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.73655 .5 m .73364 .46299 L .71834 .46465 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.71834 .53535 m .71059 .56996 L .72498 .5731 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.72498 .5731 m .73364 .53701 L .71834 .53535 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28923 .39261 m .27502 .4269 L .28941 .43004 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28941 .43004 m .30216 .39695 L .28923 .39261 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.26636 .53701 m .27502 .5731 L .28941 .56996 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.30216 .60305 m .28941 .56996 L .27502 .5731 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.69784 .39695 m .71059 .43004 L .72498 .4269 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.73364 .46299 m .72498 .4269 L .71059 .43004 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71059 .56996 m .69784 .60305 L .71077 .60739 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71077 .60739 m .72498 .5731 L .71059 .56996 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30862 .36096 m .28923 .39261 L .30216 .39695 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30216 .39695 m .3197 .36608 L .30862 .36096 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.27502 .5731 m .28923 .60739 L .30216 .60305 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.3197 .63392 m .30216 .60305 L .28923 .60739 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.6803 .36608 m .69784 .39695 L .71077 .39261 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.72498 .4269 m .71077 .39261 L .69784 .39695 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69784 .60305 m .6803 .63392 L .69138 .63904 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69138 .63904 m .71077 .60739 L .69784 .60305 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.42953 .27826 m .39716 .29366 L .40584 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.40584 .29772 m .43508 .28127 L .42953 .27826 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.36767 .6862 m .39716 .70634 L .40584 .70228 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.43508 .71873 m .40584 .70228 L .39716 .70634 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.40584 .70228 m .43508 .71873 L .44321 .71606 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.59416 .29772 m .56492 .28127 L .55679 .28394 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.56492 .28127 m .59416 .29772 L .60284 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.63233 .3138 m .60284 .29366 L .59416 .29772 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.59416 .70228 m .56492 .71873 L .57047 .72174 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.57047 .72174 m .60284 .70634 L .59416 .70228 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.46668 .26969 m .43508 .28127 L .44321 .28394 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.44321 .28394 m .47068 .27114 L .46668 .26969 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.55679 .28394 m .52932 .27114 L .52412 .27237 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.52932 .27114 m .55679 .28394 L .56492 .28127 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.47068 .72886 m .44321 .71606 L .43508 .71873 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.44321 .71606 m .47068 .72886 L .47588 .72763 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.55679 .71606 m .52932 .72886 L .53332 .73031 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.53332 .73031 m .56492 .71873 L .55679 .71606 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.33273 .33273 m .30862 .36096 L .3197 .36608 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.3197 .36608 m .34168 .33814 L .33273 .33273 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.28923 .60739 m .30862 .63904 L .3197 .63392 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.34168 .66186 m .3197 .63392 L .30862 .63904 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.65832 .33814 m .6803 .36608 L .69138 .36096 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.71077 .39261 m .69138 .36096 L .6803 .36608 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.6803 .63392 m .65832 .66186 L .66727 .66727 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.66727 .66727 m .69138 .63904 L .6803 .63392 L p F P
.505 .664 .505 r
s
.554 .773 .585 r
.49626 .27434 m .5 .26345 L .48894 .274 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50374 .27434 m .5 .26345 L .49626 .27434 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.51106 .274 m .5 .26345 L .50374 .27434 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49626 .72566 L .48894 .726 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50374 .72566 L .49626 .72566 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .51106 .726 L .50374 .72566 L closepath p F P
.505 .664 .505 r
s
.551 .769 .581 r
.48894 .274 m .5 .26345 L .48205 .27334 L closepath p F P
.505 .664 .505 r
s
.554 .773 .586 r
.51795 .27334 m .5 .26345 L .51106 .274 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48894 .726 L .48205 .72666 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .51795 .72666 L .51106 .726 L closepath p F P
.505 .664 .505 r
s
.47 .648 .464 r
.36096 .30862 m .33273 .33273 L .34168 .33814 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.34168 .33814 m .36767 .3138 L .36096 .30862 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.30862 .63904 m .33273 .66727 L .34168 .66186 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.36767 .6862 m .34168 .66186 L .33273 .66727 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.63233 .3138 m .65832 .33814 L .66727 .33273 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.69138 .36096 m .66727 .33273 L .65832 .33814 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.65832 .66186 m .63233 .6862 L .63904 .69138 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.63904 .69138 m .66727 .66727 L .65832 .66186 L p F P
.505 .664 .505 r
s
.546 .763 .576 r
.48205 .27334 m .5 .26345 L .47588 .27237 L closepath p F P
.505 .664 .505 r
s
.55 .768 .584 r
.52412 .27237 m .5 .26345 L .51795 .27334 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .52412 .72763 L .51795 .72666 L closepath p F P
.505 .664 .505 r
s
.198 .204 .155 r
.5 .73655 m .48205 .72666 L .47588 .72763 L closepath p F P
.505 .664 .505 r
s
.537 .749 .559 r
.46407 .26807 m .42953 .27826 L .43508 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.43508 .28127 m .46668 .26969 L .46407 .26807 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.39716 .70634 m .42953 .72174 L .43508 .71873 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.46668 .73031 m .43508 .71873 L .42953 .72174 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.43508 .71873 m .46668 .73031 L .47068 .72886 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.56492 .28127 m .53332 .26969 L .52932 .27114 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.53332 .26969 m .56492 .28127 L .57047 .27826 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.60284 .29366 m .57047 .27826 L .56492 .28127 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.56492 .71873 m .53332 .73031 L .53593 .73193 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.53593 .73193 m .57047 .72174 L .56492 .71873 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.39261 .28923 m .36096 .30862 L .36767 .3138 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.36767 .3138 m .39716 .29366 L .39261 .28923 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.33273 .66727 m .36096 .69138 L .36767 .6862 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.39716 .70634 m .36767 .6862 L .36096 .69138 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.60284 .29366 m .63233 .3138 L .63904 .30862 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.66727 .33273 m .63904 .30862 L .63233 .3138 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.63233 .6862 m .60284 .70634 L .60739 .71077 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.60739 .71077 m .63904 .69138 L .63233 .6862 L p F P
.505 .664 .505 r
s
.539 .755 .57 r
.47588 .27237 m .5 .26345 L .47068 .27114 L closepath p F P
.505 .664 .505 r
s
.545 .762 .58 r
.52932 .27114 m .5 .26345 L .52412 .27237 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .47588 .72763 L .47068 .72886 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .52932 .72886 L .52412 .72763 L closepath p F P
.505 .664 .505 r
s
.501 .701 .516 r
.4269 .27502 m .39261 .28923 L .39716 .29366 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.39716 .29366 m .42953 .27826 L .4269 .27502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.36096 .69138 m .39261 .71077 L .39716 .70634 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42953 .72174 m .39716 .70634 L .39261 .71077 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.57047 .27826 m .60284 .29366 L .60739 .28923 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.63904 .30862 m .60739 .28923 L .60284 .29366 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.60284 .70634 m .57047 .72174 L .5731 .72498 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.5731 .72498 m .60739 .71077 L .60284 .70634 L p F P
.505 .664 .505 r
s
.531 .745 .563 r
.47068 .27114 m .5 .26345 L .46668 .26969 L closepath p F P
.505 .664 .505 r
s
.537 .753 .575 r
.53332 .26969 m .5 .26345 L .52932 .27114 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .47068 .72886 L .46668 .73031 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .53332 .73031 L .52932 .72886 L closepath p F P
.505 .664 .505 r
s
.509 .716 .534 r
.46299 .26636 m .4269 .27502 L .42953 .27826 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.42953 .27826 m .46407 .26807 L .46299 .26636 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.39261 .71077 m .4269 .72498 L .42953 .72174 L p F P
.505 .664 .505 r
s
.187 .194 .147 r
.46407 .73193 m .42953 .72174 L .4269 .72498 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.42953 .72174 m .46407 .73193 L .46668 .73031 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.57047 .27826 m .53593 .26807 L .53332 .26969 L p F P
.505 .664 .505 r
s
.53 .744 .575 r
.53593 .26807 m .57047 .27826 L .5731 .27502 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.60739 .28923 m .5731 .27502 L .57047 .27826 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57047 .72174 m .53593 .73193 L .53701 .73364 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.53701 .73364 m .5731 .72498 L .57047 .72174 L p F P
.505 .664 .505 r
s
.522 .734 .555 r
.46668 .26969 m .5 .26345 L .46407 .26807 L closepath p F P
.505 .664 .505 r
s
.183 .191 .145 r
.5 .73655 m .46668 .73031 L .46407 .73193 L closepath p F P
.505 .664 .505 r
s
.529 .743 .568 r
.53593 .26807 m .5 .26345 L .53332 .26969 L closepath p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .53593 .73193 L .53332 .73031 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27268 .43663 m
.2727 .43658 L
s
0 0 0 r
.71452 .59835 m
.716 .59892 L
s
1 .5 0 r
.27075 .43994 m
.27268 .43663 L
s
.27723 .42157 m
.27754 .41831 L
s
.5 Mabswid
.512 .722 .546 r
.46407 .26807 m .5 .26345 L .46299 .26636 L closepath p F P
.505 .664 .505 r
s
.187 .194 .147 r
.4269 .72498 m .46299 .73364 L .46407 .73193 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.5 .73655 m .46407 .73193 L .46299 .73364 L closepath p F P
.505 .664 .505 r
s
.519 .731 .56 r
.53701 .26636 m .5 .26345 L .53593 .26807 L closepath p F P
.505 .664 .505 r
s
.53 .744 .575 r
.5731 .27502 m .53701 .26636 L .53593 .26807 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .53701 .73364 L .53593 .73193 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26936 .44149 m
.27075 .43994 L
s
.27735 .41618 m
.27754 .41831 L
s
.5 Mabswid
.206 .269 .179 r
.26028 .46118 m .25714 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26345 .5 m .26636 .46299 L .26028 .46118 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.26636 .53701 m .26345 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26959 .42346 m .26028 .46118 L .26636 .46299 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26636 .46299 m .27502 .4269 L .26959 .42346 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.25714 .5 m .26028 .53882 L .26636 .53701 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.27502 .5731 m .26636 .53701 L .26028 .53882 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.28477 .38789 m .26959 .42346 L .27502 .4269 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.27502 .4269 m .28923 .39261 L .28477 .38789 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.26028 .53882 m .26959 .57654 L .27502 .5731 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.28923 .60739 m .27502 .5731 L .26959 .57654 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.30537 .35543 m .28477 .38789 L .28923 .39261 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.28923 .39261 m .30862 .36096 L .30537 .35543 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.26959 .57654 m .28477 .61211 L .28923 .60739 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.30862 .63904 m .28923 .60739 L .28477 .61211 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.33073 .32695 m .30537 .35543 L .30862 .36096 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.30862 .36096 m .33273 .33273 L .33073 .32695 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.28477 .61211 m .30537 .64457 L .30862 .63904 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.33273 .66727 m .30862 .63904 L .30537 .64457 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.36011 .30316 m .33073 .32695 L .33273 .33273 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.33273 .33273 m .36096 .30862 L .36011 .30316 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.30537 .64457 m .33073 .67305 L .33273 .66727 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.36096 .69138 m .33273 .66727 L .33073 .67305 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.39265 .28461 m .36011 .30316 L .36096 .30862 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.36096 .30862 m .39261 .28923 L .39265 .28461 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.33073 .67305 m .36011 .69684 L .36096 .69138 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.39261 .71077 m .36096 .69138 L .36011 .69684 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.42744 .27169 m .39265 .28461 L .39261 .28923 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.39261 .28923 m .4269 .27502 L .42744 .27169 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.36011 .69684 m .39265 .71539 L .39261 .71077 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.4269 .72498 m .39261 .71077 L .39265 .71539 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.46353 .26462 m .42744 .27169 L .4269 .27502 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.4269 .27502 m .46299 .26636 L .46353 .26462 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.39265 .71539 m .42744 .72831 L .4269 .72498 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.46299 .73364 m .4269 .72498 L .42744 .72831 L p F P
.505 .664 .505 r
s
.501 .709 .537 r
.46299 .26636 m .5 .26345 L .46353 .26462 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.42744 .72831 m .46353 .73538 L .46299 .73364 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .46299 .73364 L .46353 .73538 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .53647 .73538 L .53701 .73364 L closepath p F P
.505 .664 .505 r
s
.159 .169 .128 r
.5 .73655 m .5343 .73707 L .53647 .73538 L closepath p F P
.505 .664 .505 r
s
.152 .162 .124 r
.5 .73655 m .53058 .73863 L .5343 .73707 L closepath p F P
.505 .664 .505 r
s
.147 .157 .119 r
.5 .73655 m .52543 .73998 L .53058 .73863 L closepath p F P
.505 .664 .505 r
s
.142 .152 .116 r
.5 .73655 m .51909 .74106 L .52543 .73998 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .51184 .74182 L .51909 .74106 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50401 .7422 L .51184 .74182 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49599 .7422 L .50401 .7422 L closepath p F P
.505 .664 .505 r
s
.137 .148 .112 r
.5 .73655 m .48816 .74182 L .49599 .7422 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48091 .74106 L .48816 .74182 L closepath p F P
.505 .664 .505 r
s
.144 .154 .117 r
.5 .73655 m .47457 .73998 L .48091 .74106 L closepath p F P
.505 .664 .505 r
s
.149 .159 .121 r
.5 .73655 m .46942 .73863 L .47457 .73998 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .4657 .73707 L .46942 .73863 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .46353 .73538 L .4657 .73707 L closepath p F P
.505 .664 .505 r
s
.508 .719 .551 r
.53647 .26462 m .5 .26345 L .53701 .26636 L closepath p F P
.505 .664 .505 r
s
.497 .705 .541 r
.5343 .26293 m .5 .26345 L .53647 .26462 L closepath p F P
.505 .664 .505 r
s
.155 .165 .126 r
.5731 .72498 m .53701 .73364 L .53647 .73538 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.53701 .26636 m .5731 .27502 L .57256 .27169 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.57256 .27169 m .53647 .26462 L .53701 .26636 L p F P
.505 .664 .505 r
s
.486 .692 .531 r
.53058 .26137 m .5 .26345 L .5343 .26293 L closepath p F P
.505 .664 .505 r
s
.49 .696 .528 r
.46353 .26462 m .5 .26345 L .4657 .26293 L closepath p F P
.505 .664 .505 r
s
.48 .683 .519 r
.4657 .26293 m .5 .26345 L .46942 .26137 L closepath p F P
.505 .664 .505 r
s
.476 .679 .522 r
.52543 .26002 m .5 .26345 L .53058 .26137 L closepath p F P
.505 .664 .505 r
s
.145 .155 .118 r
.60739 .71077 m .5731 .72498 L .57256 .72831 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.53647 .73538 m .57256 .72831 L .5731 .72498 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.5731 .27502 m .60739 .28923 L .60735 .28461 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.60735 .28461 m .57256 .27169 L .5731 .27502 L p F P
.505 .664 .505 r
s
.47 .672 .511 r
.46942 .26137 m .5 .26345 L .47457 .26002 L closepath p F P
.505 .664 .505 r
s
.467 .668 .513 r
.51909 .25894 m .5 .26345 L .52543 .26002 L closepath p F P
.505 .664 .505 r
s
.462 .662 .505 r
.47457 .26002 m .5 .26345 L .48091 .25894 L closepath p F P
.505 .664 .505 r
s
.46 .659 .507 r
.51184 .25818 m .5 .26345 L .51909 .25894 L closepath p F P
.505 .664 .505 r
s
.135 .146 .111 r
.63904 .69138 m .60739 .71077 L .60735 .71539 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.57256 .72831 m .60735 .71539 L .60739 .71077 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.60739 .28923 m .63904 .30862 L .63989 .30316 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.63989 .30316 m .60735 .28461 L .60739 .28923 L p F P
.505 .664 .505 r
s
.457 .655 .501 r
.48091 .25894 m .5 .26345 L .48816 .25818 L closepath p F P
.505 .664 .505 r
s
.455 .653 .502 r
.50401 .2578 m .5 .26345 L .51184 .25818 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49599 .2578 m .5 .26345 L .50401 .2578 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.48816 .25818 m .5 .26345 L .49599 .2578 L closepath p F P
.505 .664 .505 r
s
.125 .137 .105 r
.66727 .66727 m .63904 .69138 L .63989 .69684 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.60735 .71539 m .63989 .69684 L .63904 .69138 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.63904 .30862 m .66727 .33273 L .66927 .32695 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.66927 .32695 m .63989 .30316 L .63904 .30862 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.69138 .63904 m .66727 .66727 L .66927 .67305 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.63989 .69684 m .66927 .67305 L .66727 .66727 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.66727 .33273 m .69138 .36096 L .69463 .35543 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.69463 .35543 m .66927 .32695 L .66727 .33273 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.69138 .36096 m .71077 .39261 L .71523 .38789 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.71523 .38789 m .69463 .35543 L .69138 .36096 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.71077 .60739 m .69138 .63904 L .69463 .64457 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.66927 .67305 m .69463 .64457 L .69138 .63904 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.72498 .5731 m .71077 .60739 L .71523 .61211 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.69463 .64457 m .71523 .61211 L .71077 .60739 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.71077 .39261 m .72498 .4269 L .73041 .42346 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.73041 .42346 m .71523 .38789 L .71077 .39261 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73364 .53701 m .72498 .5731 L .73041 .57654 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.71523 .61211 m .73041 .57654 L .72498 .5731 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.72498 .4269 m .73364 .46299 L .73972 .46118 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.73972 .46118 m .73041 .42346 L .72498 .4269 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.73364 .46299 m .73655 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.74286 .5 m .73972 .46118 L .73364 .46299 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73655 .5 m .73364 .53701 L .73972 .53882 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73041 .57654 m .73972 .53882 L .73364 .53701 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73972 .53882 m .74286 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.57256 .72831 m .53647 .73538 L .5343 .73707 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.53647 .26462 m .57256 .27169 L .56874 .26841 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.56874 .26841 m .5343 .26293 L .53647 .26462 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.43126 .73159 m .4657 .73707 L .46353 .73538 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.46353 .73538 m .42744 .72831 L .43126 .73159 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.42744 .27169 m .46353 .26462 L .4657 .26293 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71996 .60104 m
.72053 .60147 L
s
.5 Mabswid
.133 .145 .11 r
.5343 .73707 m .56874 .73159 L .57256 .72831 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.56874 .73159 m .5343 .73707 L .53058 .73863 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.43832 .73466 m .46942 .73863 L .4657 .73707 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.4657 .73707 m .43126 .73159 L .43832 .73466 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.5343 .26293 m .56874 .26841 L .56168 .26534 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.56168 .26534 m .53058 .26137 L .5343 .26293 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.43126 .26841 m .4657 .26293 L .46942 .26137 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.4657 .26293 m .43126 .26841 L .42744 .27169 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.60735 .71539 m .57256 .72831 L .56874 .73159 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.57256 .27169 m .60735 .28461 L .60241 .28 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.60241 .28 m .56874 .26841 L .57256 .27169 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.39759 .72 m .43126 .73159 L .42744 .72831 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.42744 .72831 m .39265 .71539 L .39759 .72 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.39265 .28461 m .42744 .27169 L .43126 .26841 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72053 .60147 m
.72185 .60018 L
s
.5 Mabswid
.099 .113 .086 r
.44839 .73736 m .47457 .73998 L .46942 .73863 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.46942 .73863 m .43832 .73466 L .44839 .73736 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.53058 .73863 m .56168 .73466 L .56874 .73159 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.56168 .73466 m .53058 .73863 L .52543 .73998 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.43832 .26534 m .46942 .26137 L .47457 .26002 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.46942 .26137 m .43832 .26534 L .43126 .26841 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.53058 .26137 m .56168 .26534 L .55161 .26264 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.55161 .26264 m .52543 .26002 L .53058 .26137 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.63989 .69684 m .60735 .71539 L .60241 .72 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56874 .73159 m .60241 .72 L .60735 .71539 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.60735 .28461 m .63989 .30316 L .63432 .29763 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.63432 .29763 m .60241 .28 L .60735 .28461 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.36568 .70237 m .39759 .72 L .39265 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.39265 .71539 m .36011 .69684 L .36568 .70237 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.43126 .26841 m .39759 .28 L .39265 .28461 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.36011 .30316 m .39265 .28461 L .39759 .28 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2642 .43984 m
.27259 .4139 L
s
.26406 .43768 m
.26623 .43255 L
s
0 0 0 r
.72185 .60018 m
.72489 .59537 L
s
.5 Mabswid
.08 .096 .073 r
.46108 .73954 m .48091 .74106 L .47457 .73998 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.47457 .73998 m .44839 .73736 L .46108 .73954 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.52543 .73998 m .55161 .73736 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.55161 .73736 m .52543 .73998 L .51909 .74106 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.44839 .26264 m .47457 .26002 L .48091 .25894 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.47457 .26002 m .44839 .26264 L .43832 .26534 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.52543 .26002 m .55161 .26264 L .53892 .26046 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.53892 .26046 m .51909 .25894 L .52543 .26002 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.66927 .67305 m .63989 .69684 L .63432 .70237 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.60241 .72 m .63432 .70237 L .63989 .69684 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.63989 .30316 m .66927 .32695 L .66349 .32103 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.66349 .32103 m .63432 .29763 L .63989 .30316 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.33651 .67897 m .36568 .70237 L .36011 .69684 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.36011 .69684 m .33073 .67305 L .33651 .67897 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.39759 .28 m .36568 .29763 L .36011 .30316 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.33073 .32695 m .36011 .30316 L .36568 .29763 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.60241 .72 m .56874 .73159 L .56168 .73466 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.56874 .26841 m .60241 .28 L .59249 .27562 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.59249 .27562 m .56168 .26534 L .56874 .26841 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.40751 .72438 m .43832 .73466 L .43126 .73159 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.43126 .73159 m .39759 .72 L .40751 .72438 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.39759 .28 m .43126 .26841 L .43832 .26534 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26324 .43927 m
.26406 .43768 L
s
.5 Mabswid
.065 .082 .063 r
.47579 .74108 m .48816 .74182 L .48091 .74106 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.48091 .74106 m .46108 .73954 L .47579 .74108 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.46108 .26046 m .48091 .25894 L .48816 .25818 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.48091 .25894 m .46108 .26046 L .44839 .26264 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.51909 .74106 m .53892 .73954 L .55161 .73736 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.53892 .73954 m .51909 .74106 L .51184 .74182 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.51909 .25894 m .53892 .26046 L .52421 .25892 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.52421 .25892 m .51184 .25818 L .51909 .25894 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72157 .60266 m
.72343 .59801 L
s
.72343 .59801 m
.7327 .57488 L
s
1 .5 0 r
.26285 .43893 m
.26324 .43927 L
s
.5 Mabswid
.056 .074 .056 r
.63432 .70237 m .66349 .67897 L .66927 .67305 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.69463 .64457 m .66927 .67305 L .66349 .67897 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.66927 .32695 m .69463 .35543 L .68896 .34972 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.68896 .34972 m .66349 .32103 L .66927 .32695 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.31104 .65028 m .33651 .67897 L .33073 .67305 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.33073 .67305 m .30537 .64457 L .31104 .65028 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.36568 .29763 m .33651 .32103 L .33073 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.30537 .35543 m .33073 .32695 L .33651 .32103 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.49179 .74187 m .49599 .7422 L .48816 .74182 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.48816 .74182 m .47579 .74108 L .49179 .74187 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.51184 .74182 m .52421 .74108 L .53892 .73954 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.52421 .74108 m .51184 .74182 L .50401 .7422 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.48816 .25818 m .47579 .25892 L .46108 .26046 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.47579 .25892 m .48816 .25818 L .49599 .2578 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.51184 .25818 m .52421 .25892 L .50821 .25813 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.50821 .25813 m .50401 .2578 L .51184 .25818 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.50401 .7422 m .50821 .74187 L .52421 .74108 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.50821 .74187 m .50401 .7422 L .49599 .7422 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.49599 .7422 m .49179 .74187 L .50821 .74187 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50401 .2578 m .50821 .25813 L .49179 .25813 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49179 .25813 m .49599 .2578 L .50401 .2578 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.49599 .2578 m .49179 .25813 L .47579 .25892 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.69463 .35543 m .71523 .38789 L .70983 .38297 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.70983 .38297 m .68896 .34972 L .69463 .35543 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.71523 .61211 m .69463 .64457 L .68896 .65028 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.66349 .67897 m .68896 .65028 L .69463 .64457 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33651 .32103 m .31104 .34972 L .30537 .35543 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.28477 .38789 m .30537 .35543 L .31104 .34972 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.29017 .61703 m .31104 .65028 L .30537 .64457 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.30537 .64457 m .28477 .61211 L .29017 .61703 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26285 .43893 m
.26317 .43686 L
s
.5 Mabswid
.346 .515 .414 r
.42217 .72827 m .44839 .73736 L .43832 .73466 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.43832 .73466 m .40751 .72438 L .42217 .72827 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.43832 .26534 m .40751 .27562 L .39759 .28 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.40751 .27562 m .43832 .26534 L .44839 .26264 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.56168 .73466 m .59249 .72438 L .60241 .72 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.59249 .72438 m .56168 .73466 L .55161 .73736 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.56168 .26534 m .59249 .27562 L .57783 .27173 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.57783 .27173 m .55161 .26264 L .56168 .26534 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26317 .43686 m
.2647 .43116 L
s
.5 Mabswid
.295 .441 .323 r
.63432 .70237 m .60241 .72 L .59249 .72438 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.60241 .28 m .63432 .29763 L .62207 .29232 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.62207 .29232 m .59249 .27562 L .60241 .28 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.37793 .70768 m .40751 .72438 L .39759 .72 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.39759 .72 m .36568 .70237 L .37793 .70768 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.36568 .29763 m .39759 .28 L .40751 .27562 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.73041 .57654 m .71523 .61211 L .70983 .61703 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.68896 .65028 m .70983 .61703 L .71523 .61211 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.71523 .38789 m .73041 .42346 L .72534 .41986 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.72534 .41986 m .70983 .38297 L .71523 .38789 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.27466 .58014 m .29017 .61703 L .28477 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.28477 .61211 m .26959 .57654 L .27466 .58014 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.31104 .34972 m .29017 .38297 L .28477 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.26959 .42346 m .28477 .38789 L .29017 .38297 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2647 .43116 m
.27124 .41217 L
s
.5 Mabswid
.188 .258 .168 r
.73972 .53882 m .73041 .57654 L .72534 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.70983 .61703 m .72534 .58014 L .73041 .57654 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73041 .42346 m .73972 .46118 L .73489 .45928 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73489 .45928 m .72534 .41986 L .73041 .42346 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26511 .54072 m .27466 .58014 L .26959 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26959 .57654 m .26028 .53882 L .26511 .54072 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.29017 .38297 m .27466 .41986 L .26959 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.26028 .46118 m .26959 .42346 L .27466 .41986 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71488 .61801 m
.71583 .61617 L
s
.71583 .61617 m
.71662 .61483 L
s
.5 Mabswid
.16 .2 .138 r
.73972 .46118 m .74286 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73811 .5 m .73489 .45928 L .73972 .46118 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.74286 .5 m .73972 .53882 L .73489 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.72534 .58014 m .73489 .54072 L .73972 .53882 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.27466 .41986 m .26511 .45928 L .26028 .46118 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.25714 .5 m .26028 .46118 L .26511 .45928 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26189 .5 m .26511 .54072 L .26028 .53882 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26028 .53882 m .25714 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.73489 .54072 m .73811 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.26511 .45928 m .26189 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71488 .61801 m
.71564 .6167 L
s
.71564 .6167 m
.71662 .61483 L
s
.72456 .59777 m
.73317 .57637 L
s
.72181 .60461 m
.72456 .59777 L
s
.5 Mabswid
.405 .59 .466 r
.44103 .73145 m .46108 .73954 L .44839 .73736 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44839 .73736 m .42217 .72827 L .44103 .73145 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.42217 .27173 m .44839 .26264 L .46108 .26046 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.44839 .26264 m .42217 .27173 L .40751 .27562 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.55161 .73736 m .57783 .72827 L .59249 .72438 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.57783 .72827 m .55161 .73736 L .53892 .73954 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55161 .26264 m .57783 .27173 L .55897 .26855 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55897 .26855 m .53892 .26046 L .55161 .26264 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.66349 .67897 m .63432 .70237 L .62207 .70768 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.59249 .72438 m .62207 .70768 L .63432 .70237 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.63432 .29763 m .66349 .32103 L .64944 .31528 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.64944 .31528 m .62207 .29232 L .63432 .29763 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.35056 .68472 m .37793 .70768 L .36568 .70237 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.36568 .70237 m .33651 .67897 L .35056 .68472 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.40751 .27562 m .37793 .29232 L .36568 .29763 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.33651 .32103 m .36568 .29763 L .37793 .29232 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26273 .43765 m
.27147 .41089 L
s
.25933 .45238 m
.25963 .45066 L
s
.25963 .45066 m
.26008 .44875 L
s
.26008 .44875 m
.25979 .45047 L
s
.25979 .45047 m
.25933 .45238 L
s
.5 Mabswid
.438 .628 .499 r
.39671 .71247 m .42217 .72827 L .40751 .72438 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.40751 .72438 m .37793 .70768 L .39671 .71247 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.37793 .29232 m .40751 .27562 L .42217 .27173 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.62207 .70768 m .59249 .72438 L .57783 .72827 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.59249 .27562 m .62207 .29232 L .60329 .28753 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.60329 .28753 m .57783 .27173 L .59249 .27562 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.4632 .7337 m .47579 .74108 L .46108 .73954 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.46108 .73954 m .44103 .73145 L .4632 .7337 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.44103 .26855 m .46108 .26046 L .47579 .25892 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.46108 .26046 m .44103 .26855 L .42217 .27173 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.53892 .73954 m .55897 .73145 L .57783 .72827 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.55897 .73145 m .53892 .73954 L .52421 .74108 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.53892 .26046 m .55897 .26855 L .5368 .2663 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.5368 .2663 m .52421 .25892 L .53892 .26046 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.68896 .65028 m .66349 .67897 L .64944 .68472 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.62207 .70768 m .64944 .68472 L .66349 .67897 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.66349 .32103 m .68896 .34972 L .67359 .34411 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.67359 .34411 m .64944 .31528 L .66349 .32103 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.37793 .29232 m .35056 .31528 L .33651 .32103 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.31104 .34972 m .33651 .32103 L .35056 .31528 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.32641 .65589 m .35056 .68472 L .33651 .67897 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.33651 .67897 m .31104 .65028 L .32641 .65589 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.48749 .73487 m .49179 .74187 L .47579 .74108 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.47579 .74108 m .4632 .7337 L .48749 .73487 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.4632 .2663 m .47579 .25892 L .49179 .25813 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.47579 .25892 m .4632 .2663 L .44103 .26855 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.52421 .74108 m .5368 .7337 L .55897 .73145 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.5368 .7337 m .52421 .74108 L .50821 .74187 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.52421 .25892 m .5368 .2663 L .51251 .26513 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.51251 .26513 m .50821 .25813 L .52421 .25892 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72364 .59906 m
.73172 .57789 L
s
.72075 .60499 m
.72364 .59906 L
s
.5 Mabswid
.459 .657 .499 r
.50821 .74187 m .51251 .73487 L .5368 .7337 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.51251 .73487 m .50821 .74187 L .49179 .74187 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.49179 .74187 m .48749 .73487 L .51251 .73487 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.48749 .26513 m .49179 .25813 L .50821 .25813 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.49179 .25813 m .48749 .26513 L .4632 .2663 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.50821 .25813 m .51251 .26513 L .48749 .26513 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71913 .60733 m
.72075 .60499 L
s
1 .5 0 r
.26987 .41744 m
.27226 .4114 L
s
.26396 .43671 m
.26987 .41744 L
s
.27226 .4114 m
.27356 .4091 L
s
0 0 0 r
.71777 .60807 m
.71913 .60733 L
s
1 .5 0 r
.27356 .4091 m
.2745 .40861 L
s
.5 Mabswid
.204 .225 .164 r
.68896 .34972 m .70983 .38297 L .69356 .3781 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.69356 .3781 m .67359 .34411 L .68896 .34972 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.70983 .61703 m .68896 .65028 L .67359 .65589 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.64944 .68472 m .67359 .65589 L .68896 .65028 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.35056 .31528 m .32641 .34411 L .31104 .34972 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.29017 .38297 m .31104 .34972 L .32641 .34411 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.30644 .6219 m .32641 .65589 L .31104 .65028 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.31104 .65028 m .29017 .61703 L .30644 .6219 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42138 .71641 m .44103 .73145 L .42217 .72827 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42217 .72827 m .39671 .71247 L .42138 .71641 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.39671 .28753 m .42217 .27173 L .44103 .26855 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.42217 .27173 m .39671 .28753 L .37793 .29232 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.57783 .72827 m .60329 .71247 L .62207 .70768 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.60329 .71247 m .57783 .72827 L .55897 .73145 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57783 .27173 m .60329 .28753 L .57862 .28359 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57862 .28359 m .55897 .26855 L .57783 .27173 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.3729 .68995 m .39671 .71247 L .37793 .70768 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.37793 .70768 m .35056 .68472 L .3729 .68995 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.35056 .31528 m .37793 .29232 L .39671 .28753 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.64944 .68472 m .62207 .70768 L .60329 .71247 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.62207 .29232 m .64944 .31528 L .6271 .31005 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.6271 .31005 m .60329 .28753 L .62207 .29232 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27445 .41028 m
.2745 .40861 L
s
.5 Mabswid
.368 .497 .336 r
.72534 .58014 m .70983 .61703 L .69356 .6219 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71757 .60671 m
.71777 .60807 L
s
.5 Mabswid
.372 .514 .354 r
.67359 .65589 m .69356 .6219 L .70983 .61703 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.70983 .38297 m .72534 .41986 L .7085 .41626 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.7085 .41626 m .69356 .3781 L .70983 .38297 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.2915 .58374 m .30644 .6219 L .29017 .61703 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.29017 .61703 m .27466 .58014 L .2915 .58374 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.32641 .34411 m .30644 .3781 L .29017 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.27466 .41986 m .29017 .38297 L .30644 .3781 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27349 .41578 m
.27445 .41028 L
s
.5 Mabswid
.351 .464 .307 r
.73489 .54072 m .72534 .58014 L .7085 .58374 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.69356 .6219 m .7085 .58374 L .72534 .58014 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71757 .60671 m
.71831 .60165 L
s
.5 Mabswid
.287 .351 .238 r
.72534 .41986 m .73489 .45928 L .71775 .45737 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.71775 .45737 m .7085 .41626 L .72534 .41986 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.30644 .3781 m .2915 .41626 L .27466 .41986 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.26511 .45928 m .27466 .41986 L .2915 .41626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26755 .4354 m
.27642 .4078 L
s
.5 Mabswid
.435 .578 .467 r
.28225 .54263 m .2915 .58374 L .27466 .58014 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.27466 .58014 m .26511 .54072 L .28225 .54263 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70875 .62152 m
.71671 .60279 L
s
.71671 .60279 m
.72242 .58938 L
s
.5 Mabswid
.551 .768 .591 r
.45078 .71923 m .4632 .7337 L .44103 .73145 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.44103 .73145 m .42138 .71641 L .45078 .71923 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.42138 .28359 m .44103 .26855 L .4632 .2663 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.44103 .26855 m .42138 .28359 L .39671 .28753 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.55897 .73145 m .57862 .71641 L .60329 .71247 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.57862 .71641 m .55897 .73145 L .5368 .7337 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.55897 .26855 m .57862 .28359 L .54922 .28077 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.54922 .28077 m .5368 .2663 L .55897 .26855 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.73489 .45928 m .73811 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.72088 .5 m .71775 .45737 L .73489 .45928 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.73811 .5 m .73489 .54072 L .71775 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.7085 .58374 m .71775 .54263 L .73489 .54072 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72242 .58938 m
.72641 .57999 L
s
.5 Mabswid
.32 .398 .325 r
.2915 .41626 m .28225 .45737 L .26511 .45928 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.26189 .5 m .26511 .45928 L .28225 .45737 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.27912 .5 m .28225 .54263 L .26511 .54072 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.26511 .54072 m .26189 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.71775 .54263 m .72088 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.28225 .45737 m .27912 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35168 .66105 m .3729 .68995 L .35056 .68472 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35056 .68472 m .32641 .65589 L .35168 .66105 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.39671 .28753 m .3729 .31005 L .35056 .31528 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.32641 .34411 m .35056 .31528 L .3729 .31005 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.67359 .65589 m .64944 .68472 L .6271 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.60329 .71247 m .6271 .68995 L .64944 .68472 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64944 .31528 m .67359 .34411 L .64832 .33895 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64832 .33895 m .6271 .31005 L .64944 .31528 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.48324 .7207 m .48749 .73487 L .4632 .7337 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.4632 .7337 m .45078 .71923 L .48324 .7207 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.45078 .28077 m .4632 .2663 L .48749 .26513 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.4632 .2663 m .45078 .28077 L .42138 .28359 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.5368 .7337 m .54922 .71923 L .57862 .71641 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.54922 .71923 m .5368 .7337 L .51251 .73487 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5368 .2663 m .54922 .28077 L .51676 .2793 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.51676 .2793 m .51251 .26513 L .5368 .2663 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.40284 .69431 m .42138 .71641 L .39671 .71247 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.39671 .71247 m .3729 .68995 L .40284 .69431 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.3729 .31005 m .39671 .28753 L .42138 .28359 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.6271 .68995 m .60329 .71247 L .57862 .71641 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.60329 .28753 m .6271 .31005 L .59716 .30569 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.59716 .30569 m .57862 .28359 L .60329 .28753 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27765 .41271 m
.27968 .40852 L
s
.27968 .40852 m
.28225 .406 L
s
.27261 .42867 m
.27433 .42458 L
s
.27211 .43249 m
.27261 .42867 L
s
.5 Mabswid
.576 .797 .602 r
.51676 .7207 m .51251 .73487 L .48749 .73487 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.48749 .73487 m .48324 .7207 L .51676 .7207 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.51251 .73487 m .51676 .7207 L .54922 .71923 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.48324 .2793 m .48749 .26513 L .51251 .26513 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.48749 .26513 m .48324 .2793 L .45078 .28077 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.51251 .26513 m .51676 .2793 L .48324 .2793 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27433 .42458 m
.27613 .42231 L
s
.27211 .43249 m
.27345 .4341 L
s
.28225 .406 m
.28423 .40552 L
s
.27613 .42231 m
.28008 .41961 L
s
0 0 0 r
.70853 .60964 m
.71206 .60527 L
s
.5 Mabswid
.226 .247 .193 r
.3729 .31005 m .35168 .33895 L .32641 .34411 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.30644 .3781 m .32641 .34411 L .35168 .33895 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.33398 .62642 m .35168 .66105 L .32641 .65589 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.32641 .65589 m .30644 .6219 L .33398 .62642 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.67359 .34411 m .69356 .3781 L .66602 .37358 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.66602 .37358 m .64832 .33895 L .67359 .34411 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.69356 .6219 m .67359 .65589 L .64832 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.6271 .68995 m .64832 .66105 L .67359 .65589 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27345 .4341 m
.27546 .43374 L
s
0 0 0 r
.7183 .58409 m
.71861 .58832 L
s
.70572 .61202 m
.70853 .60964 L
s
1 .5 0 r
.28423 .40552 m
.28563 .40709 L
s
0 0 0 r
.70255 .61275 m
.70572 .61202 L
s
1 .5 0 r
.28008 .41961 m
.28218 .4173 L
s
.27546 .43374 m
.27816 .4314 L
s
0 0 0 r
.71705 .58209 m
.7183 .58409 L
s
1 .5 0 r
.28495 .41103 m
.28563 .40709 L
s
.5 Mabswid
.613 .837 .639 r
.43899 .69745 m .45078 .71923 L .42138 .71641 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.42138 .71641 m .40284 .69431 L .43899 .69745 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.40284 .30569 m .42138 .28359 L .45078 .28077 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.42138 .28359 m .40284 .30569 L .3729 .31005 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.57862 .71641 m .59716 .69431 L .6271 .68995 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.59716 .69431 m .57862 .71641 L .54922 .71923 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.57862 .28359 m .59716 .30569 L .56101 .30255 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.56101 .30255 m .54922 .28077 L .57862 .28359 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28218 .4173 m
.28426 .41307 L
s
.28426 .41307 m
.28495 .41103 L
s
.27816 .4314 m
.27998 .42727 L
s
0 0 0 r
.71378 .58265 m
.71705 .58209 L
s
.5 Mabswid
.315 .371 .289 r
.35168 .33895 m .33398 .37358 L .30644 .3781 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.2915 .41626 m .30644 .3781 L .33398 .37358 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.32065 .58709 m .33398 .62642 L .30644 .6219 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.30644 .6219 m .2915 .58374 L .32065 .58709 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.7085 .58374 m .69356 .6219 L .66602 .62642 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7011 .61131 m
.70255 .61275 L
s
.5 Mabswid
.5 .674 .477 r
.64832 .66105 m .66602 .62642 L .69356 .6219 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.69356 .3781 m .7085 .41626 L .67935 .41291 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.67935 .41291 m .66602 .37358 L .69356 .3781 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.38619 .66538 m .40284 .69431 L .3729 .68995 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.3729 .68995 m .35168 .66105 L .38619 .66538 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.35168 .33895 m .3729 .31005 L .40284 .30569 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.64832 .66105 m .6271 .68995 L .59716 .69431 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.6271 .31005 m .64832 .33895 L .61381 .33462 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.61381 .33462 m .59716 .30569 L .6271 .31005 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.31236 .54441 m .32065 .58709 L .2915 .58374 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.2915 .58374 m .28225 .54263 L .31236 .54441 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.33398 .37358 m .32065 .41291 L .2915 .41626 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29222 .40583 m
.29241 .40775 L
s
.29222 .40583 m
.29386 .4036 L
s
.5 Mabswid
.444 .557 .432 r
.28225 .45737 m .2915 .41626 L .32065 .41291 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.7085 .41626 m .71775 .45737 L .68764 .45559 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.68764 .45559 m .67935 .41291 L .7085 .41626 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.71775 .54263 m .7085 .58374 L .67935 .58709 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71068 .58543 m
.71378 .58265 L
s
.5 Mabswid
.497 .66 .462 r
.66602 .62642 m .67935 .58709 L .7085 .58374 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70033 .60783 m
.7011 .61131 L
s
.5 Mabswid
.63 .856 .647 r
.47919 .69909 m .48324 .7207 L .45078 .71923 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.45078 .71923 m .43899 .69745 L .47919 .69909 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.43899 .30255 m .45078 .28077 L .48324 .2793 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.45078 .28077 m .43899 .30255 L .40284 .30569 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.54922 .71923 m .56101 .69745 L .59716 .69431 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.56101 .69745 m .54922 .71923 L .51676 .7207 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.54922 .28077 m .56101 .30255 L .52081 .30091 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.52081 .30091 m .51676 .2793 L .54922 .28077 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29386 .4036 m
.29406 .40552 L
s
0 0 0 r
.70033 .60783 m
.70149 .60185 L
s
.70668 .59053 m
.71068 .58543 L
s
1 .5 0 r
.29241 .40775 m
.29406 .40552 L
s
0 0 0 r
.70149 .60185 m
.70307 .59752 L
s
.70307 .59752 m
.70668 .59053 L
s
.5 Mabswid
.444 .557 .432 r
.32065 .41291 m .31236 .45559 L .28225 .45737 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28233 .4463 m
.28913 .41808 L
s
.5 Mabswid
.489 .624 .484 r
.27912 .5 m .28225 .45737 L .31236 .45559 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.30955 .5 m .31236 .54441 L .28225 .54263 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.28225 .54263 m .27912 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.71775 .45737 m .72088 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.69045 .5 m .68764 .45559 L .71775 .45737 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.72088 .5 m .71775 .54263 L .68764 .54441 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.67935 .58709 m .68764 .54441 L .71775 .54263 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.51676 .7207 m .52081 .69909 L .56101 .69745 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.52081 .69909 m .51676 .7207 L .48324 .7207 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.48324 .7207 m .47919 .69909 L .52081 .69909 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.51676 .2793 m .52081 .30091 L .47919 .30091 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.47919 .30091 m .48324 .2793 L .51676 .2793 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.48324 .2793 m .47919 .30091 L .43899 .30255 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.31236 .45559 m .30955 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.68764 .54441 m .69045 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.40284 .30569 m .38619 .33462 L .35168 .33895 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.33398 .37358 m .35168 .33895 L .38619 .33462 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.3722 .63023 m .38619 .66538 L .35168 .66105 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.35168 .66105 m .33398 .62642 L .3722 .63023 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.64832 .33895 m .66602 .37358 L .6278 .36977 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.6278 .36977 m .61381 .33462 L .64832 .33895 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.66602 .62642 m .64832 .66105 L .61381 .66538 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.59716 .69431 m .61381 .66538 L .64832 .66105 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6854 .6158 m
.68985 .61512 L
s
.5 Mabswid
.365 .429 .314 r
.38619 .33462 m .40284 .30569 L .43899 .30255 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.42833 .66851 m .43899 .69745 L .40284 .69431 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.40284 .69431 m .38619 .66538 L .42833 .66851 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.61381 .66538 m .59716 .69431 L .56101 .69745 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.59716 .30569 m .61381 .33462 L .57167 .33149 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.57167 .33149 m .56101 .30255 L .59716 .30569 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68306 .6143 m
.6854 .6158 L
s
.68133 .6107 m
.68306 .6143 L
s
.67974 .6097 m
.68758 .58588 L
s
.68133 .6107 m
.68188 .60457 L
s
.5 Mabswid
.397 .478 .36 r
.38619 .33462 m .3722 .36977 L .33398 .37358 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.32065 .41291 m .33398 .37358 L .3722 .36977 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.36161 .58993 m .3722 .63023 L .33398 .62642 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.33398 .62642 m .32065 .58709 L .36161 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.67935 .58709 m .66602 .62642 L .6278 .63023 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67736 .61692 m
.67974 .6097 L
s
.5 Mabswid
.576 .769 .553 r
.61381 .66538 m .6278 .63023 L .66602 .62642 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.66602 .37358 m .67935 .41291 L .63839 .41007 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.63839 .41007 m .6278 .36977 L .66602 .37358 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.47552 .67016 m .47919 .69909 L .43899 .69745 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.43899 .69745 m .42833 .66851 L .47552 .67016 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.42833 .33149 m .43899 .30255 L .47919 .30091 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.43899 .30255 m .42833 .33149 L .38619 .33462 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.56101 .69745 m .57167 .66851 L .61381 .66538 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.57167 .66851 m .56101 .69745 L .52081 .69909 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.56101 .30255 m .57167 .33149 L .52448 .32984 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.52448 .32984 m .52081 .30091 L .56101 .30255 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.3722 .36977 m .38619 .33462 L .42833 .33149 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.41933 .63301 m .42833 .66851 L .38619 .66538 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.38619 .66538 m .3722 .63023 L .41933 .63301 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.61381 .33462 m .6278 .36977 L .58067 .36699 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.58067 .36699 m .57167 .33149 L .61381 .33462 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.6278 .63023 m .61381 .66538 L .57167 .66851 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.52448 .67016 m .52081 .69909 L .47919 .69909 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.47919 .69909 m .47552 .67016 L .52448 .67016 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.52081 .69909 m .52448 .67016 L .57167 .66851 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.47552 .32984 m .47919 .30091 L .52081 .30091 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.47919 .30091 m .47552 .32984 L .42833 .33149 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.52081 .30091 m .52448 .32984 L .47552 .32984 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.35499 .54593 m .36161 .58993 L .32065 .58709 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.32065 .58709 m .31236 .54441 L .35499 .54593 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.3722 .36977 m .36161 .41007 L .32065 .41291 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.31236 .45559 m .32065 .41291 L .36161 .41007 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.67935 .41291 m .68764 .45559 L .64501 .45407 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.64501 .45407 m .63839 .41007 L .67935 .41291 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.68764 .54441 m .67935 .58709 L .63839 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.6278 .63023 m .63839 .58993 L .67935 .58709 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67351 .59678 m
.68025 .58655 L
s
.65006 .6324 m
.66411 .61107 L
s
.66411 .61107 m
.67351 .59678 L
s
.648 .61174 m
.65006 .6324 L
s
.64778 .60955 m
.648 .61174 L
s
.64865 .60549 m
.66973 .60373 L
s
.5 Mabswid
.511 .643 .487 r
.36161 .41007 m .35499 .45407 L .31236 .45559 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.30955 .5 m .31236 .45559 L .35499 .45407 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.35274 .5 m .35499 .54593 L .31236 .54441 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.31236 .54441 m .30955 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.68764 .45559 m .69045 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.64726 .5 m .64501 .45407 L .68764 .45559 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.69045 .5 m .68764 .54441 L .64501 .54593 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.63839 .58993 m .64501 .54593 L .68764 .54441 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64573 .58898 m
.64778 .60955 L
s
.5 Mabswid
.55 .702 .533 r
.35499 .45407 m .35274 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.64501 .54593 m .64726 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.41933 .36699 m .42833 .33149 L .47552 .32984 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.47241 .63448 m .47552 .67016 L .42833 .66851 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.42833 .66851 m .41933 .63301 L .47241 .63448 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.42833 .33149 m .41933 .36699 L .3722 .36977 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.57167 .66851 m .58067 .63301 L .6278 .63023 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.57167 .33149 m .58067 .36699 L .52759 .36552 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.52759 .36552 m .52448 .32984 L .57167 .33149 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.58067 .63301 m .57167 .66851 L .52448 .67016 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.41249 .59201 m .41933 .63301 L .3722 .63023 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.3722 .63023 m .36161 .58993 L .41249 .59201 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.36161 .41007 m .3722 .36977 L .41933 .36699 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.63839 .58993 m .6278 .63023 L .58067 .63301 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.6278 .36977 m .63839 .41007 L .58751 .40799 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.58751 .40799 m .58067 .36699 L .6278 .36977 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.47241 .36552 m .47552 .32984 L .52448 .32984 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.52759 .63448 m .52448 .67016 L .47552 .67016 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.47552 .67016 m .47241 .63448 L .52759 .63448 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.47552 .32984 m .47241 .36552 L .41933 .36699 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.52448 .67016 m .52759 .63448 L .58067 .63301 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.52448 .32984 m .52759 .36552 L .47241 .36552 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.4082 .54705 m .41249 .59201 L .36161 .58993 L p F P
.505 .664 .505 r
s
.627 .817 .614 r
.36161 .58993 m .35499 .54593 L .4082 .54705 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.41933 .36699 m .41249 .40799 L .36161 .41007 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.35499 .45407 m .36161 .41007 L .41249 .40799 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.64501 .54593 m .63839 .58993 L .58751 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.58067 .63301 m .58751 .59201 L .63839 .58993 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.63839 .41007 m .64501 .45407 L .5918 .45295 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.5918 .45295 m .58751 .40799 L .63839 .41007 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.47004 .59312 m .47241 .63448 L .41933 .63301 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.41933 .63301 m .41249 .59201 L .47004 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.41249 .40799 m .41933 .36699 L .47241 .36552 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.58751 .59201 m .58067 .63301 L .52759 .63448 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.58067 .36699 m .58751 .40799 L .52996 .40688 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.52996 .40688 m .52759 .36552 L .58067 .36699 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.41249 .40799 m .4082 .45295 L .35499 .45407 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.35274 .5 m .35499 .45407 L .4082 .45295 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.40674 .5 m .4082 .54705 L .35499 .54593 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.35499 .54593 m .35274 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.64501 .45407 m .64726 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.59326 .5 m .5918 .45295 L .64501 .45407 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.64726 .5 m .64501 .54593 L .5918 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.58751 .59201 m .5918 .54705 L .64501 .54593 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.4082 .45295 m .40674 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.5918 .54705 m .59326 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.52996 .59312 m .52759 .63448 L .47241 .63448 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.47241 .63448 m .47004 .59312 L .52996 .59312 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.52759 .63448 m .52996 .59312 L .58751 .59201 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.47004 .40688 m .47241 .36552 L .52759 .36552 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.47241 .36552 m .47004 .40688 L .41249 .40799 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.52759 .36552 m .52996 .40688 L .47004 .40688 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.4082 .45295 m .41249 .40799 L .47004 .40688 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.46856 .54764 m .47004 .59312 L .41249 .59201 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.41249 .59201 m .4082 .54705 L .46856 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.5918 .54705 m .58751 .59201 L .52996 .59312 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.58751 .40799 m .5918 .45295 L .53144 .45236 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.53144 .45236 m .52996 .40688 L .58751 .40799 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.47004 .40688 m .46856 .45236 L .4082 .45295 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.40674 .5 m .4082 .45295 L .46856 .45236 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.46805 .5 m .46856 .54764 L .4082 .54705 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.4082 .54705 m .40674 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.5918 .45295 m .59326 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.53195 .5 m .53144 .45236 L .5918 .45295 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.59326 .5 m .5918 .54705 L .53144 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.52996 .59312 m .53144 .54764 L .5918 .54705 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.46856 .45236 m .47004 .40688 L .52996 .40688 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.53144 .54764 m .52996 .59312 L .47004 .59312 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.47004 .59312 m .46856 .54764 L .53144 .54764 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.52996 .40688 m .53144 .45236 L .46856 .45236 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.46856 .45236 m .46805 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.53144 .54764 m .53195 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.46805 .5 m .46856 .45236 L .53144 .45236 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.53195 .5 m .53144 .54764 L .46856 .54764 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.46856 .54764 m .46805 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.53144 .45236 m .53195 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?40/>3V4@21ZH7a0;3PiP40oooo003U0;3PiPd0PJV10P0S9Qd0
0`21ZH409BPN02DX7P0602DX7P04086YP@0T9ah092LN02@W7Pd0PJV1i@2`h>H10?ooo`00h@2`h>H2
086YP@0301TM5P21ZH40PJV100D07b8J0P21ZH4702<V7@03086YP@0U:1h09BPN00L09BPN00<0PJV1
02@W7P0T9ah01@0T9ah2086YP@D08B@K1@21ZH7Q0;3PiP40oooo003M0;3PiP<0PJV10P0I7AH2086Y
P@D07b8J0P21ZH4802<V7@03086YP@0U:1h09BPN00P09BPN00<0PJV102@W7P0T9ah01`0T9ah2086Y
P@D08B@K0P21ZH400`0L7aP0PJV1086YP@02086YPMd0/>3V0@3oool00=T0/>3V0`21ZH4401TM5P80
PJV10`0O8QXY086YP@<08B@K0P21ZH4201`O60D0PJV1f@2`h>H10?ooo`00eP2`h>H3086YP@D06AdF
1`21ZH400`0`<RH0PJV103Df:@0;03Df:@03086YP@0g>2/0=cP[00T0=cP[00<0PJV103Hh:P0f>2X0
2P0f>2X00`21ZH40<c@X086YP@06086YP@<071lH1@21ZH7F0;3PiP40oooo003C0;3PiP<0PJV10P0I
7AH7086YP@H0<38V00<0PJV103Df:@0e=RT02P0e=RT00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103<d:00c=2P0100c=2P7086YP@0301`O6021ZH40PJV10080PJV1d`2`
h>H10?ooo`00d02`h>H8086YP@80:2/Q0P21ZH48030b9P03086YP@0e=RT0=CHY00/0=CHY00<0PJV1
03Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0c=2P0<c@X00H0<c@X0P21ZH42
02d_8`P0PJV1d02`h>H10?ooo`00c@2`h>H5086YP@L0:2/Q00<0PJV1030b9P0`<RH01`0`<RH00`21
ZH40=CHY03Df:@0<03Df:@03086YP@0g>2/0=cP[00/0=cP[00<0PJV103Hh:P0f>2X02`0f>2X00`21
ZH40<c@X03<d:00803<d:003086YP@0];b<0;BlS00D0;BlS1@21ZH7=0;3PiP40oooo003:0;3PiP<0
PJV100<07R4I086YP@21ZH40200X:b400`21ZH40<38V030b9P08030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X00<0PJV102d_8`0];b<01P0];b<2086YP@0402<V7021ZH40PJV1086YPLX0/>3V0@3oool00<P0
/>3V0`21ZH4201hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH4:030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X0P21ZH4802d_8`03086YP@0S9Q`08bHL00<0PJV1b02`h>H10?ooo`00aP2`h>H3086YP@807R4I
0P21ZH4802P[8@03086YP@0`<RH0<38V00T0<38V00<0PJV103Df:@0e=RT01@0e=RTQ086YP@L0=SPZ
00<0PJV103<d:00c=2P02@0c=2P00`21ZH40;BlS02d_8`0602d_8`80PJV10P0S9Q`3086YPLH0/>3V
0@3oool00<@0/>3V0`21ZH4301hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH45030b9Pl0PJV1201;
E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>Ech0CULn00H0CULn3`21ZH4503<d:080PJV1200]
;b<01021ZH408bHL02<V700S9Q`3086YPL@0/>3V0@3oool00<80/>3V0`21ZH4301hQ6@80PJV11@0X
:b4;086YP@D0@dXe00<0PJV104]D?01;E3`03`1;E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>
Ech0CULn00h0CULn00<0PJV104Q@>@18D3T01018D3T;086YP@D0;BlS0P21ZH4302<V70<0PJV1`P2`
h>H10?ooo`00`02`h>H3086YP@<07R4I0P21ZH400`0X:b40PJV1086YP@04086YP@80=STZ00<0PJV1
04=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00>04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV1
04iG?P1>Ech03P1>Ech00`21ZH40B50i04Q@>@0;04Q@>@03086YP@0m@S00?D8`00H0PJV100<0;BlS
086YP@21ZH400`0S9Q`3086YPL00/>3V0@3oool00;l0/>3V0P21ZH4201hQ6@H0PJV11`0f>BX00`21
ZH40@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21
ZH40CULn04iG?P0>04iG?P03086YP@18D3T0B50i00`0B50i00<0PJV103e2<00m@S001@0m@S06086Y
P@808bHL0P21ZH6o0;3PiP40oooo002m0;3PiPH0PJV100<0:B/Q086YP@0f>BX02P0f>BX00`21ZH40
@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21ZH40
CULn04iG?P0?04iG?P03086YP@18D3T0B50i00/0B50i00<0PJV103e2<00m@S002@0m@S000`21ZH40
;c4U086YP@05086YPKd0/>3V0@3oool00;/0/>3V1021ZH4402T[8@03086YP@0f>BX0=STZ00T0=STZ
00<0PJV104=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn00l0CUTn
00<0PJV104iG?P1>Ech03`1>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m@S00?D8`00T0?D8`
00<0PJV102la9@0_<BD00P0_<BD4086YPK/0/>3V0@3oool00;T0/>3V0`21ZH4602T[8@03086YP@0f
>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>
FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m
@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD3086YPKT0/>3V0@3oool00;L0/>3V1021ZH46
02T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00A
04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0=
04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086YPKL0/>3V0@3oool0
0;H0/>3V1021ZH4602T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03@13BSD00`21
ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn0140CUTn00<0PJV104iG?P1>Ech0401>Ech00`21
ZH40B50i04Q@>@0=04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086Y
PKH0/>3V0@3oool00;D0/>3V00<0PJV101TM5P21ZH401`0Y:b400`21ZH40=STZ03Hi:P0903Hi:P03
086YP@13BSD0@dXe00d0@dXe00<0PJV104]D?01;E3`04@1;E3`00`21ZH40CUTn04iI?P0A04iI?P03
086YP@1>Ech0CULn0100CULn00<0PJV104Q@>@18D3T03P18D3T00`21ZH40?D8`03e2<00903e2<003
086YP@0_<BD0;c4U00D0;c4U00<0PJV1020S6`21ZH40]@2`h>H10?ooo`00/`2`h>H2086YP@0301TM
5P21ZH40:B/Q00H0:B/Q00<0PJV103Hi:P0f>BX02P0f>BX00`21ZH40@dXe04=:=@0904=:=DD0PJV1
2`18D3T00`21ZH40?D8`03e2<00:03e2<003086YP@0_<BD0;c4U00D0;c4U00@0PJV1020S6`21ZH40
PJV1/`2`h>H10?ooo`00/P2`h>H01021ZH406AdF01TM5P21ZH4702T[8@03086YP@0f>BX0=STZ00X0
=STZ00@0PJV104=:=@13BSD0@dXe2@21ZH4405e]D003086YP@1SMU@0HgID0140HgID00<0PJV106Ag
E01TMe@04@1TMe@00`21ZH40H75>061aCP0A061aCP03086YP@1JJDP0FVU80080FVU82@21ZH4304Q@
>@03086YP@0m@S00?D8`00X0?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S6`21ZH6b
0;3PiP40oooo002a0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0PJV103Hi:P0f>BX01`0f>BX8
086YP@`0GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0
H75>0180H75>00<0PJV105YYB01JJDP02P1JJDP8086YP@T0?D8`00<0PJV102la9@0_<BD01@0_<BD0
1021ZH4082<K020S6`21ZH6a0;3PiP40oooo002`0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0
PJV103Hi:P0f>BX02021ZH42051LA@03086YP@1MKE00GFe@00l0GFe@00<0PJV106=fE01SMU@04P1S
MU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP03`1J
JDP00`21ZH40D5a0051L@008086YP@80?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S
6`21ZH6`0;3PiP40oooo002^0;3PiP80PJV100<06AdF086YP@21ZH401P0Y:b45086YP@X0D5a500<0
PJV105e]D01MKE003P1MKE000`21ZH40HgID06=fE00B06=fE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1061aCP1PLDh04P1PLDh00`21ZH40FVU805YYB00>05YYB003086YP@1@G400D5a000P0D5a01@21
ZH4602la9@80PJV100<082<K086YP@21ZH40[P2`h>H10?ooo`00[@2`h>H01021ZH406AdF01TM5P21
ZH4402T[8@D0PJV13@1@G4D00`21ZH40GFe@05e]D00?05e]D003086YP@1SMU@0HgID0180HgID00<0
PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0B061aCP03086YP@1JJDP0FVU800l0FVU800<0
PJV1051L@01@G4002`1@G405086YP@@0;c4U00@0PJV1020S6`0P8a/0PJV1[@2`h>H10?ooo`00[02`
h>H01@21ZH406AdF01TM5P21ZH40:B/Q00@0PJV1100i?c400`21ZH40D5a5051LA@0:051LA@03086Y
P@1MKE00GFe@0100GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00C06AgE003086Y
P@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP0401JJDP00`21ZH40D5a0051L@00:051L@003086Y
P@0oAS80?dHb0080?dHb1021ZH401@0_<BD0PJV1020S6`0P8a/0PJV10:`0/>3V0@3oool00:/0/>3V
00<0PJV101TM5P21ZH400`21ZH4703To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00
3`1MKE000`21ZH40HgID06=fE00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh0
4`1PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS80
1@0oAS84086YP@03020S6`21ZH40/>3V0:X0/>3V0@3oool00:T0/>3V00<0PJV101TM5P21ZH400P21
ZH4903To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00401MKE000`21ZH40HgID06=f
E00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh04`1PLDh00`21ZH40FVU805YY
B00@05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS801`0oAS85086YPJT0/>3V0@3o
ool00:P0/>3V0`21ZH400`0Q91`0PJV103To<@0803To<@03086YP@1@G4D0D5a500/0D5a500<0PJV1
05e]D01MKE00401MKE000`21ZH40HgID06=fE00D06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1
061aCP1PLDh0501PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000`0D5a000<0PJV1
03m6<P0oAS801`0oAS800`21ZH40:B/Q086YP@02086YPJP0/>3V0@3oool00:L0/>3V0P21ZH42024T
7003086YP@0i?c40>Cla00P0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00@05e]
D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0D061a
CP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6
<P03086YP@0Y:b40:B/Q0080PJV1Y`2`h>H10?ooo`00YP2`h>H00`21ZH408B@L024T7002024T7003
086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00A05e]D003
086YP@1SMU@0HgID01<0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>061aCP0C061aCP03
086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0703m6<P03
086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y@2`h>H00`21ZH408B@L
024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@
05e]D00@05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>
061aCP0D061aCP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G400301@G4000`21ZH40?dHb
03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00Y02`
h>H00`21ZH408B@L024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1T
Me@00`21ZH40H75>061aCP0D061aCP03086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G400301@
G4000`21ZH40?dHb03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0XP2`
h>H10?ooo`00Y02`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla00<0PJV1051LA@1@G4D02`1@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID00X0HgID;`21ZH4<061aCP03086YP@1J
JDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6<P05086YP@0Y
:b40:B/Q02T[8@21ZH40Y02`h>H10?ooo`00X`2`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla
00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@05e]D00705e]D1L0PJV12`1fT6P00`21ZH40MY1W
07J@I`0E07J@I`03086YP@1bRf80LX]R00T0LX]R5`21ZH4905YYB003086YP@1@G400D5a000`0D5a0
00<0PJV103m6<P0oAS80200oAS801@21ZH40:B/Q02T[8@0Y:b40PJV10:<0/>3V0@3oool00:80/>3V
00D0PJV1024T700Q91`08B@L086YP@0:03To<@03086YP@1@G4D0D5a500X0D5a53@21ZH4:0769I@03
086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03
086YP@1YOeP0JGmH00P0JGmH3@21ZH4<051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[8@0Y
:b40:B/Q086YP@2R0;3PiP40oooo002Q0;3PiP05086YP@0Q91`08B@L024T7021ZH402P0i?c400`21
ZH40D5a5051LA@05051LA@H0PJV10P1UNU`00`21ZH40LHUU0769I@0B0769I@03086YP@1fT6P0MY1X
01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03086YP@1YOeP0JGmH
0180JGmH00<0PJV105i`C01NL4`01P21ZH47051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[
8@0Y:b40:B/Q086YP@2Q0;3PiP40oooo002P0;3PiP03086YP@0Q91`08B@L00808B@L00<0PJV103To
<@0i?c40200i?c400`21ZH40D5a5086YP@05086YP@L0IGYL00<0PJV10769I@1aRFD04P1aRFD00`21
ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01D0MY1W00<0PJV107:;HP1bRf805P1bRf800`21
ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00D0GW1<1P21ZH400`1@G400PJV103m6<P0903m6
<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00W`2`h>H00`21ZH40
8B@L024T7002024T7003086YP@0i?c40>Cla00D0>Cla1P21ZH4=06EjG003086YP@1aRFD0LHUU0180
LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01D0
LX]R00<0PJV106UoF01YOeP04P1YOeP00`21ZH40GW1<05i`C00;05i`C0H0PJV11`0oAS800`21ZH40
:B/Q02T[8@0202T[8@03086YP@2`h>H0/>3V09d0/>3V0@3oool009h0/>3V00<0PJV1024T700Q91`0
0P0Q91`00`21ZH40>Cla03To<@06086YP@80D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU
0769I@0C0769I@03086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R
07:;HP0E07:;HP03086YP@1YOeP0JGmH01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o
04iK?`06086YP@80?dHb00<0PJV102T[8@0Y:b400P0Y:b400`21ZH40/>3V0;3PiP2L0;3PiP40oooo
002N0;3PiP03086YP@0Q91`08B@L00D0PJV1201@GTT00`21ZH40IGYL06EjG00=06EjG003086YP@1a
RFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1b
Rf80LX]R01D0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`C00=05i`C003086YP@1>
Fcl0CU/o00H0CU/o1@21ZH4202T[8@03086YP@2`h>H0/>3V09`0/>3V0@3oool009d0/>3V00<0PJV1
024T7021ZH400P21ZH4;051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD04P1aRFD0
0`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf80
0`21ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl3
086YP@0302T[8@21ZH40/>3V09`0/>3V0@3oool009`0/>3V0`21ZH42030e;@03086YP@1@GTT0D5i9
00T0D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU0769I@0C0769I@03086YP@1fT6P0MY1X
01H0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH
01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY
00<0PJV1W02`h>H10?ooo`00V`2`h>H2086YP@<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00@0PJV103@i:@0d>BT0=3TY0P21ZH6K0;3P
iP40oooo002J0;3PiP03086YP@0`=Bd0<3D]00<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00=06EjG003086YP@1aRFD0LHUU01@0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00<0PJV103@i:@0d>BT00`0d>BT00`21ZH40
/>3V0;3PiP2H0;3PiP40oooo002I0;3PiP80PJV1100`=Bd00`21ZH40D5i9051NB@09051NB@03086Y
P@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086Y
P@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086Y
P@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl00`21ZH40=3TY03@i:@0203@i:@80PJV1
V@2`h>H10?ooo`00V02`h>H2086YP@@0<3D]00<0PJV1051NB@1@GTT02P1@GTT00`21ZH40IGYL06Ej
G00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05`1fT6P00`21ZH40MY1W07J@
I`0G07J@I`03086YP@1bRf80LX]R01L0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`
C00>05i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i:@0d>BT00P0d>BT2086YPIP0/>3V0@3o
ool009L0/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03P1UNU`0
0`21ZH40LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L0
0`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03P1NL4`0
0`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6G0;3PiP40oooo002G0;3P
iP80PJV1100`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769
I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;
HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK
?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i:@03086YP@0I71H0/>3V09H0/>3V0@3oool009H0
/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40
LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L00`21ZH40
LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03`1NL4`00`21ZH40
CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6F0;3PiP40oooo002E0;3PiP80PJV1
1@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0
501aRFD00`21ZH40MY1X07J@J00G07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;HP1bRf80
5`1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl0
2P1>Fcl00`21ZH40=3TY03@i:@0303@i:@03086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V0P21
ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40LHUU0769
I@0D0769I@03086YP@1fT6P0MY1X00/0MY1X=@21ZH4=07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0
PJV105i`C01NL4`03`1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21
ZH6E0;3PiP40oooo002D0;3PiP80PJV11@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0
IGYL00h0IGYL00<0PJV10769I@1aRFD02P1aRFDI086YP@`0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H0
0`21ZH40P9ma082OL@0:082OLAT0PJV1301YOeP00`21ZH40GW1<05i`C00>05i`C003086YP@1>Fcl0
CU/o00X0CU/o00<0PJV103@i:@0d>BT00`0d>BT2086YPI@0/>3V0@3oool009@0/>3V0P21ZH44030e
;@03086YP@1@GTT0D5i900X0D5i900<0PJV106EjG01UNU`02`1UNU`A086YP@/0Oiie00<0PJV108BT
N024Y7P05`24Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01L0P9ma00<0PJV107RE
J01hUFP02@1hUFPA086YP@d0GW1<00<0PJV104iK?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i
:@80PJV1U02`h>H10?ooo`00T`2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT02P1@GTT01021ZH40
IGYL06EjG01UNU`:086YP@@0MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00G08BT
N003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg405`20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0080JX9H2P21ZH4305i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i
:@0d>BT00`0d>BT2086YPI<0/>3V0@3oool00980/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900L0
D5i92021ZH4=07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06024Y7P00`21ZH40
Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP0501hUFP00`21ZH40
JX9H06Z2F00<06Z2F0P0PJV12@1>Fcl00`21ZH40=3TY03@i:@0303@i:@80PJV1TP2`h>H10?ooo`00
TP2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT01`21ZH4306=iGP03086YP@1fTFh0MY5^00l0MY5^
00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H00l0JX9H
00@0PJV105Y/B@1JK4T0FVa91`21ZH4204iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6B0;3PiP40
oooo002A0;3PiP80PJV1100`=Bd5086YP@T0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie
07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma
082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa9
05Y/B@0705Y/B@D0PJV1100d>BT2086YPI40/>3V0@3oool00900/>3V0P21ZH43030e;@80PJV100<0
@Ti1086YP@1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0
PJV108BTN024Y7P06024Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0
PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900X0FVa900@0
PJV1041;=021ZH40PJV10`0d>BT00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002@0;3PiP03086YP@0`
=Bd0PJV10080PJV10P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^00l0MY5^00<0
PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0
PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0
PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=005086YPI00/>3V0@3oool008l0/>3V0`21ZH45
049>@@03086YP@1SNEh0HgUN00X0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E
07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma082OL@0I
082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP03`1ZPUP00`21ZH40FVa905Y/B@0;
05Y/B@03086YP@10Bc@0@4/d00<0@4/d0`21ZH6?0;3PiP40oooo002?0;3PiP80PJV11P12CT400`21
ZH40HgUN06=iGP0:06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21
ZH40Q:Ah08BTN00I08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21
ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02P1JK4T00`21
ZH40@4/d041;=004041;=080PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@H0@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024
Y7P06024Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01h
UFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010
Bc@01010Bc@2086YPHh0/>3V0@3oool008h0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0PJV101`P602`h>H0S@2`h>H10?ooo`00S@2`h>H2086YP@H0@Ti100<0PJV106=iGP1SNEh02`1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06024
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010
Bc@2086YPHd0/>3V0@3oool008d0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV1
07JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV1
08BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV1
06Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d0P21ZH6=
0;3PiP40oooo002<0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21
ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06@24Y7P00`21
ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05@1hUFP00`21
ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@00`21
ZH40720H086YP@2<0;3PiP40oooo002<0;3PiP80PJV11P12CT400`21ZH40HgUN06=iGP0;06=iGP03
086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00I08BTN003
086YP@24Y7H0Q:Af01/0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21ZH40N9EX07REJ00E07REJ003
086YP@1ZPUP0JX9H0140JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080
PJV1S02`h>H10?ooo`00R`2`h>H00`21ZH406b<O086YP@06049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01H0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0PJV101`P6021ZH40R`2`h>H10?ooo`00R`2`h>H2086YP@D0@Ti100<0ogl0049>@@21ZH403@1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06@24
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010
Bc@00`21ZH40720H086YP@2;0;3PiP40oooo002:0;3PiP04086YP@0K8al0ogl00?mo00<0@Ti10`3o
O`0=06=iGP03086YP@1fTFh0MY5^0140MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BT
N00J08BTN003086YP@24Y7H0Q:Af01/0Q:Af00<0PJV1082OL@20Wg406P20Wg400`21ZH40N9EX07RE
J00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T0301JK4T00`21ZH40@4/d041;
=004041;=003086YP@0L81P0PJV108X0/>3V0@3oool008T0/>3V00<0ogl0086YP@3oO`000`3oO`00
0`12CT40ogl00?mo00020?mo00d0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F
07nNM@03086YP@24Y7P0Q:Ah01X0Q:Ah00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0J
082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP04@1ZPUP00`21ZH40FVa905Y/B@0;
05Y/B@03086YP@10Bc@0@4/d00@0@4/d00<0PJV101`P6021ZH40RP2`h>H10?ooo`00Q`2`h>H<0?mo
00h0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0:07nNMG40PJV1301hUFP00`21
ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900`0FVa900<0PJV1041;=010Bc@01010Bc@2086Y
PHX0/>3V0@3oool008L0/>3V1@3oO`001012CT40ogl00?mo0012CT420?mo0003086YP@1SNEh0HgUN
00`0HgUN00<0PJV107JAKP1fTFh0301fTFhA086YP@`0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@02P23YG@A086Y
P@h0JX9H00<0PJV105Y/B@1JK4T0301JK4T00`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV1
08T0/>3V0@3oool008H0/>3V1@3oO`000`21ZH40@Ti10?mo00020?mo0080@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0307JAKPX0PJV11022Y7`00`21ZH40Rjn208^_PP0F08^_PP03
086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h806`2>/h800`21ZH40Rjmm08^_O@0J08^_O@03
086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H00P1gU6H:086YP@D0JX9H00<0PJV105Y/B@1J
K4T02`1JK4T00`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV108T0/>3V0@3oool008H0/>3V
1@3oO`001012CT40ogl00?mo003oO`02049>@@03086YP@1SNEh0HgUN00D0HgUN3@21ZH4>08:TO003
086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0K08jcPP03
086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0<07NDIPd0
PJV11`1JK4T00`21ZH40@4/d041;=004041;=003086YP@0L81P0PJV108P0/>3V0@3oool008H0/>3V
0`3oO`000`0K8al0PJV1049>@@020?mo0080@Ti100<0ogl0086YP@21ZH401P21ZH47076>KP03086Y
P@22Y7`0PZAl0140PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086Y
P@2>/h80S[>201/0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086Y
P@1gU6H0MiAV0140MiAV00<0PJV1069jD@1RNU401@1RNU49086YP@D0@4/d00<0PJV101`P6021ZH40
R02`h>H10?ooo`00Q@2`h>H40?mo0003086YP@12CT40ogl00080ogl000@0PJV10?mo003oO`00ogl0
3P1aSVh00`21ZH40PZAl08:TO00@08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@0
6P2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@0
5`23YG@00`21ZH40MiAV07NDIP0@07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?021ZH40
0`21ZH42041;=003086YP@0L81P0PJV108L0/>3V0@3oool008D0/>3V203oO`02055UD`80ogl000<0
PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0
PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0
PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00/0HWYA00<0
PJV104UI?019FC`00`19FC`3086YP@0301`P6021ZH40/>3V08H0/>3V0@3oool008D0/>3V1`3oO`03
055UD`80ogl03P1aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV1
08jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV1
08>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV1
04UI?019FC`01019FC`4086YPHH0/>3V0@3oool008@0/>3V1P3oO`04055UD`<0ogl03P1aSVh00`21
ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21
ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21
ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019FC`01021
ZH408RLM028W7@21ZH660;3PiP40oooo00240;3PiPD0ogl00P1AIE<00`3oO`00DFEC055UD`020?mo
0003086YP@1aSVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21ZH40Rjn208^_PP0F08^_
PP03086YP@2>/h@0S[>401/0S[>400<0PJV108jcPP2>/h806`2>/h800`21ZH40Rjmm08^_O@0K08^_
O@03086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04@1gU6H00`21ZH40HWYA069jD@0<069j
D@03086YP@19FC`0BETl00D0BETl00<0PJV1028W7@0R9ad0QP2`h>H10?ooo`00Q02`h>H50?mo0080
DFEC00<0ogl0055UD`1AIE<00P3oO`000`21ZH40LHi^076>KP0;076>KP03086YP@22Y7`0PZAl0180
PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h80S[>201/0
S[>200<0PJV108^_O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV0180
MiAV00<0PJV1069jD@1RNU402`1RNU400`21ZH40BETl04UI?00504UI?004086YP@0R9ad08RLM086Y
PHD0/>3V0@3oool008<0/>3V1P3oO`000`1AIE<0ogl00?mo0002055UD`80ogl03P1aSVh00`21ZH40
PZAl08:TO00B08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40
S[>208jcPP0L08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40
MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019FC`01021ZH40
8RLM028W7@21ZH650;3PiP40oooo00230;3PiPT0ogl000@0DFEC0?mo003oO`00ogl03P1aSVh00`21
ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05P23YG@00`21
ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019FC`01021
ZH408RLM028W7@21ZH650;3PiP40oooo00230;3PiPP0ogl00P1AIE<20?mo0003086YP@1aSVh0LHi^
00`0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcPP2>/h807@2>/h800`21ZH40Rjmm08^_O@0J08^_O@03086YP@23YG@0PjEd
01L0PjEd00<0PJV107NDIP1gU6H04@1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@19FC`0BETl
00D0BETl00<0PJV1028W7@21ZH40Q@2`h>H10?ooo`00PP2`h>H80?mo00<0DFEC0P3oO`000`21ZH40
LHi^076>KP0;076>KP03086YP@22Y7`0PZAl0180PZAl00<0PJV108^_PP2;[h805`2;[h800`21ZH40
S[>408jcQ00J08jcQ003086YP@2>/h80S[>201d0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40
PjEd08>UM00G08>UM003086YP@1gU6H0MiAV0180MiAV00<0PJV1069jD@1RNU402`1RNU400`21ZH40
BETl04UI?00504UI?004086YP@0R9ad08RLM086YPH@0/>3V0@3oool00880/>3V103oO`000`0U;R/0
PJV1055UD`04055UD`80ogl03P1aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0
Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0
Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0
HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH640;3PiP40oooo00210;3PiP<0
ogl000<0PJV102D^:`21ZH401@1AIE<30?mo00h0LHi^00<0PJV108:TO022Y7`04P22Y7`00`21ZH40
Rjn208^_PP0G08^_PP03086YP@2>/h@0S[>401X0S[>400<0PJV108jcPP2>/h807@2>/h800`21ZH40
Rjmm08^_O@0J08^_O@03086YP@23YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40
HWYA069jD@0<069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV1Q02`h>H10?oo
o`00P@2`h>H30?mo0003086YP@0U;R/0PJV100D0DFEC0P3oO`000`21ZH40LHi^076>KP0<076>KP03
086YP@22Y7`0PZAl0180PZAl00<0PJV108^_PP2;[h805`2;[h800`21ZH40S[>408jcQ00J08jcQ003
086YP@2>/h80S[>201d0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00G08>UM003
086YP@1gU6H0MiAV0180MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00504UI?003
086YP@0R9ad0PJV108@0/>3V0@3oool008<0/>3V00@0PJV102D^:`0U;R/0PJV11@1AIE<20?mo0003
086YP@1aSVh0LHi^00/0LHi^00<0PJV108:TO022Y7`04`22Y7`00`21ZH40Rjn208^_PP0F08^_PP03
086YP@2>/h@0S[>401/0S[>400<0PJV108jcPP2>/h807@2>/h800`21ZH40Rjmm08^_O@0K08^_O@03
086YP@23YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04`1gU6H00`21ZH40HWYA069jD@0;069jD@03
086YP@19FC`0BETl00D0BETl00@0PJV1028W7@0R9ad0PJV1P`2`h>H10?ooo`00P`2`h>H01021ZH40
9Bh[02D^:`21ZH44055UD`<0ogl03P1aSVh00`21ZH40PZAl08:TO00C08:TO003086YP@2;[h80Rjn2
01H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm
01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA
00`0HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH630;3PiP40oooo00200;3P
iP80ogl000@0/>3V086YP@0U;R/0PJV11P1AIE<00`3oO`00PJV1076>KP0=076>KP03086YP@22Y7`0
PZAl0180PZAl00<0PJV108^_PP2;[h805`2;[h800`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h80
S[>201d0S[>200<0PJV108^_O@2;[gd06`2;[gd00`21ZH40PjEd08>UM00G08>UM003086YP@1gU6H0
MiAV0180MiAV00<0PJV1069jD@1RNU40301RNU400`21ZH40BETl04UI?00404UI?004086YP@0R9ad0
8RLM086YPH<0/>3V0@3oool00800/>3V0P3oO`00102`h>H0PJV102D^:`21ZH47055UD`03086YP@1a
SVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04P22Y7`00`21ZH40Rjn208^_PP0G08^_PP03086YP@2>
/h@0S[>401/0S[>400<0PJV108jcPP2>/h807@2>/h800`21ZH40Rjmm08^_O@0K08^_O@03086YP@23
YG@0PjEd01L0PjEd00<0PJV107NDIP1gU6H04P1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@19
FC`0BETl00D0BETl00<0PJV1028W7@21ZH40P`2`h>H10?ooo`00P02`h>H20?mo0004086YP@0U;R/0
9Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:TO00C08:TO003086YP@2;
[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@03@2>/h@m086YP@l0Rjmm00<0PJV108>UM023YG@05`23
YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19
FC`01021ZH408RLM028W7@21ZH620;3PiP40oooo00200;3PiP80ogl000@0PJV102D^:`0U;R/0PJV1
1P1AIE<00`21ZH40LHi^076>KP0<076>KP03086YP@22Y7`0PZAl00T0PZAl=021ZH4>09K0SP03086Y
P@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0302C^hLd086YP@/0MiAV00<0PJV1069jD@1RNU40
301RNU400`21ZH40BETl04UI?00404UI?004086YP@0R9ad08RLM086YPH80/>3V0@3oool00880/>3V
00<0PJV102D^:`21ZH401`1AIE<00`21ZH40LHi^076>KP05076>KQ<0PJV12P2</hP00`21ZH40U;f=
09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^7
09>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg802021Xg8C086YP@L0HWYA
00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH620;3PiP40oooo00220;3PiP809Bh[
00<0PJV1055UD`1AIE<00P1AIE<;086YP@L0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=
09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^7
09>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL
06b9G00506b9G0/0PJV11019FC`00`21ZH408RLM086YP@220;3PiP40oooo00210;3PiP03086YP@0U
;R/0PJV100D0PJV10`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0
PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0
PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0
PJV106b9G01/RE`0301/RE`01021ZH40D6E3051U@`1@ID<6086YP@03028W7@21ZH40/>3V0800/>3V
0@3oool00840/>3V0P21ZH400`0]>SH0PJV105iiHP0605iiHP03086YP@1mWg/0OImk00`0OImk00<0
PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0
PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0
PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0
PJV102Pc8`21ZH40PJV1P@2`h>H10?ooo`00P@2`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086Y
P@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086Y
P@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086Y
P@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086Y
P@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P@2`h>H10?ooo`00P@2`h>H01021ZH40;CXf
02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40
U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40
Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40
K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P@2`h>H10?oo
o`00P@2`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bc
R02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109Jo
S02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086S
LP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc
8`0X<b<0PJV1P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk
00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>
01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o
01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E3
00D0D6E300@0PJV102Pc8`0X<b<0PJV1P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0805ii
HP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09Bm
S@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0K09>k
Q`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9
G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40
;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40
U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40
Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40
K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P@2`h>H10?ooo`00
P@2`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP0
4`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01/0U/2>00<0PJV109JoS02F_h`0
7@2F_h`00`21ZH40Tk^709>kQ`0K09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg80
4`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40
P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00/0OImk00<0
PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0
PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0
PJV1086SLP21Xg804P21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0
PJV102Pc8`21ZH40P@2`h>H10?ooo`00P@2`h>H00`21ZH40;CXf086YP@0705iiHP03086YP@1mWg/0
OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0
U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0
S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0
D6E300D0D6E300<0PJV102Pc8`21ZH40P@2`h>H10?ooo`00P02`h>H01021ZH40;CXf02dj=P21ZH47
05iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G
09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L
09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<
06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P02`h>H10?ooo`00P02`h>H0
1021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2<
/hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F
_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21
Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1
P02`h>H10?ooo`00P02`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03086YP@1mWg/0OImk00`0OImk
00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>
00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o
00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E3
00@0PJV102Pc8`0X<b<0PJV1P02`h>H10?ooo`00P02`h>H01021ZH40;CXf02dj=P21ZH4705iiHP03
086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03
086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03
086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003
086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P02`h>H10?ooo`00P02`h>H00`21ZH40
;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40
U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40
Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40
K8UL06b9G00<06b9G003086YP@1@ID<0D6E300D0D6E300@0PJV102Pc8`0X<b<0PJV1P02`h>H10?oo
o`00P02`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02<
/hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F
_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21
Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21
ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1mWg/0OImk00`0OImk
00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F`8h0U/2>01`0U/2>
00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2</gl0S;=o01L0S;=o
00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@ID<0D6E300H0D6E3
00<0PJV102Pc8`21ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40;CXf086YP@0805iiHP03086YP@1m
Wg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G09BmS@03086YP@2F
`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L09>kQ`03086YP@2<
/gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<06b9G003086YP@1@
ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P02`h>H10?ooo`00P02`h>H00`21ZH40;CXf086YP@08
05iiHP03086YP@1mWg/0OImk00`0OImk00<0PJV108bcR02</hP04`2</hP00`21ZH40U;f=09BmS@0G
09BmS@03086YP@2F`8h0U/2>01`0U/2>00<0PJV109JoS02F_h`07@2F_h`00`21ZH40Tk^709>kQ`0L
09>kQ`03086YP@2</gl0S;=o01L0S;=o00<0PJV1086SLP21Xg804`21Xg800`21ZH40K8UL06b9G00<
06b9G003086YP@1@ID<0D6E300H0D6E300<0PJV102Pc8`21ZH40P02`h>H10?ooo`00P02`h>Kc086Y
PH00/>3V0@3oool00800/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03
086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03
086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03
086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03
086YP@0]>bP0PJV10800/>3V0@3oool00800/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf6
08F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F
09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj7
09>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e7
05A]A`0605A]A`03086YP@0]>bP0PJV10800/>3V0@3oool00800/>3V00<0PJV103Q:@`21ZH40201X
R6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2K
b9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702J
aXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301d
UVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10800/>3V0@3oool00800/>3V00<0PJV1
03Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV1
09_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV1
09[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV1
07BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10800/>3V0@3oool0
0800/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA
01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC
01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k
01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X
086YPH00/>3V0@3oool00800/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<
08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L
09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G
09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`05
05A]A`04086YP@0]>bP0;C/X086YPH00/>3V0@3oool00800/>3V00@0PJV103Q:@`0hBT<0PJV11`1X
R6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2K
b9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702J
aXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301d
UVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH00/>3V0@3oool00800/>3V00@0
PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA
00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC
00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k
00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH00
/>3V0@3oool00800/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03
086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03
086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03
086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04
086YP@0]>bP0;C/X086YPH00/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH401`1XR6h00`21ZH40
QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40
WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0702JaXl00`21ZH40
Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40
E6e705A]A`0505A]A`03086YP@0]>bP0PJV10840/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40
201XR6h00`21ZH40QJf608F]QP0;08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H0
5`2Kb9H00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl0
702JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k0180R;1k00<0PJV107BFI`1dUVL0
301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10840/>3V0@3oool00840/>3V00<0
PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0
PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0
PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0
PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0PJV10840/>3V0@3o
ool00840/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40
U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0
W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0
R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]A`03086YP@0]>bP0
PJV10840/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40QJf608F]QP0<08F]
QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;
UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>n
Q`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0605A]
A`03086YP@0]>bP0PJV10840/>3V0@3oool00840/>3V00<0PJV103Q:@`21ZH40201XR6h00`21ZH40
QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40
WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40
Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40
E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH40/>3V0@3oool00840/>3V00@0PJV103Q:@`0h
BT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8
UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6
S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BF
I`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0;C/X086YPH40/>3V0@3oool0
0840/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40
U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0
W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0
R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0
;C/X086YPH40/>3V0@3oool00840/>3V00@0PJV103Q:@`0hBT<0PJV11`1XR6h00`21ZH40QJf608F]
QP0<08F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;
UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>n
Q`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]
A`0505A]A`04086YP@0]>bP0;C/X086YPH40/>3V0@3oool00840/>3V0P21ZH400`0hBT<0PJV106R8
KP0606R8KP03086YP@25[HH0QJf600`0QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8
UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6
S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BF
I`0<07BFI`03086YP@1DKDL0E6e700D0E6e700@0PJV102dk:021ZH40PJV1P@2`h>H10?ooo`00P@2`
h>H00`21ZH40?eM=086YP@04086YP@@0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09Bo
T@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:
T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`
N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL00P1DKDL5086YP@030312:`21
ZH40/>3V0800/>3V0@3oool00880/>3V00<0PJV103mGC@21ZH400`1_TgL<086YP@L0QJf600<0PJV1
09BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0WL^F00<0PJV1
09c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0Tkj700<0PJV1
08R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0507BFI``0PJV10`1IMTh00`21ZH40<48[0312:`22
0;3PiP40oooo00220;3PiP03086YP@0oEdd0PJV100L0Ki=g00<0PJV108bgS`2<]hl01@2<]hlB086Y
P@/0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC
01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k
00T0R;1k4P21ZH4707^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1PP2`h>H1
0?ooo`00PP2`h>H01021ZH40?eM=03mGC@21ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV1
09[9V@2JbIT0202JbITd086YP@l0WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0=
09[6Sc@0PJV12P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV1
0312:`0`@R/0PJV1PP2`h>H10?ooo`00PP2`h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<
]hl0S;N?00/0S;N?00<0PJV109[9V@2JbIT04`2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2R
did0X]>M00`0X]>M?`21ZH4>09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04`2>
^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>00@0PJV10312:`0`@R/0PJV1
PP2`h>H10?ooo`00P`2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0S;N?00`0S;N?00<0
PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0
PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0
PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00D0FGI>00<0
PJV10312:`21ZH40P`2`h>H10?ooo`00P`2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0
S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0
X]>M01/0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0
VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0
FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1P`2`h>H10?ooo`00P`2`h>H01021ZH40?eM=03mGC@21
ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04`2JbIT00`21ZH40X=6M0:3A
W@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>
UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04`2>^H<00`21ZH40Nj5_07^Q
K`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1P`2`h>H10?ooo`00P`2`
h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<]hl0S;N?00/0S;N?00<0PJV109[9V@2JbIT0
4`2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX0
7@2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<0
4`2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>00@0PJV10312:`0`@R/0
PJV1P`2`h>H10?ooo`00Q02`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0S;N?00`0S;N?
00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M
00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0VLN?
00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00D0FGI>
00<0PJV10312:`21ZH40Q02`h>H10?ooo`00Q02`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<
]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2R
did0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2I
ahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1I
MTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1Q02`h>H10?ooo`00Q02`h>H01021ZH40?eM=03mG
C@21ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40X=6M
0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF
09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_
07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1Q02`h>H10?ooo`00
Q02`h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<]hl0S;N?00/0S;N?00<0PJV109[9V@2J
bIT04P2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2R
dYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0VLN?00<0PJV108jiP`2>
^H<04P2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>00@0PJV10312:`0`
@R/0PJV1Q02`h>H10?ooo`00Q@2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0S;N?00`0
S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086YP@2Rdid0X]>M01X0
X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?01L0
VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00D0
FGI>00<0PJV10312:`21ZH40Q@2`h>H10?ooo`00Q@2`h>H00`21ZH40?eM=086YP@0706nCM`03086Y
P@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0G0:3AW@03086Y
P@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX07@2RdYX00`21ZH40WljF09o>UP0J09o>UP03086Y
P@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086Y
P@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1Q@2`h>H10?ooo`00Q@2`h>H01021ZH40?eM=
03mGC@21ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04P2JbIT00`21ZH40
X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX0702RdYX00`21ZH40
WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04P2>^H<00`21ZH40
Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00@0PJV10312:`0`@R/0PJV1Q@2`h>H10?oo
o`00Q@2`h>H01021ZH40?eM=03mGC@21ZH4706nCM`03086YP@2<]hl0S;N?00/0S;N?00<0PJV109[9
V@2JbIT04P2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;B
VP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108ji
P`2>^H<04P2>^H<00`21ZH40Nj5_07^QK`0;07^QK`03086YP@1IMTh0FGI>00D0FGI>00@0PJV10312
:`0`@R/0PJV1Q@2`h>H10?ooo`00QP2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<]hl0S;N?
00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M
01/0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?
01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0<07^QK`03086YP@1IMTh0FGI>
00D0FGI>00<0PJV10312:`21ZH400P0000240;3PiP40oooo00260;3PiP03086YP@0oEdd0PJV100L0
Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A09[9V@03086YP@2PdId0X=6M01H0
X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01/0
WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0A08jiP`03086YP@1kXFl0Nj5_00`0
Nj5_00<0PJV105UfCP1IMTh0101IMTh00`21ZH40<48[0312:`03000008@0/>3V0@3oool008H0/>3V
1021ZH4606nCM`03086YP@2<]hl0S;N?00`0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M
0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF
09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40Nj5_
07^QK`0<07^QK`03086YP@1IMTh0FGI>00@0FGI>00<0PJV100000021ZH400`0000240;3PiP40oooo
00270;3PiP04086YP@15HE@0PJV1086YP@H0Ki=g00<0PJV108bgS`2<]hl02`2<]hl00`21ZH40V/VI
09[9V@0A09[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J
0:;BVP0K0:;BVP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V3
08jiP`0A08jiP`03086YP@1kXFl0Nj5_00/0Nj5_00<0PJV105UfCP1IMTh00P00000205UfCP03086Y
P@000000000000<00000Q@2`h>H10?ooo`00Q`2`h>H01021ZH40AF5D086YP@1bVgd4086YP@80Ki=g
00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0@09[9V@03086YP@2PdId0X=6M01L0X=6M
00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF
00<0PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0@08jiP`03086YP@1kXFl0Nj5_00`0Nj5_
00<0PJV105UfCP0000000`0000000`21ZH40GWmF00000004000008D0/>3V0@3oool008P0/>3V00<0
PJV104EQE021ZH40101bVgd:086YP@L0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3A
W@0F0:3AW@03086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>
UP0J09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<00`21ZH40000007^Q
K`0207^QK`030000001kXFl0Nj5_00P0PJV12`0000260;3PiP40oooo00280;3PiP03086YP@15HE@0
PJV100H0LY]m00<0PJV108nnU02?_Y@01@2?_Y@<086YP@l0V/VI00<0PJV10:3AW@2PdId05P2PdId0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06P2OcYH0
0`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V300d0S[V31@21ZH400`000000PJV1086YP@03
00000003086YP@1oZ7H0OjQf00D0OjQf0`000000101NOeH000000000001NOeH5000008H0/>3V0@3o
ool008T0/>3V00<0PJV104EQE021ZH401P1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0
WM2O0080WM2O2P21ZH4509[9V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05P2Iahl0
1021ZH40S[V308jiP`2>^H<2000000X0PJV1102B`8T200000080OjQf0P00000807nXMP<000000P1N
OeH200000003086YP@000000000000<00000QP2`h>H10?ooo`00R@2`h>H00`21ZH40AF5D086YP@06
07:KO@03086YP@2?_Y@0SkjD00`0SkjD00<0PJV109g@W`2Md9l02`2Md9lB086YP@`0X=6M00<0PJV1
0:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV1
09W7S`2Iahl02P2Iahl@086YP@8000003@2B`8T2000000<0OjQf0P00000707nXMP<000000`1NOeH7
000008L0/>3V0@3oool008X0/>3V0P21ZH4607:KO@03086YP@2?_Y@0SkjD00`0SkjD00<0PJV109g@
W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0:0:CHXW40PJV1302McYD01021ZH40T/2909;0R@2B`8T2
000000d0T/2900@0000007nXMP1oZ7H0OjQf0`00000707nXMP8000001P1NOeH5000008L0/>3V0@3o
ool008X0/>3V00<0PJV104EQE021ZH401P1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0
WM2O0100WM2O00<0PJV10:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2UfJ00
YMVP01/0YMVP00<0PJV10:?EW02SeI`06P2SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0
T/290080T/290P00000<09;0R@8000000`1oZ7H2000000P0OjQf00<0000005ioEP1NOeH0101NOeH0
0`21ZH400000086YP@02000008P0/>3V0@3oool008X0/>3V00<0PJV104EQE021ZH401P1bVgd00`21
ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O0140WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21
ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02SeI`06P2SeI`00`21
ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/290080T/290P00000<09;0R@030000001oZ7H0OjQf
0080OjQf0P00000707nXMP8000001P1NOeH200000003086YP@000000000008P0/>3V0@3oool008/0
/>3V0P21ZH4707:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40
Y=RR0:CHXP0F0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21ZH40
XmFL0:?EW00I0:?EW003086YP@2McYD0WLjE01H0WLjE00<0PJV109;0R@2B`8T00P2B`8T2000000/0
T/290P00000307nXMP<000001P1oZ7H2000000H0GWmF00<0PJV100000021ZH400`0000280;3PiP40
oooo002;0;3PiP03086YP@15HE@0PJV100H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O
09g@W`0@09g@W`03086YP@2Tf:80Y=RR01H0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMVP
0:GIX00K0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05P2McYD00`21ZH40T/29
09;0R@0209;0R@8000002P2B`8T200000004086YP@1oZ7H0OjQf07nXMP8000001`1oZ7H2000000H0
GWmF0P0000000`21ZH400000000000290;3PiP40oooo002<0;3PiP80PJV11P1bVgd00`21ZH40SkjD
08nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR
0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02SeI`06@2SeI`00`21ZH40WLjE
09g>U@0E09g>U@03086YP@2B`8T0T/2900<0T/290P00000909;0R@80000000<0T/29086YP@1oZ7H0
0P1oZ7H2000000L0OjQf0`00000405ioEPH00000R@2`h>H10?ooo`00S02`h>H00`21ZH40AF5D086Y
P@0607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CH
XP0E0:CHXP03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21ZH40XmFL0:?E
W00I0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T00`2B`8T=00000004086YP@1o
Z7H0OjQf07nXMP<000001`1oZ7H2000000@0GWmF1`0000290;3PiP40oooo002=0;3PiP80PJV11P1b
Vgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:805@2T
f:800`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2UfJ00YMVP01/0YMVP00<0PJV10:?EW02SeI`06@2S
eI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/2900<0T/293@0000001021ZH40OjQf07nX
MP1oZ7H2000000P0OjQf0P00000305ioEPL00000RP2`h>H10?ooo`00S@2`h>H2086YP@H0LY]m00<0
PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR01H0Y=RR00<0
PJV10:KJXP2VfZ80602VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2SeI`0XmFL01P0XmFL00<0
PJV109g>U@2McYD05P2McYD00`21ZH40T/2909;0R@0309;0R@8000001`2B`8T200000080T/2900@0
PJV107nXMP1oZ7H0OjQf0P00000707nXMP<000000P1NOeH6000008`0/>3V0@3oool008h0/>3V0P21
ZH4607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l03`2Md9l00`21ZH40Y=RR0:CH
XP0F0:CHXP03086YP@2VfZ80Y]ZR01P0Y]ZR00<0PJV10:GIX02UfJ006`2UfJ000`21ZH40XmFL0:?E
W00H0:?EW003086YP@2McYD0WLjE01D0WLjE00<0PJV109;0R@2B`8T0102B`8T2000000L0T/2900@0
000009;0R@2B`8T0PJV10`1oZ7H3000000L0OjQf0P00000205ioEPL00000S02`h>H10?ooo`00SP2`
h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2T
f:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMVP0:GIX00K0:GIX003086YP@2S
eI`0XmFL01P0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0409;0R@<000001@2B
`8T200000080T/2900@0PJV107nXMP1oZ7H0OjQf0`00000307nXMP040000001oZ7H0OjQf07nXMPT0
0000SP2`h>H10?ooo`00S`2`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02P2?_Y@00`21ZH40WM2O
09g@W`0@09g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMVP
0:GIX00I0:GIX003086YP@2SeI`0XmFL01T0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/29
09;0R@0409;0R@<00000102B`8T2000000<0T/2900@0PJV107nXMP1oZ7H0OjQf200000000`1oZ7H0
PJV1000000040000000305ioEP000000000000800000S@2`h>H10?ooo`00S`2`h>H3086YP@D0LY]m
00<0PJV108nnU02?_Y@02P2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR01D0Y=RR
00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0XmFL01T0XmFL
00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0R@0509;0R@800000102B`8T01@000000T/29
09;0R@2B`8T0PJV100<0OjQf2000000207nXMP03086YP@1NOeH0GWmF00<0GWmF1P00002<0;3PiP40
oooo002@0;3PiP@0PJV10`1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O00l0WM2O
00<0PJV10:CHXP2Tf:805P2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP01T0YMVP
00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/2900H0T/29
0P00000309;0R@8000000`2B`8T00`21ZH40OjQf07nXMP0207nXMP050000001oZ7H0OjQf07nXMP00
0000101oZ7H01021ZH40GWmF05ioEP1NOeH2086YP@D00000S@2`h>H10?ooo`00T02`h>H2086YP@80
LYeo0`21ZH400`1bVgd0PJV108nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2T
f:805@2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02S
eI`0602SeI`00`21ZH40WLjE09g>U@0E09g>U@03086YP@2B`8T0T/2900H0T/290P00000209;0R@80
0000102B`8T00`21ZH40OjQf07nXMP0:07nXMP03086YP@1NOeH0PJV10080PJV10P1OPeX200000003
0;3PiP000000/>3V08d0/>3V0@3oool00940/>3V0P21ZH4407:MO`D0PJV12@2?_Y@00`21ZH40WM2O
09g@W`0@09g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40YMVP
0:GIX00I0:GIX003086YP@2SeI`0XmFL01P0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/29
09;0R@0609;0R@8000000P2B`8T00`000000T/2909;0R@0309;0R@03086YP@1oZ7H0OjQf00L0OjQf
1@21ZH4405n3FP<00000T02`h>H10?ooo`00TP2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL01`21
ZH4308nnU003086YP@2Md9l0WM2O00l0WM2O00<0PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJ
XP0H0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>
U@0E09g>U@03086YP@2B`8T0T/2900H0T/290P0000000`2B`8T000000000000409;0R@04086YP@1o
Z7H0OjQf07nXMPL0PJV10P1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV100<000000;3PiP2`h>H0
S`2`h>H10?ooo`00TP2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL01`2?`IL8086YP@d0WM2O00<0
PJV10:CHXP2Tf:805@2Tf:800`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2UfJ00YMVP01T0YMVP00<0
PJV10:?EW02SeI`0602SeI`00`21ZH40WLjE09g>U@0D09g>U@03086YP@2B`8T0T/2900L0T/290P00
00000`2B`8T0000009;0R@08086YP@T0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPI80/>3V0@3o
ool009<0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00X0Sl6G00@0PJV109kCXP2Ndj80W]>R2P21
ZH4409g@W`03086YP@2Tf:80Y=RR01D0Y=RR00<0PJV10:KJXP2VfZ805`2VfZ800`21ZH40YMVP0:GI
X00I0:GIX003086YP@2SeI`0XmFL01L0XmFL00<0PJV109g>U@2McYD05@2McYD00`21ZH40T/2909;0
R@0209;0R@D0PJV1100000001@21ZH40TlB=09?4S@2Ca8d0PJV100`0Ojaj00<0PJV105n3FP1OPeX0
0`1OPeX2086YPI<0/>3V0@3oool009@0/>3V0P21ZH4407:MO`03086YP@2?`IL0Sl6G00X0Sl6G00<0
PJV109kCXP2Ndj802`2Ndj8@086YP@`0Y=RR00<0PJV10:KJXP2VfZ805`2VfZ800`21ZH40YMVP0:GI
X00I0:GIX003086YP@2SeI`0XmFL01L0XmFL00<0PJV109g>U@2McYD02P2McYD@086YP@D0TlB=0`00
000509?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPI@0/>3V0@3o
ool009@0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00X0Sl6G00<0PJV109kCXP2Ndj803P2Ndj80
0`21ZH40YMbV0:GLYP090:GLYQT0PJV13@2VfZ800`21ZH40YMVP0:GIX00I0:GIX003086YP@2SeI`0
XmFL00/0XmFL6@21ZH4;09kBV@03086YP@2Ca8d0TlB=00P0TlB=0P00000409?4S@03086YP@1o[7X0
Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPI@0/>3V0@3oool009D0/>3V0P21ZH4507:M
O`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803`2Ndj800`21ZH40YMbV0:GLYP0D0:GL
YP03086YP@2XgjH0Z=nV00X0Z=nV=`21ZH4<0:GJX003086YP@2NdYT0W]:I01@0W]:I00<0PJV109?4
S@2Ca8d02@2Ca8d2000000@0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3
FP80PJV1U@2`h>H10?ooo`00U@2`h>H2086YP@D0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40
W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40
YmjT0:ONY00I0:ONY003086YP@2UfZ00YMZP01L0YMZP00<0PJV109kBV@2NdYT0502NdYT00`21ZH40
TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00`1OPeX00`21ZH40
/>3V0;3PiP2D0;3PiP40oooo002F0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086Y
P@2Ndj80W]>R00l0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086Y
P@2WgZ@0YmjT01T0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0D09kBV@03086Y
P@2Ca8d0TlB=00l0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3FP0305n3FP80PJV1
UP2`h>H10?ooo`00U`2`h>H2086YP@@0LYeo00<0PJV108o1U`2?`IL02P2?`IL00`21ZH40W]>R09kC
XP0>09kCXP03086YP@2Ug:H0YMbV01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ON
Y00I0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT0502NdYT00`21ZH40TlB=09?4
S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPIL0/>3V0@3o
ool009L0/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803P2Ndj80
0`21ZH40YMbV0:GLYP0D0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@06@2WgZ@0
0`21ZH40YMZP0:GJX00F0:GJX003086YP@2NdYT0W]:I01@0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d0
0`21ZH40Ojaj07n/NP0907n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6G0;3PiP40oooo002H0;3P
iP80PJV1101bWGl00`21ZH40Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GL
YP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJ
X02UfZ005`2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/
NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0205n3FP80PJV1V02`h>H10?ooo`00V@2`h>H2086YP@@0
LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01@0
YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0
YMZP00<0PJV109kBV@2NdYT0502NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00T0
Ojaj00<0PJV105n3FP1OPeX00P1OPeX2086YPIT0/>3V0@3oool009X0/>3V00<0PJV107:MO`1bWGl0
0`1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00d0W]>R00<0PJV10:GLYP2Ug:H0
502Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ00
5P2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/NP1o[7X0
2@1o[7X00`21ZH40Gh=J05n3FP0305n3FP03086YP@2`h>H0/>3V09P0/>3V0@3oool009/0/>3V0P21
ZH4307:MO`03086YP@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803P2Ndj800`21ZH40YMbV0:GL
YP0C0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJ
X00F0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/
NP0907n/NP04086YP@1OPeX0Gh=J05n3FP80PJV1V`2`h>H10?ooo`00W02`h>H3086YP@80LYeo00<0
PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0=09kCXP03086YP@2Ug:H0YMbV01<0YMbV00<0
PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0
PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0=09?4S@03086YP@1o[7X0Ojaj00T0Ojaj00<0
PJV105n3FP1OPeX00`21ZH6L0;3PiP40oooo002M0;3PiP03086YP@1^VWd0PJV10080PJV12`2?`IL0
0`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV0180YMbV00<0PJV10:SOYP2XgjH05P2XgjH0
0`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT04P2NdYT0
0`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00T0Ojaj0`21ZH400`1LPe/0PJV10;3PiP2L
0;3PiP40oooo002N0;3PiP03086YP@1^VWd0KYYm00D0PJV1202?`IL00`21ZH40W]>R09kCXP0=09kC
XP03086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00G0:ON
Y003086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0=09?4
S@03086YP@1o[7X0Ojaj00H0Ojaj1@21ZH4205b3F`03086YP@2`h>H0/>3V09`0/>3V0@3oool009h0
/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^nU@06086YP@80Sl6G00<0PJV109kCXP2N
dj803@2Ndj800`21ZH40YMbV0:GLYP0C0:GLYP03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:ONY02W
gZ@05`2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2C
a8d03@2Ca8d00`21ZH40Ojaj07n/NP06086YP@80O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21ZH40
/>3V0;3PiP2L0;3PiP40oooo002O0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;_YD0
1@2;_YD6086YP@d0W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV0:SOYP0E0:SOYP03086Y
P@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I09kBV@0B09kBV@03086Y
P@2Ca8d0TlB=00/0TlB=1P21ZH4707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`h>H0
W@2`h>H10?ooo`00X02`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00P0RkjE00<0
PJV109_BXP21ZH401@21ZH4709kCXP03086YP@2Ug:H0YMbV0180YMbV00<0PJV10:SOYP2XgjH05P2X
gjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0PJV109kBV@2NdYT04P2N
dYT00`21ZH40TlB=09?4S@0509?4S@H0PJV100<0TLB>086YP@1lZgX02@1lZgX00`21ZH40G8=K05b3
F`0205b3F`03086YP@2`h>H0/>3V09h0/>3V0@3oool00:40/>3V00D0PJV106jJO@1^VWd0KYYm086Y
P@0:08^nU@03086YP@2KdZ80Vm:R00D0Vm:R1P21ZH4209kCXP03086YP@2Ug:H0YMbV0180YMbV00<0
PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00E0:ONY003086YP@2UfZ00YMZP01D0YMZP00<0
PJV109kBV@2NdYT04P2NdYT00`21ZH40TlB=09?4S@06086YP@L0TLB>00<0PJV107b[NP1lZgX0201l
ZgX01@21ZH40G8=K05b3F`1LPe/0PJV10:40/>3V0@3oool00:80/>3V00D0PJV106jJO@1^VWd0KYYm
086YP@0:08^nU@03086YP@2KdZ80Vm:R00X0Vm:R3@21ZH4:0:GLYP03086YP@2XgjH0Z=nV01D0Z=nV
00<0PJV10:ONY02WgZ@05@2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I00P0W]:I
3@21ZH4<0974SP03086YP@1lZgX0O:]j00P0O:]j00D0PJV105b3F`1LPe/0G8=K086YP@2R0;3PiP40
oooo002S0;3PiP05086YP@1^VWd0KYYm06jJO@21ZH402P2;_YD00`21ZH40Vm:R09_BXP0<09_BXP03
086YP@2Tg:L0Y=bW00L0Y=bW5P21ZH4<0:SOYP03086YP@2WgZ@0YmjT01D0YmjT00<0PJV10:GJX02U
fZ002P2UfZ0F086YP@T0WM>J00<0PJV10974SP2Aa8h0302Aa8h00`21ZH40O:]j07b[NP0807b[NP05
086YP@1LPe/0G8=K05b3F`21ZH40X`2`h>H10?ooo`00Y02`h>H01@21ZH40KYYm06jJO@1^VWd0PJV1
00X0RkjE00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0Yn2X
00T0Yn2X<@21ZH4;0:CKXP03086YP@2MdiX0WM>J0140WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21
ZH40O:]j07b[NP0807b[NP05086YP@1LPe/0G8=K05b3F`21ZH40Y02`h>H10?ooo`00Y02`h>H00`21
ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0RkjE00<0PJV109_BXP2KdZ80302KdZ800`21
ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:OOYP2WgjH05@2WgjH00`21
ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J0140WM>J00<0PJV10974SP2Aa8h0302Aa8h00`21
ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`h>H0XP2`h>H10?oo
o`00Y@2`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0RkjE00<0PJV109_BXP2K
dZ80302KdZ800`21ZH40Y=bW0:CLY`0@0:CLY`03086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:OOYP2W
gjH05@2WgjH00`21ZH40Y=^R0:CKXP0D0:CKXP03086YP@2MdiX0WM>J0100WM>J00<0PJV10974SP2A
a8h0302Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080G8=K00<0PJV10;3PiP2`
h>H0X`2`h>H10?ooo`00YP2`h>H00`21ZH40KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00L0RkjE
00<0PJV109_BXP2KdZ802`2KdZ800`21ZH40Y=bW0:CLY`0A0:CLY`03086YP@2Wh:P0Yn2X01<0Yn2X
00<0PJV10:OOYP2WgjH05@2WgjH00`21ZH40Y=^R0:CKXP0C0:CKXP03086YP@2MdiX0WM>J0140WM>J
00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j07b[NP0707b[NP03086YP@1LPe/0G8=K0080G8=K
00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y`2`h>H2086YP@80KYYm00<0PJV108^nU@2;_YD0202;
_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P0502W
h:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX0402M
diX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00P0O:]j00<0PJV105b3F`1LPe/00P21
ZH6W0;3PiP40oooo002X0;3PiP<0PJV100<0KYYm086YP@2;_YD0202;_YD00`21ZH40Vm:R09_BXP0;
09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40YmnV0:OOYP0C
0:OOYP03086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40TLB>0974SP0<
0974SP03086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`21ZH400P21ZH6X0;3PiP40oooo002Y0;3P
iPD0PJV12@2;_YD00`21ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OP
Z02Wh:P04`2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R00<0PJV109gC
VP2MdiX0402MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00L0O:]j0`21ZH400`1F
O5T0PJV10;3PiP2X0;3PiP40oooo002[0;3PiP03086YP@1UTGH0PJV10080PJV1202;_YD00`21ZH40
Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40
YmnV0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40
TLB>0974SP0;0974SP03086YP@1lZgX0O:]j00H0O:]j0`21ZH400`1FO5T0PJV10;3PiP2Z0;3PiP40
oooo002/0;3PiP03086YP@1UTGH0II5f00D0PJV11@2;_YD00`21ZH40Vm:R09_BXP0:09_BXP03086Y
P@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0C0:OOYP03086Y
P@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX0402MdiX00`21ZH40TLB>0974SP0:0974SP03086Y
P@1lZgX0O:]j00<0O:]j1@21ZH4205IlF@03086YP@2`h>H0/>3V0:X0/>3V0@3oool00:d0/>3V00@0
PJV106FAMP1UTGH0PJV10`21]8h4086YP@0308^nU@21ZH40Vm:R00`0Vm:R00<0PJV10:CLY`2Tg:L0
3`2Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj80
4P2Tfj800`21ZH40WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[NP21ZH40
0`21ZH4307BSMP04086YP@1FO5T0EWaI086YPJd0/>3V0@3oool00:h0/>3V0P21ZH400`1UTGH0PJV1
086YP@05086dSPH0PJV12P2KdZ800`21ZH40Y=bW0:CLY`0>0:CLY`03086YP@2Wh:P0Yn2X0180Yn2X
00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086YP@2MdiX0WM>J00h0WM>J
00<0PJV10974SP2Aa8h0202Aa8h6086YP@D0M:=f0P21ZH400`1FO5T0PJV1086YP@2^0;3PiP40oooo
002`0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`02021ZH4209_BXP03086Y
P@2Tg:L0Y=bW00l0Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV0:OOYP0A0:OOYP03086Y
P@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX03`2MdiX00`21ZH40TLB>0974SP08086YP@80RKf:
00<0PJV107BSMP1dXgH01@1dXgH01021ZH40EWaI05IlF@21ZH6`0;3PiP40oooo002a0;3PiP04086Y
P@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`01`2BbY`8086YP@`0Y=bW00<0PJV10:OPZ02W
h:P04P2Wh:P00`21ZH40YmnV0:OOYP0A0:OOYP03086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2M
diX02P2MdiX8086YP@T0RKf:00<0PJV107BSMP1dXgH01@1dXgH01021ZH40EWaI05IlF@21ZH6a0;3P
iP40oooo002b0;3PiP04086YP@1UTGH0II5f086YP@L0PKB>00<0PJV109;:W02BbY`02P2BbY`01021
ZH40W=JS09cFX`2LeZ<9086YP@@0Y=bW00<0PJV10:OPZ02Wh:P04@2Wh:P00`21ZH40YmnV0:OOYP0A
0:OOYP03086YP@2Tfj80Y=^R0140Y=^R00<0PJV109gCVP2MdiX00P2MdiX9086YP@<0U/fG00<0PJV1
08VmRP29_HX02P29_HX00`21ZH40M:=f07BSMP0507BSMP04086YP@1FO5T0EWaI086YPK80/>3V0@3o
ool00;<0/>3V0P21ZH400`1UTGH0PJV1086dSP06086dSP03086YP@2BbY`0T/ZL00X0T/ZL00<0PJV1
09cFX`2LeZ<02@2LeZ=5086YP@/0U/fG00<0PJV108VmRP29_HX02P29_HX00`21ZH40M:=f07BSMP05
07BSMP04086YP@1FO5T0PJV1086YPK<0/>3V0@3oool00;D0/>3V00<0PJV106FAMP21ZH401`21]8h0
0`21ZH40T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00d0W=JS00<0PJV10:7KY@2QfjD04@2QfjD0
0`21ZH40XM^T0:7KY00A0:7KY003086YP@2Neil0W]NO0100W]NO00<0PJV109K=U`2FcIL03P2FcIL0
0`21ZH40RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f00D0M:=f00<0PJV105IlF@21ZH40]@2`h>H1
0?ooo`00]P2`h>H01021ZH40II5f086YP@21ZH46086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV1
09cFX`2LeZ<03@2LeZ<00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV1
09kGW`2Neil0402Neil00`21ZH40U/fG09K=U`0=09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV1
07BSMP1dXgH0101dXgH2086YP@0305IlF@21ZH40/>3V0;D0/>3V0@3oool00;L0/>3V0P21ZH400`1U
TGH0PJV1086dSP05086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<0302LeZ<00`21
ZH40XM^U0:7KY@0A0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kGW`2Neil0402Neil00`21
ZH40U/fG09K=U`0=09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BSMP1dXgH0101dXgH01021
ZH40EWaI086YP@21ZH6g0;3PiP40oooo002i0;3PiP<0PJV11P21]8h00`21ZH40T/ZL09;:W00909;:
W003086YP@2LeZ<0W=JS00`0W=JS00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40XM^T0:7KY00?0:7K
Y003086YP@2Neil0W]NO0100W]NO00<0PJV109K=U`2FcIL0302FcIL00`21ZH40RKf:08VmRP0908Vm
RP03086YP@1dXgH0M:=f00@0M:=f0`21ZH6i0;3PiP40oooo002k0;3PiP@0PJV11021]8h00`21ZH40
T/ZL09;:W00909;:W003086YP@2LeZ<0W=JS00/0W=JS00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40
XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO00l0W]NO00<0PJV109K=U`2FcIL0302FcIL00`21ZH40
RKf:08VmRP0908VmRP03086YP@1dXgH0M:=f0080M:=f1021ZH6k0;3PiP40oooo002m0;3PiPH0PJV1
00<0PKB>086YP@2BbY`02P2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2QfjD0XM^U00l0XM^U
00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0?09kGW`03086YP@2FcIL0U/fG00/0U/fG
00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f086YP@05086YPKd0/>3V0@3oool00;h0/>3V0`21
ZH42072PO`H0PJV11`2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2QfjD0XM^U00l0XM^U00<0
PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0>09kGW`03086YP@2FcIL0U/fG00`0U/fG00<0
PJV108VmRP29_HX01@29_HX6086YP@80II9/0`21ZH6n0;3PiP40oooo00300;3PiP<0PJV10`1`X7l2
086YP@0308:gSP21ZH40PJV100@0PJV10P2BbY`00`21ZH40W=JS09cFX`0;09cFX`03086YP@2QfjD0
XM^U00h0XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0>09kGW`03086YP@2FcIL0
U/fG00/0U/fG00<0PJV108VmRP29_HX01P21ZH400`1i[7l0PJV1086YP@0306FBK0<0PJV1`02`h>H1
0?ooo`00`P2`h>H3086YP@<0L:1o0P21ZH4508:gSPX0PJV11P2LeZ<00`21ZH40XM^U0:7KY@0?0:7K
Y@03086YP@2Qfj@0XM^T00d0XM^T00<0PJV109kGW`2Neil03P2Neil00`21ZH40U/fG09K=U`0509K=
U`X0PJV11@1i[7l2086YP@<0II9/0`21ZH720;3PiP40oooo00340;3PiP<0PJV10`1`X7l00`21ZH40
P[N>08:gSP0608:gSP80PJV1102=a9L@086YP@P0XM^U00<0PJV10:7KY02Qfj@03@2Qfj@00`21ZH40
W]NO09kGW`0609kGWa00PJV11027_Hd2086YP@P0NJao00@0PJV106FBK01UTV`0II9/0`21ZH740;3P
iP40oooo00360;3PiP<0PJV10P1`X7l2086YP@P0P[N>00<0PJV108g4U`2=a9L02@2=a9L00`21ZH40
T/^J09;;VP0509;;VR40PJV11`2?aiD00`21ZH40Qkf=08NmS@0908NmS@03086YP@1i[7l0NJao00H0
NJao0P21ZH4206FBK0<0PJV1aP2`h>H10?ooo`00b02`h>H3086YP@80L:1o00<0PJV108:gSP22]hh0
1P22]hh00`21ZH40SLBG08g4U`0908g4U`03086YP@2BbiX0T/^J00`0T/^J00<0PJV109?<VP2Cc9X0
3@2Cc9X00`21ZH40SlNE08o7U@0<08o7U@03086YP@27_Hd0Qkf=00T0Qkf=00<0PJV107V/O`1i[7l0
1P1i[7l00`21ZH40II9/06FBK003086YPLP0/>3V0@3oool00<X0/>3V0`21ZH400`1`X7l0PJV1086Y
P@0708:gSP80PJV12P2=a9L00`21ZH40T/^J09;;VP0<09;;VP03086YP@2Cc9X0TlbJ00/0TlbJ00<0
PJV108o7U@2?aiD0302?aiD00`21ZH40Qkf=08NmS@0808NmS@80PJV11`1i[7l2086YP@0406FBK021
ZH40PJV1086YPLX0/>3V0@3oool00<d0/>3V1@21ZH4708:gSP03086YP@2=a9L0SLBG00L0SLBG00<0
PJV109;;VP2BbiX0302BbiX00`21ZH40TlbJ09?<VP0;09?<VP03086YP@2?aiD0SlNE00/0SlNE00<0
PJV108NmS@27_Hd02027_Hd00`21ZH40NJao07V/O`0507V/O`D0PJV1c@2`h>H10?ooo`00d02`h>H7
086YP@<0P[N>0P21ZH4808g4U`03086YP@2BbiX0T/^J00/0T/^J00<0PJV109?<VP2Cc9X02`2Cc9X0
0`21ZH40SlNE08o7U@0;08o7U@03086YP@27_Hd0Qkf=00H0Qkf=0P21ZH4307V/O`L0PJV1d02`h>H1
0?ooo`00d`2`h>H<086YP@H0SLBG00<0PJV109;;VP2BbiX02P2BbiX00`21ZH40TlbJ09?<VP0;09?<
VP03086YP@2?aiD0SlNE00X0SlNE00<0PJV108NmS@27_Hd01027_Hd8086YP@04066>J`21ZH40PJV1
086YPM<0/>3V0@3oool00=H0/>3V1@21ZH4206NGM`P0PJV100<0SLBG086YP@2BbiX02`2BbiX00`21
ZH40TlbJ09?<VP0909?<VP03086YP@2?aiD0SlNE00X0SlNE00<0PJV108NmS@21ZH401`21ZH44066>
J`<0PJV1eP2`h>H10?ooo`00f@2`h>H5086YP@0306NGM`21ZH40PJV100@0LJAo:@21ZH4406fNM`80
PJV10P1QSV/4086YPMT0/>3V0@3oool00=d0/>3V1P21ZH45076TO`80PJV12@1gZh<00`21ZH40N:b3
07R/P`0807R/P`03086YP@1eZ7l0MJQo00P0MJQo0P21ZH4506fNM`80PJV100@0HHi[086YP@21ZH40
PJV1g@2`h>H10?ooo`00h@2`h>H4086YP@D0LJAo0P21ZH4807N[P`03086YP@1h[8<0N:b300L0N:b3
00<0PJV107FXO`1eZ7l01P1eZ7l2086YP@D0KIig1021ZH7Q0;3PiP40oooo003U0;3PiP`0PJV10`1g
Zh<00`21ZH40N:b307R/P`0607R/P`03086YP@1eZ7l0MJQo0080MJQo3021ZH7U0;3PiP40oooo003`
0;3PiQ<0PJV1l02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.605 .777 .566 r
.4503 .46959 m .4498 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.605 .777 .566 r
.48991 .5 m .49001 .46977 L .4503 .46959 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.49001 .53023 m .48991 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.49001 .46977 m .48991 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.48991 .5 m .49001 .53023 L .52992 .53029 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.52992 .53029 m .53022 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.53022 .5 m .52992 .46971 L .49001 .46977 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.52992 .46971 m .53022 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.53022 .5 m .52992 .53029 L .56922 .53059 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.56922 .53059 m .56993 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.45183 .43953 m .4503 .46959 L .49001 .46977 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.49001 .46977 m .49032 .43988 L .45183 .43953 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.4498 .5 m .4503 .53041 L .49001 .53023 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.49032 .56012 m .49001 .53023 L .4503 .53041 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.49032 .43988 m .49001 .46977 L .52992 .46971 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.49001 .53023 m .49032 .56012 L .529 .56024 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.529 .56024 m .52992 .53029 L .49001 .53023 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.52992 .46971 m .529 .43976 L .49032 .43988 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.529 .43976 m .52992 .46971 L .56922 .46941 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.56993 .5 m .56922 .46941 L .52992 .46971 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.52992 .53029 m .529 .56024 L .56709 .56082 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.56709 .56082 m .56922 .53059 L .52992 .53029 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.41161 .46916 m .41069 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.4498 .5 m .4503 .46959 L .41161 .46916 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.4503 .53041 m .4498 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.41436 .43871 m .41161 .46916 L .4503 .46959 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.4503 .46959 m .45183 .43953 L .41436 .43871 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.41069 .5 m .41161 .53084 L .4503 .53041 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.45183 .56047 m .4503 .53041 L .41161 .53084 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.4503 .53041 m .45183 .56047 L .49032 .56012 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.45437 .41018 m .45183 .43953 L .49032 .43988 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.49032 .43988 m .49082 .41067 L .45437 .41018 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.49082 .41067 m .49032 .43988 L .529 .43976 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.49082 .58933 m .49032 .56012 L .45183 .56047 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.49032 .56012 m .49082 .58933 L .52748 .58949 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.52748 .58949 m .529 .56024 L .49032 .56012 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.529 .43976 m .52748 .41051 L .49082 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.52748 .41051 m .529 .43976 L .56709 .43918 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.56922 .46941 m .56709 .43918 L .529 .43976 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.529 .56024 m .52748 .58949 L .56352 .59032 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.56352 .59032 m .56709 .56082 L .529 .56024 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.56922 .46941 m .56993 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.56993 .5 m .56922 .53059 L .60709 .53114 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.60709 .53114 m .60821 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.56709 .43918 m .56922 .46941 L .60709 .46886 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.60821 .5 m .60709 .46886 L .56922 .46941 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.56922 .53059 m .56709 .56082 L .60373 .56188 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.60373 .56188 m .60709 .53114 L .56922 .53059 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.41894 .40902 m .41436 .43871 L .45183 .43953 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.45183 .43953 m .45437 .41018 L .41894 .40902 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.41161 .53084 m .41436 .56129 L .45183 .56047 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.45437 .58982 m .45183 .56047 L .41436 .56129 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.45183 .56047 m .45437 .58982 L .49082 .58933 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.37481 .46849 m .37348 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.41069 .5 m .41161 .46916 L .37481 .46849 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.41161 .53084 m .41069 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.45794 .38193 m .45437 .41018 L .49082 .41067 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.49082 .41067 m .49154 .38253 L .45794 .38193 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.49154 .61747 m .49082 .58933 L .45437 .58982 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.49154 .38253 m .49082 .41067 L .52748 .41051 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.49082 .58933 m .49154 .61747 L .52534 .61767 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.52534 .61767 m .52748 .58949 L .49082 .58933 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.56709 .43918 m .56352 .40968 L .52748 .41051 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.56352 .40968 m .56709 .43918 L .60373 .43812 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.60709 .46886 m .60373 .43812 L .56709 .43918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.56709 .56082 m .56352 .59032 L .59813 .5918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.59813 .5918 m .60373 .56188 L .56709 .56082 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.37878 .43741 m .37481 .46849 L .41161 .46916 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.41161 .46916 m .41436 .43871 L .37878 .43741 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.37348 .5 m .37481 .53151 L .41161 .53084 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.41436 .56129 m .41161 .53084 L .37481 .53151 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.52748 .41051 m .52534 .38233 L .49154 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.52534 .38233 m .52748 .41051 L .56352 .40968 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.52748 .58949 m .52534 .61767 L .55853 .61867 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.55853 .61867 m .56352 .59032 L .52748 .58949 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.42535 .38053 m .41894 .40902 L .45437 .41018 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.45437 .41018 m .45794 .38193 L .42535 .38053 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.41436 .56129 m .41894 .59098 L .45437 .58982 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.45794 .61807 m .45437 .58982 L .41894 .59098 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.45437 .58982 m .45794 .61807 L .49154 .61747 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.38539 .40721 m .37878 .43741 L .41436 .43871 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.41436 .43871 m .41894 .40902 L .38539 .40721 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.37481 .53151 m .37878 .56259 L .41436 .56129 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.41894 .59098 m .41436 .56129 L .37878 .56259 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.60709 .46886 m .60821 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.60821 .5 m .60709 .53114 L .64258 .53194 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.64258 .53194 m .64411 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.56352 .40968 m .55853 .38133 L .52534 .38233 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.55853 .38133 m .56352 .40968 L .59813 .4082 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.60373 .43812 m .59813 .4082 L .56352 .40968 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.56352 .59032 m .55853 .61867 L .59031 .62047 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.59031 .62047 m .59813 .5918 L .56352 .59032 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.60373 .43812 m .60709 .46886 L .64258 .46806 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.64411 .5 m .64258 .46806 L .60709 .46886 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.60709 .53114 m .60373 .56188 L .63799 .56341 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.63799 .56341 m .64258 .53194 L .60709 .53114 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.46253 .35521 m .45794 .38193 L .49154 .38253 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.49154 .38253 m .49246 .35586 L .46253 .35521 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.49246 .64414 m .49154 .61747 L .45794 .61807 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.49246 .35586 m .49154 .38253 L .52534 .38233 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.49154 .61747 m .49246 .64414 L .52258 .64436 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.52258 .64436 m .52534 .61767 L .49154 .61747 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.52534 .38233 m .52258 .35564 L .49246 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.52258 .35564 m .52534 .38233 L .55853 .38133 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.52534 .61767 m .52258 .64436 L .55212 .64545 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.55212 .64545 m .55853 .61867 L .52534 .61767 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.59813 .4082 m .60373 .43812 L .63799 .43659 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.64258 .46806 m .63799 .43659 L .60373 .43812 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.60373 .56188 m .59813 .5918 L .63037 .59394 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.63037 .59394 m .63799 .56341 L .60373 .56188 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.39462 .37834 m .38539 .40721 L .41894 .40902 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.41894 .40902 m .42535 .38053 L .39462 .37834 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.37878 .56259 m .38539 .59279 L .41894 .59098 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.42535 .61947 m .41894 .59098 L .38539 .59279 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.41894 .59098 m .42535 .61947 L .45794 .61807 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.43357 .35368 m .42535 .38053 L .45794 .38193 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.45794 .38193 m .46253 .35521 L .43357 .35368 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.46253 .64479 m .45794 .61807 L .42535 .61947 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.45794 .61807 m .46253 .64479 L .49246 .64414 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.3409 .46758 m .33917 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.37348 .5 m .37481 .46849 L .3409 .46758 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.37481 .53151 m .37348 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.3461 .43565 m .3409 .46758 L .37481 .46849 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.37481 .46849 m .37878 .43741 L .3461 .43565 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.33917 .5 m .3409 .53242 L .37481 .53151 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.37878 .56259 m .37481 .53151 L .3409 .53242 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.55853 .38133 m .55212 .35455 L .52258 .35564 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.55212 .35455 m .55853 .38133 L .59031 .37953 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.59813 .4082 m .59031 .37953 L .55853 .38133 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.55853 .61867 m .55212 .64545 L .58028 .6474 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.58028 .6474 m .59031 .62047 L .55853 .61867 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.59031 .37953 m .59813 .4082 L .63037 .40606 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.63799 .43659 m .63037 .40606 L .59813 .4082 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.59813 .5918 m .59031 .62047 L .61975 .62304 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.61975 .62304 m .63037 .59394 L .59813 .5918 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.35472 .40475 m .3461 .43565 L .37878 .43741 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.37878 .43741 m .38539 .40721 L .35472 .40475 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.3409 .53242 m .3461 .56435 L .37878 .56259 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.38539 .59279 m .37878 .56259 L .3461 .56435 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.40642 .3513 m .39462 .37834 L .42535 .38053 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.42535 .38053 m .43357 .35368 L .40642 .3513 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.38539 .59279 m .39462 .62166 L .42535 .61947 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.43357 .64632 m .42535 .61947 L .39462 .62166 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.42535 .61947 m .43357 .64632 L .46253 .64479 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.64258 .46806 m .64411 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.64411 .5 m .64258 .53194 L .6746 .53297 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.6746 .53297 m .67654 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.46813 .3305 m .46253 .35521 L .49246 .35586 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.49246 .35586 m .49358 .33115 L .46813 .3305 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.49358 .33115 m .49246 .35586 L .52258 .35564 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.49358 .66885 m .49246 .64414 L .46253 .64479 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.49246 .64414 m .49358 .66885 L .51922 .66907 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.51922 .66907 m .52258 .64436 L .49246 .64414 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.52258 .35564 m .51922 .33093 L .49358 .33115 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.51922 .33093 m .52258 .35564 L .55212 .35455 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.63799 .43659 m .64258 .46806 L .6746 .46703 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.67654 .5 m .6746 .46703 L .64258 .46806 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.64258 .53194 m .63799 .56341 L .66881 .5654 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.66881 .5654 m .6746 .53297 L .64258 .53194 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.52258 .64436 m .51922 .66907 L .5443 .67015 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.5443 .67015 m .55212 .64545 L .52258 .64436 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.3667 .37538 m .35472 .40475 L .38539 .40721 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.38539 .40721 m .39462 .37834 L .3667 .37538 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.3461 .56435 m .35472 .59525 L .38539 .59279 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.39462 .62166 m .38539 .59279 L .35472 .59525 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.44359 .32898 m .43357 .35368 L .46253 .35521 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.46253 .35521 m .46813 .3305 L .44359 .32898 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.46813 .6695 m .46253 .64479 L .43357 .64632 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.46253 .64479 m .46813 .6695 L .49358 .66885 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.59031 .37953 m .58028 .3526 L .55212 .35455 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.58028 .3526 m .59031 .37953 L .61975 .37696 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.63037 .40606 m .61975 .37696 L .59031 .37953 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.59031 .62047 m .58028 .6474 L .60621 .6502 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.60621 .6502 m .61975 .62304 L .59031 .62047 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.63037 .40606 m .63799 .43659 L .66881 .4346 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.6746 .46703 m .66881 .4346 L .63799 .43659 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.63799 .56341 m .63037 .59394 L .65921 .59672 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.65921 .59672 m .66881 .5654 L .63799 .56341 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.55212 .35455 m .5443 .32985 L .51922 .33093 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.5443 .32985 m .55212 .35455 L .58028 .3526 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.55212 .64545 m .5443 .67015 L .5681 .67209 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.5681 .67209 m .58028 .6474 L .55212 .64545 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34398 .447 m
.34422 .44718 L
s
.5 Mabswid
.634 .843 .617 r
.42073 .32662 m .40642 .3513 L .43357 .35368 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.43357 .35368 m .44359 .32898 L .42073 .32662 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.39462 .62166 m .40642 .6487 L .43357 .64632 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.44359 .67102 m .43357 .64632 L .40642 .6487 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.43357 .64632 m .44359 .67102 L .46813 .6695 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.61975 .37696 m .63037 .40606 L .65921 .40328 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.66881 .4346 m .65921 .40328 L .63037 .40606 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.63037 .59394 m .61975 .62304 L .64589 .62639 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.64589 .62639 m .65921 .59672 L .63037 .59394 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.31108 .46642 m .30894 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.33917 .5 m .3409 .46758 L .31108 .46642 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.3409 .53242 m .33917 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.38195 .34809 m .3667 .37538 L .39462 .37834 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.39462 .37834 m .40642 .3513 L .38195 .34809 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.35472 .59525 m .3667 .62462 L .39462 .62166 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.40642 .6487 m .39462 .62166 L .3667 .62462 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.31746 .43343 m .31108 .46642 L .3409 .46758 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.3409 .46758 m .3461 .43565 L .31746 .43343 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.30894 .5 m .31108 .53358 L .3409 .53242 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.3461 .56435 m .3409 .53242 L .31108 .53358 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.34808 .42766 m
.34837 .42751 L
s
.5 Mabswid
.559 .731 .518 r
.32801 .40165 m .31746 .43343 L .3461 .43565 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.3461 .43565 m .35472 .40475 L .32801 .40165 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.31108 .53358 m .31746 .56657 L .3461 .56435 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.35472 .59525 m .3461 .56435 L .31746 .56657 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.58028 .3526 m .5681 .32791 L .5443 .32985 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.5681 .32791 m .58028 .3526 L .60621 .3498 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.61975 .37696 m .60621 .3498 L .58028 .3526 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58028 .6474 m .5681 .67209 L .58983 .67486 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58983 .67486 m .60621 .6502 L .58028 .6474 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.47472 .30833 m .46813 .3305 L .49358 .33115 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.49358 .33115 m .4949 .30892 L .47472 .30833 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.4949 .30892 m .49358 .33115 L .51922 .33093 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.4949 .69108 m .49358 .66885 L .46813 .6695 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.49358 .66885 m .4949 .69108 L .51525 .69128 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.51525 .69128 m .51922 .66907 L .49358 .66885 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.51922 .33093 m .51525 .30872 L .4949 .30892 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.51525 .30872 m .51922 .33093 L .5443 .32985 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.51922 .66907 m .51525 .69128 L .5351 .69225 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.5351 .69225 m .5443 .67015 L .51922 .66907 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.60621 .3498 m .61975 .37696 L .64589 .37361 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.65921 .40328 m .64589 .37361 L .61975 .37696 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.61975 .62304 m .60621 .6502 L .62899 .65381 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.62899 .65381 m .64589 .62639 L .61975 .62304 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.45535 .30698 m .44359 .32898 L .46813 .3305 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.46813 .3305 m .47472 .30833 L .45535 .30698 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.47472 .69167 m .46813 .6695 L .44359 .67102 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.46813 .6695 m .47472 .69167 L .4949 .69108 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.34262 .37167 m .32801 .40165 L .35472 .40475 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.35472 .40475 m .3667 .37538 L .34262 .37167 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.31746 .56657 m .32801 .59835 L .35472 .59525 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.3667 .62462 m .35472 .59525 L .32801 .59835 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40032 .32347 m .38195 .34809 L .40642 .3513 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40642 .3513 m .42073 .32662 L .40032 .32347 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.3667 .62462 m .38195 .65191 L .40642 .6487 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.42073 .67338 m .40642 .6487 L .38195 .65191 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.40642 .6487 m .42073 .67338 L .44359 .67102 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.5443 .32985 m .5351 .30775 L .51525 .30872 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5351 .30775 m .5443 .32985 L .5681 .32791 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.5443 .67015 m .5351 .69225 L .55383 .69398 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.55383 .69398 m .5681 .67209 L .5443 .67015 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.6746 .46703 m .67654 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.67654 .5 m .6746 .53297 L .70188 .53425 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.70188 .53425 m .70421 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.66881 .4346 m .6746 .46703 L .70188 .46575 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.70421 .5 m .70188 .46575 L .6746 .46703 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.6746 .53297 m .66881 .5654 L .69493 .56784 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.69493 .56784 m .70188 .53425 L .6746 .53297 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.43743 .30488 m .42073 .32662 L .44359 .32898 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.44359 .32898 m .45535 .30698 L .43743 .30488 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.45535 .69302 m .44359 .67102 L .42073 .67338 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.44359 .67102 m .45535 .69302 L .47472 .69167 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.65921 .40328 m .66881 .4346 L .69493 .43216 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.70188 .46575 m .69493 .43216 L .66881 .4346 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.66881 .5654 m .65921 .59672 L .68346 .60013 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.68346 .60013 m .69493 .56784 L .66881 .5654 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3611 .34411 m .34262 .37167 L .3667 .37538 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3667 .37538 m .38195 .34809 L .3611 .34411 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.32801 .59835 m .34262 .62833 L .3667 .62462 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.38195 .65191 m .3667 .62462 L .34262 .62833 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.60621 .3498 m .58983 .32514 L .5681 .32791 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.58983 .32514 m .60621 .3498 L .62899 .34619 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.64589 .37361 m .62899 .34619 L .60621 .3498 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.60621 .6502 m .58983 .67486 L .6087 .6784 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.6087 .6784 m .62899 .65381 L .60621 .6502 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5681 .32791 m .55383 .30602 L .5351 .30775 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.55383 .30602 m .5681 .32791 L .58983 .32514 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.5681 .67209 m .55383 .69398 L .57077 .69644 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.57077 .69644 m .58983 .67486 L .5681 .67209 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.64589 .37361 m .65921 .40328 L .68346 .39987 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.69493 .43216 m .68346 .39987 L .65921 .40328 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.65921 .59672 m .64589 .62639 L .66762 .63045 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.66762 .63045 m .68346 .60013 L .65921 .59672 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42163 .30208 m .40032 .32347 L .42073 .32662 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42073 .32662 m .43743 .30488 L .42163 .30208 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.38195 .65191 m .40032 .67653 L .42073 .67338 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.43743 .69512 m .42073 .67338 L .40032 .67653 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.42073 .67338 m .43743 .69512 L .45535 .69302 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.28671 .46503 m .2842 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.30894 .5 m .31108 .46642 L .28671 .46503 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.31108 .53358 m .30894 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.48228 .28932 m .47472 .30833 L .4949 .30892 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.4949 .30892 m .49643 .28977 L .48228 .28932 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.49643 .28977 m .4949 .30892 L .51525 .30872 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.49643 .71023 m .4949 .69108 L .47472 .69167 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.4949 .69108 m .49643 .71023 L .51069 .71038 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51069 .71038 m .51525 .69128 L .4949 .69108 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.2942 .43077 m .28671 .46503 L .31108 .46642 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.31108 .46642 m .31746 .43343 L .2942 .43077 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.2842 .5 m .28671 .53497 L .31108 .53358 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.31746 .56657 m .31108 .53358 L .28671 .53497 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.51525 .30872 m .51069 .28962 L .49643 .28977 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.51069 .28962 m .51525 .30872 L .5351 .30775 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.51525 .69128 m .51069 .71038 L .52458 .71113 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.52458 .71113 m .5351 .69225 L .51525 .69128 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.3832 .31957 m .3611 .34411 L .38195 .34809 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.38195 .34809 m .40032 .32347 L .3832 .31957 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.34262 .62833 m .3611 .65589 L .38195 .65191 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.40032 .67653 m .38195 .65191 L .3611 .65589 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.62899 .34619 m .64589 .37361 L .66762 .36955 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.68346 .39987 m .66762 .36955 L .64589 .37361 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64589 .62639 m .62899 .65381 L .64765 .65816 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64765 .65816 m .66762 .63045 L .64589 .62639 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.46877 .28827 m .45535 .30698 L .47472 .30833 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.47472 .30833 m .48228 .28932 L .46877 .28827 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.48228 .71068 m .47472 .69167 L .45535 .69302 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47472 .69167 m .48228 .71068 L .49643 .71023 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.30655 .39796 m .2942 .43077 L .31746 .43343 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.31746 .43343 m .32801 .40165 L .30655 .39796 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.28671 .53497 m .2942 .56923 L .31746 .56657 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.32801 .59835 m .31746 .56657 L .2942 .56923 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.5351 .30775 m .52458 .28887 L .51069 .28962 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.52458 .28887 m .5351 .30775 L .55383 .30602 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5351 .69225 m .52458 .71113 L .5376 .71246 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5376 .71246 m .55383 .69398 L .5351 .69225 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.58983 .32514 m .57077 .30356 L .55383 .30602 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.57077 .30356 m .58983 .32514 L .6087 .3216 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.62899 .34619 m .6087 .3216 L .58983 .32514 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58983 .67486 m .57077 .69644 L .58528 .69956 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58528 .69956 m .6087 .6784 L .58983 .67486 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32354 .36727 m .30655 .39796 L .32801 .40165 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32801 .40165 m .34262 .37167 L .32354 .36727 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.2942 .56923 m .30655 .60204 L .32801 .59835 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.34262 .62833 m .32801 .59835 L .30655 .60204 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45638 .28667 m .43743 .30488 L .45535 .30698 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45535 .30698 m .46877 .28827 L .45638 .28667 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.46877 .71173 m .45535 .69302 L .43743 .69512 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.45535 .69302 m .46877 .71173 L .48228 .71068 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.6087 .3216 m .62899 .34619 L .64765 .34184 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.66762 .36955 m .64765 .34184 L .62899 .34619 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62899 .65381 m .6087 .6784 L .62388 .68263 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62388 .68263 m .64765 .65816 L .62899 .65381 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.55383 .30602 m .5376 .28754 L .52458 .28887 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.5376 .28754 m .55383 .30602 L .57077 .30356 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.55383 .69398 m .5376 .71246 L .54924 .71433 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.54924 .71433 m .57077 .69644 L .55383 .69398 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40859 .29866 m .3832 .31957 L .40032 .32347 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40032 .32347 m .42163 .30208 L .40859 .29866 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.3611 .65589 m .3832 .68043 L .40032 .67653 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.42163 .69792 m .40032 .67653 L .3832 .68043 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.40032 .67653 m .42163 .69792 L .43743 .69512 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34488 .33941 m .32354 .36727 L .34262 .37167 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34262 .37167 m .3611 .34411 L .34488 .33941 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.30655 .60204 m .32354 .63273 L .34262 .62833 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.3611 .65589 m .34262 .62833 L .32354 .63273 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.70188 .46575 m .70421 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.70421 .5 m .70188 .53425 L .72294 .53575 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.72294 .53575 m .72562 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.69493 .43216 m .70188 .46575 L .72294 .46425 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.72562 .5 m .72294 .46425 L .70188 .46575 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.70188 .53425 m .69493 .56784 L .71494 .57071 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.71494 .57071 m .72294 .53575 L .70188 .53425 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.4456 .28455 m .42163 .30208 L .43743 .30488 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.43743 .30488 m .45638 .28667 L .4456 .28455 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45638 .71333 m .43743 .69512 L .42163 .69792 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.43743 .69512 m .45638 .71333 L .46877 .71173 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.68346 .39987 m .69493 .43216 L .71494 .42929 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.72294 .46425 m .71494 .42929 L .69493 .43216 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.69493 .56784 m .68346 .60013 L .70178 .6041 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.70178 .6041 m .71494 .57071 L .69493 .56784 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.37018 .31502 m .34488 .33941 L .3611 .34411 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.3611 .34411 m .3832 .31957 L .37018 .31502 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.32354 .63273 m .34488 .66059 L .3611 .65589 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.3832 .68043 m .3611 .65589 L .34488 .66059 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.57077 .30356 m .54924 .28567 L .5376 .28754 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.54924 .28567 m .57077 .30356 L .58528 .30044 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.6087 .3216 m .58528 .30044 L .57077 .30356 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.57077 .69644 m .54924 .71433 L .55905 .71669 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.55905 .71669 m .58528 .69956 L .57077 .69644 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.58528 .30044 m .6087 .3216 L .62388 .31737 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.64765 .34184 m .62388 .31737 L .6087 .3216 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.6087 .6784 m .58528 .69956 L .59668 .70325 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.59668 .70325 m .62388 .68263 L .6087 .6784 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.66762 .36955 m .68346 .39987 L .70178 .3959 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.71494 .42929 m .70178 .3959 L .68346 .39987 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68346 .60013 m .66762 .63045 L .68373 .63515 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68373 .63515 m .70178 .6041 L .68346 .60013 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49074 .27412 m .48228 .28932 L .49643 .28977 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49643 .28977 m .49813 .27437 L .49074 .27412 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.49813 .27437 m .49643 .28977 L .51069 .28962 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49813 .72563 m .49643 .71023 L .48228 .71068 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49643 .71023 m .49813 .72563 L .50559 .72571 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.50559 .72571 m .51069 .71038 L .49643 .71023 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.51069 .28962 m .50559 .27429 L .49813 .27437 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.50559 .27429 m .51069 .28962 L .52458 .28887 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51069 .71038 m .50559 .72571 L .51284 .72613 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51284 .72613 m .52458 .71113 L .51069 .71038 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48372 .27353 m .46877 .28827 L .48228 .28932 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48228 .28932 m .49074 .27412 L .48372 .27353 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.49074 .72588 m .48228 .71068 L .46877 .71173 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.48228 .71068 m .49074 .72588 L .49813 .72563 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.64765 .34184 m .66762 .36955 L .68373 .36485 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.70178 .3959 m .68373 .36485 L .66762 .36955 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66762 .63045 m .64765 .65816 L .66116 .66317 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66116 .66317 m .68373 .63515 L .66762 .63045 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.52458 .28887 m .51284 .27387 L .50559 .27429 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.51284 .27387 m .52458 .28887 L .5376 .28754 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.52458 .71113 m .51284 .72613 L .51957 .72688 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.51957 .72688 m .5376 .71246 L .52458 .71113 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.43688 .28198 m .40859 .29866 L .42163 .30208 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.42163 .30208 m .4456 .28455 L .43688 .28198 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.3832 .68043 m .40859 .70134 L .42163 .69792 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.4456 .71545 m .42163 .69792 L .40859 .70134 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.42163 .69792 m .4456 .71545 L .45638 .71333 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29021 .44465 m
.29134 .44385 L
s
.5 Mabswid
.597 .819 .612 r
.47734 .27264 m .45638 .28667 L .46877 .28827 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.46877 .28827 m .48372 .27353 L .47734 .27264 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.48372 .72647 m .46877 .71173 L .45638 .71333 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.46877 .71173 m .48372 .72647 L .49074 .72588 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2971 .42057 m
.29765 .42162 L
s
.5 Mabswid
.555 .759 .553 r
.39896 .29471 m .37018 .31502 L .3832 .31957 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.3832 .31957 m .40859 .29866 L .39896 .29471 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.34488 .66059 m .37018 .68498 L .3832 .68043 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.40859 .70134 m .3832 .68043 L .37018 .68498 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.5376 .28754 m .51957 .27312 L .51284 .27387 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.51957 .27312 m .5376 .28754 L .54924 .28567 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.5376 .71246 m .51957 .72688 L .52552 .72791 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.52552 .72791 m .54924 .71433 L .5376 .71246 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.26939 .46342 m .26655 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.2842 .5 m .28671 .46503 L .26939 .46342 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.28671 .53497 m .2842 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.27785 .42772 m .26939 .46342 L .28671 .46503 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.28671 .46503 m .2942 .43077 L .27785 .42772 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.26655 .5 m .26939 .53658 L .28671 .53497 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.2942 .56923 m .28671 .53497 L .26939 .53658 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.62388 .31737 m .64765 .34184 L .66116 .33683 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.68373 .36485 m .66116 .33683 L .64765 .34184 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.64765 .65816 m .62388 .68263 L .63452 .68746 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.63452 .68746 m .66116 .66317 L .64765 .65816 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.58528 .30044 m .55905 .28331 L .54924 .28567 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.55905 .28331 m .58528 .30044 L .59668 .29675 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.62388 .31737 m .59668 .29675 L .58528 .30044 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.58528 .69956 m .55905 .71669 L .56657 .71945 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.56657 .71945 m .59668 .70325 L .58528 .69956 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.29173 .39373 m .27785 .42772 L .2942 .43077 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.2942 .43077 m .30655 .39796 L .29173 .39373 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.26939 .53658 m .27785 .57228 L .2942 .56923 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.30655 .60204 m .2942 .56923 L .27785 .57228 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.47187 .27147 m .4456 .28455 L .45638 .28667 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.45638 .28667 m .47734 .27264 L .47187 .27147 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.47734 .72736 m .45638 .71333 L .4456 .71545 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.45638 .71333 m .47734 .72736 L .48372 .72647 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.31071 .36228 m .29173 .39373 L .30655 .39796 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.30655 .39796 m .32354 .36727 L .31071 .36228 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.27785 .57228 m .29173 .60627 L .30655 .60204 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.32354 .63273 m .30655 .60204 L .29173 .60627 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.54924 .28567 m .52552 .27209 L .51957 .27312 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.52552 .27209 m .54924 .28567 L .55905 .28331 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.54924 .71433 m .52552 .72791 L .53045 .7292 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.53045 .7292 m .55905 .71669 L .54924 .71433 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.59668 .29675 m .62388 .31737 L .63452 .31254 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.66116 .33683 m .63452 .31254 L .62388 .31737 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.62388 .68263 m .59668 .70325 L .60439 .70742 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.60439 .70742 m .63452 .68746 L .62388 .68263 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.33435 .33413 m .31071 .36228 L .32354 .36727 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.32354 .36727 m .34488 .33941 L .33435 .33413 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.29173 .60627 m .31071 .63772 L .32354 .63273 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.34488 .66059 m .32354 .63273 L .31071 .63772 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.43065 .27904 m .39896 .29471 L .40859 .29866 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.40859 .29866 m .43688 .28198 L .43065 .27904 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.37018 .68498 m .39896 .70529 L .40859 .70134 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.43688 .71802 m .40859 .70134 L .39896 .70529 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.40859 .70134 m .43688 .71802 L .4456 .71545 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.46755 .27007 m .43688 .28198 L .4456 .28455 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.4456 .28455 m .47187 .27147 L .46755 .27007 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.47187 .72853 m .4456 .71545 L .43688 .71802 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.4456 .71545 m .47187 .72853 L .47734 .72736 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70512 .59562 m
.70513 .59563 L
s
.5 Mabswid
.489 .672 .482 r
.36211 .30995 m .33435 .33413 L .34488 .33941 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.34488 .33941 m .37018 .31502 L .36211 .30995 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.31071 .63772 m .33435 .66587 L .34488 .66059 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.37018 .68498 m .34488 .66059 L .33435 .66587 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.55905 .28331 m .53045 .2708 L .52552 .27209 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.53045 .2708 m .55905 .28331 L .56657 .28055 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.59668 .29675 m .56657 .28055 L .55905 .28331 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.55905 .71669 m .53045 .7292 L .53411 .7307 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.53411 .7307 m .56657 .71945 L .55905 .71669 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.56657 .28055 m .59668 .29675 L .60439 .29258 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.63452 .31254 m .60439 .29258 L .59668 .29675 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.59668 .70325 m .56657 .71945 L .57141 .72253 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.57141 .72253 m .60439 .70742 L .59668 .70325 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.72294 .46425 m .72562 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.72562 .5 m .72294 .53575 L .73609 .53744 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.73609 .53744 m .73907 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.555 .774 .585 r
.49813 .27437 m .5 .26345 L .49074 .27412 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50559 .27429 m .5 .26345 L .49813 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49813 .72563 L .49074 .72588 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50559 .72571 L .49813 .72563 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51284 .27387 m .5 .26345 L .50559 .27429 L closepath p F P
.505 .664 .505 r
s
.415 .55 .447 r
.71494 .42929 m .72294 .46425 L .73609 .46256 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.73907 .5 m .73609 .46256 L .72294 .46425 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72294 .53575 m .71494 .57071 L .72724 .57394 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72724 .57394 m .73609 .53744 L .72294 .53575 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .51284 .72613 L .50559 .72571 L closepath p F P
.505 .664 .505 r
s
.504 .697 .507 r
.39333 .29036 m .36211 .30995 L .37018 .31502 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.37018 .31502 m .39896 .29471 L .39333 .29036 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.33435 .66587 m .36211 .69005 L .37018 .68498 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.39896 .70529 m .37018 .68498 L .36211 .69005 L p F P
.505 .664 .505 r
s
.552 .77 .582 r
.49074 .27412 m .5 .26345 L .48372 .27353 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .49074 .72588 L .48372 .72647 L closepath p F P
.505 .664 .505 r
s
.444 .597 .482 r
.70178 .3959 m .71494 .42929 L .72724 .42606 L p F P
.505 .664 .505 r
s
.415 .55 .447 r
.73609 .46256 m .72724 .42606 L .71494 .42929 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71494 .57071 m .70178 .6041 L .71274 .60854 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71274 .60854 m .72724 .57394 L .71494 .57071 L p F P
.505 .664 .505 r
s
.553 .772 .586 r
.51957 .27312 m .5 .26345 L .51284 .27387 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .51957 .72688 L .51284 .72613 L closepath p F P
.505 .664 .505 r
s
.544 .757 .564 r
.46458 .26849 m .43065 .27904 L .43688 .28198 L p F P
.505 .664 .505 r
s
.544 .757 .564 r
.43688 .28198 m .46755 .27007 L .46458 .26849 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.39896 .70529 m .43065 .72096 L .43688 .71802 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.46755 .72993 m .43688 .71802 L .43065 .72096 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.43688 .71802 m .46755 .72993 L .47187 .72853 L p F P
.505 .664 .505 r
s
.547 .764 .578 r
.48372 .27353 m .5 .26345 L .47734 .27264 L closepath p F P
.505 .664 .505 r
s
.238 .276 .227 r
.70178 .6041 m .68373 .63515 L .69297 .64039 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.69297 .64039 m .71274 .60854 L .70178 .6041 L p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .48372 .72647 L .47734 .72736 L closepath p F P
.505 .664 .505 r
s
.469 .638 .513 r
.68373 .36485 m .70178 .3959 L .71274 .39146 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.72724 .42606 m .71274 .39146 L .70178 .3959 L p F P
.505 .664 .505 r
s
.549 .767 .583 r
.52552 .27209 m .5 .26345 L .51957 .27312 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .52552 .72791 L .51957 .72688 L closepath p F P
.505 .664 .505 r
s
.491 .673 .537 r
.66116 .33683 m .68373 .36485 L .69297 .35961 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.71274 .39146 m .69297 .35961 L .68373 .36485 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.68373 .63515 m .66116 .66317 L .66846 .66869 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.66846 .66869 m .69297 .64039 L .68373 .63515 L p F P
.505 .664 .505 r
s
.541 .757 .572 r
.47734 .27264 m .5 .26345 L .47187 .27147 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .47734 .72736 L .47187 .72853 L closepath p F P
.505 .664 .505 r
s
.513 .715 .527 r
.42727 .27585 m .39333 .29036 L .39896 .29471 L p F P
.505 .664 .505 r
s
.513 .715 .527 r
.39896 .29471 m .43065 .27904 L .42727 .27585 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.36211 .69005 m .39333 .70964 L .39896 .70529 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.43065 .72096 m .39896 .70529 L .39333 .70964 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.56657 .28055 m .53411 .2693 L .53045 .2708 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.53411 .2693 m .56657 .28055 L .57141 .27747 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.60439 .29258 m .57141 .27747 L .56657 .28055 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.56657 .71945 m .53411 .7307 L .53635 .73235 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.53635 .73235 m .57141 .72253 L .56657 .71945 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27384 .44241 m
.27435 .44249 L
s
.5 Mabswid
.543 .76 .579 r
.53045 .2708 m .5 .26345 L .52552 .27209 L closepath p F P
.505 .664 .505 r
s
.507 .701 .556 r
.63452 .31254 m .66116 .33683 L .66846 .33131 L p F P
.505 .664 .505 r
s
.491 .673 .537 r
.69297 .35961 m .66846 .33131 L .66116 .33683 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.66116 .66317 m .63452 .68746 L .63983 .69272 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.63983 .69272 m .66846 .66869 L .66116 .66317 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .53045 .7292 L .52552 .72791 L closepath p F P
.505 .664 .505 r
s
.533 .748 .565 r
.47187 .27147 m .5 .26345 L .46755 .27007 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .47187 .72853 L .46755 .72993 L closepath p F P
.505 .664 .505 r
s
.518 .721 .567 r
.60439 .29258 m .63452 .31254 L .63983 .30728 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.66846 .33131 m .63983 .30728 L .63452 .31254 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.63452 .68746 m .60439 .70742 L .60783 .71191 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60783 .71191 m .63983 .69272 L .63452 .68746 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27317 .44045 m
.27384 .44241 L
s
.5 Mabswid
.535 .751 .573 r
.53411 .2693 m .5 .26345 L .53045 .2708 L closepath p F P
.505 .664 .505 r
s
.184 .192 .146 r
.5 .73655 m .53411 .7307 L .53045 .7292 L closepath p F P
.505 .664 .505 r
s
.517 .725 .541 r
.46311 .26679 m .42727 .27585 L .43065 .27904 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.43065 .27904 m .46458 .26849 L .46311 .26679 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.39333 .70964 m .42727 .72415 L .43065 .72096 L p F P
.505 .664 .505 r
s
.191 .198 .151 r
.46458 .73151 m .43065 .72096 L .42727 .72415 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.43065 .72096 m .46458 .73151 L .46755 .72993 L p F P
.505 .664 .505 r
s
.524 .737 .557 r
.46755 .27007 m .5 .26345 L .46458 .26849 L closepath p F P
.505 .664 .505 r
s
.185 .192 .146 r
.5 .73655 m .46755 .72993 L .46458 .73151 L closepath p F P
.505 .664 .505 r
s
.524 .733 .572 r
.57141 .27747 m .60439 .29258 L .60783 .28809 L p F P
.505 .664 .505 r
s
.518 .721 .567 r
.63983 .30728 m .60783 .28809 L .60439 .29258 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60439 .70742 m .57141 .72253 L .57327 .72581 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57327 .72581 m .60783 .71191 L .60439 .70742 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27317 .44045 m
.27407 .43506 L
s
.27407 .43506 m
.28 .41702 L
s
.5 Mabswid
.526 .74 .566 r
.53635 .26765 m .5 .26345 L .53411 .2693 L closepath p F P
.505 .664 .505 r
s
.551 .768 .591 r
.57141 .27747 m .53635 .26765 L .53411 .2693 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .53635 .73235 L .53411 .7307 L closepath p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26084 .46165 m .25775 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26655 .5 m .26939 .46342 L .26084 .46165 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.26939 .53658 m .26655 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.27002 .42434 m .26084 .46165 L .26939 .46342 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.26939 .46342 m .27785 .42772 L .27002 .42434 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.25775 .5 m .26084 .53835 L .26939 .53658 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.27785 .57228 m .26939 .53658 L .26084 .53835 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.28501 .38909 m .27002 .42434 L .27785 .42772 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.27785 .42772 m .29173 .39373 L .28501 .38909 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.26084 .53835 m .27002 .57566 L .27785 .57228 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.29173 .60627 m .27785 .57228 L .27002 .57566 L p F P
.505 .664 .505 r
s
.523 .735 .568 r
.53635 .26765 m .57141 .27747 L .57327 .27419 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.60783 .28809 m .57327 .27419 L .57141 .27747 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57141 .72253 m .53635 .73235 L .53702 .73408 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.53702 .73408 m .57327 .72581 L .57141 .72253 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.30538 .35684 m .28501 .38909 L .29173 .39373 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.29173 .39373 m .31071 .36228 L .30538 .35684 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.27002 .57566 m .28501 .61091 L .29173 .60627 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.31071 .63772 m .29173 .60627 L .28501 .61091 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.33053 .32842 m .30538 .35684 L .31071 .36228 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.31071 .36228 m .33435 .33413 L .33053 .32842 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.28501 .61091 m .30538 .64316 L .31071 .63772 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.33435 .66587 m .31071 .63772 L .30538 .64316 L p F P
.505 .664 .505 r
s
.514 .725 .548 r
.46458 .26849 m .5 .26345 L .46311 .26679 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.42727 .72415 m .46311 .73321 L .46458 .73151 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .46458 .73151 L .46311 .73321 L closepath p F P
.505 .664 .505 r
s
.399 .562 .4 r
.35974 .30454 m .33053 .32842 L .33435 .33413 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.33435 .33413 m .36211 .30995 L .35974 .30454 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.30538 .64316 m .33053 .67158 L .33435 .66587 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.36211 .69005 m .33435 .66587 L .33053 .67158 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.39219 .28577 m .35974 .30454 L .36211 .30995 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.36211 .30995 m .39333 .29036 L .39219 .28577 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.33053 .67158 m .35974 .69546 L .36211 .69005 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39333 .70964 m .36211 .69005 L .35974 .69546 L p F P
.505 .664 .505 r
s
.516 .728 .557 r
.53702 .26592 m .5 .26345 L .53635 .26765 L closepath p F P
.505 .664 .505 r
s
.523 .735 .568 r
.57327 .27419 m .53702 .26592 L .53635 .26765 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .53702 .73408 L .53635 .73235 L closepath p F P
.505 .664 .505 r
s
.461 .653 .481 r
.427 .27253 m .39219 .28577 L .39333 .29036 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.39333 .29036 m .42727 .27585 L .427 .27253 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.35974 .69546 m .39219 .71423 L .39333 .70964 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.42727 .72415 m .39333 .70964 L .39219 .71423 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.46325 .26505 m .427 .27253 L .42727 .27585 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.42727 .27585 m .46311 .26679 L .46325 .26505 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39219 .71423 m .427 .72747 L .42727 .72415 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.46311 .73321 m .42727 .72415 L .427 .72747 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72745 .57307 m
.72802 .57251 L
s
.71726 .59775 m
.71744 .59956 L
s
.5 Mabswid
.504 .712 .539 r
.46311 .26679 m .5 .26345 L .46325 .26505 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.427 .72747 m .46325 .73495 L .46311 .73321 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .46311 .73321 L .46325 .73495 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .53351 .73747 L .53608 .73581 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .52942 .73899 L .53351 .73747 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .52395 .74028 L .52942 .73899 L closepath p F P
.505 .664 .505 r
s
.141 .151 .115 r
.5 .73655 m .51735 .74128 L .52395 .74028 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50992 .74195 L .51735 .74128 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50201 .74224 L .50992 .74195 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .494 .74214 L .50201 .74224 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .48628 .74166 L .494 .74214 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .47923 .74082 L .48628 .74166 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .47316 .73967 L .47923 .74082 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .46835 .73825 L .47316 .73967 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .46501 .73666 L .46835 .73825 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .46325 .73495 L .46501 .73666 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .53608 .73581 L .53702 .73408 L closepath p F P
.505 .664 .505 r
s
.506 .715 .548 r
.53608 .26419 m .5 .26345 L .53702 .26592 L closepath p F P
.505 .664 .505 r
s
.494 .702 .539 r
.53351 .26253 m .5 .26345 L .53608 .26419 L closepath p F P
.505 .664 .505 r
s
.493 .699 .53 r
.46325 .26505 m .5 .26345 L .46501 .26334 L closepath p F P
.505 .664 .505 r
s
.483 .689 .529 r
.52942 .26101 m .5 .26345 L .53351 .26253 L closepath p F P
.505 .664 .505 r
s
.482 .686 .521 r
.46501 .26334 m .5 .26345 L .46835 .26175 L closepath p F P
.505 .664 .505 r
s
.473 .676 .52 r
.52395 .25972 m .5 .26345 L .52942 .26101 L closepath p F P
.505 .664 .505 r
s
.472 .674 .513 r
.46835 .26175 m .5 .26345 L .47316 .26033 L closepath p F P
.505 .664 .505 r
s
.465 .666 .512 r
.51735 .25872 m .5 .26345 L .52395 .25972 L closepath p F P
.505 .664 .505 r
s
.464 .664 .506 r
.47316 .26033 m .5 .26345 L .47923 .25918 L closepath p F P
.505 .664 .505 r
s
.458 .658 .505 r
.50992 .25805 m .5 .26345 L .51735 .25872 L closepath p F P
.505 .664 .505 r
s
.458 .657 .502 r
.47923 .25918 m .5 .26345 L .48628 .25834 L closepath p F P
.505 .664 .505 r
s
.454 .652 .501 r
.50201 .25776 m .5 .26345 L .50992 .25805 L closepath p F P
.505 .664 .505 r
s
.454 .652 .499 r
.48628 .25834 m .5 .26345 L .494 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.494 .25786 m .5 .26345 L .50201 .25776 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71744 .59956 m
.71876 .60025 L
s
.5 Mabswid
.15 .16 .122 r
.57327 .72581 m .53702 .73408 L .53608 .73581 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.53702 .26592 m .57327 .27419 L .57192 .27086 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.57192 .27086 m .53608 .26419 L .53702 .26592 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72802 .57251 m
.72948 .57304 L
s
.5 Mabswid
.136 .147 .112 r
.60783 .71191 m .57327 .72581 L .57192 .72914 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.53608 .73581 m .57192 .72914 L .57327 .72581 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.57327 .27419 m .60783 .28809 L .60658 .28345 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.60658 .28345 m .57192 .27086 L .57327 .27419 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.63983 .69272 m .60783 .71191 L .60658 .71655 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.57192 .72914 m .60658 .71655 L .60783 .71191 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.60783 .28809 m .63983 .30728 L .63911 .30177 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.63911 .30177 m .60658 .28345 L .60783 .28809 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.42999 .73078 m .46501 .73666 L .46325 .73495 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.46325 .73495 m .427 .72747 L .42999 .73078 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.427 .27253 m .46325 .26505 L .46501 .26334 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.66846 .66869 m .63983 .69272 L .63911 .69823 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.60658 .71655 m .63911 .69823 L .63983 .69272 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.63983 .30728 m .66846 .33131 L .66858 .32547 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.66858 .32547 m .63911 .30177 L .63983 .30728 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.69297 .64039 m .66846 .66869 L .66858 .67453 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.63911 .69823 m .66858 .67453 L .66846 .66869 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.66846 .33131 m .69297 .35961 L .69409 .35401 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.69409 .35401 m .66858 .32547 L .66846 .33131 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.57192 .72914 m .53608 .73581 L .53351 .73747 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.53608 .26419 m .57192 .27086 L .56728 .26762 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.56728 .26762 m .53351 .26253 L .53608 .26419 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.69297 .35961 m .71274 .39146 L .71485 .38667 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.71485 .38667 m .69409 .35401 L .69297 .35961 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.71274 .60854 m .69297 .64039 L .69409 .64599 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.66858 .67453 m .69409 .64599 L .69297 .64039 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.71274 .39146 m .72724 .42606 L .73019 .42257 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.73019 .42257 m .71485 .38667 L .71274 .39146 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.72724 .57394 m .71274 .60854 L .71485 .61333 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.69409 .64599 m .71485 .61333 L .71274 .60854 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.39589 .71886 m .42999 .73078 L .427 .72747 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.427 .72747 m .39219 .71423 L .39589 .71886 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.46501 .26334 m .42999 .26922 L .427 .27253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.39219 .28577 m .427 .27253 L .42999 .26922 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.72724 .42606 m .73609 .46256 L .7396 .46071 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.7396 .46071 m .73019 .42257 L .72724 .42606 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73609 .53744 m .72724 .57394 L .73019 .57743 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.71485 .61333 m .73019 .57743 L .72724 .57394 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72476 .59014 m
.72534 .59041 L
s
.5 Mabswid
.202 .269 .246 r
.73609 .46256 m .73907 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.74277 .5 m .7396 .46071 L .73609 .46256 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.73907 .5 m .73609 .53744 L .7396 .53929 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73019 .57743 m .7396 .53929 L .73609 .53744 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.7396 .53929 m .74277 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.43626 .73392 m .46835 .73825 L .46501 .73666 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.46501 .73666 m .42999 .73078 L .43626 .73392 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.42999 .26922 m .46501 .26334 L .46835 .26175 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7219 .59682 m
.72263 .59582 L
s
1 .5 0 r
.27108 .42185 m
.27275 .41636 L
s
.26546 .44037 m
.26871 .42967 L
s
.5 Mabswid
.119 .131 .1 r
.36367 .701 m .39589 .71886 L .39219 .71423 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.39219 .71423 m .35974 .69546 L .36367 .701 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.42999 .26922 m .39589 .28114 L .39219 .28577 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.35974 .30454 m .39219 .28577 L .39589 .28114 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.53351 .73747 m .56728 .73238 L .57192 .72914 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56728 .73238 m .53351 .73747 L .52942 .73899 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.53351 .26253 m .56728 .26762 L .55944 .26462 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.55944 .26462 m .52942 .26101 L .53351 .26253 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27275 .41636 m
.27297 .41417 L
s
0 0 0 r
.72263 .59582 m
.72534 .59041 L
s
.5 Mabswid
.097 .111 .084 r
.60658 .71655 m .57192 .72914 L .56728 .73238 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.57192 .27086 m .60658 .28345 L .60039 .27887 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.60039 .27887 m .56728 .26762 L .57192 .27086 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72691 .58649 m
.7285 .58137 L
s
.5 Mabswid
.104 .118 .09 r
.44561 .73673 m .47316 .73967 L .46835 .73825 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.46835 .73825 m .43626 .73392 L .44561 .73673 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.43626 .26608 m .46835 .26175 L .47316 .26033 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.46835 .26175 m .43626 .26608 L .42999 .26922 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27234 .41371 m
.27297 .41417 L
s
0 0 0 r
.72534 .59041 m
.72691 .58649 L
s
.5 Mabswid
.342 .499 .362 r
.39589 .28114 m .36367 .299 L .35974 .30454 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.33053 .32842 m .35974 .30454 L .36367 .299 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.3343 .67749 m .36367 .701 L .35974 .69546 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.35974 .69546 m .33053 .67158 L .3343 .67749 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.52942 .73899 m .55944 .73538 L .56728 .73238 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.55944 .73538 m .52942 .73899 L .52395 .74028 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.52942 .26101 m .55944 .26462 L .54866 .26204 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.54866 .26204 m .52395 .25972 L .52942 .26101 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.36367 .299 m .3343 .32251 L .33053 .32842 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.30538 .35684 m .33053 .32842 L .3343 .32251 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.30873 .64885 m .3343 .67749 L .33053 .67158 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.33053 .67158 m .30538 .64316 L .30873 .64885 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.4577 .73906 m .47923 .74082 L .47316 .73967 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.47316 .73967 m .44561 .73673 L .4577 .73906 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.44561 .26327 m .47316 .26033 L .47923 .25918 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.47316 .26033 m .44561 .26327 L .43626 .26608 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.40457 .72332 m .43626 .73392 L .42999 .73078 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.42999 .73078 m .39589 .71886 L .40457 .72332 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.39589 .28114 m .42999 .26922 L .43626 .26608 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27126 .41529 m
.27234 .41371 L
s
.5 Mabswid
.066 .083 .063 r
.63911 .69823 m .60658 .71655 L .60039 .72113 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.56728 .73238 m .60039 .72113 L .60658 .71655 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.60658 .28345 m .63911 .30177 L .63189 .29627 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.63189 .29627 m .60039 .27887 L .60658 .28345 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.52395 .74028 m .54866 .73796 L .55944 .73538 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.54866 .73796 m .52395 .74028 L .51735 .74128 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.52395 .25972 m .54866 .26204 L .5354 .26001 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.5354 .26001 m .51735 .25872 L .52395 .25972 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.3343 .32251 m .30873 .35115 L .30538 .35684 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.28501 .38909 m .30538 .35684 L .30873 .35115 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.28783 .6158 m .30873 .64885 L .30538 .64316 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.30538 .64316 m .28501 .61091 L .28783 .6158 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47197 .74076 m .48628 .74166 L .47923 .74082 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47923 .74082 m .4577 .73906 L .47197 .74076 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.4577 .26094 m .47923 .25918 L .48628 .25834 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.47923 .25918 m .4577 .26094 L .44561 .26327 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.30873 .35115 m .28783 .3842 L .28501 .38909 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.27002 .42434 m .28501 .38909 L .28783 .3842 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.27233 .57924 m .28783 .6158 L .28501 .61091 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.28501 .61091 m .27002 .57566 L .27233 .57924 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.51735 .74128 m .5354 .73999 L .54866 .73796 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.5354 .73999 m .51735 .74128 L .50992 .74195 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.51735 .25872 m .5354 .26001 L .5203 .25865 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.5203 .25865 m .50992 .25805 L .51735 .25872 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.60039 .72113 m .56728 .73238 L .55944 .73538 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.56728 .26762 m .60039 .27887 L .58926 .27459 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.58926 .27459 m .55944 .26462 L .56728 .26762 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48771 .74174 m .494 .74214 L .48628 .74166 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48628 .74166 m .47197 .74076 L .48771 .74174 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.48628 .25834 m .47197 .25924 L .4577 .26094 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.47197 .25924 m .48628 .25834 L .494 .25786 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.28783 .3842 m .27233 .42076 L .27002 .42434 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26877 .42052 m
.27126 .41529 L
s
.5 Mabswid
.115 .151 .14 r
.26084 .46165 m .27002 .42434 L .27233 .42076 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.2628 .54024 m .27233 .57924 L .27002 .57566 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.27002 .57566 m .26084 .53835 L .2628 .54024 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.50992 .74195 m .5203 .74135 L .5354 .73999 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.5203 .74135 m .50992 .74195 L .50201 .74224 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50992 .25805 m .5203 .25865 L .50411 .25806 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50411 .25806 m .50201 .25776 L .50992 .25805 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.60039 .72113 m .63189 .70373 L .63911 .69823 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.66858 .67453 m .63911 .69823 L .63189 .70373 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.63911 .30177 m .66858 .32547 L .66077 .31957 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66077 .31957 m .63189 .29627 L .63911 .30177 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.27233 .42076 m .2628 .45976 L .26084 .46165 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26306 .43913 m
.27159 .41292 L
s
.5 Mabswid
.141 .185 .177 r
.25775 .5 m .26084 .46165 L .2628 .45976 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.25958 .5 m .2628 .54024 L .26084 .53835 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.26084 .53835 m .25775 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.50411 .74194 m .50201 .74224 L .494 .74214 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.494 .74214 m .48771 .74174 L .50411 .74194 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.48771 .25826 m .494 .25786 L .50201 .25776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.494 .25786 m .48771 .25826 L .47197 .25924 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.50201 .74224 m .50411 .74194 L .5203 .74135 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.50201 .25776 m .50411 .25806 L .48771 .25826 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.2628 .45976 m .25958 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72511 .59578 m
.73297 .57521 L
s
.7227 .60155 m
.72511 .59578 L
s
.5 Mabswid
.32 .475 .391 r
.37424 .70639 m .40457 .72332 L .39589 .71886 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.39589 .71886 m .36367 .701 L .37424 .70639 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.43626 .26608 m .40457 .27668 L .39589 .28114 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36367 .299 m .39589 .28114 L .40457 .27668 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.41809 .72736 m .44561 .73673 L .43626 .73392 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.43626 .73392 m .40457 .72332 L .41809 .72736 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.40457 .27668 m .43626 .26608 L .44561 .26327 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72193 .60382 m
.7227 .60155 L
s
.5 Mabswid
.241 .356 .243 r
.69409 .64599 m .66858 .67453 L .66077 .68043 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.63189 .70373 m .66077 .68043 L .66858 .67453 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.66858 .32547 m .69409 .35401 L .68605 .34829 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.68605 .34829 m .66077 .31957 L .66858 .32547 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72182 .60456 m
.72193 .60382 L
s
.5 Mabswid
.058 .075 .057 r
.55944 .73538 m .58926 .72541 L .60039 .72113 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.58926 .72541 m .55944 .73538 L .54866 .73796 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.55944 .26462 m .58926 .27459 L .57348 .27086 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.57348 .27086 m .54866 .26204 L .55944 .26462 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26902 .41758 m
.27046 .41358 L
s
.5 Mabswid
.322 .477 .349 r
.63189 .70373 m .60039 .72113 L .58926 .72541 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.60039 .27887 m .63189 .29627 L .61797 .29106 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.61797 .29106 m .58926 .27459 L .60039 .27887 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26408 .43274 m
.2652 .42885 L
s
.26303 .43635 m
.26408 .43274 L
s
.5 Mabswid
.123 .135 .103 r
.69409 .35401 m .71485 .38667 L .70681 .38173 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.70681 .38173 m .68605 .34829 L .69409 .35401 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.71485 .61333 m .69409 .64599 L .68605 .65171 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.66077 .68043 m .68605 .65171 L .69409 .64599 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.34626 .68331 m .37424 .70639 L .36367 .701 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.36367 .701 m .3343 .67749 L .34626 .68331 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.40457 .27668 m .37424 .29361 L .36367 .299 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.3343 .32251 m .36367 .299 L .37424 .29361 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27046 .41358 m
.27133 .41117 L
s
.2652 .42885 m
.26584 .42669 L
s
.26261 .43786 m
.26303 .43635 L
s
.5 Mabswid
.392 .574 .454 r
.43597 .73074 m .4577 .73906 L .44561 .73673 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.44561 .73673 m .41809 .72736 L .43597 .73074 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.41809 .27264 m .44561 .26327 L .4577 .26094 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.44561 .26327 m .41809 .27264 L .40457 .27668 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.73019 .57743 m .71485 .61333 L .70681 .61827 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72182 .60456 m
.72247 .60324 L
s
.5 Mabswid
.241 .346 .229 r
.68605 .65171 m .70681 .61827 L .71485 .61333 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.71485 .38667 m .73019 .42257 L .72227 .41895 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.72227 .41895 m .70681 .38173 L .71485 .38667 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26584 .42669 m
.26687 .42409 L
s
.27133 .41117 m
.27161 .41068 L
s
.5 Mabswid
.334 .498 .374 r
.54866 .73796 m .57348 .72914 L .58926 .72541 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.57348 .72914 m .54866 .73796 L .5354 .73999 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.54866 .26204 m .57348 .27086 L .55369 .26789 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.55369 .26789 m .5354 .26001 L .54866 .26204 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26261 .43786 m
.26285 .4375 L
s
.5 Mabswid
.231 .312 .203 r
.7396 .53929 m .73019 .57743 L .72227 .58105 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.70681 .61827 m .72227 .58105 L .73019 .57743 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72247 .60324 m
.72449 .59832 L
s
.5 Mabswid
.176 .21 .148 r
.73019 .42257 m .7396 .46071 L .7318 .4588 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.7318 .4588 m .72227 .41895 L .73019 .42257 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.39143 .71134 m .41809 .72736 L .40457 .72332 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.40457 .72332 m .37424 .70639 L .39143 .71134 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.37424 .29361 m .40457 .27668 L .41809 .27264 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.32164 .65452 m .34626 .68331 L .3343 .67749 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.3343 .67749 m .30873 .64885 L .32164 .65452 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.37424 .29361 m .34626 .31669 L .3343 .32251 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.30873 .35115 m .3343 .32251 L .34626 .31669 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.7396 .46071 m .74277 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.73502 .5 m .7318 .4588 L .7396 .46071 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.74277 .5 m .7396 .53929 L .7318 .5412 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.72227 .58105 m .7318 .5412 L .7396 .53929 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27128 .41216 m
.27161 .41068 L
s
.5 Mabswid
.221 .289 .192 r
.7318 .5412 m .73502 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.45741 .73324 m .47197 .74076 L .4577 .73906 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.4577 .73906 m .43597 .73074 L .45741 .73324 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.43597 .26926 m .4577 .26094 L .47197 .25924 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.4577 .26094 m .43597 .26926 L .41809 .27264 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26285 .4375 m
.26375 .43526 L
s
.5 Mabswid
.37 .529 .38 r
.66077 .68043 m .63189 .70373 L .61797 .70894 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.58926 .72541 m .61797 .70894 L .63189 .70373 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.63189 .29627 m .66077 .31957 L .64462 .31391 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.64462 .31391 m .61797 .29106 L .63189 .29627 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26687 .42409 m
.2678 .42188 L
s
0 0 0 r
.72449 .59832 m
.73254 .57728 L
s
.7217 .60421 m
.72449 .59832 L
s
.5 Mabswid
.394 .575 .434 r
.5354 .73999 m .55369 .73211 L .57348 .72914 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.55369 .73211 m .5354 .73999 L .5203 .74135 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5354 .26001 m .55369 .26789 L .53087 .2659 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.53087 .2659 m .5203 .25865 L .5354 .26001 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72028 .60653 m
.7217 .60421 L
s
1 .5 0 r
.27 .4159 m
.27128 .41216 L
s
.2678 .42188 m
.2693 .41785 L
s
.5 Mabswid
.42 .601 .443 r
.61797 .70894 m .58926 .72541 L .57348 .72914 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.58926 .27459 m .61797 .29106 L .59764 .28646 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.59764 .28646 m .57348 .27086 L .58926 .27459 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26375 .43526 m
.26498 .43134 L
s
.2693 .41785 m
.27 .4159 L
s
.5 Mabswid
.463 .664 .513 r
.48129 .73469 m .48771 .74174 L .47197 .74076 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.47197 .74076 m .45741 .73324 L .48129 .73469 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.45741 .26676 m .47197 .25924 L .48771 .25826 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.47197 .25924 m .45741 .26676 L .43597 .26926 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.34626 .31669 m .32164 .34548 L .30873 .35115 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.28783 .3842 m .30873 .35115 L .32164 .34548 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30132 .62071 m .32164 .65452 L .30873 .64885 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30873 .64885 m .28783 .6158 L .30132 .62071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71921 .60728 m
.72028 .60653 L
s
.5 Mabswid
.438 .63 .477 r
.5203 .74135 m .53087 .7341 L .55369 .73211 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.53087 .7341 m .5203 .74135 L .50411 .74194 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.5203 .25865 m .53087 .2659 L .50627 .26502 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.50627 .26502 m .50411 .25806 L .5203 .25865 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.50627 .73498 m .50411 .74194 L .48771 .74174 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.48771 .74174 m .48129 .73469 L .50627 .73498 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.48129 .26531 m .48771 .25826 L .50411 .25806 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.48771 .25826 m .48129 .26531 L .45741 .26676 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.50411 .74194 m .50627 .73498 L .53087 .7341 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.50411 .25806 m .50627 .26502 L .48129 .26531 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.32164 .34548 m .30132 .37929 L .28783 .3842 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.27233 .42076 m .28783 .3842 L .30132 .37929 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28614 .58285 m .30132 .62071 L .28783 .6158 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28783 .6158 m .27233 .57924 L .28614 .58285 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.41809 .27264 m .39143 .28866 L .37424 .29361 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.34626 .31669 m .37424 .29361 L .39143 .28866 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.36656 .68871 m .39143 .71134 L .37424 .70639 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.37424 .70639 m .34626 .68331 L .36656 .68871 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.68605 .65171 m .66077 .68043 L .64462 .68609 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.61797 .70894 m .64462 .68609 L .66077 .68043 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66077 .31957 m .68605 .34829 L .66819 .34276 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66819 .34276 m .64462 .31391 L .66077 .31957 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41472 .71552 m .43597 .73074 L .41809 .72736 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41809 .72736 m .39143 .71134 L .41472 .71552 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.39143 .28866 m .41809 .27264 L .43597 .26926 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71921 .60728 m
.71921 .60593 L
s
.5 Mabswid
.396 .528 .433 r
.27676 .54216 m .28614 .58285 L .27233 .57924 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27233 .57924 m .2628 .54024 L .27676 .54216 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.30132 .37929 m .28614 .41715 L .27233 .42076 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27275 .4127 m
.27317 .41088 L
s
.27317 .41088 m
.27425 .40873 L
s
.5 Mabswid
.278 .344 .287 r
.2628 .45976 m .27233 .42076 L .28614 .41715 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71921 .60593 m
.72025 .6009 L
s
1 .5 0 r
.27382 .41056 m
.27425 .40873 L
s
.27275 .4127 m
.27382 .41056 L
s
.5 Mabswid
.42 .601 .443 r
.57348 .72914 m .59764 .71354 L .61797 .70894 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.59764 .71354 m .57348 .72914 L .55369 .73211 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57348 .27086 m .59764 .28646 L .57165 .28277 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57165 .28277 m .55369 .26789 L .57348 .27086 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.28614 .41715 m .27676 .45784 L .2628 .45976 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.26233 .44931 m
.26935 .42254 L
s
.5 Mabswid
.329 .42 .348 r
.25958 .5 m .2628 .45976 L .27676 .45784 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.27358 .5 m .27676 .54216 L .2628 .54024 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.2628 .54024 m .25958 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.27676 .45784 m .27358 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68605 .34829 m .70681 .38173 L .68772 .37692 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68772 .37692 m .66819 .34276 L .68605 .34829 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.70681 .61827 m .68605 .65171 L .66819 .65724 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.64462 .68609 m .66819 .65724 L .68605 .65171 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.64462 .68609 m .61797 .70894 L .59764 .71354 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.61797 .29106 m .64462 .31391 L .62029 .30886 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.62029 .30886 m .59764 .28646 L .61797 .29106 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71875 .60365 m
.72836 .57938 L
s
.71682 .60852 m
.71875 .60365 L
s
.5 Mabswid
.542 .758 .585 r
.44307 .71864 m .45741 .73324 L .43597 .73074 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.43597 .73074 m .41472 .71552 L .44307 .71864 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.41472 .28448 m .43597 .26926 L .45741 .26676 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.43597 .26926 m .41472 .28448 L .39143 .28866 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34445 .65982 m .36656 .68871 L .34626 .68331 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34626 .68331 m .32164 .65452 L .34445 .65982 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.39143 .28866 m .36656 .31129 L .34626 .31669 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.32164 .34548 m .34626 .31669 L .36656 .31129 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.72227 .58105 m .70681 .61827 L .68772 .62308 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.66819 .65724 m .68772 .62308 L .70681 .61827 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70681 .38173 m .72227 .41895 L .70237 .41539 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70237 .41539 m .68772 .37692 L .70681 .38173 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.55369 .73211 m .57165 .71723 L .59764 .71354 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.57165 .71723 m .55369 .73211 L .53087 .7341 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.55369 .26789 m .57165 .28277 L .54132 .28027 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.54132 .28027 m .53087 .2659 L .55369 .26789 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39471 .69332 m .41472 .71552 L .39143 .71134 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39143 .71134 m .36656 .68871 L .39471 .69332 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.36656 .31129 m .39143 .28866 L .41472 .28448 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70439 .62444 m
.70605 .62254 L
s
.5 Mabswid
.569 .79 .603 r
.47494 .72046 m .48129 .73469 L .45741 .73324 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.45741 .73324 m .44307 .71864 L .47494 .72046 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.44307 .28136 m .45741 .26676 L .48129 .26531 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.45741 .26676 m .44307 .28136 L .41472 .28448 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.7318 .5412 m .72227 .58105 L .70237 .58461 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.68772 .62308 m .70237 .58461 L .72227 .58105 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70439 .62444 m
.70445 .62307 L
s
.70605 .62254 m
.70614 .62114 L
s
.5 Mabswid
.317 .389 .262 r
.72227 .41895 m .7318 .4588 L .71144 .45691 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.71144 .45691 m .70237 .41539 L .72227 .41895 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70445 .62307 m
.70614 .62114 L
s
.5 Mabswid
.539 .752 .561 r
.53087 .7341 m .54132 .71973 L .57165 .71723 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.54132 .71973 m .53087 .7341 L .50627 .73498 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.53087 .2659 m .54132 .28027 L .5084 .27916 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.5084 .27916 m .50627 .26502 L .53087 .2659 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.36656 .31129 m .34445 .34018 L .32164 .34548 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.30132 .37929 m .32164 .34548 L .34445 .34018 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32606 .62534 m .34445 .65982 L .32164 .65452 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32164 .65452 m .30132 .62071 L .32606 .62534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71136 .6105 m
.71842 .59228 L
s
.5 Mabswid
.511 .698 .501 r
.66819 .65724 m .64462 .68609 L .62029 .69114 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.59764 .71354 m .62029 .69114 L .64462 .68609 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64462 .31391 m .66819 .34276 L .64051 .33778 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64051 .33778 m .62029 .30886 L .64462 .31391 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.7318 .4588 m .73502 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.71452 .5 m .71144 .45691 L .7318 .4588 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.73502 .5 m .7318 .5412 L .71144 .54309 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.70237 .58461 m .71144 .54309 L .7318 .5412 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71842 .59228 m
.72283 .58091 L
s
.5 Mabswid
.576 .798 .604 r
.5084 .72084 m .50627 .73498 L .48129 .73469 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.48129 .73469 m .47494 .72046 L .5084 .72084 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.47494 .27954 m .48129 .26531 L .50627 .26502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.48129 .26531 m .47494 .27954 L .44307 .28136 L p F P
.505 .664 .505 r
s
.567 .786 .59 r
.50627 .73498 m .5084 .72084 L .54132 .71973 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.50627 .26502 m .5084 .27916 L .47494 .27954 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.71144 .54309 m .71452 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.62029 .69114 m .59764 .71354 L .57165 .71723 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.59764 .28646 m .62029 .30886 L .58863 .30478 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.58863 .30478 m .57165 .28277 L .59764 .28646 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.34445 .34018 m .32606 .37466 L .30132 .37929 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.28614 .41715 m .30132 .37929 L .32606 .37466 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.31222 .58629 m .32606 .62534 L .30132 .62071 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.30132 .62071 m .28614 .58285 L .31222 .58629 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.42948 .69679 m .44307 .71864 L .41472 .71552 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.41472 .71552 m .39471 .69332 L .42948 .69679 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.39471 .30668 m .41472 .28448 L .44307 .28136 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.41472 .28448 m .39471 .30668 L .36656 .31129 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.37677 .66439 m .39471 .69332 L .36656 .68871 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.36656 .68871 m .34445 .65982 L .37677 .66439 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.34445 .34018 m .36656 .31129 L .39471 .30668 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.66819 .34276 m .68772 .37692 L .65741 .37255 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.65741 .37255 m .64051 .33778 L .66819 .34276 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.68772 .62308 m .66819 .65724 L .64051 .66222 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.62029 .69114 m .64051 .66222 L .66819 .65724 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.30362 .54399 m .31222 .58629 L .28614 .58285 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.28614 .58285 m .27676 .54216 L .30362 .54399 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.32606 .37466 m .31222 .41371 L .28614 .41715 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.27676 .45784 m .28614 .41715 L .31222 .41371 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7072 .60462 m
.71512 .58242 L
s
.70361 .61079 m
.7072 .60462 L
s
.7005 .61318 m
.70361 .61079 L
s
.5 Mabswid
.552 .758 .556 r
.57165 .71723 m .58863 .69522 L .62029 .69114 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.58863 .69522 m .57165 .71723 L .54132 .71973 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.57165 .28277 m .58863 .30478 L .55125 .302 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.55125 .302 m .54132 .28027 L .57165 .28277 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.31222 .41371 m .30362 .45601 L .27676 .45784 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.27358 .5 m .27676 .45784 L .30362 .45601 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.3007 .5 m .30362 .54399 L .27676 .54216 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.27676 .54216 m .27358 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.30362 .45601 m .3007 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.4689 .69883 m .47494 .72046 L .44307 .71864 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.44307 .71864 m .42948 .69679 L .4689 .69883 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.42948 .30321 m .44307 .28136 L .47494 .27954 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.44307 .28136 m .42948 .30321 L .39471 .30668 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.64051 .66222 m .62029 .69114 L .58863 .69522 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.62029 .30886 m .64051 .33778 L .60391 .33372 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.60391 .33372 m .58863 .30478 L .62029 .30886 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.70237 .58461 m .68772 .62308 L .65741 .62745 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69686 .6139 m
.7005 .61318 L
s
.5 Mabswid
.523 .703 .5 r
.64051 .66222 m .65741 .62745 L .68772 .62308 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.68772 .37692 m .70237 .41539 L .67017 .41214 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.67017 .41214 m .65741 .37255 L .68772 .37692 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69508 .61244 m
.69686 .6139 L
s
.5 Mabswid
.597 .815 .602 r
.54132 .71973 m .55125 .698 L .58863 .69522 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.55125 .698 m .54132 .71973 L .5084 .72084 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.54132 .28027 m .55125 .302 L .51043 .30076 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.51043 .30076 m .5084 .27916 L .54132 .28027 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.39471 .30668 m .37677 .33561 L .34445 .34018 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.32606 .37466 m .34445 .34018 L .37677 .33561 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.36172 .62936 m .37677 .66439 L .34445 .65982 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.34445 .65982 m .32606 .62534 L .36172 .62936 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.51043 .69924 m .5084 .72084 L .47494 .72046 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.47494 .72046 m .4689 .69883 L .51043 .69924 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.4689 .30117 m .47494 .27954 L .5084 .27916 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.47494 .27954 m .4689 .30117 L .42948 .30321 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.5084 .72084 m .51043 .69924 L .55125 .698 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.5084 .27916 m .51043 .30076 L .4689 .30117 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.41721 .66786 m .42948 .69679 L .39471 .69332 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.39471 .69332 m .37677 .66439 L .41721 .66786 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.37677 .33561 m .39471 .30668 L .42948 .30321 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.71144 .54309 m .70237 .58461 L .67017 .58786 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.65741 .62745 m .67017 .58786 L .70237 .58461 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69184 .60825 m
.6936 .60363 L
s
.68444 .62773 m
.69184 .60825 L
s
.69333 .60709 m
.69508 .61244 L
s
.5 Mabswid
.405 .504 .337 r
.70237 .41539 m .71144 .45691 L .67811 .45518 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.67811 .45518 m .67017 .41214 L .70237 .41539 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.71144 .45691 m .71452 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.6808 .5 m .67811 .45518 L .71144 .45691 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.71452 .5 m .71144 .54309 L .67811 .54482 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.67017 .58786 m .67811 .54482 L .71144 .54309 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6936 .60363 m
.7009 .58444 L
s
.5 Mabswid
.38 .454 .309 r
.64051 .33778 m .65741 .37255 L .61675 .36896 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.61675 .36896 m .60391 .33372 L .64051 .33778 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.65741 .62745 m .64051 .66222 L .60391 .66628 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.58863 .69522 m .60391 .66628 L .64051 .66222 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.67811 .54482 m .6808 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.37677 .33561 m .36172 .37064 L .32606 .37466 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.31222 .41371 m .32606 .37466 L .36172 .37064 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.35034 .58928 m .36172 .62936 L .32606 .62534 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.32606 .62534 m .31222 .58629 L .35034 .58928 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.60391 .66628 m .58863 .69522 L .55125 .698 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.58863 .30478 m .60391 .33372 L .56023 .33093 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.56023 .33093 m .55125 .302 L .58863 .30478 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67676 .61513 m
.68166 .61066 L
s
.5 Mabswid
.652 .874 .659 r
.46342 .6699 m .4689 .69883 L .42948 .69679 L p F P
.505 .664 .505 r
s
.652 .874 .659 r
.42948 .69679 m .41721 .66786 L .46342 .6699 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.41721 .33214 m .42948 .30321 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.42948 .30321 m .41721 .33214 L .37677 .33561 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67251 .61753 m
.67676 .61513 L
s
.5 Mabswid
.592 .774 .593 r
.34324 .54559 m .35034 .58928 L .31222 .58629 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.31222 .58629 m .30362 .54399 L .34324 .54559 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.36172 .37064 m .35034 .41072 L .31222 .41371 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.30362 .45601 m .31222 .41371 L .35034 .41072 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68548 .5885 m
.68758 .59299 L
s
.5 Mabswid
.433 .526 .39 r
.36172 .37064 m .37677 .33561 L .41721 .33214 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.40686 .63243 m .41721 .66786 L .37677 .66439 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.37677 .66439 m .36172 .62936 L .40686 .63243 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.55125 .698 m .56023 .66907 L .60391 .66628 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.56023 .66907 m .55125 .698 L .51043 .69924 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.55125 .302 m .56023 .33093 L .51227 .32969 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.51227 .32969 m .51043 .30076 L .55125 .302 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.67017 .58786 m .65741 .62745 L .61675 .63104 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66704 .61816 m
.67251 .61753 L
s
.5 Mabswid
.59 .786 .567 r
.60391 .66628 m .61675 .63104 L .65741 .62745 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.65741 .37255 m .67017 .41214 L .6265 .40946 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.6265 .40946 m .61675 .36896 L .65741 .37255 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6825 .58635 m
.68548 .5885 L
s
.5 Mabswid
.498 .627 .477 r
.35034 .41072 m .34324 .45441 L .30362 .45601 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.3007 .5 m .30362 .45601 L .34324 .45441 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.34082 .5 m .34324 .54559 L .30362 .54399 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.30362 .54399 m .3007 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.51227 .67031 m .51043 .69924 L .4689 .69883 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.4689 .69883 m .46342 .6699 L .51227 .67031 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.46342 .3301 m .4689 .30117 L .51043 .30076 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.4689 .30117 m .46342 .3301 L .41721 .33214 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66395 .61659 m
.66704 .61816 L
s
.5 Mabswid
.645 .864 .639 r
.51043 .69924 m .51227 .67031 L .56023 .66907 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.51043 .30076 m .51227 .32969 L .46342 .3301 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.34324 .45441 m .34082 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67677 .58684 m
.6825 .58635 L
s
.66141 .61289 m
.66395 .61659 L
s
.5 Mabswid
.425 .514 .356 r
.60391 .33372 m .61675 .36896 L .56782 .36649 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.56782 .36649 m .56023 .33093 L .60391 .33372 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.61675 .63104 m .60391 .66628 L .56023 .66907 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.67811 .54482 m .67017 .58786 L .6265 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67215 .58968 m
.67677 .58684 L
s
.5 Mabswid
.585 .769 .551 r
.61675 .63104 m .6265 .59054 L .67017 .58786 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66141 .61289 m
.66141 .60665 L
s
.5 Mabswid
.481 .602 .418 r
.67017 .41214 m .67811 .45518 L .63259 .45374 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.63259 .45374 m .6265 .40946 L .67017 .41214 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66677 .59493 m
.67215 .58968 L
s
.66141 .60665 m
.66274 .60215 L
s
.5 Mabswid
.433 .526 .39 r
.41721 .33214 m .40686 .36757 L .36172 .37064 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.35034 .41072 m .36172 .37064 L .40686 .36757 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.39899 .59158 m .40686 .63243 L .36172 .62936 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.36172 .62936 m .35034 .58928 L .39899 .59158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66274 .60215 m
.66677 .59493 L
s
.5 Mabswid
.459 .56 .408 r
.40686 .36757 m .41721 .33214 L .46342 .3301 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.45878 .63424 m .46342 .6699 L .41721 .66786 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.41721 .66786 m .40686 .63243 L .45878 .63424 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64024 .62069 m
.64686 .62014 L
s
.5 Mabswid
.518 .658 .461 r
.67811 .45518 m .6808 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.63466 .5 m .63259 .45374 L .67811 .45518 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.6808 .5 m .67811 .54482 L .63259 .54626 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.6265 .59054 m .63259 .54626 L .67811 .54482 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63629 .61902 m
.64024 .62069 L
s
.5 Mabswid
.548 .705 .498 r
.63259 .54626 m .63466 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.56023 .66907 m .56782 .63351 L .61675 .63104 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.56023 .33093 m .56782 .36649 L .51383 .36538 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.51383 .36538 m .51227 .32969 L .56023 .33093 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.56782 .63351 m .56023 .66907 L .51227 .67031 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63278 .6152 m
.63629 .61902 L
s
.5 Mabswid
.621 .815 .591 r
.6265 .59054 m .61675 .63104 L .56782 .63351 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.61675 .36896 m .6265 .40946 L .57359 .40761 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.57359 .40761 m .56782 .36649 L .61675 .36896 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.40686 .36757 m .39899 .40842 L .35034 .41072 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.34324 .45441 m .35034 .41072 L .39899 .40842 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.39407 .54682 m .39899 .59158 L .35034 .58928 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.35034 .58928 m .34324 .54559 L .39407 .54682 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.45878 .36576 m .46342 .3301 L .51227 .32969 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.51383 .63462 m .51227 .67031 L .46342 .6699 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.46342 .6699 m .45878 .63424 L .51383 .63462 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.46342 .3301 m .45878 .36576 L .40686 .36757 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63046 .6141 m
.63639 .58948 L
s
.62867 .62155 m
.63046 .6141 L
s
.63208 .60882 m
.63278 .6152 L
s
.5 Mabswid
.648 .859 .632 r
.51227 .67031 m .51383 .63462 L .56782 .63351 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.51227 .32969 m .51383 .36538 L .45878 .36576 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.39899 .40842 m .39407 .45318 L .34324 .45441 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.34082 .5 m .34324 .45441 L .39407 .45318 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.3924 .5 m .39407 .54682 L .34324 .54559 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.34324 .54559 m .34082 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.45525 .59294 m .45878 .63424 L .40686 .63243 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.40686 .63243 m .39899 .59158 L .45525 .59294 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.39899 .40842 m .40686 .36757 L .45878 .36576 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59524 .63659 m
.60602 .62033 L
s
.5 Mabswid
.574 .732 .549 r
.39407 .45318 m .3924 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.6265 .40946 m .63259 .45374 L .57721 .45275 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.57721 .45275 m .57359 .40761 L .6265 .40946 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.63259 .54626 m .6265 .59054 L .57359 .59239 L p F P
.505 .664 .505 r
s
.621 .815 .591 r
.56782 .63351 m .57359 .59239 L .6265 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60602 .62033 m
.61247 .61059 L
s
.61247 .61059 m
.62613 .58998 L
s
.58787 .61288 m
.58858 .61514 L
s
.58858 .61514 m
.59524 .63659 L
s
.58755 .6087 m
.61488 .60754 L
s
.5 Mabswid
.641 .84 .615 r
.57359 .59239 m .56782 .63351 L .51383 .63462 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.56782 .36649 m .57359 .40761 L .51502 .40678 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.51502 .40678 m .51383 .36538 L .56782 .36649 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.63259 .45374 m .63466 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.57845 .5 m .57721 .45275 L .63259 .45374 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.63466 .5 m .63259 .54626 L .57721 .54725 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.57359 .59239 m .57721 .54725 L .63259 .54626 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.58125 .59158 m
.58787 .61288 L
s
.5 Mabswid
.517 .644 .466 r
.45525 .40706 m .45878 .36576 L .51383 .36538 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.51502 .59322 m .51383 .63462 L .45878 .63424 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.45878 .63424 m .45525 .59294 L .51502 .59322 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.45878 .36576 m .45525 .40706 L .39899 .40842 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.39407 .45318 m .39899 .40842 L .45525 .40706 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.45304 .54755 m .45525 .59294 L .39899 .59158 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.39899 .59158 m .39407 .54682 L .45304 .54755 L p F P
.505 .664 .505 r
s
.641 .84 .615 r
.51383 .63462 m .51502 .59322 L .57359 .59239 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.51383 .36538 m .51502 .40678 L .45525 .40706 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.57721 .54725 m .57845 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.626 .813 .593 r
.57721 .54725 m .57359 .59239 L .51502 .59322 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.57359 .40761 m .57721 .45275 L .51576 .4523 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.51576 .4523 m .51502 .40678 L .57359 .40761 L p F P
.505 .664 .505 r
s
.555 .7 .516 r
.45525 .40706 m .45304 .45245 L .39407 .45318 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.3924 .5 m .39407 .45318 L .45304 .45245 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.45228 .5 m .45304 .54755 L .39407 .54682 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.39407 .54682 m .3924 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.45304 .45245 m .45228 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.51576 .5477 m .51502 .59322 L .45525 .59294 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.45525 .59294 m .45304 .54755 L .51576 .5477 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.45304 .45245 m .45525 .40706 L .51502 .40678 L p F P
.505 .664 .505 r
s
.626 .813 .593 r
.51502 .59322 m .51576 .5477 L .57721 .54725 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.51502 .40678 m .51576 .4523 L .45304 .45245 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.57721 .45275 m .57845 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.51602 .5 m .51576 .4523 L .57721 .45275 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.57845 .5 m .57721 .54725 L .51576 .5477 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.51576 .5477 m .51602 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.45228 .5 m .45304 .45245 L .51576 .4523 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.51602 .5 m .51576 .5477 L .45304 .54755 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.45304 .54755 m .45228 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.51576 .4523 m .51602 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>l0/>3V4P21ZH7b0;3PiP40oooo003X0;3PiPP0PJV10P0S9A`0
0`21ZH409BLN02DW7P0602DW7P04086YP@0U9ah09BLN02DW7Pl0PJV1i@2`h>H10?ooo`00hP2`h>H6
086YP@0301hQ6@21ZH40PJV100H08bDL00<0PJV102DW7P0U9ah01`0U9ah00`21ZH409BLN02DW7P06
02DW7P80PJV11`0R9A`6086YPN00/>3V0@3oool00=`0/>3V1`21ZH4401hQ6@80PJV1200S9A`00`21
ZH409BLN02DW7P0802DW7P03086YP@0U9ah09BLN00L09BLN0P21ZH47028U7080PJV10P0M8AT3086Y
PMd0/>3V0@3oool00=P0/>3V1@21ZH400`0G6a@0PJV1086YP@0501hQ6@80PJV1100S9A`S086YP@<0
8RDL0P21ZH4201dQ6@@0PJV1fP2`h>H10?ooo`00eP2`h>H4086YP@0301LK5021ZH40PJV100807R4I
3021ZH4403@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=3HX
03@f:00203@f:0T0PJV100<07B4I086YP@21ZH400`21ZH7F0;3PiP40oooo003C0;3PiP`0PJV1100_
<BD00`21ZH40=3HX03@f:00903@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02`0g
>2/00`21ZH40=3HX03@f:00803@f:003086YP@0^<2D0PJV100L0PJV1e02`h>H10?ooo`00d02`h>H9
086YP@T0;c4U00<0PJV103@f:00d=RP02@0d=RP00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0g>2/0
=cP[00`0=cP[00<0PJV103@f:00d=RP0200d=RP00`21ZH40;S0U02h`9@0302h`9@H0PJV1d@2`h>H1
0?ooo`00cP2`h>H5086YP@<09RTO00<0PJV102la9@0_<BD0200_<BD00`21ZH40=3HX03@f:00:03@f
:003086YP@0g>2/0=cP[00`0=cP[00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=3HX03@f:00903@f
:003086YP@0^<2D0;S0U00D0;S0U1P21ZH7>0;3PiP40oooo003;0;3PiPD0PJV1100V:Al2086YP@X0
;c4U00<0PJV103@f:00d=RP02P0d=RP00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0g>2/0=cP[00`0
=cP[00<0PJV103@f:00d=RP02@0d=RP2086YP@L0;S0U0P21ZH400`0V:1h0PJV1086YP@02086YPL/0
/>3V0@3oool00<T0/>3V0P21ZH400`0K7QL0PJV1086YP@0402HY7`80PJV12`0_<BD00`21ZH40=3HX
03@f:00;03@f:003086YP@0g>2/0=cP[00d0=cP[00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=3HX
03@f:00:03@f:003086YP@0^<2D0;S0U00H0;S0U00@0PJV102HX7P0V:1h09RPN0`21ZH790;3PiP40
oooo00370;3PiP80PJV10P0K7QL00`21ZH409RTO02HY7`0302HY7`03086YP@0_<BD0;c4U00X0;c4U
00<0PJV103@f:00d=RP0100d=RP]086YP@T0=3HX00<0PJV102h`9@0^<2D01P0^<2D2086YP@<09RPN
0`21ZH770;3PiP40oooo00350;3PiP80PJV10P0K7QL2086YP@@09RTO0P21ZH4502la9@l0PJV11`1:
DSX00`21ZH40CUPn04iH?P0>04iH?P03086YP@1>F3h0CUPn00h0CUPn00@0PJV104YB>`1:DS/0BU8k
2021ZH4203@f:003086YP@0^<2D0;S0U00L0;S0U0P21ZH4302HX7P<0PJV1a@2`h>H10?ooo`00``2`
h>H2086YP@<06ahG00<0PJV102HY7`0V:Al00P0V:Al9086YP@H0@DHc00<0PJV104YB>P1:DSX0301:
DSX00`21ZH40CUPn04iH?P0?04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0201:
DS/:086YP@@0;S0U0P21ZH4302HX7P<0PJV1``2`h>H10?ooo`00`@2`h>H2086YP@<06ahG0P21ZH40
0`0V:Al0PJV1086YP@03086YP@h0@DHc00<0PJV104YB>P1:DSX0301:DSX00`21ZH40CUPn04iH?P0?
04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`03
0456<`P0PJV10P0V:1h4086YPL40/>3V0@3oool00;l0/>3V0P21ZH4301/N5`D0PJV10`0b=2L00`21
ZH40@DHc0456<`0<0456<`03086YP@1:DSX0BU8j00d0BU8j00<0PJV104iH?P1>F3h03`1>F3h00`21
ZH40CUPn04iH?P0@04iH?P03086YP@1:DS/0BU8k00/0BU8k00<0PJV10456<`11AS<02P11AS<4086Y
P@0302HX7P21ZH40PJV10080PJV1_`2`h>H10?ooo`00_@2`h>H2086YP@806ahG1021ZH46038d9`03
086YP@11AS<0@DHc00`0@DHc00<0PJV104YB>P1:DSX03P1:DSX00`21ZH40CUPn04iH?P0?04iH?P03
086YP@1>F3h0CUPn0100CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`0:0456<`03
086YP@0b=2L0<S@W00L0PJV1_@2`h>H10?ooo`00^`2`h>H6086YP@0302DX7P21ZH40<S@W00L0<S@W
00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0=04YB>P03086YP@1>F3h0CUPn0140CUPn
00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0<04YB>`03086YP@11AS<0@DHc00X0@DHc
00<0PJV1038d9`0b=2L00`0b=2L5086YPK/0/>3V0@3oool00;X0/>3V0`21ZH4402DX7P03086YP@0b
=2L0<S@W00H0<S@W00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0>04YB>P03086YP@1>
F3h0CUPn0140CUPn00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0=04YB>`03086YP@11
AS<0@DHc00X0@DHc00<0PJV1038d9`0b=2L0100b=2L5086YPKT0/>3V0@3oool00;P0/>3V0P21ZH45
02DX7P80PJV1200b=2L00`21ZH40@DHc0456<`0=0456<`03086YP@1:DSX0BU8j00h0BU8j00<0PJV1
04iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A04iH?P03086YP@1:DS/0BU8k00`0BU8k00<0PJV1
0456<`11AS<02`11AS<00`21ZH40<S@W038d9`04038d9`04086YP@0T9ah092LN02@W7P80PJV1]`2`
h>H10?ooo`00]P2`h>H3086YP@D09BPN00<0PJV1038d9`0b=2L01`0b=2L00`21ZH40@DHc0456<`0=
0456<`03086YP@1:DSX0BU8j00l0BU8j00<0PJV104iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A
04iH?P03086YP@1:DS/0BU8k00d0BU8k00<0PJV10456<`11AS<02P11AS<00`21ZH40<S@W038d9`05
038d9`80PJV10`0T9ah00`21ZH40/>3V0;3PiP2d0;3PiP40oooo002e0;3PiP<0PJV11@0U:1h00`21
ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc00d0@DHc00<0PJV104YB>P1:DSX03`1:DSX00`21
ZH40CUPn04iH?P0B04iH?P03086YP@1>F3h0CUPn0180CUPn00<0PJV104YB>`1:DS/03@1:DS/00`21
ZH40@DHc0456<`0:0456<`03086YP@0b=2L0<S@W00H0<S@W00D0PJV102@W7P0T9ah092LN086YP@2e
0;3PiP40oooo002c0;3PiP<0PJV11P0U:1h00`21ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc
00h0@DHc00<0PJV104YB>P1:DSX01P1:DSXh086YP@`0BU8k00<0PJV10456<`11AS<02P11AS<00`21
ZH40<S@W038d9`06038d9`04086YP@0T9ah092LN02@W7P80PJV1/`2`h>H10?ooo`00/P2`h>H00`21
ZH4051PB086YP@0602DX7P03086YP@0b=2L0<S@W00P0<S@W00<0PJV10456<`11AS<02@11AS<>086Y
P@T0HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00B065cD003086YP@1KJdX0Ff]:
0080Ff]:2@21ZH4304YB>`03086YP@11AS<0@DHc00/0@DHc00<0PJV1038d9`0b=2L01P0b=2L00`21
ZH4092LN02@W7P0202@W7P03086YP@2`h>H0/>3V0;00/>3V0@3oool00;40/>3V00<0PJV101@H4P21
ZH401@0U:1h2086YP@X0<S@W00@0PJV10456<`11AS<0@DHc2@21ZH4405YZCP03086YP@1RM5@0HWAD
0100HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:
00X0Ff]:2021ZH4:0456<`03086YP@0b=2L0<S@W00H0<S@W00<0PJV102@W7P0T9ah00P0T9ah00`21
ZH40/>3V0;3PiP2_0;3PiP40oooo002_0;3PiP04086YP@0D618051PB086YP@D09BPN00<0PJV1038d
9`0b=2L01P0b=2L8086YP@`0FVY>00<0PJV1069dE01RM5@04@1RM5@00`21ZH40I7MD06AgE00B06Ag
E003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX03`1KJdX00`21ZH40Df1305=P@`08086Y
P@<0@DHc00<0PJV1038d9`0b=2L01P0b=2L2086YP@<092LN00<0PJV10;3PiP2`h>H0[P2`h>H10?oo
o`00[P2`h>H01021ZH4051PB01@H4P21ZH4502DX7P03086YP@0b=2L0<S@W00L0PJV10P1;ET400`21
ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0100HWAD00<0PJV106AgE01TMe@04`1TMe@00`21
ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:00l0Ff]:00<0PJV105=P@`1CH4<0201CH4<7086Y
P@L0<S@W00D0PJV102@W7P0T9ah092LN086YP@2_0;3PiP40oooo002]0;3PiP04086YP@0D6180PJV1
086YP@@09BPN1@21ZH4904]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1069dE01RM5@04@1RM5@0
0`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX0401KJdX0
0`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0PJV100D0PJV10P0b=2L01@21ZH4092LN02@W7P0T
9ah0PJV10:h0/>3V0@3oool00:/0/>3V00@0PJV101@H4P0D6180PJV10`0U:1h4086YP@`0BeI100<0
PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD069dE00A069dE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0?05][BP03086YP@1CH4<0Df1300`0Df1300<0
PJV104A<=P14C3H01@14C3H5086YP@8092LN0P21ZH6/0;3PiP40oooo002Z0;3PiP03086YP@0D6180
51PB00D0PJV10P0b=R/00`21ZH40BeI104]F@@0;04]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1
069dE01RM5@04P1RM5@00`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV1
05][BP1KJdX0401KJdX00`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0A4`f00P0A4`f0`21ZH42
02@W7P03086YP@2`h>H0/>3V0:T0/>3V0@3oool00:T0/>3V0P0D6183086YP@H0<SH[00<0PJV104]F
@@1;ET402P1;ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0180HWAD00<0PJV106Ag
E01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:0100Ff]:00<0PJV105=P
@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0PJV100<0PJV1ZP2`h>H10?oo
o`00Y`2`h>H5086YP@L0<SH[00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0?05YZCP03
086YP@1RM5@0HWAD0180HWAD00<0PJV106AgE01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003
086YP@1KJdX0Ff]:0140Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0704A<=P03
086YP@0];b@0;BlT0080;BlT0P21ZH6Y0;3PiP40oooo002V0;3PiP80PJV10P0K7aL00`21ZH40<SH[
038f:`05038f:`03086YP@1;ET40BeI100/0BeI100<0PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD
069dE00C069dE003086YP@1TMe@0I7MD01@0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:
05][BP0A05][BP03086YP@1CH4<0Df1300`0Df1300<0PJV104A<=P14C3H02014C3H00`21ZH40;BlT
02d_900302d_9080PJV1Y`2`h>H10?ooo`00Y@2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[
00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0@05YZCP03086YP@1RM5@0HWAD0180HWAD
00<0PJV106AgE01TMe@05@1TMe@00`21ZH40HG=@065cD00D065cD003086YP@1KJdX0Ff]:0140Ff]:
00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00<0;BlT
0P21ZH6V0;3PiP40oooo002T0;3PiP03086YP@0K7aL06alG00806alG00<0PJV1038f:`0b=R/0100b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00l0FVY>00<0PJV1069dE01RM5@04`1R
M5@00`21ZH40I7MD06AgE00E06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV105][BP1KJdX04P1K
JdX00`21ZH40Df1305=P@`0=05=P@`03086YP@14C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0]
;b@2086YPJD0/>3V0@3oool00:@0/>3V00D0PJV101/O5`0K7aL06alG086YP@07038f:`03086YP@1;
ET40BeI100/0BeI100<0PJV105YZCP1JJTh0401JJTh00`21ZH40HWAD069dE00C069dE003086YP@1T
Me@0I7MD01D0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0B05][BP03086YP@1C
H4<0Df1300d0Df1300<0PJV104A<=P14C3H02@14C3H00`21ZH40;BlT02d_900302d_9080PJV1Y02`
h>H10?ooo`00X`2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[00<0PJV104]F@@1;ET40301;
ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD00T0HWAD;`21ZH4<065cD003086YP@1K
JdX0Ff]:0180Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0]
;b@0;BlT00@0;BlT0P21ZH6S0;3PiP40oooo002R0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00`0FVY>4021ZH4;07F?J003086YP@1g
TFP0Mi5X01D0Mi5X00<0PJV107B=I01dSF@02@1dSF@G086YP@X0Ff]:00<0PJV105=P@`1CH4<03P1C
H4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00@0;BlT0P21ZH6R0;3PiP40oooo002Q
0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b=R/00`21ZH40BeI104]F@@0=04]F@@03086YP@1J
JTh0FVY>0080FVY>2P21ZH4406j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05@1g
TFP00`21ZH40M8eT07B=I00E07B=I003086YP@1/Pe/0K8=K00P0K8=K4021ZH4<05=P@`03086YP@14
C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2Q0;3PiP40oooo002P
0;3PiP05086YP@0K7aL06alG01/O5`21ZH40200b=R/00`21ZH40BeI104]F@@0804]F@@X0PJV13@1^
QV<00`21ZH40MHmX07F?J00D07F?J003086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05@1d
SF@00`21ZH40K8=K06b3F`0C06b3F`03086YP@1QM4l0HGA?0080HGA?2@21ZH4305=P@`03086YP@14
C3H0A4`f00T0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2P0;3PiP40oooo002P
0;3PiP04086YP@0K7aL06alG086YP@P0<SH[00@0PJV104]F@@1;ET40BeI12021ZH44065dF003086Y
P@1^QV<0KXIS0100KXIS00<0PJV107F?J01eSfP0501eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01H0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0:065dC`L0PJV1
2@14C3H00`21ZH40;BlT02d_900302d_9003086YP@0I7AH0PJV109l0/>3V0@3oool009l0/>3V00D0
PJV101/O5`0K7aL06alG086YP@06038f:`H0PJV12`1QM5P00`21ZH40KXIS06j6H`0A06j6H`03086Y
P@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086Y
P@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df93086YP@03086YP@D0A4`f
00<0PJV102d_900];b@0100];b@2086YPIl0/>3V0@3oool009h0/>3V00D0PJV101/O5`0K7aL06alG
086YP@03038f:`D0PJV1401QM5P00`21ZH40KXIS06j6H`0A06j6H`03086YP@1eSfP0MHmX01@0MHmX
00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0K8=K01<0K8=K
00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df9305=R@`0305=R@`D0PJV100<0A4`f086YP@0];b@0
1@0];b@2086YPIh0/>3V0@3oool009d0/>3V00@0PJV101/O5`0K7aL06alG1@21ZH4404UE@`03086Y
P@1QM5P0HGAH00d0HGAH00<0PJV106j6H`1^QV<04@1^QV<00`21ZH40MHmX07F?J00E07F?J003086Y
P@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05P1dSF@00`21ZH40K8=K06b3F`0D06b3F`03086Y
P@1QM4l0HGA?00l0HGA?00<0PJV105=R@`1CHT<01`1CHT<5086YP@@0;BlT0P21ZH6M0;3PiP40oooo
002L0;3PiP04086YP@0K7aL06alG01/O5`80PJV11`19ED<00`21ZH40HGAH065dF00>065dF003086Y
P@1^QV<0KXIS0140KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01L0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0?065dC`03086Y
P@1CHT<0Df9300X0Df9300<0PJV103]3<021ZH400`21ZH400`0];b@0PJV1086YP@2L0;3PiP40oooo
002L0;3PiP04086YP@0K7aL0PJV1086YP@T0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS
06j6H`0B06j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05`1gTFP00`21ZH40M8eT
07B=I00G07B=I003086YP@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df93
05=R@`0905=R@`03086YP@0k@c00>d<`00<0>d<`1021ZH6K0;3PiP40oooo002K0;3PiP<0PJV100<0
:2hV086YP@19ED<01`19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0140KXIS00<0
PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01H0M8eT00<0
PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0?065dC`03086YP@1CHT<0Df9300X0Df9300<0
PJV103]3<00k@c001@0k@c02086YPIX0/>3V0@3oool009X0/>3V0P21ZH4202P^9P03086YP@19ED<0
BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0B06j6H`03086YP@1eSfP0
MHmX01D0MHmX00<0PJV107NAJ01gTFP0601gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0
K8=K01@0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df9305=R@`0905=R@`03086YP@0k@c00
>d<`00D0>d<`0`21ZH6I0;3PiP40oooo002I0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE
@`19ED<01P19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c001@0k@c000`21ZH407b8J086YP@2H0;3PiP40oooo002I0;3PiP05086YP@0X;RH0:2hV02P^
9P21ZH402@19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c00100k@c001021ZH407b8J01lR6P21ZH6G0;3PiP40oooo002H0;3PiP05086YP@0X;RH0:2hV
02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV1
07F?J01eSfP05P1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV1
06b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV1
03]3<00k@c001@0k@c000`21ZH407b8J086YP@2G0;3PiP40oooo002G0;3PiP03086YP@0X;RH0:2hV
0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01L0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002G0;3PiP05
086YP@0X;RH0:2hV02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002F0;3PiP03
086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003
086YP@1^QV<0KXIS01@0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003
086YP@1dSF@0M8eT01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03
086YP@1CHT<0Df9300X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2E0;3PiP40
oooo002E0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH
065dF00>065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?J01eSfP02P1eSfQ9086YPA40K8=K
00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086YP@0k@c00>d<`00D0>d<`
00@0PJV101lR6P0O8QX0PJV1U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^9P0302P^9P03086Y
P@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0906j6HaP0PJV1
3023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0PJV107^HJ`1kV6/0
0`1kV6/<086YP@H0K8=K00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086Y
P@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^
9P0202P^9P03086YP@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P02P1QM5P@086YP@/0OIad00<0
PJV108>SN023XgP05P23XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0
PJV107^HJ`1kV6/03`1kV6/A086YP@T0HGA?00<0PJV105=R@`1CHT<02`1CHT<00`21ZH40>d<`03]3
<00403]3<004086YP@0O8QX07b8J086YPI<0/>3V0@3oool009<0/>3V00<0PJV102P^9P0X;RH00P0X
;RH00`21ZH40BEE304UE@`0804UE@`04086YP@1QM5P0HGAH065dF0T0PJV1101bSF/00`21ZH40OIad
07fLM00D07fLM003086YP@23XgP0Pj=h01H0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c
086QL`0H086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d0201^R5d=086YP@X0Df93
00<0PJV103]3<00k@c001@0k@c001021ZH407b8J01lR6P21ZH6B0;3PiP40oooo002B0;3PiP03086Y
P@0X;RH0:2hV00<0:2hV00<0PJV104UE@`19ED<01P19ED<6086YP@`0LXe[00<0PJV107fLM01mW7@0
501mW7@00`21ZH40Pj=h08>SN00G08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<0
6@21XG<00`21ZH40NiQ[07^HJ`0D07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0
1@21ZH4605=R@`03086YP@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40TP2`h>H10?ooo`00TP2`
h>H00`21ZH40:2hV02P^9P0202P^9P03086YP@19ED<0BEE300<0BEE31021ZH400`1LL5P0PJV107:=
J`0?07:=J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BT
M`0I08BTM`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8
G@0B06j8G@03086YP@1NLTd0GW9=00@0GW9=1@21ZH400`1CHT<0PJV103]3<00603]3<004086YP@0O
8QX07b8J086YPI40/>3V0@3oool00940/>3V00<0PJV102P^9P0X;RH00`0X;RH00`21ZH40BEE3086Y
P@03086YP@@0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23
XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I086QL`03086YP@1k
V6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0905ibC@D0PJV11@0k
@c000`21ZH407b8J086YP@2A0;3PiP40oooo002@0;3PiP03086YP@0X;RH0:2hV0080:2hV1021ZH48
05a`F003086YP@1bSF/0LXe[00h0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00G
08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21XG<00`21ZH40NiQ[07^HJ`0E
07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21ZH40AeDj04ME>P04
086YP@0503]3<021ZH407b8J01lR6P21ZH40T02`h>H10?ooo`00T02`h>H00`0X;RH0PJV1086YP@02
086YP@0303M0=`21ZH40G71H00T0G71H00<0PJV107:=J`1bSF/03P1bSF/00`21ZH40OIad07fLM00E
07fLM003086YP@23XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I
086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0<
05ibC@03086YP@17ECX0AeDj00<0AeDj0`21ZH4201lR6P03086YP@2`h>H0/>3V08d0/>3V0@3oool0
08l0/>3V0P21ZH4403M0=`03086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21
ZH40OIad07fLM00D07fLM003086YP@23XgP0Pj=h01P0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21
ZH40PJ5c086QL`0I086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21
ZH40GW9=05ibC@0;05ibC@03086YP@17ECX0AeDj00D0AeDj1021ZH6?0;3PiP40oooo002?0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03
086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM086YP@21ZH6>0;3P
iP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40
LXe[07:=J`0>07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40
KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH40
92LM02@W7@0T9af>0;3PiP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05@1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03086YP@0g@3L0=d0g00<0
=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0
OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0
PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0
GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BTM`03
086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM02@W7@21ZH6<0;3P
iP40oooo002<0;3PiP03086YP@0g@3L0=d0g00@0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40
LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40
KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH40
92LM02@W7@21ZH6<0;3PiP40oooo002<0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05P1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17
ECX01@17ECX01@21ZH4092LM02@W7@0T9ad0PJV108/0/>3V0@3oool008/0/>3V00<0PJV103M0=`0g
@3L0100g@3L00`21ZH40G71H05a`F00805a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01m
W7@05P1mW7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21
XG<06P21XG<00`21ZH40NiQ[07^HJ`0G07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1N
LTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPH/0/>3V0@3oool008/0
/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00l0
LXe[00<0PJV107fLM01mW7@05P1mW7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0
Q:Ag00<0PJV1086QL`21XG<06`21XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0180
KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P05086YP@0T9ad092LM02@W
7@21ZH40RP2`h>H10?ooo`00R`2`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0
G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00E07fLM003086YP@23XgP0Pj=h01T0
Pj=h00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PJ5c086QL`0K086QL`03086YP@1kV6/0NiQ[01H0
NiQ[00<0PJV106j8G@1^R5d04`1^R5d00`21ZH40GW9=05ibC@0<05ibC@03086YP@17ECX0AeDj00H0
AeDj00@0PJV102@W7@0T9ad0PJV1RP2`h>H10?ooo`00RP2`h>H00`21ZH40=d0g03M0=`0403M0=`03
086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/0401bSF/00`21ZH40OIad07fLM00E07fLM003
086YP@23XgP0Pj=h01T0Pj=h00<0PJV108BTM`24Y7L03024Y7LM086YP@l0PJ5c00<0PJV107^HJ`1k
V6/05P1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6:0;3PiP40oooo00270;3PiP80ogl000<0/>3V086YP@0g
@3L0100g@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01m
W7@02P1mW7@g086YP@h0S[>300<0PJV108b`OP2</7h0302</7hL086YP@d0NiQ[00<0PJV106j8G@1^
R5d04P1^R5d00`21ZH40GW9=05ibC@0=05ibC@03086YP@17ECX0AeDj00D0AeDj00D0PJV102@W7@0T
9ad092LM086YP@290;3PiP40oooo00260;3PiP<0ogl000<0PJV103M0=`0g@3L0100g@3L00`21ZH40
G71H05a`F00905a`F003086YP@1bSF/0LXe[00/0LXe[4@21ZH4<08V]P@03086YP@2>/h@0S[>401T0
S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg00X0
QZQg6021ZH4;06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH40
92LM02@W7@21ZH690;3PiP40oooo00260;3PiP<0ogl000<0PJV103M0=`0g@3L00`0g@3L00`21ZH40
G71H05a`F00905a`F003086YP@1bSF/0LXe[0080LXe[2P21ZH4407nPNP03086YP@29[H40RJf101H0
RJf100<0PJV108jcQ02>/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0
S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0807^JJ`l0PJV12`1NLTd00`21ZH40
AeDj04ME>P0604ME>P05086YP@0T9ad092LM02@W7@21ZH40R02`h>H10?ooo`00Q@2`h>H40?mo00H0
=d0g00<0PJV105a`F01LL5P01P1LL5P8086YP@h0Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40
S[>408jcQ00I08jcQ003086YP@2>/h<0S[>301X0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40
QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01<0NiY[00@0PJV106N1EP1WPEH0Ih5F2021ZH4405ib
C@03086YP@17ECX0AeDj00H0AeDj00@0PJV102@W7@0T9ad0PJV1R02`h>H10?ooo`00Q@2`h>H30?mo
0003086YP@0g@3L0=d0g00<0=d0g00@0PJV105a`F01LL5P0G71H1P21ZH4306^6J@03086YP@1oX7X0
Oj1j0100Oj1j00<0PJV108V]P@29[H405@29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0
S[>301X0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0
NiY[01<0NiY[00<0PJV106N1EP1WPEH02@1WPEH7086YP@H0AeDj00D0PJV102@W7@0T9ad092LM086Y
P@270;3PiP40oooo00250;3PiP80ogl000@0PJV103M0=`0g@3L0=d0g1`21ZH4906^6J@03086YP@1o
X7X0Oj1j00l0Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>
/h<0S[>301X0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1k
VV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH0301WPEH00`21ZH40DF=3055S@`05086YP@80AeDj00@0
PJV102@W7@0T9ad0PJV1Q`2`h>H10?ooo`00Q@2`h>H20?mo00@0PJV10`17F4T00`21ZH40JhIY06^6
J@0906^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jc
Q00J08jcQ003086YP@2>/h<0S[>301X0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JX
M`0G08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH0301WPEH00`21ZH40DF=3055S
@`05055S@`@0PJV10P0T9ad00`21ZH40/>3V0;3PiP240;3PiP40oooo00240;3PiP@0ogl01P17F4T0
0`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H40
0`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301X0S[>300<0PJV108b`OP2</7h0702</7h0
0`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH03@1WPEH0
0`21ZH40DF=3055S@`06055S@`03086YP@0]=BD0PJV10080PJV1QP2`h>H10?ooo`00Q02`h>H30?mo
0003086YP@17F4T0AeQ900<0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0J08jc
P`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021ZH40;CDU02de9@0]=BF6
0;3PiP40oooo00230;3PiP@0ogl01P17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j
0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>3
01X0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[
01<0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU
02de9@21ZH40Q@2`h>H10?ooo`00P`2`h>H40?mo00H0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21
ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21
ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21
ZH40;CDU02de9@0]=BD0PJV108D0/>3V0@3oool008<0/>3V0`3oO`000`21ZH40AeQ904MHB@0404MH
B@03086YP@1[QVT0JhIY00T0JhIY00<0PJV107nPNP1oX7X04@1oX7X00`21ZH40RJf108V]P@0F08V]
P@03086YP@2>/h@0S[>401T0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`
OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1
EP03086YP@1AHd<0DF=300H0DF=300D0PJV102de9@0]=BD0;CDU086YP@250;3PiP40oooo00220;3P
iP@0ogl000<0PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0906^6J@03086YP@1oX7X0Oj1j
0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>3
01`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[
01@0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S@`04086YP@0]=BD0;CDU
086YPHD0/>3V0@3oool00880/>3V103oO`000`21ZH40AeQ904MHB@0304MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg
01P0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@240;3PiP40oooo00220;3PiP@0ogl01P17F4T00`21
ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21
ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h06`2</7h00`21
ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21
ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU02de9@21ZH40Q02`h>H10?ooo`00P@2`h>H40?mo
0003086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0L08jc
P`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S@`1AHd<01P1AHd<01@21ZH40;CDU02de9@0]=BD0
PJV108@0/>3V0@3oool00840/>3V103oO`000`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg
01P0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300@0PJV102de9@0]=BD0PJV1Q02`h>H10?ooo`00P`2`h>H20?mo0003086YP@17F4T0AeQ9
00@0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21ZH40Oj1j07nPNP0A07nPNP03086YP@29[H40RJf1
01H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n
01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F
00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108<0/>3V0@3oool0
0880/>3V0`3oO`000`21ZH40AeQ904MHB@0304MHB@03086YP@1[QVT0JhIY00X0JhIY00<0PJV107nP
NP1oX7X04@1oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jc
P`2>/h<0702>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^J
J`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300L0DF=300D0PJV102de
9@0]=BD0;CDU086YP@230;3PiP40oooo00220;3PiP80ogl000<0PJV104MHB@17F4T01017F4T00`21
ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405P29[H400`21
ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h0702</7h00`21
ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21
ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU02de9@21ZH40P`2`h>H10?ooo`00PP2`h>H20?mo
0003086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>308jcP`0L08jc
P`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021ZH40;CDU02de9@21ZH63
0;3PiP40oooo00210;3PiP<0ogl000<0PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6
J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00K08jc
Q003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0H08JX
M`03086YP@1kVV/0NiY[01<0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`07055S
@`05086YP@0]=BD0;CDU02de9@21ZH40PP2`h>H10?ooo`00PP2`h>H00`3oO`00PJV1086YP@0604MH
B@03086YP@1[QVT0JhIY00T0JhIY00<0PJV107nPNP1oX7X04@1oX7X00`21ZH40RJf108V]P@0F08V]
P@03086YP@2>/h@0S[>400d0S[>4FP21ZH4=08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1
EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU02de9@21ZH40PP2`h>H1
0?ooo`00P`2`h>H00`0M9R<0PJV104MHB@0404MHB@03086YP@1[QVT0JhIY00X0JhIY00<0PJV107nP
NP1oX7X0201oX7Xb086YP@h0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09Bm
R003086YP@2>]H40S[F100/0S[F16@21ZH4;07^JJ`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S
@`1AHd<01P1AHd<01@21ZH40;CDU02de9@0]=BD0PJV10880/>3V0@3oool008<0/>3V00<0PJV104MH
B@17F4T01017F4T00`21ZH40JhIY06^6J@0406^6JA40PJV12@29[hH00`21ZH40T[^<09:kS00F09:k
S003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09Bm
R003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H02@24Z7HQ086YP@D0DF=300@0PJV102de
9@0]=BD0PJV1PP2`h>H10?ooo`00PP2`h>H2086YP@<0AeQ92P21ZH4607NHM`03086YP@29[hH0RJn6
0140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<
01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf
01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0205M^B@L0PJV10P0]=BD00`21
ZH40/>3V0;3PiP1o0;3PiP40oooo00220;3PiPD0PJV10`1DJeT00`21ZH40MiQg07NHM`0:07NHM`03
086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03
086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03
086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@03
086YP@0c@B`0PJV10080PJV1P@2`h>H10?ooo`00PP2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L0
2P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840/>3V0@3oool00880/>3V0P21ZH4605A[F@03086Y
P@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086Y
P@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086Y
P@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086Y
P@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00220;3PiP80PJV1
1P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00
PP2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00L09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840
/>3V0@3oool00880/>3V00<0PJV105A[F@1DJeT0101DJeT00`21ZH40MiQg07NHM`0;07NHM`03086Y
P@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086Y
P@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086Y
P@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086Y
P@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L0
2`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
602>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840/>3V0@3oool00840/>3V0P21ZH4605A[F@03086Y
P@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086Y
P@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086Y
P@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086Y
P@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00210;3PiP80PJV1
1P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0J09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00
P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0C08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10840
/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0
7@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900@0PJV103=1;00c@B`0
PJV1P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10800/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg
00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>
00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F1
00<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi9
00D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P@2`h>H00`0T;bd0PJV1
05A[F@0505A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<
09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f8
09BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R
07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40
oooo00210;3PiP03086YP@1DJeT0E6]I00@0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10800/>3V0@3oool00800/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg
00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>
00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F1
00<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi9
00D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40oooo00200;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0E6]I
00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<
00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f8
00<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R
00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00800/>3V
0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<
09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f8
09BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R
07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@200;3PiP40
oooo00200;3Pi_<0PJV1P02`h>H10?ooo`00P02`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20
YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2M
bYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E
`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1L
N4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V0@3oool00800/>3V0P21ZH4605ikI@03086YP@20
YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2M
bYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E
`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1L
N4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00200;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P02`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V
0@3oool00840/>3V00<0PJV105ikI@1NNfD0101NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20
YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2M
bYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E
`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1L
N4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20
YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2M
bYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E
`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1L
N4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10800/>3V
0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00@0PJV103Q9<@0hBC40PJV1
P@2`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bd
O`0C08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9
<@0hBC40PJV10840/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01X0WLZF00<0
PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0
PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0
PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0
PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0
PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00880/>3V00<0
PJV105ikI@1NNfD0101NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P@2`h>H10?ooo`00PP2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bd
O`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9
<@0hBC40PJV10840/>3V0@3oool00880/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0
PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H2086YP@H0GW]U00<0
PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0
PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0
PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0
PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V0@3oool00880/>3V1@21
ZH4305ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6
U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7
T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^N
K@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00<0PJV103Q9<@0hBC400P21ZH610;3PiP40oooo0022
0;3PiP80PJV10`1UQfh:086YP@H0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F
09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L
09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@06
07^NKAD0PJV100<0>dlc086YP@2`h>H0P02`h>H10?ooo`00P`2`h>H00`21ZH40IHM^06F7KP0406F7
KP03086YP@26/8X0Q[2:00@0Q[2:4021ZH4:096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:
UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0
RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0908bdOa@0PJV12021Z7D00`21ZH40Hh=H06>3F00706>3
F004086YP@0kCc<0>dlc03]?<h80/>3V0@3oool008<0/>3V0P21ZH4506F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL01`2GaYLb086YP@l0WLZF00<0PJV109g:U02MbY@0702MbY@00`21
ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:00/0UL2:6@21ZH4;096mQ`03086YP@21Z7D0PJQe
00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV10880/>3V0@3oool0
08<0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6U`2GaYL04@2GaYL00`21
ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M00`0X]>MF`21ZH4=09_9T@03086YP@2A_HL0TKf7
01@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc
03]?<`21ZH40PP2`h>H10?ooo`00P`2`h>H2086YP@H0IHM^00<0PJV108J`RP26/8X02P26/8X00`21
ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06`2Rdid00`21
ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI40602KbI400`21
ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01`1SPeP01@21
ZH40>dlc03]?<`0kCc<0PJV10880/>3V0@3oool008<0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01/0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA
01P0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0>086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00@0PJV103]?<`0kCc<0PJV1P`2`h>H10?ooo`00Q02`h>H00`21ZH40IHM^06F7KP0406F7
KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL04@2GaYL00`21ZH40WlnL09o?W00F09o?
W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@
U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0>086X
M@03086YP@1SPeP0Hh=H00H0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@230;3PiP40oooo00240;3P
iP80PJV11@1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?
W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@
U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086X
M@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40P`2`h>H1
0?ooo`00Q02`h>H2086YP@H0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0A09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096m
Q`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0
PJV108<0/>3V0@3oool008@0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6
U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;C
V`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01P0VlVA00<0PJV1096m
Q`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?
<`0kCc<0PJV1Q02`h>H10?ooo`00Q@2`h>H00`21ZH40IHM^06F7KP0406F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA
01P0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0>086XM@03086YP@1SPeP0Hh=H
00H0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@240;3PiP40oooo00250;3PiP03086YP@1UQfh0IHM^
00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe
00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108@0/>3V0@3oool0
08D0/>3V0P21ZH4506F7KP03086YP@26/8X0Q[2:00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21
ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21
ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01P0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21
ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@24
0;3PiP40oooo00250;3PiP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG
0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K
01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf7
01@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F004086YP@0kCc<0>dlc
086YPHD0/>3V0@3oool008D0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6
U`2GaYL04@2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01T0X]>M00<0PJV10:;C
V`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096m
Q`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00H0Hh=H00D0PJV103]?
<`0kCc<0>dlc086YP@250;3PiP40oooo00260;3PiP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`
RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9
T@2KbI405`2KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3
F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108D0/>3V0@3oool008H0/>3V00<0PJV106F7
KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?
W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@
U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086X
M@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40Q@2`h>H1
0?ooo`00QP2`h>H2086YP@D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0J0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH42
000008@0/>3V0@3oool008H0/>3V0P21ZH4606F7KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6
U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;C
V`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096m
Q`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H00H0Hh=H00<0000003]?
<`0kCc<0100000240;3PiP40oooo00270;3PiP@0PJV10`1UQfh00`21ZH40Q[2:08J`RP0908J`RP03
086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03
086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03
086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03021Z7D00`21ZH40Hh=H06>3F00306>3F003
0000001SPeP0PJV100L00000Q@2`h>H10?ooo`00Q`2`h>H01021ZH40J8id06R>M01XSW@7086YP@T0
Q[2:00<0PJV109O6U`2GaYL03`2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0
X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01P0
VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0;086XM@0400000021ZH40Hh=H06>3
F080PJV10`000000101WRel000000000000kDS@4000008D0/>3V0@3oool008P0/>3V00<0PJV106R>
M01XSW@00`1XSW@01021ZH40RKN@08VgT029]i06086YP@<0Q[2:00<0PJV109O6U`2GaYL0402GaYL0
0`21ZH40WlnL09o?W00E09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/0
0`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL0
1021ZH40PJQe086XM@000002086XM@0300000021Z7D0PJQe00@0PJQe00@0PJV10000000000000000
0P21ZH4206N;G`8000000P1WRel6000008H0/>3V0@3oool008P0/>3V00<0PJV106R>M01XSW@0101X
SW@00`21ZH40RKN@08VgT00608VgT0P0PJV13P2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2R
did0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2K
bI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe00000006000000@0PJV100@0
QK1l000000000000PJV1101WRel20000000306N;G`000000000000D00000QP2`h>H10?ooo`00R@2`
h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00T0RKN@00<0PJV109_=W@2KcId00P2K
cId:086YP@@0UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0I0:;CW@03086YP@2R
di/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0G09_9T@030000002A
_HL0TKf70080TKf700<00000096mQ`2A_HL0102A_HL;086YP@T000001025/7`2000000@0Ih]O0`00
0000101WRel000000000000kDS@4000008H0/>3V0@3oool008T0/>3V00<0PJV106R>M01XSW@0101X
SW@00`21ZH40RKN@08VgT00908VgT003086YP@2KcId0VlfM00/0VlfM4@21ZH4<09o?W003086YP@2R
did0X]>M01T0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`05086YP@2K
bI40VlVA09_9T@0000002@2KbI4<086YP@0400000021ZH40PJV1086YP@<000001@21ZH4909G4S@@0
00001@25/7`2000000<0QK1l0`00000406N;G`8000000P1WRel6000008L0/>3V0@3oool008X0/>3V
00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08VgT00908VgT003086YP@2KcId0VlfM00l0VlfM
00<0PJV10:?FXP2SeZ802P2SeZ8g086YP@h0X]>K00<0PJV10:3@U`2Pd9L03@2Pd9LA086YP@<00000
2021ZH4;09k@U`8000000`2Ea8d2000000h0ULB=1000000708F`O00400000025/7`0QK1l08F`O080
000000@0PJV106N;G`1WRel0Ih]O0`0000000`1WRel0000000000005000008L0/>3V0@3oool008X0
/>3V00<0PJV106R>M01XSW@0101XSW@00`21ZH40RKN@08VgT00808VgT003086YP@2KcId0VlfM0100
VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJX`0I0:KJX`03086YP@2VfZ40Y]ZQ00`0
Y]ZQ7P21ZH4>0:CGW@04086YP@2Nd9L0W]2G09k@U`8000004P2Nd9L2000000@0ULB=0P00000=09G4
S@<000002@25/7`010000000QK1l08F`O025/7`2000000@0Ih]O0P00000206N;G`H00000R02`h>H1
0?ooo`00R`2`h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00T0RKN@00<0PJV109_=
W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01T0Y]ZS00<0PJV10:KJ
X@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0K0:CGW@04086YP@2Nd9L0W]2G09k@U`8000004P2Nd9L0
0`000000PJV109G4S@0309G4S@8000003@2Ea8d200000003086YP@25/7`0QK1l00/0QK1l0P000004
06N;G`8000000P1WRel00`000000>e8d00000003000008P0/>3V0@3oool008/0/>3V00<0PJV106R>
M01XSW@00`1XSW@00`21ZH40RKN@08VgT00908VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?F
XP2SeZ805P2SeZ800`21ZH40Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CG
W@2Teid06`2Teid01021ZH40W]2G09k@U`2Nd9L300000100W]2G0P0000001021ZH40ULB=09G4S@2E
a8d3000000d0ULB=00<00000086YP@25/7`03025/7`3000000<0Ih]O0`000000101WRel000000000
000kDS@4000008P0/>3V0@3oool008/0/>3V00<0PJV106R>M01XSW@0101XSW@00`21ZH40RKN@08Vg
T00808VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805P2SeZ800`21ZH40Y]ZS0:KJ
X`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40W]2G09k@
U`0309k@U`8000003`2Nd9L20000000309k@U`21ZH40ULB=0080ULB=0P00000=09G4S@80000000<0
PJV108F`O025/7`02`25/7`2000000@0Ih]O0P00000206N;G`030000000kDS@0000000<00000R@2`
h>H10?ooo`00S02`h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00T0RKN@00<0PJV1
09_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV1
0:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G00<0W]2G0P00000>
09k@U`80000000<0W]2G086YP@2Ea8d00`2Ea8d2000000`0ULB=0P0000000`2Ea8d0PJV108F`O00<
08F`O0800000101WRel20000000406N;G`21ZH40000003]B=0@00000R@2`h>H10?ooo`00S02`h>H0
0`21ZH40J8id06R>M00406R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId0
0`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ40
0`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0W]2G00<0W]2G0P00000>09k@U`040000002Nd9L0
W]2G086YP@@0ULB=0P00000<09G4S@80000000<0ULB=086YP@25/7`02`25/7`3000000<0Ih]O0`00
00000`1WRel0000000000005000008T0/>3V0@3oool008d0/>3V00<0PJV106R>M01XSW@00`1XSW@0
0`21ZH40RKN@08VgT00808VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ805@2SeZ80
0`21ZH40Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid0
0`21ZH40W]2G09k@U`0309k@U`<00000302Nd9L200000080W]2G00@0PJV109G4S@2Ea8d0ULB=0`00
000<09G4S@80000000<0PJV108F`O025/7`02P25/7`3000000@0Ih]O0P00000206N;G`030000000k
DS@0000000<00000RP2`h>H10?ooo`00S@2`h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00
RKN@00T0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR0:?FXP0E0:?FXP03086YP@2VfZ<0
Y]ZS01L0Y]ZS00<0PJV10:KJX@2VfZ406P2VfZ400`21ZH40Y=NM0:CGW@0J0:CGW@03086YP@2Nd9L0
W]2G00@0W]2G3`00000309k@U`04086YP@2Ea8d0ULB=09G4S@8000003@2Ea8d200000003086YP@25
/7`0QK1l00H0QK1l00@0000008F`O025/7`0QK1l0`00000406N;G`80000000@0Ih]O000000000000
>e8d0`00002;0;3PiP40oooo002>0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i00
2029]i000`21ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2VfZ<0
5`2VfZ<00`21ZH40Y]ZQ0:KJX@0J0:KJX@03086YP@2Teid0Y=NM01X0Y=NM00<0PJV109k@U`2Nd9L0
102Nd9L?00000080W]2G00<0PJV109G4S@2Ea8d00P2Ea8d2000000d0ULB=0P0000000`21ZH40QK1l
08F`O00408F`O0@000000P25/7`300000080Ih]O10000000101WRel0000003]B=00kDS@2000008`0
/>3V0@3oool008h0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08VgT00908VgT003086Y
P@2KcId0VlfM00h0VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJX`0G0:KJX`03086Y
P@2VfZ40Y]ZQ01X0Y]ZQ00<0PJV10:CGW@2Teid06P2Teid00`21ZH40W]2G09k@U`0409k@U`<00000
2@2Nd9L2000000<0W]2G00<0PJV109G4S@2Ea8d00P2Ea8d2000000d0ULB=0P00000608F`O0@00000
0P25/7`90000000506N;G`21ZH40000003]B=021ZH40SP2`h>H10?ooo`00S`2`h>H00`21ZH40J8id
06R>M00306R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03`2KcId00`21ZH40XmJR
0:?FXP0D0:?FXP03086YP@2VfZ<0Y]ZS01P0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21ZH40Y=NM
0:CGW@0I0:CGW@03086YP@2Nd9L0W]2G00D0W]2G0`00000809k@U`800000102Nd9L01021ZH40ULB=
09G4S@2Ea8d4000000`0ULB=0`00000408F`O0<000001025/7`20000000306N;G`00000000000080
00000`1WRel01021ZH40>e8d03]B=021ZH6>0;3PiP40oooo002?0;3PiP80PJV1101XSW@00`21ZH40
RKN@08VgT00808VgT003086YP@2KcId0VlfM00l0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40
Y]ZS0:KJX`0H0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40
W]2G09k@U`0509k@U`<00000202Nd9L00`000000W]2G09k@U`0309k@U`04086YP@2Ea8d0ULB=09G4
S@D00000302Ea8d300000080QK1l0`00000508F`O08000000P1WRel00`000000Ih]O06N;G`0206N;
G`04086YP@0kDS@0PJV1086YPHl0/>3V0@3oool00900/>3V1@21ZH400`1XSW@0PJV108VgT00908Vg
T003086YP@2KcId0VlfM00h0VlfM00<0PJV10:?FXP2SeZ805@2SeZ800`21ZH40Y]ZS0:KJX`0G0:KJ
X`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid06@2Teid00`21ZH40W]2G09k@U`0609k@
U`8000001`2Nd9L2000000@0W]2G00<0PJV109G4S@2Ea8d00P2Ea8d20000000309G4S@0000000000
008000002@2Ea8d00`21ZH40QK1l00000005000000D0QK1l0`00000506N;G`80PJV100@00000086Y
P@0mF3X0PJV1S`2`h>H10?ooo`00T02`h>H00`21ZH40JI5g06VAM`0206VAM`<0PJV12@29]i000`21
ZH40VlfM09_=W@0>09_=W@03086YP@2SeZ80XmJR01D0XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21
ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2Nd9L01P2Nd9L30000
00H0W]2G00<0000009k@U`2Nd9L00`2Nd9L00`21ZH40ULB=09G4S@0209G4S@8000000P2Ea8d60000
00H0ULB=00<0PJV108F`O00000001000000608F`O08000000P1WRel4086YP@0506R?H`0000000000
00000021ZH40T02`h>H10?ooo`00T@2`h>H00`21ZH40JI5g06VAM`0306VAM`D0PJV11@29]i000`21
ZH40VlfM09_=W@0?09_=W@03086YP@2SeZ80XmJR01@0XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21
ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2Nd9L01`2Nd9L20000
00D0W]2G0P00000509k@U`04086YP@2Ea8d0ULB=09G4S@<000000`2Ea8d5000000H0ULB=00<0PJV1
08F`O025/7`02@25/7`300000080PJV1101XSf<400000940/>3V0@3oool00980/>3V00<0PJV106VA
M`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0208VjTP@0PJV10P29]i000`21ZH40VlfM09_=W@0>09_=
W@03086YP@2SeZ80XmJR01@0XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJ
X@03086YP@2Teid0Y=NM01T0Y=NM00<0PJV109k@U`2Nd9L01`2Nd9L2000000@0W]2G0P00000609k@
U`03086YP@2Ea8d0ULB=0080ULB=00<0000009G4S@2Ea8d03@2Ea8d00`21ZH40QK1l08F`O00408F`
O0D0PJV10P00000706R?H`<0000000<0PJV10;3PiP2`h>H0S`2`h>H10?ooo`00TP2`h>H00`21ZH40
JI5g06VAM`0306VAM`03086YP@29^Y80RKZB00D0RKZB1`21ZH4<09_=W@03086YP@2SeZ80XmJR01@0
XmJR00<0PJV10:KJX`2VfZ<05`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01T0
Y=NM00<0PJV109k@U`2Nd9L01`2Nd9L3000000<0W]2G00<0000009k@U`2Nd9L0102Nd9L00`21ZH40
ULB=09G4S@0B09G4S@03086YP@25/7`0QK1l00D0PJV11@25/gl2000000L0J8mS0P0000000`21ZH40
/>3V0;3PiP2@0;3PiP40oooo002C0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y80
2029^Y801021ZH40Vm2P09_@X02Kd:09086YP@@0VlfM00<0PJV10:?FXP2SeZ80502SeZ800`21ZH40
Y]ZS0:KJX`0F0:KJX`03086YP@2VfZ40Y]ZQ01T0Y]ZQ00<0PJV10:CGW@2Teid0602Teid00`21ZH40
W]2G09k@U`0909k@U`8000000P2Nd9L2000000H0W]2G00<0PJV109G4S@2Ea8d0202Ea8d=086YP@T0
QK=o0`00000606R?H`04086YP@0mF3X0?EPj086YPI80/>3V0@3oool009@0/>3V00<0PJV106VAM`1Y
TGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00X0Vm2P4021ZH4;0:?FXP03
086YP@2VfZ<0Y]ZS01H0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21ZH40Y=NM0:CGW@0H0:CGW@03
086YP@2Nd9L0W]2G00T0W]2G0`000000102Nd9L0000009k@U`2Nd9L@086YP@T0UlVA00<0PJV108Fc
O`25/gl02`25/gl00`000000J8mS06R?H`0406R?H`04086YP@0mF3X0?EPj086YPI<0/>3V0@3oool0
09@0/>3V00<0PJV106VAM`1YTGL00`1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P
00d0Vm2P00<0PJV10:CJYP2TfZH02@2TfZHH086YP@`0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21
ZH40Y=NM0:CGW@0H0:CGW@03086YP@2Nd9L0W]2G00@0W]2G1P21ZH4400000080PJV11@2PeI/00`21
ZH40UlVA09O9T@0A09O9T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21
ZH40?EPj086YP@2D0;3PiP40oooo002E0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29
^Y801`29^Y800`21ZH40Vm2P09_@X00>09_@X003086YP@2TfZH0Y=ZV01<0Y=ZV00<0PJV10:SNY`2X
gZL02P2XgZM:086YP@H0X=FK0`0000070:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25
/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`04086YP@0mF3X0?EPj086YPI@0/>3V0@3oool009H0
/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0
Vm2P00<0PJV10:CJYP2TfZH0502TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0
Z=jU00<0PJV10:GKX@2Ufj40602Ufj400`21ZH40X=FK0:3EV`0:0:3EV`<000001`2PeI/00`21ZH40
UlVA09O9T@0A09O9T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21ZH40
?EPj086YP@2E0;3PiP40oooo002G0;3PiP05086YP@1YTGL0JI5g06VAM`21ZH402@29^Y800`21ZH40
Vm2P09_@X00>09_@X003086YP@2TfZH0Y=ZV01<0Y=ZV00<0PJV10:SNY`2XgZL05@2XgZL00`21ZH40
Z=jU0:SNY@0I0:SNY@03086YP@2Ufj40YM^Q01P0YM^Q00<0PJV10:3EV`2PeI/02`2PeI/00`000000
X=FK0:3EV`060:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40
J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3oool009L0/>3V00<0PJV106VAM`1YTGL0
0P1YTGL00`21ZH40RKZB08VjTP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH0
4`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01T0Z=jU00<0PJV10:GKX@2Ufj40
5`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA00<0PJV108FcO`25/gl0
2P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109H0/>3V0@3oool009P0/>3V00D0
PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH0
4P2TfZH00`21ZH40Z=jW0:SNY`0F0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj40
5`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl0
2P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109L0/>3V0@3oool009T0/>3V00D0
PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH0
4`2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj40
5`2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl0
2P25/gl00`21ZH40J8mS06R?H`0406R?H`04086YP@0mF3X0?EPj086YPIL0/>3V0@3oool009T0/>3V
00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0608VjTP03086YP@2Kd:00Vm2P00h0Vm2P
00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU
00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA0100UlVA
00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109P0/>3V
0@3oool009X0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00d0Vm2P
00<0PJV10:CJYP2TfZH04P2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2XgZD0Z=jU01P0Z=jU
00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0100UlVA
00<0PJV108FcO`25/gl02@25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109T0/>3V
0@3oool009/0/>3V0P21ZH4206VAM`03086YP@29^Y80RKZB00H0RKZB00<0PJV109_@X02Kd:003P2K
d:000`21ZH40Y=ZV0:CJYP0A0:CJYP03086YP@2XgZL0Z=jW01D0Z=jW00<0PJV10:SNY@2XgZD0602X
gZD00`21ZH40YM^Q0:GKX@0F0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI403`2G
bI400`21ZH40QK=o08FcO`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS0P21ZH6J0;3PiP40oooo002L
0;3PiP@0PJV12@29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV0180Y=ZV00<0PJV1
0:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0G0:SNY@03086YP@2Ufj40YM^Q01L0YM^Q00<0PJV1
0:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0@09O9T@03086YP@25/gl0QK=o00T0QK=o00<0PJV1
06R?H`1XSf<00`1XSf<4086YPI/0/>3V0@3oool009`0/>3V00<0PJV106F?M@1USgD00`21ZH4708Vj
TP03086YP@2Kd:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0E0:SN
Y`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405`2Ufj400`21ZH40X=FK0:3EV`0C0:3E
V`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS086YP@03086Y
P@0306F>I021ZH40PJV109`0/>3V0@3oool009d0/>3V00@0PJV106F?M@1USgD0IHme1@21ZH4408Vj
TP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0E0:SN
Y`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D0:3E
V`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`25/gl01`25/gl5086YP@@0IHiT0P21ZH6M0;3P
iP40oooo002N0;3PiP05086YP@1USgD0IHme06F?M@21ZH400`25]i05086YPA00Vm2P00<0PJV10:CJ
YP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GK
X@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108Fc
O`25/gl01025/gl4086YP@0308:bP021ZH40IHiT00D0IHiT0P21ZH6N0;3PiP40oooo002O0;3PiP05
086YP@1USgD0IHme06F?M@21ZH401P25]i06086YP@/0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21
ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21
ZH40X=FK0:3EV`0C0:3EV`03086YP@2GbI40UlVA00l0UlVA00<0PJV108FcO`21ZH401021ZH4408:b
P003086YP@1USV@0IHiT00@0IHiT0P21ZH6O0;3PiP40oooo002P0;3PiP04086YP@1USgD0IHme086Y
P@P0QKN@00@0PJV109S>W`2HcYl0V<jO2021ZH4409_@X003086YP@2TfZH0Y=ZV0100Y=ZV00<0PJV1
0:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q01H0YM^Q00<0PJV1
0:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0:09O9T@L0PJV12@22/X000`21ZH40IHiT06F>I003
06F>I003086YP@0mFch0PJV109l0/>3V0@3oool00:00/>3V00D0PJV106F?M@1USgD0IHme086YP@08
08FgT003086YP@2HcYl0V<jO00P0V<jO2@21ZH4>0:CJYP03086YP@2XgZL0Z=jW01@0Z=jW00<0PJV1
0:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0E0:GKX@03086YP@2PeI/0X=FK01<0X=FK00<0PJV1
09O9T@2GbI400P2GbI49086YP@<0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40IHiT06F>I003
06F>I003086YP@0mFch0PJV10:00/>3V0@3oool00:40/>3V00D0PJV106F?M@1USgD0IHme086YP@07
08FgT003086YP@2HcYl0V<jO00d0V<jO00@0PJV10:;JYP2RfZH0X]ZV2P21ZH450:CJYP03086YP@2X
gZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05@2XgZD00`21ZH40YM^Q0:GKX@0E0:GKX@03086YP@2P
eI/0X=FK00T0X=FK3`21ZH4<09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1U
SV@00`21ZH40?E/n086YP@2Q0;3PiP40oooo002R0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25
]i000`21ZH40V<jO09S>W`0<09S>W`03086YP@2RfZH0X]ZV00/0X]ZV4@21ZH4;0:SNY`03086YP@2X
gZD0Z=jU01D0Z=jU00<0PJV10:GKX@2Ufj402P2Ufj4G086YP@T0WmJL00<0PJV109C8TP2Db9803P2D
b9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00@0IHiT0P21ZH6R0;3PiP40oooo002S
0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0<09S>W`03086YP@2R
fZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP02@2VgjP`086YP@/0YMfS00<0PJV109oFW02OeY`04P2O
eY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@0101U
SV@2086YPJ<0/>3V0@3oool00:@0/>3V00D0PJV106F?M@1USgD0IHme086YP@0708FgT003086YP@2H
cYl0V<jO00/0V<jO00<0PJV10:;JYP2RfZH0402RfZH00`21ZH40Y]nX0:KOZ00C0:KOZ003086YP@2W
h:L0Yn2W01D0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00B09oFW003086YP@2D
b980U<RB00d0U<RB00<0PJV108:bP022/X002@22/X000`21ZH40IHiT06F>I00306F>I080PJV1Y02`
h>H10?ooo`00Y02`h>H00`21ZH40IHme06F?M@0206F?M@03086YP@25]i00QKN@00@0QKN@00<0PJV1
09S>W`2HcYl0302HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0PJV1
0:OPY`2Wh:L05@2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0180WmJL00<0PJV1
09C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6U
0;3PiP40oooo002U0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0;
09S>W`03086YP@2RfZH0X]ZV0100X]ZV00<0PJV10:KOZ02VgjP04P2VgjP00`21ZH40Yn2W0:OPY`0E
0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04@2OeY`00`21ZH40U<RB09C8TP0=
09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@00`1USV@2086YPJH0/>3V0@3oool0
0:H0/>3V0P21ZH4206F?M@03086YP@25]i00QKN@00D0QKN@00<0PJV109S>W`2HcYl02`2HcYl00`21
ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX01<0Y]nX00<0PJV10:OPY`2Wh:L0502Wh:L00`21
ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0140WmJL00<0PJV109C8TP2Db980302Db9800`21
ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6W0;3PiP40oooo002W0;3PiPD0
PJV11`25]i000`21ZH40V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02V
gjP04P2VgjP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02O
eY`04@2OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000L0P[:000<0PJV106F>I01U
SV@00P1USV@2086YPJT0/>3V0@3oool00:T0/>3V00<0PJV105f6KP21ZH400P21ZH4608FgT003086Y
P@2HcYl0V<jO00X0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003086Y
P@2Wh:L0Yn2W01@0Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oFW00@09oFW003086Y
P@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I003086YPJX0/>3V
0@3oool00:X0/>3V00<0PJV105f6KP1MQVh01021ZH4308FgT003086YP@2HcYl0V<jO00/0V<jO00<0
PJV10:;JYP2RfZH03P2RfZH00`21ZH40Y]nX0:KOZ00B0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0
PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00@09oFW003086YP@2Db980U<RB00`0U<RB00<0
PJV108:bP022/X002022/X04086YP@0305j7H@21ZH40/>3V0:X0/>3V0@3oool00:/0/>3V0P21ZH40
101MQVh0PJV107^/R@1k[8T5086YP@`0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KO
Z00A0:KOZ003086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oF
W00?09oFW003086YP@2Db980U<RB00`0U<RB00<0PJV108:bP022/X001P22/X04086YP@80GXMQ0P21
ZH6/0;3PiP40oooo002]0;3PiP04086YP@1MQVh0PJV1086YP@@0Njb91@21ZH4909S>W`03086YP@2R
fZH0X]ZV00h0X]ZV00<0PJV10:KOZ02VgjP04@2VgjP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2U
gJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`0402OeY`00`21ZH40U<RB09C8TP0<09C8TP03086YP@22
/X00P[:000H0PJV100<0NZYk086YP@1NQf400P1NQf400`21ZH40/>3V0;3PiP2/0;3PiP40oooo002^
0;3PiP04086YP@1MQVh0GHI^086YP@D0Njb900<0PJV108o5V@2?aIT01`21ZH4209S>W`03086YP@2R
fZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP0402VgjP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2U
gJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`03`2OeY`00`21ZH40U<RB09C8TP0909C8TPL0PJV11P1j
ZW/01@21ZH40GXMQ05j7H@1NQf40PJV10:l0/>3V0@3oool00:l0/>3V0P21ZH400`1MQVh0PJV107^/
R@0407^/R@03086YP@2?aIT0SlFI00H0SlFI2021ZH4<0:;JYP03086YP@2VgjP0Y]nX0140Y]nX00<0
PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00l0WmJL00@0
PJV109C8TP2Db980U<RB2021ZH4208g2SP03086YP@1jZW/0NZYk00H0NZYk0P21ZH4305j7H@03086Y
P@2`h>H0/>3V0:h0/>3V0@3oool00;40/>3V00<0PJV105f6KP21ZH401@1k[8T2086YP@X0SlFI00@0
PJV109[CXP2Jdj80V]>R2@21ZH440:;JYP03086YP@2VgjP0Y]nX0100Y]nX00<0PJV10:OPY`2Wh:L0
4P2Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00X0WmJL2@21ZH4908g2SP03086Y
P@1jZW/0NZYk00H0NZYk00<0PJV105j7H@1NQf400P1NQf400`21ZH40/>3V0;3PiP2_0;3PiP40oooo
002b0;3PiP03086YP@1MQVh0PJV100H0Njb900<0PJV108o5V@2?aIT0202?aIT00`21ZH40V]>R09[C
XP0909[CXPh0PJV12@2VgjP00`21ZH40Yn2W0:OPY`0B0:OPY`03086YP@2UgJ<0YMfS0180YMfS00<0
PJV109oFW02OeY`00P2OeY`9086YP@<0V=2J00<0PJV108g2SP2=`Xh02`2=`Xh00`21ZH40NZYk07ZZ
N`0607ZZN`03086YP@1NQf40GXMQ0080GXMQ00<0PJV10;3PiP2`h>H0/02`h>H10?ooo`00/`2`h>H3
086YP@H0Njb900<0PJV108o5V@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0>09[CXP03086YP@2PfZD0
X=ZU00H0X=ZU>021ZH4<09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01P1jZW/0
1021ZH40GXMQ05j7H@1NQf42086YPK<0/>3V0@3oool00;D0/>3V0`21ZH4507^/R@03086YP@2?aIT0
SlFI00L0SlFI00<0PJV109[CXP2Jdj803@2Jdj800`21ZH40X=ZU0:3JY@0?0:3JY@03086YP@2Qfj@0
XM^T0180XM^T00<0PJV109oHX@2Of:404P2Of:400`21ZH40V=2J09S@VP0=09S@VP03086YP@2=`Xh0
SL:>00X0SL:>00<0PJV107ZZN`1jZW/01P1jZW/01@21ZH40GXMQ05j7H@1NQf40PJV10;D0/>3V0@3o
ool00;H0/>3V0`21ZH4507^/R@03086YP@2?aIT0SlFI00L0SlFI00<0PJV109[CXP2Jdj803@2Jdj80
0`21ZH40X=ZU0:3JY@0?0:3JY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109oHX@2Of:404@2Of:40
0`21ZH40V=2J09S@VP0=09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1jZW/01@1jZW/2
086YP@<0GXMQ00<0PJV10;3PiP2`h>H0]02`h>H10?ooo`00^02`h>H2086YP@D0Njb90P21ZH4808o5
V@03086YP@2Jdj80V]>R00d0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00A0:7K
Y003086YP@2Of:40WmRQ0140WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2SP0;08g2
SP03086YP@1jZW/0NZYk00@0NZYk00@0PJV105j7H@1NQf40GXMQ0P21ZH6g0;3PiP40oooo002j0;3P
iP<0PJV1101k[8T00`21ZH40SlFI08o5V@0608o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3J
Y@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@
VP2Hd9X03@2Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0NZYk00@0NZYk1P21ZH6h0;3P
iP40oooo002k0;3PiPH0PJV100<0Njb9086YP@2?aIT01`2?aIT00`21ZH40V]>R09[CXP0<09[CXP03
086YP@2PfZD0X=ZU00d0X=ZU00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40WmRQ09oHX@0@09oHX@03
086YP@2Hd9X0V=2J00`0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk07ZZN`0307ZZN`<0
PJV100<0DWYI086YP@21ZH40^P2`h>H10?ooo`00_@2`h>H2086YP@80JYUj1021ZH4608o5V@03086Y
P@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03P2PfZD00`21ZH40XM^T0:7KY00?0:7KY003086Y
P@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2SP0:08g2SP04086Y
P@1jZW/0NZYk07ZZN`@0PJV100<0DWYI086YP@21ZH40_02`h>H10?ooo`00_`2`h>H2086YP@<0JYUj
1@21ZH4308o5V@03086YP@2Jdj80V]>R00`0V]>R00<0PJV10:3JY@2PfZD03@2PfZD00`21ZH40XM^T
0:7KY00?0:7KY003086YP@2Of:40WmRQ0100WmRQ00<0PJV109S@VP2Hd9X02`2Hd9X00`21ZH40SL:>
08g2SP0:08g2SPL0PJV100<0DWYI086YP@21ZH40_P2`h>H10?ooo`00`@2`h>H2086YP@<0JYUj0P21
ZH400`1n/X/0PJV1086YP@03086YP@h0V]>R00<0PJV10:3JY@2PfZD0302PfZD00`21ZH40XM^T0:7K
Y00?0:7KY003086YP@2Of:40WmRQ00l0WmRQ00<0PJV109S@VP2Hd9X0302Hd9X00`21ZH40SL:>08g2
SP0308g2SPP0PJV10P1[VG42086YP@03059jF@21ZH40PJV10<00/>3V0@3oool00<<0/>3V0P21ZH43
06ZINP03086YP@1n/X/0O[:;0080O[:;2@21ZH4609[CXP03086YP@2PfZD0X=ZU00`0X=ZU00<0PJV1
0:7KY02Qfj@03`2Qfj@00`21ZH40WmRQ09oHX@0?09oHX@03086YP@2Hd9X0V=2J00P0V=2J2P21ZH44
07faP`80PJV10`1[VG401021ZH40DWYI086YP@21ZH720;3PiP40oooo00350;3PiP80PJV10P1ZVGX2
086YP@@0O[:;0P21ZH4508[2U@l0PJV11`2PfZD00`21ZH40XM^T0:7KY00>0:7KY003086YP@2Of:40
WmRQ00h0WmRQ00@0PJV109S@VP2Hd9X0V=2J2021ZH4208W0S`03086YP@1m/H<0OK6300L0OK630P21
ZH4306^IL@@0PJV1a02`h>H10?ooo`00aP2`h>H3086YP@80JYUj00<0PJV107jbR`1n/X/00`1n/X/0
0`21ZH40R/:E08[2U@0:08[2U@03086YP@2AbYX0TLZJ00@0TLZJ;@21ZH4908W0S`03086YP@1m/H<0
OK6300L0OK6300@0PJV106^IL@1[VG40JiUa1021ZH760;3PiP40oooo00380;3PiP<0PJV100<0JYUj
086YP@21ZH40101n/X/2086YP@/0R/:E00<0PJV1097:VP2AbYX02`2AbYX00`21ZH40TlbJ09?<VP0=
09?<VP03086YP@2AbIL0TLVG00d0TLVG00<0PJV108W0S`29`8l02P29`8l00`21ZH40OK6307faP`06
07faP`80PJV10P1[VG43086YPLT0/>3V0@3oool00</0/>3V1@21ZH4407jbR`80PJV12P2:`YD00`21
ZH40TLZJ097:VP0:097:VP03086YP@2Cc9X0TlbJ00d0TlbJ00<0PJV10979U`2AbIL0302AbIL00`21
ZH40RL2?08W0S`0908W0S`80PJV11`1m/H<2086YP@80JiUa0`21ZH7;0;3PiP40oooo003=0;3PiPH0
PJV10`1n/X/00`21ZH40R/:E08[2U@0808[2U@03086YP@2AbYX0TLZJ00X0TLZJ00<0PJV109?<VP2C
c9X0302Cc9X00`21ZH40TLVG0979U`0;0979U`03086YP@29`8l0RL2?00T0RL2?00<0PJV107faP`1m
/H<01@1m/H<6086YPLh0/>3V0@3oool00=00/>3V2@21ZH4908[2U@03086YP@2AbYX0TLZJ00T0TLZJ
00<0PJV109?<VP2Cc9X02`2Cc9X00`21ZH40TLVG0979U`0<0979U`03086YP@29`8l0RL2?00P0RL2?
00<0PJV107faP`1m/H<00`1m/H<6086YPM40/>3V0@3oool00=<0/>3V3021ZH4408[2U@03086YP@2A
bYX0TLZJ00T0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21ZH40TLVG0979U`0;0979U`03086YP@29
`8l0RL2?00P0RL2?00<0PJV107faP`21ZH402021ZH7C0;3PiP40oooo003E0;3PiPD0PJV100D0I99d
086YP@21ZH40PJV106nQO@0;086YP@D0TLZJ00<0PJV109?<VP2Cc9X02P2Cc9X00`21ZH40TLVG0979
U`0:0979U`03086YP@29`8l0RL2?00<0RL2?2021ZH400`1TTfl0PJV1086YP@03086YPMH0/>3V0@3o
ool00=P0/>3V1@21ZH400`1TTW@0PJV1086YP@0506nQO@80PJV10`1fZH<U086YP@80L:5j0P21ZH42
06BCK`D0PJV1f@2`h>H10?ooo`00g02`h>H7086YP@@0Kj5m0P21ZH4807JYP`03086YP@1h[8@0N:b4
00P0N:b400<0PJV107JYP@1fZH401`1fZH42086YP@L0L:5j0P21ZH4206BCK`<0PJV1g@2`h>H10?oo
o`00h@2`h>H7086YP@0306nQO@21ZH40PJV100H0MZV300<0PJV107R/Q01h[8@01`1h[8@00`21ZH40
MZV107JYP@0607JYP@80PJV11`1`XGX6086YPN00/>3V0@3oool00>P0/>3V1`21ZH4307JYP`03086Y
P@1h[8@0N:b400H0N:b400<0PJV107JYP@1fZH400P1fZH4?086YPN@0/>3V0@3oool00>l0/>3V4P21
ZH7b0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.606 .779 .568 r
.46017 .46966 m .45976 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.606 .779 .568 r
.5 .5 m .5 .46978 L .46017 .46966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.5 .53022 m .5 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.5 .46978 m .5 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.5 .5 m .5 .53022 L .53983 .53034 L p F P
.505 .664 .505 r
s
.595 .76 .557 r
.53983 .53034 m .54024 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.46139 .43966 m .46017 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.621 .802 .586 r
.5 .46978 m .5 .43989 L .46139 .43966 L p F P
.505 .664 .505 r
s
.59 .754 .548 r
.45976 .5 m .46017 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.5 .56011 m .5 .53022 L .46017 .53034 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.5 .43989 m .5 .46978 L .53983 .46966 L p F P
.505 .664 .505 r
s
.611 .785 .577 r
.54024 .5 m .53983 .46966 L .5 .46978 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.5 .53022 m .5 .56011 L .53861 .56034 L p F P
.505 .664 .505 r
s
.576 .731 .534 r
.53861 .56034 m .53983 .53034 L .5 .53022 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.42114 .46929 m .42033 .5 L .45976 .5 L p F P
.505 .664 .505 r
s
.598 .768 .556 r
.45976 .5 m .46017 .46966 L .42114 .46929 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.46017 .53034 m .45976 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.53983 .46966 m .54024 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.54024 .5 m .53983 .53034 L .57886 .53071 L p F P
.505 .664 .505 r
s
.595 .76 .561 r
.57886 .53071 m .57967 .5 L .54024 .5 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.42358 .43896 m .42114 .46929 L .46017 .46966 L p F P
.505 .664 .505 r
s
.613 .792 .575 r
.46017 .46966 m .46139 .43966 L .42358 .43896 L p F P
.505 .664 .505 r
s
.582 .742 .536 r
.42033 .5 m .42114 .53071 L .46017 .53034 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.46139 .56034 m .46017 .53034 L .42114 .53071 L p F P
.505 .664 .505 r
s
.572 .725 .526 r
.46017 .53034 m .46139 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .808 .595 r
.53983 .46966 m .53861 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.53861 .43966 m .53983 .46966 L .57886 .46929 L p F P
.505 .664 .505 r
s
.611 .786 .581 r
.57967 .5 m .57886 .46929 L .53983 .46966 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.53983 .53034 m .53861 .56034 L .57642 .56104 L p F P
.505 .664 .505 r
s
.576 .731 .538 r
.57642 .56104 m .57886 .53071 L .53983 .53034 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.46342 .41036 m .46139 .43966 L .5 .43989 L p F P
.505 .664 .505 r
s
.633 .822 .603 r
.5 .43989 m .5 .41069 L .46342 .41036 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.5 .41069 m .5 .43989 L .53861 .43966 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.5 .58931 m .5 .56011 L .46139 .56034 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.5 .56011 m .5 .58931 L .53658 .58964 L p F P
.505 .664 .505 r
s
.554 .698 .509 r
.53658 .58964 m .53861 .56034 L .5 .56011 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.42766 .40937 m .42358 .43896 L .46139 .43966 L p F P
.505 .664 .505 r
s
.625 .813 .592 r
.46139 .43966 m .46342 .41036 L .42766 .40937 L p F P
.505 .664 .505 r
s
.637 .828 .611 r
.53861 .43966 m .53658 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.53658 .41036 m .53861 .43966 L .57642 .43896 L p F P
.505 .664 .505 r
s
.626 .809 .6 r
.57886 .46929 m .57642 .43896 L .53861 .43966 L p F P
.505 .664 .505 r
s
.562 .713 .513 r
.42114 .53071 m .42358 .56104 L .46139 .56034 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.46342 .58964 m .46139 .56034 L .42358 .56104 L p F P
.505 .664 .505 r
s
.55 .693 .501 r
.46139 .56034 m .46342 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.53861 .56034 m .53658 .58964 L .57234 .59063 L p F P
.505 .664 .505 r
s
.553 .697 .511 r
.57234 .59063 m .57642 .56104 L .53861 .56034 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.38378 .46868 m .38255 .5 L .42033 .5 L p F P
.505 .664 .505 r
s
.585 .751 .539 r
.42033 .5 m .42114 .46929 L .38378 .46868 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.42114 .53071 m .42033 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.57886 .46929 m .57967 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.57967 .5 m .57886 .53071 L .61622 .53132 L p F P
.505 .664 .505 r
s
.59 .754 .561 r
.61622 .53132 m .61745 .5 L .57967 .5 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.38745 .43778 m .38378 .46868 L .42114 .46929 L p F P
.505 .664 .505 r
s
.6 .776 .559 r
.42114 .46929 m .42358 .43896 L .38745 .43778 L p F P
.505 .664 .505 r
s
.567 .723 .518 r
.38255 .5 m .38378 .53132 L .42114 .53071 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.42358 .56104 m .42114 .53071 L .38378 .53132 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.57642 .43896 m .57886 .46929 L .61622 .46868 L p F P
.505 .664 .505 r
s
.607 .782 .582 r
.61745 .5 m .61622 .46868 L .57886 .46929 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.57886 .53071 m .57642 .56104 L .61255 .56222 L p F P
.505 .664 .505 r
s
.569 .723 .536 r
.61255 .56222 m .61622 .53132 L .57886 .53071 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.46628 .38215 m .46342 .41036 L .5 .41069 L p F P
.505 .664 .505 r
s
.643 .84 .618 r
.5 .41069 m .5 .38255 L .46628 .38215 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.5 .38255 m .5 .41069 L .53658 .41036 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.5 .61745 m .5 .58931 L .46342 .58964 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.5 .58931 m .5 .61745 L .53372 .61785 L p F P
.505 .664 .505 r
s
.528 .66 .479 r
.53372 .61785 m .53658 .58964 L .5 .58931 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.43336 .38095 m .42766 .40937 L .46342 .41036 L p F P
.505 .664 .505 r
s
.636 .831 .608 r
.46342 .41036 m .46628 .38215 L .43336 .38095 L p F P
.505 .664 .505 r
s
.54 .68 .487 r
.42358 .56104 m .42766 .59063 L .46342 .58964 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.46628 .61785 m .46342 .58964 L .42766 .59063 L p F P
.505 .664 .505 r
s
.524 .655 .471 r
.46342 .58964 m .46628 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.647 .846 .626 r
.53658 .41036 m .53372 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.53372 .38215 m .53658 .41036 L .57234 .40937 L p F P
.505 .664 .505 r
s
.638 .83 .616 r
.57642 .43896 m .57234 .40937 L .53658 .41036 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.53658 .58964 m .53372 .61785 L .56664 .61905 L p F P
.505 .664 .505 r
s
.526 .657 .481 r
.56664 .61905 m .57234 .59063 L .53658 .58964 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.39355 .40772 m .38745 .43778 L .42358 .43896 L p F P
.505 .664 .505 r
s
.613 .798 .578 r
.42358 .43896 m .42766 .40937 L .39355 .40772 L p F P
.505 .664 .505 r
s
.547 .692 .494 r
.38378 .53132 m .38745 .56222 L .42358 .56104 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.42766 .59063 m .42358 .56104 L .38745 .56222 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.57234 .40937 m .57642 .43896 L .61255 .43778 L p F P
.505 .664 .505 r
s
.623 .806 .602 r
.61622 .46868 m .61255 .43778 L .57642 .43896 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.57642 .56104 m .57234 .59063 L .60645 .59228 L p F P
.505 .664 .505 r
s
.546 .687 .508 r
.60645 .59228 m .61255 .56222 L .57642 .56104 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.40208 .37896 m .39355 .40772 L .42766 .40937 L p F P
.505 .664 .505 r
s
.625 .818 .594 r
.42766 .40937 m .43336 .38095 L .40208 .37896 L p F P
.505 .664 .505 r
s
.524 .657 .466 r
.38745 .56222 m .39355 .59228 L .42766 .59063 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.43336 .61905 m .42766 .59063 L .39355 .59228 L p F P
.505 .664 .505 r
s
.514 .641 .457 r
.42766 .59063 m .43336 .61905 L .46628 .61785 L p F P
.505 .664 .505 r
s
.648 .848 .631 r
.57234 .40937 m .56664 .38095 L .53372 .38215 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.56664 .38095 m .57234 .40937 L .60645 .40772 L p F P
.505 .664 .505 r
s
.635 .828 .619 r
.61255 .43778 m .60645 .40772 L .57234 .40937 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.57234 .59063 m .56664 .61905 L .59792 .62104 L p F P
.505 .664 .505 r
s
.517 .645 .476 r
.59792 .62104 m .60645 .59228 L .57234 .59063 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.34905 .46783 m .34741 .5 L .38255 .5 L p F P
.505 .664 .505 r
s
.564 .725 .516 r
.38255 .5 m .38378 .46868 L .34905 .46783 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.38378 .53132 m .38255 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.46995 .35545 m .46628 .38215 L .5 .38255 L p F P
.505 .664 .505 r
s
.65 .856 .631 r
.5 .38255 m .5 .35589 L .46995 .35545 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.5 .64411 m .5 .61745 L .46628 .61785 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.5 .35589 m .5 .38255 L .53372 .38215 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.5 .61745 m .5 .64411 L .53005 .64455 L p F P
.505 .664 .505 r
s
.497 .614 .444 r
.53005 .64455 m .53372 .61785 L .5 .61745 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.61622 .46868 m .61745 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.61745 .5 m .61622 .53132 L .65095 .53217 L p F P
.505 .664 .505 r
s
.578 .739 .555 r
.65095 .53217 m .65259 .5 L .61745 .5 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.35394 .43614 m .34905 .46783 L .38378 .46868 L p F P
.505 .664 .505 r
s
.581 .752 .537 r
.38378 .46868 m .38745 .43778 L .35394 .43614 L p F P
.505 .664 .505 r
s
.545 .694 .492 r
.34741 .5 m .34905 .53217 L .38378 .53132 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.38745 .56222 m .38378 .53132 L .34905 .53217 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.61255 .43778 m .61622 .46868 L .65095 .46783 L p F P
.505 .664 .505 r
s
.597 .769 .578 r
.65259 .5 m .65095 .46783 L .61622 .46868 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.61622 .53132 m .61255 .56222 L .64606 .56386 L p F P
.505 .664 .505 r
s
.556 .705 .528 r
.64606 .56386 m .65095 .53217 L .61622 .53132 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.44068 .35415 m .43336 .38095 L .46628 .38215 L p F P
.505 .664 .505 r
s
.644 .847 .621 r
.46628 .38215 m .46995 .35545 L .44068 .35415 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.46995 .64455 m .46628 .61785 L .43336 .61905 L p F P
.505 .664 .505 r
s
.493 .609 .436 r
.46628 .61785 m .46995 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.654 .861 .638 r
.53372 .38215 m .53005 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.53005 .35545 m .53372 .38215 L .56664 .38095 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.53372 .61785 m .53005 .64455 L .55932 .64585 L p F P
.505 .664 .505 r
s
.494 .61 .444 r
.55932 .64585 m .56664 .61905 L .53372 .61785 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.36206 .40542 m .35394 .43614 L .38745 .43778 L p F P
.505 .664 .505 r
s
.596 .776 .557 r
.38745 .43778 m .39355 .40772 L .36206 .40542 L p F P
.505 .664 .505 r
s
.523 .661 .466 r
.34905 .53217 m .35394 .56386 L .38745 .56222 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.39355 .59228 m .38745 .56222 L .35394 .56386 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.60645 .40772 m .61255 .43778 L .64606 .43614 L p F P
.505 .664 .505 r
s
.614 .796 .599 r
.65095 .46783 m .64606 .43614 L .61255 .43778 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.61255 .56222 m .60645 .59228 L .63794 .59458 L p F P
.505 .664 .505 r
s
.53 .666 .497 r
.63794 .59458 m .64606 .56386 L .61255 .56222 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.41299 .35198 m .40208 .37896 L .43336 .38095 L p F P
.505 .664 .505 r
s
.633 .835 .609 r
.43336 .38095 m .44068 .35415 L .41299 .35198 L p F P
.505 .664 .505 r
s
.496 .617 .435 r
.39355 .59228 m .40208 .62104 L .43336 .61905 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.44068 .64585 m .43336 .61905 L .40208 .62104 L p F P
.505 .664 .505 r
s
.482 .594 .422 r
.43336 .61905 m .44068 .64585 L .46995 .64455 L p F P
.505 .664 .505 r
s
.655 .863 .644 r
.56664 .38095 m .55932 .35415 L .53005 .35545 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.55932 .35415 m .56664 .38095 L .59792 .37896 L p F P
.505 .664 .505 r
s
.646 .847 .634 r
.60645 .40772 m .59792 .37896 L .56664 .38095 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.56664 .61905 m .55932 .64585 L .58701 .64802 L p F P
.505 .664 .505 r
s
.483 .596 .437 r
.58701 .64802 m .59792 .62104 L .56664 .61905 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.37336 .37619 m .36206 .40542 L .39355 .40772 L p F P
.505 .664 .505 r
s
.608 .798 .575 r
.39355 .40772 m .40208 .37896 L .37336 .37619 L p F P
.505 .664 .505 r
s
.498 .623 .436 r
.35394 .56386 m .36206 .59458 L .39355 .59228 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.40208 .62104 m .39355 .59228 L .36206 .59458 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.59792 .37896 m .60645 .40772 L .63794 .40542 L p F P
.505 .664 .505 r
s
.628 .819 .618 r
.64606 .43614 m .63794 .40542 L .60645 .40772 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.60645 .59228 m .59792 .62104 L .62664 .62381 L p F P
.505 .664 .505 r
s
.499 .621 .462 r
.62664 .62381 m .63794 .59458 L .60645 .59228 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.47443 .33074 m .46995 .35545 L .5 .35589 L p F P
.505 .664 .505 r
s
.654 .867 .641 r
.5 .35589 m .5 .33118 L .47443 .33074 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.5 .33118 m .5 .35589 L .53005 .35545 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.5 .66882 m .5 .64411 L .46995 .64455 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.5 .64411 m .5 .66882 L .52557 .66926 L p F P
.505 .664 .505 r
s
.457 .558 .4 r
.52557 .66926 m .53005 .64455 L .5 .64411 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.4496 .32944 m .44068 .35415 L .46995 .35545 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.46995 .35545 m .47443 .33074 L .4496 .32944 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.47443 .66926 m .46995 .64455 L .44068 .64585 L p F P
.505 .664 .505 r
s
.454 .553 .394 r
.46995 .64455 m .47443 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.658 .872 .648 r
.53005 .35545 m .52557 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.52557 .33074 m .53005 .35545 L .55932 .35415 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.53005 .64455 m .52557 .66926 L .5504 .67056 L p F P
.505 .664 .505 r
s
.454 .552 .4 r
.5504 .67056 m .55932 .64585 L .53005 .64455 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.31808 .46673 m .31604 .5 L .34741 .5 L p F P
.505 .664 .505 r
s
.532 .684 .48 r
.34741 .5 m .34905 .46783 L .31808 .46673 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.34905 .53217 m .34741 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.65095 .46783 m .65259 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.65259 .5 m .65095 .53217 L .68192 .53327 L p F P
.505 .664 .505 r
s
.556 .711 .539 r
.68192 .53327 m .68396 .5 L .65259 .5 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.32417 .43403 m .31808 .46673 L .34905 .46783 L p F P
.505 .664 .505 r
s
.551 .714 .505 r
.34905 .46783 m .35394 .43614 L .32417 .43403 L p F P
.505 .664 .505 r
s
.51 .65 .453 r
.31604 .5 m .31808 .53327 L .34905 .53217 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.35394 .56386 m .34905 .53217 L .31808 .53327 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.64606 .43614 m .65095 .46783 L .68192 .46673 L p F P
.505 .664 .505 r
s
.577 .745 .566 r
.68396 .5 m .68192 .46673 L .65095 .46783 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.65095 .53217 m .64606 .56386 L .67583 .56597 L p F P
.505 .664 .505 r
s
.531 .672 .509 r
.67583 .56597 m .68192 .53327 L .65095 .53217 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.38776 .34897 m .37336 .37619 L .40208 .37896 L p F P
.505 .664 .505 r
s
.617 .816 .591 r
.40208 .37896 m .41299 .35198 L .38776 .34897 L p F P
.505 .664 .505 r
s
.469 .579 .403 r
.36206 .59458 m .37336 .62381 L .40208 .62104 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.41299 .64802 m .40208 .62104 L .37336 .62381 L p F P
.505 .664 .505 r
s
.463 .569 .399 r
.40208 .62104 m .41299 .64802 L .44068 .64585 L p F P
.505 .664 .505 r
s
.653 .862 .647 r
.59792 .37896 m .58701 .35198 L .55932 .35415 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.58701 .35198 m .59792 .37896 L .62664 .37619 L p F P
.505 .664 .505 r
s
.638 .839 .634 r
.63794 .40542 m .62664 .37619 L .59792 .37896 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.59792 .62104 m .58701 .64802 L .61224 .65103 L p F P
.505 .664 .505 r
s
.463 .568 .421 r
.61224 .65103 m .62664 .62381 L .59792 .62104 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.42624 .32729 m .41299 .35198 L .44068 .35415 L p F P
.505 .664 .505 r
s
.637 .847 .62 r
.44068 .35415 m .4496 .32944 L .42624 .32729 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.4496 .67056 m .44068 .64585 L .41299 .64802 L p F P
.505 .664 .505 r
s
.443 .537 .379 r
.44068 .64585 m .4496 .67056 L .47443 .66926 L p F P
.505 .664 .505 r
s
.659 .874 .653 r
.55932 .35415 m .5504 .32944 L .52557 .33074 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.5504 .32944 m .55932 .35415 L .58701 .35198 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.55932 .64585 m .5504 .67056 L .57376 .67271 L p F P
.505 .664 .505 r
s
.441 .536 .391 r
.57376 .67271 m .58701 .64802 L .55932 .64585 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.33425 .40248 m .32417 .43403 L .35394 .43614 L p F P
.505 .664 .505 r
s
.568 .742 .528 r
.35394 .43614 m .36206 .40542 L .33425 .40248 L p F P
.505 .664 .505 r
s
.486 .612 .424 r
.31808 .53327 m .32417 .56597 L .35394 .56386 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.36206 .59458 m .35394 .56386 L .32417 .56597 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.63794 .40542 m .64606 .43614 L .67583 .43403 L p F P
.505 .664 .505 r
s
.596 .775 .59 r
.68192 .46673 m .67583 .43403 L .64606 .43614 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.64606 .56386 m .63794 .59458 L .66575 .59752 L p F P
.505 .664 .505 r
s
.502 .629 .475 r
.66575 .59752 m .67583 .56597 L .64606 .56386 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.34822 .37266 m .33425 .40248 L .36206 .40542 L p F P
.505 .664 .505 r
s
.582 .766 .548 r
.36206 .40542 m .37336 .37619 L .34822 .37266 L p F P
.505 .664 .505 r
s
.458 .57 .392 r
.32417 .56597 m .33425 .59752 L .36206 .59458 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.37336 .62381 m .36206 .59458 L .33425 .59752 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.62664 .37619 m .63794 .40542 L .66575 .40248 L p F P
.505 .664 .505 r
s
.611 .8 .61 r
.67583 .43403 m .66575 .40248 L .63794 .40542 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.63794 .59458 m .62664 .62381 L .65178 .62734 L p F P
.505 .664 .505 r
s
.468 .579 .435 r
.65178 .62734 m .66575 .59752 L .63794 .59458 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.47972 .30855 m .47443 .33074 L .5 .33118 L p F P
.505 .664 .505 r
s
.653 .872 .648 r
.5 .33118 m .5 .30894 L .47972 .30855 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.5 .69106 m .5 .66882 L .47443 .66926 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.5 .30894 m .5 .33118 L .52557 .33074 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.5 .66882 m .5 .69106 L .52028 .69145 L p F P
.505 .664 .505 r
s
.407 .486 .346 r
.52028 .69145 m .52557 .66926 L .5 .66882 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.46008 .30739 m .4496 .32944 L .47443 .33074 L p F P
.505 .664 .505 r
s
.646 .864 .639 r
.47443 .33074 m .47972 .30855 L .46008 .30739 L p F P
.505 .664 .505 r
s
.656 .877 .654 r
.52557 .33074 m .52028 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.52028 .30855 m .52557 .33074 L .5504 .32944 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.52557 .66926 m .52028 .69145 L .53992 .69261 L p F P
.505 .664 .505 r
s
.402 .479 .344 r
.53992 .69261 m .5504 .67056 L .52557 .66926 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.47972 .69145 m .47443 .66926 L .4496 .67056 L p F P
.505 .664 .505 r
s
.404 .481 .339 r
.47443 .66926 m .47972 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.40515 .32433 m .38776 .34897 L .41299 .35198 L p F P
.505 .664 .505 r
s
.622 .829 .604 r
.41299 .35198 m .42624 .32729 L .40515 .32433 L p F P
.505 .664 .505 r
s
.434 .529 .365 r
.37336 .62381 m .38776 .65103 L .41299 .64802 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.42624 .67271 m .41299 .64802 L .38776 .65103 L p F P
.505 .664 .505 r
s
.423 .511 .355 r
.41299 .64802 m .42624 .67271 L .4496 .67056 L p F P
.505 .664 .505 r
s
.656 .872 .656 r
.58701 .35198 m .57376 .32729 L .5504 .32944 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.57376 .32729 m .58701 .35198 L .61224 .34897 L p F P
.505 .664 .505 r
s
.646 .855 .646 r
.62664 .37619 m .61224 .34897 L .58701 .35198 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.58701 .64802 m .57376 .67271 L .59485 .67567 L p F P
.505 .664 .505 r
s
.419 .505 .371 r
.59485 .67567 m .61224 .65103 L .58701 .64802 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.36592 .34517 m .34822 .37266 L .37336 .37619 L p F P
.505 .664 .505 r
s
.592 .786 .567 r
.37336 .37619 m .38776 .34897 L .36592 .34517 L p F P
.505 .664 .505 r
s
.427 .523 .357 r
.33425 .59752 m .34822 .62734 L .37336 .62381 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.38776 .65103 m .37336 .62381 L .34822 .62734 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.61224 .34897 m .62664 .37619 L .65178 .37266 L p F P
.505 .664 .505 r
s
.623 .822 .627 r
.66575 .40248 m .65178 .37266 L .62664 .37619 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.62664 .62381 m .61224 .65103 L .63408 .65483 L p F P
.505 .664 .505 r
s
.429 .522 .391 r
.63408 .65483 m .65178 .62734 L .62664 .62381 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.44174 .30547 m .42624 .32729 L .4496 .32944 L p F P
.505 .664 .505 r
s
.636 .853 .628 r
.4496 .32944 m .46008 .30739 L .44174 .30547 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.46008 .69261 m .4496 .67056 L .42624 .67271 L p F P
.505 .664 .505 r
s
.392 .466 .325 r
.4496 .67056 m .46008 .69261 L .47972 .69145 L p F P
.505 .664 .505 r
s
.656 .878 .658 r
.5504 .32944 m .53992 .30739 L .52028 .30855 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.53992 .30739 m .5504 .32944 L .57376 .32729 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.5504 .67056 m .53992 .69261 L .55826 .69453 L p F P
.505 .664 .505 r
s
.389 .461 .333 r
.55826 .69453 m .57376 .67271 L .5504 .67056 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.29221 .4654 m .28979 .5 L .31604 .5 L p F P
.505 .664 .505 r
s
.481 .618 .426 r
.31604 .5 m .31808 .46673 L .29221 .4654 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.31808 .53327 m .31604 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.68192 .46673 m .68396 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.68396 .5 m .68192 .53327 L .70779 .5346 L p F P
.505 .664 .505 r
s
.515 .658 .507 r
.70779 .5346 m .71021 .5 L .68396 .5 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.29943 .43148 m .29221 .4654 L .31808 .46673 L p F P
.505 .664 .505 r
s
.503 .654 .455 r
.31808 .46673 m .32417 .43403 L .29943 .43148 L p F P
.505 .664 .505 r
s
.455 .578 .395 r
.28979 .5 m .29221 .5346 L .31808 .53327 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.32417 .56597 m .31808 .53327 L .29221 .5346 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.67583 .43403 m .68192 .46673 L .70779 .4654 L p F P
.505 .664 .505 r
s
.54 .698 .539 r
.71021 .5 m .70779 .4654 L .68192 .46673 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.68192 .53327 m .67583 .56597 L .70057 .56852 L p F P
.505 .664 .505 r
s
.486 .614 .472 r
.70057 .56852 m .70779 .5346 L .68192 .53327 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.31135 .39893 m .29943 .43148 L .32417 .43403 L p F P
.505 .664 .505 r
s
.523 .687 .482 r
.32417 .43403 m .33425 .40248 L .31135 .39893 L p F P
.505 .664 .505 r
s
.427 .535 .362 r
.29221 .5346 m .29943 .56852 L .32417 .56597 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.33425 .59752 m .32417 .56597 L .29943 .56852 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42535 .30284 m .40515 .32433 L .42624 .32729 L p F P
.505 .664 .505 r
s
.621 .835 .613 r
.42624 .32729 m .44174 .30547 L .42535 .30284 L p F P
.505 .664 .505 r
s
.392 .469 .321 r
.38776 .65103 m .40515 .67567 L .42624 .67271 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.44174 .69453 m .42624 .67271 L .40515 .67567 L p F P
.505 .664 .505 r
s
.372 .439 .302 r
.42624 .67271 m .44174 .69453 L .46008 .69261 L p F P
.505 .664 .505 r
s
.652 .875 .659 r
.57376 .32729 m .55826 .30547 L .53992 .30739 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.55826 .30547 m .57376 .32729 L .59485 .32433 L p F P
.505 .664 .505 r
s
.648 .865 .655 r
.61224 .34897 m .59485 .32433 L .57376 .32729 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57376 .67271 m .55826 .69453 L .57465 .69716 L p F P
.505 .664 .505 r
s
.365 .429 .312 r
.57465 .69716 m .59485 .67567 L .57376 .67271 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.66575 .40248 m .67583 .43403 L .70057 .43148 L p F P
.505 .664 .505 r
s
.562 .733 .566 r
.70779 .4654 m .70057 .43148 L .67583 .43403 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.67583 .56597 m .66575 .59752 L .68865 .60107 L p F P
.505 .664 .505 r
s
.453 .565 .433 r
.68865 .60107 m .70057 .56852 L .67583 .56597 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38713 .32061 m .36592 .34517 L .38776 .34897 L p F P
.505 .664 .505 r
s
.598 .801 .581 r
.38776 .34897 m .40515 .32433 L .38713 .32061 L p F P
.505 .664 .505 r
s
.391 .471 .319 r
.34822 .62734 m .36592 .65483 L .38776 .65103 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.40515 .67567 m .38776 .65103 L .36592 .65483 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.59485 .32433 m .61224 .34897 L .63408 .34517 L p F P
.505 .664 .505 r
s
.631 .839 .64 r
.65178 .37266 m .63408 .34517 L .61224 .34897 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61224 .65103 m .59485 .67567 L .61287 .67939 L p F P
.505 .664 .505 r
s
.383 .456 .339 r
.61287 .67939 m .63408 .65483 L .61224 .65103 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.48578 .28949 m .47972 .30855 L .5 .30894 L p F P
.505 .664 .505 r
s
.641 .866 .646 r
.5 .30894 m .5 .28979 L .48578 .28949 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.5 .28979 m .5 .30894 L .52028 .30855 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.5 .71021 m .5 .69106 L .47972 .69145 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.5 .69106 m .5 .71021 L .51422 .71051 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51422 .71051 m .52028 .69145 L .5 .69106 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.32778 .36843 m .31135 .39893 L .33425 .40248 L p F P
.505 .664 .505 r
s
.54 .716 .507 r
.33425 .40248 m .34822 .37266 L .32778 .36843 L p F P
.505 .664 .505 r
s
.397 .489 .326 r
.29943 .56852 m .31135 .60107 L .33425 .59752 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.34822 .62734 m .33425 .59752 L .31135 .60107 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.65178 .37266 m .66575 .40248 L .68865 .39893 L p F P
.505 .664 .505 r
s
.58 .763 .59 r
.70057 .43148 m .68865 .39893 L .66575 .40248 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.66575 .59752 m .65178 .62734 L .67222 .63157 L p F P
.505 .664 .505 r
s
.416 .51 .39 r
.67222 .63157 m .68865 .60107 L .66575 .59752 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47206 .28859 m .46008 .30739 L .47972 .30855 L p F P
.505 .664 .505 r
s
.635 .858 .638 r
.47972 .30855 m .48578 .28949 L .47206 .28859 L p F P
.505 .664 .505 r
s
.644 .869 .651 r
.52028 .30855 m .51422 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.51422 .28949 m .52028 .30855 L .53992 .30739 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.48578 .71051 m .47972 .69145 L .46008 .69261 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47972 .69145 m .48578 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52028 .69145 m .51422 .71051 L .52794 .71141 L p F P
.505 .664 .505 r
s
.334 .385 .271 r
.52794 .71141 m .53992 .69261 L .52028 .69145 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.45934 .28712 m .44174 .30547 L .46008 .30739 L p F P
.505 .664 .505 r
s
.625 .847 .628 r
.46008 .30739 m .47206 .28859 L .45934 .28712 L p F P
.505 .664 .505 r
s
.643 .869 .653 r
.53992 .30739 m .52794 .28859 L .51422 .28949 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.52794 .28859 m .53992 .30739 L .55826 .30547 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.47206 .71141 m .46008 .69261 L .44174 .69453 L p F P
.505 .664 .505 r
s
.335 .385 .268 r
.46008 .69261 m .47206 .71141 L .48578 .71051 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.53992 .69261 m .52794 .71141 L .54066 .71288 L p F P
.505 .664 .505 r
s
.321 .366 .26 r
.54066 .71288 m .55826 .69453 L .53992 .69261 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34844 .34065 m .32778 .36843 L .34822 .37266 L p F P
.505 .664 .505 r
s
.553 .74 .529 r
.34822 .37266 m .36592 .34517 L .34844 .34065 L p F P
.505 .664 .505 r
s
.376 .456 .308 r
.31135 .60107 m .32778 .63157 L .34822 .62734 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.36592 .65483 m .34822 .62734 L .32778 .63157 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.63408 .34517 m .65178 .37266 L .67222 .36843 L p F P
.505 .664 .505 r
s
.593 .788 .609 r
.68865 .39893 m .67222 .36843 L .65178 .37266 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65178 .62734 m .63408 .65483 L .65156 .65935 L p F P
.505 .664 .505 r
s
.375 .45 .341 r
.65156 .65935 m .67222 .63157 L .65178 .62734 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.41156 .29957 m .38713 .32061 L .40515 .32433 L p F P
.505 .664 .505 r
s
.598 .809 .592 r
.40515 .32433 m .42535 .30284 L .41156 .29957 L p F P
.505 .664 .505 r
s
.363 .429 .294 r
.36592 .65483 m .38713 .67939 L .40515 .67567 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.42535 .69716 m .40515 .67567 L .38713 .67939 L p F P
.505 .664 .505 r
s
.354 .413 .285 r
.40515 .67567 m .42535 .69716 L .44174 .69453 L p F P
.505 .664 .505 r
s
.644 .866 .657 r
.59485 .32433 m .57465 .30284 L .55826 .30547 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.57465 .30284 m .59485 .32433 L .61287 .32061 L p F P
.505 .664 .505 r
s
.633 .849 .648 r
.63408 .34517 m .61287 .32061 L .59485 .32433 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.59485 .67567 m .57465 .69716 L .58844 .70043 L p F P
.505 .664 .505 r
s
.329 .379 .278 r
.58844 .70043 m .61287 .67939 L .59485 .67567 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44812 .28512 m .42535 .30284 L .44174 .30547 L p F P
.505 .664 .505 r
s
.611 .83 .614 r
.44174 .30547 m .45934 .28712 L .44812 .28512 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.45934 .71288 m .44174 .69453 L .42535 .69716 L p F P
.505 .664 .505 r
s
.325 .372 .26 r
.44174 .69453 m .45934 .71288 L .47206 .71141 L p F P
.505 .664 .505 r
s
.639 .865 .653 r
.55826 .30547 m .54066 .28712 L .52794 .28859 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.54066 .28712 m .55826 .30547 L .57465 .30284 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55826 .69453 m .54066 .71288 L .55188 .71488 L p F P
.505 .664 .505 r
s
.298 .335 .239 r
.55188 .71488 m .57465 .69716 L .55826 .69453 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.37301 .31621 m .34844 .34065 L .36592 .34517 L p F P
.505 .664 .505 r
s
.562 .759 .548 r
.36592 .34517 m .38713 .32061 L .37301 .31621 L p F P
.505 .664 .505 r
s
.352 .418 .286 r
.32778 .63157 m .34844 .65935 L .36592 .65483 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.38713 .67939 m .36592 .65483 L .34844 .65935 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.61287 .32061 m .63408 .34517 L .65156 .34065 L p F P
.505 .664 .505 r
s
.603 .807 .623 r
.67222 .36843 m .65156 .34065 L .63408 .34517 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.63408 .65483 m .61287 .67939 L .62699 .68379 L p F P
.505 .664 .505 r
s
.328 .383 .288 r
.62699 .68379 m .65156 .65935 L .63408 .65483 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.2965 .4436 m
.29678 .44395 L
s
0 0 0 r
.70066 .56809 m
.70177 .56767 L
s
.69613 .58063 m
.69639 .58096 L
s
1 .5 0 r
.2965 .4436 m
.29682 .43848 L
s
.5 Mabswid
.394 .508 .339 r
.27297 .46384 m .2702 .5 L .28979 .5 L p F P
.505 .664 .505 r
s
.394 .508 .339 r
.28979 .5 m .29221 .4654 L .27297 .46384 L p F P
.505 .664 .505 r
s
.369 .466 .308 r
.29221 .5346 m .28979 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.49256 .27421 m .48578 .28949 L .5 .28979 L p F P
.505 .664 .505 r
s
.613 .838 .629 r
.5 .28979 m .5 .27438 L .49256 .27421 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.5 .27438 m .5 .28979 L .51422 .28949 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.5 .72562 m .5 .71021 L .48578 .71051 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.5 .71021 m .5 .72562 L .50744 .72579 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.50744 .72579 m .51422 .71051 L .5 .71021 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.70779 .4654 m .71021 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.71021 .5 m .70779 .5346 L .72703 .53616 L p F P
.505 .664 .505 r
s
.44 .563 .445 r
.72703 .53616 m .7298 .5 L .71021 .5 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.2812 .42852 m .27297 .46384 L .29221 .4654 L p F P
.505 .664 .505 r
s
.423 .552 .375 r
.29221 .4654 m .29943 .43148 L .2812 .42852 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.29891 .43139 m
.30188 .42129 L
s
.5 Mabswid
.369 .466 .308 r
.2702 .5 m .27297 .53616 L .29221 .5346 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.29943 .56852 m .29221 .5346 L .27297 .53616 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.70057 .43148 m .70779 .4654 L .72703 .46384 L p F P
.505 .664 .505 r
s
.47 .61 .483 r
.7298 .5 m .72703 .46384 L .70779 .4654 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.70779 .5346 m .70057 .56852 L .7188 .57148 L p F P
.505 .664 .505 r
s
.407 .512 .404 r
.7188 .57148 m .72703 .53616 L .70779 .5346 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.43884 .28266 m .41156 .29957 L .42535 .30284 L p F P
.505 .664 .505 r
s
.59 .806 .595 r
.42535 .30284 m .44812 .28512 L .43884 .28266 L p F P
.505 .664 .505 r
s
.328 .378 .263 r
.38713 .67939 m .41156 .70043 L .42535 .69716 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.44812 .71488 m .42535 .69716 L .41156 .70043 L p F P
.505 .664 .505 r
s
.309 .349 .247 r
.42535 .69716 m .44812 .71488 L .45934 .71288 L p F P
.505 .664 .505 r
s
.63 .855 .649 r
.57465 .30284 m .55188 .28512 L .54066 .28712 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.55188 .28512 m .57465 .30284 L .58844 .29957 L p F P
.505 .664 .505 r
s
.629 .85 .649 r
.61287 .32061 m .58844 .29957 L .57465 .30284 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.57465 .69716 m .55188 .71488 L .56116 .71734 L p F P
.505 .664 .505 r
s
.267 .294 .212 r
.56116 .71734 m .58844 .70043 L .57465 .69716 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48542 .27371 m .47206 .28859 L .48578 .28949 L p F P
.505 .664 .505 r
s
.608 .832 .623 r
.48578 .28949 m .49256 .27421 L .48542 .27371 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51422 .28949 m .50744 .27421 L .5 .27438 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.50744 .27421 m .51422 .28949 L .52794 .28859 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.49256 .72579 m .48578 .71051 L .47206 .71141 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.48578 .71051 m .49256 .72579 L .5 .72562 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51422 .71051 m .50744 .72579 L .51458 .72629 L p F P
.505 .664 .505 r
s
.269 .293 .212 r
.51458 .72629 m .52794 .71141 L .51422 .71051 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29473 .39483 m .2812 .42852 L .29943 .43148 L p F P
.505 .664 .505 r
s
.448 .594 .409 r
.29943 .43148 m .31135 .39893 L .29473 .39483 L p F P
.505 .664 .505 r
s
.353 .438 .292 r
.27297 .53616 m .2812 .57148 L .29943 .56852 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.31135 .60107 m .29943 .56852 L .2812 .57148 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.40102 .29574 m .37301 .31621 L .38713 .32061 L p F P
.505 .664 .505 r
s
.566 .771 .562 r
.38713 .32061 m .41156 .29957 L .40102 .29574 L p F P
.505 .664 .505 r
s
.323 .375 .26 r
.34844 .65935 m .37301 .68379 L .38713 .67939 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.41156 .70043 m .38713 .67939 L .37301 .68379 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.58844 .29957 m .61287 .32061 L .62699 .31621 L p F P
.505 .664 .505 r
s
.606 .818 .631 r
.65156 .34065 m .62699 .31621 L .61287 .32061 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.61287 .67939 m .58844 .70043 L .59898 .70426 L p F P
.505 .664 .505 r
s
.276 .309 .229 r
.59898 .70426 m .62699 .68379 L .61287 .67939 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.68865 .39893 m .70057 .43148 L .7188 .42852 L p F P
.505 .664 .505 r
s
.497 .653 .516 r
.72703 .46384 m .7188 .42852 L .70057 .43148 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70057 .56852 m .68865 .60107 L .70527 .60517 L p F P
.505 .664 .505 r
s
.371 .457 .36 r
.70527 .60517 m .7188 .57148 L .70057 .56852 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47886 .27289 m .45934 .28712 L .47206 .28859 L p F P
.505 .664 .505 r
s
.599 .822 .614 r
.47206 .28859 m .48542 .27371 L .47886 .27289 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.48542 .72629 m .47206 .71141 L .45934 .71288 L p F P
.505 .664 .505 r
s
.273 .298 .216 r
.47206 .71141 m .48542 .72629 L .49256 .72579 L p F P
.505 .664 .505 r
s
.613 .84 .634 r
.52794 .28859 m .51458 .27371 L .50744 .27421 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.51458 .27371 m .52794 .28859 L .54066 .28712 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52794 .71141 m .51458 .72629 L .52114 .72711 L p F P
.505 .664 .505 r
s
.258 .278 .203 r
.52114 .72711 m .54066 .71288 L .52794 .71141 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31326 .36358 m .29473 .39483 L .31135 .39893 L p F P
.505 .664 .505 r
s
.471 .632 .442 r
.31135 .39893 m .32778 .36843 L .31326 .36358 L p F P
.505 .664 .505 r
s
.334 .406 .275 r
.2812 .57148 m .29473 .60517 L .31135 .60107 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.32778 .63157 m .31135 .60107 L .29473 .60517 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.67222 .36843 m .68865 .39893 L .70527 .39483 L p F P
.505 .664 .505 r
s
.52 .69 .544 r
.7188 .42852 m .70527 .39483 L .68865 .39893 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68865 .60107 m .67222 .63157 L .68674 .63642 L p F P
.505 .664 .505 r
s
.332 .399 .313 r
.68674 .63642 m .70527 .60517 L .68865 .60107 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.3364 .3355 m .31326 .36358 L .32778 .36843 L p F P
.505 .664 .505 r
s
.491 .665 .471 r
.32778 .36843 m .34844 .34065 L .3364 .3355 L p F P
.505 .664 .505 r
s
.313 .372 .255 r
.29473 .60517 m .31326 .63642 L .32778 .63157 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.34844 .65935 m .32778 .63157 L .31326 .63642 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.47314 .27179 m .44812 .28512 L .45934 .28712 L p F P
.505 .664 .505 r
s
.587 .808 .603 r
.45934 .28712 m .47886 .27289 L .47314 .27179 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.47886 .72711 m .45934 .71288 L .44812 .71488 L p F P
.505 .664 .505 r
s
.265 .287 .209 r
.45934 .71288 m .47886 .72711 L .48542 .72629 L p F P
.505 .664 .505 r
s
.608 .834 .632 r
.54066 .28712 m .52114 .27289 L .51458 .27371 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.52114 .27289 m .54066 .28712 L .55188 .28512 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.54066 .71288 m .52114 .72711 L .52686 .72821 L p F P
.505 .664 .505 r
s
.242 .256 .19 r
.52686 .72821 m .55188 .71488 L .54066 .71288 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.65156 .34065 m .67222 .36843 L .68674 .36358 L p F P
.505 .664 .505 r
s
.538 .722 .568 r
.70527 .39483 m .68674 .36358 L .67222 .36843 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.67222 .63157 m .65156 .65935 L .6636 .6645 L p F P
.505 .664 .505 r
s
.291 .338 .264 r
.6636 .6645 m .68674 .63642 L .67222 .63157 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.43196 .2798 m .40102 .29574 L .41156 .29957 L p F P
.505 .664 .505 r
s
.562 .773 .57 r
.41156 .29957 m .43884 .28266 L .43196 .2798 L p F P
.505 .664 .505 r
s
.29 .326 .232 r
.37301 .68379 m .40102 .70426 L .41156 .70043 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.43884 .71734 m .41156 .70043 L .40102 .70426 L p F P
.505 .664 .505 r
s
.285 .316 .226 r
.41156 .70043 m .43884 .71734 L .44812 .71488 L p F P
.505 .664 .505 r
s
.614 .838 .64 r
.58844 .29957 m .56116 .28266 L .55188 .28512 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.56116 .28266 m .58844 .29957 L .59898 .29574 L p F P
.505 .664 .505 r
s
.603 .821 .632 r
.62699 .31621 m .59898 .29574 L .58844 .29957 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.58844 .70043 m .56116 .71734 L .56804 .7202 L p F P
.505 .664 .505 r
s
.23 .244 .181 r
.56804 .7202 m .59898 .70426 L .58844 .70043 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.36362 .31126 m .3364 .3355 L .34844 .34065 L p F P
.505 .664 .505 r
s
.507 .693 .498 r
.34844 .34065 m .37301 .31621 L .36362 .31126 L p F P
.505 .664 .505 r
s
.29 .335 .234 r
.31326 .63642 m .3364 .6645 L .34844 .65935 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.37301 .68379 m .34844 .65935 L .3364 .6645 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.62699 .31621 m .65156 .34065 L .6636 .3355 L p F P
.505 .664 .505 r
s
.552 .747 .586 r
.68674 .36358 m .6636 .3355 L .65156 .34065 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.65156 .65935 m .62699 .68379 L .63638 .68874 L p F P
.505 .664 .505 r
s
.248 .276 .212 r
.63638 .68874 m .6636 .6645 L .65156 .65935 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.46851 .27044 m .43884 .28266 L .44812 .28512 L p F P
.505 .664 .505 r
s
.571 .789 .588 r
.44812 .28512 m .47314 .27179 L .46851 .27044 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.47314 .72821 m .44812 .71488 L .43884 .71734 L p F P
.505 .664 .505 r
s
.251 .268 .197 r
.44812 .71488 m .47314 .72821 L .47886 .72711 L p F P
.505 .664 .505 r
s
.6 .825 .627 r
.55188 .28512 m .52686 .27179 L .52114 .27289 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.52686 .27179 m .55188 .28512 L .56116 .28266 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.55188 .71488 m .52686 .72821 L .53149 .72956 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.53149 .72956 m .56116 .71734 L .55188 .71488 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.39434 .29148 m .36362 .31126 L .37301 .31621 L p F P
.505 .664 .505 r
s
.518 .715 .52 r
.37301 .31621 m .40102 .29574 L .39434 .29148 L p F P
.505 .664 .505 r
s
.265 .296 .212 r
.3364 .6645 m .36362 .68874 L .37301 .68379 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.40102 .70426 m .37301 .68379 L .36362 .68874 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.59898 .29574 m .62699 .31621 L .63638 .31126 L p F P
.505 .664 .505 r
s
.56 .765 .598 r
.6636 .3355 m .63638 .31126 L .62699 .31621 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.62699 .68379 m .59898 .70426 L .60566 .70852 L p F P
.505 .664 .505 r
s
.205 .213 .161 r
.60566 .70852 m .63638 .68874 L .62699 .68379 L p F P
.505 .664 .505 r
s
.555 .774 .586 r
.5 .27438 m .5 .26345 L .49256 .27421 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50744 .27421 m .5 .26345 L .5 .27438 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .5 .72562 L .49256 .72579 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50744 .72579 L .5 .72562 L closepath p F P
.505 .664 .505 r
s
.55 .764 .57 r
.46519 .2689 m .43196 .2798 L .43884 .28266 L p F P
.505 .664 .505 r
s
.55 .764 .57 r
.43884 .28266 m .46851 .27044 L .46519 .2689 L p F P
.505 .664 .505 r
s
.252 .271 .199 r
.40102 .70426 m .43196 .7202 L .43884 .71734 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.46851 .72956 m .43884 .71734 L .43196 .7202 L p F P
.505 .664 .505 r
s
.233 .243 .182 r
.43884 .71734 m .46851 .72956 L .47314 .72821 L p F P
.505 .664 .505 r
s
.586 .81 .618 r
.56116 .28266 m .53149 .27044 L .52686 .27179 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.53149 .27044 m .56116 .28266 L .56804 .2798 L p F P
.505 .664 .505 r
s
.591 .812 .624 r
.59898 .29574 m .56804 .2798 L .56116 .28266 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.56116 .71734 m .53149 .72956 L .53481 .7311 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.53481 .7311 m .56804 .7202 L .56116 .71734 L p F P
.505 .664 .505 r
s
.553 .771 .583 r
.49256 .27421 m .5 .26345 L .48542 .27371 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51458 .27371 m .5 .26345 L .50744 .27421 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .49256 .72579 L .48542 .72629 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51458 .72629 L .50744 .72579 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7089 .59614 m
.7091 .59664 L
s
.5 Mabswid
.549 .766 .579 r
.48542 .27371 m .5 .26345 L .47886 .27289 L closepath p F P
.505 .664 .505 r
s
.552 .771 .585 r
.52114 .27289 m .5 .26345 L .51458 .27371 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .48542 .72629 L .47886 .72711 L closepath p F P
.505 .664 .505 r
s
.197 .204 .155 r
.5 .73655 m .52114 .72711 L .51458 .72629 L closepath p F P
.505 .664 .505 r
s
.524 .728 .536 r
.42783 .27666 m .39434 .29148 L .40102 .29574 L p F P
.505 .664 .505 r
s
.524 .728 .536 r
.40102 .29574 m .43196 .2798 L .42783 .27666 L p F P
.505 .664 .505 r
s
.238 .255 .188 r
.36362 .68874 m .39434 .70852 L .40102 .70426 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.43196 .7202 m .40102 .70426 L .39434 .70852 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.56804 .2798 m .59898 .29574 L .60566 .29148 L p F P
.505 .664 .505 r
s
.562 .773 .602 r
.63638 .31126 m .60566 .29148 L .59898 .29574 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.59898 .70426 m .56804 .7202 L .57217 .72334 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.57217 .72334 m .60566 .70852 L .59898 .70426 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28359 .41993 m
.28517 .41864 L
s
.5 Mabswid
.543 .759 .573 r
.47886 .27289 m .5 .26345 L .47314 .27179 L closepath p F P
.505 .664 .505 r
s
.548 .765 .582 r
.52686 .27179 m .5 .26345 L .52114 .27289 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .47886 .72711 L .47314 .72821 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .52686 .72821 L .52114 .72711 L closepath p F P
.505 .664 .505 r
s
.535 .75 .567 r
.47314 .27179 m .5 .26345 L .46851 .27044 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .47314 .72821 L .46851 .72956 L closepath p F P
.505 .664 .505 r
s
.541 .758 .578 r
.53149 .27044 m .5 .26345 L .52686 .27179 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .53149 .72956 L .52686 .72821 L closepath p F P
.505 .664 .505 r
s
.279 .362 .238 r
.26206 .46211 m .25902 .5 L .2702 .5 L p F P
.505 .664 .505 r
s
.279 .362 .238 r
.2702 .5 m .27297 .46384 L .26206 .46211 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.27297 .53616 m .2702 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.72703 .46384 m .7298 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.7298 .5 m .72703 .53616 L .73794 .53789 L p F P
.505 .664 .505 r
s
.308 .394 .33 r
.73794 .53789 m .74098 .5 L .7298 .5 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27109 .42521 m .26206 .46211 L .27297 .46384 L p F P
.505 .664 .505 r
s
.295 .391 .254 r
.27297 .46384 m .2812 .42852 L .27109 .42521 L p F P
.505 .664 .505 r
s
.263 .332 .222 r
.25902 .5 m .26206 .53789 L .27297 .53616 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.2812 .57148 m .27297 .53616 L .26206 .53789 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.7188 .42852 m .72703 .46384 L .73794 .46211 L p F P
.505 .664 .505 r
s
.344 .45 .374 r
.74098 .5 m .73794 .46211 L .72703 .46384 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72703 .53616 m .7188 .57148 L .72891 .57479 L p F P
.505 .664 .505 r
s
.272 .337 .284 r
.72891 .57479 m .73794 .53789 L .72703 .53616 L p F P
.505 .664 .505 r
s
.325 .44 .292 r
.28585 .39028 m .27109 .42521 L .2812 .42852 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.28197 .42216 m
.28359 .41993 L
s
.5 Mabswid
.325 .44 .292 r
.2812 .42852 m .29473 .39483 L .28585 .39028 L p F P
.505 .664 .505 r
s
.247 .301 .206 r
.26206 .53789 m .27109 .57479 L .2812 .57148 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.29473 .60517 m .2812 .57148 L .27109 .57479 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.70527 .39483 m .7188 .42852 L .72891 .42521 L p F P
.505 .664 .505 r
s
.379 .505 .416 r
.73794 .46211 m .72891 .42521 L .7188 .42852 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.7188 .57148 m .70527 .60517 L .71415 .60972 L p F P
.505 .664 .505 r
s
.236 .281 .238 r
.71415 .60972 m .72891 .57479 L .7188 .57148 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.46333 .26722 m .42783 .27666 L .43196 .2798 L p F P
.505 .664 .505 r
s
.524 .733 .547 r
.43196 .2798 m .46519 .2689 L .46333 .26722 L p F P
.505 .664 .505 r
s
.21 .216 .164 r
.39434 .70852 m .42783 .72334 L .43196 .7202 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.46519 .7311 m .43196 .7202 L .42783 .72334 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.43196 .7202 m .46519 .7311 L .46851 .72956 L p F P
.505 .664 .505 r
s
.568 .789 .604 r
.56804 .2798 m .53481 .2689 L .53149 .27044 L p F P
.505 .664 .505 r
s
.544 .761 .586 r
.53481 .2689 m .56804 .2798 L .57217 .27666 L p F P
.505 .664 .505 r
s
.557 .772 .598 r
.60566 .29148 m .57217 .27666 L .56804 .2798 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.56804 .7202 m .53481 .7311 L .53667 .73278 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.53667 .73278 m .57217 .72334 L .56804 .7202 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.30594 .35823 m .28585 .39028 L .29473 .39483 L p F P
.505 .664 .505 r
s
.36 .494 .337 r
.29473 .39483 m .31326 .36358 L .30594 .35823 L p F P
.505 .664 .505 r
s
.23 .27 .189 r
.27109 .57479 m .28585 .60972 L .29473 .60517 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.31326 .63642 m .29473 .60517 L .28585 .60972 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.68674 .36358 m .70527 .39483 L .71415 .39028 L p F P
.505 .664 .505 r
s
.411 .555 .454 r
.72891 .42521 m .71415 .39028 L .70527 .39483 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.70527 .60517 m .68674 .63642 L .69406 .64177 L p F P
.505 .664 .505 r
s
.2 .226 .192 r
.69406 .64177 m .71415 .60972 L .70527 .60517 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.33081 .32987 m .30594 .35823 L .31326 .36358 L p F P
.505 .664 .505 r
s
.394 .546 .382 r
.31326 .36358 m .3364 .3355 L .33081 .32987 L p F P
.505 .664 .505 r
s
.213 .24 .173 r
.28585 .60972 m .30594 .64177 L .31326 .63642 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.3364 .6645 m .31326 .63642 L .30594 .64177 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.6636 .3355 m .68674 .36358 L .69406 .35823 L p F P
.505 .664 .505 r
s
.44 .601 .487 r
.71415 .39028 m .69406 .35823 L .68674 .36358 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.68674 .63642 m .6636 .6645 L .66919 .67013 L p F P
.505 .664 .505 r
s
.178 .195 .159 r
.66919 .67013 m .69406 .64177 L .68674 .63642 L p F P
.505 .664 .505 r
s
.527 .74 .559 r
.46851 .27044 m .5 .26345 L .46519 .2689 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .46851 .72956 L .46519 .7311 L closepath p F P
.505 .664 .505 r
s
.533 .749 .571 r
.53481 .2689 m .5 .26345 L .53149 .27044 L closepath p F P
.505 .664 .505 r
s
.183 .19 .145 r
.5 .73655 m .53481 .7311 L .53149 .72956 L closepath p F P
.505 .664 .505 r
s
.425 .593 .423 r
.35976 .30591 m .33081 .32987 L .3364 .3355 L p F P
.505 .664 .505 r
s
.425 .593 .423 r
.3364 .3355 m .36362 .31126 L .35976 .30591 L p F P
.505 .664 .505 r
s
.197 .211 .157 r
.30594 .64177 m .33081 .67013 L .3364 .6645 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.36362 .68874 m .3364 .6645 L .33081 .67013 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.6636 .6645 m .63638 .68874 L .64024 .69409 L p F P
.505 .664 .505 r
s
.157 .167 .128 r
.64024 .69409 m .66919 .67013 L .6636 .6645 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.63638 .31126 m .6636 .3355 L .66919 .32987 L p F P
.505 .664 .505 r
s
.465 .641 .516 r
.69406 .35823 m .66919 .32987 L .6636 .3355 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.39203 .28693 m .35976 .30591 L .36362 .31126 L p F P
.505 .664 .505 r
s
.452 .635 .461 r
.36362 .31126 m .39434 .29148 L .39203 .28693 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.33081 .67013 m .35976 .69409 L .36362 .68874 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.39434 .70852 m .36362 .68874 L .35976 .69409 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.60566 .29148 m .63638 .31126 L .64024 .30591 L p F P
.505 .664 .505 r
s
.485 .675 .538 r
.66919 .32987 m .64024 .30591 L .63638 .31126 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.63638 .68874 m .60566 .70852 L .60797 .71307 L p F P
.505 .664 .505 r
s
.16 .169 .129 r
.60797 .71307 m .64024 .69409 L .63638 .68874 L p F P
.505 .664 .505 r
s
.517 .728 .55 r
.46519 .2689 m .5 .26345 L .46333 .26722 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42783 .72334 m .46333 .73278 L .46519 .7311 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .46519 .7311 L .46333 .73278 L closepath p F P
.505 .664 .505 r
s
.524 .738 .564 r
.53667 .26722 m .5 .26345 L .53481 .2689 L closepath p F P
.505 .664 .505 r
s
.544 .761 .586 r
.57217 .27666 m .53667 .26722 L .53481 .2689 L p F P
.505 .664 .505 r
s
.176 .185 .14 r
.5 .73655 m .53667 .73278 L .53481 .7311 L closepath p F P
.505 .664 .505 r
s
.475 .67 .494 r
.42676 .27336 m .39203 .28693 L .39434 .29148 L p F P
.505 .664 .505 r
s
.475 .67 .494 r
.39434 .29148 m .42783 .27666 L .42676 .27336 L p F P
.505 .664 .505 r
s
.183 .19 .145 r
.35976 .69409 m .39203 .71307 L .39434 .70852 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.42783 .72334 m .39434 .70852 L .39203 .71307 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.60566 .70852 m .57217 .72334 L .57324 .72664 L p F P
.505 .664 .505 r
s
.163 .172 .131 r
.57324 .72664 m .60797 .71307 L .60566 .70852 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.57217 .27666 m .60566 .29148 L .60797 .28693 L p F P
.505 .664 .505 r
s
.501 .7 .553 r
.64024 .30591 m .60797 .28693 L .60566 .29148 L p F P
.505 .664 .505 r
s
.18 .188 .143 r
.39203 .71307 m .42676 .72664 L .42783 .72334 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.46333 .73278 m .42783 .72334 L .42676 .72664 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.46306 .26549 m .42676 .27336 L .42783 .27666 L p F P
.505 .664 .505 r
s
.493 .697 .521 r
.42783 .27666 m .46333 .26722 L .46306 .26549 L p F P
.505 .664 .505 r
s
.515 .726 .562 r
.53667 .26722 m .57217 .27666 L .57324 .27336 L p F P
.505 .664 .505 r
s
.511 .718 .561 r
.60797 .28693 m .57324 .27336 L .57217 .27666 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.57217 .72334 m .53667 .73278 L .53694 .73451 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.53694 .73451 m .57324 .72664 L .57217 .72334 L p F P
.505 .664 .505 r
s
.506 .715 .541 r
.46333 .26722 m .5 .26345 L .46306 .26549 L closepath p F P
.505 .664 .505 r
s
.177 .185 .14 r
.42676 .72664 m .46306 .73451 L .46333 .73278 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .46333 .73278 L .46306 .73451 L closepath p F P
.505 .664 .505 r
s
.514 .725 .555 r
.53694 .26549 m .5 .26345 L .53667 .26722 L closepath p F P
.505 .664 .505 r
s
.515 .726 .562 r
.57324 .27336 m .53694 .26549 L .53667 .26722 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .53694 .73451 L .53667 .73278 L closepath p F P
.505 .664 .505 r
s
.149 .16 .121 r
.5 .73655 m .52817 .73933 L .53263 .73787 L closepath p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .73655 m .5224 .74056 L .52817 .73933 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .51556 .74148 L .5224 .74056 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50797 .74206 L .51556 .74148 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .5 .74225 L .50797 .74206 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49203 .74206 L .5 .74225 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .48444 .74148 L .49203 .74206 L closepath p F P
.505 .664 .505 r
s
.141 .152 .116 r
.5 .73655 m .4776 .74056 L .48444 .74148 L closepath p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .73655 m .47183 .73933 L .4776 .74056 L closepath p F P
.505 .664 .505 r
s
.152 .162 .123 r
.5 .73655 m .46737 .73787 L .47183 .73933 L closepath p F P
.505 .664 .505 r
s
.159 .168 .128 r
.5 .73655 m .46442 .73624 L .46737 .73787 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .46306 .73451 L .46442 .73624 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .53558 .73624 L .53694 .73451 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .53263 .73787 L .53558 .73624 L closepath p F P
.505 .664 .505 r
s
.503 .712 .546 r
.53558 .26376 m .5 .26345 L .53694 .26549 L closepath p F P
.505 .664 .505 r
s
.496 .702 .532 r
.46306 .26549 m .5 .26345 L .46442 .26376 L closepath p F P
.505 .664 .505 r
s
.492 .698 .536 r
.53263 .26213 m .5 .26345 L .53558 .26376 L closepath p F P
.505 .664 .505 r
s
.485 .689 .523 r
.46442 .26376 m .5 .26345 L .46737 .26213 L closepath p F P
.505 .664 .505 r
s
.481 .685 .526 r
.52817 .26067 m .5 .26345 L .53263 .26213 L closepath p F P
.505 .664 .505 r
s
.471 .673 .518 r
.5224 .25944 m .5 .26345 L .52817 .26067 L closepath p F P
.505 .664 .505 r
s
.475 .677 .515 r
.46737 .26213 m .5 .26345 L .47183 .26067 L closepath p F P
.505 .664 .505 r
s
.463 .663 .51 r
.51556 .25852 m .5 .26345 L .5224 .25944 L closepath p F P
.505 .664 .505 r
s
.466 .667 .508 r
.47183 .26067 m .5 .26345 L .4776 .25944 L closepath p F P
.505 .664 .505 r
s
.457 .656 .504 r
.50797 .25794 m .5 .26345 L .51556 .25852 L closepath p F P
.505 .664 .505 r
s
.459 .658 .503 r
.4776 .25944 m .5 .26345 L .48444 .25852 L closepath p F P
.505 .664 .505 r
s
.453 .652 .5 r
.5 .25775 m .5 .26345 L .50797 .25794 L closepath p F P
.505 .664 .505 r
s
.455 .653 .499 r
.48444 .25852 m .5 .26345 L .49203 .25794 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49203 .25794 m .5 .26345 L .5 .25775 L closepath p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27418 .41706 m
.27471 .41664 L
s
.26717 .43899 m
.26748 .43995 L
s
.5 Mabswid
.155 .165 .125 r
.42894 .72997 m .46442 .73624 L .46306 .73451 L p F P
.505 .664 .505 r
s
.155 .165 .125 r
.46306 .73451 m .42676 .72664 L .42894 .72997 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.42676 .27336 m .46306 .26549 L .46442 .26376 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.57324 .72664 m .53694 .73451 L .53558 .73624 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.53694 .26549 m .57324 .27336 L .57106 .27003 L p F P
.505 .664 .505 r
s
.481 .685 .533 r
.57106 .27003 m .53558 .26376 L .53694 .26549 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71989 .59869 m
.72065 .59466 L
s
.7277 .57765 m
.72912 .57534 L
s
.5 Mabswid
.144 .154 .117 r
.3945 .71771 m .42894 .72997 L .42676 .72664 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.42676 .72664 m .39203 .71307 L .3945 .71771 L p F P
.505 .664 .505 r
s
.459 .655 .491 r
.46442 .26376 m .42894 .27003 L .42676 .27336 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.39203 .28693 m .42676 .27336 L .42894 .27003 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.57324 .27336 m .60797 .28693 L .6055 .28229 L p F P
.505 .664 .505 r
s
.452 .646 .511 r
.6055 .28229 m .57106 .27003 L .57324 .27336 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60797 .71307 m .57324 .72664 L .57106 .72997 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.53558 .73624 m .57106 .72997 L .57324 .72664 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27249 .42063 m
.27418 .41706 L
s
.27134 .42462 m
.27184 .42249 L
s
.26717 .43899 m
.26781 .43528 L
s
.27184 .42249 m
.27249 .42063 L
s
0 0 0 r
.7198 .6009 m
.71989 .59869 L
s
.5 Mabswid
.132 .144 .11 r
.36207 .69962 m .3945 .71771 L .39203 .71307 L p F P
.505 .664 .505 r
s
.132 .144 .11 r
.39203 .71307 m .35976 .69409 L .36207 .69962 L p F P
.505 .664 .505 r
s
.415 .597 .441 r
.42894 .27003 m .3945 .28229 L .39203 .28693 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.35976 .30591 m .39203 .28693 L .3945 .28229 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.64024 .69409 m .60797 .71307 L .6055 .71771 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.57106 .72997 m .6055 .71771 L .60797 .71307 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.60797 .28693 m .64024 .30591 L .63793 .30038 L p F P
.505 .664 .505 r
s
.417 .598 .481 r
.63793 .30038 m .6055 .28229 L .60797 .28693 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.43439 .73316 m .46737 .73787 L .46442 .73624 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.46442 .73624 m .42894 .72997 L .43439 .73316 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.42894 .27003 m .46442 .26376 L .46737 .26213 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.57106 .72997 m .53558 .73624 L .53263 .73787 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.53558 .26376 m .57106 .27003 L .56561 .26684 L p F P
.505 .664 .505 r
s
.444 .639 .5 r
.56561 .26684 m .53263 .26213 L .53558 .26376 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72912 .57534 m
.73064 .57354 L
s
.5 Mabswid
.122 .134 .102 r
.33261 .67601 m .36207 .69962 L .35976 .69409 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.35976 .69409 m .33081 .67013 L .33261 .67601 L p F P
.505 .664 .505 r
s
.366 .529 .384 r
.3945 .28229 m .36207 .30038 L .35976 .30591 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.33081 .32987 m .35976 .30591 L .36207 .30038 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.66919 .67013 m .64024 .69409 L .63793 .69962 L p F P
.505 .664 .505 r
s
.108 .121 .092 r
.6055 .71771 m .63793 .69962 L .64024 .69409 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.64024 .30591 m .66919 .32987 L .66739 .32399 L p F P
.505 .664 .505 r
s
.376 .54 .443 r
.66739 .32399 m .63793 .30038 L .64024 .30591 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.30703 .64742 m .33261 .67601 L .33081 .67013 L p F P
.505 .664 .505 r
s
.112 .125 .095 r
.33081 .67013 m .30594 .64177 L .30703 .64742 L p F P
.505 .664 .505 r
s
.312 .453 .321 r
.36207 .30038 m .33261 .32399 L .33081 .32987 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.30594 .35823 m .33081 .32987 L .33261 .32399 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.66919 .32987 m .69406 .35823 L .69297 .35258 L p F P
.505 .664 .505 r
s
.332 .476 .399 r
.69297 .35258 m .66739 .32399 L .66919 .32987 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.69406 .64177 m .66919 .67013 L .66739 .67601 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.63793 .69962 m .66739 .67601 L .66919 .67013 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.443 .73607 m .47183 .73933 L .46737 .73787 L p F P
.505 .664 .505 r
s
.11 .123 .094 r
.46737 .73787 m .43439 .73316 L .443 .73607 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.43439 .26684 m .46737 .26213 L .47183 .26067 L p F P
.505 .664 .505 r
s
.422 .61 .459 r
.46737 .26213 m .43439 .26684 L .42894 .27003 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.53263 .73787 m .56561 .73316 L .57106 .72997 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.56561 .73316 m .53263 .73787 L .52817 .73933 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.53263 .26213 m .56561 .26684 L .557 .26393 L p F P
.505 .664 .505 r
s
.405 .591 .465 r
.557 .26393 m .52817 .26067 L .53263 .26213 L p F P
.505 .664 .505 r
s
.256 .373 .255 r
.33261 .32399 m .30703 .35258 L .30594 .35823 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.28585 .39028 m .30594 .35823 L .30703 .35258 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.28616 .61456 m .30703 .64742 L .30594 .64177 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.30594 .64177 m .28585 .60972 L .28616 .61456 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.69406 .35823 m .71415 .39028 L .71384 .38544 L p F P
.505 .664 .505 r
s
.285 .408 .351 r
.71384 .38544 m .69297 .35258 L .69406 .35823 L p F P
.505 .664 .505 r
s
.075 .096 .079 r
.71415 .60972 m .69406 .64177 L .69297 .64742 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66739 .67601 m .69297 .64742 L .69406 .64177 L p F P
.505 .664 .505 r
s
.199 .292 .188 r
.30703 .35258 m .28616 .38544 L .28585 .39028 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.27109 .42521 m .28585 .39028 L .28616 .38544 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.27072 .57833 m .28616 .61456 L .28585 .60972 L p F P
.505 .664 .505 r
s
.097 .112 .085 r
.28585 .60972 m .27109 .57479 L .27072 .57833 L p F P
.505 .664 .505 r
s
.092 .12 .107 r
.72891 .57479 m .71415 .60972 L .71384 .61456 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7198 .6009 m
.72069 .60161 L
s
.5 Mabswid
.075 .096 .079 r
.69297 .64742 m .71384 .61456 L .71415 .60972 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.71415 .39028 m .72891 .42521 L .72928 .42167 L p F P
.505 .664 .505 r
s
.241 .34 .302 r
.72928 .42167 m .71384 .38544 L .71415 .39028 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.40194 .72224 m .43439 .73316 L .42894 .72997 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.42894 .72997 m .3945 .71771 L .40194 .72224 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.3945 .28229 m .42894 .27003 L .43439 .26684 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.6055 .71771 m .57106 .72997 L .56561 .73316 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.57106 .27003 m .6055 .28229 L .59806 .27776 L p F P
.505 .664 .505 r
s
.384 .561 .45 r
.59806 .27776 m .56561 .26684 L .57106 .27003 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.26123 .53976 m .27072 .57833 L .27109 .57479 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.27109 .57479 m .26206 .53789 L .26123 .53976 L p F P
.505 .664 .505 r
s
.165 .239 .153 r
.28616 .38544 m .27072 .42167 L .27109 .42521 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27105 .41759 m
.27197 .41586 L
s
.27197 .41586 m
.27248 .41382 L
s
.5 Mabswid
.141 .198 .13 r
.26206 .46211 m .27109 .42521 L .27072 .42167 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.72891 .42521 m .73794 .46211 L .73877 .46024 L p F P
.505 .664 .505 r
s
.201 .277 .255 r
.73877 .46024 m .72928 .42167 L .72891 .42521 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.73794 .53789 m .72891 .57479 L .72928 .57833 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73064 .57354 m
.73166 .57408 L
s
.5 Mabswid
.092 .12 .107 r
.71384 .61456 m .72928 .57833 L .72891 .57479 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72069 .60161 m
.72198 .60032 L
s
.5 Mabswid
.141 .198 .13 r
.27072 .42167 m .26123 .46024 L .26206 .46211 L p F P
.505 .664 .505 r
s
.12 .16 .109 r
.25902 .5 m .26206 .46211 L .26123 .46024 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.25803 .5 m .26123 .53976 L .26206 .53789 L p F P
.505 .664 .505 r
s
.102 .126 .091 r
.26206 .53789 m .25902 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.73794 .46211 m .74098 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
.161 .212 .205 r
.74197 .5 m .73877 .46024 L .73794 .46211 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.74098 .5 m .73794 .53789 L .73877 .53976 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.72928 .57833 m .73877 .53976 L .73794 .53789 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73146 .57663 m
.73166 .57408 L
s
.5 Mabswid
.12 .16 .109 r
.26123 .46024 m .25803 .5 L .25902 .5 L p F P
.505 .664 .505 r
s
.138 .181 .173 r
.73877 .53976 m .74197 .5 L .74098 .5 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.45445 .73853 m .4776 .74056 L .47183 .73933 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.47183 .73933 m .443 .73607 L .45445 .73853 L p F P
.505 .664 .505 r
s
.101 .115 .087 r
.52817 .73933 m .557 .73607 L .56561 .73316 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.557 .73607 m .52817 .73933 L .5224 .74056 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.443 .26393 m .47183 .26067 L .4776 .25944 L p F P
.505 .664 .505 r
s
.386 .565 .428 r
.47183 .26067 m .443 .26393 L .43439 .26684 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.52817 .26067 m .557 .26393 L .54555 .26147 L p F P
.505 .664 .505 r
s
.369 .546 .431 r
.54555 .26147 m .5224 .25944 L .52817 .26067 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.27156 .41556 m
.27248 .41382 L
s
.27105 .41759 m
.27156 .41556 L
s
.26116 .45228 m
.26782 .42694 L
s
0 0 0 r
.72198 .60032 m
.724 .59715 L
s
.73038 .58131 m
.73146 .57663 L
s
.5 Mabswid
.082 .097 .074 r
.5224 .74056 m .54555 .73853 L .557 .73607 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.54555 .73853 m .5224 .74056 L .51556 .74148 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.46823 .7404 m .48444 .74148 L .4776 .74056 L p F P
.505 .664 .505 r
s
.072 .089 .067 r
.4776 .74056 m .45445 .73853 L .46823 .7404 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.5224 .25944 m .54555 .26147 L .53177 .2596 L p F P
.505 .664 .505 r
s
.338 .507 .401 r
.53177 .2596 m .51556 .25852 L .5224 .25944 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.45445 .26147 m .4776 .25944 L .48444 .25852 L p F P
.505 .664 .505 r
s
.353 .524 .4 r
.4776 .25944 m .45445 .26147 L .443 .26393 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.724 .59715 m
.7266 .59167 L
s
.5 Mabswid
.075 .092 .07 r
.37097 .70507 m .40194 .72224 L .3945 .71771 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.3945 .71771 m .36207 .69962 L .37097 .70507 L p F P
.505 .664 .505 r
s
.348 .513 .382 r
.43439 .26684 m .40194 .27776 L .3945 .28229 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.36207 .30038 m .3945 .28229 L .40194 .27776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63793 .69962 m .6055 .71771 L .59806 .72224 L p F P
.505 .664 .505 r
s
.087 .102 .077 r
.56561 .73316 m .59806 .72224 L .6055 .71771 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.6055 .28229 m .63793 .30038 L .62903 .29493 L p F P
.505 .664 .505 r
s
.32 .474 .391 r
.62903 .29493 m .59806 .27776 L .6055 .28229 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7282 .5877 m
.73038 .58131 L
s
.5 Mabswid
.066 .083 .063 r
.51556 .74148 m .53177 .7404 L .54555 .73853 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.53177 .7404 m .51556 .74148 L .50797 .74206 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48368 .74157 m .49203 .74206 L .48444 .74148 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.48444 .74148 m .46823 .7404 L .48368 .74157 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51556 .25852 m .53177 .2596 L .51632 .25843 L p F P
.505 .664 .505 r
s
.315 .478 .377 r
.51632 .25843 m .50797 .25794 L .51556 .25852 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.46823 .2596 m .48444 .25852 L .49203 .25794 L p F P
.505 .664 .505 r
s
.326 .491 .378 r
.48444 .25852 m .46823 .2596 L .45445 .26147 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7266 .59167 m
.7282 .5877 L
s
.5 Mabswid
.056 .074 .056 r
.50797 .74206 m .51632 .74157 L .53177 .7404 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.51632 .74157 m .50797 .74206 L .5 .74225 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.5 .74197 m .5 .74225 L .49203 .74206 L p F P
.505 .664 .505 r
s
.317 .48 .377 r
.49203 .74206 m .48368 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50797 .25794 m .51632 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.5 .25803 m .5 .25775 L .50797 .25794 L p F P
.505 .664 .505 r
s
.307 .468 .363 r
.49203 .25794 m .48368 .25843 L .46823 .2596 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.48368 .25843 m .49203 .25794 L .5 .25775 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.41427 .7264 m .443 .73607 L .43439 .73316 L p F P
.505 .664 .505 r
s
.064 .081 .062 r
.43439 .73316 m .40194 .72224 L .41427 .7264 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.40194 .27776 m .43439 .26684 L .443 .26393 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .56561 .73316 L .557 .73607 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.56561 .26684 m .59806 .27776 L .58573 .2736 L p F P
.505 .664 .505 r
s
.319 .478 .388 r
.58573 .2736 m .557 .26393 L .56561 .26684 L p F P
.505 .664 .505 r
s
.315 .477 .372 r
.5 .74225 m .5 .74197 L .51632 .74157 L p F P
.505 .664 .505 r
s
.059 .077 .058 r
.5 .25775 m .5 .25803 L .48368 .25843 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.34248 .68188 m .37097 .70507 L .36207 .69962 L p F P
.505 .664 .505 r
s
.329 .482 .401 r
.36207 .69962 m .33261 .67601 L .34248 .68188 L p F P
.505 .664 .505 r
s
.265 .403 .294 r
.40194 .27776 m .37097 .29493 L .36207 .30038 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.33261 .32399 m .36207 .30038 L .37097 .29493 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.59806 .72224 m .62903 .70507 L .63793 .69962 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.66739 .67601 m .63793 .69962 L .62903 .70507 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.63793 .30038 m .66739 .32399 L .65752 .31812 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.65752 .31812 m .62903 .29493 L .63793 .30038 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.43113 .72997 m .45445 .73853 L .443 .73607 L p F P
.505 .664 .505 r
s
.378 .556 .442 r
.443 .73607 m .41427 .7264 L .43113 .72997 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.557 .73607 m .58573 .7264 L .59806 .72224 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.58573 .7264 m .557 .73607 L .54555 .73853 L p F P
.505 .664 .505 r
s
.279 .427 .321 r
.443 .26393 m .41427 .2736 L .40194 .27776 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.41427 .2736 m .443 .26393 L .45445 .26147 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.557 .26393 m .58573 .2736 L .56887 .27003 L p F P
.505 .664 .505 r
s
.097 .111 .085 r
.56887 .27003 m .54555 .26147 L .557 .26393 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72354 .60087 m
.72527 .59688 L
s
.72527 .59688 m
.72693 .593 L
s
.73238 .57873 m
.73093 .58271 L
s
.72261 .60295 m
.72354 .60087 L
s
.5 Mabswid
.357 .51 .423 r
.31748 .65312 m .34248 .68188 L .33261 .67601 L p F P
.505 .664 .505 r
s
.357 .51 .423 r
.33261 .67601 m .30703 .64742 L .31748 .65312 L p F P
.505 .664 .505 r
s
.064 .081 .061 r
.37097 .29493 m .34248 .31812 L .33261 .32399 L p F P
.505 .664 .505 r
s
.087 .102 .078 r
.30703 .35258 m .33261 .32399 L .34248 .31812 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.69297 .64742 m .66739 .67601 L .65752 .68188 L p F P
.505 .664 .505 r
s
.266 .398 .282 r
.62903 .70507 m .65752 .68188 L .66739 .67601 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.66739 .32399 m .69297 .35258 L .68252 .34688 L p F P
.505 .664 .505 r
s
.122 .135 .102 r
.68252 .34688 m .65752 .31812 L .66739 .32399 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7215 .60525 m
.72261 .60295 L
s
.5 Mabswid
.394 .571 .46 r
.38653 .71016 m .41427 .7264 L .40194 .72224 L p F P
.505 .664 .505 r
s
.394 .571 .46 r
.40194 .72224 m .37097 .70507 L .38653 .71016 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.37097 .29493 m .40194 .27776 L .41427 .2736 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.62903 .70507 m .59806 .72224 L .58573 .7264 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.59806 .27776 m .62903 .29493 L .61347 .28984 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.61347 .28984 m .58573 .2736 L .59806 .27776 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73238 .57873 m
.73292 .57686 L
s
.72089 .60599 m
.7215 .60525 L
s
.5 Mabswid
.087 .102 .078 r
.34248 .31812 m .31748 .34688 L .30703 .35258 L p F P
.505 .664 .505 r
s
.131 .152 .126 r
.28616 .38544 m .30703 .35258 L .31748 .34688 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.2969 .61949 m .31748 .65312 L .30703 .64742 L p F P
.505 .664 .505 r
s
.369 .516 .428 r
.30703 .64742 m .28616 .61456 L .2969 .61949 L p F P
.505 .664 .505 r
s
.351 .519 .391 r
.54555 .73853 m .56887 .72997 L .58573 .7264 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.56887 .72997 m .54555 .73853 L .53177 .7404 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45177 .7327 m .46823 .7404 L .45445 .73853 L p F P
.505 .664 .505 r
s
.427 .618 .485 r
.45445 .73853 m .43113 .72997 L .45177 .7327 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54555 .26147 m .56887 .27003 L .54823 .2673 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.54823 .2673 m .53177 .2596 L .54555 .26147 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.43113 .27003 m .45445 .26147 L .46823 .2596 L p F P
.505 .664 .505 r
s
.084 .099 .076 r
.45445 .26147 m .43113 .27003 L .41427 .2736 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.69297 .35258 m .71384 .38544 L .7031 .38051 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.7031 .38051 m .68252 .34688 L .69297 .35258 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.71384 .61456 m .69297 .64742 L .68252 .65312 L p F P
.505 .664 .505 r
s
.284 .411 .284 r
.65752 .68188 m .68252 .65312 L .69297 .64742 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73237 .57743 m
.73292 .57686 L
s
.5 Mabswid
.131 .152 .126 r
.31748 .34688 m .2969 .38051 L .28616 .38544 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.27072 .42167 m .28616 .38544 L .2969 .38051 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28156 .58196 m .2969 .61949 L .28616 .61456 L p F P
.505 .664 .505 r
s
.367 .503 .418 r
.28616 .61456 m .27072 .57833 L .28156 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.72928 .57833 m .71384 .61456 L .7031 .61949 L p F P
.505 .664 .505 r
s
.288 .406 .273 r
.68252 .65312 m .7031 .61949 L .71384 .61456 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71384 .38544 m .72928 .42167 L .71844 .41804 L p F P
.505 .664 .505 r
s
.181 .205 .148 r
.71844 .41804 m .7031 .38051 L .71384 .38544 L p F P
.505 .664 .505 r
s
.407 .591 .446 r
.53177 .7404 m .54823 .7327 L .56887 .72997 L p F P
.505 .664 .505 r
s
.446 .641 .486 r
.54823 .7327 m .53177 .7404 L .51632 .74157 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.47517 .73443 m .48368 .74157 L .46823 .7404 L p F P
.505 .664 .505 r
s
.458 .657 .509 r
.46823 .7404 m .45177 .7327 L .47517 .73443 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53177 .2596 m .54823 .2673 L .52483 .26557 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.52483 .26557 m .51632 .25843 L .53177 .2596 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.45177 .2673 m .46823 .2596 L .48368 .25843 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.46823 .2596 m .45177 .2673 L .43113 .27003 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27208 .54168 m .28156 .58196 L .27072 .57833 L p F P
.505 .664 .505 r
s
.351 .472 .394 r
.27072 .57833 m .26123 .53976 L .27208 .54168 L p F P
.505 .664 .505 r
s
.177 .207 .182 r
.2969 .38051 m .28156 .41804 L .27072 .42167 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.26123 .46024 m .27072 .42167 L .28156 .41804 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.36072 .68742 m .38653 .71016 L .37097 .70507 L p F P
.505 .664 .505 r
s
.455 .642 .514 r
.37097 .70507 m .34248 .68188 L .36072 .68742 L p F P
.505 .664 .505 r
s
.093 .108 .082 r
.41427 .2736 m .38653 .28984 L .37097 .29493 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.34248 .31812 m .37097 .29493 L .38653 .28984 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72928 .42167 m .73877 .46024 L .72792 .45832 L p F P
.505 .664 .505 r
s
.217 .261 .181 r
.72792 .45832 m .71844 .41804 L .72928 .42167 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.73877 .53976 m .72928 .57833 L .71844 .58196 L p F P
.505 .664 .505 r
s
.279 .384 .251 r
.7031 .61949 m .71844 .58196 L .72928 .57833 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72441 .5957 m
.72693 .593 L
s
.72089 .60599 m
.7212 .60465 L
s
.5 Mabswid
.4 .568 .409 r
.65752 .68188 m .62903 .70507 L .61347 .71016 L p F P
.505 .664 .505 r
s
.349 .511 .375 r
.58573 .7264 m .61347 .71016 L .62903 .70507 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.62903 .29493 m .65752 .31812 L .63928 .31258 L p F P
.505 .664 .505 r
s
.159 .169 .128 r
.63928 .31258 m .61347 .28984 L .62903 .29493 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7212 .60465 m
.72225 .60137 L
s
.5 Mabswid
.446 .641 .486 r
.51632 .74157 m .52483 .73443 L .54823 .7327 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.52483 .73443 m .51632 .74157 L .5 .74197 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.5 .73502 m .5 .74197 L .48368 .74157 L p F P
.505 .664 .505 r
s
.471 .674 .517 r
.48368 .74157 m .47517 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.51632 .25843 m .52483 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.146 .157 .119 r
.5 .26498 m .5 .25803 L .51632 .25843 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.47517 .26557 m .48368 .25843 L .5 .25803 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.48368 .25843 m .47517 .26557 L .45177 .2673 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.61347 .71016 m .58573 .7264 L .56887 .72997 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.40837 .71456 m .43113 .72997 L .41427 .7264 L p F P
.505 .664 .505 r
s
.477 .676 .532 r
.41427 .7264 m .38653 .71016 L .40837 .71456 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.38653 .28984 m .41427 .2736 L .43113 .27003 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.58573 .2736 m .61347 .28984 L .59163 .28544 L p F P
.505 .664 .505 r
s
.158 .168 .128 r
.59163 .28544 m .56887 .27003 L .58573 .2736 L p F P
.505 .664 .505 r
s
.232 .284 .246 r
.28156 .41804 m .27208 .45832 L .26123 .46024 L p F P
.505 .664 .505 r
s
.283 .361 .307 r
.25803 .5 m .26123 .46024 L .27208 .45832 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26887 .5 m .27208 .54168 L .26123 .53976 L p F P
.505 .664 .505 r
s
.323 .424 .356 r
.26123 .53976 m .25803 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73877 .46024 m .74197 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
.244 .306 .206 r
.73113 .5 m .72792 .45832 L .73877 .46024 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.74197 .5 m .73877 .53976 L .72792 .54168 L p F P
.505 .664 .505 r
s
.27 .362 .235 r
.71844 .58196 m .72792 .54168 L .73877 .53976 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73108 .58009 m
.73237 .57743 L
s
.72886 .58495 m
.73108 .58009 L
s
.5 Mabswid
.283 .361 .307 r
.27208 .45832 m .26887 .5 L .25803 .5 L p F P
.505 .664 .505 r
s
.467 .668 .509 r
.5 .74197 m .5 .73502 L .52483 .73443 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.5 .25803 m .5 .26498 L .47517 .26557 L p F P
.505 .664 .505 r
s
.262 .34 .224 r
.72792 .54168 m .73113 .5 L .74197 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72225 .60137 m
.72441 .5957 L
s
.72606 .59159 m
.72886 .58495 L
s
.72441 .5957 m
.72606 .59159 L
s
.5 Mabswid
.494 .682 .543 r
.33783 .65855 m .36072 .68742 L .34248 .68188 L p F P
.505 .664 .505 r
s
.494 .682 .543 r
.34248 .68188 m .31748 .65312 L .33783 .65855 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.38653 .28984 m .36072 .31258 L .34248 .31812 L p F P
.505 .664 .505 r
s
.178 .191 .15 r
.31748 .34688 m .34248 .31812 L .36072 .31258 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.68252 .65312 m .65752 .68188 L .63928 .68742 L p F P
.505 .664 .505 r
s
.4 .568 .409 r
.61347 .71016 m .63928 .68742 L .65752 .68188 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.65752 .31812 m .68252 .34688 L .66217 .34145 L p F P
.505 .664 .505 r
s
.202 .214 .16 r
.66217 .34145 m .63928 .31258 L .65752 .31812 L p F P
.505 .664 .505 r
s
.44 .627 .463 r
.56887 .72997 m .59163 .71456 L .61347 .71016 L p F P
.505 .664 .505 r
s
.506 .71 .527 r
.59163 .71456 m .56887 .72997 L .54823 .7327 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43559 .71798 m .45177 .7327 L .43113 .72997 L p F P
.505 .664 .505 r
s
.532 .746 .577 r
.43113 .72997 m .40837 .71456 L .43559 .71798 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56887 .27003 m .59163 .28544 L .56441 .28202 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.56441 .28202 m .54823 .2673 L .56887 .27003 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.40837 .28544 m .43113 .27003 L .45177 .2673 L p F P
.505 .664 .505 r
s
.141 .152 .115 r
.43113 .27003 m .40837 .28544 L .38653 .28984 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7192 .60132 m
.7273 .57973 L
s
.716 .60735 m
.7192 .60132 L
s
.5 Mabswid
.543 .752 .588 r
.38699 .69227 m .40837 .71456 L .38653 .71016 L p F P
.505 .664 .505 r
s
.543 .752 .588 r
.38653 .71016 m .36072 .68742 L .38699 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.63928 .68742 m .61347 .71016 L .59163 .71456 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61347 .28984 m .63928 .31258 L .61301 .30773 L p F P
.505 .664 .505 r
s
.211 .219 .165 r
.61301 .30773 m .59163 .28544 L .61347 .28984 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.36072 .31258 m .38653 .28984 L .40837 .28544 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71379 .60971 m
.716 .60735 L
s
.5 Mabswid
.178 .191 .15 r
.36072 .31258 m .33783 .34145 L .31748 .34688 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.2969 .38051 m .31748 .34688 L .33783 .34145 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31882 .62423 m .33783 .65855 L .31748 .65312 L p F P
.505 .664 .505 r
s
.512 .695 .552 r
.31748 .65312 m .2969 .61949 L .31882 .62423 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68252 .34688 m .7031 .38051 L .68118 .37577 L p F P
.505 .664 .505 r
s
.261 .298 .211 r
.68118 .37577 m .66217 .34145 L .68252 .34688 L p F P
.505 .664 .505 r
s
.443 .603 .422 r
.7031 .61949 m .68252 .65312 L .66217 .65855 L p F P
.505 .664 .505 r
s
.431 .598 .424 r
.63928 .68742 m .66217 .65855 L .68252 .65312 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71152 .61045 m
.71379 .60971 L
s
.5 Mabswid
.506 .71 .527 r
.54823 .7327 m .56441 .71798 L .59163 .71456 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.56441 .71798 m .54823 .7327 L .52483 .73443 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.46675 .72014 m .47517 .73443 L .45177 .7327 L p F P
.505 .664 .505 r
s
.564 .784 .6 r
.45177 .7327 m .43559 .71798 L .46675 .72014 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.54823 .2673 m .56441 .28202 L .53325 .27986 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.53325 .27986 m .52483 .26557 L .54823 .2673 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.43559 .28202 m .45177 .2673 L .47517 .26557 L p F P
.505 .664 .505 r
s
.177 .185 .141 r
.45177 .2673 m .43559 .28202 L .40837 .28544 L p F P
.505 .664 .505 r
s
.548 .763 .57 r
.52483 .73443 m .53325 .72014 L .56441 .71798 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.53325 .72014 m .52483 .73443 L .5 .73502 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.5 .72088 m .5 .73502 L .47517 .73443 L p F P
.505 .664 .505 r
s
.576 .798 .606 r
.47517 .73443 m .46675 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.52483 .26557 m .53325 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.5 .27912 m .5 .26498 L .52483 .26557 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.46675 .27986 m .47517 .26557 L .5 .26498 L p F P
.505 .664 .505 r
s
.201 .207 .158 r
.47517 .26557 m .46675 .27986 L .43559 .28202 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.30454 .58546 m .31882 .62423 L .2969 .61949 L p F P
.505 .664 .505 r
s
.513 .686 .543 r
.2969 .61949 m .28156 .58196 L .30454 .58546 L p F P
.505 .664 .505 r
s
.256 .294 .236 r
.33783 .34145 m .31882 .37577 L .2969 .38051 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.28156 .41804 m .2969 .38051 L .31882 .37577 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.71844 .58196 m .7031 .61949 L .68118 .62423 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71071 .60906 m
.71152 .61045 L
s
.5 Mabswid
.443 .603 .422 r
.66217 .65855 m .68118 .62423 L .7031 .61949 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.7031 .38051 m .71844 .41804 L .69546 .41454 L p F P
.505 .664 .505 r
s
.307 .368 .252 r
.69546 .41454 m .68118 .37577 L .7031 .38051 L p F P
.505 .664 .505 r
s
.571 .791 .595 r
.5 .73502 m .5 .72088 L .53325 .72014 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5 .26498 m .5 .27912 L .46675 .27986 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36786 .66334 m .38699 .69227 L .36072 .68742 L p F P
.505 .664 .505 r
s
.58 .79 .614 r
.36072 .68742 m .33783 .65855 L .36786 .66334 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63928 .31258 m .66217 .34145 L .63214 .33666 L p F P
.505 .664 .505 r
s
.285 .323 .229 r
.63214 .33666 m .61301 .30773 L .63928 .31258 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.66217 .65855 m .63928 .68742 L .61301 .69227 L p F P
.505 .664 .505 r
s
.5 .694 .505 r
.59163 .71456 m .61301 .69227 L .63928 .68742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.40837 .28544 m .38699 .30773 L .36072 .31258 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.33783 .34145 m .36072 .31258 L .38699 .30773 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.29568 .54355 m .30454 .58546 L .28156 .58196 L p F P
.505 .664 .505 r
s
.5 .659 .521 r
.28156 .58196 m .27208 .54168 L .29568 .54355 L p F P
.505 .664 .505 r
s
.33 .4 .318 r
.31882 .37577 m .30454 .41454 L .28156 .41804 L p F P
.505 .664 .505 r
s
.391 .488 .386 r
.27208 .45832 m .28156 .41804 L .30454 .41454 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.61301 .69227 m .59163 .71456 L .56441 .71798 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.42026 .69605 m .43559 .71798 L .40837 .71456 L p F P
.505 .664 .505 r
s
.596 .817 .628 r
.40837 .71456 m .38699 .69227 L .42026 .69605 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.59163 .28544 m .61301 .30773 L .57974 .30395 L p F P
.505 .664 .505 r
s
.265 .29 .21 r
.57974 .30395 m .56441 .28202 L .59163 .28544 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.38699 .30773 m .40837 .28544 L .43559 .28202 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.72792 .54168 m .71844 .58196 L .69546 .58546 L p F P
.505 .664 .505 r
s
.44 .589 .407 r
.68118 .62423 m .69546 .58546 L .71844 .58196 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71048 .60388 m
.71071 .60906 L
s
.5 Mabswid
.343 .423 .283 r
.71844 .41804 m .72792 .45832 L .70432 .45645 L p F P
.505 .664 .505 r
s
.343 .423 .283 r
.70432 .45645 m .69546 .41454 L .71844 .41804 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71048 .60388 m
.71376 .59484 L
s
.70697 .61002 m
.71048 .60388 L
s
.5 Mabswid
.391 .488 .386 r
.30454 .41454 m .29568 .45645 L .27208 .45832 L p F P
.505 .664 .505 r
s
.438 .56 .442 r
.26887 .5 m .27208 .45832 L .29568 .45645 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.29268 .5 m .29568 .54355 L .27208 .54168 L p F P
.505 .664 .505 r
s
.475 .616 .487 r
.27208 .54168 m .26887 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.72792 .45832 m .73113 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.368 .465 .307 r
.70732 .5 m .70432 .45645 L .72792 .45832 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.73113 .5 m .72792 .54168 L .70432 .54355 L p F P
.505 .664 .505 r
s
.425 .558 .38 r
.69546 .58546 m .70432 .54355 L .72792 .54168 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71376 .59484 m
.71847 .58182 L
s
.70406 .61241 m
.70697 .61002 L
s
.5 Mabswid
.438 .56 .442 r
.29568 .45645 m .29268 .5 L .26887 .5 L p F P
.505 .664 .505 r
s
.399 .514 .344 r
.70432 .54355 m .70732 .5 L .73113 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70073 .61314 m
.70406 .61241 L
s
.69918 .61169 m
.70073 .61314 L
s
.5 Mabswid
.623 .849 .645 r
.45874 .69847 m .46675 .72014 L .43559 .71798 L p F P
.505 .664 .505 r
s
.623 .849 .645 r
.43559 .71798 m .42026 .69605 L .45874 .69847 L p F P
.505 .664 .505 r
s
.565 .775 .569 r
.56441 .71798 m .57974 .69605 L .61301 .69227 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.57974 .69605 m .56441 .71798 L .53325 .72014 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.42026 .30395 m .43559 .28202 L .46675 .27986 L p F P
.505 .664 .505 r
s
.242 .261 .191 r
.43559 .28202 m .42026 .30395 L .38699 .30773 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.56441 .28202 m .57974 .30395 L .54126 .30153 L p F P
.505 .664 .505 r
s
.297 .332 .236 r
.54126 .30153 m .53325 .27986 L .56441 .28202 L p F P
.505 .664 .505 r
s
.275 .311 .236 r
.38699 .30773 m .36786 .33666 L .33783 .34145 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.31882 .37577 m .33783 .34145 L .36786 .33666 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.35184 .62843 m .36786 .66334 L .33783 .65855 L p F P
.505 .664 .505 r
s
.595 .798 .618 r
.33783 .65855 m .31882 .62423 L .35184 .62843 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.66217 .34145 m .68118 .37577 L .64816 .37157 L p F P
.505 .664 .505 r
s
.342 .405 .278 r
.64816 .37157 m .63214 .33666 L .66217 .34145 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.68118 .62423 m .66217 .65855 L .63214 .66334 L p F P
.505 .664 .505 r
s
.532 .724 .522 r
.61301 .69227 m .63214 .66334 L .66217 .65855 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69778 .60638 m
.69918 .61169 L
s
.5 Mabswid
.594 .801 .583 r
.63214 .66334 m .61301 .69227 L .57974 .69605 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.40645 .66711 m .42026 .69605 L .38699 .69227 L p F P
.505 .664 .505 r
s
.627 .846 .647 r
.38699 .69227 m .36786 .66334 L .40645 .66711 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.61301 .30773 m .63214 .33666 L .59355 .33289 L p F P
.505 .664 .505 r
s
.337 .391 .271 r
.59355 .33289 m .57974 .30395 L .61301 .30773 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.36786 .33666 m .38699 .30773 L .42026 .30395 L p F P
.505 .664 .505 r
s
.605 .824 .61 r
.53325 .72014 m .54126 .69847 L .57974 .69605 L p F P
.505 .664 .505 r
s
.626 .851 .635 r
.54126 .69847 m .53325 .72014 L .5 .72088 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.5 .6993 m .5 .72088 L .46675 .72014 L p F P
.505 .664 .505 r
s
.632 .859 .646 r
.46675 .72014 m .45874 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.53325 .27986 m .54126 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.309 .348 .246 r
.5 .3007 m .5 .27912 L .53325 .27986 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45874 .30153 m .46675 .27986 L .5 .27912 L p F P
.505 .664 .505 r
s
.283 .314 .225 r
.46675 .27986 m .45874 .30153 L .42026 .30395 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69635 .60925 m
.70547 .58387 L
s
.69453 .61432 m
.69635 .60925 L
s
.5 Mabswid
.626 .851 .635 r
.5 .72088 m .5 .6993 L .54126 .69847 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.5 .27912 m .5 .3007 L .45874 .30153 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.33974 .58859 m .35184 .62843 L .31882 .62423 L p F P
.505 .664 .505 r
s
.593 .786 .606 r
.31882 .62423 m .30454 .58546 L .33974 .58859 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.69546 .58546 m .68118 .62423 L .64816 .62843 L p F P
.505 .664 .505 r
s
.543 .728 .52 r
.63214 .66334 m .64816 .62843 L .68118 .62423 L p F P
.505 .664 .505 r
s
.362 .432 .329 r
.36786 .33666 m .35184 .37157 L .31882 .37577 L p F P
.505 .664 .505 r
s
.43 .529 .404 r
.30454 .41454 m .31882 .37577 L .35184 .37157 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.68118 .37577 m .69546 .41454 L .66026 .41141 L p F P
.505 .664 .505 r
s
.385 .468 .315 r
.66026 .41141 m .64816 .37157 L .68118 .37577 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67659 .6306 m
.67891 .62867 L
s
.67818 .62719 m
.67891 .62867 L
s
.67583 .62915 m
.67659 .6306 L
s
.67583 .62915 m
.67818 .62719 L
s
.5 Mabswid
.525 .685 .48 r
.70432 .54355 m .69546 .58546 L .66026 .58859 L p F P
.505 .664 .505 r
s
.54 .713 .505 r
.64816 .62843 m .66026 .58859 L .69546 .58546 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68292 .61617 m
.68544 .60872 L
s
.5 Mabswid
.43 .529 .404 r
.35184 .37157 m .33974 .41141 L .30454 .41454 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.29568 .45645 m .30454 .41454 L .33974 .41141 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.3322 .54522 m .33974 .58859 L .30454 .58546 L p F P
.505 .664 .505 r
s
.58 .759 .584 r
.30454 .58546 m .29568 .54355 L .3322 .54522 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.69546 .41454 m .70432 .45645 L .6678 .45478 L p F P
.505 .664 .505 r
s
.428 .533 .361 r
.6678 .45478 m .66026 .41141 L .69546 .41454 L p F P
.505 .664 .505 r
s
.594 .801 .583 r
.57974 .69605 m .59355 .66711 L .63214 .66334 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.59355 .66711 m .57974 .69605 L .54126 .69847 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.57974 .30395 m .59355 .33289 L .54851 .33047 L p F P
.505 .664 .505 r
s
.364 .428 .294 r
.54851 .33047 m .54126 .30153 L .57974 .30395 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.45149 .66953 m .45874 .69847 L .42026 .69605 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.42026 .69605 m .40645 .66711 L .45149 .66953 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.40645 .33289 m .42026 .30395 L .45874 .30153 L p F P
.505 .664 .505 r
s
.343 .401 .296 r
.42026 .30395 m .40645 .33289 L .36786 .33666 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.63214 .33666 m .64816 .37157 L .60519 .36823 L p F P
.505 .664 .505 r
s
.389 .466 .316 r
.60519 .36823 m .59355 .33289 L .63214 .33666 L p F P
.505 .664 .505 r
s
.601 .8 .579 r
.64816 .62843 m .63214 .66334 L .59355 .66711 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.35184 .37157 m .36786 .33666 L .40645 .33289 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.39481 .63177 m .40645 .66711 L .36786 .66334 L p F P
.505 .664 .505 r
s
.637 .848 .646 r
.36786 .66334 m .35184 .62843 L .39481 .63177 L p F P
.505 .664 .505 r
s
.483 .607 .465 r
.33974 .41141 m .3322 .45478 L .29568 .45645 L p F P
.505 .664 .505 r
s
.525 .67 .513 r
.29268 .5 m .29568 .45645 L .3322 .45478 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.32963 .5 m .3322 .54522 L .29568 .54355 L p F P
.505 .664 .505 r
s
.557 .72 .553 r
.29568 .54355 m .29268 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.70432 .45645 m .70732 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.469 .595 .409 r
.67037 .5 m .6678 .45478 L .70432 .45645 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.70732 .5 m .70432 .54355 L .6678 .54522 L p F P
.505 .664 .505 r
s
.525 .685 .48 r
.66026 .58859 m .6678 .54522 L .70432 .54355 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68544 .60872 m
.69338 .58529 L
s
.5 Mabswid
.525 .67 .513 r
.3322 .45478 m .32963 .5 L .29268 .5 L p F P
.505 .664 .505 r
s
.501 .645 .448 r
.6678 .54522 m .67037 .5 L .70732 .5 L p F P
.505 .664 .505 r
s
.63 .845 .621 r
.54126 .69847 m .54851 .66953 L .59355 .66711 L p F P
.505 .664 .505 r
s
.649 .868 .644 r
.54851 .66953 m .54126 .69847 L .5 .6993 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.5 .67037 m .5 .6993 L .45874 .69847 L p F P
.505 .664 .505 r
s
.655 .877 .656 r
.45874 .69847 m .45149 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.54126 .30153 m .54851 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.387 .458 .321 r
.5 .32963 m .5 .3007 L .54126 .30153 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.45149 .33047 m .45874 .30153 L .5 .3007 L p F P
.505 .664 .505 r
s
.38 .449 .326 r
.45874 .30153 m .45149 .33047 L .40645 .33289 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66814 .61614 m
.67218 .60978 L
s
.66363 .61853 m
.66814 .61614 L
s
.67218 .60978 m
.6791 .58665 L
s
.5 Mabswid
.649 .868 .644 r
.5 .6993 m .5 .67037 L .54851 .66953 L p F P
.505 .664 .505 r
s
.393 .467 .333 r
.5 .3007 m .5 .32963 L .45149 .33047 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.66026 .58859 m .64816 .62843 L .60519 .63177 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65772 .61914 m
.66363 .61853 L
s
.5 Mabswid
.601 .8 .579 r
.59355 .66711 m .60519 .63177 L .64816 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.38598 .59108 m .39481 .63177 L .35184 .62843 L p F P
.505 .664 .505 r
s
.632 .832 .632 r
.35184 .62843 m .33974 .58859 L .38598 .59108 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.64816 .37157 m .66026 .41141 L .61402 .40892 L p F P
.505 .664 .505 r
s
.448 .551 .38 r
.61402 .40892 m .60519 .36823 L .64816 .37157 L p F P
.505 .664 .505 r
s
.423 .513 .382 r
.40645 .33289 m .39481 .36823 L .35184 .37157 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.33974 .41141 m .35184 .37157 L .39481 .36823 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65431 .61753 m
.65772 .61914 L
s
.5 Mabswid
.434 .527 .367 r
.59355 .33289 m .60519 .36823 L .55465 .36608 L p F P
.505 .664 .505 r
s
.434 .527 .367 r
.55465 .36608 m .54851 .33047 L .59355 .33289 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.60519 .63177 m .59355 .66711 L .54851 .66953 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.39481 .36823 m .40645 .33289 L .45149 .33047 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.44535 .63392 m .45149 .66953 L .40645 .66711 L p F P
.505 .664 .505 r
s
.655 .868 .653 r
.40645 .66711 m .39481 .63177 L .44535 .63392 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64269 .63314 m
.64867 .61303 L
s
.5 Mabswid
.494 .619 .432 r
.66026 .41141 m .6678 .45478 L .61955 .45345 L p F P
.505 .664 .505 r
s
.494 .619 .432 r
.61955 .45345 m .61402 .40892 L .66026 .41141 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.6678 .54522 m .66026 .58859 L .61402 .59108 L p F P
.505 .664 .505 r
s
.596 .783 .563 r
.60519 .63177 m .61402 .59108 L .66026 .58859 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64867 .61303 m
.6501 .60825 L
s
.6501 .60825 m
.65602 .58836 L
s
.64988 .61185 m
.65431 .61753 L
s
.5 Mabswid
.618 .805 .609 r
.38045 .54655 m .38598 .59108 L .33974 .58859 L p F P
.505 .664 .505 r
s
.618 .805 .609 r
.33974 .58859 m .3322 .54522 L .38045 .54655 L p F P
.505 .664 .505 r
s
.484 .6 .449 r
.39481 .36823 m .38598 .40892 L .33974 .41141 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.3322 .45478 m .33974 .41141 L .38598 .40892 L p F P
.505 .664 .505 r
s
.634 .841 .614 r
.54851 .66953 m .55465 .63392 L .60519 .63177 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.54851 .33047 m .55465 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
.458 .559 .397 r
.5 .36534 m .5 .32963 L .54851 .33047 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.55465 .63392 m .54851 .66953 L .5 .67037 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.44535 .36608 m .45149 .33047 L .5 .32963 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.5 .63466 m .5 .67037 L .45149 .66953 L p F P
.505 .664 .505 r
s
.658 .872 .649 r
.45149 .66953 m .44535 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.454 .554 .406 r
.45149 .33047 m .44535 .36608 L .39481 .36823 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.6678 .45478 m .67037 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.62143 .5 m .61955 .45345 L .6678 .45478 L p F P
.505 .664 .505 r
s
.559 .719 .51 r
.67037 .5 m .6678 .54522 L .61955 .54655 L p F P
.505 .664 .505 r
s
.581 .756 .54 r
.61402 .59108 m .61955 .54655 L .6678 .54522 L p F P
.505 .664 .505 r
s
.531 .669 .502 r
.38598 .40892 m .38045 .45345 L .3322 .45478 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.32963 .5 m .3322 .45478 L .38045 .45345 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.37857 .5 m .38045 .54655 L .3322 .54522 L p F P
.505 .664 .505 r
s
.596 .769 .58 r
.3322 .54522 m .32963 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62732 .61966 m
.63326 .61517 L
s
.5 Mabswid
.559 .719 .51 r
.61955 .54655 m .62143 .5 L .67037 .5 L p F P
.505 .664 .505 r
s
.567 .724 .545 r
.38045 .45345 m .37857 .5 L .32963 .5 L p F P
.505 .664 .505 r
s
.652 .863 .636 r
.5 .67037 m .5 .63466 L .55465 .63392 L p F P
.505 .664 .505 r
s
.465 .568 .41 r
.5 .32963 m .5 .36534 L .44535 .36608 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62191 .622 m
.62732 .61966 L
s
.5 Mabswid
.627 .823 .598 r
.61402 .59108 m .60519 .63177 L .55465 .63392 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.44068 .5927 m .44535 .63392 L .39481 .63177 L p F P
.505 .664 .505 r
s
.648 .851 .638 r
.39481 .63177 m .38598 .59108 L .44068 .5927 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.60519 .36823 m .61402 .40892 L .55932 .4073 L p F P
.505 .664 .505 r
s
.489 .606 .427 r
.55932 .4073 m .55465 .36608 L .60519 .36823 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.38598 .40892 m .39481 .36823 L .44535 .36608 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61445 .62246 m
.62191 .622 L
s
.63386 .59217 m
.63778 .59691 L
s
.60986 .62071 m
.61445 .62246 L
s
.6056 .61679 m
.60986 .62071 L
s
.62925 .58984 m
.63386 .59217 L
s
.6043 .6103 m
.6056 .61679 L
s
.62138 .59019 m
.62925 .58984 L
s
.5 Mabswid
.612 .795 .575 r
.61955 .54655 m .61402 .59108 L .55932 .5927 L p F P
.505 .664 .505 r
s
.627 .823 .598 r
.55465 .63392 m .55932 .5927 L .61402 .59108 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6043 .6103 m
.60519 .60569 L
s
.5799 .62411 m
.58816 .62378 L
s
.5 Mabswid
.531 .669 .476 r
.61402 .40892 m .61955 .45345 L .56224 .45258 L p F P
.505 .664 .505 r
s
.531 .669 .476 r
.56224 .45258 m .55932 .4073 L .61402 .40892 L p F P
.505 .664 .505 r
s
.51 .634 .467 r
.44535 .36608 m .44068 .4073 L .38598 .40892 L p F P
.505 .664 .505 r
s
.552 .697 .516 r
.38045 .45345 m .38598 .40892 L .44068 .4073 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.43776 .54742 m .44068 .5927 L .38598 .59108 L p F P
.505 .664 .505 r
s
.633 .824 .615 r
.38598 .59108 m .38045 .54655 L .43776 .54742 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61555 .59302 m
.62138 .59019 L
s
.5 Mabswid
.644 .844 .62 r
.55932 .5927 m .55465 .63392 L .5 .63466 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.5 .59326 m .5 .63466 L .44535 .63392 L p F P
.505 .664 .505 r
s
.651 .853 .633 r
.44535 .63392 m .44068 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.55465 .36608 m .55932 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.511 .635 .455 r
.5 .40674 m .5 .36534 L .55465 .36608 L p F P
.505 .664 .505 r
s
.518 .644 .468 r
.44068 .4073 m .44535 .36608 L .5 .36534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60519 .60569 m
.60923 .59831 L
s
.60923 .59831 m
.61555 .59302 L
s
.57464 .62226 m
.5799 .62411 L
s
.56958 .6182 m
.57464 .62226 L
s
.56579 .62459 m
.56673 .617 L
s
.5 Mabswid
.644 .844 .62 r
.5 .63466 m .5 .59326 L .55932 .5927 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51886 .61673 m
.52966 .63877 L
s
.52966 .63877 m
.54255 .61724 L
s
.5 Mabswid
.518 .644 .468 r
.5 .36534 m .5 .40674 L .44068 .4073 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.56758 .61162 m
.56958 .6182 L
s
.5 Mabswid
.565 .719 .515 r
.61955 .45345 m .62143 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.565 .719 .515 r
.56324 .5 m .56224 .45258 L .61955 .45345 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.62143 .5 m .61955 .54655 L .56224 .54742 L p F P
.505 .664 .505 r
s
.612 .795 .575 r
.55932 .5927 m .56224 .54742 L .61955 .54655 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.56673 .617 m
.56984 .59186 L
s
.5 Mabswid
.552 .697 .516 r
.44068 .4073 m .43776 .45258 L .38045 .45345 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.37857 .5 m .38045 .45345 L .43776 .45258 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.43676 .5 m .43776 .54742 L .38045 .54655 L p F P
.505 .664 .505 r
s
.613 .789 .588 r
.38045 .54655 m .37857 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
.591 .761 .548 r
.56224 .54742 m .56324 .5 L .62143 .5 L p F P
.505 .664 .505 r
s
.586 .748 .555 r
.43776 .45258 m .43676 .5 L .37857 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51617 .61014 m
.54692 .60977 L
s
.5 Mabswid
.629 .817 .597 r
.56224 .54742 m .55932 .5927 L .5 .59326 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.54519 .61283 m
.5576 .59211 L
s
.54255 .61724 m
.54519 .61283 L
s
.51772 .6144 m
.51886 .61673 L
s
.5 Mabswid
.636 .826 .61 r
.5 .54772 m .5 .59326 L .44068 .5927 L p F P
.505 .664 .505 r
s
.636 .826 .61 r
.44068 .5927 m .43776 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.55932 .4073 m .56224 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.551 .695 .501 r
.5 .45228 m .5 .40674 L .55932 .4073 L p F P
.505 .664 .505 r
s
.558 .704 .514 r
.43776 .45258 m .44068 .4073 L .5 .40674 L p F P
.505 .664 .505 r
s
.629 .817 .597 r
.5 .59326 m .5 .54772 L .56224 .54742 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50705 .59261 m
.51772 .6144 L
s
.5 Mabswid
.558 .704 .514 r
.5 .40674 m .5 .45228 L .43776 .45258 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.56224 .45258 m .56324 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.583 .743 .539 r
.5 .5 m .5 .45228 L .56224 .45258 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.56324 .5 m .56224 .54742 L .5 .54772 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.43676 .5 m .43776 .45258 L .5 .45228 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.5 .5 m .5 .54772 L .43776 .54742 L p F P
.505 .664 .505 r
s
.616 .793 .584 r
.43776 .54742 m .43676 .5 L .5 .5 L p F P
.505 .664 .505 r
s
.609 .783 .571 r
.5 .54772 m .5 .5 L .56324 .5 L p F P
.505 .664 .505 r
s
.59 .753 .552 r
.5 .45228 m .5 .5 L .43676 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>h0/>3V5`21ZH7^0;3PiP40oooo003V0;3PiPP0PJV10P0R9A`0
0`21ZH4092LN02@W7P0602@W7P03086YP@0U:1h09BPN00H09BPN00<0PJV102<V7@0S9Qd02021ZH7V
0;3PiP40oooo003P0;3PiPH0PJV100<0720H086YP@21ZH401P0R9A`00`21ZH4092LN02@W7P0702@W
7P03086YP@0U:1h09BPN00L09BPN00<0PJV102<V7@0S9Qd0100S9Qd2086YP@0301lR6P21ZH40PJV1
00@0PJV1h02`h>H10?ooo`00g02`h>H5086YP@@0720H0P21ZH47028U7003086YP@0T9ah092LN00P0
92LN00<0PJV102DX7P0U:1h0200U:1h00`21ZH408bHM02<V7@0502<V7@80PJV1100O8QX5086YPM`0
/>3V0@3oool00=T0/>3V1@21ZH4501`P6080PJV10`0R9A`S086YP@<08bHM0P21ZH4501lR6PD0PJV1
f@2`h>H10?ooo`00eP2`h>H2086YP@0301DI4`21ZH40PJV10080720H2`21ZH4403<d:003086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@0203Df:@/0PJV100<0
7b8J086YP@21ZH401021ZH7F0;3PiP40oooo003C0;3PiPX0PJV10`0];b@00`21ZH40<c@X03<d:009
03<d:003086YP@0f>2X0=SPZ00X0=SPZ00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=CHY03Df:@09
03Df:@04086YP@0`<RH0<38V030b9PX0PJV1d`2`h>H10?ooo`00d02`h>H7086YP@P0;BlT00<0PJV1
03<d:00c=2P02@0c=2P00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0g>2/0=cP[00/0=cP[00<0PJV1
03Df:@0e=RT02@0e=RT00`21ZH40<38V030b9P06030b9PL0PJV1d02`h>H10?ooo`00c@2`h>H4086Y
P@<092HM00<0PJV102d_900];b@01`0];b@00`21ZH40<c@X03<d:00903<d:003086YP@0f>2X0=SPZ
00`0=SPZ00<0PJV103Lh:`0g>2/0300g>2/00`21ZH40=CHY03Df:@0903Df:@03086YP@0`<RH0<38V
00L0<38V00@0PJV102P[800X:b00:2/P1021ZH7=0;3PiP40oooo003:0;3PiP@0PJV1100T9Qd2086Y
P@P0;BlT0P21ZH4;03<d:003086YP@0f>2X0=SPZ00d0=SPZ00<0PJV103Lh:`0g>2/03@0g>2/00`21
ZH40=CHY03Df:@0903Df:@80PJV1200`<RH2086YP@@0:2/P1021ZH7:0;3PiP40oooo00380;3PiP@0
PJV11@0T9Qd00`21ZH40;BlT02d_900702d_9003086YP@0c=2P0<c@X00/0<c@X00<0PJV103Hh:P0f
>2X03@0f>2X00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0e=RT0=CHY00/0=CHY00<0PJV1030b9P0`
<RH01`0`<RH00`21ZH40:2/P02P[800302P[80@0PJV1b02`h>H10?ooo`00aP2`h>H4086YP@D092HM
0P21ZH4902d_9003086YP@0c=2P0<c@X00@0<c@X<@21ZH4603Df:@03086YP@0`<RH0<38V00L0<38V
0P21ZH4502P[8080PJV100<07B0H086YP@2`h>H0a@2`h>H10?ooo`00a02`h>H2086YP@0301LK5021
ZH4092HM00D092HM00<0PJV102d_900];b@01@0];b@;086YP@L0B50i00<0PJV104eG?@1=Ecd03P1=
Ecd00`21ZH40CeTn04mI?P0>04mI?P03086YP@1<E3`0C5@l00D0C5@l2`21ZH47030b9P03086YP@0X
:b00:2/P00@0:2/P00@0PJV101dP6021ZH40PJV1a02`h>H10?ooo`00`P2`h>H2086YP@0301LK5021
ZH40PJV100D092HM0P21ZH400`0];b@0PJV1086YP@05086YP@80?D8`00<0PJV104Q@>@18D3T03018
D3T00`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<
E3`00`21ZH40@dXe04=:=@07086YP@03030b9P21ZH40PJV100D0:2/P0P21ZH400`0M81P0PJV1086Y
P@320;3PiP40oooo00300;3PiPD0PJV1100T9Qd6086YP@T0?D8`00<0PJV104Q@>@18D3T03018D3T0
0`21ZH40CELm04eG?@0?04eG?@03086YP@1?FCh0CeTn00l0CeTn00<0PJV104aD?01<E3`0301<E3`0
0`21ZH40@dXe04=:=@0704=:=@H0PJV1100X:b05086YPL00/>3V0@3oool00;h0/>3V2`21ZH400`0`
<BD0PJV103e2<00;03e2<003086YP@18D3T0B50i00d0B50i00<0PJV104eG?@1=Ecd03`1=Ecd00`21
ZH40CeTn04mI?P0?04mI?P03086YP@1<E3`0C5@l00d0C5@l00<0PJV104=:=@13BSD02P13BSD00`21
ZH40=SPZ086YP@0:086YPKh0/>3V0@3oool00;d0/>3V1P21ZH46030a9@03086YP@0m@S00?D8`00X0
?D8`00<0PJV104Q@>@18D3T03@18D3T00`21ZH40CELm04eG?@0@04eG?@03086YP@1?FCh0CeTn0100
CeTn00<0PJV104aD?01<E3`03@1<E3`00`21ZH40@dXe04=:=@0:04=:=@03086YP@0f>2X0=SPZ00@0
=SPZ1P21ZH6m0;3PiP40oooo002k0;3PiPD0PJV1200`<BD00`21ZH40?D8`03e2<00:03e2<003086Y
P@18D3T0B50i00h0B50i00<0PJV104eG?@1=Ecd0401=Ecd00`21ZH40CeTn04mI?P0@04mI?P03086Y
P@1<E3`0C5@l00h0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0603Hh:PD0PJV1
^`2`h>H10?ooo`00^@2`h>H4086YP@03028T7021ZH40<34U00L0<34U00<0PJV103e2<00m@S002`0m
@S000`21ZH40B50i04Q@>@0=04Q@>@03086YP@1=Ecd0CELm0140CELm00<0PJV104mI?P1?FCh04@1?
FCh00`21ZH40C5@l04aD?00=04aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f
>2X00`21ZH40:2/P086YP@03086YPKT0/>3V0@3oool00;L0/>3V1021ZH42028T7003086YP@0`<BD0
<34U00H0<34U00<0PJV103e2<00m@S002`0m@S000`21ZH40B50i04Q@>@0>04Q@>@03086YP@1=Ecd0
CELm0140CELm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40C5@l04aD?00>04aD?003086YP@13BSD0
@dXe00/0@dXe00<0PJV103Hh:P0f>2X01P0f>2X2086YP@0302P[8021ZH40PJV10080PJV1]`2`h>H1
0?ooo`00]@2`h>H4086YP@<08R@L00<0PJV1030a9@0`<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2
<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=Ecd04@1=Ecd00`21ZH40CeTn04mI?P0A04mI
?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh
:P03086YP@0X:b00:2/P00@0PJV1]@2`h>H10?ooo`00]02`h>H3086YP@@08R@L00<0PJV1030a9@0`
<BD01`0`<BD00`21ZH40?D8`03e2<00:03e2<003086YP@18D3T0B50i00l0B50i00<0PJV104eG?@1=
Ecd04P1=Ecd00`21ZH40CeTn04mI?P0B04mI?P03086YP@1<E3`0C5@l00l0C5@l00<0PJV104=:=@13
BSD02P13BSD00`21ZH40=SPZ03Hh:P0803Hh:P04086YP@0X:b00:2/P02P[80<0PJV1]02`h>H10?oo
o`00/`2`h>H00`21ZH4041@?086YP@03028T7080PJV12@0`<BD00`21ZH40?D8`03e2<00;03e2<003
086YP@18D3T0B50i00H0B50i?@21ZH4804aD?003086YP@13BSD0@dXe00/0@dXe00<0PJV103Hh:P0f
>2X0200f>2X01@21ZH40:2/P02P[800X:b00PJV1008061/D/`2`h>H10?ooo`00/@2`h>H4086YP@<0
8R@L00<0PJV1030a9@0`<BD0200`<BD00`21ZH40?D8`03e2<00803e2<0d0PJV12@1QLU<00`21ZH40
I7ME06AgE@0B06AgE@03086YP@1SME80HgEB0180HgEB00<0PJV105e]B`1MKD/01`1MKD/=086YP@X0
@dXe00<0PJV103Hh:P0f>2X0200f>2X01021ZH40:2/P02P[800X:b02086YP@0301PK5021ZH40/>3V
0;00/>3V0@3oool00;00/>3V00<0PJV1010D3`21ZH40100R91`00`21ZH40<34U030a9@08030a9@04
086YP@0m@S00?D8`03e2<0P0PJV10`1GIT/00`21ZH40HG9C065bD`0@065bD`03086YP@1TMeD0I7ME
0180I7ME00<0PJV106=eDP1SME804P1SME800`21ZH40GFe;05e]B`0@05e]B`04086YP@1FI4D0EVA5
05ITA@P0PJV10`13BSD00`21ZH40=SPZ03Hh:P0803Hh:P80PJV10`0X:b000`21ZH4061/D086YP@2`
0;3PiP40oooo002_0;3PiP03086YP@0@50l0PJV100@08R@L00<0PJV1030a9@0`<BD01@0`<BD8086Y
P@X0EfI;00<0PJV1065bD`1QLU<0401QLU<00`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB
01<0HgEB00<0PJV105e]B`1MKD/0401MKD/00`21ZH40EVA505ITA@0805ITA@P0PJV1200f>2X01`21
ZH40:2/P02P[800X:b00PJV101PK5021ZH40[`2`h>H10?ooo`00[P2`h>H3086YP@@08R@L00<0PJV1
030a9@0`<BD01P21ZH4204I??003086YP@1GIT/0EfI;00d0EfI;00<0PJV1065bD`1QLU<0401QLU<0
0`21ZH40I7ME06AgE@0C06AgE@03086YP@1SME80HgEB01<0HgEB00<0PJV105e]B`1MKD/0401MKD/0
0`21ZH40EVA505ITA@0=05ITA@03086YP@18DSX0B58j00L0PJV10P0f>2X01021ZH40:2/P02P[800X
:b03086YPJh0/>3V0@3oool00:`0/>3V0`21ZH44028T70D0PJV12016Cc`00`21ZH40EfI;05MVB`0<
05MVB`03086YP@1QLU<0HG9C0140HG9C00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgEB06=eDP0C
06=eDP03086YP@1MKD/0GFe;0140GFe;00<0PJV105ITA@1FI4D0301FI4D00`21ZH40B58j04QB>P07
04QB>PD0PJV10`0X:b03086YPJ`0/>3V0@3oool00:/0/>3V00<0PJV1010D3`21ZH400P0R91`4086Y
P@/0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01<0I7ME00<0PJV106=eDP1SME804`1SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00d0EVA500<0PJV104QB>P18DSX02P18DSX4086YP@0402P[8021ZH4061/D086YPJ/0/>3V0@3oool0
0:X0/>3V1P21ZH4202d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MVB`1GIT/03@1GIT/00`21
ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=eDP1SME804`1SME800`21
ZH40GFe;05e]B`0B05e]B`03086YP@1FI4D0EVA500d0EVA500<0PJV104QB>P18DSX02@18DSX01021
ZH40<cHX03<f:00c=RP5086YPJX0/>3V0@3oool00:T0/>3V0`21ZH4602d`9P03086YP@16Cc`0ATll
00P0ATll00<0PJV105MVB`1GIT/03P1GIT/00`21ZH40HG9C065bD`0A065bD`03086YP@1TMeD0I7ME
01@0I7ME00<0PJV106=eDP1SME80501SME800`21ZH40GFe;05e]B`0A05e]B`03086YP@1FI4D0EVA5
00h0EVA500<0PJV104QB>P18DSX02@18DSX00`21ZH40<cHX03<f:00303<f:0<0PJV1Z@2`h>H10?oo
o`00Y`2`h>H3086YP@L0;C0V00<0PJV104I??016Cc`02@16Cc`00`21ZH40EfI;05MVB`0=05MVB`03
086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgEB06=eDP0D06=eDP03
086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03@1FI4D00`21ZH40B58j04QB>P0:04QB>P03
086YP@0c=RP0<cHX00@0<cHX0`21ZH6W0;3PiP40oooo002V0;3PiP<0PJV11`0]<2H00`21ZH40ATll
04I??00904I??003086YP@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04P1QLU<00`21ZH40I7ME
06AgE@0D06AgE@03086YP@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04P1MKD/00`21ZH40EVA5
05ITA@0>05ITA@03086YP@18DSX0B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP3086YPJH0/>3V
0@3oool00:D0/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H00`21ZH40ATll04I??00904I??003086Y
P@1GIT/0EfI;00h0EfI;00<0PJV1065bD`1QLU<04`1QLU<00`21ZH40I7ME06AgE@0D06AgE@03086Y
P@1SME80HgEB01@0HgEB00<0PJV105e]B`1MKD/04`1MKD/00`21ZH40EVA505ITA@0>05ITA@03086Y
P@18DSX0B58j00T0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6U0;3PiP40
oooo002T0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02P16Cc`00`21ZH40
EfI;05MVB`0>05MVB`03086YP@1QLU<0HG9C0180HG9C00<0PJV106AgE@1TMeD05@1TMeD00`21ZH40
HgEB06=eDP0E06=eDP03086YP@1MKD/0GFe;0180GFe;00<0PJV105ITA@1FI4D03P1FI4D00`21ZH40
B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1Y02`h>H10?oo
o`00X`2`h>H01021ZH405QXC01HJ4`21ZH4702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV105MV
B`1GIT/03P1GIT/00`21ZH40HG9C065bD`0C065bD`03086YP@1TMeD0I7ME01D0I7ME00<0PJV106=e
DP1SME805@1SME800`21ZH40GFe;05e]B`0C05e]B`03086YP@1FI4D0EVA500h0EVA500<0PJV104QB
>P18DSX02P18DSX00`21ZH40<cHX03<f:00403<f:004086YP@0O8QX07b8J086YPJ<0/>3V0@3oool0
0:80/>3V00@0PJV101HJ4`0F6Q<0PJV11`0]<2H00`21ZH40ATll04I??00904I??003086YP@1GIT/0
EfI;00l0EfI;00<0PJV1065bD`1QLU<03P1QLU<k086YPA00GFe;00<0PJV105ITA@1FI4D03`1FI4D0
0`21ZH40B58j04QB>P0:04QB>P03086YP@0c=RP0<cHX00@0<cHX00@0PJV101lR6P0O8QX0PJV1XP2`
h>H10?ooo`00XP2`h>H00`21ZH405QXC086YP@0702d`9P03086YP@16Cc`0ATll00T0ATll00<0PJV1
05MVB`1GIT/03`1GIT/00`21ZH40HG9C065bD`03065bD``0PJV11@1dSFL00`21ZH40Mi5X07NAJ00E
07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0PJV106n6G@1_QUd00`1_QUd<086YP@D0GFe;00<0PJV1
05ITA@1FI4D03`1FI4D00`21ZH40B58j04QB>P0904QB>P03086YP@0c=RP0<cHX00D0<cHX00<0PJV1
01lR6P21ZH40XP2`h>H10?ooo`00X@2`h>H01021ZH405QXC01HJ4`21ZH4602d`9P03086YP@16Cc`0
ATll00X0ATll00<0PJV105MVB`1GIT/01P1GIT/?086YPA40M8eW00<0PJV107NAJ01gTFP05@1gTFP0
0`21ZH40MHmU07F?I@0E07F?I@03086YP@1_QUd0KhIM00l0KhIM3`21ZH4805ITA@03086YP@18DSX0
B58j00X0B58j00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6Q0;3PiP40oooo002P
0;3PiP04086YP@0F6Q<05QXC086YP@H0;C0V00<0PJV104I??016Cc`02016Cc`<086YP@T0K8=Q00<0
PJV107B=I`1dSFL04`1dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01D0MHmU00<0
PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00706=gD0`0PJV12P18DSX00`21ZH40<cHX03<f
:00403<f:004086YP@0O8QX07b8J086YPJ00/>3V0@3oool009l0/>3V00@0PJV101HJ4`0F6Q<0PJV1
1`0]<2H00`21ZH40ATll04I??00304I??0D0PJV10P1LKU@00`21ZH40K8=Q06b3H@0?06b3H@03086Y
P@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40MHmU07F?I@0F07F?I@03086Y
P@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe003`1SMe000`21ZH40EfM705MWA`05086YP@H0B58j
00<0PJV103<f:00c=RP0100c=RP01021ZH407b8J01lR6P21ZH6O0;3PiP40oooo002N0;3PiP04086Y
P@0F6Q<05QXC086YP@L0;C0V00<0PJV104I??021ZH401021ZH4605a^E003086YP@1/Pf40K8=Q0100
K8=Q00<0PJV107B=I`1dSFL0501dSFL00`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0
MHmU00<0PJV106n6G@1_QUd0501_QUd00`21ZH40HgM@06=gD00@06=gD003086YP@1GIdL0EfM700@0
EfM71@21ZH400`18DSX0PJV103<f:00603<f:004086YP@0O8QX07b8J086YPIh0/>3V0@3oool009d0
/>3V00@0PJV101HJ4`0F6Q<0PJV11P0]<2H4086YP@/0G6iD00<0PJV106b3H@1/Pf40401/Pf400`21
ZH40M8eW07B=I`0D07B=I`03086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107F?I@1eSfD05P1eSfD00`21
ZH40KhIM06n6G@0D06n6G@03086YP@1SMe00HgM@0100HgM@00<0PJV105MWA`1GIdL02@1GIdL4086Y
P@H0<cHX00@0PJV101lR6P0O8QX0PJV1W@2`h>H10?ooo`00W02`h>H01@21ZH405QXC01HJ4`0F6Q<0
PJV100<0;C0V1021ZH4=05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL0501dSFL0
0`21ZH40Mi5X07NAJ00F07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd0501_QUd0
0`21ZH40HgM@06=gD00A06=gD003086YP@1GIdL0EfM700/0EfM71021ZH4303<f:005086YP@0O8QX0
7b8J01lR6P21ZH40W02`h>H10?ooo`00W02`h>H301HJ4`D0PJV10`11Bc`00`21ZH40G6iD05a^E00;
05a^E003086YP@1/Pf40K8=Q0100K8=Q00<0PJV107B=I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00F
07NAJ003086YP@1eSfD0MHmU01H0MHmU00<0PJV106n6G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00@
06=gD003086YP@1GIdL0EfM700/0EfM700@0PJV1049<=P12C3H0@T`f1@21ZH4201lR6P03086YP@2`
h>H0/>3V09X0/>3V0@3oool009/0/>3V0P0F6Q<3086YP@H0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0F07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00@0@T`f0`21ZH400`0O8QX0PJV10;3PiP2J
0;3PiP40oooo002J0;3PiP0401HJ4`21ZH40PJV1086YP@P0@D/l00<0PJV105a^E01LKU@02`1LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01@0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01@0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f1021ZH6J0;3PiP40oooo002I0;3P
iP80PJV10P0Q9R000`21ZH40@D/l045;?005045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3
H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086YP@1gTFP0Mi5X01L0Mi5X00<0PJV107F?
I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0E06n6G@03086YP@1SMe00HgM@0140HgM@00<0PJV105MW
A`1GIdL02`1GIdL00`21ZH40@T`f049<=P05049<=P03086YP@0U9ah09BLN0080PJV1V@2`h>H10?oo
o`00V02`h>H01@21ZH408BHP024V800Q9R00PJV100P0@D/l00<0PJV105a^E01LKU@02`1LKU@00`21
ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP00`21
ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe000`21
ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0@T`f00D0PJV102DW7P0U9ah09BLN086YP@2H
0;3PiP40oooo002H0;3PiP04086YP@0Q9R008BHP086YP@P0@D/l00<0PJV105a^E01LKU@0301LKU@0
0`21ZH40K8=Q06b3H@0A06b3H@03086YP@1dSFL0M8eW01D0M8eW00<0PJV107NAJ01gTFP05`1gTFP0
0`21ZH40MHmU07F?I@0G07F?I@03086YP@1_QUd0KhIM01D0KhIM00<0PJV106=gD01SMe004@1SMe00
0`21ZH40EfM705MWA`0<05MWA`03086YP@12C3H0@T`f00D0@T`f00D0PJV102DW7P0U9ah09BLN086Y
P@2H0;3PiP40oooo002G0;3PiP05086YP@0Q9R008BHP024V8021ZH402011Bc`00`21ZH40G6iD05a^
E00;05a^E003086YP@1/Pf40K8=Q0140K8=Q00<0PJV107B=I`1dSFL05P1dSFL00`21ZH40Mi5X07NA
J00G07NAJ003086YP@1eSfD0MHmU01L0MHmU00<0PJV106n6G@1_QUd05P1_QUd00`21ZH40HgM@06=g
D00A06=gD003086YP@1GIdL0EfM700/0EfM700<0PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW
7P0U9ah0PJV109L0/>3V0@3oool009H0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086Y
P@1LKU@0G6iD00`0G6iD00<0PJV106b3H@1/Pf404@1/Pf400`21ZH40M8eW07B=I`0E07B=I`03086Y
P@1gTFP0Mi5X01P0Mi5X00<0PJV107F?I@1eSfD05`1eSfD00`21ZH40KhIM06n6G@0F06n6G@03086Y
P@1SMe00HgM@0140HgM@00<0PJV105MWA`1GIdL0301GIdL00`21ZH40@T`f049<=P06049<=P05086Y
P@0U9ah09BLN02DW7P21ZH40UP2`h>H10?ooo`00UP2`h>H01@21ZH408BHP024V800Q9R00PJV100P0
@D/l00<0PJV105a^E01LKU@02`1LKU@00`21ZH40K8=Q06b3H@0B06b3H@03086YP@1dSFL0M8eW01D0
M8eW00<0PJV107NAJ01gTFP0601gTFP00`21ZH40MHmU07F?I@0H07F?I@03086YP@1_QUd0KhIM01D0
KhIM00<0PJV106=gD01SMe004P1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00H0
@T`f00D0PJV102DW7P0U9ah09BLN086YP@2F0;3PiP40oooo002E0;3PiP05086YP@0Q9R008BHP024V
8021ZH402011Bc`00`21ZH40G6iD05a^E00<05a^E003086YP@1/Pf40K8=Q0180K8=Q00<0PJV107B=
I`1dSFL05@1dSFL00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1eSfD0MHmU01P0MHmU00<0PJV106n6
G@1_QUd05@1_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0EfM700`0EfM700<0PJV1049<
=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109D0/>3V0@3oool009@0/>3V00D0PJV1024V
800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf404P1/Pf40
0`21ZH40M8eW07B=I`0:07B=Idl0PJV1301_QUd00`21ZH40HgM@06=gD00B06=gD003086YP@1GIdL0
EfM700/0EfM700<0PJV1049<=P12C3H01`12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3o
ool009@0/>3V00D0PJV1024V800Q9R008BHP086YP@08045;?003086YP@1LKU@0G6iD00`0G6iD00<0
PJV106b3H@1/Pf403@1/Pf4B086YP@`0PZ9g00<0PJV108BTM`24Y7L06024Y7L00`21ZH40PZ9d08:R
M00H08:RM003086YP@1mVfd0OI]]00X0OI]]4P21ZH4?06=gD003086YP@1GIdL0EfM700`0EfM700<0
PJV1049<=P12C3H01P12C3H01@21ZH409BLN02DW7P0U9ah0PJV109@0/>3V0@3oool009<0/>3V00D0
PJV1024V800Q9R008BHP086YP@09045;?003086YP@1LKU@0G6iD00/0G6iD00<0PJV106b3H@1/Pf40
0`1/Pf4;086YP@D0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03086Y
P@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0307:=H@/0PJV1
1@1SMe000`21ZH40EfM705MWA`0;05MWA`03086YP@12C3H0@T`f00L0@T`f00D0PJV102DW7P0U9ah0
9BLN086YP@2C0;3PiP40oooo002C0;3PiP04086YP@0Q9R008BHP086YP@T0@D/l00<0PJV105a^E01L
KU@02@1LKU@9086YPA00NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0H08BTM`03
086YP@22XW@0PZ9d01P0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0>07:=H@T0
PJV12`1GIdL00`21ZH40@T`f049<=P06049<=P05086YP@0U9ah09BLN02DW7P21ZH40T`2`h>H10?oo
o`00TP2`h>H01@21ZH408BHP024V800Q9R00PJV100T0@D/l00@0PJV105a^E01LKU@0G6iD2021ZH43
06j7I`03086YP@1kVG80NiUb0180NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag08BTM`0I
08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ07:=H@0B
07:=H@04086YP@1RMe00HWM@069gD0P0PJV10`1GIdL00`21ZH40@T`f049<=P07049<=P05086YP@0U
9ah09BLN02DW7P21ZH40TP2`h>H10?ooo`00T@2`h>H01@21ZH408BHP024V800Q9R00PJV100L0@D/l
1`21ZH4:06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21ZH40Q:Ag
08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21ZH40LXeQ
07:=H@0C07:=H@03086YP@1RMe00HWM@00P0HWM@1`21ZH47049<=P05086YP@0U9ah09BLN02DW7P21
ZH40T@2`h>H10?ooo`00T@2`h>H01P21ZH408BHP024V800Q9R00PJV1045;?0H0PJV10P1DIU400`21
ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL05P22XWL00`21
ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0PZ9d00<0PJV107fKK@1mVfd05P1mVfd00`21
ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00`0HWM@00<0PJV104iN@01>GT001P21ZH400`12
C3H0PJV102DW7P0202DW7P03086YP@2`h>H0/>3V08l0/>3V0@3oool00900/>3V00@0PJV1024V800Q
9R008BHP0`21ZH4705AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG804`1kVG800`21
ZH40PZ9g08:RM`0F08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV108:RM022XW@06@22XW@00`21
ZH40OI]]07fKK@0F07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe003@1RMe000`21
ZH40CUi004iN@00504iN@0<0PJV10`0U9ah00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002?0;3PiP03
086YP@0Q9R008BHP00<0PJV12@1DIU400`21ZH40KXMW06j7I`0<06j7I`03086YP@1kVG80NiUb01<0
NiUb00<0PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@22XW@0PZ9d01T0
PZ9d00<0PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0B07:=H@03086YP@1RMe00HWM@00d0
HWM@00<0PJV104iN@01>GT001`1>GT03086YP@809BLN00<0PJV10;3PiP2`h>H0S@2`h>H10?ooo`00
S`2`h>H01@0Q9R00PJV1086YP@0]=2h0PJV100T0E6IA00<0PJV106j7I`1^QfL03@1^QfL00`21ZH40
NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40
PZ9d08:RM00I08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF404`1bSF400`21ZH40
HWM@069gD00=069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@21ZH400P21ZH6?0;3PiP40
oooo002>0;3PiP80PJV10`0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00d0KXMW
00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01T0Q:Ag
00<0PJV108:RM022XW@06@22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ
00<0PJV1069gD01RMe003@1RMe000`21ZH40CUi004iN@00704iN@004086YP@0^=2D0;S@U02hd9@80
PJV1SP2`h>H10?ooo`00SP2`h>H01@21ZH40;C@^02dd;P0]=2h0PJV100T0E6IA00<0PJV106j7I`1^
QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01H0PZ9g00<0PJV108BTM`24
Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01H0OI]]00<0PJV107:=H@1b
SF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^
=2D00P0^=2F>0;3PiP40oooo002=0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0PJV105AVD@1DIU40
1`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01<0NiUb00<0PJV108:RM`22XWL0
5`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0PJV107fKK@1mVfd0
5`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00d0HWM@00<0PJV104iN@01>GT00
1`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08/0/>3V0@3oool008d0/>3V00D0
PJV102dd;P0]=2h0;C@^086YP@0:05AVD@03086YP@1^QfL0KXMW00d0KXMW00<0PJV107^ILP1kVG80
4`1kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV108:RM022XW@0
6P22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0PJV1069gD01RMe00
3@1RMe000`21ZH40CUi004iN@00804iN@005086YP@0^=2D0;S@U02hd9@21ZH40S@2`h>H10?ooo`00
S02`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0PJV106j7I`1^QfL0
3P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01L0PZ9g00<0PJV108BTM`24Y7L0
6P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01L0OI]]00<0PJV107:=H@1bSF40
4`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0PJV102hd9@0^=2D0
0P0^=2D00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002<0;3PiP03086YP@0]=2h0;C@^0080;C@^00<0
PJV105AVD@1DIU401`1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@22XW@0PZ9d01X0PZ9d00<0
PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0D07:=H@03086YP@1RMe00HWM@00d0HWM@00<0
PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd9@0202hd9@03086YP@2`h>H0/>3V08X0/>3V0@3o
ool008`0/>3V00D0PJV102dd;P0]=2h0;C@^086YP@0905AVD@03086YP@1^QfL0KXMW00h0KXMW00<0
PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:RM`0H08:RM`03086YP@24Y7L0Q:Ag01X0Q:Ag00<0
PJV108:RM022XW@06P22XW@00`21ZH40OI]]07fKK@0H07fKK@03086YP@1bSF40LXeQ01<0LXeQ00<0
PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40
S02`h>H10?ooo`00R`2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0
PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0
PJV108BTM`24Y7L06P24Y7L00`21ZH40PZ9d08:RM00J08:RM003086YP@1mVfd0OI]]01P0OI]]00<0
PJV107:=H@1bSF404`1bSF400`21ZH40HWM@069gD00>069gD003086YP@1>GT00CUi000L0CUi000<0
PJV102hd9@0^=2D00P0^=2D00`21ZH40/>3V0;3PiP290;3PiP40oooo002;0;3PiP05086YP@0]=2h0
;C@^02dd;P21ZH402P1DIU400`21ZH40KXMW06j7I`0=06j7I`03086YP@1kVG80NiUb01@0NiUb00<0
PJV108:RM`22XWL05`22XWL00`21ZH40Q:Ag08BTM`0K08BTM`03086YP@22XW@0PZ9d01/0PZ9d00<0
PJV107fKK@1mVfd05`1mVfd00`21ZH40LXeQ07:=H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0
PJV104iN@01>GT00201>GT001@21ZH40;S@U02hd9@0^=2D0PJV108/0/>3V0@3oool008X0/>3V00<0
PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AVD@0705AVD@03086YP@1^QfL0KXMW00h0KXMW00<0
PJV107^ILP1kVG80501kVG800`21ZH40PZ9g08:RM`0G08:RM`03086YP@24Y7L0Q:Ag01/0Q:Ag00<0
PJV108:RM022XW@06`22XW@00`21ZH40OI]]07fKK@0G07fKK@03086YP@1bSF40LXeQ01@0LXeQ00<0
PJV1069gD01RMe003P1RMe000`21ZH40CUi004iN@00704iN@005086YP@0^=2D0;S@U02hd9@21ZH40
R`2`h>H10?ooo`00RP2`h>H00`21ZH40;C@^02dd;P0202dd;P03086YP@1DIU40E6IA00L0E6IA00<0
PJV106j7I`1^QfL03P1^QfL00`21ZH40NiUb07^ILP0C07^ILP03086YP@22XWL0PZ9g01P0PZ9g00<0
PJV108BTM`24Y7L03@24Y7LM086YP@l0PZ9d00<0PJV107fKK@1mVfd0601mVfd00`21ZH40LXeQ07:=
H@0C07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd
9@0202hd9@03086YP@2`h>H0/>3V08P0/>3V0@3oool008X0/>3V00D0PJV102dd;P0]=2h0;C@^086Y
P@0905AVD@03086YP@1^QfL0KXMW00l0KXMW00<0PJV107^ILP1kVG804`1kVG800`21ZH40PZ9g08:R
M`0;08:RMad0PJV13P2>]8<00`21ZH40SK6008faP00<08faP1d0PJV13@1mVfd00`21ZH40LXeQ07:=
H@0C07:=H@03086YP@1RMe00HWM@00l0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd
9@0^=2D0PJV108X0/>3V0@3oool008T0/>3V00<0PJV102dd;P0]=2h00P0]=2h00`21ZH40E6IA05AV
D@0705AVD@03086YP@1^QfL0KXMW00h0KXMW00<0PJV107^ILP1kVG802@1kVG8I086YP@d0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i00/0Qj]i6@21
ZH4;07:=H@03086YP@1RMe00HWM@00h0HWM@00<0PJV104iN@01>GT001`1>GT000`21ZH40;S@U02hd
9@0202hd9@03086YP@2`h>H0/>3V08L0/>3V0@3oool008T0/>3V00D0PJV102dd;P0]=2h0;C@^086Y
P@0905AVD@03086YP@1^QfL0KXMW00L0KXMW5021ZH4;08N[P003086YP@2=/X@0SK:401P0SK:400<0
PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01P0Qj]i00<0
PJV107jNKP1nWVh02@1nWVhD086YP@T0HWM@00<0PJV104iN@01>GT001`1>GT001@21ZH40;S@U02hd
9@0^=2D0PJV108T0/>3V0@3oool008H0/>3V0P3oO`000`2`h>H0PJV102dd;P0202dd;P03086YP@1D
IU40E6IA00D0E6IA3021ZH4807^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@0602=
/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06027
ZgT00`21ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00H0KHQL3021ZH4704iN@005086YP@0^
=2D0;S@U02hd9@21ZH40R@2`h>H10?ooo`00QP2`h>H20?mo0005086YP@0]=2h0;C@^02dd;P21ZH40
0P1DIU46086YP@80I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P003086Y
P@2=/X@0SK:401P0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086Y
P@27ZgT0Qj]i01P0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8G003086Y
P@1GK4P0Efa800H0PJV10P1>GT001@21ZH40;S@U02hd9@0^=2D0PJV108P0/>3V0@3oool008H0/>3V
0P3oO`000`21ZH40;C@^02dd;P04086YP@P0I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21ZH40Qj^0
08N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK60
08faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL
06f8G00>06f8G003086YP@1GK4P0Efa800H0Efa81021ZH4202hd9@03086YP@2`h>H0/>3V08H0/>3V
0@3oool008H0/>3V00<0ogl0086YP@0]=2h00P21ZH400`0kB3h0PJV106AlHP0806AlHP03086YP@1k
VgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>
]8<0S[B301/0S[B300<0PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1n
WVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00705M/B006086YP@0g
@Rh0PJV1086YP@0^=2D0PJV1Q`2`h>H10?ooo`00QP2`h>H00`3oO`00PJV1086YP@0203]8?P03086Y
P@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00D08N[P003086Y
P@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<06`2>]8<00`21ZH40SK6008faP00K08faP003086Y
P@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501nWVh00`21ZH40KHQL06f8G00?06f8G003086Y
P@1GK4P0Efa800L0Efa800@0PJV103M2;P0g@Rh0=d8^0P21ZH670;3PiP40oooo00260;3PiP030?mo
0021ZH40>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^KM`03086Y
P@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0K08jdP`03086Y
P@2=/H00SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0D07jNKP03086Y
P@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108L0
/>3V0@3oool008D0/>3V00<0ogl0086YP@0kB3h00`0kB3h00`21ZH40I7aR06AlHP0806AlHP03086Y
P@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh000`21ZH40SK:408fbQ00I08fbQ003086Y
P@2>]8<0S[B301/0S[B300<0PJV108faP02=/H006`2=/H000`21ZH40Qj]i08N[N@0I08N[N@03086Y
P@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`00`21ZH40Efa805M/B00805M/B003086Y
P@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q02`h>H20?mo0003086YP@0k
B3h0>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0>07^KM`03086YP@27
Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0K08jdP`03086YP@2=
/H00SK6001/0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@1]
R5`0KHQL00h0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`
h>H0/>3V08@0/>3V0@3oool008@0/>3V0P3oO`001@21ZH40>dPn03]8?P0kB3h0PJV100X0I7aR00<0
PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:401P0SK:400<0
PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00K08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0
PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800L0Efa800<0
PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP240;3PiP40oooo00240;3PiP80ogl000D0PJV1
03]8?P0kB3h0>dPn086YP@0:06AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027
Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=
/H000`21ZH40Qj]i08N[N@0H08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03`1]
R5`00`21ZH40Efa805M/B00805M/B005086YP@0g@Rh0=d8^03M2;P21ZH40QP2`h>H10?ooo`00Q02`
h>H00`3oO`00PJV103]8?P0303]8?P03086YP@1TO680I7aR00P0I7aR00<0PJV107^KM`1kVgL03`1k
VgL00`21ZH40Qj^008N[P00D08N[P003086YP@2=/X@0SK:401T0SK:400<0PJV108jdP`2>]8<0702>
]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i01T0Qj]i00<0PJV107jNKP1nWVh0501n
WVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0Efa800<0PJV103M2;P0g@Rh00P0g
@Rh00`21ZH40/>3V0;3PiP230;3PiP40oooo00230;3PiP80ogl000<0PJV103]8?P0kB3h00P0kB3h0
0`21ZH40I7aR06AlHP0806AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[P027Zh005027Zh00
0`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H00
0`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01@0OYi^00<0PJV106f8G01]R5`03`1]R5`0
0`21ZH40Efa805M/B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0P`2`h>H1
0?ooo`00P`2`h>H20?mo0005086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21ZH40Ni]g07^KM`0?
07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0L
08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0D
07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P02
03M2;P03086YP@2`h>H0/>3V08<0/>3V0@3oool008<0/>3V0P3oO`001@21ZH40>dPn03]8?P0kB3h0
PJV100/0I7aR00<0PJV107^KM`1kVgL03P1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0
SK:401T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0
Qj]i01T0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00>06f8G003086YP@1GK4P0
Efa800T0Efa800D0PJV103M2;P0g@Rh0=d8^086YP@250;3PiP40oooo00230;3PiP030?mo0021ZH40
>dPn00<0>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00
Qj^001D0Qj^000<0PJV108fbQ02=/X@06@2=/X@00`21ZH40S[B308jdP`0L08jdP`03086YP@2=/H00
SK6001`0SK6000<0PJV108N[N@27ZgT06@27ZgT00`21ZH40OYi^07jNKP0E07jNKP03086YP@1]R5`0
KHQL00l0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086YP@2`h>H0
/>3V0880/>3V0@3oool00880/>3V0P3oO`000`21ZH40>dPn03]8?P0203]8?P03086YP@1TO680I7aR
00P0I7aR00<0PJV107^KM`1kVgL03`1kVgL00`21ZH40Qj^008N[P00E08N[P003086YP@2=/X@0SK:4
01T0SK:400<0PJV108jdP`2>]8<0702>]8<00`21ZH40SK6008faP00L08faP003086YP@27ZgT0Qj]i
01T0Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa8
00P0Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP220;3PiP40oooo00220;3PiP80
ogl000D0PJV103]8?P0kB3h0>dPn086YP@0;06AlHP03086YP@1kVgL0Ni]g00l0Ni]g00<0PJV108N[
P027Zh005@27Zh000`21ZH40SK:408fbQ00I08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108fa
P02=/H00702=/H000`21ZH40Qj]i08N[N@0I08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8
G01]R5`03`1]R5`00`21ZH40Efa805M/B00805M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3P
iP2`h>H0PP2`h>H10?ooo`00PP2`h>H20?mo0005086YP@0kB3h0>dPn03]8?P21ZH402`1TO6800`21
ZH40Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001@0Qj^000<0PJV108fbQ02=/X@06P2=/X@00`21
ZH40S[B308jdP`0L08jdP`03086YP@2=/H00SK6001`0SK6000<0PJV108N[N@27ZgT06P27ZgT00`21
ZH40OYi^07jNKP0D07jNKP03086YP@1]R5`0KHQL00l0KHQL00<0PJV105M/B01GK4P02@1GK4P01@21
ZH40=d8^03M2;P0g@Rh0PJV108@0/>3V0@3oool00880/>3V00<0ogl0086YP@0kB3h00`0kB3h00`21
ZH40I7aR06AlHP0906AlHP03086YP@1kVgL0Ni]g00h0Ni]g00<0PJV108N[P027Zh005@27Zh000`21
ZH40SK:408fbQ00J08fbQ003086YP@2>]8<0S[B301`0S[B300<0PJV108faP02=/H00702=/H000`21
ZH40Qj]i08N[N@0J08N[N@03086YP@1nWVh0OYi^01D0OYi^00<0PJV106f8G01]R5`03P1]R5`00`21
ZH40Efa805M/B00905M/B003086YP@0g@Rh0=d8^0080=d8^00<0PJV10;3PiP2`h>H0P@2`h>H10?oo
o`00P@2`h>H20?mo0003086YP@0kB3h0>dPn0080>dPn00<0PJV106AlHP1TO680201TO6800`21ZH40
Ni]g07^KM`0?07^KM`03086YP@27Zh00Qj^001D0Qj^000<0PJV108fbQ02=/X@0302=/XAK086YP@h0
Qj]i00<0PJV107jNKP1nWVh05@1nWVh00`21ZH40KHQL06f8G00?06f8G003086YP@1GK4P0Efa800P0
Efa800<0PJV103M2;P0g@Rh00P0g@Rh00`21ZH40/>3V0;3PiP210;3PiP40oooo00220;3PiP030?mo
0021ZH40>dPn0080>dPn00<0PJV106AlHP1TO6802@1TO6800`21ZH40Ni]g07^KM`0707^KMbl0PJV1
3P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<0
302@^8<_086YP@T0KHQL00<0PJV105M/B01GK4P0201GK4P00`21ZH40=d8^03M2;P0203M2;P03086Y
P@2`h>H0/>3V0840/>3V0@3oool008<0/>3V100kB3h00`21ZH40I7aR06AlHP0406AlHPl0PJV12026
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G
`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00607RHJ0l0PJV11P1GK4P01@21ZH40=d8^03M2;P0g@Rh0PJV108<0/>3V
0@3oool00880/>3V00<0PJV103]8?P0kB3h02@21ZH45072?L@03086YP@26Zh<0QZ^300l0QZ^300<0
PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0
PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0
PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0305igCPT0PJV10P0g@Rh00`21ZH40/>3V0;3P
iP200;3PiP40oooo00220;3PiP<0PJV10P18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0
QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0
Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0
Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0
?Thd00<0PJV1PP2`h>H10?ooo`00PP2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03
086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03
086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03
086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03
086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003
086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma
072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>
09JoSP0J09JoSP03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3
092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>
05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`
h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G
`8d00`21ZH40UKj909FnR@0L09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0n
CS@00`21ZH40/>3V0;3PiP200;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1
072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV1
09JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1
092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV1
05igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V0800/>3V0@3oool0
0840/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^3
00l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=
01`0Ul2=00<0PJV109FnR@2E_XT0702E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai
01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd
00<0?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0304QLCP03
086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03
086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d0702G`8d00`21ZH40UKj909FnR@0L09FnR@03
086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003
086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40
oooo00210;3PiP03086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^3
08J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06@2F_hh00`21ZH40Ul2=
09O0S@0M09O0S@03086YP@2E_XT0UKj901`0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai
08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd
03i>=00303i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00`18
G4h00`21ZH40L8ma072?L@08072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A
^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E
_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03P1h
V6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0O`2`
h>H10?ooo`00P@2`h>H00`21ZH40B5a>04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV1
08J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV1
09O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV1
08N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV1
03i>=00nCS@00P0nCS@00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>
0080B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;
01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj9
01d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX
00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V
07l0/>3V0@3oool00840/>3V00<0PJV104QLCP18G4h00P18G4h00`21ZH40L8ma072?L@09072?L@03
086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03
086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03
086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03
086YP@0nCS@0?Thd0080?Thd00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40B5a>
04QLCP0204QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;
096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj9
09FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX
07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00P0nCS@00`21ZH40/>3V
0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@18G4h0B5a>0080B5a>00<0PJV1072?L@1`Sg402@1`
Sg400`21ZH40QZ^308J[P`0?08J[P`03086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F
_hh00`21ZH40Ul2=09O0S@0M09O0S@03086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@
^8<00`21ZH40Qjai08N/N@0E08N/N@03086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1N
Mdh00`21ZH40?Thd03i>=00203i>=003086YP@2`h>H0/>3V07l0/>3V0@3oool00800/>3V00<0PJV1
04QLCP18G4h00`18G4h00`21ZH40L8ma072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1
096iR`2A^H/05@2A^H/00`21ZH40U[n>09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV1
09FnR@2E_XT07@2E_XT00`21ZH40T;R3092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV1
07RHJ01hV6P03`1hV6P00`21ZH40GWM>05igCP0905igCP03086YP@0nCS@0?Thd0080?Thd00<0PJV1
0;3PiP2`h>H0O`2`h>H10?ooo`00P02`h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma
00T0L8ma00<0PJV108J[P`26Zh<03`26Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>
01X0U[n>00<0PJV109O0S@2G`8d07@2G`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R3
01X0T;R300<0PJV108N/N@27[7T05@27[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>
00T0GWM>00<0PJV103i>=00nCS@00`0nCS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03
086YP@18G4h0B5a>00<0B5a>00<0PJV1072?L@1`Sg402@1`Sg400`21ZH40QZ^308J[P`0?08J[P`03
086YP@2A^H/0TKV;01D0TKV;00<0PJV109JoSP2F_hh06P2F_hh00`21ZH40Ul2=09O0S@0M09O0S@03
086YP@2E_XT0UKj901d0UKj900<0PJV1092hP`2@^8<06P2@^8<00`21ZH40Qjai08N/N@0E08N/N@03
086YP@1hV6P0N9QX00l0N9QX00<0PJV105igCP1NMdh02@1NMdh00`21ZH40?Thd03i>=00303i>=003
086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V00<0PJV104QLCP18G4h00`18G4h00`21ZH40L8ma
072?L@09072?L@03086YP@26Zh<0QZ^300l0QZ^300<0PJV1096iR`2A^H/05@2A^H/00`21ZH40U[n>
09JoSP0J09JoSP03086YP@2G`8d0Ul2=01d0Ul2=00<0PJV109FnR@2E_XT07@2E_XT00`21ZH40T;R3
092hP`0J092hP`03086YP@27[7T0Qjai01D0Qjai00<0PJV107RHJ01hV6P03`1hV6P00`21ZH40GWM>
05igCP0905igCP03086YP@0nCS@0?Thd00<0?Thd00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`
h>H00`21ZH40B5a>04QLCP0304QLCP03086YP@1`Sg40L8ma00T0L8ma00<0PJV108J[P`26Zh<03`26
Zh<00`21ZH40TKV;096iR`0E096iR`03086YP@2F_hh0U[n>01X0U[n>00<0PJV109O0S@2G`8d07@2G
`8d00`21ZH40UKj909FnR@0M09FnR@03086YP@2@^8<0T;R301X0T;R300<0PJV108N/N@27[7T05@27
[7T00`21ZH40N9QX07RHJ00?07RHJ003086YP@1NMdh0GWM>00T0GWM>00<0PJV103i>=00nCS@00`0n
CS@00`21ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3Pi_<0PJV1P02`h>H10?ooo`00P02`h>H00`21
ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21
ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21
ZH40/>3V0;3PiP1n0;3PiP40oooo00200;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01i
WG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2L
bIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G
`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01V
PeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07h0/>3V0@3oool00800/>3V
00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=
00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E
00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR2
00<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi
00<0PJV10;3PiP2`h>H0OP2`h>H10?ooo`00P02`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1i
WG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2L
bIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G
`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1V
PeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1n0;3PiP40oooo0020
0;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?
08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M
09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E
08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@02
04=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21
ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21
ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21
ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21
ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?oo
o`00P@2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>
^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2M
biD07@2MbiD00`21ZH40VlRB09_8TP0M09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?
^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13
EcT00P13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK0080DVaK
00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD
00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB
00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb
00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V07l0/>3V
0@3oool00840/>3V00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>
^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2M
biD0WL^E01d0WL^E00<0PJV109_8TP2Kb9807@2Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?
^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13
EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`02
059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E
09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD07@2MbiD00`21ZH40VlRB09_8TP0M
09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?
082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP1o
0;3PiP40oooo00210;3PiP03086YP@1BK5/0DVaK00<0DVaK00<0PJV107VMO01iWG`0201iWG`00`21
ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21
ZH40WL^E09g;U@0M09g;U@03086YP@2Kb980VlRB01d0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21
ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00h0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21
ZH40@eLi04=G>@0304=G>@03086YP@2`h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1B
K5/00`1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02H
a9@05@2Ha9@00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiD0WL^E01d0WL^E00<0PJV109_8TP2K
b980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20
YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0@eLi00<0PJV10;3PiP2`
h>H0O`2`h>H10?ooo`00P@2`h>H00`21ZH40DVaK059/F`03059/F`03086YP@1iWG`0NIel00T0NIel
00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF
00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<
00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H
00<0PJV104=G>@13EcT00`13EcT00`21ZH40/>3V0;3PiP1o0;3PiP40oooo00210;3PiP03086YP@1B
K5/0DVaK00<0DVaK00<0PJV107VMO01iWG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2H
a9@0V<BD01D0V<BD00<0PJV109c9UP2LbIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2K
b980VlRB01`0VlRB00<0PJV109O2S02G`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20
YG80P:Eb00l0P:Eb00<0PJV106J3F01VPeP02@1VPeP00`21ZH40@eLi04=G>@0304=G>@03086YP@2`
h>H0/>3V07l0/>3V0@3oool00840/>3V00<0PJV1059/F`1BK5/00`1BK5/00`21ZH40NIel07VMO009
07VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J
09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J
09O2S003086YP@2?^880SkR201D0SkR200<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F009
06J3F003086YP@13EcT0@eLi0080@eLi00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21
ZH40DVaK059/F`02059/F`03086YP@1iWG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21
ZH40/>3V0;3PiP200;3PiP40oooo00220;3PiP03086YP@1BK5/0DVaK0080DVaK00<0PJV107VMO01i
WG`02@1iWG`00`21ZH40S[R=08jhS@0?08jhS@03086YP@2Ha9@0V<BD01D0V<BD00<0PJV109c9UP2L
bIH06P2LbIH00`21ZH40WL^E09g;U@0L09g;U@03086YP@2Kb980VlRB01`0VlRB00<0PJV109O2S02G
`X`06P2G`X`00`21ZH40SkR208nhPP0E08nhPP03086YP@20YG80P:Eb00l0P:Eb00<0PJV106J3F01V
PeP02@1VPeP00`21ZH40@eLi04=G>@0204=G>@03086YP@2`h>H0/>3V0800/>3V0@3oool00880/>3V
00<0PJV1059/F`1BK5/00P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=
00<0PJV109S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E
00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR2
00<0PJV1082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi0080@eLi
00<0PJV10;3PiP2`h>H0P02`h>H10?ooo`00PP2`h>H00`21ZH40DVaK059/F`02059/F`03086YP@1i
WG`0NIel00T0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21ZH40V<BD09S4U00E09S4U003086YP@2L
bIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21ZH40VlRB09_8TP0L09_8TP03086YP@2G
`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21ZH40P:Eb082ULP0?082ULP03086YP@1V
PeP0IX=H00T0IX=H00<0PJV104=G>@13EcT00P13EcT00`21ZH40/>3V0;3PiP200;3PiP40oooo0022
0;3PiP<0PJV10P1BK5/00`21ZH40NIel07VMO00907VMO003086YP@2>^8d0S[R=00l0S[R=00<0PJV1
09S4U02Ha9@05@2Ha9@00`21ZH40W<VF09c9UP0J09c9UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV1
09_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00J09O2S003086YP@2?^880SkR201D0SkR200<0PJV1
082ULP20YG803`20YG800`21ZH40IX=H06J3F00906J3F003086YP@13EcT0@eLi00<0PJV1PP2`h>H1
0?ooo`00PP2`h>H00`21ZH40FGQT05UhI008086YP@H0NIel00<0PJV108jhS@2>^8d03`2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP0?082ULP03086YP@1VPeP0IX=H00@0IX=H2021ZH4204EL?003086YP@2`h>H0/>3V
0800/>3V0@3oool008<0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0507nXQ@l0PJV12@2>^8d00`21
ZH40V<BD09S4U00E09S4U003086YP@2LbIH0W<VF01X0W<VF00<0PJV109g;U@2MbiD0702MbiD00`21
ZH40VlRB09_8TP0L09_8TP03086YP@2G`X`0Ul:<01X0Ul:<00<0PJV108nhPP2?^8805@2?^8800`21
ZH40P:Eb082ULP07082ULPl0PJV11@1/SV400`21ZH40AE`l04EL?00204EL?8<0/>3V0@3oool008<0
/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00H0U<:E<021ZH4>09c9
UP03086YP@2MbiD0WL^E01`0WL^E00<0PJV109_8TP2Kb980702Kb9800`21ZH40Ul:<09O2S00<09O2
S300PJV12026[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3P
iP2`h>H0P@2`h>H10?ooo`00P`2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0
OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M00`0
X]:MF`21ZH4>09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40
K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0P@2`h>H10?ooo`00
P`2`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500T0OjR500<0PJV109C2U@2D`YD0
3P2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01X0X]:M00<0PJV10:;CW02Rdi`0
702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01X0W<^C00<0PJV109C1RP2D`HX0
5@2D`HX00`21ZH40QZmj08J_NP0>08J_NP03086YP@1/SV40K8iQ00T0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP210;3PiP40oooo00240;3PiP05086YP@1IN6@0FGQT05UhI021ZH40
2`1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd0
6P2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0PJV109c;T`2Lbi<0
6P2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40
2@1/SV401@21ZH40AE`l04EL?015G3`0PJV108@0/>3V0@3oool008@0/>3V00D0PJV105UhI01IN6@0
FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00l0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40
X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40
W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40
K8iQ06b>H@0806b>H@03086YP@15G3`0AE`l0080AE`l00<0PJV10;3PiP2`h>H0PP2`h>H10?ooo`00
Q02`h>H00`21ZH40FGQT05UhI00205UhI003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD0
3`2D`YD00`21ZH40W/jK09k>V`0E09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0
702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0
5@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP220;3PiP40oooo00240;3PiP03086YP@1IN6@0FGQT0080FGQT00<0
PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0
PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0
PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V0880/>3V0@3o
ool008D0/>3V00D0PJV105UhI01IN6@0FGQT086YP@0;07nXQ@03086YP@2D`YD0U<:E00h0U<:E00<0
PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0X]>L01`0X]>L00<0
PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0U<6:01D0U<6:00<0
PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0906b>H@05086YP@15G3`0AE`l04EL?021ZH40
Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40FGQT05UhI01IN6@0PJV100/0OjR500<0PJV109C2U@2D`YD0
3`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`0
702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0
502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`0
0P15G3`00`21ZH40/>3V0;3PiP230;3PiP40oooo00250;3PiP03086YP@1IN6@0FGQT0080FGQT00<0
PJV107nXQ@1oZ8D0201oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0
PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01`0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0
PJV106b>H@1/SV40201/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08<0/>3V0@3o
ool008D0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0
U<:E00l0U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0
X]>L01`0X]>L00<0PJV10:7AV02QdIP0702QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0
U<6:01@0U<6:00<0PJV108J_NP26[gX03`26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0
AE`l0080AE`l00<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00QP2`h>H01@21ZH40FGQT05UhI01IN6@0
PJV100X0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0
X]:M01T0X]:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6H0:7AV00L0:7AV003086YP@2Lbi<0
W<^C01P0W<^C00<0PJV109C1RP2D`HX05@2D`HX00`21ZH40QZmj08J_NP0?08J_NP03086YP@1/SV40
K8iQ00P0K8iQ00D0PJV104EL?015G3`0AE`l086YP@260;3PiP40oooo00260;3PiP05086YP@1IN6@0
FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01D0W/jK00<0
PJV10:;BW@2RdYd0602RdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0E09C1RP03086YP@26[gX0QZmj00l0QZmj00<0
PJV106b>H@1/SV401`1/SV400`21ZH40AE`l04EL?00204EL?003086YP@2`h>H0/>3V08@0/>3V0@3o
ool008H0/>3V00<0PJV105UhI01IN6@00P1IN6@00`21ZH40OjR507nXQ@0807nXQ@03086YP@2D`YD0
U<:E00h0U<:E00<0PJV109k>V`2NcY/05@2NcY/00`21ZH40X]:M0:;BW@0I0:;BW@03086YP@2Rdi`0
X]>L01/0X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0I09c;T`03086YP@2D`HX0
U<6:01D0U<6:00<0PJV108J_NP26[gX03P26[gX00`21ZH40K8iQ06b>H@0806b>H@03086YP@15G3`0
AE`l0080AE`l00<0PJV10000002`h>H0Q02`h>H10?ooo`00QP2`h>H00`21ZH40FGQT05UhI00205Uh
I003086YP@1oZ8D0OjR500P0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>
V`03086YP@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7A
V003086YP@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_
NP03086YP@1/SV40K8iQ00P0K8iQ00<0PJV104EL?015G3`00P15G3`00`21ZH400000000000240;3P
iP40oooo00270;3PiP05086YP@1IN6@0FGQT05UhI021ZH402P1oZ8D00`21ZH40U<:E09C2U@0?09C2
U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K0:;C
W003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1
RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV40201/SV401@21ZH40AE`l04EL?015G3`0
PJV100800000Q@2`h>H10?ooo`00Q`2`h>H2086YP@80FGQT00<0PJV107nXQ@1oZ8D0201oZ8D00`21
ZH40U<:E09C2U@0?09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0PJV10:;BW@2RdYd06@2RdYd00`21
ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0PJV109c;T`2Lbi<06@2Lbi<00`21
ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00l0QZmj00<0PJV106b>H@1/SV401`1/SV401P21
ZH40AE`l04EL?015G3`00000086YP@<00000Q02`h>H10?ooo`00Q`2`h>H01P21ZH40GH1[086YP@21
ZH40FGQT086YP@T0OjR500<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086Y
P@2RdYd0X]:M01T0X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086Y
P@2Lbi<0W<^C01T0W<^C00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0?08J_NP03086Y
P@1/SV40K8iQ00L0K8iQ00<0000004EL?021ZH401@0000250;3PiP40oooo00280;3PiP03086YP@1M
P6/0GH1[00@0PJV1201oZ8D00`21ZH40U<:E09C2U@0>09C2U@03086YP@2NcY/0W/jK01@0W/jK00<0
PJV10:;BW@2RdYd06@2RdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIP0XM6H01/0XM6H00<0
PJV109c;T`2Lbi<06@2Lbi<00`21ZH40U<6:09C1RP0D09C1RP03086YP@26[gX0QZmj00h0QZmj00<0
PJV106b>H@1/SV400P1/SV401@000000K8iQ06b>H@1/SV40PJV100<0000000<0Af90000000000000
0`0000250;3PiP40oooo00280;3PiP05086YP@1MP6/0GH1[05f0J`21ZH400P23[h/6086YP@80OjR5
00<0PJV109C2U@2D`YD03`2D`YD00`21ZH40W/jK09k>V`0D09k>V`03086YP@2RdYd0X]:M01P0X]:M
00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0W<^C
00<0PJV109C1RP2D`HX0502D`HX00`21ZH40QZmj08J_NP0608J_NP0300000026[gX0QZmj00@0QZmj
00<0000008J_NP21ZH400P1/SV401021ZH400000000000000002086YP@03072FJ000000000000080
Af90100000260;3PiP40oooo00290;3PiP05086YP@1MP6/0GH1[05f0J`21ZH401`23[h/;086YP@T0
U<:E00<0PJV109k>V`2NcY/0502NcY/00`21ZH40X]:M0:;BW@0H0:;BW@03086YP@2Rdi`0X]>L01/0
X]>L00<0PJV10:7AV02QdIP06`2QdIP00`21ZH40W<^C09c;T`0H09c;T`03086YP@2D`HX0U<6:0180
U<6:00<0000009C1RP21ZH401`26[gX3000000@0PJV10`000003086YP@03072FJ0000000000000@0
L9IX0P0000000`17HT00000000000003000008H0/>3V0@3oool008T0/>3V00D0PJV105f0J`1MP6/0
GH1[086YP@0908>_R`03086YP@2GbI/0UlVK00H0UlVK5@21ZH4;09k>V`03086YP@2RdYd0X]:M01P0
X]:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6H0:7AV00K0:7AV003086YP@2Lbi<0W<^C01P0
W<^C00D0PJV109C1RP2D`HX0U<6:0000000209C1RP030000002D`HX0U<6:0080U<6:2021ZH430000
00P0PJV10P00000508ZfP@80000000<0R[J1086YP@1`UVP00P1`UVP2000000<0L9IX0`0000000`17
HT00000000000003000008H0/>3V0@3oool008T0/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40
Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:402@2Qe:4I086YP@d0
X]:M00<0PJV10:;CW02Rdi`06`2Rdi`01@21ZH40XM6H0:7AV02QdIP0000001P0XM6H00<00000086Y
P@2Lbi<0302Lbi<>086YP@X0000000<0PJV109S8T02Hb9001P2Hb9020000000309S8T021ZH40R[J1
00H0R[J10P00000508ZfP@80000000@0PJV1072FJ01`UVP0L9IX0`000003072FJ080000000<0Af90
0000000000000`0000270;3PiP40oooo002:0;3PiP05086YP@1MP6/0GH1[05f0J`21ZH402@23[h/0
0`21ZH40UlVK09O9V`0?09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<02`2UfJ<L
086YP@l0X]>L00D0PJV10:7AV02QdIP0XM6H0000000;0:7AV0d0PJV100<00000086YP@21ZH400`21
ZH42000000L0PJV13@2PdYT<000000P0V<R@0P0000000`21ZH40R[J108ZfP@0608ZfP@8000001@2:
]X4200000004086YP@1`UVP0L9IX072FJ0800000101`UVP20000000304MR@0000000000000<00000
Q`2`h>H10?ooo`00RP2`h>H00`21ZH40GH1[05f0J`0205f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0
PJV109O9V`2GbI/03P2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0YMVS01P0YMVS00<0
PJV10:KJXP2VfZ80302VfZ8C086YP@8000002P21ZH4<0:CHWP80000000@0PJV10:3BV@2PdYT0X=:I
0P00000D0:3BV@<00000202Hb903000000H0V<R@0`0000000`21ZH40R[J108ZfP@0508ZfP@<00000
102:]X43000000<0L9IX0`000003072FJ0<0000000<0Af900000000000000P0000280;3PiP40oooo
002:0;3PiP03086YP@1MP6/0GH1[0080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9
V`0>09O9V`03086YP@2Qe:40XMBQ01@0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJ
XP0K0:KJXP03086YP@2Tf9h0Y=RN0080Y=RN00<000000:CHWP2Tf9h04`2Tf9h2000000030:CHWP21
ZH40X=:I0080X=:I0P00000C0:3BV@<000002P2Hb903000000D0V<R@0P0000000`2Hb900PJV108Zf
P@0608ZfP@8000001@2:]X4200000004086YP@1`UVP0L9IX072FJ0800000101`UVP20000000304MR
@0000000000000<00000R02`h>H10?ooo`00R`2`h>H01@21ZH40GH1[05f0J`1MP6/0PJV100X0Pjn;
00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7DX@0D0:7DX@03086YP@2UfJ<0YMVS01L0YMVS
00<0PJV10:KJXP2VfZ806`2VfZ800`21ZH40Y=RN0:CHWP020:CHWP800000502Tf9h010000000Y=RN
0:CHWP21ZH430:3BV@8000004P2PdYT3000000`0V<R@00<0000009S8T02Hb900102Hb90200000003
086YP@2:]X40R[J100H0R[J10P00000508ZfP@800000101`UVP2000000<0L9IX0`0000000`17HT00
000000000002000008T0/>3V0@3oool008/0/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;
08>_R`0708>_R`03086YP@2GbI/0UlVK00h0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS
0:GIX`0H0:GIX`03086YP@2VfZ80Y]ZR01X0Y]ZR00<0PJV10:CHWP2Tf9h00`2Tf9h00`000000Y=RN
0:CHWP0A0:CHWP80000000<0Y=RN086YP@2PdYT00`2PdYT200000180X=:I0P0000000`21ZH40V<R@
09S8T00A09S8T080000000<0PJV108ZfP@2:]X401P2:]X42000000@0R[J10`000003072FJ0<00000
0`1`UVP200000080Af901@0000280;3PiP40oooo002<0;3PiP05086YP@1MP6/0GH1[05f0J`21ZH40
2@23[h/00`21ZH40UlVK09O9V`0>09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<0
602UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJXP03086YP@2Tf9h0Y=RN00<0Y=RN00<000000:CHWP2Tf9h0
4@2Tf9h010000000Y=RN0:CHWP21ZH440:3BV@8000004@2PdYT2000000030:3BV@21ZH40V<R@0140
V<R@0`0000000`21ZH40R[J108ZfP@0508ZfP@<00000102:]X4200000004086YP@1`UVP0L9IX072F
J0800000101`UVP20000000304MR@0000000000000<00000R@2`h>H10?ooo`00S02`h>H00`21ZH40
GH1[05f0J`0205f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40
XMBQ0:7DX@0D0:7DX@03086YP@2UfJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40
Y=RN0:CHWP030:CHWP8000004@2Tf9h200000080Y=RN00@0PJV10:3BV@2PdYT0X=:I0P00000A0:3B
V@80000000<0X=:I086YP@2Hb9004P2Hb9020000000309S8T021ZH40R[J100H0R[J10P00000508Zf
P@8000000`1`UVP3000000<0L9IX0`0000000`17HT00000000000002000008X0/>3V0@3oool008`0
/>3V00<0PJV105f0J`1MP6/00P1MP6/00`21ZH40Pjn;08>_R`0708>_R`03086YP@2GbI/0UlVK00h0
UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR01X0
Y]ZR00<0PJV10:CHWP2Tf9h0102Tf9h00`000000Y=RN0:CHWP0?0:CHWP050000002Tf9h0Y=RN0:CH
WP21ZH400`2PdYT200000100X=:I0P0000020:3BV@03086YP@2Hb900V<R@0140V<R@0P0000000`21
ZH40R[J108ZfP@0608ZfP@8000001@2:]X42000000<0L9IX0P000004072FJ08000000P17HT040000
08X0/>3V0@3oool008d0/>3V00D0PJV105f0J`1MP6/0GH1[086YP@0:08>_R`03086YP@2GbI/0UlVK
00d0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0G0:GIX`03086YP@2VfZ80Y]ZR
01X0Y]ZR00<0PJV10:CHWP2Tf9h0102Tf9h2000000l0Y=RN0P0000030:CHWP04086YP@2PdYT0X=:I
0:3BV@800000402PdYT200000080X=:I00<0PJV109S8T02Hb900402Hb90300000003086YP@2:]X40
R[J100H0R[J10P00000408ZfP@<000000`1`UVP2000000<0L9IX2@00002:0;3PiP40oooo002=0;3P
iP03086YP@1MP6/0GH1[0080GH1[00<0PJV108>_R`23[h/01`23[h/00`21ZH40UlVK09O9V`0=09O9
V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0J0:KJ
XP03086YP@2Tf9h0Y=RN00@0Y=RN4P0000040:CHWP04086YP@2PdYT0X=:I0:3BV@800000402PdYT3
000000030:3BV@21ZH40V<R@0140V<R@0P0000000`2Hb900PJV108ZfP@0608ZfP@<00000102:]X42
000000<0L9IX0`000002072FJ0L00000S@2`h>H10?ooo`00SP2`h>H01@21ZH40GH1[05f0J`1MP6/0
PJV100T0Pjn;00<0PJV109O9V`2GbI/03P2GbI/00`21ZH40XMBQ0:7DX@0C0:7DX@03086YP@2UfJ<0
YMVS01H0YMVS00<0PJV10:KJXP2VfZ806P2VfZ800`21ZH40Y=RN0:CHWP040:CHWQ4000001@2Tf9h0
1021ZH40X=:I0:3BV@2PdYT3000000l0X=:I0`0000000`21ZH40V<R@09S8T00909S8T0030000002H
b900V<R@00@0V<R@0`0000000`21ZH40R[J108ZfP@0608ZfP@8000001@2:]X400`000000PJV1072F
J002072FJ0L0000000@0Af900000000000000000SP2`h>H10?ooo`00SP2`h>H00`21ZH40GH1[05f0
J`0205f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7D
X@0C0:7DX@03086YP@2UfJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40Y=RN0:CH
WP050:CHWP800000302Tf9h2000000@0Y=RN00<0PJV10:3BV@2PdYT00P2PdYT300000100X=:I0P00
00000`21ZH40V<R@09S8T00909S8T0030000002Hb900V<R@00@0V<R@1000000708ZfP@8000001@2:
]X42000000@0L9IX1P00000404MR@003086YP@2`h>H0/>3V08`0/>3V0@3oool008l0/>3V0P21ZH42
05f0J`03086YP@23[h/0Pjn;00L0Pjn;00<0PJV109O9V`2GbI/03@2GbI/00`21ZH40XMBQ0:7DX@0C
0:7DX@03086YP@2UfJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ806@2VfZ800`21ZH40Y=RN0:CHWP05
0:CHWP8000002`2Tf9h2000000D0Y=RN00@0PJV10:3BV@2PdYT0X=:I1000000@0:3BV@<000002P2H
b902000000H0V<R@0P0000000`2Hb90000000000000408ZfP@@000001@2:]X400`000000PJV1072F
J003072FJ0030000001`UVP0L9IX0080L9IX00<0PJV104MR@017HT000P21ZH6?0;3PiP40oooo002?
0;3PiP06086YP@1NQ6d0PJV1086YP@1MP6/0PJV12@23[h/00`21ZH40UlVK09O9V`0<09O9V`03086Y
P@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086Y
P@2Tf9h0Y=RN00D0Y=RN0`00000:0:CHWP030000002Tf9h0Y=RN00@0Y=RN00@0PJV10:3BV@2PdYT0
X=:I1@00000@0:3BV@<00000202Hb902000000H0V<R@0`0000000`21ZH40000000000007000000H0
R[J100<00000072FJ01`UVP01`1`UVP01P21ZH40Af90086YP@21ZH40BFM5086YPHl0/>3V0@3oool0
0900/>3V00<0PJV105j4K@1NQ6d01021ZH4708>_R`03086YP@2GbI/0UlVK00d0UlVK00<0PJV10:7D
X@2Qe:404`2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CH
WP2Tf9h01`2Tf9h00`000000Y=RN0:CHWP070:CHWP8000001P2Tf9h01021ZH40X=:I0:3BV@2PdYT2
000000040:3BV@0000000000000000l0X=:I00<0PJV10000000000000P00000309S8T0D000001P2H
b9020000000309S8T021ZH40000000H00000202:]X400`21ZH40L9IX072FJ005072FJ0@0PJV10P19
IdD00`21ZH40/>3V0;3PiP2>0;3PiP40oooo002A0;3PiP06086YP@1NQ6d0GXA]05j4K@21ZH40Pk6=
1P21ZH4208>_R`03086YP@2GbI/0UlVK00`0UlVK00<0PJV10:7DX@2Qe:404`2Qe:400`21ZH40YMVS
0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0PJV10:CHWP2Tf9h01`2Tf9h2000000L0Y=RN
0P0000070:CHWP04086YP@2PdYT0X=:I0:3BV@8000000P2PdYT5000000`0X=:I00<0PJV109S8T000
00002@00000709S8T080000000<0V<R@086YP@2:]X403@2:]X400`21ZH40L9IX072FJ006086YP@03
076JK021ZH40BFM50080BFM500<0PJV10;3PiP2`h>H0S`2`h>H10?ooo`00T@2`h>H01@21ZH40GXA]
05j4K@1NQ6d0PJV100L0Pk6=1P21ZH4;09O9V`03086YP@2Qe:40XMBQ01<0XMBQ00<0PJV10:GIX`2U
fJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP0I0:KJXP03086YP@2Tf9h0Y=RN00P0Y=RN00<000000:CHWP2T
f9h01@2Tf9h00`000000Y=RN0:CHWP060:CHWP04086YP@2PdYT0X=:I0:3BV@8000000`2PdYT80000
00P0X=:I00<0PJV109S8T02Hb9001P00000:09S8T080000000<0V<R@086YP@2:]X402P2:]X42086Y
P@0400000021ZH40PJV1086YP@L0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2A0;3PiP40oooo002B
0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402@23/Hd00`21ZH40V<bN09S<WP08086YP@@0UlVK00<0
PJV10:7DX@2Qe:404P2Qe:400`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR01T0Y]ZR00<0
PJV10:CHWP2Tf9h0202Tf9h2000000D0Y=RN0P0000080:CHWP04086YP@2PdYT0X=:I0:3BV@800000
1@2PdYT6000000P0X=:I00<0PJV109S8T02Hb9003`2Hb90300000003086YP@2:]X40R[J10080R[J1
2021ZH40102;^XD00000000000000008076JK005086YP@19IdD0BFM504UWA@21ZH40TP2`h>H10?oo
o`00T`2`h>H01021ZH40GXA]05j4K@21ZH4908>aS@03086YP@2Hc9h0V<bN00P0V<bN2P21ZH4@0:7D
X@03086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40Y=RN0:CHWP090:CH
WP800000102Tf9h00`000000Y=RN0:CHWP060:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8
T02Hb9003P2Hb902086YP@8000001P21ZH4808^jQ@@000001`1aVV`01@21ZH40BFM504UWA@19IdD0
PJV109<0/>3V0@3oool009<0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0908>aS@03086YP@2Hc9h0
V<bN00/0V<bN00<0PJV10:?IY@2SfJD00`2SfJD;086YP@D0XMBQ00<0PJV10:GIX`2UfJ<05P2UfJ<0
0`21ZH40Y]ZR0:KJXP0H0:KJXP03086YP@2Tf9h0Y=RN00X0Y=RN00@000000:CHWP2Tf9h0Y=RN0P00
00080:CHWP03086YP@2PdYT0X=:I01H0X=:I00<0PJV109S8T02Hb9000`2Hb90;086YP@80VLbD0P00
00000`2Ic9@0PJV108^jQ@0;08^jQ@<00000201aVV`01@21ZH40BFM504UWA@19IdD0PJV109<0/>3V
0@3oool009@0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00`0V<bN
00<0PJV10:?IY@2SfJD03@2SfJDB086YP@`0YMVS00<0PJV10:KJXP2VfZ80602VfZ800`21ZH40Y=RN
0:CHWP0:0:CHWP8000000P2Tf9h00`000000Y=RN0:CHWP070:CHWP03086YP@2PdYT0X=:I00X0X=:I
4P21ZH4<09W<U0<0000000<0PJV108^jQ@2;^XD02`2;^XD2000000P0LIY/00D0PJV104UWA@19IdD0
BFM5086YP@2D0;3PiP40oooo002D0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402@23/Hd00`21ZH40
V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0180XmVU00<0PJV10:ONY`2WgZL02P2WgZLe086YP@04
00000021ZH400000000001H0PJV1302Reid00`21ZH40VLbD09W<U00@09W<U0030000002Ic9@0PJV1
00d0RkZ500<0PJV1076JK01aVV`01`1aVV`01@21ZH40BFM504UWA@19IdD0PJV109@0/>3V0@3oool0
09D0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2Hc9h0V<bN00`0V<bN00<0PJV1
0:?IY@2SfJD04P2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2XgjH0Z=nV01P0Z=nV00<0PJV1
0:KLXP2Vg:802`2Vg:83000000X0Y]bR00<0PJV10:;GW@2Reid05@2Reid00`21ZH40VLbD09W<U00B
09W<U003086YP@2;^XD0RkZ500`0RkZ500<0PJV1076JK01aVV`01P1aVV`01@21ZH40BFM504UWA@19
IdD0PJV109D0/>3V0@3oool009H0/>3V00D0PJV105j4K@1NQ6d0GXA]086YP@0808>aS@03086YP@2H
c9h0V<bN00/0V<bN00<0PJV10:?IY@2SfJD04P2SfJD00`21ZH40YmjW0:ONY`0E0:ONY`03086YP@2X
gjH0Z=nV01P0Z=nV00<0PJV10:KLXP2Vg:80302Vg:800`000000Y]bR0:KLXP090:KLXP03086YP@2R
eid0X]NM01D0X]NM00<0PJV109W<U02Ic9@04P2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1a
VV`0LIY/00H0LIY/00D0PJV104UWA@19IdD0BFM5086YP@2F0;3PiP40oooo002F0;3PiP05086YP@1N
Q6d0GXA]05j4K@21ZH402023/Hd00`21ZH40V<bN09S<WP0<09S<WP03086YP@2SfJD0XmVU0140XmVU
00<0PJV10:ONY`2WgZL05@2WgZL00`21ZH40Z=nV0:SOYP0H0:SOYP03086YP@2Vg:80Y]bR00`0Y]bR
00<000000:KLXP2Vg:80202Vg:800`21ZH40X]NM0:;GW@0F0:;GW@03086YP@2Ic9@0VLbD0140VLbD
00<0PJV108^jQ@2;^XD0302;^XD00`21ZH40LIY/076JK006076JK005086YP@19IdD0BFM504UWA@21
ZH40UP2`h>H10?ooo`00U`2`h>H01@21ZH40GXA]05j4K@1NQ6d0PJV100P0Pk6=00<0PJV109S<WP2H
c9h02`2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01H0YmjW00<0PJV10:SOYP2X
gjH05`2XgjH00`21ZH40Y]bR0:KLXP0G0:KLXP03086YP@2Reid0X]NM01H0X]NM00<0PJV109W<U02I
c9@04@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/00H0LIY/00D0PJV104UWA@19
IdD0BFM5086YP@2G0;3PiP40oooo002H0;3PiP04086YP@1NQ6d0GXA]086YP@P0Pk6=00<0PJV109S<
WP2Hc9h0302Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SO
YP2XgjH05`2XgjH00`21ZH40Y]bR0:KLXP0G0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<
U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0<08^jQ@03086YP@1aVV`0LIY/00D0LIY/00D0PJV104UW
A@19IdD0BFM5086YP@2H0;3PiP40oooo002H0;3PiP05086YP@1NQ6d0GXA]05j4K@21ZH402023/Hd0
0`21ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL05@2WgZL0
0`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid05@2Reid0
0`21ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01P1aVV`0
1@21ZH40BFM504UWA@19IdD0PJV109P0/>3V0@3oool009T0/>3V0P21ZH4205j4K@03086YP@23/Hd0
Pk6=00D0Pk6=00<0PJV109S<WP2Hc9h02`2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0
YmjW01D0YmjW00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40Y]bR0:KLXP0G0:KLXP03086YP@2Reid0
X]NM01D0X]NM00<0PJV109W<U02Ic9@04@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0
LIY/00D0LIY/00<0PJV104UWA@19IdD00P21ZH6I0;3PiP40oooo002J0;3PiP@0PJV12023/Hd00`21
ZH40V<bN09S<WP0;09S<WP03086YP@2SfJD0XmVU0140XmVU00<0PJV10:ONY`2WgZL0502WgZL00`21
ZH40Z=nV0:SOYP0G0:SOYP03086YP@2Vg:80Y]bR01L0Y]bR00<0PJV10:;GW@2Reid0502Reid00`21
ZH40VLbD09W<U00A09W<U003086YP@2;^XD0RkZ500/0RkZ500<0PJV1076JK01aVV`01P1aVV`4086Y
PIX0/>3V0@3oool009/0/>3V00<0PJV105^2K021ZH400P21ZH4608>aS@03086YP@2Hc9h0V<bN00/0
V<bN00<0PJV10:?IY@2SfJD04@2SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01L0
Z=nV00<0PJV10:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0E0:;GW@03086YP@2Ic9@0VLbD0140
VLbD00<0PJV108^jQ@2;^XD02`2;^XD00`21ZH40LIY/076JK004076JK0<0PJV100<0B6U8086YP@2`
h>H0VP2`h>H10?ooo`00W02`h>H00`21ZH40Fh9/05^2K004086YP@@0Pk6=00<0PJV109S<WP2Hc9h0
2`2Hc9h00`21ZH40XmVU0:?IY@0@0:?IY@03086YP@2WgZL0YmjW01D0YmjW00<0PJV10:SOYP2XgjH0
5P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086YP@2Reid0X]NM01D0X]NM00<0PJV109W<U02Ic9@0
402Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@03086YP@1aVV`0LIY/0080LIY/1021ZH4204QYB003086Y
P@2`h>H0/>3V09X0/>3V0@3oool009`0/>3V00D0PJV105^2K01KPV`0Fh9/086YP@0207j^R`D0PJV1
3@2Hc9h00`21ZH40XmVU0:?IY@0A0:?IY@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH0
5P2XgjH00`21ZH40Y]bR0:KLXP0F0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@0
4@2Ic9@00`21ZH40RkZ508^jQ@0;08^jQ@D0PJV10P1^VF`01@21ZH40B6U804QYB018JDP0PJV109`0
/>3V0@3oool009d0/>3V00@0PJV105^2K01KPV`0PJV11P1n[X/4086YP@/0V<bN00<0PJV10:?IY@2S
fJD0402SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:KLXP2V
g:805P2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD0100VLbD00<0PJV108^jQ@2;
^XD02@2;^XD4086YP@H0KYU/00@0PJV104QYB018JDP0PJV1W@2`h>H10?ooo`00WP2`h>H01021ZH40
Fh9/05^2K021ZH4707j^R`03086YP@2DbYd0PJV100@0PJV11P2Hc9h00`21ZH40XmVU0:?IY@0@0:?I
Y@03086YP@2WgZL0YmjW01@0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KLXP0F0:KL
XP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@0402Ic9@00`21ZH40RkZ508^jQ@0408^j
Q@D0PJV100<0R;V5086YP@1^VF`01P1^VF`01021ZH40B6U804QYB021ZH6N0;3PiP40oooo002O0;3P
iP04086YP@1KPV`0Fh9/086YP@L0OZj;00<0PJV109C:W@2DbYd00`2DbYd5086YP@80V<bN00<0PJV1
0:?IY@2SfJD03`2SfJD00`21ZH40YmjW0:ONY`0D0:ONY`03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV1
0:KLXP2Vg:805P2Vg:800`21ZH40X]NM0:;GW@0D0:;GW@03086YP@2Ic9@0VLbD00l0VLbD00<0PJV1
08^jQ@2;^XD01@21ZH4608RiQ@03086YP@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1W`2`
h>H10?ooo`00X02`h>H01021ZH40Fh9/05^2K021ZH4607j^R`03086YP@2DbYd0U<ZM00P0U<ZM3021
ZH490:?IY@03086YP@2WgZL0YmjW01<0YmjW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40Y]bR0:KL
XP0E0:KLXP03086YP@2Reid0X]NM01@0X]NM00<0PJV109W<U02Ic9@01`2Ic9@<086YP@X0R;V500<0
PJV106jIK01^VF`0101^VF`01021ZH40B6U804QYB021ZH6P0;3PiP40oooo002Q0;3PiP04086YP@1K
PV`0Fh9/086YP@H0OZj;00<0PJV109C:W@2DbYd02P2DbYd00`21ZH40X=RU0:3HY@060:3HY@l0PJV1
4@2WgZL00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2Vg:80Y]bR01D0Y]bR00<0PJV10:;GW@2Reid0
3`2Reid?086YP@P0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40KYU/06jIK00406jIK004086Y
P@18JDP0B6U8086YPJ40/>3V0@3oool00:80/>3V00<0PJV105^2K021ZH401`1n[X/00`21ZH40U<ZM
09C:W@0909C:W@03086YP@2Pf:D0X=RU00l0X=RU00<0PJV10:KNZ02VgZP00`2VgZP<086YP@D0YmjW
00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40Y]bR0:KLXP0E0:KLXP03086YP@2Reid0X]NM00<0X]NM
3021ZH450:7HWP03086YP@2HcID0V<fE00l0V<fE00<0PJV108RiQ@28^HD02@28^HD00`21ZH40KYU/
06jIK00506jIK003086YP@18JDP0PJV10:80/>3V0@3oool00:80/>3V00@0PJV105^2K01KPV`0PJV1
1`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU00l0X=RU00<0PJV10:KNZ02VgZP0
3P2VgZPk086YPA00XMRN00<0PJV109S=U@2HcID03`2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086Y
P@1^VF`0KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1XP2`h>H10?ooo`00X`2`h>H01021ZH40Fh9/
05^2K021ZH4707j^R`03086YP@2DbYd0U<ZM00T0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40
Y]jX0:KNZ00C0:KNZ003086YP@2Wh:L0Yn2W01D0Yn2W00<0PJV10:KNY02VgZ@05@2VgZ@00`21ZH40
XMRN0:7HWP0C0:7HWP03086YP@2HcID0V<fE00h0V<fE00<0PJV108RiQ@28^HD02P28^HD00`21ZH40
KYU/06jIK00406jIK004086YP@18JDP0B6U8086YPJ<0/>3V0@3oool00:@0/>3V00@0PJV105^2K01K
PV`0PJV11P1n[X/00`21ZH40U<ZM09C:W@0:09C:W@03086YP@2Pf:D0X=RU00h0X=RU00<0PJV10:KN
Z02VgZP04P2VgZP00`21ZH40Yn2W0:OPY`0E0:OPY`03086YP@2VgZ@0Y]jT01D0Y]jT00<0PJV10:7H
WP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0>09S=U@03086YP@28^HD0R;V500X0R;V500<0PJV106jI
K01^VF`0101^VF`01021ZH40B6U804QYB021ZH6T0;3PiP40oooo002U0;3PiP04086YP@1KPV`0Fh9/
086YP@H0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0
Y]jX01<0Y]jX00<0PJV10:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0
XMRN01<0XMRN00<0PJV109S=U@2HcID03P2HcID00`21ZH40R;V508RiQ@0908RiQ@03086YP@1^VF`0
KYU/00@0KYU/00@0PJV104QYB018JDP0PJV1Y@2`h>H10?ooo`00YP2`h>H3086YP@L0OZj;00<0PJV1
09C:W@2DbYd02@2DbYd00`21ZH40X=RU0:3HY@0>0:3HY@03086YP@2VgZP0Y]jX0180Y]jX00<0PJV1
0:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT0:KNY00D0:KNY003086YP@2Qf9h0XMRN0180XMRN00<0PJV1
09S=U@2HcID03P2HcID00`21ZH40R;V508RiQ@0:08RiQ@03086YP@1^VF`0KYU/00@0KYU/0`21ZH6V
0;3PiP40oooo002W0;3PiP<0PJV11`1n[X/00`21ZH40U<ZM09C:W@0909C:W@03086YP@2Pf:D0X=RU
00d0X=RU00<0PJV10:KNZ02VgZP04P2VgZP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2VgZ@0Y]jT
01@0Y]jT00<0PJV10:7HWP2Qf9h04P2Qf9h00`21ZH40V<fE09S=U@0=09S=U@03086YP@28^HD0R;V5
00X0R;V500<0PJV106jIK01^VF`0101^VF`3086YPJL0/>3V0@3oool00:T0/>3V0`21ZH4607j^R`03
086YP@2DbYd0U<ZM00P0U<ZM00<0PJV10:3HY@2Pf:D03P2Pf:D00`21ZH40Y]jX0:KNZ00A0:KNZ003
086YP@2Wh:L0Yn2W01@0Yn2W00<0PJV10:KNY02VgZ@0502VgZ@00`21ZH40XMRN0:7HWP0A0:7HWP03
086YP@2HcID0V<fE00h0V<fE00<0PJV108RiQ@28^HD02@28^HD00`21ZH40KYU/06jIK00306jIK0<0
PJV1Z@2`h>H10?ooo`00ZP2`h>H5086YP@<0OZj;00<0PJV109C:W@2DbYd02@2DbYd00`21ZH40X=RU
0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L0502Wh:L00`21ZH40Y]jT
0:KNY00C0:KNY003086YP@2Qf9h0XMRN0180XMRN00<0PJV109S=U@2HcID03@2HcID00`21ZH40R;V5
08RiQ@0908RiQ@04086YP@1^VF`0KYU/06jIK0D0PJV1ZP2`h>H10?ooo`00Z`2`h>H01021ZH40E7]V
086YP@1dY8<5086YP@/0U<ZM00<0PJV10:3HY@2Pf:D03@2Pf:D00`21ZH40Y]jX0:KNZ00A0:KNZ003
086YP@2Wh:L0Yn2W01<0Yn2W00<0PJV10:KNY02VgZ@04`2VgZ@00`21ZH40XMRN0:7HWP0A0:7HWP03
086YP@2HcID0V<fE00d0V<fE00<0PJV108RiQ@28^HD02P28^HD4086YP@0406JAJ021ZH40A6E8086Y
PJ/0/>3V0@3oool00:`0/>3V0`21ZH4407BTP`D0PJV1202DbYd00`21ZH40X=RU0:3HY@0<0:3HY@03
086YP@2VgZP0Y]jX0140Y]jX00<0PJV10:OPY`2Wh:L04`2Wh:L00`21ZH40Y]jT0:KNY00C0:KNY003
086YP@2Qf9h0XMRN0140XMRN00<0PJV109S=U@2HcID0302HcID00`21ZH40R;V508RiQ@0708RiQ@D0
PJV10`1VTFP3086YPJ`0/>3V0@3oool00:h0/>3V0`21ZH4407BTP`03086YP@2;`9H0Rl2F00H0PJV1
0P2DbYd00`21ZH40X=RU0:3HY@0=0:3HY@03086YP@2VgZP0Y]jX0100Y]jX00<0PJV10:OPY`2Wh:L0
4`2Wh:L00`21ZH40Y]jT0:KNY00C0:KNY003086YP@2Qf9h0XMRN0100XMRN00<0PJV109S=U@2HcID0
3@2HcID00`21ZH40R;V508RiQ@07086YP@80Ok6100@0PJV106JAJ01VTFP0IY5X0`21ZH6^0;3PiP40
oooo002_0;3PiP03086YP@1DNfH0PJV100@0M:B300<0PJV108_0UP2;`9H01@2;`9H7086YP@/0X=RU
00<0PJV10:KNZ02VgZP0402VgZP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2VgZ@0Y]jT01<0Y]jT
00<0PJV10:7HWP2Qf9h0402Qf9h00`21ZH40V<fE09S=U@0909S=U@L0PJV1201o/H401`21ZH40IY5X
06JAJ01VTFP0PJV104AUB021ZH40[`2`h>H10?ooo`00/02`h>H00`21ZH40E7]V086YP@0407BTP`03
086YP@2;`9H0Rl2F00P0Rl2F00<0PJV109SAX02HdJ002021ZH440:3HY@03086YP@2VgZP0Y]jX0100
Y]jX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40Y]jT0:KNY00B0:KNY003086YP@2Qf9h0XMRN0100
XMRN00<0PJV109S=U@2HcID00P2HcID8086YP@80T<JA00<0PJV107naP@1o/H40201o/H42086YP@<0
IY5X00<0PJV104AUB021ZH40/02`h>H10?ooo`00/@2`h>H4086YP@<0M:B300<0PJV108_0UP2;`9H0
202;`9H00`21ZH40V=6P09SAX00709SAX0h0PJV12@2VgZP00`21ZH40Yn2W0:OPY`0B0:OPY`03086Y
P@2VgZ@0Y]jT0180Y]jT00<0PJV10:7HWP2Qf9h01`2Qf9h>086YP@T0T<JA00<0PJV107naP@1o/H40
201o/H401021ZH40IY5X06JAJ01VTFP4086YPK40/>3V0@3oool00;<0/>3V00<0PJV105AkIP21ZH40
0`1dY8<00`21ZH40Rl2F08_0UP0808_0UP03086YP@2HdJ00V=6P00/0V=6P00<0PJV109oIY@2OfJD0
1P2OfJDm086YP@P0V]:L00<0PJV10936T@2@aY402`2@aY400`21ZH40Ok6107naP@0807naP@07086Y
P@1VTFP0IY5X06JAJ021ZH40A6E8086YP@2c0;3PiP40oooo002d0;3PiP<0PJV10`1dY8<2086YP@T0
Rl2F00<0PJV109SAX02HdJ002P2HdJ000`21ZH40WmVU09oIY@0?09oIY@03086YP@2QfjD0XM^U0180
XM^U00<0PJV10:3IXP2PfJ804P2PfJ800`21ZH40V]:L09[BW00?09[BW003086YP@2@aY40T<JA00X0
T<JA00<0PJV107naP@1o/H40201o/H401021ZH40IY5X06JAJ01VTFP3086YPK@0/>3V0@3oool00;D0
/>3V1021ZH4307BTP`03086YP@2;`9H0Rl2F00L0Rl2F00<0PJV109SAX02HdJ002P2HdJ000`21ZH40
WmVU09oIY@0?09oIY@03086YP@2QfjD0XM^U0140XM^U00<0PJV10:3IXP2PfJ804@2PfJ800`21ZH40
V]:L09[BW00?09[BW003086YP@2@aY40T<JA00X0T<JA00<0PJV107naP@1o/H40201o/H400`21ZH40
IY5X06JAJ004086YPKD0/>3V0@3oool00;L0/>3V1021ZH4207BTP`03086YP@2;`9H0Rl2F00H0Rl2F
00<0PJV109SAX02HdJ002`2HdJ000`21ZH40WmVU09oIY@0>09oIY@03086YP@2QfjD0XM^U0140XM^U
00<0PJV10:3IXP2PfJ804@2PfJ800`21ZH40V]:L09[BW00>09[BW003086YP@2@aY40T<JA00/0T<JA
00<0PJV107naP@1o/H401P1o/H42086YP@0306JAJ021ZH40PJV10080PJV1]`2`h>H10?ooo`00^@2`
h>H4086YP@0307BTP`21ZH40Rl2F00L0Rl2F00<0PJV109SAX02HdJ002`2HdJ000`21ZH40WmVU09oI
Y@0=09oIY@03086YP@2QfjD0XM^U0140XM^U00<0PJV10:3IXP2PfJ804@2PfJ800`21ZH40V]:L09[B
W00=09[BW003086YP@2@aY40T<JA00/0T<JA00<0PJV107naP@1o/H401P1o/H400`21ZH40IY5X086Y
P@03086YPKT0/>3V0@3oool00;/0/>3V1@21ZH4808_0UP03086YP@2HdJ00V=6P00X0V=6P00<0PJV1
09oIY@2OfJD03P2OfJD00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2PfJ80X=VR0100X=VR00<0PJV1
09[BW02JdY`03P2JdY`00`21ZH40T<JA0936T@0:0936T@03086YP@1o/H40Ok6100H0Ok611@21ZH6k
0;3PiP40oooo002l0;3PiPL0PJV11P2;`9H00`21ZH40V=6P09SAX00:09SAX003086YP@2OfJD0WmVU
00d0WmVU00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40X=VR0:3IXP0@0:3IXP03086YP@2JdY`0V]:L
00d0V]:L00<0PJV10936T@2@aY402P2@aY400`21ZH40Ok6107naP@0407naP@L0PJV1_02`h>H10?oo
o`00_P2`h>H;086YP@0308_0UP21ZH40V=6P00/0V=6P00<0PJV109oIY@2OfJD03@2OfJD00`21ZH40
XM^U0:7KY@0?0:7KY@03086YP@2PfJ80X=VR00l0X=VR00<0PJV109[BW02JdY`03@2JdY`00`21ZH40
T<JA0936T@0:0936T@03086YP@1o/H40PJV100X0PJV1_P2`h>H10?ooo`00`02`h>H5086YP@@0NZf8
1P21ZH4909SAX003086YP@2OfJD0WmVU00`0WmVU00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40X=VR
0:3IXP0?0:3IXP03086YP@2JdY`0V]:L00`0V]:L00<0PJV10936T@2@aY401`2@aY46086YP@@0L:1f
1@21ZH700;3PiP40oooo00320;3PiP80PJV100<0I99e086YP@21ZH401@1j[HP2086YP@0308RnT`21
ZH40PJV100D0PJV10P2HdJ000`21ZH40WmVU09oIY@0<09oIY@03086YP@2QfjD0XM^U00l0XM^U00<0
PJV10:3IXP2PfJ803`2PfJ800`21ZH40V]:L09[BW00<09[BW003086YP@2@aY40T<JA00L0PJV100<0
PKF6086YP@21ZH401@1`X7H2086YP@0305V2G`21ZH40PJV10<80/>3V0@3oool00<@0/>3V0P21ZH40
0`1TTWD0PJV107Z]R00507Z]R003086YP@28_Y<0R;jC00D0R;jC2`21ZH4709oIY@03086YP@2QfjD0
XM^U00h0XM^U00<0PJV10:3IXP2PfJ803P2PfJ800`21ZH40V]:L09[BW00509[BW0/0PJV11`21]HH0
0`21ZH40L:1f072PMP04072PMP04086YP@1IPUl0PJV1086YPL@0/>3V0@3oool00<D0/>3V1@21ZH45
07Z]R080PJV12@28_Y<00`21ZH40T<RI0938V@040938VC40PJV11P2<`i400`21ZH40PKF6086eQP07
086eQP80PJV11@1`X7H5086YPLD0/>3V0@3oool00<L0/>3V1@21ZH4507Z]R003086YP@28_Y<0R;jC
00L0R;jC00<0PJV10938V@2@b9T02`2@b9T00`21ZH40TlbK09?<V`0=09?<V`03086YP@2BbYP0T/ZH
00d0T/ZH00<0PJV108c3T@2<`i402`2<`i400`21ZH40PKF6086eQP07086eQP03086YP@1`X7H0L:1f
00<0L:1f1@21ZH770;3PiP40oooo003:0;3PiP@0PJV1101j[HP2086YP@P0R;jC00<0PJV10938V@2@
b9T02P2@b9T00`21ZH40TlbK09?<V`0=09?<V`03086YP@2BbYP0T/ZH00d0T/ZH00<0PJV108c3T@2<
`i402P2<`i400`21ZH40PKF6086eQP06086eQP80PJV1101`X7H4086YPLX0/>3V0@3oool00<d0/>3V
1021ZH4307Z]R003086YP@28_Y<0R;jC00H0R;jC0P21ZH4;0938V@03086YP@2Cc9/0TlbK00`0TlbK
00<0PJV109;:V02BbYP0302BbYP00`21ZH40S<>A08c3T@0908c3T@80PJV12021]HH01021ZH40L:1f
072PMP1`X7H4086YPLd0/>3V0@3oool00=00/>3V1`21ZH4808RnT`03086YP@2@b9T0T<RI00T0T<RI
00<0PJV109?<V`2Cc9/02`2Cc9/00`21ZH40T/ZH09;:V00;09;:V003086YP@2<`i40S<>A00T0S<>A
00<0PJV1086eQP21]HH01P21]HH7086YPM00/>3V0@3oool00=<0/>3V2@21ZH4408RnT`03086YP@2@
b9T0T<RI00T0T<RI00<0PJV109?<V`2Cc9/02P2Cc9/00`21ZH40T/ZH09;:V00:09;:V003086YP@2<
`i40S<>A00T0S<>A00<0PJV1086eQP21]HH00P21]HH9086YPM<0/>3V0@3oool00=H0/>3V4@21ZH45
0938V@03086YP@2Cc9/0TlbK00X0TlbK00<0PJV109;:V02BbYP02P2BbYP00`21ZH40S<>A08c3T@03
08c3T@/0PJV100<0J9Mb086YP@21ZH400`21ZH7F0;3PiP40oooo003I0;3PiPD0PJV1101]WW`2086Y
P@<0MJR29@21ZH4307:TO080PJV1101XUg85086YPMT0/>3V0@3oool00=`0/>3V1@21ZH4306fNO080
PJV1201eZ8800`21ZH40N:b407R/Q00807R/Q003086YP@1gZh80Mj^200P0Mj^200<0PJV107:TO01b
Y7`01P1bY7`2086YP@<0J9Mb1@21ZH7L0;3PiP40oooo003P0;3PiPP0PJV11`1eZ8800`21ZH40N:b4
07R/Q00707R/Q003086YP@1gZh80Mj^200L0Mj^200<0PJV107:TO01bY7`01@1bY7`8086YPN00/>3V
0@3oool00>H0/>3V1`21ZH4307FXPP03086YP@1h[8@0N:b400H0N:b400<0PJV107N[PP1gZh801P1g
Zh801021ZH40LZAl07:TO01bY7`7086YPNH0/>3V0@3oool00>d0/>3V6@21ZH7]0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.608 .781 .571 r
.47008 .46971 m .46978 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.608 .781 .571 r
.51009 .5 m .50999 .46977 L .47008 .46971 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.50999 .53023 m .51009 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.50999 .46977 m .51009 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.51009 .5 m .50999 .53023 L .5497 .53041 L p F P
.505 .664 .505 r
s
.595 .76 .558 r
.5497 .53041 m .5502 .5 L .51009 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.43078 .46941 m .43007 .5 L .46978 .5 L p F P
.505 .664 .505 r
s
.601 .771 .56 r
.46978 .5 m .47008 .46971 L .43078 .46941 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.47008 .53029 m .46978 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.592 .756 .551 r
.46978 .5 m .47008 .53029 L .50999 .53023 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.471 .43976 m .47008 .46971 L .50999 .46977 L p F P
.505 .664 .505 r
s
.622 .804 .589 r
.50999 .46977 m .50968 .43988 L .471 .43976 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.50968 .56012 m .50999 .53023 L .47008 .53029 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.50968 .43988 m .50999 .46977 L .5497 .46959 L p F P
.505 .664 .505 r
s
.611 .786 .578 r
.5502 .5 m .5497 .46959 L .50999 .46977 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.50999 .53023 m .50968 .56012 L .54817 .56047 L p F P
.505 .664 .505 r
s
.576 .732 .536 r
.54817 .56047 m .5497 .53041 L .50999 .53023 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.43291 .43918 m .43078 .46941 L .47008 .46971 L p F P
.505 .664 .505 r
s
.615 .795 .578 r
.47008 .46971 m .471 .43976 L .43291 .43918 L p F P
.505 .664 .505 r
s
.584 .746 .539 r
.43007 .5 m .43078 .53059 L .47008 .53029 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.471 .56024 m .47008 .53029 L .43078 .53059 L p F P
.505 .664 .505 r
s
.573 .727 .529 r
.47008 .53029 m .471 .56024 L .50968 .56012 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.5497 .46959 m .5502 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.5502 .5 m .5497 .53041 L .58839 .53084 L p F P
.505 .664 .505 r
s
.594 .759 .561 r
.58839 .53084 m .58931 .5 L .5502 .5 L p F P
.505 .664 .505 r
s
.625 .809 .596 r
.5497 .46959 m .54817 .43953 L .50968 .43988 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.54817 .43953 m .5497 .46959 L .58839 .46916 L p F P
.505 .664 .505 r
s
.611 .786 .582 r
.58931 .5 m .58839 .46916 L .5497 .46959 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.5497 .53041 m .54817 .56047 L .58564 .56129 L p F P
.505 .664 .505 r
s
.575 .729 .538 r
.58564 .56129 m .58839 .53084 L .5497 .53041 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.47252 .41051 m .471 .43976 L .50968 .43988 L p F P
.505 .664 .505 r
s
.634 .824 .605 r
.50968 .43988 m .50918 .41067 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.50918 .41067 m .50968 .43988 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.50918 .58933 m .50968 .56012 L .471 .56024 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.50968 .56012 m .50918 .58933 L .54563 .58982 L p F P
.505 .664 .505 r
s
.555 .699 .51 r
.54563 .58982 m .54817 .56047 L .50968 .56012 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.43648 .40968 m .43291 .43918 L .471 .43976 L p F P
.505 .664 .505 r
s
.627 .816 .595 r
.471 .43976 m .47252 .41051 L .43648 .40968 L p F P
.505 .664 .505 r
s
.565 .717 .517 r
.43078 .53059 m .43291 .56082 L .471 .56024 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.47252 .58949 m .471 .56024 L .43291 .56082 L p F P
.505 .664 .505 r
s
.552 .695 .503 r
.471 .56024 m .47252 .58949 L .50918 .58933 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.39291 .46886 m .39179 .5 L .43007 .5 L p F P
.505 .664 .505 r
s
.589 .756 .544 r
.43007 .5 m .43078 .46941 L .39291 .46886 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.43078 .53059 m .43007 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.39627 .43812 m .39291 .46886 L .43078 .46941 L p F P
.505 .664 .505 r
s
.604 .78 .564 r
.43078 .46941 m .43291 .43918 L .39627 .43812 L p F P
.505 .664 .505 r
s
.571 .729 .523 r
.39179 .5 m .39291 .53114 L .43078 .53059 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.43291 .56082 m .43078 .53059 L .39291 .53114 L p F P
.505 .664 .505 r
s
.638 .829 .613 r
.54817 .43953 m .54563 .41018 L .50918 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.54563 .41018 m .54817 .43953 L .58564 .43871 L p F P
.505 .664 .505 r
s
.625 .809 .601 r
.58839 .46916 m .58564 .43871 L .54817 .43953 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.54817 .56047 m .54563 .58982 L .58106 .59098 L p F P
.505 .664 .505 r
s
.552 .695 .511 r
.58106 .59098 m .58564 .56129 L .54817 .56047 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.58839 .46916 m .58931 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.58931 .5 m .58839 .53084 L .62519 .53151 L p F P
.505 .664 .505 r
s
.588 .751 .56 r
.62519 .53151 m .62652 .5 L .58931 .5 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.47466 .38233 m .47252 .41051 L .50918 .41067 L p F P
.505 .664 .505 r
s
.644 .842 .62 r
.50918 .41067 m .50846 .38253 L .47466 .38233 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.50846 .38253 m .50918 .41067 L .54563 .41018 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.50846 .61747 m .50918 .58933 L .47252 .58949 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.50918 .58933 m .50846 .61747 L .54206 .61807 L p F P
.505 .664 .505 r
s
.529 .66 .48 r
.54206 .61807 m .54563 .58982 L .50918 .58933 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.40187 .4082 m .39627 .43812 L .43291 .43918 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.43291 .43918 m .43648 .40968 L .40187 .4082 L p F P
.505 .664 .505 r
s
.552 .698 .499 r
.39291 .53114 m .39627 .56188 L .43291 .56082 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.43648 .59032 m .43291 .56082 L .39627 .56188 L p F P
.505 .664 .505 r
s
.543 .684 .491 r
.43291 .56082 m .43648 .59032 L .47252 .58949 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.44147 .38133 m .43648 .40968 L .47252 .41051 L p F P
.505 .664 .505 r
s
.638 .834 .61 r
.47252 .41051 m .47466 .38233 L .44147 .38133 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.58564 .43871 m .58839 .46916 L .62519 .46849 L p F P
.505 .664 .505 r
s
.606 .779 .582 r
.62652 .5 m .62519 .46849 L .58839 .46916 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.58839 .53084 m .58564 .56129 L .62122 .56259 L p F P
.505 .664 .505 r
s
.567 .719 .535 r
.62122 .56259 m .62519 .53151 L .58839 .53084 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.47466 .61767 m .47252 .58949 L .43648 .59032 L p F P
.505 .664 .505 r
s
.526 .657 .474 r
.47252 .58949 m .47466 .61767 L .50846 .61747 L p F P
.505 .664 .505 r
s
.648 .847 .627 r
.54563 .41018 m .54206 .38193 L .50846 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.54206 .38193 m .54563 .41018 L .58106 .40902 L p F P
.505 .664 .505 r
s
.638 .83 .617 r
.58564 .43871 m .58106 .40902 L .54563 .41018 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.54563 .58982 m .54206 .61807 L .57465 .61947 L p F P
.505 .664 .505 r
s
.525 .655 .48 r
.57465 .61947 m .58106 .59098 L .54563 .58982 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.58106 .40902 m .58564 .43871 L .62122 .43741 L p F P
.505 .664 .505 r
s
.621 .804 .602 r
.62519 .46849 m .62122 .43741 L .58564 .43871 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.58564 .56129 m .58106 .59098 L .61461 .59279 L p F P
.505 .664 .505 r
s
.543 .683 .506 r
.61461 .59279 m .62122 .56259 L .58564 .56129 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.35742 .46806 m .35589 .5 L .39179 .5 L p F P
.505 .664 .505 r
s
.57 .732 .522 r
.39179 .5 m .39291 .46886 L .35742 .46806 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.39291 .53114 m .39179 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.40969 .37953 m .40187 .4082 L .43648 .40968 L p F P
.505 .664 .505 r
s
.628 .822 .598 r
.43648 .40968 m .44147 .38133 L .40969 .37953 L p F P
.505 .664 .505 r
s
.529 .664 .472 r
.39627 .56188 m .40187 .5918 L .43648 .59032 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.44147 .61867 m .43648 .59032 L .40187 .5918 L p F P
.505 .664 .505 r
s
.517 .645 .461 r
.43648 .59032 m .44147 .61867 L .47466 .61767 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.36201 .43659 m .35742 .46806 L .39291 .46886 L p F P
.505 .664 .505 r
s
.587 .759 .544 r
.39291 .46886 m .39627 .43812 L .36201 .43659 L p F P
.505 .664 .505 r
s
.551 .703 .499 r
.35589 .5 m .35742 .53194 L .39291 .53114 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.39627 .56188 m .39291 .53114 L .35742 .53194 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.47742 .35564 m .47466 .38233 L .50846 .38253 L p F P
.505 .664 .505 r
s
.652 .857 .633 r
.50846 .38253 m .50754 .35586 L .47742 .35564 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.50754 .64414 m .50846 .61747 L .47466 .61767 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.50754 .35586 m .50846 .38253 L .54206 .38193 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.50846 .61747 m .50754 .64414 L .53747 .64479 L p F P
.505 .664 .505 r
s
.497 .614 .445 r
.53747 .64479 m .54206 .61807 L .50846 .61747 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.44788 .35455 m .44147 .38133 L .47466 .38233 L p F P
.505 .664 .505 r
s
.646 .85 .624 r
.47466 .38233 m .47742 .35564 L .44788 .35455 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.47742 .64436 m .47466 .61767 L .44147 .61867 L p F P
.505 .664 .505 r
s
.495 .611 .439 r
.47466 .61767 m .47742 .64436 L .50754 .64414 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.36963 .40606 m .36201 .43659 L .39627 .43812 L p F P
.505 .664 .505 r
s
.601 .783 .563 r
.39627 .43812 m .40187 .4082 L .36963 .40606 L p F P
.505 .664 .505 r
s
.53 .67 .474 r
.35742 .53194 m .36201 .56341 L .39627 .56188 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.40187 .5918 m .39627 .56188 L .36201 .56341 L p F P
.505 .664 .505 r
s
.648 .848 .632 r
.58106 .40902 m .57465 .38053 L .54206 .38193 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.57465 .38053 m .58106 .40902 L .61461 .40721 L p F P
.505 .664 .505 r
s
.634 .826 .619 r
.62122 .43741 m .61461 .40721 L .58106 .40902 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.58106 .59098 m .57465 .61947 L .60538 .62166 L p F P
.505 .664 .505 r
s
.514 .64 .473 r
.60538 .62166 m .61461 .59279 L .58106 .59098 L p F P
.505 .664 .505 r
s
.655 .862 .64 r
.54206 .38193 m .53747 .35521 L .50754 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.53747 .35521 m .54206 .38193 L .57465 .38053 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.54206 .61807 m .53747 .64479 L .56643 .64632 L p F P
.505 .664 .505 r
s
.492 .608 .443 r
.56643 .64632 m .57465 .61947 L .54206 .61807 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.62519 .46849 m .62652 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.62652 .5 m .62519 .53151 L .6591 .53242 L p F P
.505 .664 .505 r
s
.574 .734 .552 r
.6591 .53242 m .66083 .5 L .62652 .5 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.62122 .43741 m .62519 .46849 L .6591 .46758 L p F P
.505 .664 .505 r
s
.593 .765 .576 r
.66083 .5 m .6591 .46758 L .62519 .46849 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.62519 .53151 m .62122 .56259 L .6539 .56435 L p F P
.505 .664 .505 r
s
.551 .698 .524 r
.6539 .56435 m .6591 .53242 L .62519 .53151 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.41972 .3526 m .40969 .37953 L .44147 .38133 L p F P
.505 .664 .505 r
s
.636 .838 .612 r
.44147 .38133 m .44788 .35455 L .41972 .3526 L p F P
.505 .664 .505 r
s
.501 .624 .442 r
.40187 .5918 m .40969 .62047 L .44147 .61867 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.44788 .64545 m .44147 .61867 L .40969 .62047 L p F P
.505 .664 .505 r
s
.486 .599 .426 r
.44147 .61867 m .44788 .64545 L .47742 .64436 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.38025 .37696 m .36963 .40606 L .40187 .4082 L p F P
.505 .664 .505 r
s
.613 .803 .581 r
.40187 .4082 m .40969 .37953 L .38025 .37696 L p F P
.505 .664 .505 r
s
.505 .633 .445 r
.36201 .56341 m .36963 .59394 L .40187 .5918 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.40969 .62047 m .40187 .5918 L .36963 .59394 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.61461 .40721 m .62122 .43741 L .6539 .43565 L p F P
.505 .664 .505 r
s
.61 .792 .598 r
.6591 .46758 m .6539 .43565 L .62122 .43741 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.62122 .56259 m .61461 .59279 L .64528 .59525 L p F P
.505 .664 .505 r
s
.524 .658 .493 r
.64528 .59525 m .6539 .56435 L .62122 .56259 L p F P
.505 .664 .505 r
s
.655 .863 .645 r
.57465 .38053 m .56643 .35368 L .53747 .35521 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.56643 .35368 m .57465 .38053 L .60538 .37834 L p F P
.505 .664 .505 r
s
.644 .845 .635 r
.61461 .40721 m .60538 .37834 L .57465 .38053 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.57465 .61947 m .56643 .64632 L .59358 .6487 L p F P
.505 .664 .505 r
s
.479 .59 .434 r
.59358 .6487 m .60538 .62166 L .57465 .61947 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.3254 .46703 m .32346 .5 L .35589 .5 L p F P
.505 .664 .505 r
s
.542 .696 .49 r
.35589 .5 m .35742 .46806 L .3254 .46703 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.35742 .53194 m .35589 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.48078 .33093 m .47742 .35564 L .50754 .35586 L p F P
.505 .664 .505 r
s
.656 .869 .643 r
.50754 .35586 m .50642 .33115 L .48078 .33093 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.50642 .66885 m .50754 .64414 L .47742 .64436 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.50642 .33115 m .50754 .35586 L .53747 .35521 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.50754 .64414 m .50642 .66885 L .53187 .6695 L p F P
.505 .664 .505 r
s
.457 .557 .401 r
.53187 .6695 m .53747 .64479 L .50754 .64414 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.33119 .4346 m .3254 .46703 L .35742 .46806 L p F P
.505 .664 .505 r
s
.56 .725 .514 r
.35742 .46806 m .36201 .43659 L .33119 .4346 L p F P
.505 .664 .505 r
s
.521 .663 .465 r
.32346 .5 m .3254 .53297 L .35742 .53194 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.36201 .56341 m .35742 .53194 L .3254 .53297 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.4557 .32985 m .44788 .35455 L .47742 .35564 L p F P
.505 .664 .505 r
s
.65 .862 .635 r
.47742 .35564 m .48078 .33093 L .4557 .32985 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.48078 .66907 m .47742 .64436 L .44788 .64545 L p F P
.505 .664 .505 r
s
.455 .555 .396 r
.47742 .64436 m .48078 .66907 L .50642 .66885 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.60538 .37834 m .61461 .40721 L .64528 .40475 L p F P
.505 .664 .505 r
s
.624 .816 .617 r
.6539 .43565 m .64528 .40475 L .61461 .40721 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.61461 .59279 m .60538 .62166 L .6333 .62462 L p F P
.505 .664 .505 r
s
.493 .612 .457 r
.6333 .62462 m .64528 .59525 L .61461 .59279 L p F P
.505 .664 .505 r
s
.659 .873 .65 r
.53747 .35521 m .53187 .3305 L .50642 .33115 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.53187 .3305 m .53747 .35521 L .56643 .35368 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.53747 .64479 m .53187 .6695 L .55641 .67102 L p F P
.505 .664 .505 r
s
.451 .549 .398 r
.55641 .67102 m .56643 .64632 L .53747 .64479 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.39379 .3498 m .38025 .37696 L .40969 .37953 L p F P
.505 .664 .505 r
s
.621 .821 .596 r
.40969 .37953 m .41972 .3526 L .39379 .3498 L p F P
.505 .664 .505 r
s
.477 .59 .413 r
.36963 .59394 m .38025 .62304 L .40969 .62047 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.41972 .6474 m .40969 .62047 L .38025 .62304 L p F P
.505 .664 .505 r
s
.469 .576 .406 r
.40969 .62047 m .41972 .6474 L .44788 .64545 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.34079 .40328 m .33119 .4346 L .36201 .43659 L p F P
.505 .664 .505 r
s
.576 .752 .536 r
.36201 .43659 m .36963 .40606 L .34079 .40328 L p F P
.505 .664 .505 r
s
.497 .626 .436 r
.3254 .53297 m .33119 .5654 L .36201 .56341 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.36963 .59394 m .36201 .56341 L .33119 .5654 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.4319 .32791 m .41972 .3526 L .44788 .35455 L p F P
.505 .664 .505 r
s
.64 .85 .624 r
.44788 .35455 m .4557 .32985 L .4319 .32791 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.4557 .67015 m .44788 .64545 L .41972 .6474 L p F P
.505 .664 .505 r
s
.446 .542 .383 r
.44788 .64545 m .4557 .67015 L .48078 .66907 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.35411 .37361 m .34079 .40328 L .36963 .40606 L p F P
.505 .664 .505 r
s
.589 .775 .556 r
.36963 .40606 m .38025 .37696 L .35411 .37361 L p F P
.505 .664 .505 r
s
.47 .585 .405 r
.33119 .5654 m .34079 .59672 L .36963 .59394 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.38025 .62304 m .36963 .59394 L .34079 .59672 L p F P
.505 .664 .505 r
s
.658 .874 .654 r
.56643 .35368 m .55641 .32898 L .53187 .3305 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.55641 .32898 m .56643 .35368 L .59358 .3513 L p F P
.505 .664 .505 r
s
.652 .861 .647 r
.60538 .37834 m .59358 .3513 L .56643 .35368 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.56643 .64632 m .55641 .67102 L .57927 .67338 L p F P
.505 .664 .505 r
s
.437 .529 .387 r
.57927 .67338 m .59358 .6487 L .56643 .64632 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.6591 .46758 m .66083 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.66083 .5 m .6591 .53242 L .68892 .53358 L p F P
.505 .664 .505 r
s
.548 .7 .533 r
.68892 .53358 m .69106 .5 L .66083 .5 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.59358 .3513 m .60538 .37834 L .6333 .37538 L p F P
.505 .664 .505 r
s
.636 .836 .633 r
.64528 .40475 m .6333 .37538 L .60538 .37834 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.60538 .62166 m .59358 .6487 L .61805 .65191 L p F P
.505 .664 .505 r
s
.456 .559 .414 r
.61805 .65191 m .6333 .62462 L .60538 .62166 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.6539 .43565 m .6591 .46758 L .68892 .46642 L p F P
.505 .664 .505 r
s
.57 .735 .561 r
.69106 .5 m .68892 .46642 L .6591 .46758 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.6591 .53242 m .6539 .56435 L .68254 .56657 L p F P
.505 .664 .505 r
s
.522 .66 .502 r
.68254 .56657 m .68892 .53358 L .6591 .53242 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.64528 .40475 m .6539 .43565 L .68254 .43343 L p F P
.505 .664 .505 r
s
.589 .766 .585 r
.68892 .46642 m .68254 .43343 L .6539 .43565 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.6539 .56435 m .64528 .59525 L .67199 .59835 L p F P
.505 .664 .505 r
s
.492 .616 .466 r
.67199 .59835 m .68254 .56657 L .6539 .56435 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41017 .32514 m .39379 .3498 L .41972 .3526 L p F P
.505 .664 .505 r
s
.626 .834 .609 r
.41972 .3526 m .4319 .32791 L .41017 .32514 L p F P
.505 .664 .505 r
s
.442 .54 .375 r
.38025 .62304 m .39379 .6502 L .41972 .6474 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.4319 .67209 m .41972 .6474 L .39379 .6502 L p F P
.505 .664 .505 r
s
.429 .518 .362 r
.41972 .6474 m .4319 .67209 L .4557 .67015 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.48475 .30872 m .48078 .33093 L .50642 .33115 L p F P
.505 .664 .505 r
s
.654 .874 .649 r
.50642 .33115 m .5051 .30892 L .48475 .30872 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.5051 .30892 m .50642 .33115 L .53187 .3305 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.5051 .69108 m .50642 .66885 L .48078 .66907 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.50642 .66885 m .5051 .69108 L .52528 .69167 L p F P
.505 .664 .505 r
s
.406 .485 .346 r
.52528 .69167 m .53187 .6695 L .50642 .66885 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.4649 .30775 m .4557 .32985 L .48078 .33093 L p F P
.505 .664 .505 r
s
.648 .867 .641 r
.48078 .33093 m .48475 .30872 L .4649 .30775 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.48475 .69128 m .48078 .66907 L .4557 .67015 L p F P
.505 .664 .505 r
s
.405 .483 .342 r
.48078 .66907 m .48475 .69128 L .5051 .69108 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.37101 .34619 m .35411 .37361 L .38025 .37696 L p F P
.505 .664 .505 r
s
.599 .795 .574 r
.38025 .37696 m .39379 .3498 L .37101 .34619 L p F P
.505 .664 .505 r
s
.439 .539 .37 r
.34079 .59672 m .35411 .62639 L .38025 .62304 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.39379 .6502 m .38025 .62304 L .35411 .62639 L p F P
.505 .664 .505 r
s
.656 .877 .655 r
.53187 .3305 m .52528 .30833 L .5051 .30892 L p F P
.505 .664 .505 r
s
.656 .877 .658 r
.52528 .30833 m .53187 .3305 L .55641 .32898 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.53187 .6695 m .52528 .69167 L .54465 .69302 L p F P
.505 .664 .505 r
s
.4 .476 .342 r
.54465 .69302 m .55641 .67102 L .53187 .6695 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.6333 .37538 m .64528 .40475 L .67199 .40165 L p F P
.505 .664 .505 r
s
.605 .793 .606 r
.68254 .43343 m .67199 .40165 L .64528 .40475 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.64528 .59525 m .6333 .62462 L .65738 .62833 L p F P
.505 .664 .505 r
s
.457 .565 .426 r
.65738 .62833 m .67199 .59835 L .64528 .59525 L p F P
.505 .664 .505 r
s
.655 .871 .656 r
.59358 .3513 m .57927 .32662 L .55641 .32898 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.57927 .32662 m .59358 .3513 L .61805 .34809 L p F P
.505 .664 .505 r
s
.643 .852 .646 r
.6333 .37538 m .61805 .34809 L .59358 .3513 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59358 .6487 m .57927 .67338 L .59968 .67653 L p F P
.505 .664 .505 r
s
.411 .495 .365 r
.59968 .67653 m .61805 .65191 L .59358 .6487 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.44617 .30602 m .4319 .32791 L .4557 .32985 L p F P
.505 .664 .505 r
s
.639 .856 .631 r
.4557 .32985 m .4649 .30775 L .44617 .30602 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4649 .69225 m .4557 .67015 L .4319 .67209 L p F P
.505 .664 .505 r
s
.396 .471 .329 r
.4557 .67015 m .4649 .69225 L .48475 .69128 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.29812 .46575 m .29579 .5 L .32346 .5 L p F P
.505 .664 .505 r
s
.496 .637 .442 r
.32346 .5 m .3254 .46703 L .29812 .46575 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.3254 .53297 m .32346 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.30507 .43216 m .29812 .46575 L .3254 .46703 L p F P
.505 .664 .505 r
s
.518 .672 .47 r
.3254 .46703 m .33119 .4346 L .30507 .43216 L p F P
.505 .664 .505 r
s
.472 .599 .412 r
.29579 .5 m .29812 .53425 L .3254 .53297 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.33119 .5654 m .3254 .53297 L .29812 .53425 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.33208 .43171 m
.33377 .42483 L
s
.5 Mabswid
.656 .877 .658 r
.55641 .32898 m .54465 .30698 L .52528 .30833 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.54465 .30698 m .55641 .32898 L .57927 .32662 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.55641 .67102 m .54465 .69302 L .56257 .69512 L p F P
.505 .664 .505 r
s
.384 .454 .329 r
.56257 .69512 m .57927 .67338 L .55641 .67102 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.31654 .39987 m .30507 .43216 L .33119 .4346 L p F P
.505 .664 .505 r
s
.536 .703 .496 r
.33119 .4346 m .34079 .40328 L .31654 .39987 L p F P
.505 .664 .505 r
s
.445 .558 .38 r
.29812 .53425 m .30507 .56784 L .33119 .5654 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.34079 .59672 m .33119 .5654 L .30507 .56784 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.61805 .34809 m .6333 .37538 L .65738 .37167 L p F P
.505 .664 .505 r
s
.617 .816 .624 r
.67199 .40165 m .65738 .37167 L .6333 .37538 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6333 .62462 m .61805 .65191 L .6389 .65589 L p F P
.505 .664 .505 r
s
.418 .507 .38 r
.6389 .65589 m .65738 .62833 L .6333 .62462 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.3913 .3216 m .37101 .34619 L .39379 .3498 L p F P
.505 .664 .505 r
s
.605 .809 .588 r
.39379 .3498 m .41017 .32514 L .3913 .3216 L p F P
.505 .664 .505 r
s
.403 .487 .331 r
.35411 .62639 m .37101 .65381 L .39379 .6502 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.41017 .67486 m .39379 .6502 L .37101 .65381 L p F P
.505 .664 .505 r
s
.401 .481 .331 r
.39379 .6502 m .41017 .67486 L .4319 .67209 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.42923 .30356 m .41017 .32514 L .4319 .32791 L p F P
.505 .664 .505 r
s
.625 .84 .617 r
.4319 .32791 m .44617 .30602 L .42923 .30356 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.44617 .69398 m .4319 .67209 L .41017 .67486 L p F P
.505 .664 .505 r
s
.378 .447 .308 r
.4319 .67209 m .44617 .69398 L .4649 .69225 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.33238 .36955 m .31654 .39987 L .34079 .40328 L p F P
.505 .664 .505 r
s
.552 .731 .519 r
.34079 .40328 m .35411 .37361 L .33238 .36955 L p F P
.505 .664 .505 r
s
.415 .512 .345 r
.30507 .56784 m .31654 .60013 L .34079 .59672 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.35411 .62639 m .34079 .59672 L .31654 .60013 L p F P
.505 .664 .505 r
s
.651 .873 .659 r
.57927 .32662 m .56257 .30488 L .54465 .30698 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.56257 .30488 m .57927 .32662 L .59968 .32347 L p F P
.505 .664 .505 r
s
.645 .862 .654 r
.61805 .34809 m .59968 .32347 L .57927 .32662 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57927 .67338 m .56257 .69512 L .57837 .69792 L p F P
.505 .664 .505 r
s
.357 .418 .305 r
.57837 .69792 m .59968 .67653 L .57927 .67338 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.68892 .46642 m .69106 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.69106 .5 m .68892 .53358 L .71329 .53497 L p F P
.505 .664 .505 r
s
.5 .639 .496 r
.71329 .53497 m .7158 .5 L .69106 .5 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.48931 .28962 m .48475 .30872 L .5051 .30892 L p F P
.505 .664 .505 r
s
.642 .867 .647 r
.5051 .30892 m .50357 .28977 L .48931 .28962 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50357 .28977 m .5051 .30892 L .52528 .30833 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.50357 .71023 m .5051 .69108 L .48475 .69128 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.5051 .69108 m .50357 .71023 L .51772 .71068 L p F P
.505 .664 .505 r
s
.339 .391 .274 r
.51772 .71068 m .52528 .69167 L .5051 .69108 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.47542 .28887 m .4649 .30775 L .48475 .30872 L p F P
.505 .664 .505 r
s
.637 .861 .64 r
.48475 .30872 m .48931 .28962 L .47542 .28887 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.48931 .71038 m .48475 .69128 L .4649 .69225 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.48475 .69128 m .48931 .71038 L .50357 .71023 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.68254 .43343 m .68892 .46642 L .71329 .46503 L p F P
.505 .664 .505 r
s
.526 .681 .528 r
.7158 .5 m .71329 .46503 L .68892 .46642 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.68892 .53358 m .68254 .56657 L .7058 .56923 L p F P
.505 .664 .505 r
s
.47 .593 .459 r
.7058 .56923 m .71329 .53497 L .68892 .53358 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.59968 .32347 m .61805 .34809 L .6389 .34411 L p F P
.505 .664 .505 r
s
.625 .833 .637 r
.65738 .37167 m .6389 .34411 L .61805 .34809 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.61805 .65191 m .59968 .67653 L .6168 .68043 L p F P
.505 .664 .505 r
s
.371 .441 .328 r
.6168 .68043 m .6389 .65589 L .61805 .65191 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35235 .34184 m .33238 .36955 L .35411 .37361 L p F P
.505 .664 .505 r
s
.565 .754 .54 r
.35411 .37361 m .37101 .34619 L .35235 .34184 L p F P
.505 .664 .505 r
s
.388 .471 .317 r
.31654 .60013 m .33238 .63045 L .35411 .62639 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.37101 .65381 m .35411 .62639 L .33238 .63045 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.52528 .30833 m .51772 .28932 L .50357 .28977 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.51772 .28932 m .52528 .30833 L .54465 .30698 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.52528 .69167 m .51772 .71068 L .53123 .71173 L p F P
.505 .664 .505 r
s
.332 .381 .269 r
.53123 .71173 m .54465 .69302 L .52528 .69167 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.67199 .40165 m .68254 .43343 L .7058 .43077 L p F P
.505 .664 .505 r
s
.549 .717 .557 r
.71329 .46503 m .7058 .43077 L .68254 .43343 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.68254 .56657 m .67199 .59835 L .69345 .60204 L p F P
.505 .664 .505 r
s
.436 .543 .419 r
.69345 .60204 m .7058 .56923 L .68254 .56657 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.47542 .71113 m .4649 .69225 L .44617 .69398 L p F P
.505 .664 .505 r
s
.336 .387 .27 r
.4649 .69225 m .47542 .71113 L .48931 .71038 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4624 .28754 m .44617 .30602 L .4649 .30775 L p F P
.505 .664 .505 r
s
.628 .85 .631 r
.4649 .30775 m .47542 .28887 L .4624 .28754 L p F P
.505 .664 .505 r
s
.37 .439 .3 r
.37101 .65381 m .3913 .6784 L .41017 .67486 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.42923 .69644 m .41017 .67486 L .3913 .6784 L p F P
.505 .664 .505 r
s
.359 .42 .289 r
.41017 .67486 m .42923 .69644 L .44617 .69398 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41472 .30044 m .3913 .3216 L .41017 .32514 L p F P
.505 .664 .505 r
s
.605 .817 .598 r
.41017 .32514 m .42923 .30356 L .41472 .30044 L p F P
.505 .664 .505 r
s
.643 .869 .654 r
.54465 .30698 m .53123 .28827 L .51772 .28932 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.53123 .28827 m .54465 .30698 L .56257 .30488 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54465 .69302 m .53123 .71173 L .54362 .71333 L p F P
.505 .664 .505 r
s
.316 .359 .256 r
.54362 .71333 m .56257 .69512 L .54465 .69302 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.65738 .37167 m .67199 .40165 L .69345 .39796 L p F P
.505 .664 .505 r
s
.568 .749 .581 r
.7058 .43077 m .69345 .39796 L .67199 .40165 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67199 .59835 m .65738 .62833 L .67646 .63273 L p F P
.505 .664 .505 r
s
.399 .487 .374 r
.67646 .63273 m .69345 .60204 L .67199 .59835 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37612 .31737 m .35235 .34184 L .37101 .34619 L p F P
.505 .664 .505 r
s
.573 .771 .558 r
.37101 .34619 m .3913 .3216 L .37612 .31737 L p F P
.505 .664 .505 r
s
.364 .434 .295 r
.33238 .63045 m .35235 .65816 L .37101 .65381 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.3913 .6784 m .37101 .65381 L .35235 .65816 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.45076 .28567 m .42923 .30356 L .44617 .30602 L p F P
.505 .664 .505 r
s
.615 .835 .618 r
.44617 .30602 m .4624 .28754 L .45076 .28567 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.4624 .71246 m .44617 .69398 L .42923 .69644 L p F P
.505 .664 .505 r
s
.328 .376 .263 r
.44617 .69398 m .4624 .71246 L .47542 .71113 L p F P
.505 .664 .505 r
s
.641 .863 .655 r
.59968 .32347 m .57837 .30208 L .56257 .30488 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.57837 .30208 m .59968 .32347 L .6168 .31957 L p F P
.505 .664 .505 r
s
.628 .843 .645 r
.6389 .34411 m .6168 .31957 L .59968 .32347 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59968 .67653 m .57837 .69792 L .59141 .70134 L p F P
.505 .664 .505 r
s
.317 .364 .267 r
.59141 .70134 m .6168 .68043 L .59968 .67653 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.6389 .34411 m .65738 .37167 L .67646 .36727 L p F P
.505 .664 .505 r
s
.583 .775 .601 r
.69345 .39796 m .67646 .36727 L .65738 .37167 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65738 .62833 m .6389 .65589 L .65512 .66059 L p F P
.505 .664 .505 r
s
.357 .426 .325 r
.65512 .66059 m .67646 .63273 L .65738 .62833 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.30393 .42877 m
.30778 .42451 L
s
.5 Mabswid
.42 .541 .365 r
.27706 .46425 m .27438 .5 L .29579 .5 L p F P
.505 .664 .505 r
s
.42 .541 .365 r
.29579 .5 m .29812 .46575 L .27706 .46425 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.29812 .53425 m .29579 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.28506 .42929 m .27706 .46425 L .29812 .46575 L p F P
.505 .664 .505 r
s
.447 .583 .399 r
.29812 .46575 m .30507 .43216 L .28506 .42929 L p F P
.505 .664 .505 r
s
.392 .496 .329 r
.27438 .5 m .27706 .53575 L .29812 .53425 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.30507 .56784 m .29812 .53425 L .27706 .53575 L p F P
.505 .664 .505 r
s
.637 .863 .652 r
.56257 .30488 m .54362 .28667 L .53123 .28827 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.54362 .28667 m .56257 .30488 L .57837 .30208 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.56257 .69512 m .54362 .71333 L .5544 .71545 L p F P
.505 .664 .505 r
s
.29 .325 .232 r
.5544 .71545 m .57837 .69792 L .56257 .69512 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.29822 .3959 m .28506 .42929 L .30507 .43216 L p F P
.505 .664 .505 r
s
.471 .622 .431 r
.30507 .43216 m .31654 .39987 L .29822 .3959 L p F P
.505 .664 .505 r
s
.371 .462 .308 r
.27706 .53575 m .28506 .57071 L .30507 .56784 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.31654 .60013 m .30507 .56784 L .28506 .57071 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.44095 .28331 m .41472 .30044 L .42923 .30356 L p F P
.505 .664 .505 r
s
.596 .813 .6 r
.42923 .30356 m .45076 .28567 L .44095 .28331 L p F P
.505 .664 .505 r
s
.335 .388 .269 r
.3913 .6784 m .41472 .69956 L .42923 .69644 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.45076 .71433 m .42923 .69644 L .41472 .69956 L p F P
.505 .664 .505 r
s
.314 .356 .251 r
.42923 .69644 m .45076 .71433 L .4624 .71246 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.6168 .31957 m .6389 .34411 L .65512 .33941 L p F P
.505 .664 .505 r
s
.593 .795 .616 r
.67646 .36727 m .65512 .33941 L .6389 .34411 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.6389 .65589 m .6168 .68043 L .62982 .68498 L p F P
.505 .664 .505 r
s
.311 .359 .272 r
.62982 .68498 m .65512 .66059 L .6389 .65589 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.40332 .29675 m .37612 .31737 L .3913 .3216 L p F P
.505 .664 .505 r
s
.575 .782 .57 r
.3913 .3216 m .41472 .30044 L .40332 .29675 L p F P
.505 .664 .505 r
s
.335 .39 .27 r
.35235 .65816 m .37612 .68263 L .3913 .6784 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.41472 .69956 m .3913 .6784 L .37612 .68263 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31627 .36485 m .29822 .3959 L .31654 .39987 L p F P
.505 .664 .505 r
s
.492 .657 .461 r
.31654 .39987 m .33238 .36955 L .31627 .36485 L p F P
.505 .664 .505 r
s
.353 .431 .29 r
.28506 .57071 m .29822 .6041 L .31654 .60013 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.33238 .63045 m .31654 .60013 L .29822 .6041 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.49441 .27429 m .48931 .28962 L .50357 .28977 L p F P
.505 .664 .505 r
s
.614 .839 .63 r
.50357 .28977 m .50187 .27437 L .49441 .27429 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50187 .27437 m .50357 .28977 L .51772 .28932 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.50187 .72563 m .50357 .71023 L .48931 .71038 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50357 .71023 m .50187 .72563 L .50926 .72588 L p F P
.505 .664 .505 r
s
.274 .3 .216 r
.50926 .72588 m .51772 .71068 L .50357 .71023 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48716 .27387 m .47542 .28887 L .48931 .28962 L p F P
.505 .664 .505 r
s
.609 .834 .625 r
.48931 .28962 m .49441 .27429 L .48716 .27387 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.49441 .72571 m .48931 .71038 L .47542 .71113 L p F P
.505 .664 .505 r
s
.276 .303 .219 r
.48931 .71038 m .49441 .72571 L .50187 .72563 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.51772 .28932 m .50926 .27412 L .50187 .27437 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.50926 .27412 m .51772 .28932 L .53123 .28827 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51772 .71068 m .50926 .72588 L .51628 .72647 L p F P
.505 .664 .505 r
s
.266 .29 .21 r
.51628 .72647 m .53123 .71173 L .51772 .71068 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33884 .33683 m .31627 .36485 L .33238 .36955 L p F P
.505 .664 .505 r
s
.51 .688 .488 r
.33238 .36955 m .35235 .34184 L .33884 .33683 L p F P
.505 .664 .505 r
s
.332 .397 .271 r
.29822 .6041 m .31627 .63515 L .33238 .63045 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.35235 .65816 m .33238 .63045 L .31627 .63515 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.48043 .27312 m .4624 .28754 L .47542 .28887 L p F P
.505 .664 .505 r
s
.602 .825 .617 r
.47542 .28887 m .48716 .27387 L .48043 .27312 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.48716 .72613 m .47542 .71113 L .4624 .71246 L p F P
.505 .664 .505 r
s
.274 .3 .217 r
.47542 .71113 m .48716 .72613 L .49441 .72571 L p F P
.505 .664 .505 r
s
.626 .852 .647 r
.57837 .30208 m .5544 .28455 L .54362 .28667 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.5544 .28455 m .57837 .30208 L .59141 .29866 L p F P
.505 .664 .505 r
s
.623 .844 .646 r
.6168 .31957 m .59141 .29866 L .57837 .30208 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.57837 .69792 m .5544 .71545 L .56312 .71802 L p F P
.505 .664 .505 r
s
.259 .282 .205 r
.56312 .71802 m .59141 .70134 L .57837 .69792 L p F P
.505 .664 .505 r
s
.613 .839 .633 r
.53123 .28827 m .51628 .27353 L .50926 .27412 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.51628 .27353 m .53123 .28827 L .54362 .28667 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.53123 .71173 m .51628 .72647 L .52266 .72736 L p F P
.505 .664 .505 r
s
.254 .273 .2 r
.52266 .72736 m .54362 .71333 L .53123 .71173 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.59141 .29866 m .6168 .31957 L .62982 .31502 L p F P
.505 .664 .505 r
s
.597 .808 .625 r
.65512 .33941 m .62982 .31502 L .6168 .31957 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.6168 .68043 m .59141 .70134 L .60104 .70529 L p F P
.505 .664 .505 r
s
.26 .287 .213 r
.60104 .70529 m .62982 .68498 L .6168 .68043 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.47448 .27209 m .45076 .28567 L .4624 .28754 L p F P
.505 .664 .505 r
s
.591 .812 .606 r
.4624 .28754 m .48043 .27312 L .47448 .27209 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.48043 .72688 m .4624 .71246 L .45076 .71433 L p F P
.505 .664 .505 r
s
.267 .29 .211 r
.4624 .71246 m .48043 .72688 L .48716 .72613 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.71329 .46503 m .7158 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.7158 .5 m .71329 .53497 L .73061 .53658 L p F P
.505 .664 .505 r
s
.414 .529 .423 r
.73061 .53658 m .73345 .5 L .7158 .5 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.7058 .43077 m .71329 .46503 L .73061 .46342 L p F P
.505 .664 .505 r
s
.445 .578 .461 r
.73345 .5 m .73061 .46342 L .71329 .46503 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.71329 .53497 m .7058 .56923 L .72215 .57228 L p F P
.505 .664 .505 r
s
.379 .476 .38 r
.72215 .57228 m .73061 .53658 L .71329 .53497 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.36548 .31254 m .33884 .33683 L .35235 .34184 L p F P
.505 .664 .505 r
s
.523 .713 .512 r
.35235 .34184 m .37612 .31737 L .36548 .31254 L p F P
.505 .664 .505 r
s
.308 .359 .249 r
.31627 .63515 m .33884 .66317 L .35235 .65816 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.37612 .68263 m .35235 .65816 L .33884 .66317 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.43343 .28055 m .40332 .29675 L .41472 .30044 L p F P
.505 .664 .505 r
s
.57 .783 .577 r
.41472 .30044 m .44095 .28331 L .43343 .28055 L p F P
.505 .664 .505 r
s
.301 .341 .241 r
.37612 .68263 m .40332 .70325 L .41472 .69956 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.44095 .71669 m .41472 .69956 L .40332 .70325 L p F P
.505 .664 .505 r
s
.292 .326 .232 r
.41472 .69956 m .44095 .71669 L .45076 .71433 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.69345 .39796 m .7058 .43077 L .72215 .42772 L p F P
.505 .664 .505 r
s
.473 .623 .497 r
.73061 .46342 m .72215 .42772 L .7058 .43077 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.7058 .56923 m .69345 .60204 L .70827 .60627 L p F P
.505 .664 .505 r
s
.343 .42 .335 r
.70827 .60627 m .72215 .57228 L .7058 .56923 L p F P
.505 .664 .505 r
s
.607 .832 .631 r
.54362 .28667 m .52266 .27264 L .51628 .27353 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.52266 .27264 m .54362 .28667 L .5544 .28455 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.54362 .71333 m .52266 .72736 L .52813 .72853 L p F P
.505 .664 .505 r
s
.237 .25 .186 r
.52813 .72853 m .5544 .71545 L .54362 .71333 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.67646 .36727 m .69345 .39796 L .70827 .39373 L p F P
.505 .664 .505 r
s
.498 .664 .527 r
.72215 .42772 m .70827 .39373 L .69345 .39796 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.69345 .60204 m .67646 .63273 L .68929 .63772 L p F P
.505 .664 .505 r
s
.304 .362 .288 r
.68929 .63772 m .70827 .60627 L .69345 .60204 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.46955 .2708 m .44095 .28331 L .45076 .28567 L p F P
.505 .664 .505 r
s
.575 .794 .592 r
.45076 .28567 m .47448 .27209 L .46955 .2708 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.47448 .72791 m .45076 .71433 L .44095 .71669 L p F P
.505 .664 .505 r
s
.255 .274 .201 r
.45076 .71433 m .47448 .72791 L .48043 .72688 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.39561 .29258 m .36548 .31254 L .37612 .31737 L p F P
.505 .664 .505 r
s
.532 .731 .532 r
.37612 .31737 m .40332 .29675 L .39561 .29258 L p F P
.505 .664 .505 r
s
.282 .318 .226 r
.33884 .66317 m .36548 .68746 L .37612 .68263 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.40332 .70325 m .37612 .68263 L .36548 .68746 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.65512 .33941 m .67646 .36727 L .68929 .36228 L p F P
.505 .664 .505 r
s
.518 .698 .553 r
.70827 .39373 m .68929 .36228 L .67646 .36727 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.67646 .63273 m .65512 .66059 L .66565 .66587 L p F P
.505 .664 .505 r
s
.264 .302 .239 r
.66565 .66587 m .68929 .63772 L .67646 .63273 L p F P
.505 .664 .505 r
s
.609 .833 .637 r
.59141 .29866 m .56312 .28198 L .5544 .28455 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.56312 .28198 m .59141 .29866 L .60104 .29471 L p F P
.505 .664 .505 r
s
.594 .811 .626 r
.62982 .31502 m .60104 .29471 L .59141 .29866 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.59141 .70134 m .56312 .71802 L .56935 .72096 L p F P
.505 .664 .505 r
s
.22 .23 .172 r
.56935 .72096 m .60104 .70529 L .59141 .70134 L p F P
.505 .664 .505 r
s
.597 .822 .625 r
.5544 .28455 m .52813 .27147 L .52266 .27264 L p F P
.505 .664 .505 r
s
.582 .805 .615 r
.52813 .27147 m .5544 .28455 L .56312 .28198 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.5544 .71545 m .52813 .72853 L .53245 .72993 L p F P
.505 .664 .505 r
s
.215 .22 .167 r
.53245 .72993 m .56312 .71802 L .5544 .71545 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.62982 .31502 m .65512 .33941 L .66565 .33413 L p F P
.505 .664 .505 r
s
.534 .726 .572 r
.68929 .36228 m .66565 .33413 L .65512 .33941 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.65512 .66059 m .62982 .68498 L .63789 .69005 L p F P
.505 .664 .505 r
s
.223 .243 .189 r
.63789 .69005 m .66565 .66587 L .65512 .66059 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.46589 .2693 m .43343 .28055 L .44095 .28331 L p F P
.505 .664 .505 r
s
.555 .771 .575 r
.44095 .28331 m .46955 .2708 L .46589 .2693 L p F P
.505 .664 .505 r
s
.261 .284 .206 r
.40332 .70325 m .43343 .71945 L .44095 .71669 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.46955 .7292 m .44095 .71669 L .43343 .71945 L p F P
.505 .664 .505 r
s
.238 .25 .186 r
.44095 .71669 m .46955 .7292 L .47448 .72791 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.42859 .27747 m .39561 .29258 L .40332 .29675 L p F P
.505 .664 .505 r
s
.535 .741 .546 r
.40332 .29675 m .43343 .28055 L .42859 .27747 L p F P
.505 .664 .505 r
s
.252 .275 .2 r
.36548 .68746 m .39561 .70742 L .40332 .70325 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.43343 .71945 m .40332 .70325 L .39561 .70742 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.26391 .46256 m .26093 .5 L .27438 .5 L p F P
.505 .664 .505 r
s
.311 .401 .263 r
.27438 .5 m .27706 .46425 L .26391 .46256 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.27706 .53575 m .27438 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.556 .775 .586 r
.50187 .27437 m .5 .26345 L .49441 .27429 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50926 .27412 m .5 .26345 L .50187 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50187 .72563 L .49441 .72571 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .50926 .72588 L .50187 .72563 L closepath p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27276 .42606 m .26391 .46256 L .27706 .46425 L p F P
.505 .664 .505 r
s
.328 .433 .283 r
.27706 .46425 m .28506 .42929 L .27276 .42606 L p F P
.505 .664 .505 r
s
.295 .372 .248 r
.26093 .5 m .26391 .53744 L .27706 .53575 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.28506 .57071 m .27706 .53575 L .26391 .53744 L p F P
.505 .664 .505 r
s
.554 .772 .584 r
.49441 .27429 m .5 .26345 L .48716 .27387 L closepath p F P
.505 .664 .505 r
s
.201 .208 .158 r
.5 .73655 m .49441 .72571 L .48716 .72613 L closepath p F P
.505 .664 .505 r
s
.549 .758 .592 r
.60104 .29471 m .62982 .31502 L .63789 .30995 L p F P
.505 .664 .505 r
s
.544 .746 .586 r
.66565 .33413 m .63789 .30995 L .62982 .31502 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.62982 .68498 m .60104 .70529 L .60667 .70964 L p F P
.505 .664 .505 r
s
.192 .199 .151 r
.60667 .70964 m .63789 .69005 L .62982 .68498 L p F P
.505 .664 .505 r
s
.554 .773 .587 r
.51628 .27353 m .5 .26345 L .50926 .27412 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .51628 .72647 L .50926 .72588 L closepath p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28726 .39146 m .27276 .42606 L .28506 .42929 L p F P
.505 .664 .505 r
s
.361 .485 .326 r
.28506 .42929 m .29822 .3959 L .28726 .39146 L p F P
.505 .664 .505 r
s
.278 .342 .231 r
.26391 .53744 m .27276 .57394 L .28506 .57071 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.29822 .6041 m .28506 .57071 L .27276 .57394 L p F P
.505 .664 .505 r
s
.55 .767 .58 r
.48716 .27387 m .5 .26345 L .48043 .27312 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48716 .72613 L .48043 .72688 L closepath p F P
.505 .664 .505 r
s
.582 .805 .615 r
.56312 .28198 m .53245 .27007 L .52813 .27147 L p F P
.505 .664 .505 r
s
.563 .782 .6 r
.53245 .27007 m .56312 .28198 L .56935 .27904 L p F P
.505 .664 .505 r
s
.583 .803 .619 r
.60104 .29471 m .56935 .27904 L .56312 .28198 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.56312 .71802 m .53245 .72993 L .53542 .73151 L p F P
.505 .664 .505 r
s
.199 .206 .156 r
.53542 .73151 m .56935 .72096 L .56312 .71802 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.30703 .35961 m .28726 .39146 L .29822 .3959 L p F P
.505 .664 .505 r
s
.393 .535 .368 r
.29822 .3959 m .31627 .36485 L .30703 .35961 L p F P
.505 .664 .505 r
s
.26 .31 .214 r
.27276 .57394 m .28726 .60854 L .29822 .6041 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.31627 .63515 m .29822 .6041 L .28726 .60854 L p F P
.505 .664 .505 r
s
.551 .769 .585 r
.52266 .27264 m .5 .26345 L .51628 .27353 L closepath p F P
.505 .664 .505 r
s
.197 .203 .154 r
.5 .73655 m .52266 .72736 L .51628 .72647 L closepath p F P
.505 .664 .505 r
s
.544 .761 .575 r
.48043 .27312 m .5 .26345 L .47448 .27209 L closepath p F P
.505 .664 .505 r
s
.197 .203 .155 r
.5 .73655 m .48043 .72688 L .47448 .72791 L closepath p F P
.505 .664 .505 r
s
.422 .581 .408 r
.33154 .33131 m .30703 .35961 L .31627 .36485 L p F P
.505 .664 .505 r
s
.422 .581 .408 r
.31627 .36485 m .33884 .33683 L .33154 .33131 L p F P
.505 .664 .505 r
s
.242 .278 .197 r
.28726 .60854 m .30703 .64039 L .31627 .63515 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.33884 .66317 m .31627 .63515 L .30703 .64039 L p F P
.505 .664 .505 r
s
.546 .764 .581 r
.52813 .27147 m .5 .26345 L .52266 .27264 L closepath p F P
.505 .664 .505 r
s
.192 .199 .152 r
.5 .73655 m .52813 .72853 L .52266 .72736 L closepath p F P
.505 .664 .505 r
s
.547 .76 .59 r
.56935 .27904 m .60104 .29471 L .60667 .29036 L p F P
.505 .664 .505 r
s
.549 .758 .592 r
.63789 .30995 m .60667 .29036 L .60104 .29471 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.60104 .70529 m .56935 .72096 L .57273 .72415 L p F P
.505 .664 .505 r
s
.187 .194 .148 r
.57273 .72415 m .60667 .70964 L .60104 .70529 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.46365 .26765 m .42859 .27747 L .43343 .28055 L p F P
.505 .664 .505 r
s
.531 .741 .553 r
.43343 .28055 m .46589 .2693 L .46365 .26765 L p F P
.505 .664 .505 r
s
.221 .229 .172 r
.39561 .70742 m .42859 .72253 L .43343 .71945 L p F P
.505 .664 .505 r
s
.2 .206 .157 r
.46589 .7307 m .43343 .71945 L .42859 .72253 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.43343 .71945 m .46589 .7307 L .46955 .7292 L p F P
.505 .664 .505 r
s
.223 .246 .179 r
.30703 .64039 m .33154 .66869 L .33884 .66317 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.36548 .68746 m .33884 .66317 L .33154 .66869 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.36017 .30728 m .33154 .33131 L .33884 .33683 L p F P
.505 .664 .505 r
s
.448 .622 .444 r
.33884 .33683 m .36548 .31254 L .36017 .30728 L p F P
.505 .664 .505 r
s
.537 .753 .568 r
.47448 .27209 m .5 .26345 L .46955 .2708 L closepath p F P
.505 .664 .505 r
s
.193 .199 .152 r
.5 .73655 m .47448 .72791 L .46955 .7292 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71784 .58301 m
.71788 .58275 L
s
.5 Mabswid
.539 .756 .576 r
.53245 .27007 m .5 .26345 L .52813 .27147 L closepath p F P
.505 .664 .505 r
s
.187 .194 .148 r
.5 .73655 m .53245 .72993 L .52813 .72853 L closepath p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71266 .59575 m
.71276 .59527 L
s
.5 Mabswid
.471 .657 .477 r
.39217 .28809 m .36017 .30728 L .36548 .31254 L p F P
.505 .664 .505 r
s
.471 .657 .477 r
.36548 .31254 m .39561 .29258 L .39217 .28809 L p F P
.505 .664 .505 r
s
.205 .216 .162 r
.33154 .66869 m .36017 .69272 L .36548 .68746 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.39561 .70742 m .36548 .68746 L .36017 .69272 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72202 .5726 m
.72414 .57141 L
s
.71784 .58301 m
.71852 .58531 L
s
.71266 .59575 m
.71389 .59812 L
s
.5 Mabswid
.529 .742 .561 r
.46955 .2708 m .5 .26345 L .46589 .2693 L closepath p F P
.505 .664 .505 r
s
.187 .195 .148 r
.5 .73655 m .46955 .7292 L .46589 .7307 L closepath p F P
.505 .664 .505 r
s
.563 .782 .6 r
.56935 .27904 m .53542 .26849 L .53245 .27007 L p F P
.505 .664 .505 r
s
.538 .753 .58 r
.53542 .26849 m .56935 .27904 L .57273 .27585 L p F P
.505 .664 .505 r
s
.547 .76 .59 r
.60667 .29036 m .57273 .27585 L .56935 .27904 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.56935 .72096 m .53542 .73151 L .53689 .73321 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.53689 .73321 m .57273 .72415 L .56935 .72096 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.42673 .27419 m .39217 .28809 L .39561 .29258 L p F P
.505 .664 .505 r
s
.489 .686 .505 r
.39561 .29258 m .42859 .27747 L .42673 .27419 L p F P
.505 .664 .505 r
s
.194 .201 .153 r
.36017 .69272 m .39217 .71191 L .39561 .70742 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.42859 .72253 m .39561 .70742 L .39217 .71191 L p F P
.505 .664 .505 r
s
.531 .746 .57 r
.53542 .26849 m .5 .26345 L .53245 .27007 L closepath p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .53542 .73151 L .53245 .72993 L closepath p F P
.505 .664 .505 r
s
.52 .731 .553 r
.46589 .2693 m .5 .26345 L .46365 .26765 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.42859 .72253 m .46365 .73235 L .46589 .7307 L p F P
.505 .664 .505 r
s
.181 .189 .144 r
.5 .73655 m .46589 .7307 L .46365 .73235 L closepath p F P
.505 .664 .505 r
s
.301 .396 .336 r
.73061 .46342 m .73345 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73345 .5 m .73061 .53658 L .73916 .53835 L p F P
.505 .664 .505 r
s
.264 .337 .29 r
.73916 .53835 m .74225 .5 L .73345 .5 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.72215 .42772 m .73061 .46342 L .73916 .46165 L p F P
.505 .664 .505 r
s
.301 .396 .336 r
.74225 .5 m .73916 .46165 L .73061 .46342 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.73061 .53658 m .72215 .57228 L .72998 .57566 L p F P
.505 .664 .505 r
s
.227 .28 .243 r
.72998 .57566 m .73916 .53835 L .73061 .53658 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.70827 .39373 m .72215 .42772 L .72998 .42434 L p F P
.505 .664 .505 r
s
.338 .453 .38 r
.73916 .46165 m .72998 .42434 L .72215 .42772 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.72215 .57228 m .70827 .60627 L .71499 .61091 L p F P
.505 .664 .505 r
s
.192 .224 .198 r
.71499 .61091 m .72998 .57566 L .72215 .57228 L p F P
.505 .664 .505 r
s
.188 .195 .148 r
.39217 .71191 m .42673 .72581 L .42859 .72253 L p F P
.505 .664 .505 r
s
.182 .189 .144 r
.46365 .73235 m .42859 .72253 L .42673 .72581 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.46298 .26592 m .42673 .27419 L .42859 .27747 L p F P
.505 .664 .505 r
s
.502 .706 .528 r
.42859 .27747 m .46365 .26765 L .46298 .26592 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.68929 .36228 m .70827 .39373 L .71499 .38909 L p F P
.505 .664 .505 r
s
.373 .508 .422 r
.72998 .42434 m .71499 .38909 L .70827 .39373 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.70827 .60627 m .68929 .63772 L .69462 .64316 L p F P
.505 .664 .505 r
s
.171 .196 .166 r
.69462 .64316 m .71499 .61091 L .70827 .60627 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.66565 .33413 m .68929 .36228 L .69462 .35684 L p F P
.505 .664 .505 r
s
.406 .56 .459 r
.71499 .38909 m .69462 .35684 L .68929 .36228 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.68929 .63772 m .66565 .66587 L .66947 .67158 L p F P
.505 .664 .505 r
s
.153 .169 .136 r
.66947 .67158 m .69462 .64316 L .68929 .63772 L p F P
.505 .664 .505 r
s
.522 .735 .562 r
.53689 .26679 m .5 .26345 L .53542 .26849 L closepath p F P
.505 .664 .505 r
s
.538 .753 .58 r
.57273 .27585 m .53689 .26679 L .53542 .26849 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .53689 .73321 L .53542 .73151 L closepath p F P
.505 .664 .505 r
s
.461 .645 .517 r
.63789 .30995 m .66565 .33413 L .66947 .32842 L p F P
.505 .664 .505 r
s
.436 .606 .491 r
.69462 .35684 m .66947 .32842 L .66565 .33413 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.66565 .66587 m .63789 .69005 L .64026 .69546 L p F P
.505 .664 .505 r
s
.141 .152 .116 r
.64026 .69546 m .66947 .67158 L .66565 .66587 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.60667 .29036 m .63789 .30995 L .64026 .30454 L p F P
.505 .664 .505 r
s
.461 .645 .517 r
.66947 .32842 m .64026 .30454 L .63789 .30995 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.63789 .69005 m .60667 .70964 L .60781 .71423 L p F P
.505 .664 .505 r
s
.147 .158 .12 r
.60781 .71423 m .64026 .69546 L .63789 .69005 L p F P
.505 .664 .505 r
s
.509 .719 .544 r
.46365 .26765 m .5 .26345 L .46298 .26592 L closepath p F P
.505 .664 .505 r
s
.182 .189 .144 r
.42673 .72581 m .46298 .73408 L .46365 .73235 L p F P
.505 .664 .505 r
s
.175 .183 .139 r
.5 .73655 m .46365 .73235 L .46298 .73408 L closepath p F P
.505 .664 .505 r
s
.497 .701 .55 r
.57273 .27585 m .60667 .29036 L .60781 .28577 L p F P
.505 .664 .505 r
s
.482 .677 .537 r
.64026 .30454 m .60781 .28577 L .60667 .29036 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.60667 .70964 m .57273 .72415 L .573 .72747 L p F P
.505 .664 .505 r
s
.154 .164 .125 r
.573 .72747 m .60781 .71423 L .60667 .70964 L p F P
.505 .664 .505 r
s
.507 .716 .555 r
.53689 .26679 m .57273 .27585 L .573 .27253 L p F P
.505 .664 .505 r
s
.497 .701 .55 r
.60781 .28577 m .573 .27253 L .57273 .27585 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.57273 .72415 m .53689 .73321 L .53675 .73495 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.53675 .73495 m .573 .72747 L .57273 .72415 L p F P
.505 .664 .505 r
s
.511 .722 .553 r
.53675 .26505 m .5 .26345 L .53689 .26679 L closepath p F P
.505 .664 .505 r
s
.507 .716 .555 r
.573 .27253 m .53675 .26505 L .53689 .26679 L p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .53675 .73495 L .53689 .73321 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .52077 .74082 L .52684 .73967 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .51372 .74166 L .52077 .74082 L closepath p F P
.505 .664 .505 r
s
.136 .148 .112 r
.5 .73655 m .506 .74214 L .51372 .74166 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49799 .74224 L .506 .74214 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .49008 .74195 L .49799 .74224 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48265 .74128 L .49008 .74195 L closepath p F P
.505 .664 .505 r
s
.143 .153 .117 r
.5 .73655 m .47605 .74028 L .48265 .74128 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .47058 .73899 L .47605 .74028 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .46649 .73747 L .47058 .73899 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .46392 .73581 L .46649 .73747 L closepath p F P
.505 .664 .505 r
s
.168 .177 .134 r
.5 .73655 m .46298 .73408 L .46392 .73581 L closepath p F P
.505 .664 .505 r
s
.161 .17 .129 r
.5 .73655 m .53499 .73666 L .53675 .73495 L closepath p F P
.505 .664 .505 r
s
.154 .164 .125 r
.5 .73655 m .53165 .73825 L .53499 .73666 L closepath p F P
.505 .664 .505 r
s
.148 .158 .12 r
.5 .73655 m .52684 .73967 L .53165 .73825 L closepath p F P
.505 .664 .505 r
s
.5 .709 .543 r
.53499 .26334 m .5 .26345 L .53675 .26505 L closepath p F P
.505 .664 .505 r
s
.498 .705 .534 r
.46298 .26592 m .5 .26345 L .46392 .26419 L closepath p F P
.505 .664 .505 r
s
.489 .695 .534 r
.53165 .26175 m .5 .26345 L .53499 .26334 L closepath p F P
.505 .664 .505 r
s
.487 .692 .525 r
.46392 .26419 m .5 .26345 L .46649 .26253 L closepath p F P
.505 .664 .505 r
s
.478 .682 .524 r
.52684 .26033 m .5 .26345 L .53165 .26175 L closepath p F P
.505 .664 .505 r
s
.477 .68 .517 r
.46649 .26253 m .5 .26345 L .47058 .26101 L closepath p F P
.505 .664 .505 r
s
.469 .671 .515 r
.52077 .25918 m .5 .26345 L .52684 .26033 L closepath p F P
.505 .664 .505 r
s
.468 .669 .509 r
.47058 .26101 m .5 .26345 L .47605 .25972 L closepath p F P
.505 .664 .505 r
s
.461 .661 .508 r
.51372 .25834 m .5 .26345 L .52077 .25918 L closepath p F P
.505 .664 .505 r
s
.461 .66 .504 r
.47605 .25972 m .5 .26345 L .48265 .25872 L closepath p F P
.505 .664 .505 r
s
.456 .655 .503 r
.506 .25786 m .5 .26345 L .51372 .25834 L closepath p F P
.505 .664 .505 r
s
.456 .654 .5 r
.48265 .25872 m .5 .26345 L .49008 .25805 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49799 .25776 m .5 .26345 L .506 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .498 r
.49008 .25805 m .5 .26345 L .49799 .25776 L closepath p F P
.505 .664 .505 r
s
.468 .666 .499 r
.42673 .27419 m .46298 .26592 L .46392 .26419 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.42808 .72914 m .46392 .73581 L .46298 .73408 L p F P
.505 .664 .505 r
s
.161 .17 .129 r
.46298 .73408 m .42673 .72581 L .42808 .72914 L p F P
.505 .664 .505 r
s
.468 .666 .499 r
.46392 .26419 m .42808 .27086 L .42673 .27419 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.39217 .28809 m .42673 .27419 L .42808 .27086 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.39342 .71655 m .42808 .72914 L .42673 .72581 L p F P
.505 .664 .505 r
s
.153 .163 .124 r
.42673 .72581 m .39217 .71191 L .39342 .71655 L p F P
.505 .664 .505 r
s
.431 .616 .455 r
.42808 .27086 m .39342 .28345 L .39217 .28809 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.36017 .30728 m .39217 .28809 L .39342 .28345 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.36089 .69823 m .39342 .71655 L .39217 .71191 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.39217 .71191 m .36017 .69272 L .36089 .69823 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.573 .72747 m .53675 .73495 L .53499 .73666 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.53675 .26505 m .573 .27253 L .57001 .26922 L p F P
.505 .664 .505 r
s
.472 .673 .525 r
.57001 .26922 m .53499 .26334 L .53675 .26505 L p F P
.505 .664 .505 r
s
.389 .558 .405 r
.39342 .28345 m .36089 .30177 L .36017 .30728 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.33154 .33131 m .36017 .30728 L .36089 .30177 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.33142 .67453 m .36089 .69823 L .36017 .69272 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.36017 .69272 m .33154 .66869 L .33142 .67453 L p F P
.505 .664 .505 r
s
.343 .492 .349 r
.36089 .30177 m .33142 .32547 L .33154 .33131 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.30703 .35961 m .33154 .33131 L .33142 .32547 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.30591 .64599 m .33142 .67453 L .33154 .66869 L p F P
.505 .664 .505 r
s
.133 .144 .11 r
.33154 .66869 m .30703 .64039 L .30591 .64599 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.43272 .73238 m .46649 .73747 L .46392 .73581 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.46392 .73581 m .42808 .72914 L .43272 .73238 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.42808 .27086 m .46392 .26419 L .46649 .26253 L p F P
.505 .664 .505 r
s
.294 .421 .29 r
.33142 .32547 m .30591 .35401 L .30703 .35961 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.28726 .39146 m .30703 .35961 L .30591 .35401 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.28515 .61333 m .30591 .64599 L .30703 .64039 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.30703 .64039 m .28726 .60854 L .28515 .61333 L p F P
.505 .664 .505 r
s
.243 .348 .229 r
.30591 .35401 m .28515 .38667 L .28726 .39146 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.27276 .42606 m .28726 .39146 L .28515 .38667 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.26981 .57743 m .28515 .61333 L .28726 .60854 L p F P
.505 .664 .505 r
s
.123 .136 .103 r
.28726 .60854 m .27276 .57394 L .26981 .57743 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.573 .27253 m .60781 .28577 L .60411 .28114 L p F P
.505 .664 .505 r
s
.436 .626 .496 r
.60411 .28114 m .57001 .26922 L .573 .27253 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.60781 .71423 m .573 .72747 L .57001 .73078 L p F P
.505 .664 .505 r
s
.139 .15 .114 r
.53499 .73666 m .57001 .73078 L .573 .72747 L p F P
.505 .664 .505 r
s
.205 .289 .185 r
.28515 .38667 m .26981 .42257 L .27276 .42606 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26391 .46256 m .27276 .42606 L .26981 .42257 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.2604 .53929 m .26981 .57743 L .27276 .57394 L p F P
.505 .664 .505 r
s
.131 .153 .112 r
.27276 .57394 m .26391 .53744 L .2604 .53929 L p F P
.505 .664 .505 r
s
.184 .252 .164 r
.26981 .42257 m .2604 .46071 L .26391 .46256 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.26093 .5 m .26391 .46256 L .2604 .46071 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.25723 .5 m .2604 .53929 L .26391 .53744 L p F P
.505 .664 .505 r
s
.146 .183 .127 r
.26391 .53744 m .26093 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.164 .216 .145 r
.2604 .46071 m .25723 .5 L .26093 .5 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.57001 .73078 m .53499 .73666 L .53165 .73825 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.53499 .26334 m .57001 .26922 L .56374 .26608 L p F P
.505 .664 .505 r
s
.434 .627 .491 r
.56374 .26608 m .53165 .26175 L .53499 .26334 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.44056 .73538 m .47058 .73899 L .46649 .73747 L p F P
.505 .664 .505 r
s
.115 .128 .098 r
.46649 .73747 m .43272 .73238 L .44056 .73538 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.43272 .26762 m .46649 .26253 L .47058 .26101 L p F P
.505 .664 .505 r
s
.432 .621 .467 r
.46649 .26253 m .43272 .26762 L .42808 .27086 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.64026 .69546 m .60781 .71423 L .60411 .71886 L p F P
.505 .664 .505 r
s
.116 .129 .098 r
.57001 .73078 m .60411 .71886 L .60781 .71423 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.60781 .28577 m .64026 .30454 L .63633 .299 L p F P
.505 .664 .505 r
s
.393 .568 .459 r
.63633 .299 m .60411 .28114 L .60781 .28577 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.722 .59778 m
.72331 .59389 L
s
.72331 .59389 m
.7249 .59011 L
s
.72874 .58009 m
.73087 .57622 L
s
.5 Mabswid
.114 .127 .097 r
.39961 .72113 m .43272 .73238 L .42808 .72914 L p F P
.505 .664 .505 r
s
.114 .127 .097 r
.42808 .72914 m .39342 .71655 L .39961 .72113 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.39342 .28345 m .42808 .27086 L .43272 .26762 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.53165 .73825 m .56374 .73392 L .57001 .73078 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.56374 .73392 m .53165 .73825 L .52684 .73967 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.53165 .26175 m .56374 .26608 L .55439 .26327 L p F P
.505 .664 .505 r
s
.396 .58 .456 r
.55439 .26327 m .52684 .26033 L .53165 .26175 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72146 .5998 m
.722 .59778 L
s
.5 Mabswid
.344 .5 .414 r
.64026 .30454 m .66947 .32842 L .6657 .32251 L p F P
.505 .664 .505 r
s
.344 .5 .414 r
.6657 .32251 m .63633 .299 L .64026 .30454 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.66947 .67158 m .64026 .69546 L .63633 .701 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.60411 .71886 m .63633 .701 L .64026 .69546 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72111 .60204 m
.72146 .5998 L
s
.5 Mabswid
.094 .109 .083 r
.45134 .73796 m .47605 .74028 L .47058 .73899 L p F P
.505 .664 .505 r
s
.094 .109 .083 r
.47058 .73899 m .44056 .73538 L .45134 .73796 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.44056 .26462 m .47058 .26101 L .47605 .25972 L p F P
.505 .664 .505 r
s
.395 .576 .436 r
.47058 .26101 m .44056 .26462 L .43272 .26762 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73087 .57622 m
.73215 .5744 L
s
.5 Mabswid
.056 .074 .056 r
.69462 .64316 m .66947 .67158 L .6657 .67749 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.63633 .701 m .6657 .67749 L .66947 .67158 L p F P
.505 .664 .505 r
s
.096 .11 .084 r
.52684 .73967 m .55439 .73673 L .56374 .73392 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.66947 .32842 m .69462 .35684 L .69127 .35115 L p F P
.505 .664 .505 r
s
.294 .428 .365 r
.69127 .35115 m .6657 .32251 L .66947 .32842 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.55439 .73673 m .52684 .73967 L .52077 .74082 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.52684 .26033 m .55439 .26327 L .5423 .26094 L p F P
.505 .664 .505 r
s
.361 .536 .423 r
.5423 .26094 m .52077 .25918 L .52684 .26033 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.57001 .26922 m .60411 .28114 L .59543 .27668 L p F P
.505 .664 .505 r
s
.366 .539 .433 r
.59543 .27668 m .56374 .26608 L .57001 .26922 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.60411 .71886 m .57001 .73078 L .56374 .73392 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.36811 .70373 m .39961 .72113 L .39342 .71655 L p F P
.505 .664 .505 r
s
.09 .105 .08 r
.39342 .71655 m .36089 .69823 L .36811 .70373 L p F P
.505 .664 .505 r
s
.365 .535 .397 r
.43272 .26762 m .39961 .27887 L .39342 .28345 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.36089 .30177 m .39342 .28345 L .39961 .27887 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.4646 .73999 m .48265 .74128 L .47605 .74028 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.47605 .74028 m .45134 .73796 L .4646 .73999 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.45134 .26204 m .47605 .25972 L .48265 .25872 L p F P
.505 .664 .505 r
s
.361 .534 .407 r
.47605 .25972 m .45134 .26204 L .44056 .26462 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.69462 .35684 m .71499 .38909 L .71217 .3842 L p F P
.505 .664 .505 r
s
.257 .366 .321 r
.71217 .3842 m .69127 .35115 L .69462 .35684 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.71499 .61091 m .69462 .64316 L .69127 .64885 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.6657 .67749 m .69127 .64885 L .69462 .64316 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.52077 .74082 m .5423 .73906 L .55439 .73673 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.5423 .73906 m .52077 .74082 L .51372 .74166 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52077 .25918 m .5423 .26094 L .52803 .25924 L p F P
.505 .664 .505 r
s
.331 .499 .394 r
.52803 .25924 m .51372 .25834 L .52077 .25918 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.4797 .74135 m .49008 .74195 L .48265 .74128 L p F P
.505 .664 .505 r
s
.062 .08 .061 r
.48265 .74128 m .4646 .73999 L .4797 .74135 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.71499 .38909 m .72998 .42434 L .72767 .42076 L p F P
.505 .664 .505 r
s
.086 .102 .077 r
.72767 .42076 m .71217 .3842 L .71499 .38909 L p F P
.505 .664 .505 r
s
.058 .077 .06 r
.69127 .64885 m .71217 .6158 L .71499 .61091 L p F P
.505 .664 .505 r
s
.148 .218 .139 r
.72998 .57566 m .71499 .61091 L .71217 .6158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72111 .60204 m
.72162 .60276 L
s
.5 Mabswid
.311 .472 .366 r
.4646 .26001 m .48265 .25872 L .49008 .25805 L p F P
.505 .664 .505 r
s
.332 .498 .383 r
.48265 .25872 m .4646 .26001 L .45134 .26204 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.41074 .72541 m .44056 .73538 L .43272 .73238 L p F P
.505 .664 .505 r
s
.074 .09 .069 r
.43272 .73238 m .39961 .72113 L .41074 .72541 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.39961 .27887 m .43272 .26762 L .44056 .26462 L p F P
.505 .664 .505 r
s
.063 .08 .061 r
.51372 .74166 m .52803 .74076 L .5423 .73906 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.52803 .74076 m .51372 .74166 L .506 .74214 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51372 .25834 m .52803 .25924 L .51229 .25826 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.51229 .25826 m .506 .25786 L .51372 .25834 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.72998 .42434 m .73916 .46165 L .7372 .45976 L p F P
.505 .664 .505 r
s
.095 .11 .083 r
.7372 .45976 m .72767 .42076 L .72998 .42434 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.73916 .53835 m .72998 .57566 L .72767 .57924 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73215 .5744 m
.73276 .57495 L
s
.5 Mabswid
.148 .218 .139 r
.71217 .6158 m .72767 .57924 L .72998 .57566 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72162 .60276 m
.72267 .60145 L
s
.7249 .59011 m
.72694 .59273 L
s
.5 Mabswid
.316 .479 .377 r
.49589 .74194 m .49799 .74224 L .49008 .74195 L p F P
.505 .664 .505 r
s
.316 .479 .377 r
.49008 .74195 m .4797 .74135 L .49589 .74194 L p F P
.505 .664 .505 r
s
.311 .472 .366 r
.49008 .25805 m .4797 .25865 L .4646 .26001 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.4797 .25865 m .49008 .25805 L .49799 .25776 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.33923 .68043 m .36811 .70373 L .36089 .69823 L p F P
.505 .664 .505 r
s
.304 .446 .375 r
.36089 .69823 m .33142 .67453 L .33923 .68043 L p F P
.505 .664 .505 r
s
.291 .435 .317 r
.39961 .27887 m .36811 .29627 L .36089 .30177 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.33142 .32547 m .36089 .30177 L .36811 .29627 L p F P
.505 .664 .505 r
s
.305 .464 .361 r
.506 .74214 m .51229 .74174 L .52803 .74076 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.51229 .74174 m .506 .74214 L .49799 .74224 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.73916 .46165 m .74225 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
.115 .143 .102 r
.74042 .5 m .7372 .45976 L .73916 .46165 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.74225 .5 m .73916 .53835 L .7372 .54024 L p F P
.505 .664 .505 r
s
.144 .202 .133 r
.72767 .57924 m .7372 .54024 L .73916 .53835 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73229 .57754 m
.73276 .57495 L
s
.5 Mabswid
.061 .078 .059 r
.506 .25786 m .51229 .25826 L .49589 .25806 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49589 .25806 m .49799 .25776 L .506 .25786 L p F P
.505 .664 .505 r
s
.316 .479 .375 r
.49799 .74224 m .49589 .74194 L .51229 .74174 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.49799 .25776 m .49589 .25806 L .4797 .25865 L p F P
.505 .664 .505 r
s
.133 .177 .12 r
.7372 .54024 m .74042 .5 L .74225 .5 L p F P
.505 .664 .505 r
s
.077 .093 .071 r
.56374 .73392 m .59543 .72332 L .60411 .71886 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.63633 .701 m .60411 .71886 L .59543 .72332 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.60411 .28114 m .63633 .299 L .62576 .29361 L p F P
.505 .664 .505 r
s
.075 .091 .069 r
.62576 .29361 m .59543 .27668 L .60411 .28114 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72267 .60145 m
.72445 .59826 L
s
.5 Mabswid
.298 .451 .339 r
.59543 .72332 m .56374 .73392 L .55439 .73673 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.56374 .26608 m .59543 .27668 L .58191 .27264 L p F P
.505 .664 .505 r
s
.073 .089 .068 r
.58191 .27264 m .55439 .26327 L .56374 .26608 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73091 .58226 m
.73229 .57754 L
s
.5 Mabswid
.316 .457 .385 r
.31395 .65171 m .33923 .68043 L .33142 .67453 L p F P
.505 .664 .505 r
s
.316 .457 .385 r
.33142 .67453 m .30591 .64599 L .31395 .65171 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36811 .29627 m .33923 .31957 L .33142 .32547 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.30591 .35401 m .33142 .32547 L .33923 .31957 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72445 .59826 m
.72694 .59273 L
s
.72857 .58873 m
.73091 .58226 L
s
.5 Mabswid
.362 .536 .428 r
.42652 .72914 m .45134 .73796 L .44056 .73538 L p F P
.505 .664 .505 r
s
.362 .536 .428 r
.44056 .73538 m .41074 .72541 L .42652 .72914 L p F P
.505 .664 .505 r
s
.296 .448 .336 r
.44056 .26462 m .41074 .27459 L .39961 .27887 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.41074 .27459 m .44056 .26462 L .45134 .26204 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72694 .59273 m
.72857 .58873 L
s
.5 Mabswid
.369 .539 .437 r
.38203 .70894 m .41074 .72541 L .39961 .72113 L p F P
.505 .664 .505 r
s
.369 .539 .437 r
.39961 .72113 m .36811 .70373 L .38203 .70894 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.36811 .29627 m .39961 .27887 L .41074 .27459 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.33923 .31957 m .31395 .34829 L .30591 .35401 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.28515 .38667 m .30591 .35401 L .31395 .34829 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.29319 .61827 m .31395 .65171 L .30591 .64599 L p F P
.505 .664 .505 r
s
.325 .459 .388 r
.30591 .64599 m .28515 .61333 L .29319 .61827 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.6657 .67749 m .63633 .701 L .62576 .70639 L p F P
.505 .664 .505 r
s
.266 .404 .295 r
.59543 .72332 m .62576 .70639 L .63633 .701 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.63633 .299 m .6657 .32251 L .65374 .31669 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.65374 .31669 m .62576 .29361 L .63633 .299 L p F P
.505 .664 .505 r
s
.298 .451 .339 r
.55439 .73673 m .58191 .72736 L .59543 .72332 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.58191 .72736 m .55439 .73673 L .5423 .73906 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.55439 .26327 m .58191 .27264 L .56403 .26926 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.56403 .26926 m .5423 .26094 L .55439 .26327 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.27773 .58105 m .29319 .61827 L .28515 .61333 L p F P
.505 .664 .505 r
s
.32 .443 .376 r
.28515 .61333 m .26981 .57743 L .27773 .58105 L p F P
.505 .664 .505 r
s
.099 .12 .098 r
.31395 .34829 m .29319 .38173 L .28515 .38667 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.26981 .42257 m .28515 .38667 L .29319 .38173 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.44631 .73211 m .4646 .73999 L .45134 .73796 L p F P
.505 .664 .505 r
s
.417 .605 .476 r
.45134 .73796 m .42652 .72914 L .44631 .73211 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.42652 .27086 m .45134 .26204 L .4646 .26001 L p F P
.505 .664 .505 r
s
.075 .092 .07 r
.45134 .26204 m .42652 .27086 L .41074 .27459 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.2682 .5412 m .27773 .58105 L .26981 .57743 L p F P
.505 .664 .505 r
s
.303 .41 .35 r
.26981 .57743 m .2604 .53929 L .2682 .5412 L p F P
.505 .664 .505 r
s
.144 .173 .153 r
.29319 .38173 m .27773 .41895 L .26981 .42257 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.2604 .46071 m .26981 .42257 L .27773 .41895 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.62576 .70639 m .59543 .72332 L .58191 .72736 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.59543 .27668 m .62576 .29361 L .60857 .28866 L p F P
.505 .664 .505 r
s
.126 .138 .105 r
.60857 .28866 m .58191 .27264 L .59543 .27668 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.6657 .32251 m .69127 .35115 L .67836 .34548 L p F P
.505 .664 .505 r
s
.143 .153 .117 r
.67836 .34548 m .65374 .31669 L .6657 .32251 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.69127 .64885 m .6657 .67749 L .65374 .68331 L p F P
.505 .664 .505 r
s
.302 .444 .316 r
.62576 .70639 m .65374 .68331 L .6657 .67749 L p F P
.505 .664 .505 r
s
.182 .22 .201 r
.27773 .41895 m .2682 .4588 L .2604 .46071 L p F P
.505 .664 .505 r
s
.233 .297 .261 r
.25723 .5 m .2604 .46071 L .2682 .4588 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.26498 .5 m .2682 .5412 L .2604 .53929 L p F P
.505 .664 .505 r
s
.273 .361 .311 r
.2604 .53929 m .25723 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72364 .59787 m
.73262 .5772 L
s
.71506 .6176 m
.72364 .59787 L
s
.5 Mabswid
.233 .297 .261 r
.2682 .4588 m .26498 .5 L .25723 .5 L p F P
.505 .664 .505 r
s
.366 .539 .406 r
.5423 .73906 m .56403 .73074 L .58191 .72736 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.56403 .73074 m .5423 .73906 L .52803 .74076 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.5423 .26094 m .56403 .26926 L .54259 .26676 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.54259 .26676 m .52803 .25924 L .5423 .26094 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72155 .60436 m
.72373 .60014 L
s
.5 Mabswid
.427 .607 .489 r
.35538 .68609 m .38203 .70894 L .36811 .70373 L p F P
.505 .664 .505 r
s
.427 .607 .489 r
.36811 .70373 m .33923 .68043 L .35538 .68609 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.41074 .27459 m .38203 .29106 L .36811 .29627 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.33923 .31957 m .36811 .29627 L .38203 .29106 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73141 .57986 m
.7303 .58388 L
s
.5 Mabswid
.452 .65 .505 r
.46913 .7341 m .4797 .74135 L .4646 .73999 L p F P
.505 .664 .505 r
s
.452 .65 .505 r
.4646 .73999 m .44631 .73211 L .46913 .7341 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.44631 .26789 m .4646 .26001 L .4797 .25865 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.4646 .26001 m .44631 .26789 L .42652 .27086 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72009 .60668 m
.72155 .60436 L
s
.5 Mabswid
.458 .653 .516 r
.40236 .71354 m .42652 .72914 L .41074 .72541 L p F P
.505 .664 .505 r
s
.458 .653 .516 r
.41074 .72541 m .38203 .70894 L .40236 .71354 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.38203 .29106 m .41074 .27459 L .42652 .27086 L p F P
.505 .664 .505 r
s
.418 .606 .458 r
.52803 .74076 m .54259 .73324 L .56403 .73074 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.54259 .73324 m .52803 .74076 L .51229 .74174 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.52803 .25924 m .54259 .26676 L .51871 .26531 L p F P
.505 .664 .505 r
s
.142 .153 .116 r
.51871 .26531 m .51229 .25826 L .52803 .25924 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69127 .35115 m .71217 .3842 L .69868 .37929 L p F P
.505 .664 .505 r
s
.171 .183 .138 r
.69868 .37929 m .67836 .34548 L .69127 .35115 L p F P
.505 .664 .505 r
s
.332 .462 .315 r
.71217 .6158 m .69127 .64885 L .67836 .65452 L p F P
.505 .664 .505 r
s
.324 .463 .323 r
.65374 .68331 m .67836 .65452 L .69127 .64885 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73141 .57986 m
.7316 .57796 L
s
.5 Mabswid
.47 .672 .517 r
.49373 .73498 m .49589 .74194 L .4797 .74135 L p F P
.505 .664 .505 r
s
.47 .672 .517 r
.4797 .74135 m .46913 .7341 L .49373 .73498 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.46913 .2659 m .4797 .25865 L .49589 .25806 L p F P
.505 .664 .505 r
s
.129 .141 .107 r
.4797 .25865 m .46913 .2659 L .44631 .26789 L p F P
.505 .664 .505 r
s
.453 .65 .493 r
.51229 .74174 m .51871 .73469 L .54259 .73324 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.51871 .73469 m .51229 .74174 L .49589 .74194 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.51229 .25826 m .51871 .26531 L .49373 .26502 L p F P
.505 .664 .505 r
s
.147 .157 .12 r
.49373 .26502 m .49589 .25806 L .51229 .25826 L p F P
.505 .664 .505 r
s
.47 .671 .513 r
.49589 .74194 m .49373 .73498 L .51871 .73469 L p F P
.505 .664 .505 r
s
.142 .153 .117 r
.49589 .25806 m .49373 .26502 L .46913 .2659 L p F P
.505 .664 .505 r
s
.326 .443 .295 r
.72767 .57924 m .71217 .6158 L .69868 .62071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71896 .60742 m
.72009 .60668 L
s
.5 Mabswid
.332 .462 .315 r
.67836 .65452 m .69868 .62071 L .71217 .6158 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71217 .3842 m .72767 .42076 L .71386 .41715 L p F P
.505 .664 .505 r
s
.217 .251 .178 r
.71386 .41715 m .69868 .37929 L .71217 .3842 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.65374 .68331 m .62576 .70639 L .60857 .71134 L p F P
.505 .664 .505 r
s
.374 .543 .399 r
.58191 .72736 m .60857 .71134 L .62576 .70639 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.62576 .29361 m .65374 .31669 L .63344 .31129 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.63344 .31129 m .60857 .28866 L .62576 .29361 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33181 .65724 m .35538 .68609 L .33923 .68043 L p F P
.505 .664 .505 r
s
.464 .646 .518 r
.33923 .68043 m .31395 .65171 L .33181 .65724 L p F P
.505 .664 .505 r
s
.117 .129 .098 r
.38203 .29106 m .35538 .31391 L .33923 .31957 L p F P
.505 .664 .505 r
s
.155 .168 .131 r
.31395 .34829 m .33923 .31957 L .35538 .31391 L p F P
.505 .664 .505 r
s
.459 .651 .481 r
.60857 .71134 m .58191 .72736 L .56403 .73074 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58191 .27264 m .60857 .28866 L .58528 .28448 L p F P
.505 .664 .505 r
s
.167 .176 .134 r
.58528 .28448 m .56403 .26926 L .58191 .27264 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72767 .42076 m .7372 .45976 L .72324 .45784 L p F P
.505 .664 .505 r
s
.254 .308 .211 r
.72324 .45784 m .71386 .41715 L .72767 .42076 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.7372 .54024 m .72767 .57924 L .71386 .58285 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7305 .57854 m
.7316 .57796 L
s
.5 Mabswid
.326 .443 .295 r
.69868 .62071 m .71386 .58285 L .72767 .57924 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71893 .60607 m
.71896 .60742 L
s
.71893 .60607 m
.71962 .60276 L
s
.5 Mabswid
.521 .731 .568 r
.42835 .71723 m .44631 .73211 L .42652 .72914 L p F P
.505 .664 .505 r
s
.521 .731 .568 r
.42652 .72914 m .40236 .71354 L .42835 .71723 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.40236 .28646 m .42652 .27086 L .44631 .26789 L p F P
.505 .664 .505 r
s
.13 .142 .108 r
.42652 .27086 m .40236 .28646 L .38203 .29106 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.7372 .45976 m .74042 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
.281 .353 .236 r
.72642 .5 m .72324 .45784 L .7372 .45976 L p F P
.505 .664 .505 r
s
.298 .386 .254 r
.74042 .5 m .7372 .54024 L .72324 .54216 L p F P
.505 .664 .505 r
s
.307 .409 .265 r
.71386 .58285 m .72324 .54216 L .7372 .54024 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72884 .58123 m
.7305 .57854 L
s
.5 Mabswid
.298 .386 .254 r
.72324 .54216 m .72642 .5 L .74042 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72625 .58614 m
.72884 .58123 L
s
.5 Mabswid
.155 .168 .131 r
.35538 .31391 m .33181 .34276 L .31395 .34829 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.29319 .38173 m .31395 .34829 L .33181 .34276 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31228 .62308 m .33181 .65724 L .31395 .65171 L p F P
.505 .664 .505 r
s
.482 .658 .527 r
.31395 .65171 m .29319 .61827 L .31228 .62308 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.37971 .69114 m .40236 .71354 L .38203 .70894 L p F P
.505 .664 .505 r
s
.525 .73 .573 r
.38203 .70894 m .35538 .68609 L .37971 .69114 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.35538 .31391 m .38203 .29106 L .40236 .28646 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71962 .60276 m
.7216 .59702 L
s
.5 Mabswid
.459 .651 .481 r
.56403 .73074 m .58528 .71552 L .60857 .71134 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.58528 .71552 m .56403 .73074 L .54259 .73324 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.56403 .26926 m .58528 .28448 L .55693 .28136 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.55693 .28136 m .54259 .26676 L .56403 .26926 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72326 .59286 m
.72625 .58614 L
s
.7216 .59702 m
.72326 .59286 L
s
.5 Mabswid
.46 .635 .453 r
.67836 .65452 m .65374 .68331 L .63344 .68871 L p F P
.505 .664 .505 r
s
.428 .604 .437 r
.60857 .71134 m .63344 .68871 L .65374 .68331 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65374 .31669 m .67836 .34548 L .65555 .34018 L p F P
.505 .664 .505 r
s
.226 .245 .18 r
.65555 .34018 m .63344 .31129 L .65374 .31669 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29763 .58461 m .31228 .62308 L .29319 .61827 L p F P
.505 .664 .505 r
s
.483 .649 .519 r
.29319 .61827 m .27773 .58105 L .29763 .58461 L p F P
.505 .664 .505 r
s
.221 .25 .205 r
.33181 .34276 m .31228 .37692 L .29319 .38173 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.27773 .41895 m .29319 .38173 L .31228 .37692 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.45868 .71973 m .46913 .7341 L .44631 .73211 L p F P
.505 .664 .505 r
s
.558 .777 .597 r
.44631 .73211 m .42835 .71723 L .45868 .71973 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.42835 .28277 m .44631 .26789 L .46913 .2659 L p F P
.505 .664 .505 r
s
.169 .178 .135 r
.44631 .26789 m .42835 .28277 L .40236 .28646 L p F P
.505 .664 .505 r
s
.519 .718 .524 r
.63344 .68871 m .60857 .71134 L .58528 .71552 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60857 .28866 m .63344 .31129 L .60529 .30668 L p F P
.505 .664 .505 r
s
.227 .24 .178 r
.60529 .30668 m .58528 .28448 L .60857 .28866 L p F P
.505 .664 .505 r
s
.518 .725 .54 r
.54259 .73324 m .55693 .71864 L .58528 .71552 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.55693 .71864 m .54259 .73324 L .51871 .73469 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.54259 .26676 m .55693 .28136 L .52506 .27954 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.52506 .27954 m .51871 .26531 L .54259 .26676 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.28856 .54309 m .29763 .58461 L .27773 .58105 L p F P
.505 .664 .505 r
s
.47 .621 .496 r
.27773 .58105 m .2682 .5412 L .28856 .54309 L p F P
.505 .664 .505 r
s
.296 .356 .288 r
.31228 .37692 m .29763 .41539 L .27773 .41895 L p F P
.505 .664 .505 r
s
.358 .446 .358 r
.2682 .4588 m .27773 .41895 L .29763 .41539 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7134 .60661 m
.71588 .60244 L
s
.71588 .60244 m
.71756 .59838 L
s
.5 Mabswid
.575 .797 .606 r
.4916 .72084 m .49373 .73498 L .46913 .7341 L p F P
.505 .664 .505 r
s
.575 .797 .606 r
.46913 .7341 m .45868 .71973 L .4916 .72084 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.45868 .28027 m .46913 .2659 L .49373 .26502 L p F P
.505 .664 .505 r
s
.196 .203 .154 r
.46913 .2659 m .45868 .28027 L .42835 .28277 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67836 .34548 m .69868 .37929 L .67394 .37466 L p F P
.505 .664 .505 r
s
.285 .33 .231 r
.67394 .37466 m .65555 .34018 L .67836 .34548 L p F P
.505 .664 .505 r
s
.473 .641 .451 r
.69868 .62071 m .67836 .65452 L .65555 .65982 L p F P
.505 .664 .505 r
s
.46 .635 .453 r
.63344 .68871 m .65555 .65982 L .67836 .65452 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71173 .60877 m
.7134 .60661 L
s
.5 Mabswid
.563 .768 .6 r
.35949 .66222 m .37971 .69114 L .35538 .68609 L p F P
.505 .664 .505 r
s
.563 .768 .6 r
.35538 .68609 m .33181 .65724 L .35949 .66222 L p F P
.505 .664 .505 r
s
.175 .184 .14 r
.40236 .28646 m .37971 .30886 L .35538 .31391 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.33181 .34276 m .35538 .31391 L .37971 .30886 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72157 .58339 m
.72163 .58758 L
s
.5 Mabswid
.358 .446 .358 r
.29763 .41539 m .28856 .45691 L .2682 .4588 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.26498 .5 m .2682 .4588 L .28856 .45691 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.28548 .5 m .28856 .54309 L .2682 .5412 L p F P
.505 .664 .505 r
s
.444 .578 .462 r
.2682 .5412 m .26498 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.555 .772 .578 r
.51871 .73469 m .52506 .72046 L .55693 .71864 L p F P
.505 .664 .505 r
s
.574 .795 .599 r
.52506 .72046 m .51871 .73469 L .49373 .73498 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.51871 .26531 m .52506 .27954 L .4916 .27916 L p F P
.505 .664 .505 r
s
.217 .222 .169 r
.4916 .27916 m .49373 .26502 L .51871 .26531 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70915 .61114 m
.71173 .60877 L
s
.5 Mabswid
.574 .795 .599 r
.49373 .73498 m .4916 .72084 L .52506 .72046 L p F P
.505 .664 .505 r
s
.212 .217 .165 r
.49373 .26502 m .4916 .27916 L .45868 .28027 L p F P
.505 .664 .505 r
s
.407 .519 .415 r
.28856 .45691 m .28548 .5 L .26498 .5 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.41137 .69522 m .42835 .71723 L .40236 .71354 L p F P
.505 .664 .505 r
s
.586 .805 .621 r
.40236 .71354 m .37971 .69114 L .41137 .69522 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.37971 .30886 m .40236 .28646 L .42835 .28277 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72057 .5814 m
.72157 .58339 L
s
.5 Mabswid
.331 .398 .271 r
.69868 .37929 m .71386 .41715 L .68778 .41371 L p F P
.505 .664 .505 r
s
.331 .398 .271 r
.68778 .41371 m .67394 .37466 L .69868 .37929 L p F P
.505 .664 .505 r
s
.471 .627 .436 r
.71386 .58285 m .69868 .62071 L .67394 .62534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70632 .61188 m
.70915 .61114 L
s
.5 Mabswid
.473 .641 .451 r
.65555 .65982 m .67394 .62534 L .69868 .62071 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71767 .58197 m
.72057 .5814 L
s
.70512 .61046 m
.70632 .61188 L
s
.5 Mabswid
.519 .718 .524 r
.58528 .71552 m .60529 .69332 L .63344 .68871 L p F P
.505 .664 .505 r
s
.577 .79 .582 r
.60529 .69332 m .58528 .71552 L .55693 .71864 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.58528 .28448 m .60529 .30668 L .57052 .30321 L p F P
.505 .664 .505 r
s
.275 .303 .218 r
.57052 .30321 m .55693 .28136 L .58528 .28448 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.63344 .31129 m .65555 .34018 L .62323 .33561 L p F P
.505 .664 .505 r
s
.301 .343 .241 r
.62323 .33561 m .60529 .30668 L .63344 .31129 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.65555 .65982 m .63344 .68871 L .60529 .69332 L p F P
.505 .664 .505 r
s
.252 .281 .216 r
.37971 .30886 m .35949 .33778 L .33181 .34276 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.31228 .37692 m .33181 .34276 L .35949 .33778 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.34259 .62745 m .35949 .66222 L .33181 .65724 L p F P
.505 .664 .505 r
s
.579 .778 .606 r
.33181 .65724 m .31228 .62308 L .34259 .62745 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.71386 .41715 m .72324 .45784 L .69638 .45601 L p F P
.505 .664 .505 r
s
.365 .452 .302 r
.69638 .45601 m .68778 .41371 L .71386 .41715 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.72324 .54216 m .71386 .58285 L .68778 .58629 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71481 .58475 m
.71767 .58197 L
s
.5 Mabswid
.471 .627 .436 r
.67394 .62534 m .68778 .58629 L .71386 .58285 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70461 .607 m
.70512 .61046 L
s
.70592 .60106 m
.71756 .59838 L
s
.5 Mabswid
.619 .844 .643 r
.44875 .698 m .45868 .71973 L .42835 .71723 L p F P
.505 .664 .505 r
s
.619 .844 .643 r
.42835 .71723 m .41137 .69522 L .44875 .698 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.41137 .30478 m .42835 .28277 L .45868 .28027 L p F P
.505 .664 .505 r
s
.228 .243 .18 r
.42835 .28277 m .41137 .30478 L .37971 .30886 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70461 .607 m
.70592 .60106 L
s
.5 Mabswid
.395 .499 .332 r
.72324 .45784 m .72642 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
.395 .499 .332 r
.6993 .5 m .69638 .45601 L .72324 .45784 L p F P
.505 .664 .505 r
s
.43 .554 .375 r
.72642 .5 m .72324 .54216 L .69638 .54399 L p F P
.505 .664 .505 r
s
.456 .597 .41 r
.68778 .58629 m .69638 .54399 L .72324 .54216 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71104 .58982 m
.71481 .58475 L
s
.5 Mabswid
.43 .554 .375 r
.69638 .54399 m .6993 .5 L .72642 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70592 .60106 m
.70752 .59676 L
s
.70752 .59676 m
.71104 .58982 L
s
.5 Mabswid
.577 .79 .582 r
.55693 .71864 m .57052 .69679 L .60529 .69332 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.57052 .69679 m .55693 .71864 L .52506 .72046 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.55693 .28136 m .57052 .30321 L .5311 .30117 L p F P
.505 .664 .505 r
s
.301 .338 .24 r
.5311 .30117 m .52506 .27954 L .55693 .28136 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.39609 .66628 m .41137 .69522 L .37971 .69114 L p F P
.505 .664 .505 r
s
.619 .836 .641 r
.37971 .69114 m .35949 .66222 L .39609 .66628 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.35949 .33778 m .37971 .30886 L .41137 .30478 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.32983 .58786 m .34259 .62745 L .31228 .62308 L p F P
.505 .664 .505 r
s
.578 .767 .595 r
.31228 .62308 m .29763 .58461 L .32983 .58786 L p F P
.505 .664 .505 r
s
.34 .404 .31 r
.35949 .33778 m .34259 .37255 L .31228 .37692 L p F P
.505 .664 .505 r
s
.41 .503 .387 r
.29763 .41539 m .31228 .37692 L .34259 .37255 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.48957 .69924 m .4916 .72084 L .45868 .71973 L p F P
.505 .664 .505 r
s
.631 .858 .647 r
.45868 .71973 m .44875 .698 L .48957 .69924 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.44875 .302 m .45868 .28027 L .4916 .27916 L p F P
.505 .664 .505 r
s
.274 .303 .218 r
.45868 .28027 m .44875 .302 L .41137 .30478 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.65555 .34018 m .67394 .37466 L .63828 .37064 L p F P
.505 .664 .505 r
s
.357 .424 .289 r
.63828 .37064 m .62323 .33561 L .65555 .34018 L p F P
.505 .664 .505 r
s
.561 .75 .537 r
.67394 .62534 m .65555 .65982 L .62323 .66439 L p F P
.505 .664 .505 r
s
.55 .747 .54 r
.60529 .69332 m .62323 .66439 L .65555 .65982 L p F P
.505 .664 .505 r
s
.612 .833 .618 r
.52506 .72046 m .5311 .69883 L .57052 .69679 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.5311 .69883 m .52506 .72046 L .4916 .72084 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.52506 .27954 m .5311 .30117 L .48957 .30076 L p F P
.505 .664 .505 r
s
.309 .349 .246 r
.48957 .30076 m .4916 .27916 L .52506 .27954 L p F P
.505 .664 .505 r
s
.629 .854 .639 r
.4916 .72084 m .48957 .69924 L .5311 .69883 L p F P
.505 .664 .505 r
s
.3 .337 .239 r
.4916 .27916 m .48957 .30076 L .44875 .302 L p F P
.505 .664 .505 r
s
.605 .814 .594 r
.62323 .66439 m .60529 .69332 L .57052 .69679 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.60529 .30668 m .62323 .33561 L .58279 .33214 L p F P
.505 .664 .505 r
s
.346 .403 .278 r
.58279 .33214 m .57052 .30321 L .60529 .30668 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69532 .60678 m
.70295 .58419 L
s
.69151 .61304 m
.69532 .60678 L
s
.5 Mabswid
.41 .503 .387 r
.34259 .37255 m .32983 .41214 L .29763 .41539 L p F P
.505 .664 .505 r
s
.465 .584 .45 r
.28856 .45691 m .29763 .41539 L .32983 .41214 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.32189 .54482 m .32983 .58786 L .29763 .58461 L p F P
.505 .664 .505 r
s
.565 .74 .573 r
.29763 .58461 m .28856 .54309 L .32189 .54482 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68781 .61544 m
.69151 .61304 L
s
.5 Mabswid
.465 .584 .45 r
.32983 .41214 m .32189 .45518 L .28856 .45691 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.28548 .5 m .28856 .45691 L .32189 .45518 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.3192 .5 m .32189 .54482 L .28856 .54309 L p F P
.505 .664 .505 r
s
.541 .7 .541 r
.28856 .54309 m .28548 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.329 .382 .284 r
.41137 .30478 m .39609 .33372 L .35949 .33778 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.34259 .37255 m .35949 .33778 L .39609 .33372 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.38325 .63104 m .39609 .66628 L .35949 .66222 L p F P
.505 .664 .505 r
s
.629 .839 .641 r
.35949 .66222 m .34259 .62745 L .38325 .63104 L p F P
.505 .664 .505 r
s
.508 .649 .5 r
.32189 .45518 m .3192 .5 L .28548 .5 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.39609 .33372 m .41137 .30478 L .44875 .302 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.43977 .66907 m .44875 .698 L .41137 .69522 L p F P
.505 .664 .505 r
s
.646 .867 .657 r
.41137 .69522 m .39609 .66628 L .43977 .66907 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.67394 .37466 m .68778 .41371 L .64966 .41072 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.64966 .41072 m .63828 .37064 L .67394 .37466 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.68778 .58629 m .67394 .62534 L .63828 .62936 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68323 .61612 m
.68781 .61544 L
s
.5 Mabswid
.561 .75 .537 r
.62323 .66439 m .63828 .62936 L .67394 .62534 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68079 .61461 m
.68323 .61612 L
s
.5 Mabswid
.605 .814 .594 r
.57052 .69679 m .58279 .66786 L .62323 .66439 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.58279 .66786 m .57052 .69679 L .5311 .69883 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.57052 .30321 m .58279 .33214 L .53658 .3301 L p F P
.505 .664 .505 r
s
.369 .434 .298 r
.53658 .3301 m .5311 .30117 L .57052 .30321 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.69638 .54399 m .68778 .58629 L .64966 .58928 L p F P
.505 .664 .505 r
s
.557 .735 .522 r
.63828 .62936 m .64966 .58928 L .68778 .58629 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67796 .60913 m
.68079 .61461 L
s
.5 Mabswid
.448 .559 .382 r
.68778 .41371 m .69638 .45601 L .65676 .45441 L p F P
.505 .664 .505 r
s
.448 .559 .382 r
.65676 .45441 m .64966 .41072 L .68778 .41371 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.62323 .33561 m .63828 .37064 L .59314 .36757 L p F P
.505 .664 .505 r
s
.402 .484 .33 r
.59314 .36757 m .58279 .33214 L .62323 .33561 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.63828 .62936 m .62323 .66439 L .58279 .66786 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67397 .61547 m
.67796 .60913 L
s
.66963 .61787 m
.67397 .61547 L
s
.5 Mabswid
.655 .877 .658 r
.48773 .67031 m .48957 .69924 L .44875 .698 L p F P
.505 .664 .505 r
s
.655 .877 .658 r
.44875 .698 m .43977 .66907 L .48773 .67031 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.43977 .33093 m .44875 .302 L .48957 .30076 L p F P
.505 .664 .505 r
s
.373 .44 .321 r
.44875 .302 m .43977 .33093 L .39609 .33372 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66401 .61849 m
.66963 .61787 L
s
.5 Mabswid
.625 .824 .628 r
.3735 .59054 m .38325 .63104 L .34259 .62745 L p F P
.505 .664 .505 r
s
.625 .824 .628 r
.34259 .62745 m .32983 .58786 L .3735 .59054 L p F P
.505 .664 .505 r
s
.411 .497 .372 r
.39609 .33372 m .38325 .36896 L .34259 .37255 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.32983 .41214 m .34259 .37255 L .38325 .36896 L p F P
.505 .664 .505 r
s
.636 .852 .628 r
.5311 .69883 m .53658 .6699 L .58279 .66786 L p F P
.505 .664 .505 r
s
.651 .872 .648 r
.53658 .6699 m .5311 .69883 L .48957 .69924 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.5311 .30117 m .53658 .3301 L .48773 .32969 L p F P
.505 .664 .505 r
s
.39 .463 .326 r
.48773 .32969 m .48957 .30076 L .5311 .30117 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.69638 .45601 m .6993 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
.488 .619 .429 r
.65918 .5 m .65676 .45441 L .69638 .45601 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.6993 .5 m .69638 .54399 L .65676 .54559 L p F P
.505 .664 .505 r
s
.542 .707 .498 r
.64966 .58928 m .65676 .54559 L .69638 .54399 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67796 .60913 m
.68507 .58612 L
s
.5 Mabswid
.651 .872 .648 r
.48957 .69924 m .48773 .67031 L .53658 .6699 L p F P
.505 .664 .505 r
s
.392 .465 .333 r
.48957 .30076 m .48773 .32969 L .43977 .33093 L p F P
.505 .664 .505 r
s
.519 .668 .467 r
.65676 .54559 m .65918 .5 L .6993 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66082 .61691 m
.66401 .61849 L
s
.5 Mabswid
.449 .547 .402 r
.38325 .36896 m .39609 .33372 L .43977 .33093 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.43218 .63351 m .43977 .66907 L .39609 .66628 L p F P
.505 .664 .505 r
s
.652 .865 .653 r
.39609 .66628 m .38325 .63104 L .43218 .63351 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65674 .61128 m
.66082 .61691 L
s
.5 Mabswid
.611 .797 .605 r
.36741 .54626 m .3735 .59054 L .32983 .58786 L p F P
.505 .664 .505 r
s
.611 .797 .605 r
.32983 .58786 m .32189 .54482 L .36741 .54626 L p F P
.505 .664 .505 r
s
.473 .586 .441 r
.38325 .36896 m .3735 .40946 L .32983 .41214 L p F P
.505 .664 .505 r
s
.522 .657 .495 r
.32189 .45518 m .32983 .41214 L .3735 .40946 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65556 .61423 m
.66313 .58788 L
s
.65405 .61949 m
.65556 .61423 L
s
.5 Mabswid
.605 .795 .573 r
.64966 .58928 m .63828 .62936 L .59314 .63243 L p F P
.505 .664 .505 r
s
.611 .813 .589 r
.58279 .66786 m .59314 .63243 L .63828 .62936 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.63828 .37064 m .64966 .41072 L .60101 .40842 L p F P
.505 .664 .505 r
s
.46 .568 .394 r
.60101 .40842 m .59314 .36757 L .63828 .37064 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.58279 .33214 m .59314 .36757 L .54122 .36576 L p F P
.505 .664 .505 r
s
.442 .537 .376 r
.54122 .36576 m .53658 .3301 L .58279 .33214 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.59314 .63243 m .58279 .66786 L .53658 .6699 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63169 .63581 m
.63452 .63388 L
s
.63293 .63231 m
.63452 .63388 L
s
.63007 .63426 m
.63169 .63581 L
s
.5 Mabswid
.522 .657 .495 r
.3735 .40946 m .36741 .45374 L .32189 .45518 L p F P
.505 .664 .505 r
s
.559 .714 .54 r
.3192 .5 m .32189 .45518 L .36741 .45374 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.36534 .5 m .36741 .54626 L .32189 .54482 L p F P
.505 .664 .505 r
s
.589 .76 .576 r
.32189 .54482 m .3192 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63007 .63426 m
.63293 .63231 L
s
.5 Mabswid
.559 .714 .54 r
.36741 .45374 m .36534 .5 L .3192 .5 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.43218 .36649 m .43977 .33093 L .48773 .32969 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.48617 .63462 m .48773 .67031 L .43977 .66907 L p F P
.505 .664 .505 r
s
.659 .872 .651 r
.43977 .66907 m .43218 .63351 L .48617 .63462 L p F P
.505 .664 .505 r
s
.449 .547 .402 r
.43977 .33093 m .43218 .36649 L .38325 .36896 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.3735 .40946 m .38325 .36896 L .43218 .36649 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.42641 .59239 m .43218 .63351 L .38325 .63104 L p F P
.505 .664 .505 r
s
.645 .848 .637 r
.38325 .63104 m .3735 .59054 L .42641 .59239 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.65676 .54559 m .64966 .58928 L .60101 .59158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63661 .62097 m
.63857 .61329 L
s
.5 Mabswid
.605 .795 .573 r
.59314 .63243 m .60101 .59158 L .64966 .58928 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63857 .61329 m
.64477 .58903 L
s
.5 Mabswid
.505 .634 .445 r
.64966 .41072 m .65676 .45441 L .60593 .45318 L p F P
.505 .664 .505 r
s
.505 .634 .445 r
.60593 .45318 m .60101 .40842 L .64966 .41072 L p F P
.505 .664 .505 r
s
.64 .848 .621 r
.53658 .6699 m .54122 .63424 L .59314 .63243 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.53658 .3301 m .54122 .36576 L .48617 .36538 L p F P
.505 .664 .505 r
s
.461 .563 .402 r
.48617 .36538 m .48773 .32969 L .53658 .3301 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.54122 .63424 m .53658 .6699 L .48773 .67031 L p F P
.505 .664 .505 r
s
.654 .866 .64 r
.48773 .67031 m .48617 .63462 L .54122 .63424 L p F P
.505 .664 .505 r
s
.464 .567 .41 r
.48773 .32969 m .48617 .36538 L .43218 .36649 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.65676 .45441 m .65918 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
.541 .688 .487 r
.6076 .5 m .60593 .45318 L .65676 .45441 L p F P
.505 .664 .505 r
s
.569 .732 .521 r
.65918 .5 m .65676 .54559 L .60593 .54682 L p F P
.505 .664 .505 r
s
.591 .768 .55 r
.60101 .59158 m .60593 .54682 L .65676 .54559 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61547 .6204 m
.61956 .61392 L
s
.60988 .62272 m
.61547 .6204 L
s
.5 Mabswid
.632 .829 .604 r
.60101 .59158 m .59314 .63243 L .54122 .63424 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.59314 .36757 m .60101 .40842 L .54475 .40706 L p F P
.505 .664 .505 r
s
.496 .615 .436 r
.54475 .40706 m .54122 .36576 L .59314 .36757 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61956 .61392 m
.62456 .59005 L
s
.60209 .62313 m
.60988 .62272 L
s
.5 Mabswid
.569 .732 .521 r
.60593 .54682 m .6076 .5 L .65918 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.58586 .63706 m
.58957 .6165 L
s
.5 Mabswid
.631 .821 .615 r
.42279 .54725 m .42641 .59239 L .3735 .59054 L p F P
.505 .664 .505 r
s
.631 .821 .615 r
.3735 .59054 m .36741 .54626 L .42279 .54725 L p F P
.505 .664 .505 r
s
.505 .628 .464 r
.43218 .36649 m .42641 .40761 L .3735 .40946 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.36741 .45374 m .3735 .40946 L .42641 .40761 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59724 .62135 m
.60209 .62313 L
s
.59032 .61532 m
.59724 .62135 L
s
.5 Mabswid
.651 .854 .635 r
.48498 .59322 m .48617 .63462 L .43218 .63351 L p F P
.505 .664 .505 r
s
.651 .854 .635 r
.43218 .63351 m .42641 .59239 L .48498 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.42641 .40761 m .43218 .36649 L .48617 .36538 L p F P
.505 .664 .505 r
s
.632 .829 .604 r
.54122 .63424 m .54475 .59294 L .60101 .59158 L p F P
.505 .664 .505 r
s
.646 .847 .624 r
.54475 .59294 m .54122 .63424 L .48617 .63462 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.54122 .36576 m .54475 .40706 L .48498 .40678 L p F P
.505 .664 .505 r
s
.514 .639 .46 r
.48498 .40678 m .48617 .36538 L .54122 .36576 L p F P
.505 .664 .505 r
s
.549 .692 .514 r
.42641 .40761 m .42279 .45275 L .36741 .45374 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.36534 .5 m .36741 .45374 L .42279 .45275 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.42155 .5 m .42279 .54725 L .36741 .54626 L p F P
.505 .664 .505 r
s
.61 .786 .587 r
.36741 .54626 m .36534 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.46057 .6386 m
.47046 .61743 L
s
.44687 .61622 m
.46057 .6386 L
s
.44588 .6146 m
.44687 .61622 L
s
.5 Mabswid
.538 .677 .483 r
.60101 .40842 m .60593 .45318 L .54696 .45245 L p F P
.505 .664 .505 r
s
.538 .677 .483 r
.54696 .45245 m .54475 .40706 L .60101 .40842 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.60593 .54682 m .60101 .59158 L .54475 .59294 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59045 .61161 m
.59414 .59121 L
s
.58957 .6165 m
.59045 .61161 L
s
.5 Mabswid
.646 .847 .624 r
.48617 .63462 m .48498 .59322 L .54475 .59294 L p F P
.505 .664 .505 r
s
.517 .644 .469 r
.48617 .36538 m .48498 .40678 L .42641 .40761 L p F P
.505 .664 .505 r
s
.583 .744 .554 r
.42279 .45275 m .42155 .5 L .36534 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.55773 .62482 m
.56379 .6226 L
s
.56379 .6226 m
.57016 .61819 L
s
.54899 .62503 m
.55773 .62482 L
s
.54331 .62308 m
.54899 .62503 L
s
.53771 .61893 m
.54331 .62308 L
s
.51025 .62554 m
.51928 .62548 L
s
.50424 .62349 m
.51025 .62554 L
s
.5 Mabswid
.636 .827 .612 r
.48424 .5477 m .48498 .59322 L .42641 .59239 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44543 .61387 m
.44588 .6146 L
s
.4725 .61308 m
.48208 .59257 L
s
.47046 .61743 m
.4725 .61308 L
s
.5 Mabswid
.636 .827 .612 r
.42641 .59239 m .42279 .54725 L .48424 .5477 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43198 .5919 m
.44543 .61387 L
s
.5 Mabswid
.558 .704 .516 r
.42279 .45275 m .42641 .40761 L .48498 .40678 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.53516 .61228 m
.53771 .61893 L
s
.49816 .61923 m
.50424 .62349 L
s
.44283 .60957 m
.4733 .61006 L
s
.56715 .59455 m
.5726 .59953 L
s
.5 Mabswid
.571 .727 .522 r
.60593 .45318 m .6076 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
.571 .727 .522 r
.54772 .5 m .54696 .45245 L .60593 .45318 L p F P
.505 .664 .505 r
s
.597 .768 .555 r
.6076 .5 m .60593 .54682 L .54696 .54755 L p F P
.505 .664 .505 r
s
.617 .802 .582 r
.54475 .59294 m .54696 .54755 L .60593 .54682 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49504 .61251 m
.49816 .61923 L
s
.53516 .61228 m
.53547 .60759 L
s
.5613 .59204 m
.56715 .59455 L
s
.5 Mabswid
.597 .768 .555 r
.54696 .54755 m .54772 .5 L .6076 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.53547 .60759 m
.53903 .60018 L
s
.5 Mabswid
.632 .82 .601 r
.54696 .54755 m .54475 .59294 L .48498 .59322 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.4951 .61792 m
.49517 .62556 L
s
.5 Mabswid
.554 .699 .506 r
.54475 .40706 m .54696 .45245 L .48424 .4523 L p F P
.505 .664 .505 r
s
.554 .699 .506 r
.48424 .4523 m .48498 .40678 L .54475 .40706 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.55202 .5922 m
.5613 .59204 L
s
.53903 .60018 m
.54561 .59495 L
s
.54561 .59495 m
.55202 .5922 L
s
.5 Mabswid
.632 .82 .601 r
.48498 .59322 m .48424 .5477 L .54696 .54755 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49487 .59262 m
.4951 .61792 L
s
.5 Mabswid
.558 .704 .516 r
.48498 .40678 m .48424 .4523 L .42279 .45275 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.42155 .5 m .42279 .45275 L .48424 .4523 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.48398 .5 m .48424 .5477 L .42279 .54725 L p F P
.505 .664 .505 r
s
.616 .793 .586 r
.42279 .54725 m .42155 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.59 .753 .554 r
.48424 .4523 m .48398 .5 L .42155 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.54696 .45245 m .54772 .5 L .48398 .5 L p F P
.505 .664 .505 r
s
.586 .747 .543 r
.48398 .5 m .48424 .4523 L .54696 .45245 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.54772 .5 m .54696 .54755 L .48424 .5477 L p F P
.505 .664 .505 r
s
.611 .787 .575 r
.48424 .5477 m .48398 .5 L .54772 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?80/>3V4P21ZH7_0;3PiP40oooo003U0;3PiPl0PJV10`0T9ad0
0`21ZH409BPN02DX7P0602DX7P03086YP@0T9ad092LM00P0PJV1j02`h>H10?ooo`00h02`h>H6086Y
P@L08B@K0P21ZH4702@W7@03086YP@0U:1h09BPN00L09BPN00<0PJV102@W7@0T9ad01@0T9ad2086Y
P@03020S6`21ZH40PJV100@0PJV1hP2`h>H10?ooo`00g@2`h>H3086YP@806ahG0P21ZH47024T6`80
PJV12@0T9ad00`21ZH409BPN02DX7P0802DX7P03086YP@0T9ad092LM00H092LM0P21ZH44020S6`L0
PJV1g02`h>H10?ooo`00fP2`h>H4086YP@806ahG0P21ZH43024T6b<0PJV1100T9ad2086YP@D082<K
0P21ZH400`0J7QL0PJV1086YP@03086YPMP0/>3V0@3oool00=H0/>3V1@21ZH400`0K7QL0PJV1086Y
P@07086YP@@0<S<W00<0PJV103Hg:P0f=bX02P0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f
=bX0=SLZ0080=SLZ3021ZH401@0P8a/0PJV1086YP@21ZH406QhG0080PJV100<04QHA086YP@2`h>H0
e@2`h>H10?ooo`00e02`h>H00`21ZH404aLA086YP@05086YP@0302/]8P21ZH40<S<W00T0<S<W00<0
PJV103Hg:P0f=bX02`0f=bX00`21ZH40=cP[03Lh:`0:03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0
PJV1038c9`0b<bL00P0b<bL<086YPM<0/>3V0@3oool00=40/>3V00<0PJV101<G4@21ZH400`21ZH45
02/]8P03086YP@0b<bL0<S<W00P0<S<W00<0PJV103Hg:P0f=bX0300f=bX00`21ZH40=cP[03Lh:`0;
03Lh:`03086YP@0f=bX0=SLZ00T0=SLZ00<0PJV1038c9`0b<bL01`0b<bL9086YPM00/>3V0@3oool0
0<h0/>3V1P21ZH4702/]8P03086YP@0b<bL0<S<W00T0<S<W00<0PJV103Hg:P0f=bX02`0f=bX00`21
ZH40=cP[03Lh:`0<03Lh:`03086YP@0f=bX0=SLZ00X0=SLZ00<0PJV1038c9`0b<bL0200b<bL01021
ZH40:RdR02X]8P0Z;B85086YPLh0/>3V0@3oool00</0/>3V1021ZH400`0Q91/0PJV1086YP@0702/]
8P80PJV12`0b<bL00`21ZH40=SLZ03Hg:P0<03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg
:P0f=bX02P0f=bX00`21ZH40<S<W038c9`08038c9`80PJV1100Z;B85086YPL/0/>3V0@3oool00<T0
/>3V0`21ZH43024T6`03086YP@0[;B80:bdR00H0:bdR00<0PJV1038c9`0b<bL02P0b<bL00`21ZH40
=SLZ03Hg:P0=03Hg:P03086YP@0g>2/0=cP[00d0=cP[00<0PJV103Hg:P0f=bX02`0f=bX00`21ZH40
<S<W038c9`09038c9`80PJV1100Z;B82086YP@03020S6P21ZH40PJV10<T0/>3V0@3oool00<L0/>3V
0`21ZH43024T6`80PJV1200[;B800`21ZH40<S<W038c9`07038c9bd0PJV11P0f=bX00`21ZH40<S<W
038c9`0:038c9`03086YP@0Z;B80:RdR00<0:RdR00<0PJV1020S6P0P8aX00P21ZH770;3PiP40oooo
00350;3PiP<0PJV10`0Q91/2086YP@T0:bdR00<0PJV1038c9`0b<bL02021ZH4304I==`03086YP@1<
ESd0C5Hm00h0C5Hm00<0PJV104mI?P1?FCh03P1?FCh00`21ZH40CEHm04eF?@0504eF?@l0PJV11@0b
<bL2086YP@@0:RdR0P21ZH42020S6P80PJV1a@2`h>H10?ooo`00``2`h>H00`21ZH4051PB086YP@03
024T6`80PJV1100[;B8:086YP@X0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI?P0?
04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL01016CCL9086YP@@0:RdR00@0PJV1
020S6P0P8aX082<J0P21ZH730;3PiP40oooo00310;3PiP04086YP@0D6180PJV1086YP@808B@K2021
ZH4503Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd03`1<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00`0CEHm00<0PJV104I==`16CCL03016CCL5086YP@0302X]8P21
ZH40PJV100<082<J0P21ZH710;3PiP40oooo002o0;3PiP05086YP@0D6180PJV1086YP@0Q91/01021
ZH4<03Xn;P03086YP@16CCL0ATdg00/0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI
?P0?04mI?P03086YP@1=ESd0CEHm00d0CEHm00<0PJV104I==`16CCL03016CCL01021ZH40>Sd]03Xm
;@0j?Bd5086YP@<082<J0P21ZH6o0;3PiP40oooo002m0;3PiP03086YP@0D6180PJV100@0PJV10P0/
;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00`0ATdg00<0PJV104aF?@1<ESd0401<
ESd00`21ZH40CeTn04mI?P0?04mI?P03086YP@1=ESd0CEHm00h0CEHm00<0PJV104I==`16CCL02`16
CCL00`21ZH40>Sd]03Xm;@0503Xm;@@0PJV10P0P8aX2086YPKd0/>3V0@3oool00;/0/>3V00<0PJV1
01@H4P21ZH400P21ZH4502`_8`03086YP@0j?Rh0>Sh^00X0>Sh^00<0PJV104I==`16CCL03016CCL0
0`21ZH40C5Hm04aF?@0@04aF?@03086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03@1=ESd0
0`21ZH40ATdg04I==`0<04I==`03086YP@0j?Bd0>Sd]00H0>Sd]00<0PJV102`^8`21ZH401@21ZH6k
0;3PiP40oooo002i0;3PiPD0PJV11P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg
00d0ATdg00<0PJV104aF?@1<ESd0401<ESd00`21ZH40CeTn04mI?P0A04mI?P03086YP@1=ESd0CEHm
00h0CEHm00<0PJV104I==`16CCL03016CCL00`21ZH40>Sd]03Xm;@0603Xm;@03086YP@0/;R<0;2hS
0080;2hS0`21ZH6j0;3PiP40oooo002g0;3PiP80PJV10`0M8AT00`21ZH40;2lS02`_8`0402`_8`03
086YP@0j?Rh0>Sh^00/0>Sh^00<0PJV104I==`16CCL03016CCL00`21ZH40C5Hm04aF?@0A04aF?@03
086YP@1?FCh0CeTn0140CeTn00<0PJV104eF?@1=ESd03P1=ESd00`21ZH40ATdg04I==`0=04I==`03
086YP@0j?Bd0>Sd]00H0>Sd]0P21ZH4502`^8`80PJV1^02`h>H10?ooo`00]P2`h>H01021ZH407B4I
01dQ6@0M8AT2086YP@H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh00`21ZH40ATdg04I==`0=04I==`03
086YP@1<ESd0C5Hm0140C5Hm00<0PJV104mI?P1?FCh04@1?FCh00`21ZH40CEHm04eF?@0?04eF?@03
086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0
PJV1]P2`h>H10?ooo`00]@2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV100P0;2lS00<0PJV103Xn;P0j
?Rh02P0j?Rh00`21ZH40ATdg04I==`0=04I==`03086YP@1<ESd0C5Hm0180C5Hm00<0PJV104mI?P1?
FCh04P1?FCh00`21ZH40CEHm04eF?@0?04eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j
?Bd01`0j?Bd00`21ZH40;2hS02`^8`0302`^8`<0PJV1]@2`h>H10?ooo`00/`2`h>H2086YP@<07B4I
00<0PJV102`_8`0/;b<01P0/;b<00`21ZH40>Sh^03Xn;P0:03Xn;P03086YP@16CCL0ATdg00X0ATdg
>021ZH4804eF?@03086YP@16CCL0ATdg00d0ATdg00<0PJV103Xm;@0j?Bd0200j?Bd00`21ZH40;2hS
02`^8`0402`^8`<0PJV1/`2`h>H10?ooo`00/P2`h>H00`21ZH407B4I01dQ6@0201dQ6@03086YP@0/
;b<0;2lS00H0;2lS00<0PJV103Xn;P0j?Rh02`0j?Rh01021ZH40ATdg04I==`16CCL9086YP@@0Gg1B
00<0PJV106AgE@1TMeD04P1TMeD00`21ZH40HgIC06=fD`0B06=fD`03086YP@1NKd`0GVm<00L0GVm<
3P21ZH4;04I==`03086YP@0j?Bd0>Sd]00P0>Sd]00<0PJV102`^8`0/;R<0100/;R<00`21ZH4071lH
086YP@2b0;3PiP40oooo002a0;3PiP03086YP@0M8AT07B4I00807B4I00<0PJV102`_8`0/;b<01P0/
;b<00`21ZH40>Sh^03Xn;P0803Xn;PP0PJV1301OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1S
MU<0HgIC0180HgIC00<0PJV105i_C01NKd`0401NKd`00`21ZH40F6M705QWA`0205QWA`T0PJV10`16
CCL00`21ZH40>Sd]03Xm;@0803Xm;@80PJV11@0/;R<00`21ZH4071lH086YP@2a0;3PiP40oooo002`
0;3PiP04086YP@0M8AT07B4I01dQ6@80PJV1200/;b<01021ZH40>Sh^03Xn;P0j?Rh8086YP@80E658
00<0PJV105m`DP1OL5803`1OL5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC0180HgIC
00<0PJV105i_C01NKd`04@1NKd`00`21ZH40F6M705QWA`0:05QWA`P0PJV1200j?Bd00`21ZH40;2hS
02`^8`0302`^8`04086YP@0L7aP0PJV1086YPJl0/>3V0@3oool00:l0/>3V00D0PJV101dQ6@0M8AT0
7B4I086YP@0702`_8`L0PJV12P1DHDP00`21ZH40Gg1B05m`DP0?05m`DP03086YP@1TMeD0I7ME01<0
I7ME00<0PJV106=fD`1SMU<04`1SMU<00`21ZH40GVm<05i_C00@05i_C003086YP@1HIdL0F6M700l0
F6M700<0PJV104eG?@1=Ecd01`21ZH4203Xm;@03086YP@0/;R<0;2hS00<0;2hS00@0PJV101`O600L
7aP0PJV1[P2`h>H10?ooo`00[P2`h>H01@21ZH407B4I01dQ6@0M8AT0PJV10080;2lS1P21ZH400`10
AcL0PJV105AQB00=05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21
ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21
ZH40CELm04eG?@0704eG?@D0PJV1100/;R<2086YP@0301`O6021ZH40/>3V0:`0/>3V0@3oool00:`0
/>3V0P21ZH4201dQ6@D0PJV11`10AcL00`21ZH40E65805AQB00<05AQB003086YP@1OL580Gg1B00l0
Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0C06=fD`03086YP@1NKd`0GVm<0140
GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@@0PJV10`0/;R<01021ZH40
71lH086YP@21ZH6[0;3PiP40oooo002[0;3PiP03086YP@0M8AT07B4I00<0PJV12P10AcL00`21ZH40
E65805AQB00<05AQB003086YP@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40
HgIC06=fD`0D06=fD`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03P1HIdL00`21ZH40
CELm04eG?@0;04eG?@03086YP@0i?Rh0>Ch^00D0PJV10P0L7aP00`21ZH40/>3V0;3PiP2X0;3PiP40
oooo002Z0;3PiP@0PJV100<09b/Q086YP@10AcL02@10AcL00`21ZH40E65805AQB00=05AQB003086Y
P@1OL580Gg1B0100Gg1B00<0PJV106AgE@1TMeD04`1TMeD00`21ZH40HgIC06=fD`0D06=fD`03086Y
P@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40CELm04eG?@0:04eG?@03086Y
P@0i?Rh0>Ch^00@0>Ch^0`21ZH400`0L7aP0PJV10;3PiP2X0;3PiP40oooo002Y0;3PiP80PJV1100W
:b400`21ZH40@4Lg0417=`070417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`DP1OL5804@1O
L5800`21ZH40I7ME06AgE@0C06AgE@03086YP@1SMU<0HgIC01@0HgIC00<0PJV105i_C01NKd`04P1N
Kd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn;P0i?Rh01@0i
?Rh5086YPJL0/>3V0@3oool00:L0/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00P0@4Lg00<0PJV1
05AQB01DHDP0301DHDP00`21ZH40Gg1B05m`DP0A05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV1
06=fD`1SMU<0501SMU<00`21ZH40GVm<05i_C00C05i_C003086YP@1HIdL0F6M700l0F6M700<0PJV1
04eG?@1=Ecd02`1=Ecd00`21ZH40>Ch^03Tn;P0503Tn;P03086YP@0T9ad092LM0080PJV1YP2`h>H1
0?ooo`00YP2`h>H2086YP@D09b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQ
B003086YP@1OL580Gg1B0140Gg1B00<0PJV106AgE@1TMeD0501TMeD00`21ZH40HgIC06=fD`0E06=f
D`03086YP@1NKd`0GVm<0180GVm<00<0PJV105QWA`1HIdL0401HIdL00`21ZH40CELm04eG?@0;04eG
?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2U0;3PiP40oooo002U0;3P
iP80PJV11@0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800d0E65800<0PJV105m`
DP1OL5804P1OL5800`21ZH40I7ME06AgE@0D06AgE@03086YP@1SMU<0HgIC01D0HgIC00<0PJV105i_
C01NKd`04`1NKd`00`21ZH40F6M705QWA`0?05QWA`03086YP@1=Ecd0CELm00/0CELm00<0PJV103Tn
;P0i?Rh01@0i?Rh00`21ZH4092LM02@W7@0202@W7@03086YP@2`h>H0/>3V0:80/>3V0@3oool00:@0
/>3V0P21ZH4502L[8@03086YP@10AcL0@4Lg00T0@4Lg00<0PJV105AQB01DHDP03@1DHDP00`21ZH40
Gg1B05m`DP0B05m`DP03086YP@1TMeD0I7ME01@0I7ME00<0PJV106=fD`1SMU<05@1SMU<00`21ZH40
GVm<05i_C00C05i_C003086YP@1HIdL0F6M70100F6M700<0PJV104eG?@1=Ecd02`1=Ecd00`21ZH40
>Ch^03Tn;P0503Tn;P05086YP@0T9ad092LM02@W7@21ZH40Y02`h>H10?ooo`00X`2`h>H2086YP@H0
9b/Q00<0PJV10417=`10AcL02010AcL00`21ZH40E65805AQB00=05AQB003086YP@1OL580Gg1B0180
Gg1B00<0PJV106AgE@1TMeD02P1TMeD_086YP@/0GVm<00<0PJV105QWA`1HIdL03`1HIdL00`21ZH40
CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2S0;3P
iP40oooo002R0;3PiP80PJV11P0W:b400`21ZH40@4Lg0417=`080417=`03086YP@1DHDP0E65800h0
E65800<0PJV105m`DP1OL580201OL58G086YP@/0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40
LHUP0769H0090769H100PJV13P1HIdL00`21ZH40CELm04eG?@0<04eG?@03086YP@0i?Rh0>Ch^00D0
>Ch^00D0PJV102@W7@0T9ad092LM086YP@2R0;3PiP40oooo002Q0;3PiP80PJV11P0W:b400`21ZH40
@4Lg0417=`080417=`03086YP@1DHDP0E65800X0E6584021ZH4:07:<IP03086YP@1fTFP0MY5X01D0
MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D0080
IW]D2P21ZH4405QWA`03086YP@1=Ecd0CELm00d0CELm00<0PJV103Tn;P0i?Rh01@0i?Rh01@21ZH40
92LM02@W7@0T9ad0PJV10:40/>3V0@3oool00:00/>3V00<0PJV1010D4021ZH401@0W:b400`21ZH40
@4Lg0417=`090417=`04086YP@1DHDP0E65805AQB0T0PJV1101YOel00`21ZH40LXaV07:<IP0C07:<
IP03086YP@1fTFP0MY5X01D0MY5X00<0PJV107J@IP1fT6H05@1fT6H00`21ZH40LHUP0769H00E0769
H003086YP@1VNe@0IW]D00/0IW]D2P21ZH4:04eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00D0PJV102@W
7@0T9ad092LM086YP@2P0;3PiP40oooo002O0;3PiP03086YP@0@5100PJV100D09b/Q00<0PJV10417
=`10AcL01`10AcL7086YP@`0JGmO00<0PJV107:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00F07JA
J003086YP@1fT6H0MY1V01H0MY1V00<0PJV10769H01aRF00501aRF000`21ZH40IW]D06IkE00@06Ik
E003086YP@1KK4T0Ffa90080Ffa92021ZH4304eG?@03086YP@0i?Rh0>Ch^00H0>Ch^00@0PJV102@W
7@0T9ad0PJV1X02`h>H10?ooo`00WP2`h>H00`21ZH4041@@086YP@0602L[8@03086YP@10AcL0@4Lg
00<0@4Lg1021ZH400`1GIdl0PJV106UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JA
J01fTFP05P1fTFP00`21ZH40MY1V07J@IP0F07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106Ik
E01VNe@04@1VNe@00`21ZH40Ffa905]/B@0905]/B@H0PJV11P0i?Rh01@21ZH4092LM02@W7@0T9ad0
PJV109l0/>3V0@3oool009h0/>3V00<041@@086YP@0W:b401@0W:b400`21ZH40@4Lg086YP@04086Y
P@D0EfM?00<0PJV106UoG`1YOel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X
01H0MY5X00<0PJV107J@IP1fT6H05P1fT6H00`21ZH40LHUP0769H00D0769H003086YP@1VNe@0IW]D
0140IW]D00<0PJV105]/B@1KK4T03P1KK4T5086YP@<0>Ch^00D0PJV102@W7@0T9ad092LM086YP@2N
0;3PiP40oooo002M0;3PiP03010D4021ZH409b/Q00<09b/Q1@21ZH4905MWC`03086YP@1YOel0JGmO
00l0JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V
01H0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00A06IkE003086YP@1KK4T0Ffa9
00d0Ffa900<0PJV104QD>`18E3/00P18E3/5086YP@<092LM00<0PJV10;3PiP2`h>H0V`2`h>H10?oo
o`00W02`h>H00`0@5100PJV102L[8@04086YP@0303Po=021ZH40EfM?00/0EfM?00<0PJV106UoG`1Y
Oel03`1YOel00`21ZH40LXaV07:<IP0C07:<IP03086YP@1fTFP0MY5X01L0MY5X00<0PJV107J@IP1f
T6H05P1fT6H00`21ZH40LHUP0769H00E0769H003086YP@1VNe@0IW]D0140IW]D00<0PJV105]/B@1K
K4T03P1KK4T00`21ZH40B5@k04QD>`0504QD>`80PJV10`0T9ad00`21ZH40/>3V0;3PiP2J0;3PiP40
oooo002K0;3PiP04010D4021ZH40PJV1086YP@D0>3ld00<0PJV105MWC`1GIdl02@1GIdl00`21ZH40
JGmO06UoG`0@06UoG`03086YP@1bS6H0LXaV01<0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40
MY1V07J@IP0G07J@IP03086YP@1aRF00LHUP01D0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40
Ffa905]/B@0=05]/B@03086YP@18E3/0B5@k00L0B5@k0P21ZH400`0T9ad0PJV10;3PiP2K0;3PiP40
oooo002J0;3PiP03010D4021ZH40>3ld00H0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO
06UoG`0?06UoG`03086YP@1bS6H0LXaV01@0LXaV00<0PJV107JAJ01fTFP05P1fTFP00`21ZH40MY1V
07J@IP0H07J@IP03086YP@1aRF00LHUP01@0LHUP00<0PJV106IkE01VNe@04P1VNe@00`21ZH40Ffa9
05]/B@0>05]/B@03086YP@18E3/0B5@k00H0B5@k00<0PJV102/^8`21ZH400P21ZH6K0;3PiP40oooo
002I0;3PiP<0PJV11`0h?c@00`21ZH40EfM?05MWC`0905MWC`03086YP@1YOel0JGmO0100JGmO00<0
PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00F07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0
PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900d0Ffa900<0
PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02086YPIX0/>3V0@3oool009P0/>3V00<0PJV1
01TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV1
07:<IP1bS6H04`1bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0MY1V01P0MY1V00<0PJV1
0769H01aRF005@1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV1
04QD>`18E3/01P18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V09L0/>3V0@3oool0
09L0/>3V00@0PJV101TN6@0I7QT0PJV11P0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109T0/>3V0@3o
ool009L0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00B06IkE003086YP@1KK4T0
Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[;R<0PJV109P0/>3V0@3o
ool009H0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0
JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00G07JAJ003086YP@1fT6H0
MY1V01P0MY1V00<0PJV10769H01aRF005P1aRF000`21ZH40IW]D06IkE00C06IkE003086YP@1KK4T0
Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0
/>3V09D0/>3V0@3oool009D0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0100JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00C
06IkE003086YP@1KK4T0Ffa900h0Ffa900<0PJV104QD>`18E3/01`18E3/01@21ZH40:bhS02/^8`0[
;R<0PJV109L0/>3V0@3oool009D0/>3V00<0PJV101TN6@21ZH401`0h?c@00`21ZH40EfM?05MWC`0:
05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H0501bS6H00`21ZH40MY5X07JAJ00H
07JAJ003086YP@1fT6H0MY1V01T0MY1V00<0PJV10769H01aRF005@1aRF000`21ZH40IW]D06IkE00D
06IkE003086YP@1KK4T0Ffa900d0Ffa900<0PJV104QD>`18E3/01`18E3/00`21ZH40:bhS02/^8`02
02/^8`03086YP@2`h>H0/>3V09@0/>3V0@3oool009@0/>3V00@0PJV101TN6@0I7QT0PJV11`0h?c@0
0`21ZH40EfM?05MWC`0:05MWC`03086YP@1YOel0JGmO0140JGmO00<0PJV107:<IP1bS6H03`1bS6I9
086YP@`0LHUP00<0PJV106IkE01VNe@04`1VNe@00`21ZH40Ffa905]/B@0>05]/B@03086YP@18E3/0
B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3PiP40oooo002D0;3P
iP03086YP@0I7QT0PJV100L0>3ld00<0PJV105MWC`1GIdl02P1GIdl00`21ZH40JGmO06UoG`0A06Uo
G`03086YP@1bS6H0LXaV00@0LXaV3021ZH45086PMP03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108>S
M@23XgD06@23XgD00`21ZH40OYe_07jMK`0:07jMKaP0PJV12`1VNe@00`21ZH40Ffa905]/B@0=05]/
B@03086YP@18E3/0B5@k00L0B5@k00<0PJV102/^8`0[;R<00P0[;R<00`21ZH40/>3V0;3PiP2C0;3P
iP40oooo002C0;3PiP04086YP@0I7QT06AhI086YP@H0>3ld00<0PJV105MWC`1GIdl02`1GIdl00`21
ZH40JGmO06UoG`0706UoGa40PJV14@21X7H00`21ZH40Q:Ah08BTN00H08BTN003086YP@23XgD0Pj=e
01T0Pj=e00<0PJV107jMK`1nWFl05P1nWFl00`21ZH40MI5T07FAI00907FAI100PJV1301KK4T00`21
ZH40B5@k04QD>`0704QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3PiP2`h>H0TP2`h>H10?oo
o`00TP2`h>H01021ZH406AhI01TN6@21ZH4703Po=003086YP@1GIdl0EfM?00P0EfM?3@21ZH4:07VF
L003086YP@21X7H0PJ1f01D0PJ1f00<0PJV108BTN024Y7P06024Y7P00`21ZH40Pj=e08>SM@0I08>S
M@03086YP@1nWFl0OYe_01H0OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0206El
D`T0PJV10`1KK4T00`21ZH40B5@k04QD>`0804QD>`03086YP@0[;R<0:bhS0080:bhS00<0PJV10;3P
iP2`h>H0T@2`h>H10?ooo`00TP2`h>H00`21ZH406AhI086YP@0703Po=003086YP@1GIdl0EfM?00@0
EfM?1@21ZH4206R0H`03086YP@1iUW00NII`0140NII`00<0PJV1086PMP21X7H05@21X7H00`21ZH40
Q:Ah08BTN00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40
MI5T07FAI00D07FAI003086YP@1UO5<0IGaC00X0IGaC1P21ZH4804QD>`03086YP@0[;R<0:bhS00<0
:bhS00<0PJV10;3PiP2`h>H0T02`h>H10?ooo`00T@2`h>H01021ZH406AhI01TN6@21ZH4703Po=003
086YP@1GIdl0PJV100@0PJV11P1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0
PJ1f00<0PJV108BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01L0
OYe_00<0PJV107FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0PJV100<0
PJV11@18E3/00`21ZH40:bhS02/^8`0202/^8`03086YP@2`h>H0/>3V0900/>3V0@3oool00900/>3V
00@0PJV101TN6@0I7QT0PJV11@0h?c@5086YP@/0J81S00<0PJV107VFL01iUW004P1iUW000`21ZH40
PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108>SM@23XgD06@23XgD00`21ZH40
OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40
E6E505AUA@0205AUA@@0PJV100<0B5@k086YP@0[;R<0100[;R<00`21ZH40/>3V0;3PiP2?0;3PiP40
oooo002@0;3PiP03086YP@0I7QT06AhI0080>3ld1021ZH4204]KB@03086YP@1XP6<0J81S00/0J81S
00<0PJV107VFL01iUW004P1iUW000`21ZH40PJ1f086PMP0E086PMP03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108>SM@23XgD06@23XgD00`21ZH40OYe_07jMK`0G07jMK`03086YP@1eTF@0MI5T01@0MI5T
00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0605AUA@@0PJV1100[;R<00`21ZH40/>3V
0;3PiP2>0;3PiP40oooo002?0;3PiP03086YP@0I7QT06AhI00<0PJV11@1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl05`1nWFl00`21ZH40MI5T07FA
I00E07FAI003086YP@1UO5<0IGaC00h0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]086Y
P@04086YPI00/>3V0@3oool008l0/>3V00@06AhI086YP@21ZH40PJV11`1;FdT00`21ZH40J81S06R0
H`0;06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1086PMP21X7H05P21X7H00`21ZH40Q:Ah08BT
N00I08BTN003086YP@23XgD0Pj=e01T0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FA
I00D07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0
;@0203M0;@80PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@0302@/9`21ZH40Be]900L0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06@24Y7P00`21ZH40Pj=e08>SM@0I08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@0501eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2f?0;3PiP40oooo002>0;3PiP04086YP@0T;2L092`W086YP@L0Be]900<0PJV1
06R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01D0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV1
03M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3PiP04086YP@0T;2L092`W
086YP@P0Be]900<0PJV106R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00B07VFL003086YP@21X7H0
PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0
OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0
E6E500P0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2<0;3PiP40oooo002=0;3P
iP04086YP@0T;2L092`W086YP@L0Be]900<0PJV106R0H`1XP6<0301XP6<00`21ZH40NII`07VFL00B
07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J
08>SM@03086YP@1nWFl0OYe_01L0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?
06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d00`21ZH40/>3V0;3PiP2;
0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV106R0H`1XP6<0301XP6<0
0`21ZH40NII`07VFL00B07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV108BTN024Y7P06P24Y7P0
0`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV107FAI01eTF@05@1eTF@0
0`21ZH40IGaC06ElD`0>06ElD`03086YP@1DIDD0E6E500T0E6E500<0PJV103M0;@0g@2d00`0g@2d0
0`21ZH40/>3V0;3PiP2;0;3PiP40oooo002<0;3PiP04086YP@0T;2L092`W086YP@P0Be]900<0PJV1
06R0H`1XP6<02`1XP6<00`21ZH40NII`07VFL00C07VFL003086YP@21X7H0PJ1f01H0PJ1f00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Pj=e08>SM@0J08>SM@03086YP@1nWFl0OYe_01P0OYe_00<0PJV1
07FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0?06ElD`03086YP@1DIDD0E6E500P0E6E500<0PJV1
03M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP2:0;3PiP40oooo002;0;3PiP05086YP@0T;2L092`W
02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0<06R0H`03086YP@1iUW00NII`0180NII`00<0PJV1
086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003086YP@23XgD0Pj=e01X0Pj=e00<0PJV1
07jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0IGaC00l0IGaC00<0PJV1
05AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@0303M0;@03086YP@2`h>H0/>3V08X0/>3V0@3oool0
08/0/>3V00@0PJV102@/9`0T;2L0PJV1201;FdT00`21ZH40J81S06R0H`0<06R0H`03086YP@1iUW00
NII`0180NII`00<0PJV1086PMP21X7H05`21X7H00`21ZH40Q:Ah08BTN00J08BTN003086YP@23XgD0
Pj=e01X0Pj=e00<0PJV107jMK`1nWFl0601nWFl00`21ZH40MI5T07FAI00E07FAI003086YP@1UO5<0
IGaC0100IGaC00<0PJV105AUA@1DIDD0201DIDD00`21ZH40=d0]03M0;@0403M0;@03086YP@2`h>H0
/>3V08T0/>3V0@3oool008X0/>3V00D0PJV102@/9`0T;2L092`W086YP@0804]KB@03086YP@1XP6<0
J81S00/0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086PMP0F086PMP03086YP@24Y7P0
Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0H07jMK`03086YP@1eTF@0
MI5T01H0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0
=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H01021ZH4092`W02@/9`21ZH48
04]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW004`1iUW000`21ZH40PJ1f086PMP0F
086PMP03086YP@24Y7P0Q:Ah01/0Q:Ah00<0PJV108>SM@23XgD06P23XgD00`21ZH40OYe_07jMK`0I
07jMK`03086YP@1eTF@0MI5T01D0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@09
05AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R@2`h>H10?ooo`00RP2`h>H01021
ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW004P1iUW00
0`21ZH40PJ1f086PMP0G086PMP03086YP@24Y7P0Q:Ah00d0Q:Ah7@21ZH4>08>SM@03086YP@1nWFl0
OYe_01T0OYe_00<0PJV107FAI01eTF@05@1eTF@00`21ZH40IGaC06ElD`0@06ElD`03086YP@1DIDD0
E6E500P0E6E500<0PJV103M0;@0g@2d0100g@2d00`21ZH40/>3V0;3PiP280;3PiP40oooo00290;3P
iP05086YP@0T;2L092`W02@/9`21ZH401`1;FdT00`21ZH40J81S06R0H`0=06R0H`03086YP@1iUW00
NII`0180NII`00<0PJV1086PMP21X7H02`21X7HL086YP@h0S[B400<0PJV108fbP@2=/X40302=/X4g
086YP@`0MI5T00<0PJV106ElD`1UO5<03`1UO5<00`21ZH40E6E505AUA@0905AUA@03086YP@0g@2d0
=d0]00<0=d0]00<0PJV10;3PiP2`h>H0R02`h>H10?ooo`00R@2`h>H01021ZH4092`W02@/9`21ZH48
04]KB@03086YP@1XP6<0J81S00`0J81S00<0PJV107VFL01iUW002@1iUW0H086YP@`0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek01T0RJek00<0PJV1
086RL@21XW402P21XW4A086YP@d0IGaC00<0PJV105AUA@1DIDD02@1DIDD00`21ZH40=d0]03M0;@04
03M0;@03086YP@2`h>H0/>3V08L0/>3V0@3oool008P0/>3V00D0PJV102@/9`0T;2L092`W086YP@08
04]KB@03086YP@1XP6<0J81S00T0J81S3`21ZH4:08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0RJek01T0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0207:?H@X0PJV1101UO5<00`21ZH40E6E505AUA@09
05AUA@03086YP@0g@2d0=d0]00<0=d0]00<0PJV10;3PiP2`h>H0Q`2`h>H10?ooo`00R02`h>H01021
ZH4092`W02@/9`21ZH4804]KB@03086YP@1XP6<0J81S0080J81S2021ZH4307NEL`03086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06@29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ00`0LXmQ2021ZH4805AUA@03086YP@0g@2d0=d0]00@0=d0]00<0PJV10;3PiP2`h>H0QP2`h>H1
0?ooo`00Q`2`h>H01@21ZH4092`W02@/9`0T;2L0PJV100H0Be]91`21ZH4;07NEL`03086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0E086RL@03086YP@1bSf40
LXmQ0100LXmQ00@0PJV105ecC@1MLdd0GG==1P21ZH4305AUA@03086YP@0g@2d0=d0]00<0=d0]00<0
PJV10;3PiP2`h>H0QP2`h>H10?ooo`00Q`2`h>H01021ZH4092`W02@/9`21ZH4204]KB@D0PJV10P1K
LU/00`21ZH40MiEc07NEL`0<07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV108baP`2</H<0602<
/H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV108V]N`29[G/06P29
[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ00l0LXmQ00<0PJV105ecC@1MLdd01`1M
Ldd7086YP@<0=d0]00<0PJV10;3PiP2`h>H0Q@2`h>H10?ooo`00QP2`h>H00`21ZH4092`W02@/9`04
086YP@H0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0
S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0J08fbP@03086YP@29[G/0
RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0
GG==00T0GG==00@0PJV1045>=P11CSH0@Dhf1021ZH670;3PiP40oooo00260;3PiP<0PJV100<0;SPc
086YP@1KLU/01`1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV1
08baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40SK:101X0SK:100<0PJV1
08V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40LXmQ0100LXmQ00<0PJV1
05ecC@1MLdd02@1MLdd00`21ZH40@Dhf045>=P04045>=P80PJV1QP2`h>H10?ooo`00QP2`h>H01021
ZH40;SPc02hh<`21ZH4905]bF`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h04`25Z7h0
0`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X406P2=/X40
0`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf40
0`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00<0@Dhf0P21ZH660;3PiP40oooo00250;3P
iP05086YP@0^>3<0;SPc02hh<`21ZH402@1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0
QJQn01<0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40
SK:101X0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ0100LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P04045>=P03086YP@2`h>H0
/>3V08@0/>3V0@3oool008D0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0
MiEc00h0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0
S[B401`0S[B400<0PJV108fbP@2=/X406P2=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40
PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0
@Dhf00@0@Dhf00<0PJV10;3PiP2`h>H0Q02`h>H10?ooo`00Q@2`h>H01@21ZH40;SPc02hh<`0^>3<0
PJV100P0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0
S;6301L0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0K08fbP@03086YP@29[G/0
RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0
GG==00T0GG==00<0PJV1045>=P11CSH01011CSH2086YPHD0/>3V0@3oool008D0/>3V00@0PJV102hh
<`0^>3<0PJV12@1KLU/00`21ZH40MiEc07NEL`0=07NEL`03086YP@25Z7h0QJQn01<0QJQn00<0PJV1
08baP`2</H<0602</H<00`21ZH40S[B408jdQ00K08jdQ003086YP@2=/X40SK:101`0SK:100<0PJV1
08V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0E086RL@03086YP@1bSf40LXmQ0140LXmQ00<0PJV1
05ecC@1MLdd02@1MLdd00`21ZH40@Dhf045>=P04045>=P80PJV1Q@2`h>H10?ooo`00Q02`h>H01@21
ZH40;SPc02hh<`0^>3<0PJV100T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0C
08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L
08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@
07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH00`11CSH2086YPHD0/>3V0@3oool0
08@0/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV1
08FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0H08baP`03086YP@2>]8@0S[B401/0S[B400<0PJV1
08fbP@2=/X40702=/X400`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV1
07:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:05ecC@03086YP@11CSH0@Dhf00@0@Dhf00<0PJV1
0;3PiP2`h>H0P`2`h>H10?ooo`00Q02`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV1
07NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV1
08jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1
045>=P11CSH01011CSH00`21ZH40/>3V0;3PiP230;3PiP40oooo00240;3PiP04086YP@0^>3<0;SPc
086YP@T0Fg9K00<0PJV107NEL`1gUG<03@1gUG<00`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0
S;6301P0S;6300<0PJV108jdQ02>]8@06`2>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0
RJek01X0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0
GG==00X0GG==00<0PJV1045>=P11CSH01011CSH2086YPH@0/>3V0@3oool008<0/>3V00D0PJV102hh
<`0^>3<0;SPc086YP@0905]bF`03086YP@1gUG<0MiEc00d0MiEc00<0PJV108FXOP25Z7h05025Z7h0
0`21ZH40S;6308baP`0G08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=/X40
0`21ZH40RJek08V]N`0J08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf404@1bSf40
0`21ZH40GG==05ecC@0905ecC@03086YP@11CSH0@Dhf00@0@Dhf0P21ZH640;3PiP40oooo00230;3P
iP05086YP@0^>3<0;SPc02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0
QJQn01@0QJQn00<0PJV108baP`2</H<05`2</H<00`21ZH40S[B408jdQ00L08jdQ003086YP@2=/X40
SK:101`0SK:100<0PJV108V]N`29[G/06P29[G/00`21ZH40PJ9a086RL@0F086RL@03086YP@1bSf40
LXmQ0140LXmQ00<0PJV105ecC@1MLdd02P1MLdd00`21ZH40@Dhf045>=P03045>=P80PJV1Q02`h>H1
0?ooo`00P`2`h>H01@21ZH40;SPc02hh<`0^>3<0PJV100P0Fg9K00<0PJV107NEL`1gUG<03P1gUG<0
0`21ZH40QJQn08FXOP0D08FXOP03086YP@2</H<0S;6301L0S;6300<0PJV108jdQ02>]8@0702>]8@0
0`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01X0RJek00<0PJV1086RL@21XW405P21XW40
0`21ZH40LXmQ07:?H@0A07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1045>=P11CSH01011CSH0
0`21ZH40/>3V0;3PiP220;3PiP40oooo00230;3PiP04086YP@0^>3<0;SPc086YP@T0Fg9K00<0PJV1
07NEL`1gUG<03P1gUG<00`21ZH40QJQn08FXOP0C08FXOP03086YP@2</H<0S;6301P0S;6300<0PJV1
08jdQ02>]8@0702>]8@00`21ZH40SK:108fbP@0L08fbP@03086YP@29[G/0RJek01/0RJek00<0PJV1
086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0@07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1
045>=P11CSH01011CSH2086YPH<0/>3V0@3oool00880/>3V00D0PJV102hh<`0^>3<0;SPc086YP@09
05]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV108FXOP25Z7h04`25Z7h00`21ZH40S;6308baP`0H
08baP`03086YP@2>]8@0S[B401`0S[B400<0PJV108fbP@2=/X40702=/X400`21ZH40RJek08V]N`0K
08V]N`03086YP@21XW40PJ9a01H0PJ9a00<0PJV107:?H@1bSf40401bSf400`21ZH40GG==05ecC@0:
05ecC@03086YP@11CSH0@Dhf00@0@Dhf0P21ZH630;3PiP40oooo00220;3PiP05086YP@0^>3<0;SPc
02hh<`21ZH40201KLU/00`21ZH40MiEc07NEL`0>07NEL`03086YP@25Z7h0QJQn01@0QJQn00<0PJV1
08baP`2</H<02`2</H=J086YP@l0RJek00<0PJV1086RL@21XW405P21XW400`21ZH40LXmQ07:?H@0A
07:?H@03086YP@1MLdd0GG==00T0GG==00<0PJV1045>=P11CSH01011CSH2086YPH<0/>3V0@3oool0
0880/>3V00D0PJV102hh<`0^>3<0;SPc086YP@0805]bF`03086YP@1gUG<0MiEc00h0MiEc00<0PJV1
08FXOP25Z7h02@25Z7hI086YP@d0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0L
09JoR`03086YP@2B^XD0T[Z500`0T[Z5<P21ZH4:07:?H@03086YP@1MLdd0GG==00X0GG==00<0PJV1
045>=P11CSH00`11CSH2086YPH<0/>3V0@3oool00880/>3V0`0^>3<00`21ZH40Fg9K05]bF`0305]b
Fb40PJV12`2?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109Jo
R`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bN
K@1lWVd01`1lWVdA086YP@H0GG==00<0PJV1045>=P11CSH01011CSH00`21ZH40/>3V0;3PiP210;3P
iP40oooo00210;3PiP03086YP@0^>3<0;SPc00L0PJV1101XQ6X00`21ZH40PZIo08:VO`0>08:VO`03
086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03
086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003
086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@0101UOe@:086YP@<0@Dhf0P21ZH620;3PiP40
oooo00210;3PiP<0PJV100<0>da2086YP@1XQ6X0201XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086Y
P@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086Y
P@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086Y
P@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@01021ZH40AeXl04MJ?017FS`5086YPH80
/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0
AeXl0P21ZH620;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40
AeXl04MJ?00404MJ?003086YP@0M91X0/>3V0840/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl00<0PJV101dT6P2`h>H0P@2`h>H10?ooo`00
P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`00`21ZH40
7B@J0;3PiP210;3PiP40oooo00210;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40
AeXl04MJ?00304MJ?003086YP@0M91X0/>3V0840/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0H09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/0702F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00210;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd0602E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01`0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00
P@2`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01P0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0L09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40
/>3V0@3oool00840/>3V00D0PJV103]<@P0kC480>da2086YP@0806R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd0401lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0
AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40
AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00:06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH610;3PiP40oooo00200;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02P1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P@2`h>H10?ooo`00
P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40
SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40
U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40
O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00X0IGmD00<0PJV104MJ?017FS`01017FS`2086YPH40
/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0
PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0
Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0
R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40IGmD06EoE00;06EoE003086YP@17FS`0AeXl00<0
AeXl0P21ZH610;3PiP40oooo00200;3PiP05086YP@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40
PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40
Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40
R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40
AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40>da203]<@P0kC480PJV100T0
J8AZ00<0PJV108:VO`22YWl03P22YWl00`21ZH40SkJ:08nfRP0D08nfRP03086YP@2E_Xd0UKj=01T0
UKj=00<0PJV109O0S@2G`8d0702G`8d00`21ZH40U[n;09JoR`0M09JoR`03086YP@2B^XD0T[Z501/0
T[Z500<0PJV108Z`O02:/7`05P2:/7`00`21ZH40O9i]07bNK@0A07bNK@03086YP@1UOe@0IGmD00/0
IGmD00<0PJV104MJ?017FS`01017FS`2086YPH00/>3V0@3oool00800/>3V00D0PJV103]<@P0kC480
>da2086YP@0906R4JP03086YP@22YWl0PZIo00h0PZIo00<0PJV108nfRP2?]XX0502?]XX00`21ZH40
UKj=09FnS@0I09FnS@03086YP@2G`8d0Ul2=01`0Ul2=00<0PJV109JoR`2F_h/07@2F_h/00`21ZH40
T[Z509:jQ@0K09:jQ@03086YP@2:/7`0R[1l01H0R[1l00<0PJV107bNK@1lWVd04@1lWVd00`21ZH40
IGmD06EoE00;06EoE003086YP@17FS`0AeXl00@0AeXl0P21ZH600;3PiP40oooo00200;3PiP05086Y
P@0kC480>da203]<@P21ZH402@1XQ6X00`21ZH40PZIo08:VO`0>08:VO`03086YP@2?]XX0SkJ:01@0
SkJ:00<0PJV109FnS@2E_Xd06@2E_Xd00`21ZH40Ul2=09O0S@0L09O0S@03086YP@2F_h/0U[n;01d0
U[n;00<0PJV109:jQ@2B^XD06`2B^XD00`21ZH40R[1l08Z`O00F08Z`O003086YP@1lWVd0O9i]0140
O9i]00<0PJV106EoE01UOe@02`1UOe@00`21ZH40AeXl04MJ?00404MJ?080PJV1P02`h>H10?ooo`00
P02`h>Kc086YPH00/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH600;3PiP40oooo00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
6@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH00/>3V0@3oool00800/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
7@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH600;3PiP40oooo
00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0304aR@@03086Y
P@0R;Ah0/>3V0800/>3V0@3oool00800/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086Y
P@1<HT40C69100@0C69100<0PJV1028]7P2`h>H0P02`h>H10?ooo`00P02`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00800/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
7@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo
00200;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH06@2LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01d0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1
P@2`h>H10?ooo`00P02`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01T0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0M09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH40/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00d0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0I09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<07@2LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04024ZgL00`21ZH40KXeO06j=G`0;06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH610;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2`1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1P@2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00/0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH40/>3V0@3oool00840/>3V00D0
PJV104ELC`15G4l0AEa?086YP@09076CMP03086YP@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0
502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086YP@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0
702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086YP@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL0
4@24ZgL00`21ZH40KXeO06j=G`0;06j=G`03086YP@1<HT40C69100@0C6910P21ZH610;3PiP40oooo
00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH402@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086Y
P@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086Y
P@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h06`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086Y
P@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl02`1^SEl00`21ZH40C69104aR@@0304aR@@80PJV1
PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04ELC`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX0
3P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0
702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD0
5P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40
101<HT42086YPH80/>3V0@3oool00840/>3V00D0PJV104ELC`15G4l0AEa?086YP@09076CMP03086Y
P@2:/hX0R[>:00h0R[>:00<0PJV109K2T`2F`Y<0502F`Y<00`21ZH40W<VF09c9UP0H09c9UP03086Y
P@2MbiH0WL^F01`0WL^F00<0PJV109c9T`2LbI<0702LbI<00`21ZH40V<B>09S4SP0K09S4SP03086Y
P@2A^hD0TK^501H0TK^500<0PJV108B[M`24ZgL04@24ZgL00`21ZH40KXeO06j=G`0:06j=G`03086Y
P@1<HT40C69100@0C6910P21ZH620;3PiP40oooo00210;3PiP05086YP@15G4l0AEa?04ELC`21ZH40
2@1aTgH00`21ZH40R[>:08ZcRP0>08ZcRP03086YP@2F`Y<0U/:C01@0U/:C00<0PJV109c9UP2LbIH0
602LbIH00`21ZH40WL^F09g;UP0L09g;UP03086YP@2LbI<0W<VC01`0W<VC00<0PJV109S4SP2Ha8h0
6`2Ha8h00`21ZH40TK^5096kQ@0F096kQ@03086YP@24ZgL0Q:]g0140Q:]g00<0PJV106j=G`1^SEl0
2P1^SEl00`21ZH40C69104aR@@0404aR@@80PJV1PP2`h>H10?ooo`00P@2`h>H01@21ZH40AEa?04EL
C`15G4l0PJV100T0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2T`0D09K2T`03086Y
P@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086Y
P@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086Y
P@1^SEl0KXeO00X0KXeO00<0PJV104aR@@1<HT40101<HT42086YPH80/>3V0@3oool00840/>3V0P21
ZH4204ELC`03086YP@1aTgH0LI=f00L0LI=f00<0PJV108ZcRP2:/hX03P2:/hX00`21ZH40U/:C09K2
T`0D09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9
T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[
M`0A08B[M`03086YP@1^SEl0KXeO00X0KXeO00@0PJV104aR@@1<HT40C6911@21ZH620;3PiP40oooo
00210;3PiP03086YP@1=J5T0PJV101@0PJV1202:/hX00`21ZH40U/:C09K2T`0D09K2T`03086YP@2L
bIH0W<VF01P0W<VF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2H
a8h0V<B>01/0V<B>00<0PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0A08B[M`03086YP@1^
SEl0KXeO00@0KXeO2P21ZH4304iX@`80PJV1PP2`h>H10?ooo`00PP2`h>H01021ZH40CFQI04eXF@21
ZH4907RNOP03086YP@2@_I80T;fB00H0T;fB5021ZH4;09K2T`03086YP@2LbIH0W<VF01P0W<VF00<0
PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>01/0V<B>00<0
PJV1096kQ@2A^hD05P2A^hD00`21ZH40Q:]g08B[M`0808B[Ma00PJV11P1dV6P00`21ZH40CVQ304iX
@`0404iX@`03086YP@2`h>H0/>3V0840/>3V0@3oool00880/>3V00D0PJV104eXF@1=J5T0CFQI086Y
P@0807RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X02@2Lc9XI086YP@d0W<VF00<0
PJV109g;UP2MbiH0702MbiH00`21ZH40W<VC09c9T`0L09c9T`03086YP@2Ha8h0V<B>00d0V<B><P21
ZH4908ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<00`1>J4<00`21ZH4093<R0;3P
iP220;3PiP40oooo00220;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092m
TP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd02`2QdYeK086YP@h0WLfD00<0
PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00T0M9QX00<0
PJV104iX@`1>J4<0101>J4<2086YPH<0/>3V0@3oool00880/>3V00D0PJV104eXF@1=J5T0CFQI086Y
P@0907RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7B
W@0H0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=
U00K09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BH
J00:07BHJ003086YP@1>J4<0CVQ300@0CVQ30P21ZH630;3PiP40oooo00230;3PiP04086YP@1=J5T0
CFQI086YP@T0N9in00<0PJV1092mTP2@_I803P2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2Q
dYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2M
cI@0WLfD01/0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1d
V6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<2086YPH<0/>3V0@3oool008<0/>3V00D0PJV1
04eXF@1=J5T0CFQI086YP@0807RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X0502L
c9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702Q
dIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:
]7l00`21ZH40M9QX07BHJ00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0PP2`
h>H10?ooo`00P`2`h>H01@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@
_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702R
di`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2G
a8`00`21ZH40R[Ao08ZdO`0A08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<00`1>
J4<2086YPH@0/>3V0@3oool008<0/>3V00D0PJV104eXF@1=J5T0CFQI086YP@0907RNOP03086YP@2@
_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X0502Lc9X00`21ZH40XM:M0:7BW@0G0:7BW@03086YP@2R
di`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2G
a8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>
J4<0CVQ300@0CVQ30P21ZH640;3PiP40oooo00240;3PiP04086YP@1=J5T0CFQI086YP@T0N9in00<0
PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0D09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0
PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0
PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0
PJV104iX@`1>J4<0101>J4<2086YPH@0/>3V0@3oool008@0/>3V00D0PJV104eXF@1=J5T0CFQI086Y
P@0807RNOP03086YP@2@_I80T;fB00h0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7B
W@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=
U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21ZH40M9QX07BH
J00:07BHJ003086YP@1>J4<0CVQ300@0CVQ300<0PJV10;3PiP2`h>H0P`2`h>H10?ooo`00Q02`h>H0
1@21ZH40CFQI04eXF@1=J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<
VP0C09c<VP03086YP@2QdYd0XM:M01P0XM:M00<0PJV10:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7A
V@0L0:7AV@03086YP@2McI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08Zd
O`0@08ZdO`03086YP@1dV6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH40/>3V0;3P
iP230;3PiP40oooo00240;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092m
TP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0602QdYd00`21ZH40X]>L0:;C
W00K0:;CW003086YP@2QdIT0XM6I01`0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4
S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX
@`0304iX@`80PJV1Q@2`h>H10?ooo`00Q@2`h>H01021ZH40CFQI04eXF@21ZH4907RNOP03086YP@2@
_I80T;fB00d0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2R
di`0X]>L01/0X]>L00<0PJV10:7AV@2QdIT0702QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2G
a8`0UlB<01D0UlB<00<0PJV108ZdO`2:]7l04@2:]7l00`21ZH40M9QX07BHJ00907BHJ003086YP@1>
J4<0CVQ300@0CVQ30P21ZH650;3PiP40oooo00250;3PiP05086YP@1=J5T0CFQI04eXF@21ZH40201h
WWh00`21ZH40T;fB092mTP0=092mTP03086YP@2Lc9X0W<bJ01@0W<bJ00<0PJV10:7BW@2QdYd05`2Q
dYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01/0XM6I00<0PJV109g=U02McI@06P2M
cI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:]7l0R[Ao0140R[Ao00<0PJV107BHJ01dV6P02@1d
V6P00`21ZH40CVQ304iX@`0404iX@`80PJV1Q@2`h>H10?ooo`00Q@2`h>H01@21ZH40CFQI04eXF@1=
J5T0PJV100T0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2Q
dYd0XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2M
cI@0WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1d
V6P0M9QX00X0M9QX00<0PJV104iX@`1>J4<0101>J4<00`21ZH4000000;3PiP240;3PiP40oooo0025
0;3PiP05086YP@1=J5T0CFQI04eXF@21ZH402@1hWWh00`21ZH40T;fB092mTP0=092mTP03086YP@2L
c9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00L0:;CW003086YP@2Q
dIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00F09O4S003086YP@2:
]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX@`0404iX@`03086YP@00
0000000008@0/>3V0@3oool008H0/>3V00@0PJV104eXF@1=J5T0PJV12@1hWWh00`21ZH40T;fB092m
TP0=092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;C
W00L0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4
S00F09O4S003086YP@2:]7l0R[Ao0100R[Ao00<0PJV107BHJ01dV6P02P1dV6P00`21ZH40CVQ304iX
@`0304iX@`03086YP@000000000008D0/>3V0@3oool008H0/>3V0P21ZH4204eXF@03086YP@1hWWh0
N9in00H0N9in00<0PJV1092mTP2@_I803@2@_I800`21ZH40W<bJ09c<VP0C09c<VP03086YP@2QdYd0
XM:M01L0XM:M00<0PJV10:;CW02Rdi`0702Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0
WLfD01X0WLfD00<0PJV109O4S02Ga8`05P2Ga8`00`21ZH40R[Ao08ZdO`0@08ZdO`03086YP@1dV6P0
M9QX00T0M9QX00<0PJV104iX@`1>J4<0101>J4<4000008@0/>3V0@3oool008H0/>3V00<0PJV1055a
H021ZH401021ZH4707RNOP03086YP@2@_I80T;fB00`0T;fB00<0PJV109c<VP2Lc9X04`2Lc9X00`21
ZH40XM:M0:7BW@0G0:7BW@03086YP@2Rdi`0X]>L01`0X]>L00<0PJV10:7AV@2QdIT06P2QdIT00`21
ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV108ZdO`2:]7l0402:]7l00`21
ZH40M9QX07BHJ00907BHJ004086YP@1>J4<00000000000<0PJV10`0000250;3PiP40oooo00270;3P
iP04086YP@1ALF00DG5P086YP@80NjJ41@21ZH4207RNOP03086YP@2@_I80T;fB00`0T;fB00<0PJV1
09c<VP2Lc9X04`2Lc9X00`21ZH40XM:M0:7BW@0H0:7BW@03086YP@2Rdi`0X]>L01/0X]>L00<0PJV1
0:7AV@2QdIT06P2QdIT00`21ZH40WLfD09g=U00J09g=U003086YP@2Ga8`0UlB<01H0UlB<00<0PJV1
08ZdO`2:]7l03`2:]7l00`21ZH40M9QX07BHJ00407BHJ0030000001dV6P0M9QX00<0PJV11@000002
05=aB`<00000Q@2`h>H10?ooo`00Q`2`h>H01@21ZH40DG5P055aH01ALF00PJV100H0NjJ41P21ZH4<
092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd05`2QdYd00`21ZH40X]>L0:;CW00K
0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@06P2McI@00`21ZH40UlB<09O4S00E
09O4S003086YP@2:]7l0R[Ao00h0R[Ao00<0000008ZdO`21ZH400`1dV6P2086YP@<0000000@0PJV1
07RPK`1hX6l0N:1_2@0000260;3PiP40oooo00280;3PiP04086YP@1ALF00DG5P086YP@P0NjJ400@0
PJV109?4V02Ca9P0TlBH2021ZH44092mTP03086YP@2Lc9X0W<bJ01<0W<bJ00<0PJV10:7BW@2QdYd0
5`2QdYd00`21ZH40X]>L0:;CW00K0:;CW003086YP@2QdIT0XM6I01X0XM6I00<0PJV109g=U02McI@0
6@2McI@00`21ZH40UlB<09O4S00C09O4S0040000002Ga8`0UlB<086YP@D0R[Ao00<0000008ZdO`2:
]7l01P2:]7l01021ZH400000000000000004086YP@80N:1_0P00000407RPK`8000000P1CLD/20000
000405=aB`0000000000000008H0/>3V0@3oool008P0/>3V00D0PJV1055aH01ALF00DG5P086YP@08
07^VQ003086YP@2Ca9P0TlBH00P0TlBH3`21ZH4;09c<VP03086YP@2QdYd0XM:M01L0XM:M00<0PJV1
0:;CW02Rdi`06`2Rdi`00`21ZH40XM6I0:7AV@0J0:7AV@03086YP@2McI@0WLfD01T0WLfD00<0PJV1
09O4S02Ga8`04P2Ga8`30000000309O4S021ZH40R[Ao00<0R[Ao0`000007086YP@0508jlQ@000000
000008jlQ@21ZH401@1hX6l2000000<0N:1_0P00000305=aB`H00000QP2`h>H10?ooo`00R@2`h>H0
1021ZH40DG5P055aH021ZH4807^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ00202O
dZ0H086YP@d0XM:M00@0PJV10:;CW02Rdi`00000602Rdi`00`000000X]>L086YP@0L0:7AV@05086Y
P@2McI@0WLfD09g=U0000000102McI@00`000000WLfD09g=U00@09g=U003086YP@2Ga8`0UlB<00T0
UlB<0P000007086YP@8000001`21ZH42000000T0S[b50P0000000`21ZH40N:1_07RPK`0307RPK`<0
00000P1hX6l3000000<0Dg5;1@0000270;3PiP40oooo00290;3PiP05086YP@1ALF00DG5P055aH021
ZH401`1kYX@00`21ZH40TlBH09?4V00=09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2U
fJ<02P2UfJ<@086YP@0300000021ZH40PJV100T0PJV13@2Rdi`00`000000X]>L086YP@030:7AV@80
00002@2QdIT?086YP@`000002`21ZH42000000d0PJV10P00000809[;TP8000000P2Jbi800`21ZH40
S[b508jlQ@0208jlQ@8000002@2>_8D200000003086YP@1hX6l0N:1_00<0N:1_0P00000307RPK`80
0000101CLD/5000008L0/>3V0@3oool008X0/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40
TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05`2UfJ<00`21ZH40
Y]ZR0:KJXP02000000X0Y]ZR3021ZH42000000D0PJV10P000009086YP@h0YMRO3P00000:0:7DVP80
00000P2Qe9X00`21ZH40V/^B09[;TP0809[;TP800000202Jbi820000000309[;TP21ZH40S[b500@0
S[b50P00000808jlQ@<0000000<0PJV107RPK`1hX6l00P1hX6l3000000<0N:1_0P00000405=aB`@0
0000R02`h>H10?ooo`00RP2`h>H01021ZH40DG5P055aH021ZH4807^VQ003086YP@2Ca9P0TlBH00`0
TlBH00<0PJV109oBX02OdZ004`2OdZ000`21ZH40YMVS0:GIX`0F0:GIX`04086YP@2VfZ80Y]ZR0:KJ
XP8000005@2VfZ8010000000Y]ZR0:KJXP21ZH430:GHW`8000005@2Uf9l4000000X0XMBJ0P00000:
0:7DVP8000000P2Qe9X00`21ZH40V/^B09[;TP0809[;TP8000001`2Jbi830000000309[;TP21ZH40
S[b500<0S[b50`00000808jlQ@80000000<0PJV107RPK`1hX6l00`1hX6l2000000<0N:1_0`000003
05=aB`D00000R02`h>H10?ooo`00RP2`h>H01@21ZH40DG5P055aH01ALF00PJV100P0NjJ400<0PJV1
09?4V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00C09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV1
0:KJXP2VfZ800P2VfZ800`000000Y]ZR0:KJXP0B0:KJXP8000000P2VfZ801021ZH40YMRO0:GHW`2U
f9l2000001@0YMRO1000000<0:7DVP8000002@2Qe9X2000000030:7DVP21ZH40V/^B00X0V/^B0P00
000709[;TP8000000P2Jbi800`21ZH40S[b508jlQ@0208jlQ@8000002@2>_8D200000003086YP@1h
X6l0N:1_00<0N:1_0P00000307RPK`/00000R02`h>H10?ooo`00R`2`h>H01021ZH40DG5P055aH021
ZH4807^VQ003086YP@2Ca9P0TlBH00`0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GI
X`0G0:GIX`04086YP@2VfZ80Y]ZR0:KJXP8000004`2VfZ801@000000Y]ZR0:KJXP2VfZ80PJV100<0
YMRO0P00000C0:GHW`<0000000<0YMRO086YP@2Qe9X0302Qe9X00`000000XMBJ0:7DVP070:7DVP80
000000<0XMBJ086YP@2Jbi802P2Jbi82000000L0V/^B0P0000000`2Jbi80PJV108jlQ@0408jlQ@80
0000202>_8D300000003086YP@1hX6l0N:1_0080N:1_0`00000207RPK`/00000R@2`h>H10?ooo`00
R`2`h>H01@21ZH40DG5P055aH01ALF00PJV100L0NjJ400<0PJV109?4V02Ca9P0302Ca9P00`21ZH40
Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01L0YMVS00<0PJV10:KJXP2VfZ800P2VfZ800`000000
Y]ZR0:KJXP0@0:KJXP8000000`2VfZ801021ZH40YMRO0:GHW`2Uf9l2000001<0YMRO0P0000020:GH
W`03086YP@2Qe9X0XMBJ00/0XMBJ00<000000:7DVP2Qe9X01P2Qe9X200000080XMBJ00<0PJV109[;
TP2Jbi80202Jbi82000000P0V/^B0P0000000`2Jbi80PJV108jlQ@0408jlQ@800000202>_8D20000
0003086YP@1hX6l0N:1_00<0N:1_0P00000307RPK`8000000`1CLD/6000008T0/>3V0@3oool008`0
/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH09?4V00;09?4V003086YP@2OdZ00Wm:P
01<0Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP020:KJXP8000004@2VfZ800`00
0000Y]ZR0:KJXP020:KJXP04086YP@2Uf9l0YMRO0:GHW`8000004`2Uf9l200000080YMRO00<0PJV1
0:7DVP2Qe9X0502Qe9X200000080XMBJ00<0PJV109[;TP2Jbi80202Jbi82000000P0V/^B0P000000
0`2Jbi80PJV108jlQ@0408jlQ@800000202>_8D200000003086YP@1hX6l0N:1_00<0N:1_0P000003
07RPK`8000000P1CLD/7000008T0/>3V0@3oool008`0/>3V00@0PJV1055aH01ALF00PJV1201kYX@0
0`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<0
0`21ZH40Y]ZR0:KJXP030:KJXP8000003`2VfZ82000000@0Y]ZR00@0PJV10:GHW`2Uf9l0YMRO0P00
000C0:GHW`8000000P2Uf9l00`21ZH40XMBJ0:7DVP0D0:7DVP8000000P2Qe9X00`21ZH40V/^B09[;
TP0809[;TP8000001`2Jbi830000000309[;TP21ZH40S[b500<0S[b50`00000808jlQ@8000001@1h
X6l300000080N:1_0`0000000`1CLD/0000000000005000008X0/>3V0@3oool008d0/>3V00@0PJV1
055aH01ALF00PJV11`1kYX@00`21ZH40TlBH09?4V00<09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0
PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR0:KJXP040:KJXP030000002VfZ80Y]ZR00d0Y]ZR00<0
00000:KJXP2VfZ800`2VfZ801021ZH40YMRO0:GHW`2Uf9l200000180YMRO0`0000020:GHW`03086Y
P@2Qe9X0XMBJ01@0XMBJ0P0000000`2Qe9X0PJV109[;TP0:09[;TP8000001`2Jbi820000000309[;
TP21ZH40S[b500@0S[b50P00000808jlQ@<000001@1hX6l2000000<0N:1_0P0000000`1CLD/00000
00000005000008/0/>3V0@3oool008d0/>3V00@0PJV1055aH01ALF00PJV1201kYX@00`21ZH40TlBH
09?4V00;09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05P2UfJ<00`21ZH40Y]ZR
0:KJXP030:KJXQ8000001@2VfZ801021ZH40YMRO0:GHW`2Uf9l200000180YMRO0P0000030:GHW`03
086YP@2Qe9X0XMBJ01@0XMBJ0P0000000`2Qe9X0PJV109[;TP0:09[;TP8000001`2Jbi8200000003
09[;TP21ZH40S[b500@0S[b50P00000808jlQ@<000001@1hX6l2000000<0N:1_1P0000000`21ZH40
00000000002<0;3PiP40oooo002>0;3PiP04086YP@1ALF00DG5P086YP@L0NjJ400<0PJV109?4V02C
a9P0302Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01D0YMVS00<0PJV10:KJXP2V
fZ800`2VfZ8B000000D0Y]ZR00@0PJV10:GHW`2Uf9l0YMRO0`00000A0:GHW`<000000P2Uf9l00`21
ZH40XMBJ0:7DVP0C0:7DVP<0000000<0XMBJ086YP@2Jbi802P2Jbi82000000L0V/^B0P0000000`2J
bi80PJV108jlQ@0308jlQ@<00000202>_8D3000000@0N:1_0`00000307RPK`@000000P1CLD/00`21
ZH4000000000002<0;3PiP40oooo002>0;3PiP04086YP@1ALF00DG5P086YP@P0NjJ400<0PJV109?4
V02Ca9P02`2Ca9P00`21ZH40Wm:P09oBX00B09oBX003086YP@2UfJ<0YMVS01H0YMVS00<0PJV10:KJ
XP2VfZ800`2VfZ83000000/0Y]ZR0P0000060:KJXP04086YP@2Uf9l0YMRO0:GHW`<000004@2Uf9l3
000000030:GHW`21ZH40XMBJ01D0XMBJ0P0000020:7DVP03086YP@2Jbi80V/^B00P0V/^B0P000007
09[;TP<0000000<0PJV108jlQ@2>_8D00`2>_8D4000000H0S[b51@00000207RPK`<000000`1hX6l0
1021ZH40Dg5;05=aB`00000205=aB`03086YP@2`h>H0000008d0/>3V0@3oool008l0/>3V0P21ZH40
0`1ALF00PJV107^VQ00607^VQ003086YP@2Ca9P0TlBH00/0TlBH00<0PJV109oBX02OdZ004P2OdZ00
0`21ZH40YMVS0:GIX`0F0:GIX`03086YP@2VfZ80Y]ZR00<0Y]ZR0`00000;0:KJXP8000001P2VfZ80
1021ZH40YMRO0:GHW`2Uf9l300000180YMRO0P0000000`2Uf9l0PJV10:7DVP0<0:7DVP030000002Q
e9X0XMBJ00H0XMBJ0`0000000`2Qe9X0PJV109[;TP0909[;TP8000001`2Jbi820000000309[;TP21
ZH40S[b500@0S[b51P00000208jlQ@@0000000<0PJV10000000000001000000407RPK`03086YP@1C
LD/0Dg5;0080Dg5;0P21ZH42000008d0/>3V0@3oool008l0/>3V00<0PJV105=eH`21ZH400`21ZH45
07^VQ003086YP@2Ca9P0TlBH00/0TlBH00<0PJV109oBX02OdZ004P2OdZ000`21ZH40YMVS0:GIX`0F
0:GIX`03086YP@2VfZ80Y]ZR00@0Y]ZR0`0000090:KJXP<000001P2VfZ801021ZH40YMRO0:GHW`2U
f9l400000140YMRO0`0000000`21ZH40XMBJ0:7DVP090:7DVP@000001`2Qe9X5000000T0V/^B0P00
000809[;TP80000000<0V/^B086YP@2>_8D0102>_8D20000000308jlQ@000000000000H0000000<0
PJV107RPK`0000001000000407RPK`03086YP@1CLD/0PJV100<0PJV100<0E7I@0;3PiP000000SP2`
h>H10?ooo`00T02`h>H01@21ZH40DgES05=eH`21ZH40NjR600@0PJV10P1kYX@00`21ZH40TlBH09?4
V00;09?4V003086YP@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJ
XP060:KJXP800000202VfZ82000000L0Y]ZR00@0PJV10:GHW`2Uf9l0YMRO1@00000A0:GHW`@00000
2@2Qe9X4000000P0XMBJ1P00000509[;TPD000001`2Jbi8300000003086YP@2>_8D0S[b500<0S[b5
0`00000208jlQ@D000000P2>_8D00`21ZH40N:1_07RPK`0707RPK`<0PJV1101DMU000`21ZH40/>3V
0000002>0;3PiP40oooo002@0;3PiP04086YP@1CMF<0DgES086YP@D0NjR61@21ZH4;09?4V003086Y
P@2OdZ00Wm:P0180Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJXP070:KJXP030000
002VfZ80Y]ZR00H0Y]ZR00<000000:KJXP2VfZ801P2VfZ801021ZH40YMRO0:GHW`2Uf9l200000004
0:GHW`000000000000000140YMRO1@0000040:7DVPD000002P2Qe9X2000000030:7DVP21ZH400000
00X000002@2Jbi800`000000V/^B086YP@0608jlQ@030000002>_8D0S[b500P0S[b500<0PJV107RP
K`1hX6l00`1hX6l5086YP@D0E7I@00<0PJV10;3PiP2`h>H0S`2`h>H10?ooo`00T@2`h>H01021ZH40
DgES05=eH`21ZH4707^XQP03086YP@2Dai/0PJV100@0PJV11P2Ca9P00`21ZH40Wm:P09oBX00B09oB
X003086YP@2UfJ<0YMVS01D0YMVS00<0PJV10:KJXP2VfZ801`2VfZ82000000H0Y]ZR0P0000080:KJ
XP04086YP@2Uf9l0YMRO0:GHW`8000000P2Uf9l5000000l0YMRO00<0PJV10000000000002@00000;
0:7DVP80000000<0XMBJ086YP@0000001`00000>09[;TP03086YP@2>_8D0S[b500h0S[b500<0PJV1
07RPK`1hX6l01021ZH4407VTL`03086YP@1DMU00E7I@0080E7I@00<0PJV10;3PiP2`h>H0T02`h>H1
0?ooo`00TP2`h>H00`21ZH40DgES086YP@0707^XQP03086YP@2Dai/0U<NK00@0U<NK1@21ZH4209?4
V003086YP@2OdZ00Wm:P0140Wm:P00<0PJV10:GIX`2UfJ<05@2UfJ<00`21ZH40Y]ZR0:KJXP080:KJ
XP030000002VfZ80Y]ZR00@0Y]ZR00<000000:KJXP2VfZ801`2VfZ801021ZH40YMRO0:GHW`2Uf9l2
000000<0YMRO2@00000:0:GHW`03086YP@2Qe9X0000000H000003@2Qe9X200000080XMBJ00<0PJV1
09[;TP2Jbi80502Jbi800`21ZH40S[b508jlQ@0:08jlQ@L0PJV11`1iY7<00`21ZH40E7I@05AfD003
05AfD003086YP@2`h>H0/>3V0900/>3V0@3oool00980/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H0
0`21ZH40U<NK09C7V`0809C7V`d0PJV12P2OdZ000`21ZH40YMVS0:GIX`0E0:GIX`03086YP@2VfZ80
Y]ZR00L0Y]ZR0P0000040:KJXP8000002@2VfZ801021ZH40YMRO0:GHW`2Uf9l2000000D0YMRO1`00
000:0:GHW`03086YP@2Qe9X0XMBJ01<0XMBJ0P0000000`2Qe9X0PJV109[;TP0E09[;TP03086YP@2>
_8D0S[b50080S[b52@21ZH4308noR@03086YP@1iY7<0NJAc00P0NJAc00<0PJV105AfD01DMU000P1D
MU000`21ZH40/>3V0;3PiP2A0;3PiP40oooo002C0;3PiP04086YP@1CMF<0DgES086YP@H0NjR600<0
PJV109C7V`2Dai/02`2Dai/00`21ZH40XMJT0:7FY0070:7FY100PJV14P2UfJ<00`21ZH40Y]ZR0:KJ
XP080:KJXP8000000`2VfZ800`000000Y]ZR0:KJXP080:KJXP03086YP@2Uf9l0YMRO01T0YMRO00<0
PJV10:7DVP2Qe9X04`2Qe9X2000000030:7DVP21ZH40V/^B00X0V/^B2021ZH400`000000PJV1086Y
P@05086YP@`0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205AfD003086YP@2`
h>H0/>3V0980/>3V0@3oool009@0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40U<NK09C7V`0:
09C7V`03086YP@2QeZ@0XMJT0140XMJT00<0PJV10:KMY`2VgJL00`2VgJL<086YP@H0YMVS00<0PJV1
0:KJXP2VfZ802@2VfZ800`000000Y]ZR0:KJXP02000000X0Y]ZR00<0PJV10:GHW`2Uf9l06@2Uf9l0
0`21ZH40XMBJ0:7DVP0:0:7DVPT0PJV10P00000=086YP@L0W=2F0`0000000`2Ld9H0PJV108noR@0>
08noR@03086YP@1iY7<0NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C
0;3PiP40oooo002D0;3PiP04086YP@1CMF<0DgES086YP@L0NjR600<0PJV109C7V`2Dai/02P2Dai/0
0`21ZH40XMJT0:7FY00A0:7FY003086YP@2VgJL0Y]fW00h0Y]fW4P21ZH4200000003086YP@000000
PJV103<0PJV12@2SfIh2000000030:?IWP21ZH40W=2F0100W=2F1@00000@08noR@03086YP@1iY7<0
NJAc00L0NJAc00<0PJV105AfD01DMU000P1DMU000`21ZH40/>3V0;3PiP2C0;3PiP40oooo002E0;3P
iP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00A0:7F
Y003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH02P2XgjH3000000/0Z=nV00<0PJV10:OM
X`2WgJ<06@2WgJ<00`21ZH40XmVN0:?IWP0C0:?IWP80000000<0PJV109c@UP2Ld9H04@2Ld9H30000
0003086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205Af
D003086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V00@0PJV105=eH`1CMF<0PJV11`1kZ8H00`21
ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21
ZH40Z=nV0:SOYP0;0:SOYP030000002XgjH0Z=nV00X0Z=nV00<0PJV10:OMX`2WgJ<06@2WgJ<00`21
ZH40XmVN0:?IWP0B0:?IWP80000000<0XmVN086YP@2Ld9H04`2Ld9H00`000000PJV108noR@0?08no
R@03086YP@1iY7<0NJAc00L0NJAc00D0PJV105AfD01DMU00E7I@086YP@2G0;3PiP40oooo002F0;3P
iP03086YP@1CMF<0PJV100L0NjR600<0PJV109C7V`2Dai/02P2Dai/00`21ZH40XMJT0:7FY00A0:7F
Y003086YP@2VgJL0Y]fW01@0Y]fW00<0PJV10:SOYP2XgjH02P2XgjH00`000000Z=nV0:SOYP0:0:SO
YP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05P2SfIh00`21ZH40W=2F09c@UP0C09c@
UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<00`21ZH40E7I@05AfD00205Af
D003086YP@2`h>H0/>3V09D0/>3V0@3oool009L0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21ZH40
U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21ZH40
Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05P2SfIh00`21ZH40
W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01`1iY7<01@21ZH40
E7I@05AfD01DMU00PJV109P0/>3V0@3oool009L0/>3V00@0PJV105=eH`1CMF<0PJV11P1kZ8H00`21
ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL0502VgJL00`21
ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21
ZH40W=2F09c@UP0C09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1iY7<01`1iY7<01@21
ZH40E7I@05AfD01DMU00PJV109T0/>3V0@3oool009P0/>3V00<0PJV105=eH`21ZH401`1kZ8H00`21
ZH40U<NK09C7V`0:09C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21
ZH40Z=nV0:SOYP0G0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21
ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01P1iY7<00`21
ZH40E7I@05AfD00205AfD003086YP@2`h>H0/>3V09L0/>3V0@3oool009T0/>3V00<0PJV105=eH`21
ZH401`1kZ8H00`21ZH40U<NK09C7V`0909C7V`03086YP@2QeZ@0XMJT0100XMJT00<0PJV10:KMY`2V
gJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01P0YmfS00<0PJV10:?IWP2S
fIh05@2SfIh00`21ZH40W=2F09c@UP0B09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV107VTL`1i
Y7<01`1iY7<01@21ZH40E7I@05AfD01DMU00PJV109X0/>3V0@3oool009X0/>3V0P21ZH4707^XQP03
086YP@2Dai/0U<NK00X0U<NK00<0PJV10:7FY02QeZ@03`2QeZ@00`21ZH40Y]fW0:KMY`0D0:KMY`03
086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:OMX`2WgJ<0602WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03
086YP@2Ld9H0W=2F0180W=2F00<0PJV108noR@2?_hT03P2?_hT00`21ZH40NJAc07VTL`0607VTL`03
086YP@1DMU00E7I@0080PJV1V`2`h>H10?ooo`00V`2`h>H4086YP@D0NjR600<0PJV109C7V`2Dai/0
2@2Dai/00`21ZH40XMJT0:7FY00@0:7FY003086YP@2VgJL0Y]fW01<0Y]fW00<0PJV10:SOYP2XgjH0
5P2XgjH00`21ZH40YmfS0:OMX`0G0:OMX`03086YP@2SfIh0XmVN01D0XmVN00<0PJV109c@UP2Ld9H0
4P2Ld9H00`21ZH40Skn908noR@0=08noR@03086YP@1iY7<0NJAc00L0NJAc1021ZH6L0;3PiP40oooo
002L0;3PiP80PJV100<0MZF4086YP@21ZH400P21ZH400`1kZ8H0PJV109C7V`0;09C7V`03086YP@2Q
eZ@0XMJT00l0XMJT00<0PJV10:KMY`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0G0:SOYP03086YP@2W
gJ<0YmfS01H0YmfS00<0PJV10:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?
_hT0Skn900h0Skn900<0PJV107VTL`1iY7<01@1iY7<3086YP@80DWIB00<0PJV10;3PiP2`h>H0VP2`
h>H10?ooo`00W@2`h>H2086YP@@0MZF41@21ZH4909C7V`03086YP@2QeZ@0XMJT00l0XMJT00<0PJV1
0:KMY`2VgJL0502VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01H0YmfS00<0PJV1
0:?IWP2SfIh05@2SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?_hT0Skn900d0Skn900<0PJV1
07VTL`1iY7<00P1iY7<5086YP@<0DWIB00<0PJV10;3PiP2`h>H0V`2`h>H10?ooo`00WP2`h>H2086Y
P@H0MZF400<0PJV10934V@21ZH400`21ZH4609C7V`03086YP@2QeZ@0XMJT00l0XMJT00<0PJV10:KM
Y`2VgJL04`2VgJL00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgJ<0YmfS01H0YmfS00<0PJV10:?I
WP2SfIh0502SfIh00`21ZH40W=2F09c@UP0A09c@UP03086YP@2?_hT0Skn900h0Skn91@21ZH4307FR
L`05086YP@1BMU80DWIB059fDP21ZH40WP2`h>H10?ooo`00WP2`h>H00`21ZH40D7AR086YP@0607JU
Q003086YP@2@a9T0T<BI0080T<BI1@21ZH400`2Dai/0PJV10:7FY00@0:7FY003086YP@2VgJL0Y]fW
01<0Y]fW00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmfS0:OMX`0F0:OMX`03086YP@2SfIh0XmVN
01@0XmVN00<0PJV109c@UP2Ld9H04@2Ld9H00`21ZH40Skn908noR@0908noR@H0PJV11P1eXW<01@21
ZH40DWIB059fDP1BMU80PJV109l0/>3V0@3oool009l0/>3V00<0PJV1051dHP21ZH401@1fYH@00`21
ZH40T<BI0934V@070934V@L0PJV1302QeZ@00`21ZH40Y]fW0:KMY`0C0:KMY`03086YP@2XgjH0Z=nV
01H0Z=nV00<0PJV10:OMX`2WgJ<05P2WgJ<00`21ZH40XmVN0:?IWP0D0:?IWP03086YP@2Ld9H0W=2F
0100W=2F00<0PJV108noR@2?_hT00P2?_hT8086YP@<0S;n:00<0PJV107FRL`1eXW<01P1eXW<01021
ZH40DWIB059fDP21ZH6P0;3PiP40oooo002P0;3PiP03086YP@1@M680PJV100D0MZF400<0PJV10934
V@2@a9T02@2@a9T01021ZH40W]JT09kFY02NeZ@9086YP@@0XMJT00<0PJV10:KMY`2VgJL04`2VgJL0
0`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgJ<0YmfS01D0YmfS00<0PJV10:?IWP2SfIh05@2SfIh0
0`21ZH40W=2F09c@UP0<09c@UPT0PJV12P2<_hX00`21ZH40MJ9c07FRL`0607FRL`05086YP@1BMU80
DWIB059fDP21ZH40X02`h>H10?ooo`00X@2`h>H2086YP@H0MZF400<0PJV10934V@2@a9T0202@a9T0
0`21ZH40W]JT09kFY00:09kFY0l0PJV12`2VgJL00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgJ<0
YmfS01D0YmfS00<0PJV10:?IWP2SfIh0502SfIh00`21ZH40W=2F09c@UP0309c@UPX0PJV10`2Jd9P0
0`21ZH40S;n:08boRP0=08boRP03086YP@1eXW<0MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086Y
P@2Q0;3PiP40oooo002R0;3PiP80PJV11P1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0
W]JT00h0W]JT00<0PJV10:GMZ02UgJP01`2UgJPG086YP@`0Z=nV00<0PJV10:OMX`2WgJ<05@2WgJ<0
0`21ZH40XmVN0:?IWP090:?IWQ40PJV13@2Jd9P00`21ZH40S;n:08boRP0<08boRP03086YP@1eXW<0
MJ9c00D0MJ9c00D0PJV1059fDP1BMU80DWIB086YP@2R0;3PiP40oooo002S0;3PiP80PJV11P1fYH@0
0`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GMZ02UgJP04P2UgJP0
0`21ZH40Yn2X0:OPZ0090:OPZ300PJV12`2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<_hX0
S;n:00`0S;n:00<0PJV107FRL`1eXW<01@1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:<0/>3V0@3o
ool00:@0/>3V0P21ZH4507JUQ003086YP@2@a9T0T<BI00T0T<BI00<0PJV109kFY02NeZ@03@2NeZ@0
0`21ZH40YMfX0:GMZ00B0:GMZ003086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD05@2VgjD0
0`21ZH40X]ZP0:;JX00C0:;JX003086YP@2Jd9P0V]2H0100V]2H00<0PJV108boRP2<_hX02`2<_hX0
0`21ZH40MJ9c07FRL`0507FRL`05086YP@1BMU80DWIB059fDP21ZH40Y02`h>H10?ooo`00Y@2`h>H2
086YP@D0MZF400<0PJV10934V@2@a9T0202@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0
YMfX0180YMfX00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40Y]nU0:KOY@0E0:KOY@03086YP@2RfZ00
X]ZP01<0X]ZP00<0PJV109[@V02Jd9P03`2Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0
MJ9c00D0MJ9c00<0PJV1059fDP1BMU800P1BMU800`21ZH40/>3V0;3PiP2R0;3PiP40oooo002V0;3P
iP80PJV11@1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT00<0PJV10:GM
Z02UgJP04@2UgJP00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2VgjD0Y]nU01D0Y]nU00<0PJV10:;J
X02RfZ004P2RfZ000`21ZH40V]2H09[@V00@09[@V003086YP@2<_hX0S;n:00/0S;n:00<0PJV107FR
L`1eXW<01@1eXW<01@21ZH40DWIB059fDP1BMU80PJV10:D0/>3V0@3oool00:L0/>3V0P21ZH4507JU
Q003086YP@2@a9T0T<BI00P0T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40YMfX0:GMZ00A0:GM
Z003086YP@2Wh:P0Yn2X01@0Yn2X00<0PJV10:KOY@2VgjD0502VgjD00`21ZH40X]ZP0:;JX00C0:;J
X003086YP@2Jd9P0V]2H00l0V]2H00<0PJV108boRP2<_hX02`2<_hX00`21ZH40MJ9c07FRL`0507FR
L`03086YP@1BMU80DWIB0080PJV1YP2`h>H10?ooo`00Z@2`h>H2086YP@@0MZF400<0PJV10934V@2@
a9T01`2@a9T00`21ZH40W]JT09kFY00=09kFY003086YP@2UgJP0YMfX0140YMfX00<0PJV10:OPZ02W
h:P04`2Wh:P00`21ZH40Y]nU0:KOY@0D0:KOY@03086YP@2RfZ00X]ZP0180X]ZP00<0PJV109[@V02J
d9P03`2Jd9P00`21ZH40S;n:08boRP0;08boRP03086YP@1eXW<0MJ9c00D0MJ9c1@21ZH6W0;3PiP40
oooo002Z0;3PiP<0PJV10P1fYH@00`21ZH40T<BI0934V@080934V@03086YP@2NeZ@0W]JT00d0W]JT
00<0PJV10:GMZ02UgJP0402UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2VgjD0Y]nU01@0Y]nU
00<0PJV10:;JX02RfZ004P2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<_hX0S;n:00X0S;n:
00<0PJV107FRL`1eXW<0101eXW<3086YP@80CG5@Z@2`h>H10?ooo`00Z`2`h>H00`21ZH40KI]m086Y
P@03086YP@X0T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40YMfX0:GMZ00@0:GMZ003086YP@2W
h:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD0502VgjD00`21ZH40X]ZP0:;JX00B0:;JX003086YP@2J
d9P0V]2H00h0V]2H00<0PJV108boRP2<_hX02`2<_hX01021ZH40MJ9c07FRL`1eXW<4086YP@80CG5@
00<0PJV10;3PiP2`h>H0Z02`h>H10?ooo`00[02`h>H2086YP@80KI]m1021ZH480934V@03086YP@2N
eZ@0W]JT00`0W]JT00<0PJV10:GMZ02UgJP03`2UgJP00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2V
gjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ004@2RfZ000`21ZH40V]2H09[@V00?09[@V003086YP@2<
_hX0S;n:00X0S;n:1@21ZH4206fJK`04086YP@1=LE00CG5@086YPJ/0/>3V0@3oool00:h0/>3V00H0
PJV106fKO@1]Vgd0KI]m086YP@26^Y86086YP@80T<BI00<0PJV109kFY02NeZ@0302NeZ@00`21ZH40
YMfX0:GMZ00@0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KOY@2VgjD04`2VgjD00`21ZH40
X]ZP0:;JX00A0:;JX003086YP@2Jd9P0V]2H00h0V]2H00<0PJV108boRP2<_hX01`2<_hX5086YP@@0
KIY_0P21ZH400`1=LE00PJV10;3PiP2/0;3PiP40oooo002_0;3PiP05086YP@1]Vgd0KI]m06fKO@21
ZH401P26^Y87086YP@/0W]JT00<0PJV10:GMZ02UgJP03`2UgJP00`21ZH40Yn2X0:OPZ00C0:OPZ003
086YP@2VgjD0Y]nU01<0Y]nU00<0PJV10:;JX02RfZ00402RfZ000`21ZH40V]2H09[@V00?09[@V003
086YP@2<_hX0S;n:00L0PJV10P24]hH00`21ZH40KIY_06fJK`0306fJK`04086YP@1=LE00CG5@086Y
PJh0/>3V0@3oool00;00/>3V00@0PJV106fKO@1]Vgd0KI]m0P21ZH4808JjTP03086YP@2FcYh0U/jN
00P0PJV10`2NeZ@00`21ZH40YMfX0:GMZ00?0:GMZ003086YP@2Wh:P0Yn2X01<0Yn2X00<0PJV10:KO
Y@2VgjD04P2VgjD00`21ZH40X]ZP0:;JX00A0:;JX003086YP@2Jd9P0V]2H00X0V]2H2021ZH4808Bg
QP03086YP@1]VVl0KIY_00<0KIY_00@0PJV104eaD021ZH40PJV1[`2`h>H10?ooo`00/@2`h>H00`21
ZH40KI]m06fKO@0206fKO@03086YP@26^Y80Q[ZB00H0Q[ZB00<0PJV109K>WP2FcYh01`2FcYh9086Y
P@`0YMfX00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40Y]nU0:KOY@0B0:KOY@03086YP@2RfZ00X]ZP
0100X]ZP00<0PJV109[@V02Jd9P00P2Jd9P9086YP@<0TlZD00<0PJV108BgQP24]hH02024]hH2086Y
P@D0KIY_00<0PJV104eaD021ZH40/@2`h>H10?ooo`00/P2`h>H00`21ZH40KI]m06fKO@0206fKO@03
086YP@26^Y80Q[ZB00H0Q[ZB00<0PJV109K>WP2FcYh02`2FcYh01021ZH40W]RT09kHY02Nf:@9086Y
P@@0YMfX00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40Y]nU0:KOY@0B0:KOY@03086YP@2RfZ00X]ZP
00L0X]ZP3P21ZH4;09?:U003086YP@24]hH0Q;N600P0Q;N600<0PJV106fJK`1]VVl0101]VVl00`21
ZH40CG5@086YP@2b0;3PiP40oooo002c0;3PiP80PJV10`1]Vgd00`21ZH40Q[ZB08JjTP0608JjTP03
086YP@2FcYh0U/jN00X0U/jN00<0PJV109kHY02Nf:@02P2Nf:@h086YP@P0W=FN00<0PJV109?:U02C
bY@03@2CbY@00`21ZH40Q;N608BgQP0808BgQP03086YP@1]VVl0KIY_00@0KIY_0`21ZH6c0;3PiP40
oooo002e0;3PiP05086YP@1]Vgd0KI]m06fKO@21ZH402026^Y800`21ZH40U/jN09K>WP0:09K>WP03
086YP@2Nf:@0W]RT00d0W]RT00<0PJV10:7KY@2QfjD04P2QfjD00`21ZH40XMZS0:7JX`0B0:7JX`03
086YP@2LeIh0W=FN00l0W=FN00<0PJV109?:U02CbY@03@2CbY@00`21ZH40Q;N608BgQP0708BgQP03
086YP@1]VVl0KIY_00<0KIY_0`21ZH6e0;3PiP40oooo002f0;3PiP04086YP@1]Vgd0KI]m06fKO@80
PJV11P26^Y800`21ZH40U/jN09K>WP0;09K>WP03086YP@2Nf:@0W]RT00d0W]RT00<0PJV10:7KY@2Q
fjD04@2QfjD00`21ZH40XMZS0:7JX`0A0:7JX`03086YP@2LeIh0W=FN00l0W=FN00<0PJV109?:U02C
bY@03@2CbY@00`21ZH40Q;N608BgQP0708BgQP03086YP@1]VVl0KIY_00<0KIY_0`21ZH6f0;3PiP40
oooo002g0;3PiP80PJV10`1]Vgd00`21ZH40Q[ZB08JjTP0408JjTP03086YP@2FcYh0U/jN00/0U/jN
00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2QfZ<0XMZS0140XMZS
00<0PJV109cEWP2LeIh03P2LeIh00`21ZH40TlZD09?:U00=09?:U003086YP@24]hH0Q;N600H0Q;N6
0P21ZH4506fJK`80PJV1^02`h>H10?ooo`00^02`h>H6086YP@H0Q[ZB00<0PJV109K>WP2FcYh02P2F
cYh00`21ZH40W]RT09kHY00=09kHY003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<04@2Q
fZ<00`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00`0TlZD00<0PJV108BgQP24]hH01P24
]hH00`21ZH40KIY_06fJK`0206fJK`<0PJV1^P2`h>H10?ooo`00^P2`h>H2086YP@0405j9K`21ZH40
PJV1086YP@D0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh00`21ZH40W]RT09kHY00<09kHY003086YP@2Q
fjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<04@2QfZ<00`21ZH40W=FN09cEWP0=09cEWP03086YP@2C
bY@0TlZD00`0TlZD00<0PJV108BgQP24]hH01P24]hH00`21ZH40KIY_086YP@05086YPK/0/>3V0@3o
ool00;`0/>3V0P21ZH400`1NRFl0PJV1086YP@02086YP@<0Q[ZB00<0PJV109K>WP2FcYh02P2FcYh0
0`21ZH40W]RT09kHY00<09kHY003086YP@2QfjD0XM^U0100XM^U00<0PJV10:7JX`2QfZ<03`2QfZ<0
0`21ZH40W=FN09cEWP0>09cEWP03086YP@2CbY@0TlZD00/0TlZD00<0PJV108BgQP24]hH01@24]hH4
086YP@80Gh]V0P21ZH6m0;3PiP40oooo002n0;3PiP80PJV100<0GXU_086YP@21ZH401@21ZH4<09K>
WP03086YP@2Nf:@0W]RT00/0W]RT00<0PJV10:7KY@2QfjD0402QfjD00`21ZH40XMZS0:7JX`0?0:7J
X`03086YP@2LeIh0W=FN00d0W=FN00<0PJV109?:U02CbY@0302CbY@01021ZH40Q;N608BgQP24]hH5
086YP@<0Gh]V0P21ZH6o0;3PiP40oooo00300;3PiP80PJV100<0GXU_086YP@21ZH400P1eYh@8086Y
P@D0U/jN00<0PJV109kHY02Nf:@0302Nf:@00`21ZH40XM^U0:7KY@0?0:7KY@03086YP@2QfZ<0XMZS
00l0XMZS00<0PJV109cEWP2LeIh0302LeIh00`21ZH40TlZD09?:U00<09?:U0D0PJV100<0MJIk086Y
P@21ZH400`1ORfH2086YPL40/>3V0@3oool00<80/>3V0P21ZH400`1NRFl0PJV107FWQ00207FWQ080
PJV11025^i4:086YP@X0W]RT00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XMZS0:7JX`0?0:7JX`03
086YP@2LeIh0W=FN00`0W=FN00<0PJV109?:U02CbY@0102CbY@9086YP@@0MJIk00@0PJV105n;IP1O
RfH0Gh]V0P21ZH730;3PiP40oooo00340;3PiP@0PJV10`1eYh@2086YP@T0QK^A00<0PJV108k6V02>
aYP02021ZH4309kHY003086YP@2QfjD0XM^U00h0XM^U00<0PJV10:7JX`2QfZ<03P2QfZ<00`21ZH40
W=FN09cEWP0509cEWPl0PJV11@24^HX2086YP@@0MJIk0P21ZH4205n;IP80PJV1a@2`h>H10?ooo`00
aP2`h>H4086YP@<0MJN400<0PJV108FkT@25^i401`25^i400`21ZH40S/JH08k6V00708k6V2d0PJV1
1P2>aI<00`21ZH40Q;V:08BiRP0:08BiRP03086YP@1eYW/0MJIk00<0MJIk00<0PJV105n;IP1ORfH0
0`21ZH760;3PiP40oooo00390;3PiP<0PJV10P1eYh@2086YP@P0QK^A00<0PJV108k6V02>aYP02P2>
aYP00`21ZH40TlbK09?<V`0=09?<V`03086YP@2BbiT0T/^I00d0T/^I00<0PJV108k5T`2>aI<02`2>
aI<00`21ZH40Q;V:08BiRP0908BiRP80PJV1101eYW/2086YP@0405n;IP21ZH40PJV1086YPLP0/>3V
0@3oool00</0/>3V0`21ZH4207FWQ080PJV11`25^i42086YP@/0S/JH00<0PJV109?<V`2Cc9/0302C
c9/00`21ZH40T/^I09;;V@0=09;;V@03086YP@2>aI<0S/FC00X0S/FC00<0PJV108BiRP24^HX02024
^HX2086YP@@0MJIk1@21ZH7;0;3PiP40oooo003>0;3PiPH0PJV11`25^i400`21ZH40S/JH08k6V009
08k6V003086YP@2Cc9/0TlbK00/0TlbK00<0PJV109;;V@2BbiT0302BbiT00`21ZH40S/FC08k5T`0:
08k5T`03086YP@24^HX0Q;V:00P0Q;V:00@0PJV107FVN`1eYW/0MJIk1P21ZH7=0;3PiP40oooo003A
0;3PiPH0PJV11@25^i400`21ZH40S/JH08k6V00808k6V003086YP@2Cc9/0TlbK00`0TlbK00<0PJV1
09;;V@2BbiT02`2BbiT00`21ZH40S/FC08k5T`0908k5T`03086YP@24^HX0Q;V:00L0Q;V:2@21ZH7@
0;3PiP40oooo003C0;3PiPT0PJV100<0QK^A086YP@2>aYP02@2>aYP00`21ZH40TlbK09?<V`0;09?<
V`03086YP@2BbiT0T/^I00X0T/^I00<0PJV108k5T`2>aI<02@2>aI<00`21ZH40Q;V:08BiRP0208Bi
RP`0PJV1d`2`h>H10?ooo`00eP2`h>H5086YP@0306ZJN@21ZH40PJV100H0PJV11@2>aYP00`21ZH40
TlbK09?<V`0:09?<V`03086YP@2BbiT0T/^I00X0T/^I00<0PJV108k5T`2>aI<00`2>aI<;086YP@80
Ji]e0P21ZH400`1MRFL0PJV1086YP@03086YPMD0/>3V0@3oool00=T0/>3V1@21ZH4206ZJN@80PJV1
0P1cYX4U086YP@<0LjIn0P21ZH4506^KM@80PJV100<0GHUW086YP@21ZH400`21ZH7H0;3PiP40oooo
003M0;3PiP<0PJV10P1ZVWT2086YP@L0LjJ10P21ZH4907R/Q003086YP@1hZh<0N:^300P0N:^300<0
PJV107>VOP1cYWh01P1cYWh2086YP@@0Ji]e1`21ZH7L0;3PiP40oooo003P0;3PiPH0PJV11`1cYX42
086YP@L0N:b400<0PJV107R[P`1hZh<01`1hZh<00`21ZH40LjIn07>VOP0507>VOP80PJV100<0Ji]e
086YP@21ZH401@21ZH7Q0;3PiP40oooo003T0;3PiPl0PJV1101h[8@00`21ZH40N:^307R[P`0607R[
P`04086YP@1cYWh0LjIn07>VOPL0PJV1j02`h>H10?ooo`00lP2`h>HB086YPNl0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo0000\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.603 .774 .563 r
.4405 .46951 m .43989 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.603 .774 .563 r
.47983 .5 m .48003 .46975 L .4405 .46951 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.48003 .53025 m .47983 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.48003 .46975 m .47983 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.609 .783 .573 r
.52017 .5 m .51997 .46975 L .48003 .46975 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.47983 .5 m .48003 .53025 L .51997 .53025 L p F P
.505 .664 .505 r
s
.593 .757 .553 r
.51997 .53025 m .52017 .5 L .47983 .5 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.51997 .46975 m .52017 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.52017 .5 m .51997 .53025 L .5595 .53049 L p F P
.505 .664 .505 r
s
.595 .761 .559 r
.5595 .53049 m .56011 .5 L .52017 .5 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.48064 .43983 m .48003 .46975 L .51997 .46975 L p F P
.505 .664 .505 r
s
.623 .805 .591 r
.51997 .46975 m .51936 .43983 L .48064 .43983 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.51936 .56017 m .51997 .53025 L .48003 .53025 L p F P
.505 .664 .505 r
s
.626 .809 .598 r
.51936 .43983 m .51997 .46975 L .5595 .46951 L p F P
.505 .664 .505 r
s
.612 .786 .579 r
.56011 .5 m .5595 .46951 L .51997 .46975 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.51997 .53025 m .51936 .56017 L .55767 .56063 L p F P
.505 .664 .505 r
s
.576 .732 .537 r
.55767 .56063 m .5595 .53049 L .51997 .53025 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.44233 .43937 m .4405 .46951 L .48003 .46975 L p F P
.505 .664 .505 r
s
.617 .797 .581 r
.48003 .46975 m .48064 .43983 L .44233 .43937 L p F P
.505 .664 .505 r
s
.587 .749 .543 r
.43989 .5 m .4405 .53049 L .48003 .53025 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.48064 .56017 m .48003 .53025 L .4405 .53049 L p F P
.505 .664 .505 r
s
.575 .729 .531 r
.48003 .53025 m .48064 .56017 L .51936 .56017 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.52155 .44146 m
.5224 .44145 L
s
.4778 .4398 m
.47943 .43534 L
s
.4932 .4323 m
.49623 .43541 L
s
.5 Mabswid
.592 .761 .549 r
.40219 .46902 m .40117 .5 L .43989 .5 L p F P
.505 .664 .505 r
s
.592 .761 .549 r
.43989 .5 m .4405 .46951 L .40219 .46902 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.4405 .53049 m .43989 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.5595 .46951 m .56011 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.56011 .5 m .5595 .53049 L .59781 .53098 L p F P
.505 .664 .505 r
s
.593 .758 .561 r
.59781 .53098 m .59883 .5 L .56011 .5 L p F P
.505 .664 .505 r
s
.568 .72 .52 r
.4405 .53049 m .44233 .56063 L .48064 .56017 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.48166 .58939 m .48064 .56017 L .44233 .56063 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.48166 .41061 m .48064 .43983 L .51936 .43983 L p F P
.505 .664 .505 r
s
.635 .826 .607 r
.51936 .43983 m .51834 .41061 L .48166 .41061 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.48064 .56017 m .48166 .58939 L .51834 .58939 L p F P
.505 .664 .505 r
s
.553 .696 .505 r
.51834 .58939 m .51936 .56017 L .48064 .56017 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.51834 .41061 m .51936 .43983 L .55767 .43937 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.52236 .44206 m
.5232 .43979 L
s
.5 Mabswid
.626 .809 .598 r
.5595 .46951 m .55767 .43937 L .51936 .43983 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.51936 .56017 m .51834 .58939 L .55461 .59005 L p F P
.505 .664 .505 r
s
.554 .699 .511 r
.55461 .59005 m .55767 .56063 L .51936 .56017 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.44539 .40995 m .44233 .43937 L .48064 .43983 L p F P
.505 .664 .505 r
s
.629 .818 .598 r
.48064 .43983 m .48166 .41061 L .44539 .40995 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.55767 .43937 m .5595 .46951 L .59781 .46902 L p F P
.505 .664 .505 r
s
.61 .785 .582 r
.59883 .5 m .59781 .46902 L .5595 .46951 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.5595 .53049 m .55767 .56063 L .59475 .56157 L p F P
.505 .664 .505 r
s
.573 .728 .538 r
.59475 .56157 m .59781 .53098 L .5595 .53049 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.40525 .43843 m .40219 .46902 L .4405 .46951 L p F P
.505 .664 .505 r
s
.607 .785 .568 r
.4405 .46951 m .44233 .43937 L .40525 .43843 L p F P
.505 .664 .505 r
s
.575 .734 .528 r
.40117 .5 m .40219 .53098 L .4405 .53049 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.44233 .56063 m .4405 .53049 L .40219 .53098 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.41034 .40863 m .40525 .43843 L .44233 .43937 L p F P
.505 .664 .505 r
s
.62 .806 .585 r
.44233 .43937 m .44539 .40995 L .41034 .40863 L p F P
.505 .664 .505 r
s
.556 .704 .504 r
.40219 .53098 m .40525 .56157 L .44233 .56063 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.44539 .59005 m .44233 .56063 L .40525 .56157 L p F P
.505 .664 .505 r
s
.546 .687 .495 r
.44233 .56063 m .44539 .59005 L .48166 .58939 L p F P
.505 .664 .505 r
s
.638 .83 .614 r
.55767 .43937 m .55461 .40995 L .51834 .41061 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.55461 .40995 m .55767 .43937 L .59475 .43843 L p F P
.505 .664 .505 r
s
.625 .808 .601 r
.59781 .46902 m .59475 .43843 L .55767 .43937 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.55767 .56063 m .55461 .59005 L .58966 .59137 L p F P
.505 .664 .505 r
s
.55 .693 .511 r
.58966 .59137 m .59475 .56157 L .55767 .56063 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.44966 .38165 m .44539 .40995 L .48166 .41061 L p F P
.505 .664 .505 r
s
.64 .836 .613 r
.48166 .41061 m .48309 .38245 L .44966 .38165 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.48309 .38245 m .48166 .41061 L .51834 .41061 L p F P
.505 .664 .505 r
s
.645 .844 .622 r
.51834 .41061 m .51691 .38245 L .48309 .38245 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.51691 .38245 m .51834 .41061 L .55461 .40995 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.48309 .61755 m .48166 .58939 L .44539 .59005 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.48166 .58939 m .48309 .61755 L .51691 .61755 L p F P
.505 .664 .505 r
s
.527 .658 .476 r
.51691 .61755 m .51834 .58939 L .48166 .58939 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.51834 .58939 m .51691 .61755 L .55034 .61835 L p F P
.505 .664 .505 r
s
.528 .66 .481 r
.55034 .61835 m .55461 .59005 L .51834 .58939 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.36601 .46829 m .36459 .5 L .40117 .5 L p F P
.505 .664 .505 r
s
.576 .739 .529 r
.40117 .5 m .40219 .46902 L .36601 .46829 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.40219 .53098 m .40117 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.59781 .46902 m .59883 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.59883 .5 m .59781 .53098 L .63399 .53171 L p F P
.505 .664 .505 r
s
.585 .748 .559 r
.63399 .53171 m .63541 .5 L .59883 .5 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.3703 .43702 m .36601 .46829 L .40219 .46902 L p F P
.505 .664 .505 r
s
.592 .765 .549 r
.40219 .46902 m .40525 .43843 L .3703 .43702 L p F P
.505 .664 .505 r
s
.557 .71 .506 r
.36459 .5 m .36601 .53171 L .40219 .53098 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.40525 .56157 m .40219 .53098 L .36601 .53171 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.59475 .43843 m .59781 .46902 L .63399 .46829 L p F P
.505 .664 .505 r
s
.603 .777 .581 r
.63541 .5 m .63399 .46829 L .59781 .46902 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.59781 .53098 m .59475 .56157 L .6297 .56298 L p F P
.505 .664 .505 r
s
.564 .715 .533 r
.6297 .56298 m .63399 .53171 L .59781 .53098 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.41746 .38006 m .41034 .40863 L .44539 .40995 L p F P
.505 .664 .505 r
s
.631 .825 .601 r
.44539 .40995 m .44966 .38165 L .41746 .38006 L p F P
.505 .664 .505 r
s
.533 .67 .478 r
.40525 .56157 m .41034 .59137 L .44539 .59005 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.44966 .61835 m .44539 .59005 L .41034 .59137 L p F P
.505 .664 .505 r
s
.52 .649 .465 r
.44539 .59005 m .44966 .61835 L .48309 .61755 L p F P
.505 .664 .505 r
s
.648 .848 .629 r
.55461 .40995 m .55034 .38165 L .51691 .38245 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.55034 .38165 m .55461 .40995 L .58966 .40863 L p F P
.505 .664 .505 r
s
.637 .83 .618 r
.59475 .43843 m .58966 .40863 L .55461 .40995 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.55461 .59005 m .55034 .61835 L .58254 .61994 L p F P
.505 .664 .505 r
s
.523 .653 .479 r
.58254 .61994 m .58966 .59137 L .55461 .59005 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.37741 .40665 m .3703 .43702 L .40525 .43843 L p F P
.505 .664 .505 r
s
.605 .788 .568 r
.40525 .43843 m .41034 .40863 L .37741 .40665 L p F P
.505 .664 .505 r
s
.536 .678 .481 r
.36601 .53171 m .3703 .56298 L .40525 .56157 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.41034 .59137 m .40525 .56157 L .3703 .56298 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.58966 .40863 m .59475 .43843 L .6297 .43702 L p F P
.505 .664 .505 r
s
.619 .802 .601 r
.63399 .46829 m .6297 .43702 L .59475 .43843 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.59475 .56157 m .58966 .59137 L .62259 .59335 L p F P
.505 .664 .505 r
s
.539 .678 .504 r
.62259 .59335 m .6297 .56298 L .59475 .56157 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.45516 .35491 m .44966 .38165 L .48309 .38245 L p F P
.505 .664 .505 r
s
.647 .852 .626 r
.48309 .38245 m .48493 .35578 L .45516 .35491 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.48493 .64422 m .48309 .61755 L .44966 .61835 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.48493 .35578 m .48309 .38245 L .51691 .38245 L p F P
.505 .664 .505 r
s
.653 .859 .635 r
.51691 .38245 m .51507 .35578 L .48493 .35578 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.48309 .61755 m .48493 .64422 L .51507 .64422 L p F P
.505 .664 .505 r
s
.496 .613 .441 r
.51507 .64422 m .51691 .61755 L .48309 .61755 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.51507 .35578 m .51691 .38245 L .55034 .38165 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.51691 .61755 m .51507 .64422 L .54484 .64509 L p F P
.505 .664 .505 r
s
.496 .613 .445 r
.54484 .64509 m .55034 .61835 L .51691 .61755 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.38734 .37767 m .37741 .40665 L .41034 .40863 L p F P
.505 .664 .505 r
s
.617 .809 .586 r
.41034 .40863 m .41746 .38006 L .38734 .37767 L p F P
.505 .664 .505 r
s
.512 .642 .453 r
.3703 .56298 m .37741 .59335 L .41034 .59137 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.41746 .61994 m .41034 .59137 L .37741 .59335 L p F P
.505 .664 .505 r
s
.506 .63 .447 r
.41034 .59137 m .41746 .61994 L .44966 .61835 L p F P
.505 .664 .505 r
s
.647 .848 .633 r
.58966 .40863 m .58254 .38006 L .55034 .38165 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.58254 .38006 m .58966 .40863 L .62259 .40665 L p F P
.505 .664 .505 r
s
.632 .824 .619 r
.6297 .43702 m .62259 .40665 L .58966 .40863 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.58966 .59137 m .58254 .61994 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .635 .47 r
.61266 .62233 m .62259 .59335 L .58966 .59137 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.42658 .35317 m .41746 .38006 L .44966 .38165 L p F P
.505 .664 .505 r
s
.639 .842 .615 r
.44966 .38165 m .45516 .35491 L .42658 .35317 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.45516 .64509 m .44966 .61835 L .41746 .61994 L p F P
.505 .664 .505 r
s
.488 .603 .43 r
.44966 .61835 m .45516 .64509 L .48493 .64422 L p F P
.505 .664 .505 r
s
.655 .863 .641 r
.55034 .38165 m .54484 .35491 L .51507 .35578 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.54484 .35491 m .55034 .38165 L .58254 .38006 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.55034 .61835 m .54484 .64509 L .57342 .64683 L p F P
.505 .664 .505 r
s
.49 .604 .442 r
.57342 .64683 m .58254 .61994 L .55034 .61835 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.33301 .46731 m .33118 .5 L .36459 .5 L p F P
.505 .664 .505 r
s
.55 .706 .5 r
.36459 .5 m .36601 .46829 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.36601 .53171 m .36459 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.63399 .46829 m .63541 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.63541 .5 m .63399 .53171 L .66699 .53269 L p F P
.505 .664 .505 r
s
.569 .727 .548 r
.66699 .53269 m .66882 .5 L .63541 .5 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.33851 .43514 m .33301 .46731 L .36601 .46829 L p F P
.505 .664 .505 r
s
.568 .735 .523 r
.36601 .46829 m .3703 .43702 L .33851 .43514 L p F P
.505 .664 .505 r
s
.53 .674 .475 r
.33118 .5 m .33301 .53269 L .36601 .53171 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.3703 .56298 m .36601 .53171 L .33301 .53269 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.6297 .43702 m .63399 .46829 L .66699 .46731 L p F P
.505 .664 .505 r
s
.589 .759 .574 r
.66882 .5 m .66699 .46731 L .63399 .46829 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.63399 .53171 m .6297 .56298 L .66149 .56486 L p F P
.505 .664 .505 r
s
.545 .691 .52 r
.66149 .56486 m .66699 .53269 L .63399 .53171 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.34762 .40403 m .33851 .43514 L .3703 .43702 L p F P
.505 .664 .505 r
s
.583 .761 .544 r
.3703 .43702 m .37741 .40665 L .34762 .40403 L p F P
.505 .664 .505 r
s
.507 .639 .447 r
.33301 .53269 m .33851 .56486 L .3703 .56298 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.37741 .59335 m .3703 .56298 L .33851 .56486 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.62259 .40665 m .6297 .43702 L .66149 .43514 L p F P
.505 .664 .505 r
s
.606 .787 .596 r
.66699 .46731 m .66149 .43514 L .6297 .43702 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.6297 .56298 m .62259 .59335 L .65238 .59597 L p F P
.505 .664 .505 r
s
.518 .65 .488 r
.65238 .59597 m .66149 .56486 L .6297 .56298 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.46188 .3302 m .45516 .35491 L .48493 .35578 L p F P
.505 .664 .505 r
s
.652 .864 .637 r
.48493 .35578 m .48717 .33107 L .46188 .3302 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.48717 .33107 m .48493 .35578 L .51507 .35578 L p F P
.505 .664 .505 r
s
.657 .87 .645 r
.51507 .35578 m .51283 .33107 L .48717 .33107 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.51283 .33107 m .51507 .35578 L .54484 .35491 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.48717 .66893 m .48493 .64422 L .45516 .64509 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.48493 .64422 m .48717 .66893 L .51283 .66893 L p F P
.505 .664 .505 r
s
.457 .556 .398 r
.51283 .66893 m .51507 .64422 L .48493 .64422 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.51507 .64422 m .51283 .66893 L .53812 .6698 L p F P
.505 .664 .505 r
s
.457 .556 .401 r
.53812 .6698 m .54484 .64509 L .51507 .64422 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.40002 .35058 m .38734 .37767 L .41746 .38006 L p F P
.505 .664 .505 r
s
.626 .826 .601 r
.41746 .38006 m .42658 .35317 L .40002 .35058 L p F P
.505 .664 .505 r
s
.484 .6 .421 r
.37741 .59335 m .38734 .62233 L .41746 .61994 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.42658 .64683 m .41746 .61994 L .38734 .62233 L p F P
.505 .664 .505 r
s
.474 .583 .412 r
.41746 .61994 m .42658 .64683 L .45516 .64509 L p F P
.505 .664 .505 r
s
.655 .863 .646 r
.58254 .38006 m .57342 .35317 L .54484 .35491 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.57342 .35317 m .58254 .38006 L .61266 .37767 L p F P
.505 .664 .505 r
s
.643 .844 .635 r
.62259 .40665 m .61266 .37767 L .58254 .38006 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.58254 .61994 m .57342 .64683 L .59998 .64942 L p F P
.505 .664 .505 r
s
.475 .584 .43 r
.59998 .64942 m .61266 .62233 L .58254 .61994 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.43769 .32847 m .42658 .35317 L .45516 .35491 L p F P
.505 .664 .505 r
s
.643 .854 .627 r
.45516 .35491 m .46188 .3302 L .43769 .32847 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.46188 .6698 m .45516 .64509 L .42658 .64683 L p F P
.505 .664 .505 r
s
.449 .546 .387 r
.45516 .64509 m .46188 .6698 L .48717 .66893 L p F P
.505 .664 .505 r
s
.659 .873 .651 r
.54484 .35491 m .53812 .3302 L .51283 .33107 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.53812 .3302 m .54484 .35491 L .57342 .35317 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.54484 .64509 m .53812 .6698 L .56231 .67153 L p F P
.505 .664 .505 r
s
.449 .545 .396 r
.56231 .67153 m .57342 .64683 L .54484 .64509 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.36027 .37452 m .34762 .40403 L .37741 .40665 L p F P
.505 .664 .505 r
s
.596 .784 .563 r
.37741 .40665 m .38734 .37767 L .36027 .37452 L p F P
.505 .664 .505 r
s
.48 .599 .417 r
.33851 .56486 m .34762 .59597 L .37741 .59335 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.38734 .62233 m .37741 .59335 L .34762 .59597 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.61266 .37767 m .62259 .40665 L .65238 .40403 L p F P
.505 .664 .505 r
s
.621 .812 .615 r
.66149 .43514 m .65238 .40403 L .62259 .40665 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.62259 .59335 m .61266 .62233 L .63973 .62548 L p F P
.505 .664 .505 r
s
.486 .603 .451 r
.63973 .62548 m .65238 .59597 L .62259 .59335 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.41536 .32591 m .40002 .35058 L .42658 .35317 L p F P
.505 .664 .505 r
s
.63 .839 .613 r
.42658 .35317 m .43769 .32847 L .41536 .32591 L p F P
.505 .664 .505 r
s
.45 .551 .384 r
.38734 .62233 m .40002 .64942 L .42658 .64683 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.43769 .67153 m .42658 .64683 L .40002 .64942 L p F P
.505 .664 .505 r
s
.434 .526 .368 r
.42658 .64683 m .43769 .67153 L .46188 .6698 L p F P
.505 .664 .505 r
s
.658 .873 .655 r
.57342 .35317 m .56231 .32847 L .53812 .3302 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.56231 .32847 m .57342 .35317 L .59998 .35058 L p F P
.505 .664 .505 r
s
.65 .859 .647 r
.61266 .37767 m .59998 .35058 L .57342 .35317 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.57342 .64683 m .56231 .67153 L .58464 .67409 L p F P
.505 .664 .505 r
s
.432 .522 .382 r
.58464 .67409 m .59998 .64942 L .57342 .64683 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.37636 .34717 m .36027 .37452 L .38734 .37767 L p F P
.505 .664 .505 r
s
.606 .803 .58 r
.38734 .37767 m .40002 .35058 L .37636 .34717 L p F P
.505 .664 .505 r
s
.45 .554 .382 r
.34762 .59597 m .36027 .62548 L .38734 .62233 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.40002 .64942 m .38734 .62233 L .36027 .62548 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.59998 .35058 m .61266 .37767 L .63973 .37452 L p F P
.505 .664 .505 r
s
.632 .832 .631 r
.65238 .40403 m .63973 .37452 L .61266 .37767 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.61266 .62233 m .59998 .64942 L .62364 .65283 L p F P
.505 .664 .505 r
s
.448 .548 .408 r
.62364 .65283 m .63973 .62548 L .61266 .62233 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.30442 .46609 m .30218 .5 L .33118 .5 L p F P
.505 .664 .505 r
s
.51 .655 .456 r
.33118 .5 m .33301 .46731 L .30442 .46609 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.33301 .53269 m .33118 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.66699 .46731 m .66882 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.66882 .5 m .66699 .53269 L .69558 .53391 L p F P
.505 .664 .505 r
s
.538 .688 .526 r
.69558 .53391 m .69782 .5 L .66882 .5 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.46978 .30806 m .46188 .3302 L .48717 .33107 L p F P
.505 .664 .505 r
s
.65 .869 .644 r
.48717 .33107 m .48982 .30885 L .46978 .30806 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.48982 .30885 m .48717 .33107 L .51283 .33107 L p F P
.505 .664 .505 r
s
.655 .875 .651 r
.51283 .33107 m .51018 .30885 L .48982 .30885 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.51018 .30885 m .51283 .33107 L .53812 .3302 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.51018 .69115 m .51283 .66893 L .48717 .66893 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.51283 .66893 m .51018 .69115 L .53022 .69194 L p F P
.505 .664 .505 r
s
.405 .484 .346 r
.53022 .69194 m .53812 .6698 L .51283 .66893 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.48982 .69115 m .48717 .66893 L .46188 .6698 L p F P
.505 .664 .505 r
s
.406 .485 .344 r
.48717 .66893 m .48982 .69115 L .51018 .69115 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.31108 .43281 m .30442 .46609 L .33301 .46731 L p F P
.505 .664 .505 r
s
.53 .688 .483 r
.33301 .46731 m .33851 .43514 L .31108 .43281 L p F P
.505 .664 .505 r
s
.486 .618 .427 r
.30218 .5 m .30442 .53391 L .33301 .53269 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.33851 .56486 m .33301 .53269 L .30442 .53391 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.66149 .43514 m .66699 .46731 L .69558 .46609 L p F P
.505 .664 .505 r
s
.562 .725 .555 r
.69782 .5 m .69558 .46609 L .66699 .46731 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.66699 .53269 m .66149 .56486 L .68892 .56719 L p F P
.505 .664 .505 r
s
.511 .647 .494 r
.68892 .56719 m .69558 .53391 L .66699 .53269 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.3375 .43192 m
.34023 .42925 L
s
.5 Mabswid
.548 .718 .508 r
.3221 .40078 m .31108 .43281 L .33851 .43514 L p F P
.505 .664 .505 r
s
.548 .718 .508 r
.33851 .43514 m .34762 .40403 L .3221 .40078 L p F P
.505 .664 .505 r
s
.46 .578 .396 r
.30442 .53391 m .31108 .56719 L .33851 .56486 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.34762 .59597 m .33851 .56486 L .31108 .56719 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.45071 .30652 m .43769 .32847 L .46188 .3302 L p F P
.505 .664 .505 r
s
.642 .859 .634 r
.46188 .3302 m .46978 .30806 L .45071 .30652 L p F P
.505 .664 .505 r
s
.656 .878 .656 r
.53812 .3302 m .53022 .30806 L .51018 .30885 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.53022 .30806 m .53812 .3302 L .56231 .32847 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.65238 .40403 m .66149 .43514 L .68892 .43281 L p F P
.505 .664 .505 r
s
.581 .757 .58 r
.69558 .46609 m .68892 .43281 L .66149 .43514 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.46978 .69194 m .46188 .6698 L .43769 .67153 L p F P
.505 .664 .505 r
s
.399 .475 .333 r
.46188 .6698 m .46978 .69194 L .48982 .69115 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.53812 .6698 m .53022 .69194 L .54929 .69348 L p F P
.505 .664 .505 r
s
.396 .472 .339 r
.54929 .69348 m .56231 .67153 L .53812 .6698 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.66149 .56486 m .65238 .59597 L .6779 .59922 L p F P
.505 .664 .505 r
s
.481 .601 .457 r
.6779 .59922 m .68892 .56719 L .66149 .56486 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.3957 .32256 m .37636 .34717 L .40002 .35058 L p F P
.505 .664 .505 r
s
.611 .817 .594 r
.40002 .35058 m .41536 .32591 L .3957 .32256 L p F P
.505 .664 .505 r
s
.414 .502 .343 r
.36027 .62548 m .37636 .65283 L .40002 .64942 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.41536 .67409 m .40002 .64942 L .37636 .65283 L p F P
.505 .664 .505 r
s
.409 .492 .34 r
.40002 .64942 m .41536 .67409 L .43769 .67153 L p F P
.505 .664 .505 r
s
.653 .869 .656 r
.59998 .35058 m .58464 .32591 L .56231 .32847 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.58464 .32591 m .59998 .35058 L .62364 .34717 L p F P
.505 .664 .505 r
s
.639 .848 .644 r
.63973 .37452 m .62364 .34717 L .59998 .35058 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.59998 .64942 m .58464 .67409 L .6043 .67744 L p F P
.505 .664 .505 r
s
.403 .483 .357 r
.6043 .67744 m .62364 .65283 L .59998 .64942 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.33733 .37063 m .3221 .40078 L .34762 .40403 L p F P
.505 .664 .505 r
s
.563 .744 .53 r
.34762 .40403 m .36027 .37452 L .33733 .37063 L p F P
.505 .664 .505 r
s
.431 .534 .363 r
.31108 .56719 m .3221 .59922 L .34762 .59597 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.36027 .62548 m .34762 .59597 L .3221 .59922 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.63973 .37452 m .65238 .40403 L .6779 .40078 L p F P
.505 .664 .505 r
s
.598 .785 .602 r
.68892 .43281 m .6779 .40078 L .65238 .40403 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.65238 .59597 m .63973 .62548 L .66267 .62937 L p F P
.505 .664 .505 r
s
.445 .549 .416 r
.66267 .62937 m .6779 .59922 L .65238 .59597 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43326 .30424 m .41536 .32591 L .43769 .32847 L p F P
.505 .664 .505 r
s
.629 .845 .621 r
.43769 .32847 m .45071 .30652 L .43326 .30424 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.45071 .69348 m .43769 .67153 L .41536 .67409 L p F P
.505 .664 .505 r
s
.383 .454 .315 r
.43769 .67153 m .45071 .69348 L .46978 .69194 L p F P
.505 .664 .505 r
s
.655 .877 .659 r
.56231 .32847 m .54929 .30652 L .53022 .30806 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.54929 .30652 m .56231 .32847 L .58464 .32591 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56231 .67153 m .54929 .69348 L .56674 .69576 L p F P
.505 .664 .505 r
s
.378 .447 .324 r
.56674 .69576 m .58464 .67409 L .56231 .67153 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.35657 .34299 m .33733 .37063 L .36027 .37452 L p F P
.505 .664 .505 r
s
.575 .766 .55 r
.36027 .37452 m .37636 .34717 L .35657 .34299 L p F P
.505 .664 .505 r
s
.398 .485 .326 r
.3221 .59922 m .33733 .62937 L .36027 .62548 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.37636 .65283 m .36027 .62548 L .33733 .62937 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.62364 .34717 m .63973 .37452 L .66267 .37063 L p F P
.505 .664 .505 r
s
.611 .808 .62 r
.6779 .40078 m .66267 .37063 L .63973 .37452 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.63973 .62548 m .62364 .65283 L .64343 .65701 L p F P
.505 .664 .505 r
s
.405 .49 .369 r
.64343 .65701 m .66267 .62937 L .63973 .62548 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.47883 .28911 m .46978 .30806 L .48982 .30885 L p F P
.505 .664 .505 r
s
.639 .862 .642 r
.48982 .30885 m .49286 .28971 L .47883 .28911 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.49286 .28971 m .48982 .30885 L .51018 .30885 L p F P
.505 .664 .505 r
s
.643 .868 .648 r
.51018 .30885 m .50714 .28971 L .49286 .28971 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.50714 .28971 m .51018 .30885 L .53022 .30806 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.49286 .71029 m .48982 .69115 L .46978 .69194 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.48982 .69115 m .49286 .71029 L .50714 .71029 L p F P
.505 .664 .505 r
s
.339 .391 .273 r
.50714 .71029 m .51018 .69115 L .48982 .69115 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.51018 .69115 m .50714 .71029 L .52117 .71089 L p F P
.505 .664 .505 r
s
.338 .39 .274 r
.52117 .71089 m .53022 .69194 L .51018 .69115 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41809 .30128 m .3957 .32256 L .41536 .32591 L p F P
.505 .664 .505 r
s
.611 .823 .603 r
.41536 .32591 m .43326 .30424 L .41809 .30128 L p F P
.505 .664 .505 r
s
.649 .871 .658 r
.58464 .32591 m .56674 .30424 L .54929 .30652 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.56674 .30424 m .58464 .32591 L .6043 .32256 L p F P
.505 .664 .505 r
s
.642 .858 .652 r
.62364 .34717 m .6043 .32256 L .58464 .32591 L p F P
.505 .664 .505 r
s
.377 .448 .306 r
.37636 .65283 m .3957 .67744 L .41536 .67409 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.43326 .69576 m .41536 .67409 L .3957 .67744 L p F P
.505 .664 .505 r
s
.363 .426 .293 r
.41536 .67409 m .43326 .69576 L .45071 .69348 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58464 .67409 m .56674 .69576 L .58191 .69872 L p F P
.505 .664 .505 r
s
.349 .406 .297 r
.58191 .69872 m .6043 .67744 L .58464 .67409 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46555 .28792 m .45071 .30652 L .46978 .30806 L p F P
.505 .664 .505 r
s
.631 .853 .633 r
.46978 .30806 m .47883 .28911 L .46555 .28792 L p F P
.505 .664 .505 r
s
.644 .87 .652 r
.53022 .30806 m .52117 .28911 L .50714 .28971 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.52117 .28911 m .53022 .30806 L .54929 .30652 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.47883 .71089 m .46978 .69194 L .45071 .69348 L p F P
.505 .664 .505 r
s
.337 .389 .27 r
.46978 .69194 m .47883 .71089 L .49286 .71029 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53022 .69194 m .52117 .71089 L .53445 .71208 L p F P
.505 .664 .505 r
s
.329 .377 .267 r
.53445 .71208 m .54929 .69348 L .53022 .69194 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37952 .31849 m .35657 .34299 L .37636 .34717 L p F P
.505 .664 .505 r
s
.582 .783 .566 r
.37636 .34717 m .3957 .32256 L .37952 .31849 L p F P
.505 .664 .505 r
s
.374 .448 .304 r
.33733 .62937 m .35657 .65701 L .37636 .65283 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.3957 .67744 m .37636 .65283 L .35657 .65701 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.6043 .32256 m .62364 .34717 L .64343 .34299 L p F P
.505 .664 .505 r
s
.619 .825 .633 r
.66267 .37063 m .64343 .34299 L .62364 .34717 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62364 .65283 m .6043 .67744 L .62048 .68151 L p F P
.505 .664 .505 r
s
.358 .423 .316 r
.62048 .68151 m .64343 .65701 L .62364 .65283 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.28166 .46465 m .27906 .5 L .30218 .5 L p F P
.505 .664 .505 r
s
.443 .57 .388 r
.30218 .5 m .30442 .46609 L .28166 .46465 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.30442 .53391 m .30218 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.69558 .46609 m .69782 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.69782 .5 m .69558 .53391 L .71834 .53535 L p F P
.505 .664 .505 r
s
.483 .618 .481 r
.71834 .53535 m .72094 .5 L .69782 .5 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.28941 .43004 m .28166 .46465 L .30442 .46609 L p F P
.505 .664 .505 r
s
.468 .61 .42 r
.30442 .46609 m .31108 .43281 L .28941 .43004 L p F P
.505 .664 .505 r
s
.416 .527 .354 r
.27906 .5 m .28166 .53535 L .30442 .53391 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.31108 .56719 m .30442 .53391 L .28166 .53535 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.68892 .43281 m .69558 .46609 L .71834 .46465 L p F P
.505 .664 .505 r
s
.511 .661 .515 r
.72094 .5 m .71834 .46465 L .69558 .46609 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.69558 .53391 m .68892 .56719 L .71059 .56996 L p F P
.505 .664 .505 r
s
.452 .57 .444 r
.71059 .56996 m .71834 .53535 L .69558 .53391 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45351 .28618 m .43326 .30424 L .45071 .30652 L p F P
.505 .664 .505 r
s
.619 .839 .621 r
.45071 .30652 m .46555 .28792 L .45351 .28618 L p F P
.505 .664 .505 r
s
.642 .868 .654 r
.54929 .30652 m .53445 .28792 L .52117 .28911 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.53445 .28792 m .54929 .30652 L .56674 .30424 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.46555 .71208 m .45071 .69348 L .43326 .69576 L p F P
.505 .664 .505 r
s
.331 .379 .265 r
.45071 .69348 m .46555 .71208 L .47883 .71089 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54929 .69348 m .53445 .71208 L .54649 .71382 L p F P
.505 .664 .505 r
s
.31 .352 .251 r
.54649 .71382 m .56674 .69576 L .54929 .69348 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.30216 .39695 m .28941 .43004 L .31108 .43281 L p F P
.505 .664 .505 r
s
.491 .646 .45 r
.31108 .43281 m .3221 .40078 L .30216 .39695 L p F P
.505 .664 .505 r
s
.388 .483 .321 r
.28166 .53535 m .28941 .56996 L .31108 .56719 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.3221 .59922 m .31108 .56719 L .28941 .56996 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.6779 .40078 m .68892 .43281 L .71059 .43004 L p F P
.505 .664 .505 r
s
.534 .699 .545 r
.71834 .46465 m .71059 .43004 L .68892 .43281 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.68892 .56719 m .6779 .59922 L .69784 .60305 L p F P
.505 .664 .505 r
s
.417 .518 .402 r
.69784 .60305 m .71059 .56996 L .68892 .56719 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3197 .36608 m .30216 .39695 L .3221 .40078 L p F P
.505 .664 .505 r
s
.51 .679 .478 r
.3221 .40078 m .33733 .37063 L .3197 .36608 L p F P
.505 .664 .505 r
s
.37 .453 .304 r
.28941 .56996 m .30216 .60305 L .3221 .59922 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.33733 .62937 m .3221 .59922 L .30216 .60305 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.66267 .37063 m .6779 .40078 L .69784 .39695 L p F P
.505 .664 .505 r
s
.554 .733 .571 r
.71059 .43004 m .69784 .39695 L .6779 .40078 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6779 .59922 m .66267 .62937 L .6803 .63392 L p F P
.505 .664 .505 r
s
.379 .461 .356 r
.6803 .63392 m .69784 .60305 L .6779 .59922 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.40584 .29772 m .37952 .31849 L .3957 .32256 L p F P
.505 .664 .505 r
s
.584 .792 .578 r
.3957 .32256 m .41809 .30128 L .40584 .29772 L p F P
.505 .664 .505 r
s
.345 .404 .279 r
.35657 .65701 m .37952 .68151 L .3957 .67744 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.41809 .69872 m .3957 .67744 L .37952 .68151 L p F P
.505 .664 .505 r
s
.342 .397 .275 r
.3957 .67744 m .41809 .69872 L .43326 .69576 L p F P
.505 .664 .505 r
s
.637 .859 .654 r
.6043 .32256 m .58191 .30128 L .56674 .30424 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.58191 .30128 m .6043 .32256 L .62048 .31849 L p F P
.505 .664 .505 r
s
.622 .836 .641 r
.64343 .34299 m .62048 .31849 L .6043 .32256 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.6043 .67744 m .58191 .69872 L .59416 .70228 L p F P
.505 .664 .505 r
s
.305 .347 .256 r
.59416 .70228 m .62048 .68151 L .6043 .67744 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.44321 .28394 m .41809 .30128 L .43326 .30424 L p F P
.505 .664 .505 r
s
.601 .819 .605 r
.43326 .30424 m .45351 .28618 L .44321 .28394 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.45351 .71382 m .43326 .69576 L .41809 .69872 L p F P
.505 .664 .505 r
s
.318 .362 .254 r
.43326 .69576 m .45351 .71382 L .46555 .71208 L p F P
.505 .664 .505 r
s
.635 .861 .652 r
.56674 .30424 m .54649 .28618 L .53445 .28792 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.54649 .28618 m .56674 .30424 L .58191 .30128 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.56674 .69576 m .54649 .71382 L .55679 .71606 L p F P
.505 .664 .505 r
s
.282 .314 .225 r
.55679 .71606 m .58191 .69872 L .56674 .69576 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.34168 .33814 m .3197 .36608 L .33733 .37063 L p F P
.505 .664 .505 r
s
.526 .707 .504 r
.33733 .37063 m .35657 .34299 L .34168 .33814 L p F P
.505 .664 .505 r
s
.349 .419 .285 r
.30216 .60305 m .3197 .63392 L .33733 .62937 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.35657 .65701 m .33733 .62937 L .3197 .63392 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.64343 .34299 m .66267 .37063 L .6803 .36608 L p F P
.505 .664 .505 r
s
.57 .76 .592 r
.69784 .39695 m .6803 .36608 L .66267 .37063 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.66267 .62937 m .64343 .65701 L .65832 .66186 L p F P
.505 .664 .505 r
s
.337 .4 .307 r
.65832 .66186 m .6803 .63392 L .66267 .62937 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.48894 .274 m .47883 .28911 L .49286 .28971 L p F P
.505 .664 .505 r
s
.611 .836 .626 r
.49286 .28971 m .49626 .27434 L .48894 .274 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.49626 .27434 m .49286 .28971 L .50714 .28971 L p F P
.505 .664 .505 r
s
.614 .84 .631 r
.50714 .28971 m .50374 .27434 L .49626 .27434 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.50374 .27434 m .50714 .28971 L .52117 .28911 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.49626 .72566 m .49286 .71029 L .47883 .71089 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.49286 .71029 m .49626 .72566 L .50374 .72566 L p F P
.505 .664 .505 r
s
.276 .303 .218 r
.50374 .72566 m .50714 .71029 L .49286 .71029 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.50714 .71029 m .50374 .72566 L .51106 .726 L p F P
.505 .664 .505 r
s
.272 .298 .215 r
.51106 .726 m .52117 .71089 L .50714 .71029 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.48205 .27334 m .46555 .28792 L .47883 .28911 L p F P
.505 .664 .505 r
s
.604 .828 .619 r
.47883 .28911 m .48894 .274 L .48205 .27334 L p F P
.505 .664 .505 r
s
.615 .841 .633 r
.52117 .28911 m .51106 .274 L .50374 .27434 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.51106 .274 m .52117 .28911 L .53445 .28792 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.48894 .726 m .47883 .71089 L .46555 .71208 L p F P
.505 .664 .505 r
s
.275 .301 .217 r
.47883 .71089 m .48894 .726 L .49626 .72566 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.52117 .71089 m .51106 .726 L .51795 .72666 L p F P
.505 .664 .505 r
s
.264 .286 .208 r
.51795 .72666 m .53445 .71208 L .52117 .71089 L p F P
.505 .664 .505 r
s
.324 .381 .263 r
.3197 .63392 m .34168 .66186 L .35657 .65701 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.37952 .68151 m .35657 .65701 L .34168 .66186 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.36767 .3138 m .34168 .33814 L .35657 .34299 L p F P
.505 .664 .505 r
s
.538 .73 .525 r
.35657 .34299 m .37952 .31849 L .36767 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.62048 .31849 m .64343 .34299 L .65832 .33814 L p F P
.505 .664 .505 r
s
.581 .781 .608 r
.6803 .36608 m .65832 .33814 L .64343 .34299 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.64343 .65701 m .62048 .68151 L .63233 .6862 L p F P
.505 .664 .505 r
s
.292 .334 .254 r
.63233 .6862 m .65832 .66186 L .64343 .65701 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.47588 .27237 m .45351 .28618 L .46555 .28792 L p F P
.505 .664 .505 r
s
.594 .816 .609 r
.46555 .28792 m .48205 .27334 L .47588 .27237 L p F P
.505 .664 .505 r
s
.611 .838 .633 r
.53445 .28792 m .51795 .27334 L .51106 .274 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.51795 .27334 m .53445 .28792 L .54649 .28618 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.48205 .72666 m .46555 .71208 L .45351 .71382 L p F P
.505 .664 .505 r
s
.269 .293 .213 r
.46555 .71208 m .48205 .72666 L .48894 .726 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.53445 .71208 m .51795 .72666 L .52412 .72763 L p F P
.505 .664 .505 r
s
.25 .268 .197 r
.52412 .72763 m .54649 .71382 L .53445 .71208 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.43508 .28127 m .40584 .29772 L .41809 .30128 L p F P
.505 .664 .505 r
s
.577 .791 .583 r
.41809 .30128 m .44321 .28394 L .43508 .28127 L p F P
.505 .664 .505 r
s
.311 .354 .249 r
.37952 .68151 m .40584 .70228 L .41809 .69872 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.44321 .71606 m .41809 .69872 L .40584 .70228 L p F P
.505 .664 .505 r
s
.298 .334 .237 r
.41809 .69872 m .44321 .71606 L .45351 .71382 L p F P
.505 .664 .505 r
s
.623 .848 .645 r
.58191 .30128 m .55679 .28394 L .54649 .28618 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.55679 .28394 m .58191 .30128 L .59416 .29772 L p F P
.505 .664 .505 r
s
.617 .837 .642 r
.62048 .31849 m .59416 .29772 L .58191 .30128 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.58191 .69872 m .55679 .71606 L .56492 .71873 L p F P
.505 .664 .505 r
s
.25 .27 .197 r
.56492 .71873 m .59416 .70228 L .58191 .69872 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.39716 .29366 m .36767 .3138 L .37952 .31849 L p F P
.505 .664 .505 r
s
.544 .745 .543 r
.37952 .31849 m .40584 .29772 L .39716 .29366 L p F P
.505 .664 .505 r
s
.297 .339 .238 r
.34168 .66186 m .36767 .6862 L .37952 .68151 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.40584 .70228 m .37952 .68151 L .36767 .6862 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.59416 .29772 m .62048 .31849 L .63233 .3138 L p F P
.505 .664 .505 r
s
.586 .795 .617 r
.65832 .33814 m .63233 .3138 L .62048 .31849 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.62048 .68151 m .59416 .70228 L .60284 .70634 L p F P
.505 .664 .505 r
s
.243 .264 .197 r
.60284 .70634 m .63233 .6862 L .62048 .68151 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.47068 .27114 m .44321 .28394 L .45351 .28618 L p F P
.505 .664 .505 r
s
.579 .799 .596 r
.45351 .28618 m .47588 .27237 L .47068 .27114 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.47588 .72763 m .45351 .71382 L .44321 .71606 L p F P
.505 .664 .505 r
s
.259 .278 .204 r
.45351 .71382 m .47588 .72763 L .48205 .72666 L p F P
.505 .664 .505 r
s
.605 .83 .63 r
.54649 .28618 m .52412 .27237 L .51795 .27334 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.52412 .27237 m .54649 .28618 L .55679 .28394 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.54649 .71382 m .52412 .72763 L .52932 .72886 L p F P
.505 .664 .505 r
s
.232 .243 .182 r
.52932 .72886 m .55679 .71606 L .54649 .71382 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.26636 .46299 m .26345 .5 L .27906 .5 L p F P
.505 .664 .505 r
s
.338 .436 .286 r
.27906 .5 m .28166 .46465 L .26636 .46299 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.28166 .53535 m .27906 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.71834 .46465 m .72094 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.72094 .5 m .71834 .53535 L .73364 .53701 L p F P
.505 .664 .505 r
s
.383 .49 .396 r
.73364 .53701 m .73655 .5 L .72094 .5 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.27502 .4269 m .26636 .46299 L .28166 .46465 L p F P
.505 .664 .505 r
s
.364 .478 .317 r
.28166 .46465 m .28941 .43004 L .27502 .4269 L p F P
.505 .664 .505 r
s
.323 .408 .271 r
.26345 .5 m .26636 .53701 L .28166 .53535 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.28941 .56996 m .28166 .53535 L .26636 .53701 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.71059 .43004 m .71834 .46465 L .73364 .46299 L p F P
.505 .664 .505 r
s
.416 .541 .437 r
.73655 .5 m .73364 .46299 L .71834 .46465 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.71834 .53535 m .71059 .56996 L .72498 .5731 L p F P
.505 .664 .505 r
s
.348 .435 .352 r
.72498 .5731 m .73364 .53701 L .71834 .53535 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28923 .39261 m .27502 .4269 L .28941 .43004 L p F P
.505 .664 .505 r
s
.394 .526 .357 r
.28941 .43004 m .30216 .39695 L .28923 .39261 L p F P
.505 .664 .505 r
s
.306 .378 .254 r
.26636 .53701 m .27502 .5731 L .28941 .56996 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.30216 .60305 m .28941 .56996 L .27502 .5731 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.69784 .39695 m .71059 .43004 L .72498 .4269 L p F P
.505 .664 .505 r
s
.446 .589 .474 r
.73364 .46299 m .72498 .4269 L .71059 .43004 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71059 .56996 m .69784 .60305 L .71077 .60739 L p F P
.505 .664 .505 r
s
.311 .379 .306 r
.71077 .60739 m .72498 .5731 L .71059 .56996 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30862 .36096 m .28923 .39261 L .30216 .39695 L p F P
.505 .664 .505 r
s
.422 .571 .395 r
.30216 .39695 m .3197 .36608 L .30862 .36096 L p F P
.505 .664 .505 r
s
.288 .346 .237 r
.27502 .5731 m .28923 .60739 L .30216 .60305 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.3197 .63392 m .30216 .60305 L .28923 .60739 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.6803 .36608 m .69784 .39695 L .71077 .39261 L p F P
.505 .664 .505 r
s
.473 .633 .506 r
.72498 .4269 m .71077 .39261 L .69784 .39695 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69784 .60305 m .6803 .63392 L .69138 .63904 L p F P
.505 .664 .505 r
s
.273 .321 .259 r
.69138 .63904 m .71077 .60739 L .69784 .60305 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.42953 .27826 m .39716 .29366 L .40584 .29772 L p F P
.505 .664 .505 r
s
.544 .752 .554 r
.40584 .29772 m .43508 .28127 L .42953 .27826 L p F P
.505 .664 .505 r
s
.266 .293 .211 r
.36767 .6862 m .39716 .70634 L .40584 .70228 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.43508 .71873 m .40584 .70228 L .39716 .70634 L p F P
.505 .664 .505 r
s
.27 .295 .214 r
.40584 .70228 m .43508 .71873 L .44321 .71606 L p F P
.505 .664 .505 r
s
.604 .827 .633 r
.59416 .29772 m .56492 .28127 L .55679 .28394 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.56492 .28127 m .59416 .29772 L .60284 .29366 L p F P
.505 .664 .505 r
s
.584 .8 .619 r
.63233 .3138 m .60284 .29366 L .59416 .29772 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.59416 .70228 m .56492 .71873 L .57047 .72174 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.57047 .72174 m .60284 .70634 L .59416 .70228 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.46668 .26969 m .43508 .28127 L .44321 .28394 L p F P
.505 .664 .505 r
s
.561 .777 .579 r
.44321 .28394 m .47068 .27114 L .46668 .26969 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.47068 .72886 m .44321 .71606 L .43508 .71873 L p F P
.505 .664 .505 r
s
.243 .257 .19 r
.44321 .71606 m .47068 .72886 L .47588 .72763 L p F P
.505 .664 .505 r
s
.594 .818 .623 r
.55679 .28394 m .52932 .27114 L .52412 .27237 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.52932 .27114 m .55679 .28394 L .56492 .28127 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.55679 .71606 m .52932 .72886 L .53332 .73031 L p F P
.505 .664 .505 r
s
.211 .216 .165 r
.53332 .73031 m .56492 .71873 L .55679 .71606 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.33273 .33273 m .30862 .36096 L .3197 .36608 L p F P
.505 .664 .505 r
s
.448 .612 .431 r
.3197 .36608 m .34168 .33814 L .33273 .33273 L p F P
.505 .664 .505 r
s
.268 .313 .218 r
.28923 .60739 m .30862 .63904 L .3197 .63392 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.34168 .66186 m .3197 .63392 L .30862 .63904 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.65832 .33814 m .6803 .36608 L .69138 .36096 L p F P
.505 .664 .505 r
s
.495 .67 .534 r
.71077 .39261 m .69138 .36096 L .6803 .36608 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.6803 .63392 m .65832 .66186 L .66727 .66727 L p F P
.505 .664 .505 r
s
.234 .263 .211 r
.66727 .66727 m .69138 .63904 L .6803 .63392 L p F P
.505 .664 .505 r
s
.554 .773 .585 r
.49626 .27434 m .5 .26345 L .48894 .274 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50374 .27434 m .5 .26345 L .49626 .27434 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.51106 .274 m .5 .26345 L .50374 .27434 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50374 .72566 L .49626 .72566 L closepath p F P
.505 .664 .505 r
s
.201 .207 .158 r
.5 .73655 m .51106 .726 L .50374 .72566 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49626 .72566 L .48894 .726 L closepath p F P
.505 .664 .505 r
s
.551 .769 .581 r
.48894 .274 m .5 .26345 L .48205 .27334 L closepath p F P
.505 .664 .505 r
s
.554 .773 .586 r
.51795 .27334 m .5 .26345 L .51106 .274 L closepath p F P
.505 .664 .505 r
s
.2 .206 .157 r
.5 .73655 m .48894 .726 L .48205 .72666 L closepath p F P
.505 .664 .505 r
s
.199 .205 .156 r
.5 .73655 m .51795 .72666 L .51106 .726 L closepath p F P
.505 .664 .505 r
s
.47 .648 .464 r
.36096 .30862 m .33273 .33273 L .34168 .33814 L p F P
.505 .664 .505 r
s
.47 .648 .464 r
.34168 .33814 m .36767 .3138 L .36096 .30862 L p F P
.505 .664 .505 r
s
.248 .279 .199 r
.30862 .63904 m .33273 .66727 L .34168 .66186 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.36767 .6862 m .34168 .66186 L .33273 .66727 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.63233 .3138 m .65832 .33814 L .66727 .33273 L p F P
.505 .664 .505 r
s
.514 .701 .556 r
.69138 .36096 m .66727 .33273 L .65832 .33814 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.65832 .66186 m .63233 .6862 L .63904 .69138 L p F P
.505 .664 .505 r
s
.197 .209 .164 r
.63904 .69138 m .66727 .66727 L .65832 .66186 L p F P
.505 .664 .505 r
s
.546 .763 .576 r
.48205 .27334 m .5 .26345 L .47588 .27237 L closepath p F P
.505 .664 .505 r
s
.55 .768 .584 r
.52412 .27237 m .5 .26345 L .51795 .27334 L closepath p F P
.505 .664 .505 r
s
.196 .202 .154 r
.5 .73655 m .52412 .72763 L .51795 .72666 L closepath p F P
.505 .664 .505 r
s
.198 .204 .155 r
.5 .73655 m .48205 .72666 L .47588 .72763 L closepath p F P
.505 .664 .505 r
s
.537 .749 .559 r
.46407 .26807 m .42953 .27826 L .43508 .28127 L p F P
.505 .664 .505 r
s
.537 .749 .559 r
.43508 .28127 m .46668 .26969 L .46407 .26807 L p F P
.505 .664 .505 r
s
.232 .244 .182 r
.39716 .70634 m .42953 .72174 L .43508 .71873 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.46668 .73031 m .43508 .71873 L .42953 .72174 L p F P
.505 .664 .505 r
s
.221 .228 .172 r
.43508 .71873 m .46668 .73031 L .47068 .72886 L p F P
.505 .664 .505 r
s
.578 .8 .612 r
.56492 .28127 m .53332 .26969 L .52932 .27114 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.53332 .26969 m .56492 .28127 L .57047 .27826 L p F P
.505 .664 .505 r
s
.575 .794 .613 r
.60284 .29366 m .57047 .27826 L .56492 .28127 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.56492 .71873 m .53332 .73031 L .53593 .73193 L p F P
.505 .664 .505 r
s
.195 .202 .153 r
.53593 .73193 m .57047 .72174 L .56492 .71873 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.39261 .28923 m .36096 .30862 L .36767 .3138 L p F P
.505 .664 .505 r
s
.488 .678 .492 r
.36767 .3138 m .39716 .29366 L .39261 .28923 L p F P
.505 .664 .505 r
s
.226 .244 .18 r
.33273 .66727 m .36096 .69138 L .36767 .6862 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.39716 .70634 m .36767 .6862 L .36096 .69138 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.60284 .29366 m .63233 .3138 L .63904 .30862 L p F P
.505 .664 .505 r
s
.527 .725 .572 r
.66727 .33273 m .63904 .30862 L .63233 .3138 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.63233 .6862 m .60284 .70634 L .60739 .71077 L p F P
.505 .664 .505 r
s
.182 .19 .144 r
.60739 .71077 m .63904 .69138 L .63233 .6862 L p F P
.505 .664 .505 r
s
.539 .755 .57 r
.47588 .27237 m .5 .26345 L .47068 .27114 L closepath p F P
.505 .664 .505 r
s
.545 .762 .58 r
.52932 .27114 m .5 .26345 L .52412 .27237 L closepath p F P
.505 .664 .505 r
s
.194 .2 .152 r
.5 .73655 m .47588 .72763 L .47068 .72886 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.5 .73655 m .52932 .72886 L .52412 .72763 L closepath p F P
.505 .664 .505 r
s
.501 .701 .516 r
.4269 .27502 m .39261 .28923 L .39716 .29366 L p F P
.505 .664 .505 r
s
.501 .701 .516 r
.39716 .29366 m .42953 .27826 L .4269 .27502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.36096 .69138 m .39261 .71077 L .39716 .70634 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.42953 .72174 m .39716 .70634 L .39261 .71077 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.57047 .27826 m .60284 .29366 L .60739 .28923 L p F P
.505 .664 .505 r
s
.534 .74 .58 r
.63904 .30862 m .60739 .28923 L .60284 .29366 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.60284 .70634 m .57047 .72174 L .5731 .72498 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.5731 .72498 m .60739 .71077 L .60284 .70634 L p F P
.505 .664 .505 r
s
.531 .745 .563 r
.47068 .27114 m .5 .26345 L .46668 .26969 L closepath p F P
.505 .664 .505 r
s
.189 .196 .149 r
.5 .73655 m .47068 .72886 L .46668 .73031 L closepath p F P
.505 .664 .505 r
s
.537 .753 .575 r
.53332 .26969 m .5 .26345 L .52932 .27114 L closepath p F P
.505 .664 .505 r
s
.186 .193 .147 r
.5 .73655 m .53332 .73031 L .52932 .72886 L closepath p F P
.505 .664 .505 r
s
.509 .716 .534 r
.46299 .26636 m .4269 .27502 L .42953 .27826 L p F P
.505 .664 .505 r
s
.509 .716 .534 r
.42953 .27826 m .46407 .26807 L .46299 .26636 L p F P
.505 .664 .505 r
s
.196 .202 .154 r
.39261 .71077 m .4269 .72498 L .42953 .72174 L p F P
.505 .664 .505 r
s
.187 .194 .147 r
.46407 .73193 m .42953 .72174 L .4269 .72498 L p F P
.505 .664 .505 r
s
.204 .21 .16 r
.42953 .72174 m .46407 .73193 L .46668 .73031 L p F P
.505 .664 .505 r
s
.557 .776 .596 r
.57047 .27826 m .53593 .26807 L .53332 .26969 L p F P
.505 .664 .505 r
s
.53 .744 .575 r
.53593 .26807 m .57047 .27826 L .5731 .27502 L p F P
.505 .664 .505 r
s
.535 .747 .581 r
.60739 .28923 m .5731 .27502 L .57047 .27826 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57047 .72174 m .53593 .73193 L .53701 .73364 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.53701 .73364 m .5731 .72498 L .57047 .72174 L p F P
.505 .664 .505 r
s
.522 .734 .555 r
.46668 .26969 m .5 .26345 L .46407 .26807 L closepath p F P
.505 .664 .505 r
s
.183 .191 .145 r
.5 .73655 m .46668 .73031 L .46407 .73193 L closepath p F P
.505 .664 .505 r
s
.529 .743 .568 r
.53593 .26807 m .5 .26345 L .53332 .26969 L closepath p F P
.505 .664 .505 r
s
.18 .188 .143 r
.5 .73655 m .53593 .73193 L .53332 .73031 L closepath p F P
.505 .664 .505 r
s
.512 .722 .546 r
.46407 .26807 m .5 .26345 L .46299 .26636 L closepath p F P
.505 .664 .505 r
s
.187 .194 .147 r
.4269 .72498 m .46299 .73364 L .46407 .73193 L p F P
.505 .664 .505 r
s
.177 .185 .14 r
.5 .73655 m .46407 .73193 L .46299 .73364 L closepath p F P
.505 .664 .505 r
s
.519 .731 .56 r
.53701 .26636 m .5 .26345 L .53593 .26807 L closepath p F P
.505 .664 .505 r
s
.53 .744 .575 r
.5731 .27502 m .53701 .26636 L .53593 .26807 L p F P
.505 .664 .505 r
s
.173 .181 .138 r
.5 .73655 m .53701 .73364 L .53593 .73193 L closepath p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26959 .42346 m .26028 .46118 L .26636 .46299 L p F P
.505 .664 .505 r
s
.224 .302 .197 r
.26636 .46299 m .27502 .4269 L .26959 .42346 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26345 .5 m .26636 .46299 L .26028 .46118 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.25714 .5 m .26028 .53882 L .26636 .53701 L p F P
.505 .664 .505 r
s
.189 .237 .162 r
.26636 .53701 m .26345 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.27502 .5731 m .26636 .53701 L .26028 .53882 L p F P
.505 .664 .505 r
s
.206 .269 .179 r
.26028 .46118 m .25714 .5 L .26345 .5 L p F P
.505 .664 .505 r
s
.173 .206 .145 r
.26028 .53882 m .26959 .57654 L .27502 .5731 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.28923 .60739 m .27502 .5731 L .26959 .57654 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.28477 .38789 m .26959 .42346 L .27502 .4269 L p F P
.505 .664 .505 r
s
.242 .336 .215 r
.27502 .4269 m .28923 .39261 L .28477 .38789 L p F P
.505 .664 .505 r
s
.158 .178 .131 r
.26959 .57654 m .28477 .61211 L .28923 .60739 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.30862 .63904 m .28923 .60739 L .28477 .61211 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.30537 .35543 m .28477 .38789 L .28923 .39261 L p F P
.505 .664 .505 r
s
.285 .401 .268 r
.28923 .39261 m .30862 .36096 L .30537 .35543 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.33073 .32695 m .30537 .35543 L .30862 .36096 L p F P
.505 .664 .505 r
s
.33 .466 .323 r
.30862 .36096 m .33273 .33273 L .33073 .32695 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.28477 .61211 m .30537 .64457 L .30862 .63904 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.33273 .66727 m .30862 .63904 L .30537 .64457 L p F P
.505 .664 .505 r
s
.153 .162 .124 r
.30537 .64457 m .33073 .67305 L .33273 .66727 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.36096 .69138 m .33273 .66727 L .33073 .67305 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.36011 .30316 m .33073 .32695 L .33273 .33273 L p F P
.505 .664 .505 r
s
.372 .528 .375 r
.33273 .33273 m .36096 .30862 L .36011 .30316 L p F P
.505 .664 .505 r
s
.156 .165 .126 r
.33073 .67305 m .36011 .69684 L .36096 .69138 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.39261 .71077 m .36096 .69138 L .36011 .69684 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.39265 .28461 m .36011 .30316 L .36096 .30862 L p F P
.505 .664 .505 r
s
.411 .585 .424 r
.36096 .30862 m .39261 .28923 L .39265 .28461 L p F P
.505 .664 .505 r
s
.159 .168 .128 r
.36011 .69684 m .39265 .71539 L .39261 .71077 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.4269 .72498 m .39261 .71077 L .39265 .71539 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.42744 .27169 m .39265 .28461 L .39261 .28923 L p F P
.505 .664 .505 r
s
.447 .635 .468 r
.39261 .28923 m .4269 .27502 L .42744 .27169 L p F P
.505 .664 .505 r
s
.162 .172 .13 r
.39265 .71539 m .42744 .72831 L .4269 .72498 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.46299 .73364 m .4269 .72498 L .42744 .72831 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.46353 .26462 m .42744 .27169 L .4269 .27502 L p F P
.505 .664 .505 r
s
.477 .676 .506 r
.4269 .27502 m .46299 .26636 L .46353 .26462 L p F P
.505 .664 .505 r
s
.501 .709 .537 r
.46299 .26636 m .5 .26345 L .46353 .26462 L closepath p F P
.505 .664 .505 r
s
.166 .175 .133 r
.42744 .72831 m .46353 .73538 L .46299 .73364 L p F P
.505 .664 .505 r
s
.17 .178 .136 r
.5 .73655 m .46299 .73364 L .46353 .73538 L closepath p F P
.505 .664 .505 r
s
.435 .613 .495 r
.63904 .30862 m .66727 .33273 L .66927 .32695 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.66727 .33273 m .69138 .36096 L .69463 .35543 L p F P
.505 .664 .505 r
s
.404 .566 .463 r
.69463 .35543 m .66927 .32695 L .66727 .33273 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.69138 .63904 m .66727 .66727 L .66927 .67305 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.66727 .66727 m .63904 .69138 L .63989 .69684 L p F P
.505 .664 .505 r
s
.125 .137 .105 r
.63989 .69684 m .66927 .67305 L .66727 .66727 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.60739 .71077 m .5731 .72498 L .57256 .72831 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.5731 .72498 m .53701 .73364 L .53647 .73538 L p F P
.505 .664 .505 r
s
.155 .165 .126 r
.53647 .73538 m .57256 .72831 L .5731 .72498 L p F P
.505 .664 .505 r
s
.166 .175 .133 r
.5 .73655 m .53647 .73538 L .53701 .73364 L closepath p F P
.505 .664 .505 r
s
.138 .149 .113 r
.5 .73655 m .51184 .74182 L .51909 .74106 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50401 .7422 L .51184 .74182 L closepath p F P
.505 .664 .505 r
s
.135 .147 .112 r
.5 .73655 m .49599 .7422 L .50401 .7422 L closepath p F P
.505 .664 .505 r
s
.137 .148 .112 r
.5 .73655 m .48816 .74182 L .49599 .7422 L closepath p F P
.505 .664 .505 r
s
.139 .15 .114 r
.5 .73655 m .48091 .74106 L .48816 .74182 L closepath p F P
.505 .664 .505 r
s
.144 .154 .117 r
.5 .73655 m .47457 .73998 L .48091 .74106 L closepath p F P
.505 .664 .505 r
s
.149 .159 .121 r
.5 .73655 m .46942 .73863 L .47457 .73998 L closepath p F P
.505 .664 .505 r
s
.156 .165 .126 r
.5 .73655 m .4657 .73707 L .46942 .73863 L closepath p F P
.505 .664 .505 r
s
.163 .172 .131 r
.5 .73655 m .46353 .73538 L .4657 .73707 L closepath p F P
.505 .664 .505 r
s
.508 .719 .551 r
.53647 .26462 m .5 .26345 L .53701 .26636 L closepath p F P
.505 .664 .505 r
s
.159 .169 .128 r
.5 .73655 m .5343 .73707 L .53647 .73538 L closepath p F P
.505 .664 .505 r
s
.152 .162 .124 r
.5 .73655 m .53058 .73863 L .5343 .73707 L closepath p F P
.505 .664 .505 r
s
.147 .157 .119 r
.5 .73655 m .52543 .73998 L .53058 .73863 L closepath p F P
.505 .664 .505 r
s
.142 .152 .116 r
.5 .73655 m .51909 .74106 L .52543 .73998 L closepath p F P
.505 .664 .505 r
s
.499 .706 .548 r
.53701 .26636 m .5731 .27502 L .57256 .27169 L p F P
.505 .664 .505 r
s
.499 .706 .548 r
.57256 .27169 m .53647 .26462 L .53701 .26636 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.5731 .27502 m .60739 .28923 L .60735 .28461 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.60739 .28923 m .63904 .30862 L .63989 .30316 L p F P
.505 .664 .505 r
s
.462 .653 .52 r
.63989 .30316 m .60735 .28461 L .60739 .28923 L p F P
.505 .664 .505 r
s
.435 .613 .495 r
.66927 .32695 m .63989 .30316 L .63904 .30862 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.63904 .69138 m .60739 .71077 L .60735 .71539 L p F P
.505 .664 .505 r
s
.145 .155 .118 r
.57256 .72831 m .60735 .71539 L .60739 .71077 L p F P
.505 .664 .505 r
s
.483 .684 .537 r
.60735 .28461 m .57256 .27169 L .5731 .27502 L p F P
.505 .664 .505 r
s
.135 .146 .111 r
.60735 .71539 m .63989 .69684 L .63904 .69138 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.71077 .39261 m .72498 .4269 L .73041 .42346 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.72498 .4269 m .73364 .46299 L .73972 .46118 L p F P
.505 .664 .505 r
s
.293 .396 .34 r
.73972 .46118 m .73041 .42346 L .72498 .4269 L p F P
.505 .664 .505 r
s
.497 .705 .541 r
.5343 .26293 m .5 .26345 L .53647 .26462 L closepath p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73364 .53701 m .72498 .5731 L .73041 .57654 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.72498 .5731 m .71077 .60739 L .71523 .61211 L p F P
.505 .664 .505 r
s
.159 .19 .168 r
.71523 .61211 m .73041 .57654 L .72498 .5731 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.73364 .46299 m .73655 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73655 .5 m .73364 .53701 L .73972 .53882 L p F P
.505 .664 .505 r
s
.215 .275 .246 r
.73972 .53882 m .74286 .5 L .73655 .5 L p F P
.505 .664 .505 r
s
.369 .513 .426 r
.69138 .36096 m .71077 .39261 L .71523 .38789 L p F P
.505 .664 .505 r
s
.332 .456 .385 r
.73041 .42346 m .71523 .38789 L .71077 .39261 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.71077 .60739 m .69138 .63904 L .69463 .64457 L p F P
.505 .664 .505 r
s
.141 .165 .139 r
.69463 .64457 m .71523 .61211 L .71077 .60739 L p F P
.505 .664 .505 r
s
.254 .335 .293 r
.74286 .5 m .73972 .46118 L .73364 .46299 L p F P
.505 .664 .505 r
s
.179 .218 .199 r
.73041 .57654 m .73972 .53882 L .73364 .53701 L p F P
.505 .664 .505 r
s
.49 .696 .528 r
.46353 .26462 m .5 .26345 L .4657 .26293 L closepath p F P
.505 .664 .505 r
s
.486 .692 .531 r
.53058 .26137 m .5 .26345 L .5343 .26293 L closepath p F P
.505 .664 .505 r
s
.369 .513 .426 r
.71523 .38789 m .69463 .35543 L .69138 .36096 L p F P
.505 .664 .505 r
s
.125 .141 .111 r
.66927 .67305 m .69463 .64457 L .69138 .63904 L p F P
.505 .664 .505 r
s
.48 .683 .519 r
.4657 .26293 m .5 .26345 L .46942 .26137 L closepath p F P
.505 .664 .505 r
s
.476 .679 .522 r
.52543 .26002 m .5 .26345 L .53058 .26137 L closepath p F P
.505 .664 .505 r
s
.47 .672 .511 r
.46942 .26137 m .5 .26345 L .47457 .26002 L closepath p F P
.505 .664 .505 r
s
.467 .668 .513 r
.51909 .25894 m .5 .26345 L .52543 .26002 L closepath p F P
.505 .664 .505 r
s
.46 .659 .507 r
.51184 .25818 m .5 .26345 L .51909 .25894 L closepath p F P
.505 .664 .505 r
s
.462 .662 .505 r
.47457 .26002 m .5 .26345 L .48091 .25894 L closepath p F P
.505 .664 .505 r
s
.455 .653 .502 r
.50401 .2578 m .5 .26345 L .51184 .25818 L closepath p F P
.505 .664 .505 r
s
.457 .655 .501 r
.48091 .25894 m .5 .26345 L .48816 .25818 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.49599 .2578 m .5 .26345 L .50401 .2578 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.48816 .25818 m .5 .26345 L .49599 .2578 L closepath p F P
.505 .664 .505 r
s
.144 .154 .117 r
.43126 .73159 m .4657 .73707 L .46353 .73538 L p F P
.505 .664 .505 r
s
.144 .154 .117 r
.46353 .73538 m .42744 .72831 L .43126 .73159 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.42744 .27169 m .46353 .26462 L .4657 .26293 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.57256 .72831 m .53647 .73538 L .5343 .73707 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.53647 .26462 m .57256 .27169 L .56874 .26841 L p F P
.505 .664 .505 r
s
.463 .662 .516 r
.56874 .26841 m .5343 .26293 L .53647 .26462 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.43832 .73466 m .46942 .73863 L .4657 .73707 L p F P
.505 .664 .505 r
s
.121 .133 .101 r
.4657 .73707 m .43126 .73159 L .43832 .73466 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.43126 .26841 m .4657 .26293 L .46942 .26137 L p F P
.505 .664 .505 r
s
.441 .633 .475 r
.4657 .26293 m .43126 .26841 L .42744 .27169 L p F P
.505 .664 .505 r
s
.133 .145 .11 r
.5343 .73707 m .56874 .73159 L .57256 .72831 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.56874 .73159 m .5343 .73707 L .53058 .73863 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.5343 .26293 m .56874 .26841 L .56168 .26534 L p F P
.505 .664 .505 r
s
.424 .615 .482 r
.56168 .26534 m .53058 .26137 L .5343 .26293 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.39759 .72 m .43126 .73159 L .42744 .72831 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.42744 .72831 m .39265 .71539 L .39759 .72 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.39265 .28461 m .42744 .27169 L .43126 .26841 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.60735 .71539 m .57256 .72831 L .56874 .73159 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.57256 .27169 m .60735 .28461 L .60241 .28 L p F P
.505 .664 .505 r
s
.419 .605 .481 r
.60241 .28 m .56874 .26841 L .57256 .27169 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.44839 .73736 m .47457 .73998 L .46942 .73863 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.46942 .73863 m .43832 .73466 L .44839 .73736 L p F P
.505 .664 .505 r
s
.111 .124 .095 r
.53058 .73863 m .56168 .73466 L .56874 .73159 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.56168 .73466 m .53058 .73863 L .52543 .73998 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.43832 .26534 m .46942 .26137 L .47457 .26002 L p F P
.505 .664 .505 r
s
.404 .588 .444 r
.46942 .26137 m .43832 .26534 L .43126 .26841 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.53058 .26137 m .56168 .26534 L .55161 .26264 L p F P
.505 .664 .505 r
s
.387 .568 .447 r
.55161 .26264 m .52543 .26002 L .53058 .26137 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.36568 .70237 m .39759 .72 L .39265 .71539 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.39265 .71539 m .36011 .69684 L .36568 .70237 L p F P
.505 .664 .505 r
s
.382 .556 .412 r
.43126 .26841 m .39759 .28 L .39265 .28461 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.36011 .30316 m .39265 .28461 L .39759 .28 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.63989 .69684 m .60735 .71539 L .60241 .72 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56874 .73159 m .60241 .72 L .60735 .71539 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.60735 .28461 m .63989 .30316 L .63432 .29763 L p F P
.505 .664 .505 r
s
.368 .536 .436 r
.63432 .29763 m .60241 .28 L .60735 .28461 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.46108 .73954 m .48091 .74106 L .47457 .73998 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.47457 .73998 m .44839 .73736 L .46108 .73954 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.52543 .73998 m .55161 .73736 L .56168 .73466 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.55161 .73736 m .52543 .73998 L .51909 .74106 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.44839 .26264 m .47457 .26002 L .48091 .25894 L p F P
.505 .664 .505 r
s
.369 .544 .414 r
.47457 .26002 m .44839 .26264 L .43832 .26534 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.52543 .26002 m .55161 .26264 L .53892 .26046 L p F P
.505 .664 .505 r
s
.353 .526 .415 r
.53892 .26046 m .51909 .25894 L .52543 .26002 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.33651 .67897 m .36568 .70237 L .36011 .69684 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.36011 .69684 m .33073 .67305 L .33651 .67897 L p F P
.505 .664 .505 r
s
.317 .467 .34 r
.39759 .28 m .36568 .29763 L .36011 .30316 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.33073 .32695 m .36011 .30316 L .36568 .29763 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.66927 .67305 m .63989 .69684 L .63432 .70237 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.60241 .72 m .63432 .70237 L .63989 .69684 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.63989 .30316 m .66927 .32695 L .66349 .32103 L p F P
.505 .664 .505 r
s
.312 .459 .384 r
.66349 .32103 m .63432 .29763 L .63989 .30316 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.40751 .72438 m .43832 .73466 L .43126 .73159 L p F P
.505 .664 .505 r
s
.084 .099 .075 r
.43126 .73159 m .39759 .72 L .40751 .72438 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.39759 .28 m .43126 .26841 L .43832 .26534 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.60241 .72 m .56874 .73159 L .56168 .73466 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.56874 .26841 m .60241 .28 L .59249 .27562 L p F P
.505 .664 .505 r
s
.348 .516 .416 r
.59249 .27562 m .56168 .26534 L .56874 .26841 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.53892 .73954 m .51909 .74106 L .51184 .74182 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.47579 .74108 m .48816 .74182 L .48091 .74106 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.48091 .74106 m .46108 .73954 L .47579 .74108 L p F P
.505 .664 .505 r
s
.073 .09 .068 r
.51909 .74106 m .53892 .73954 L .55161 .73736 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.51909 .25894 m .53892 .26046 L .52421 .25892 L p F P
.505 .664 .505 r
s
.325 .491 .388 r
.52421 .25892 m .51184 .25818 L .51909 .25894 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.46108 .26046 m .48091 .25894 L .48816 .25818 L p F P
.505 .664 .505 r
s
.338 .506 .388 r
.48091 .25894 m .46108 .26046 L .44839 .26264 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72256 .60117 m
.72409 .59728 L
s
.5 Mabswid
.285 .414 .354 r
.31104 .65028 m .33651 .67897 L .33073 .67305 L p F P
.505 .664 .505 r
s
.285 .414 .354 r
.33073 .67305 m .30537 .64457 L .31104 .65028 L p F P
.505 .664 .505 r
s
.246 .371 .262 r
.36568 .29763 m .33651 .32103 L .33073 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.30537 .35543 m .33073 .32695 L .33651 .32103 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.66927 .32695 m .69463 .35543 L .68896 .34972 L p F P
.505 .664 .505 r
s
.08 .096 .073 r
.68896 .34972 m .66349 .32103 L .66927 .32695 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.63432 .70237 m .66349 .67897 L .66927 .67305 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.69463 .64457 m .66927 .67305 L .66349 .67897 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72971 .58352 m
.73048 .58143 L
s
.72828 .58783 m
.72971 .58352 L
s
.73048 .58143 m
.73214 .57731 L
s
.5 Mabswid
.061 .078 .059 r
.51184 .74182 m .52421 .74108 L .53892 .73954 L p F P
.505 .664 .505 r
s
.309 .469 .366 r
.52421 .74108 m .51184 .74182 L .50401 .7422 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.51184 .25818 m .52421 .25892 L .50821 .25813 L p F P
.505 .664 .505 r
s
.059 .076 .058 r
.50821 .25813 m .50401 .2578 L .51184 .25818 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.49179 .74187 m .49599 .7422 L .48816 .74182 L p F P
.505 .664 .505 r
s
.314 .476 .375 r
.48816 .74182 m .47579 .74108 L .49179 .74187 L p F P
.505 .664 .505 r
s
.315 .478 .369 r
.48816 .25818 m .47579 .25892 L .46108 .26046 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.47579 .25892 m .48816 .25818 L .49599 .2578 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72192 .60368 m
.72256 .60117 L
s
.5 Mabswid
.309 .469 .366 r
.50401 .7422 m .50821 .74187 L .52421 .74108 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.50821 .74187 m .50401 .7422 L .49599 .7422 L p F P
.505 .664 .505 r
s
.317 .481 .376 r
.49599 .7422 m .49179 .74187 L .50821 .74187 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.50401 .2578 m .50821 .25813 L .49179 .25813 L p F P
.505 .664 .505 r
s
.061 .078 .059 r
.49179 .25813 m .49599 .2578 L .50401 .2578 L p F P
.505 .664 .505 r
s
.057 .074 .056 r
.49599 .2578 m .49179 .25813 L .47579 .25892 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72768 .59026 m
.72828 .58783 L
s
.73214 .57731 m
.73318 .57566 L
s
.5 Mabswid
.056 .074 .056 r
.33651 .32103 m .31104 .34972 L .30537 .35543 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.28477 .38789 m .30537 .35543 L .31104 .34972 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.29017 .61703 m .31104 .65028 L .30537 .64457 L p F P
.505 .664 .505 r
s
.277 .399 .345 r
.30537 .64457 m .28477 .61211 L .29017 .61703 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.69463 .35543 m .71523 .38789 L .70983 .38297 L p F P
.505 .664 .505 r
s
.099 .113 .086 r
.70983 .38297 m .68896 .34972 L .69463 .35543 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.71523 .61211 m .69463 .64457 L .68896 .65028 L p F P
.505 .664 .505 r
s
.197 .3 .202 r
.66349 .67897 m .68896 .65028 L .69463 .64457 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.42217 .72827 m .44839 .73736 L .43832 .73466 L p F P
.505 .664 .505 r
s
.346 .515 .414 r
.43832 .73466 m .40751 .72438 L .42217 .72827 L p F P
.505 .664 .505 r
s
.313 .47 .351 r
.43832 .26534 m .40751 .27562 L .39759 .28 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.40751 .27562 m .43832 .26534 L .44839 .26264 L p F P
.505 .664 .505 r
s
.067 .084 .064 r
.56168 .73466 m .59249 .72438 L .60241 .72 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.59249 .72438 m .56168 .73466 L .55161 .73736 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.56168 .26534 m .59249 .27562 L .57783 .27173 L p F P
.505 .664 .505 r
s
.081 .097 .074 r
.57783 .27173 m .55161 .26264 L .56168 .26534 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.37793 .70768 m .40751 .72438 L .39759 .72 L p F P
.505 .664 .505 r
s
.342 .506 .413 r
.39759 .72 m .36568 .70237 L .37793 .70768 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.36568 .29763 m .39759 .28 L .40751 .27562 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.63432 .70237 m .60241 .72 L .59249 .72438 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.60241 .28 m .63432 .29763 L .62207 .29232 L p F P
.505 .664 .505 r
s
.088 .103 .079 r
.62207 .29232 m .59249 .27562 L .60241 .28 L p F P
.505 .664 .505 r
s
.066 .086 .069 r
.31104 .34972 m .29017 .38297 L .28477 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.26959 .42346 m .28477 .38789 L .29017 .38297 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.27466 .58014 m .29017 .61703 L .28477 .61211 L p F P
.505 .664 .505 r
s
.27 .379 .33 r
.28477 .61211 m .26959 .57654 L .27466 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.73041 .57654 m .71523 .61211 L .70983 .61703 L p F P
.505 .664 .505 r
s
.192 .284 .183 r
.68896 .65028 m .70983 .61703 L .71523 .61211 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.71523 .38789 m .73041 .42346 L .72534 .41986 L p F P
.505 .664 .505 r
s
.113 .126 .096 r
.72534 .41986 m .70983 .38297 L .71523 .38789 L p F P
.505 .664 .505 r
s
.108 .138 .122 r
.29017 .38297 m .27466 .41986 L .26959 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.26028 .46118 m .26959 .42346 L .27466 .41986 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26511 .54072 m .27466 .58014 L .26959 .57654 L p F P
.505 .664 .505 r
s
.25 .343 .302 r
.26959 .57654 m .26028 .53882 L .26511 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.73972 .53882 m .73041 .57654 L .72534 .58014 L p F P
.505 .664 .505 r
s
.19 .271 .173 r
.70983 .61703 m .72534 .58014 L .73041 .57654 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72684 .59335 m
.72768 .59026 L
s
.72186 .60441 m
.72192 .60368 L
s
.5 Mabswid
.134 .156 .114 r
.73041 .42346 m .73972 .46118 L .73489 .45928 L p F P
.505 .664 .505 r
s
.134 .156 .114 r
.73489 .45928 m .72534 .41986 L .73041 .42346 L p F P
.505 .664 .505 r
s
.145 .182 .168 r
.27466 .41986 m .26511 .45928 L .26028 .46118 L p F P
.505 .664 .505 r
s
.179 .228 .212 r
.25714 .5 m .26028 .46118 L .26511 .45928 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26189 .5 m .26511 .54072 L .26028 .53882 L p F P
.505 .664 .505 r
s
.22 .292 .263 r
.26028 .53882 m .25714 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73972 .46118 m .74286 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
.16 .2 .138 r
.73811 .5 m .73489 .45928 L .73972 .46118 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.74286 .5 m .73972 .53882 L .73489 .54072 L p F P
.505 .664 .505 r
s
.188 .258 .168 r
.72534 .58014 m .73489 .54072 L .73972 .53882 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73318 .57566 m
.73321 .57622 L
s
.5 Mabswid
.179 .228 .212 r
.26511 .45928 m .26189 .5 L .25714 .5 L p F P
.505 .664 .505 r
s
.178 .234 .157 r
.73489 .54072 m .73811 .5 L .74286 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72186 .60441 m
.72241 .60333 L
s
.73221 .57904 m
.73321 .57622 L
s
.72579 .59577 m
.72684 .59335 L
s
.5 Mabswid
.405 .59 .466 r
.44103 .73145 m .46108 .73954 L .44839 .73736 L p F P
.505 .664 .505 r
s
.405 .59 .466 r
.44839 .73736 m .42217 .72827 L .44103 .73145 L p F P
.505 .664 .505 r
s
.316 .475 .357 r
.55161 .73736 m .57783 .72827 L .59249 .72438 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.57783 .72827 m .55161 .73736 L .53892 .73954 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.42217 .27173 m .44839 .26264 L .46108 .26046 L p F P
.505 .664 .505 r
s
.067 .083 .064 r
.44839 .26264 m .42217 .27173 L .40751 .27562 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55161 .26264 m .57783 .27173 L .55897 .26855 L p F P
.505 .664 .505 r
s
.111 .124 .094 r
.55897 .26855 m .53892 .26046 L .55161 .26264 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.35056 .68472 m .37793 .70768 L .36568 .70237 L p F P
.505 .664 .505 r
s
.396 .568 .462 r
.36568 .70237 m .33651 .67897 L .35056 .68472 L p F P
.505 .664 .505 r
s
.065 .082 .063 r
.40751 .27562 m .37793 .29232 L .36568 .29763 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.33651 .32103 m .36568 .29763 L .37793 .29232 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.63432 .29763 m .66349 .32103 L .64944 .31528 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.64944 .31528 m .62207 .29232 L .63432 .29763 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.66349 .67897 m .63432 .70237 L .62207 .70768 L p F P
.505 .664 .505 r
s
.295 .441 .323 r
.59249 .72438 m .62207 .70768 L .63432 .70237 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72241 .60333 m
.72396 .59985 L
s
.72396 .59985 m
.72579 .59577 L
s
.73052 .58364 m
.73221 .57904 L
s
.5 Mabswid
.438 .628 .499 r
.39671 .71247 m .42217 .72827 L .40751 .72438 L p F P
.505 .664 .505 r
s
.438 .628 .499 r
.40751 .72438 m .37793 .70768 L .39671 .71247 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.37793 .29232 m .40751 .27562 L .42217 .27173 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.62207 .70768 m .59249 .72438 L .57783 .72827 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.59249 .27562 m .62207 .29232 L .60329 .28753 L p F P
.505 .664 .505 r
s
.138 .149 .113 r
.60329 .28753 m .57783 .27173 L .59249 .27562 L p F P
.505 .664 .505 r
s
.381 .558 .42 r
.53892 .73954 m .55897 .73145 L .57783 .72827 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.55897 .73145 m .53892 .73954 L .52421 .74108 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.4632 .7337 m .47579 .74108 L .46108 .73954 L p F P
.505 .664 .505 r
s
.445 .641 .499 r
.46108 .73954 m .44103 .73145 L .4632 .7337 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.53892 .26046 m .55897 .26855 L .5368 .2663 L p F P
.505 .664 .505 r
s
.132 .144 .109 r
.5368 .2663 m .52421 .25892 L .53892 .26046 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.44103 .26855 m .46108 .26046 L .47579 .25892 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.46108 .26046 m .44103 .26855 L .42217 .27173 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.32641 .65589 m .35056 .68472 L .33651 .67897 L p F P
.505 .664 .505 r
s
.431 .604 .49 r
.33651 .67897 m .31104 .65028 L .32641 .65589 L p F P
.505 .664 .505 r
s
.099 .114 .086 r
.37793 .29232 m .35056 .31528 L .33651 .32103 L p F P
.505 .664 .505 r
s
.131 .143 .11 r
.31104 .34972 m .33651 .32103 L .35056 .31528 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.68896 .65028 m .66349 .67897 L .64944 .68472 L p F P
.505 .664 .505 r
s
.337 .488 .349 r
.62207 .70768 m .64944 .68472 L .66349 .67897 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.66349 .32103 m .68896 .34972 L .67359 .34411 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.67359 .34411 m .64944 .31528 L .66349 .32103 L p F P
.505 .664 .505 r
s
.429 .619 .468 r
.52421 .74108 m .5368 .7337 L .55897 .73145 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.5368 .7337 m .52421 .74108 L .50821 .74187 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.52421 .25892 m .5368 .2663 L .51251 .26513 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.51251 .26513 m .50821 .25813 L .52421 .25892 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.48749 .73487 m .49179 .74187 L .47579 .74108 L p F P
.505 .664 .505 r
s
.467 .668 .515 r
.47579 .74108 m .4632 .7337 L .48749 .73487 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.4632 .2663 m .47579 .25892 L .49179 .25813 L p F P
.505 .664 .505 r
s
.124 .136 .104 r
.47579 .25892 m .4632 .2663 L .44103 .26855 L p F P
.505 .664 .505 r
s
.459 .657 .499 r
.50821 .74187 m .51251 .73487 L .5368 .7337 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.51251 .73487 m .50821 .74187 L .49179 .74187 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.50821 .25813 m .51251 .26513 L .48749 .26513 L p F P
.505 .664 .505 r
s
.147 .157 .119 r
.48749 .26513 m .49179 .25813 L .50821 .25813 L p F P
.505 .664 .505 r
s
.471 .673 .515 r
.49179 .74187 m .48749 .73487 L .51251 .73487 L p F P
.505 .664 .505 r
s
.14 .151 .115 r
.49179 .25813 m .48749 .26513 L .4632 .2663 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72117 .60342 m
.72324 .59935 L
s
.72324 .59935 m
.72493 .59538 L
s
.71991 .60553 m
.72117 .60342 L
s
.729 .58487 m
.72982 .5808 L
s
.71816 .60787 m
.71991 .60553 L
s
.5 Mabswid
.131 .143 .11 r
.35056 .31528 m .32641 .34411 L .31104 .34972 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.29017 .38297 m .31104 .34972 L .32641 .34411 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.30644 .6219 m .32641 .65589 L .31104 .65028 L p F P
.505 .664 .505 r
s
.448 .616 .498 r
.31104 .65028 m .29017 .61703 L .30644 .6219 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.68896 .34972 m .70983 .38297 L .69356 .3781 L p F P
.505 .664 .505 r
s
.204 .225 .164 r
.69356 .3781 m .67359 .34411 L .68896 .34972 L p F P
.505 .664 .505 r
s
.372 .514 .354 r
.70983 .61703 m .68896 .65028 L .67359 .65589 L p F P
.505 .664 .505 r
s
.363 .512 .359 r
.64944 .68472 m .67359 .65589 L .68896 .65028 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42138 .71641 m .44103 .73145 L .42217 .72827 L p F P
.505 .664 .505 r
s
.508 .715 .558 r
.42217 .72827 m .39671 .71247 L .42138 .71641 L p F P
.505 .664 .505 r
s
.398 .573 .422 r
.57783 .72827 m .60329 .71247 L .62207 .70768 L p F P
.505 .664 .505 r
s
.476 .672 .498 r
.60329 .71247 m .57783 .72827 L .55897 .73145 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.39671 .28753 m .42217 .27173 L .44103 .26855 L p F P
.505 .664 .505 r
s
.118 .131 .1 r
.42217 .27173 m .39671 .28753 L .37793 .29232 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57783 .27173 m .60329 .28753 L .57862 .28359 L p F P
.505 .664 .505 r
s
.176 .184 .14 r
.57862 .28359 m .55897 .26855 L .57783 .27173 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.7297 .57888 m
.72982 .5808 L
s
.5 Mabswid
.504 .704 .555 r
.3729 .68995 m .39671 .71247 L .37793 .70768 L p F P
.505 .664 .505 r
s
.504 .704 .555 r
.37793 .70768 m .35056 .68472 L .3729 .68995 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.35056 .31528 m .37793 .29232 L .39671 .28753 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.64944 .68472 m .62207 .70768 L .60329 .71247 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.62207 .29232 m .64944 .31528 L .6271 .31005 L p F P
.505 .664 .505 r
s
.186 .193 .147 r
.6271 .31005 m .60329 .28753 L .62207 .29232 L p F P
.505 .664 .505 r
s
.188 .21 .176 r
.32641 .34411 m .30644 .3781 L .29017 .38297 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.27466 .41986 m .29017 .38297 L .30644 .3781 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.2915 .58374 m .30644 .6219 L .29017 .61703 L p F P
.505 .664 .505 r
s
.449 .606 .49 r
.29017 .61703 m .27466 .58014 L .2915 .58374 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.70983 .38297 m .72534 .41986 L .7085 .41626 L p F P
.505 .664 .505 r
s
.251 .294 .205 r
.7085 .41626 m .69356 .3781 L .70983 .38297 L p F P
.505 .664 .505 r
s
.368 .497 .336 r
.72534 .58014 m .70983 .61703 L .69356 .6219 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71659 .60862 m
.71816 .60787 L
s
.5 Mabswid
.372 .514 .354 r
.67359 .65589 m .69356 .6219 L .70983 .61703 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.28225 .54263 m .2915 .58374 L .27466 .58014 L p F P
.505 .664 .505 r
s
.435 .578 .467 r
.27466 .58014 m .26511 .54072 L .28225 .54263 L p F P
.505 .664 .505 r
s
.258 .307 .254 r
.30644 .3781 m .2915 .41626 L .27466 .41986 L p F P
.505 .664 .505 r
s
.32 .398 .325 r
.26511 .45928 m .27466 .41986 L .2915 .41626 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.72534 .41986 m .73489 .45928 L .71775 .45737 L p F P
.505 .664 .505 r
s
.287 .351 .238 r
.71775 .45737 m .7085 .41626 L .72534 .41986 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.73489 .54072 m .72534 .58014 L .7085 .58374 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72814 .57946 m
.7297 .57888 L
s
.5 Mabswid
.368 .497 .336 r
.69356 .6219 m .7085 .58374 L .72534 .58014 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71626 .60725 m
.71659 .60862 L
s
.71846 .59811 m
.72493 .59538 L
s
.5 Mabswid
.476 .672 .498 r
.55897 .73145 m .57862 .71641 L .60329 .71247 L p F P
.505 .664 .505 r
s
.53 .739 .551 r
.57862 .71641 m .55897 .73145 L .5368 .7337 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.45078 .71923 m .4632 .7337 L .44103 .73145 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.44103 .73145 m .42138 .71641 L .45078 .71923 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.55897 .26855 m .57862 .28359 L .54922 .28077 L p F P
.505 .664 .505 r
s
.201 .207 .157 r
.54922 .28077 m .5368 .2663 L .55897 .26855 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.42138 .28359 m .44103 .26855 L .4632 .2663 L p F P
.505 .664 .505 r
s
.16 .17 .129 r
.44103 .26855 m .42138 .28359 L .39671 .28753 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71626 .60725 m
.71664 .6039 L
s
.5 Mabswid
.32 .398 .325 r
.2915 .41626 m .28225 .45737 L .26511 .45928 L p F P
.505 .664 .505 r
s
.37 .473 .384 r
.26189 .5 m .26511 .45928 L .28225 .45737 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.27912 .5 m .28225 .54263 L .26511 .54072 L p F P
.505 .664 .505 r
s
.409 .533 .431 r
.26511 .54072 m .26189 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.73489 .45928 m .73811 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
.314 .395 .263 r
.72088 .5 m .71775 .45737 L .73489 .45928 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.73811 .5 m .73489 .54072 L .71775 .54263 L p F P
.505 .664 .505 r
s
.351 .464 .307 r
.7085 .58374 m .71775 .54263 L .73489 .54072 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72616 .58217 m
.72814 .57946 L
s
.5 Mabswid
.37 .473 .384 r
.28225 .45737 m .27912 .5 L .26189 .5 L p F P
.505 .664 .505 r
s
.331 .428 .28 r
.71775 .54263 m .72088 .5 L .73811 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72325 .58713 m
.72616 .58217 L
s
.71664 .6039 m
.71846 .59811 L
s
.5 Mabswid
.543 .744 .584 r
.35168 .66105 m .3729 .68995 L .35056 .68472 L p F P
.505 .664 .505 r
s
.543 .744 .584 r
.35056 .68472 m .32641 .65589 L .35168 .66105 L p F P
.505 .664 .505 r
s
.162 .171 .13 r
.39671 .28753 m .3729 .31005 L .35056 .31528 L p F P
.505 .664 .505 r
s
.226 .247 .193 r
.32641 .34411 m .35056 .31528 L .3729 .31005 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.67359 .65589 m .64944 .68472 L .6271 .68995 L p F P
.505 .664 .505 r
s
.454 .637 .461 r
.60329 .71247 m .6271 .68995 L .64944 .68472 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64944 .31528 m .67359 .34411 L .64832 .33895 L p F P
.505 .664 .505 r
s
.248 .274 .198 r
.64832 .33895 m .6271 .31005 L .64944 .31528 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72011 .59391 m
.72325 .58713 L
s
.71846 .59811 m
.72011 .59391 L
s
.5 Mabswid
.53 .739 .551 r
.5368 .7337 m .54922 .71923 L .57862 .71641 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.54922 .71923 m .5368 .7337 L .51251 .73487 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.5368 .2663 m .54922 .28077 L .51676 .2793 L p F P
.505 .664 .505 r
s
.214 .219 .167 r
.51676 .2793 m .51251 .26513 L .5368 .2663 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.48324 .7207 m .48749 .73487 L .4632 .7337 L p F P
.505 .664 .505 r
s
.572 .794 .605 r
.4632 .7337 m .45078 .71923 L .48324 .7207 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.45078 .28077 m .4632 .2663 L .48749 .26513 L p F P
.505 .664 .505 r
s
.19 .197 .15 r
.4632 .2663 m .45078 .28077 L .42138 .28359 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.40284 .69431 m .42138 .71641 L .39671 .71247 L p F P
.505 .664 .505 r
s
.574 .79 .612 r
.39671 .71247 m .3729 .68995 L .40284 .69431 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.3729 .31005 m .39671 .28753 L .42138 .28359 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.6271 .68995 m .60329 .71247 L .57862 .71641 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.60329 .28753 m .6271 .31005 L .59716 .30569 L p F P
.505 .664 .505 r
s
.241 .259 .19 r
.59716 .30569 m .57862 .28359 L .60329 .28753 L p F P
.505 .664 .505 r
s
.562 .78 .585 r
.51251 .73487 m .51676 .7207 L .54922 .71923 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.51676 .7207 m .51251 .73487 L .48749 .73487 L p F P
.505 .664 .505 r
s
.576 .797 .602 r
.48749 .73487 m .48324 .7207 L .51676 .7207 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.51251 .26513 m .51676 .2793 L .48324 .2793 L p F P
.505 .664 .505 r
s
.216 .221 .168 r
.48324 .2793 m .48749 .26513 L .51251 .26513 L p F P
.505 .664 .505 r
s
.209 .214 .163 r
.48749 .26513 m .48324 .2793 L .45078 .28077 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70145 .62397 m
.71047 .6021 L
s
.71047 .6021 m
.71886 .58175 L
s
.5 Mabswid
.226 .247 .193 r
.3729 .31005 m .35168 .33895 L .32641 .34411 L p F P
.505 .664 .505 r
s
.315 .371 .289 r
.30644 .3781 m .32641 .34411 L .35168 .33895 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.33398 .62642 m .35168 .66105 L .32641 .65589 L p F P
.505 .664 .505 r
s
.56 .755 .591 r
.32641 .65589 m .30644 .6219 L .33398 .62642 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.67359 .34411 m .69356 .3781 L .66602 .37358 L p F P
.505 .664 .505 r
s
.307 .358 .248 r
.66602 .37358 m .64832 .33895 L .67359 .34411 L p F P
.505 .664 .505 r
s
.5 .674 .477 r
.69356 .6219 m .67359 .65589 L .64832 .66105 L p F P
.505 .664 .505 r
s
.487 .668 .478 r
.6271 .68995 m .64832 .66105 L .67359 .65589 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70637 .61017 m
.71003 .60579 L
s
.71609 .58451 m
.71656 .58877 L
s
.70342 .61256 m
.70637 .61017 L
s
.5 Mabswid
.588 .803 .592 r
.59716 .69431 m .57862 .71641 L .54922 .71923 L p F P
.505 .664 .505 r
s
.536 .739 .541 r
.57862 .71641 m .59716 .69431 L .6271 .68995 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.57862 .28359 m .59716 .30569 L .56101 .30255 L p F P
.505 .664 .505 r
s
.284 .314 .225 r
.56101 .30255 m .54922 .28077 L .57862 .28359 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.40284 .30569 m .42138 .28359 L .45078 .28077 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.43899 .69745 m .45078 .71923 L .42138 .71641 L p F P
.505 .664 .505 r
s
.613 .837 .639 r
.42138 .71641 m .40284 .69431 L .43899 .69745 L p F P
.505 .664 .505 r
s
.213 .223 .167 r
.42138 .28359 m .40284 .30569 L .3729 .31005 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71468 .5825 m
.71609 .58451 L
s
.5 Mabswid
.315 .371 .289 r
.35168 .33895 m .33398 .37358 L .30644 .3781 L p F P
.505 .664 .505 r
s
.387 .474 .368 r
.2915 .41626 m .30644 .3781 L .33398 .37358 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.32065 .58709 m .33398 .62642 L .30644 .6219 L p F P
.505 .664 .505 r
s
.56 .744 .581 r
.30644 .6219 m .2915 .58374 L .32065 .58709 L p F P
.505 .664 .505 r
s
.497 .66 .462 r
.7085 .58374 m .69356 .6219 L .66602 .62642 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70003 .61328 m
.70342 .61256 L
s
.5 Mabswid
.5 .674 .477 r
.64832 .66105 m .66602 .62642 L .69356 .6219 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.69356 .3781 m .7085 .41626 L .67935 .41291 L p F P
.505 .664 .505 r
s
.352 .425 .288 r
.67935 .41291 m .66602 .37358 L .69356 .3781 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.38619 .66538 m .40284 .69431 L .3729 .68995 L p F P
.505 .664 .505 r
s
.608 .823 .634 r
.3729 .68995 m .35168 .66105 L .38619 .66538 L p F P
.505 .664 .505 r
s
.314 .362 .27 r
.35168 .33895 m .3729 .31005 L .40284 .30569 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.6271 .31005 m .64832 .33895 L .61381 .33462 L p F P
.505 .664 .505 r
s
.315 .362 .253 r
.61381 .33462 m .59716 .30569 L .6271 .31005 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.64832 .66105 m .6271 .68995 L .59716 .69431 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69844 .61183 m
.70003 .61328 L
s
.5 Mabswid
.387 .474 .368 r
.33398 .37358 m .32065 .41291 L .2915 .41626 L p F P
.505 .664 .505 r
s
.444 .557 .432 r
.28225 .45737 m .2915 .41626 L .32065 .41291 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.31236 .54441 m .32065 .58709 L .2915 .58374 L p F P
.505 .664 .505 r
s
.547 .718 .559 r
.2915 .58374 m .28225 .54263 L .31236 .54441 L p F P
.505 .664 .505 r
s
.588 .803 .592 r
.54922 .71923 m .56101 .69745 L .59716 .69431 L p F P
.505 .664 .505 r
s
.618 .84 .624 r
.56101 .69745 m .54922 .71923 L .51676 .7207 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.54922 .28077 m .56101 .30255 L .52081 .30091 L p F P
.505 .664 .505 r
s
.305 .343 .243 r
.52081 .30091 m .51676 .2793 L .54922 .28077 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.7085 .41626 m .71775 .45737 L .68764 .45559 L p F P
.505 .664 .505 r
s
.385 .477 .318 r
.68764 .45559 m .67935 .41291 L .7085 .41626 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.71775 .54263 m .7085 .58374 L .67935 .58709 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71118 .58306 m
.71468 .5825 L
s
.5 Mabswid
.497 .66 .462 r
.66602 .62642 m .67935 .58709 L .7085 .58374 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6975 .60833 m
.69844 .61183 L
s
.5 Mabswid
.63 .856 .647 r
.47919 .69909 m .48324 .7207 L .45078 .71923 L p F P
.505 .664 .505 r
s
.63 .856 .647 r
.45078 .71923 m .43899 .69745 L .47919 .69909 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.43899 .30255 m .45078 .28077 L .48324 .2793 L p F P
.505 .664 .505 r
s
.265 .291 .21 r
.45078 .28077 m .43899 .30255 L .40284 .30569 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6975 .60833 m
.69856 .60232 L
s
.5 Mabswid
.444 .557 .432 r
.32065 .41291 m .31236 .45559 L .28225 .45737 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.27912 .5 m .28225 .45737 L .31236 .45559 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.30955 .5 m .31236 .54441 L .28225 .54263 L p F P
.505 .664 .505 r
s
.523 .677 .527 r
.28225 .54263 m .27912 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.71775 .45737 m .72088 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
.423 .536 .361 r
.69045 .5 m .68764 .45559 L .71775 .45737 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.72088 .5 m .71775 .54263 L .68764 .54441 L p F P
.505 .664 .505 r
s
.482 .631 .437 r
.67935 .58709 m .68764 .54441 L .71775 .54263 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70793 .58585 m
.71118 .58306 L
s
.7038 .59097 m
.70793 .58585 L
s
.5 Mabswid
.618 .84 .624 r
.51676 .7207 m .52081 .69909 L .56101 .69745 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.52081 .69909 m .51676 .7207 L .48324 .7207 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.51676 .2793 m .52081 .30091 L .47919 .30091 L p F P
.505 .664 .505 r
s
.308 .348 .246 r
.47919 .30091 m .48324 .2793 L .51676 .2793 L p F P
.505 .664 .505 r
s
.631 .857 .642 r
.48324 .7207 m .47919 .69909 L .52081 .69909 L p F P
.505 .664 .505 r
s
.296 .331 .235 r
.48324 .2793 m .47919 .30091 L .43899 .30255 L p F P
.505 .664 .505 r
s
.489 .624 .484 r
.31236 .45559 m .30955 .5 L .27912 .5 L p F P
.505 .664 .505 r
s
.457 .589 .403 r
.68764 .54441 m .69045 .5 L .72088 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69856 .60232 m
.70013 .59798 L
s
.70013 .59798 m
.7038 .59097 L
s
.5 Mabswid
.314 .362 .27 r
.40284 .30569 m .38619 .33462 L .35168 .33895 L p F P
.505 .664 .505 r
s
.397 .478 .36 r
.33398 .37358 m .35168 .33895 L .38619 .33462 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.3722 .63023 m .38619 .66538 L .35168 .66105 L p F P
.505 .664 .505 r
s
.62 .828 .635 r
.35168 .66105 m .33398 .62642 L .3722 .63023 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.64832 .33895 m .66602 .37358 L .6278 .36977 L p F P
.505 .664 .505 r
s
.369 .44 .3 r
.6278 .36977 m .61381 .33462 L .64832 .33895 L p F P
.505 .664 .505 r
s
.576 .769 .553 r
.66602 .62642 m .64832 .66105 L .61381 .66538 L p F P
.505 .664 .505 r
s
.567 .768 .556 r
.59716 .69431 m .61381 .66538 L .64832 .66105 L p F P
.505 .664 .505 r
s
.614 .826 .604 r
.61381 .66538 m .59716 .69431 L .56101 .69745 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.42833 .66851 m .43899 .69745 L .40284 .69431 L p F P
.505 .664 .505 r
s
.641 .862 .655 r
.40284 .69431 m .38619 .66538 L .42833 .66851 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.59716 .30569 m .61381 .33462 L .57167 .33149 L p F P
.505 .664 .505 r
s
.353 .413 .285 r
.57167 .33149 m .56101 .30255 L .59716 .30569 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.38619 .33462 m .40284 .30569 L .43899 .30255 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68511 .61213 m
.68823 .60783 L
s
.68823 .60783 m
.68977 .60359 L
s
.68274 .61434 m
.68511 .61213 L
s
.6787 .61674 m
.68274 .61434 L
s
.69169 .58787 m
.69352 .59231 L
s
.5 Mabswid
.397 .478 .36 r
.38619 .33462 m .3722 .36977 L .33398 .37358 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.32065 .41291 m .33398 .37358 L .3722 .36977 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.36161 .58993 m .3722 .63023 L .33398 .62642 L p F P
.505 .664 .505 r
s
.616 .814 .622 r
.33398 .62642 m .32065 .58709 L .36161 .58993 L p F P
.505 .664 .505 r
s
.572 .753 .538 r
.67935 .58709 m .66602 .62642 L .6278 .63023 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67357 .6174 m
.6787 .61674 L
s
.5 Mabswid
.576 .769 .553 r
.61381 .66538 m .6278 .63023 L .66602 .62642 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.66602 .37358 m .67935 .41291 L .63839 .41007 L p F P
.505 .664 .505 r
s
.417 .51 .346 r
.63839 .41007 m .6278 .36977 L .66602 .37358 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68898 .58574 m
.69169 .58787 L
s
.5 Mabswid
.614 .826 .604 r
.56101 .69745 m .57167 .66851 L .61381 .66538 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.57167 .66851 m .56101 .69745 L .52081 .69909 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.56101 .30255 m .57167 .33149 L .52448 .32984 L p F P
.505 .664 .505 r
s
.376 .444 .307 r
.52448 .32984 m .52081 .30091 L .56101 .30255 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.47552 .67016 m .47919 .69909 L .43899 .69745 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.43899 .69745 m .42833 .66851 L .47552 .67016 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.42833 .33149 m .43899 .30255 L .47919 .30091 L p F P
.505 .664 .505 r
s
.365 .429 .314 r
.43899 .30255 m .42833 .33149 L .38619 .33462 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67073 .61585 m
.67357 .6174 L
s
.5 Mabswid
.414 .5 .344 r
.61381 .33462 m .6278 .36977 L .58067 .36699 L p F P
.505 .664 .505 r
s
.414 .5 .344 r
.58067 .36699 m .57167 .33149 L .61381 .33462 L p F P
.505 .664 .505 r
s
.62 .823 .599 r
.6278 .63023 m .61381 .66538 L .57167 .66851 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.3722 .36977 m .38619 .33462 L .42833 .33149 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.41933 .63301 m .42833 .66851 L .38619 .66538 L p F P
.505 .664 .505 r
s
.648 .861 .651 r
.38619 .66538 m .3722 .63023 L .41933 .63301 L p F P
.505 .664 .505 r
s
.641 .859 .634 r
.52081 .69909 m .52448 .67016 L .57167 .66851 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.52448 .67016 m .52081 .69909 L .47919 .69909 L p F P
.505 .664 .505 r
s
.653 .874 .651 r
.47919 .69909 m .47552 .67016 L .52448 .67016 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.52081 .30091 m .52448 .32984 L .47552 .32984 L p F P
.505 .664 .505 r
s
.393 .466 .329 r
.47552 .32984 m .47919 .30091 L .52081 .30091 L p F P
.505 .664 .505 r
s
.389 .462 .332 r
.47919 .30091 m .47552 .32984 L .42833 .33149 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.35499 .54593 m .36161 .58993 L .32065 .58709 L p F P
.505 .664 .505 r
s
.602 .787 .6 r
.32065 .58709 m .31236 .54441 L .35499 .54593 L p F P
.505 .664 .505 r
s
.461 .57 .431 r
.3722 .36977 m .36161 .41007 L .32065 .41291 L p F P
.505 .664 .505 r
s
.511 .643 .487 r
.31236 .45559 m .32065 .41291 L .36161 .41007 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.67935 .41291 m .68764 .45559 L .64501 .45407 L p F P
.505 .664 .505 r
s
.466 .582 .401 r
.64501 .45407 m .63839 .41007 L .67935 .41291 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.68764 .54441 m .67935 .58709 L .63839 .58993 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68361 .58625 m
.68898 .58574 L
s
.5 Mabswid
.572 .753 .538 r
.6278 .63023 m .63839 .58993 L .67935 .58709 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66845 .61219 m
.67073 .61585 L
s
.66864 .60598 m
.68977 .60359 L
s
.67921 .58909 m
.68361 .58625 L
s
.66845 .61219 m
.66864 .60598 L
s
.67402 .59431 m
.67921 .58909 L
s
.66864 .60598 m
.67002 .60151 L
s
.67002 .60151 m
.67402 .59431 L
s
.5 Mabswid
.511 .643 .487 r
.36161 .41007 m .35499 .45407 L .31236 .45559 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.30955 .5 m .31236 .45559 L .35499 .45407 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.35274 .5 m .35499 .54593 L .31236 .54441 L p F P
.505 .664 .505 r
s
.58 .749 .57 r
.31236 .54441 m .30955 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.68764 .45559 m .69045 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.504 .64 .446 r
.64726 .5 m .64501 .45407 L .68764 .45559 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.69045 .5 m .68764 .54441 L .64501 .54593 L p F P
.505 .664 .505 r
s
.557 .725 .514 r
.63839 .58993 m .64501 .54593 L .68764 .54441 L p F P
.505 .664 .505 r
s
.55 .702 .533 r
.35499 .45407 m .35274 .5 L .30955 .5 L p F P
.505 .664 .505 r
s
.534 .688 .483 r
.64501 .54593 m .64726 .5 L .69045 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6488 .61802 m
.65292 .6116 L
s
.6438 .6204 m
.6488 .61802 L
s
.65292 .6116 m
.65917 .58815 L
s
.5 Mabswid
.62 .823 .599 r
.57167 .66851 m .58067 .63301 L .6278 .63023 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.57167 .33149 m .58067 .36699 L .52759 .36552 L p F P
.505 .664 .505 r
s
.448 .546 .384 r
.52759 .36552 m .52448 .32984 L .57167 .33149 L p F P
.505 .664 .505 r
s
.645 .854 .627 r
.58067 .63301 m .57167 .66851 L .52448 .67016 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.41933 .36699 m .42833 .33149 L .47552 .32984 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.47241 .63448 m .47552 .67016 L .42833 .66851 L p F P
.505 .664 .505 r
s
.658 .872 .652 r
.42833 .66851 m .41933 .63301 L .47241 .63448 L p F P
.505 .664 .505 r
s
.442 .538 .397 r
.42833 .33149 m .41933 .36699 L .3722 .36977 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.63839 .58993 m .6278 .63023 L .58067 .63301 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63707 .62094 m
.6438 .6204 L
s
.5 Mabswid
.471 .583 .407 r
.6278 .36977 m .63839 .41007 L .58751 .40799 L p F P
.505 .664 .505 r
s
.471 .583 .407 r
.58751 .40799 m .58067 .36699 L .6278 .36977 L p F P
.505 .664 .505 r
s
.5 .621 .46 r
.36161 .41007 m .3722 .36977 L .41933 .36699 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.41249 .59201 m .41933 .63301 L .3722 .63023 L p F P
.505 .664 .505 r
s
.642 .844 .636 r
.3722 .63023 m .36161 .58993 L .41249 .59201 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63303 .61926 m
.63707 .62094 L
s
.62755 .61344 m
.63303 .61926 L
s
.5 Mabswid
.645 .854 .627 r
.52448 .67016 m .52759 .63448 L .58067 .63301 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.52448 .32984 m .52759 .36552 L .47241 .36552 L p F P
.505 .664 .505 r
s
.463 .566 .405 r
.47241 .36552 m .47552 .32984 L .52448 .32984 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.52759 .63448 m .52448 .67016 L .47552 .67016 L p F P
.505 .664 .505 r
s
.656 .869 .644 r
.47552 .67016 m .47241 .63448 L .52759 .63448 L p F P
.505 .664 .505 r
s
.462 .564 .41 r
.47552 .32984 m .47241 .36552 L .41933 .36699 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62344 .61991 m
.62755 .61344 L
s
.61796 .62225 m
.62344 .61991 L
s
.39612 .6361 m
.40192 .61554 L
s
.3812 .61371 m
.39612 .6361 L
s
.38013 .6121 m
.3812 .61371 L
s
.5 Mabswid
.515 .647 .457 r
.63839 .41007 m .64501 .45407 L .5918 .45295 L p F P
.505 .664 .505 r
s
.515 .647 .457 r
.5918 .45295 m .58751 .40799 L .63839 .41007 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.64501 .54593 m .63839 .58993 L .58751 .59201 L p F P
.505 .664 .505 r
s
.614 .806 .583 r
.58067 .63301 m .58751 .59201 L .63839 .58993 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62755 .61344 m
.63285 .58966 L
s
.61039 .62269 m
.61796 .62225 L
s
.5 Mabswid
.627 .817 .614 r
.4082 .54705 m .41249 .59201 L .36161 .58993 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.37964 .61137 m
.38013 .6121 L
s
.40192 .61554 m
.40311 .61131 L
s
.5 Mabswid
.627 .817 .614 r
.36161 .58993 m .35499 .54593 L .4082 .54705 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.36512 .58956 m
.37964 .61137 L
s
.5 Mabswid
.5 .621 .46 r
.41933 .36699 m .41249 .40799 L .36161 .41007 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.35499 .45407 m .36161 .41007 L .41249 .40799 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.60571 .62093 m
.61039 .62269 L
s
.37634 .60708 m
.40292 .60834 L
s
.59909 .61495 m
.60571 .62093 L
s
.5 Mabswid
.637 .835 .61 r
.58751 .59201 m .58067 .63301 L .52759 .63448 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.58067 .36699 m .58751 .40799 L .52996 .40688 L p F P
.505 .664 .505 r
s
.502 .623 .443 r
.52996 .40688 m .52759 .36552 L .58067 .36699 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.47004 .59312 m .47241 .63448 L .41933 .63301 L p F P
.505 .664 .505 r
s
.651 .853 .636 r
.41933 .63301 m .41249 .59201 L .47004 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.41249 .40799 m .41933 .36699 L .47241 .36552 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.57026 .63772 m
.57264 .63938 L
s
.57264 .63938 m
.5757 .63751 L
s
.5 Mabswid
.55 .7 .497 r
.64501 .45407 m .64726 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.55 .7 .497 r
.59326 .5 m .5918 .45295 L .64501 .45407 L p F P
.505 .664 .505 r
s
.578 .743 .531 r
.64726 .5 m .64501 .54593 L .5918 .54705 L p F P
.505 .664 .505 r
s
.599 .778 .56 r
.58751 .59201 m .5918 .54705 L .64501 .54593 L p F P
.505 .664 .505 r
s
.544 .686 .511 r
.41249 .40799 m .4082 .45295 L .35499 .45407 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.35274 .5 m .35499 .45407 L .4082 .45295 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.40674 .5 m .4082 .54705 L .35499 .54593 L p F P
.505 .664 .505 r
s
.606 .782 .586 r
.35499 .54593 m .35274 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59832 .61797 m
.60327 .5909 L
s
.59733 .62337 m
.59832 .61797 L
s
.57334 .63582 m
.5757 .63751 L
s
.57026 .63772 m
.57334 .63582 L
s
.5 Mabswid
.578 .743 .531 r
.5918 .54705 m .59326 .5 L .64726 .5 L p F P
.505 .664 .505 r
s
.579 .739 .552 r
.4082 .45295 m .40674 .5 L .35274 .5 L p F P
.505 .664 .505 r
s
.637 .835 .61 r
.52759 .63448 m .52996 .59312 L .58751 .59201 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.52996 .59312 m .52759 .63448 L .47241 .63448 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.52759 .36552 m .52996 .40688 L .47004 .40688 L p F P
.505 .664 .505 r
s
.516 .642 .463 r
.47004 .40688 m .47241 .36552 L .52759 .36552 L p F P
.505 .664 .505 r
s
.648 .85 .627 r
.47241 .63448 m .47004 .59312 L .52996 .59312 L p F P
.505 .664 .505 r
s
.516 .642 .469 r
.47241 .36552 m .47004 .40688 L .41249 .40799 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.43333 .62251 m
.43938 .62474 L
s
.42697 .6181 m
.43333 .62251 L
s
.4231 .61135 m
.42697 .6181 L
s
.43938 .62474 m
.44808 .62496 L
s
.5 Mabswid
.622 .808 .588 r
.5918 .54705 m .58751 .59201 L .52996 .59312 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.57654 .61642 m
.58006 .59161 L
s
.57542 .62427 m
.57654 .61642 L
s
.5 Mabswid
.543 .684 .49 r
.58751 .40799 m .5918 .45295 L .53144 .45236 L p F P
.505 .664 .505 r
s
.543 .684 .49 r
.53144 .45236 m .52996 .40688 L .58751 .40799 L p F P
.505 .664 .505 r
s
.557 .703 .516 r
.4082 .45295 m .41249 .40799 L .47004 .40688 L p F P
.505 .664 .505 r
s
.636 .826 .614 r
.46856 .54764 m .47004 .59312 L .41249 .59201 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.42407 .61672 m
.42514 .62429 L
s
.5 Mabswid
.636 .826 .614 r
.41249 .59201 m .4082 .54705 L .46856 .54764 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.42053 .59163 m
.42407 .61672 L
s
.40588 .60149 m
.40876 .5913 L
s
.40311 .61131 m
.40588 .60149 L
s
.54981 .62295 m
.55346 .61645 L
s
.5437 .62514 m
.54981 .62295 L
s
.53482 .62529 m
.5437 .62514 L
s
.529 .62331 m
.53482 .62529 L
s
.4716 .62332 m
.47772 .62545 L
s
.47772 .62545 m
.48674 .62552 L
s
.52024 .61695 m
.529 .62331 L
s
.4653 .61898 m
.4716 .62332 L
s
.48674 .62552 m
.49273 .62348 L
s
.46178 .61223 m
.4653 .61898 L
s
.49273 .62348 m
.49878 .61923 L
s
.46145 .60755 m
.46178 .61223 L
s
.46145 .60755 m
.46408 .60022 L
s
.5 Mabswid
.576 .733 .528 r
.5918 .45295 m .59326 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
.576 .733 .528 r
.53195 .5 m .53144 .45236 L .5918 .45295 L p F P
.505 .664 .505 r
s
.602 .774 .561 r
.59326 .5 m .5918 .54705 L .53144 .54764 L p F P
.505 .664 .505 r
s
.622 .808 .588 r
.52996 .59312 m .53144 .54764 L .5918 .54705 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.55346 .61645 m
.55575 .59214 L
s
.5 Mabswid
.557 .703 .516 r
.47004 .40688 m .46856 .45236 L .4082 .45295 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.40674 .5 m .4082 .45295 L .46856 .45236 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.46805 .5 m .46856 .54764 L .4082 .54705 L p F P
.505 .664 .505 r
s
.615 .793 .587 r
.4082 .54705 m .40674 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.46408 .60022 m
.4701 .59513 L
s
.5 Mabswid
.634 .823 .605 r
.53144 .54764 m .52996 .59312 L .47004 .59312 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.51923 .6389 m
.52027 .61319 L
s
.5 Mabswid
.556 .701 .509 r
.52996 .40688 m .53144 .45236 L .46856 .45236 L p F P
.505 .664 .505 r
s
.556 .701 .509 r
.46856 .45236 m .47004 .40688 L .52996 .40688 L p F P
.505 .664 .505 r
s
.634 .823 .605 r
.47004 .59312 m .46856 .54764 L .53144 .54764 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.52027 .61319 m
.52111 .59255 L
s
.5 Mabswid
.602 .774 .561 r
.53144 .54764 m .53195 .5 L .59326 .5 L p F P
.505 .664 .505 r
s
.589 .752 .555 r
.46856 .45236 m .46805 .5 L .40674 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.49234 .59527 m
.49873 .60044 L
s
.4701 .59513 m
.47634 .59254 L
s
.48591 .59259 m
.49234 .59527 L
s
.47634 .59254 m
.48591 .59259 L
s
.5 Mabswid
.588 .75 .547 r
.53144 .45236 m .53195 .5 L .46805 .5 L p F P
.505 .664 .505 r
s
.588 .75 .547 r
.46805 .5 m .46856 .45236 L .53144 .45236 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.53195 .5 m .53144 .54764 L .46856 .54764 L p F P
.505 .664 .505 r
s
.613 .79 .578 r
.46856 .54764 m .46805 .5 L .53195 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?40/>3V4@21ZH7a0;3PiP40oooo003U0;3PiPd0PJV10P0S9Qd0
0`21ZH409BPN02DX7P0602DX7P04086YP@0T9ah092LN02@W7Pd0PJV1i@2`h>H10?ooo`00h@2`h>H2
086YP@0301TM5P21ZH40PJV100D07b8J0P21ZH4702<V7@03086YP@0U:1h09BPN00L09BPN00<0PJV1
02@W7P0T9ah01@0T9ah2086YP@D08B@K1@21ZH7Q0;3PiP40oooo003M0;3PiP<0PJV10P0I7AH2086Y
P@D07b8J0P21ZH4802<V7@03086YP@0U:1h09BPN00P09BPN00<0PJV102@W7P0T9ah01`0T9ah2086Y
P@D08B@K0P21ZH400`0L7aP0PJV1086YP@02086YPMd0/>3V0@3oool00=T0/>3V0`21ZH4401TM5P80
PJV10`0O8QXY086YP@<08B@K0P21ZH4201`O60D0PJV1f@2`h>H10?ooo`00eP2`h>H3086YP@D06AdF
1`21ZH400`0`<RH0PJV103Df:@0;03Df:@03086YP@0g>2/0=cP[00T0=cP[00<0PJV103Hh:P0f>2X0
2P0f>2X00`21ZH40<c@X086YP@06086YP@<071lH1@21ZH7F0;3PiP40oooo003C0;3PiP<0PJV10P0I
7AH7086YP@H0<38V00<0PJV103Df:@0e=RT02P0e=RT00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0f
>2X0=SPZ00X0=SPZ00<0PJV103<d:00c=2P0100c=2P7086YP@0301`O6021ZH40PJV10080PJV1d`2`
h>H10?ooo`00d02`h>H8086YP@80:2/Q0P21ZH48030b9P03086YP@0e=RT0=CHY00/0=CHY00<0PJV1
03Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0;03Hh:P03086YP@0c=2P0<c@X00H0<c@X0P21ZH42
02d_8`P0PJV1d02`h>H10?ooo`00c@2`h>H5086YP@L0:2/Q00<0PJV1030b9P0`<RH01`0`<RH00`21
ZH40=CHY03Df:@0<03Df:@03086YP@0g>2/0=cP[00/0=cP[00<0PJV103Hh:P0f>2X02`0f>2X00`21
ZH40<c@X03<d:00803<d:003086YP@0];b<0;BlS00D0;BlS1@21ZH7=0;3PiP40oooo003:0;3PiP<0
PJV100<07R4I086YP@21ZH40200X:b400`21ZH40<38V030b9P08030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X00<0PJV102d_8`0];b<01P0];b<2086YP@0402<V7021ZH40PJV1086YPLX0/>3V0@3oool00<P0
/>3V0`21ZH4201hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH4:030b9P03086YP@0e=RT0=CHY00`0
=CHY00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=SPZ03Hh:P0<03Hh:P03086YP@0c=2P0<c@X00P0
<c@X0P21ZH4802d_8`03086YP@0S9Q`08bHL00<0PJV1b02`h>H10?ooo`00aP2`h>H3086YP@807R4I
0P21ZH4802P[8@03086YP@0`<RH0<38V00T0<38V00<0PJV103Df:@0e=RT01@0e=RTQ086YP@L0=SPZ
00<0PJV103<d:00c=2P02@0c=2P00`21ZH40;BlS02d_8`0602d_8`80PJV10P0S9Q`3086YPLH0/>3V
0@3oool00<@0/>3V0`21ZH4301hQ6@03086YP@0X:b40:2/Q00H0:2/Q0P21ZH45030b9Pl0PJV1201;
E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>Ech0CULn00H0CULn3`21ZH4503<d:080PJV1200]
;b<01021ZH408bHL02<V700S9Q`3086YPL@0/>3V0@3oool00<80/>3V0`21ZH4301hQ6@80PJV11@0X
:b4;086YP@D0@dXe00<0PJV104]D?01;E3`03`1;E3`00`21ZH40CUTn04iI?P0=04iI?P03086YP@1>
Ech0CULn00h0CULn00<0PJV104Q@>@18D3T01018D3T;086YP@D0;BlS0P21ZH4302<V70<0PJV1`P2`
h>H10?ooo`00`02`h>H3086YP@<07R4I0P21ZH400`0X:b40PJV1086YP@04086YP@80=STZ00<0PJV1
04=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00>04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV1
04iG?P1>Ech03P1>Ech00`21ZH40B50i04Q@>@0;04Q@>@03086YP@0m@S00?D8`00H0PJV100<0;BlS
086YP@21ZH400`0S9Q`3086YPL00/>3V0@3oool00;l0/>3V0P21ZH4201hQ6@H0PJV11`0f>BX00`21
ZH40@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21
ZH40CULn04iG?P0>04iG?P03086YP@18D3T0B50i00`0B50i00<0PJV103e2<00m@S001@0m@S06086Y
P@808bHL0P21ZH6o0;3PiP40oooo002m0;3PiPH0PJV100<0:B/Q086YP@0f>BX02P0f>BX00`21ZH40
@dXe04=:=@0;04=:=@03086YP@1;E3`0Be@l00l0Be@l00<0PJV104iI?P1>FCh03`1>FCh00`21ZH40
CULn04iG?P0?04iG?P03086YP@18D3T0B50i00/0B50i00<0PJV103e2<00m@S002@0m@S000`21ZH40
;c4U086YP@05086YPKd0/>3V0@3oool00;/0/>3V1021ZH4402T[8@03086YP@0f>BX0=STZ00T0=STZ
00<0PJV104=:=@13BSD02`13BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn00l0CUTn
00<0PJV104iG?P1>Ech03`1>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m@S00?D8`00T0?D8`
00<0PJV102la9@0_<BD00P0_<BD4086YPK/0/>3V0@3oool00;T0/>3V0`21ZH4602T[8@03086YP@0f
>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00@04]D?003086YP@1>
FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0<04Q@>@03086YP@0m
@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD3086YPKT0/>3V0@3oool00;L0/>3V1021ZH46
02T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03013BSD00`21ZH40Be@l04]D?00A
04]D?003086YP@1>FCh0CUTn00l0CUTn00<0PJV104iG?P1>Ech0401>Ech00`21ZH40B50i04Q@>@0=
04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086YPKL0/>3V0@3oool0
0;H0/>3V1021ZH4602T[8@03086YP@0f>BX0=STZ00T0=STZ00<0PJV104=:=@13BSD03@13BSD00`21
ZH40Be@l04]D?00@04]D?003086YP@1>FCh0CUTn0140CUTn00<0PJV104iG?P1>Ech0401>Ech00`21
ZH40B50i04Q@>@0=04Q@>@03086YP@0m@S00?D8`00T0?D8`00<0PJV102la9@0_<BD0100_<BD4086Y
PKH0/>3V0@3oool00;D0/>3V00<0PJV101TM5P21ZH401`0Y:b400`21ZH40=STZ03Hi:P0903Hi:P03
086YP@13BSD0@dXe00d0@dXe00<0PJV104]D?01;E3`04@1;E3`00`21ZH40CUTn04iI?P0A04iI?P03
086YP@1>Ech0CULn0100CULn00<0PJV104Q@>@18D3T03P18D3T00`21ZH40?D8`03e2<00903e2<003
086YP@0_<BD0;c4U00D0;c4U00<0PJV1020S6`21ZH40]@2`h>H10?ooo`00/`2`h>H2086YP@0301TM
5P21ZH40:B/Q00H0:B/Q00<0PJV103Hi:P0f>BX02P0f>BX00`21ZH40@dXe04=:=@0904=:=DD0PJV1
2`18D3T00`21ZH40?D8`03e2<00:03e2<003086YP@0_<BD0;c4U00D0;c4U00@0PJV1020S6`21ZH40
PJV1/`2`h>H10?ooo`00/P2`h>H01021ZH406AdF01TM5P21ZH4702T[8@03086YP@0f>BX0=STZ00X0
=STZ00@0PJV104=:=@13BSD0@dXe2@21ZH4405e]D003086YP@1SMU@0HgID0140HgID00<0PJV106Ag
E01TMe@04@1TMe@00`21ZH40H75>061aCP0A061aCP03086YP@1JJDP0FVU80080FVU82@21ZH4304Q@
>@03086YP@0m@S00?D8`00X0?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S6`21ZH6b
0;3PiP40oooo002a0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0PJV103Hi:P0f>BX01`0f>BX8
086YP@`0GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0
H75>0180H75>00<0PJV105YYB01JJDP02P1JJDP8086YP@T0?D8`00<0PJV102la9@0_<BD01@0_<BD0
1021ZH4082<K020S6`21ZH6a0;3PiP40oooo002`0;3PiP04086YP@0I7AH06AdF086YP@L0:B/Q00<0
PJV103Hi:P0f>BX02021ZH42051LA@03086YP@1MKE00GFe@00l0GFe@00<0PJV106=fE01SMU@04P1S
MU@00`21ZH40I7MD06AgE00A06AgE003086YP@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP03`1J
JDP00`21ZH40D5a0051L@008086YP@80?D8`00<0PJV102la9@0_<BD01@0_<BD01021ZH4082<K020S
6`21ZH6`0;3PiP40oooo002^0;3PiP80PJV100<06AdF086YP@21ZH401P0Y:b45086YP@X0D5a500<0
PJV105e]D01MKE003P1MKE000`21ZH40HgID06=fE00B06=fE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1061aCP1PLDh04P1PLDh00`21ZH40FVU805YYB00>05YYB003086YP@1@G400D5a000P0D5a01@21
ZH4602la9@80PJV100<082<K086YP@21ZH40[P2`h>H10?ooo`00[@2`h>H01021ZH406AdF01TM5P21
ZH4402T[8@D0PJV13@1@G4D00`21ZH40GFe@05e]D00?05e]D003086YP@1SMU@0HgID0180HgID00<0
PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0B061aCP03086YP@1JJDP0FVU800l0FVU800<0
PJV1051L@01@G4002`1@G405086YP@@0;c4U00@0PJV1020S6`0P8a/0PJV1[@2`h>H10?ooo`00[02`
h>H01@21ZH406AdF01TM5P21ZH40:B/Q00@0PJV1100i?c400`21ZH40D5a5051LA@0:051LA@03086Y
P@1MKE00GFe@0100GFe@00<0PJV106=fE01SMU@04P1SMU@00`21ZH40I7MD06AgE00C06AgE003086Y
P@1PLDh0H75>0180H75>00<0PJV105YYB01JJDP0401JJDP00`21ZH40D5a0051L@00:051L@003086Y
P@0oAS80?dHb0080?dHb1021ZH401@0_<BD0PJV1020S6`0P8a/0PJV10:`0/>3V0@3oool00:/0/>3V
00<0PJV101TM5P21ZH400`21ZH4703To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00
3`1MKE000`21ZH40HgID06=fE00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh0
4`1PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS80
1@0oAS84086YP@03020S6`21ZH40/>3V0:X0/>3V0@3oool00:T0/>3V00<0PJV101TM5P21ZH400P21
ZH4903To<@03086YP@1@G4D0D5a500/0D5a500<0PJV105e]D01MKE00401MKE000`21ZH40HgID06=f
E00C06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1061aCP1PLDh04`1PLDh00`21ZH40FVU805YY
B00@05YYB003086YP@1@G400D5a000/0D5a000<0PJV103m6<P0oAS801`0oAS85086YPJT0/>3V0@3o
ool00:P0/>3V0`21ZH400`0Q91`0PJV103To<@0803To<@03086YP@1@G4D0D5a500/0D5a500<0PJV1
05e]D01MKE00401MKE000`21ZH40HgID06=fE00D06=fE003086YP@1TMe@0I7MD01<0I7MD00<0PJV1
061aCP1PLDh0501PLDh00`21ZH40FVU805YYB00?05YYB003086YP@1@G400D5a000`0D5a000<0PJV1
03m6<P0oAS801`0oAS800`21ZH40:B/Q086YP@02086YPJP0/>3V0@3oool00:L0/>3V0P21ZH42024T
7003086YP@0i?c40>Cla00P0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00@05e]
D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@04`1TMe@00`21ZH40H75>061aCP0D061a
CP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6
<P03086YP@0Y:b40:B/Q0080PJV1Y`2`h>H10?ooo`00YP2`h>H00`21ZH408B@L024T7002024T7003
086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D02`1@G4D00`21ZH40GFe@05e]D00A05e]D003
086YP@1SMU@0HgID01<0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>061aCP0C061aCP03
086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0703m6<P03
086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0Y02`h>H10?ooo`00Y@2`h>H00`21ZH408B@L
024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@
05e]D00@05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1TMe@00`21ZH40H75>
061aCP0D061aCP03086YP@1JJDP0FVU80100FVU800<0PJV1051L@01@G400301@G4000`21ZH40?dHb
03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0X`2`h>H10?ooo`00Y02`
h>H00`21ZH408B@L024T7002024T7003086YP@0i?c40>Cla00L0>Cla00<0PJV1051LA@1@G4D0301@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID01@0HgID00<0PJV106AgE01TMe@05@1T
Me@00`21ZH40H75>061aCP0D061aCP03086YP@1JJDP0FVU80140FVU800<0PJV1051L@01@G400301@
G4000`21ZH40?dHb03m6<P0703m6<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0XP2`
h>H10?ooo`00Y02`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla00<0PJV1051LA@1@G4D02`1@
G4D00`21ZH40GFe@05e]D00A05e]D003086YP@1SMU@0HgID00X0HgID;`21ZH4<061aCP03086YP@1J
JDP0FVU80140FVU800<0PJV1051L@01@G4002`1@G4000`21ZH40?dHb03m6<P0803m6<P05086YP@0Y
:b40:B/Q02T[8@21ZH40Y02`h>H10?ooo`00X`2`h>H01@21ZH408B@L024T700Q91`0PJV100X0>Cla
00<0PJV1051LA@1@G4D0301@G4D00`21ZH40GFe@05e]D00705e]D1L0PJV12`1fT6P00`21ZH40MY1W
07J@I`0E07J@I`03086YP@1bRf80LX]R00T0LX]R5`21ZH4905YYB003086YP@1@G400D5a000`0D5a0
00<0PJV103m6<P0oAS80200oAS801@21ZH40:B/Q02T[8@0Y:b40PJV10:<0/>3V0@3oool00:80/>3V
00D0PJV1024T700Q91`08B@L086YP@0:03To<@03086YP@1@G4D0D5a500X0D5a53@21ZH4:0769I@03
086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03
086YP@1YOeP0JGmH00P0JGmH3@21ZH4<051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[8@0Y
:b40:B/Q086YP@2R0;3PiP40oooo002Q0;3PiP05086YP@0Q91`08B@L024T7021ZH402P0i?c400`21
ZH40D5a5051LA@05051LA@H0PJV10P1UNU`00`21ZH40LHUU0769I@0B0769I@03086YP@1fT6P0MY1X
01D0MY1X00<0PJV107J@I`1fT6L05@1fT6L00`21ZH40LX]R07:;HP0E07:;HP03086YP@1YOeP0JGmH
0180JGmH00<0PJV105i`C01NL4`01P21ZH47051L@003086YP@0oAS80?dHb00P0?dHb00D0PJV102T[
8@0Y:b40:B/Q086YP@2Q0;3PiP40oooo002P0;3PiP03086YP@0Q91`08B@L00808B@L00<0PJV103To
<@0i?c40200i?c400`21ZH40D5a5086YP@05086YP@L0IGYL00<0PJV10769I@1aRFD04P1aRFD00`21
ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01D0MY1W00<0PJV107:;HP1bRf805P1bRf800`21
ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00D0GW1<1P21ZH400`1@G400PJV103m6<P0903m6
<P03086YP@0Y:b40:B/Q0080:B/Q00<0PJV10;3PiP2`h>H0WP2`h>H10?ooo`00W`2`h>H00`21ZH40
8B@L024T7002024T7003086YP@0i?c40>Cla00D0>Cla1P21ZH4=06EjG003086YP@1aRFD0LHUU0180
LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01D0
LX]R00<0PJV106UoF01YOeP04P1YOeP00`21ZH40GW1<05i`C00;05i`C0H0PJV11`0oAS800`21ZH40
:B/Q02T[8@0202T[8@03086YP@2`h>H0/>3V09d0/>3V0@3oool009h0/>3V00<0PJV1024T700Q91`0
0P0Q91`00`21ZH40>Cla03To<@06086YP@80D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU
0769I@0C0769I@03086YP@1fT6P0MY1X01D0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R
07:;HP0E07:;HP03086YP@1YOeP0JGmH01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o
04iK?`06086YP@80?dHb00<0PJV102T[8@0Y:b400P0Y:b400`21ZH40/>3V0;3PiP2L0;3PiP40oooo
002N0;3PiP03086YP@0Q91`08B@L00D0PJV1201@GTT00`21ZH40IGYL06EjG00=06EjG003086YP@1a
RFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05@1fT6P00`21ZH40MY1W07J@I`0G07J@I`03086YP@1b
Rf80LX]R01D0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`C00=05i`C003086YP@1>
Fcl0CU/o00H0CU/o1@21ZH4202T[8@03086YP@2`h>H0/>3V09`0/>3V0@3oool009d0/>3V00<0PJV1
024T7021ZH400P21ZH4;051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD04P1aRFD0
0`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf80
0`21ZH40JGmH06UoF00B06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl3
086YP@0302T[8@21ZH40/>3V09`0/>3V0@3oool009`0/>3V0`21ZH42030e;@03086YP@1@GTT0D5i9
00T0D5i900<0PJV106EjG01UNU`03@1UNU`00`21ZH40LHUU0769I@0C0769I@03086YP@1fT6P0MY1X
01H0MY1X00<0PJV107J@I`1fT6L05`1fT6L00`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH
01<0JGmH00<0PJV105i`C01NL4`03@1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY
00<0PJV1W02`h>H10?ooo`00V`2`h>H2086YP@<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00@0PJV103@i:@0d>BT0=3TY0P21ZH6K0;3P
iP40oooo002J0;3PiP03086YP@0`=Bd0<3D]00<0<3D]00<0PJV1051NB@1@GTT02@1@GTT00`21ZH40
IGYL06EjG00=06EjG003086YP@1aRFD0LHUU01@0LHUU00<0PJV107J@J01fT6P05P1fT6P00`21ZH40
MY1W07J@I`0G07J@I`03086YP@1bRf80LX]R01H0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40
GW1<05i`C00>05i`C003086YP@1>Fcl0CU/o00T0CU/o00<0PJV103@i:@0d>BT00`0d>BT00`21ZH40
/>3V0;3PiP2H0;3PiP40oooo002I0;3PiP80PJV1100`=Bd00`21ZH40D5i9051NB@09051NB@03086Y
P@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086Y
P@1fT6L0MY1W01L0MY1W00<0PJV107:;HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086Y
P@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl02@1>Fcl00`21ZH40=3TY03@i:@0203@i:@80PJV1
V@2`h>H10?ooo`00V02`h>H2086YP@@0<3D]00<0PJV1051NB@1@GTT02P1@GTT00`21ZH40IGYL06Ej
G00>06EjG003086YP@1aRFD0LHUU01<0LHUU00<0PJV107J@J01fT6P05`1fT6P00`21ZH40MY1W07J@
I`0G07J@I`03086YP@1bRf80LX]R01L0LX]R00<0PJV106UoF01YOeP04`1YOeP00`21ZH40GW1<05i`
C00>05i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i:@0d>BT00P0d>BT2086YPIP0/>3V0@3o
ool009L0/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03P1UNU`0
0`21ZH40LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L0
0`21ZH40LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03P1NL4`0
0`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6G0;3PiP40oooo002G0;3P
iP80PJV1100`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769
I@1aRFD0501aRFD00`21ZH40MY1X07J@J00F07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;
HP1bRf805P1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK
?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i:@03086YP@0I71H0/>3V09H0/>3V0@3oool009H0
/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40
LHUU0769I@0D0769I@03086YP@1fT6P0MY1X01H0MY1X00<0PJV107J@I`1fT6L06@1fT6L00`21ZH40
LX]R07:;HP0F07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0PJV105i`C01NL4`03`1NL4`00`21ZH40
CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6F0;3PiP40oooo002E0;3PiP80PJV1
1@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0IGYL00h0IGYL00<0PJV10769I@1aRFD0
501aRFD00`21ZH40MY1X07J@J00G07J@J003086YP@1fT6L0MY1W01T0MY1W00<0PJV107:;HP1bRf80
5`1bRf800`21ZH40JGmH06UoF00D06UoF003086YP@1NL4`0GW1<00h0GW1<00<0PJV104iK?`1>Fcl0
2P1>Fcl00`21ZH40=3TY03@i:@0303@i:@03086YP@2`h>H0/>3V09@0/>3V0@3oool009D0/>3V0P21
ZH45030e;@03086YP@1@GTT0D5i900T0D5i900<0PJV106EjG01UNU`03`1UNU`00`21ZH40LHUU0769
I@0D0769I@03086YP@1fT6P0MY1X00/0MY1X=@21ZH4=07:;HP03086YP@1YOeP0JGmH01@0JGmH00<0
PJV105i`C01NL4`03`1NL4`00`21ZH40CU/o04iK?`0904iK?`03086YP@0d>BT0=3TY00<0=3TY0P21
ZH6E0;3PiP40oooo002D0;3PiP80PJV11@0`=Bd00`21ZH40D5i9051NB@0:051NB@03086YP@1UNU`0
IGYL00h0IGYL00<0PJV10769I@1aRFD02P1aRFDI086YP@`0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H0
0`21ZH40P9ma082OL@0:082OLAT0PJV1301YOeP00`21ZH40GW1<05i`C00>05i`C003086YP@1>Fcl0
CU/o00X0CU/o00<0PJV103@i:@0d>BT00`0d>BT2086YPI@0/>3V0@3oool009@0/>3V0P21ZH44030e
;@03086YP@1@GTT0D5i900X0D5i900<0PJV106EjG01UNU`02`1UNU`A086YP@/0Oiie00<0PJV108BT
N024Y7P05`24Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01L0P9ma00<0PJV107RE
J01hUFP02@1hUFPA086YP@d0GW1<00<0PJV104iK?`1>Fcl02P1>Fcl00`21ZH40=3TY03@i:@0203@i
:@80PJV1U02`h>H10?ooo`00T`2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT02P1@GTT01021ZH40
IGYL06EjG01UNU`:086YP@@0MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00G08BT
N003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg405`20Wg400`21ZH40N9EX07REJ00E07RE
J003086YP@1ZPUP0JX9H0080JX9H2P21ZH4305i`C003086YP@1>Fcl0CU/o00X0CU/o00<0PJV103@i
:@0d>BT00`0d>BT2086YPI<0/>3V0@3oool00980/>3V0P21ZH45030e;@03086YP@1@GTT0D5i900L0
D5i92021ZH4=07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06024Y7P00`21ZH40
Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP0501hUFP00`21ZH40
JX9H06Z2F00<06Z2F0P0PJV12@1>Fcl00`21ZH40=3TY03@i:@0303@i:@80PJV1TP2`h>H10?ooo`00
TP2`h>H2086YP@D0<3D]00<0PJV1051NB@1@GTT01`21ZH4306=iGP03086YP@1fTFh0MY5^00l0MY5^
00<0PJV107nNM@1oWWD05@1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af
00<0PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H00l0JX9H
00@0PJV105Y/B@1JK4T0FVa91`21ZH4204iK?`03086YP@0d>BT0=3TY00<0=3TY0P21ZH6B0;3PiP40
oooo002A0;3PiP80PJV1100`=Bd5086YP@T0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie
07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma
082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa9
05Y/B@0705Y/B@D0PJV1100d>BT2086YPI40/>3V0@3oool00900/>3V0P21ZH43030e;@80PJV100<0
@Ti1086YP@1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0
PJV108BTN024Y7P06024Y7P00`21ZH40Q:Af08BTMP0I08BTMP03086YP@20Wg40P9ma01P0P9ma00<0
PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900X0FVa900@0
PJV1041;=021ZH40PJV10`0d>BT00`21ZH40/>3V0;3PiP2?0;3PiP40oooo002@0;3PiP03086YP@0`
=Bd0PJV10080PJV10P12CT400`21ZH40HgUN06=iGP0;06=iGP03086YP@1fTFh0MY5^00l0MY5^00<0
PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00H08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0
PJV1082OL@20Wg406020Wg400`21ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0
PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=005086YPI00/>3V0@3oool008l0/>3V0`21ZH45
049>@@03086YP@1SNEh0HgUN00X0HgUN00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E
07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV108BTMP24Y7H06@24Y7H00`21ZH40P9ma082OL@0I
082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV106Z2F01ZPUP03`1ZPUP00`21ZH40FVa905Y/B@0;
05Y/B@03086YP@10Bc@0@4/d00<0@4/d0`21ZH6?0;3PiP40oooo002?0;3PiP80PJV11P12CT400`21
ZH40HgUN06=iGP0:06=iGP03086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05@1oWWD00`21
ZH40Q:Ah08BTN00I08BTN003086YP@24Y7H0Q:Af01T0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21
ZH40N9EX07REJ00E07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1JK4T02P1JK4T00`21
ZH40@4/d041;=004041;=080PJV1S`2`h>H10?ooo`00SP2`h>H2086YP@H0@Ti100<0PJV106=iGP1S
NEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024
Y7P06024Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01h
UFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010
Bc@01010Bc@2086YPHh0/>3V0@3oool008h0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh03`1fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01P0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0H082OL@03086YP@1hUFP0N9EX01D0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0PJV101`P602`h>H0S@2`h>H10?ooo`00S@2`h>H2086YP@H0@Ti100<0PJV106=iGP1SNEh02`1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06024
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01P0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010
Bc@2086YPHd0/>3V0@3oool008d0/>3V0P21ZH46049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV1
07JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0E07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah00<0PJV1
08BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01D0N9EX00<0PJV1
06Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d0P21ZH6=
0;3PiP40oooo002<0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21
ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV108BTN024Y7P06@24Y7P00`21
ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05@1hUFP00`21
ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@00`21
ZH40720H086YP@2<0;3PiP40oooo002<0;3PiP80PJV11P12CT400`21ZH40HgUN06=iGP0;06=iGP03
086YP@1fTFh0MY5^0100MY5^00<0PJV107nNM@1oWWD05P1oWWD00`21ZH40Q:Ah08BTN00I08BTN003
086YP@24Y7H0Q:Af01/0Q:Af00<0PJV1082OL@20Wg406@20Wg400`21ZH40N9EX07REJ00E07REJ003
086YP@1ZPUP0JX9H0140JX9H00<0PJV105Y/B@1JK4T02`1JK4T00`21ZH40@4/d041;=004041;=080
PJV1S02`h>H10?ooo`00R`2`h>H00`21ZH406b<O086YP@06049>@@03086YP@1SNEh0HgUN00/0HgUN
00<0PJV107JAKP1fTFh0401fTFh00`21ZH40Oiie07nNM@0F07nNM@03086YP@24Y7P0Q:Ah01T0Q:Ah
00<0PJV108BTMP24Y7H06`24Y7H00`21ZH40P9ma082OL@0I082OL@03086YP@1hUFP0N9EX01H0N9EX
00<0PJV106Z2F01ZPUP0401ZPUP00`21ZH40FVa905Y/B@0;05Y/B@03086YP@10Bc@0@4/d00@0@4/d
00<0PJV101`P6021ZH40R`2`h>H10?ooo`00R`2`h>H2086YP@L0@Ti100<0PJV106=iGP1SNEh02`1S
NEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie01H0Oiie00<0PJV108BTN024Y7P06@24
Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01T0P9ma00<0PJV107REJ01hUFP05P1h
UFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010
Bc@00`21ZH40720H086YP@2;0;3PiP40oooo002:0;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV1
06=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0A07JAKP03086YP@1oWWD0Oiie01D0Oiie00<0PJV1
08BTN024Y7P06P24Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma01X0P9ma00<0PJV1
07REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00@06Z2F003086YP@1JK4T0FVa900`0FVa900<0PJV1
041;=010Bc@01010Bc@00`21ZH40720H086YP@2:0;3PiP40oooo002:0;3PiP03086YP@0K8al0PJV1
00H0@Ti100<0PJV106=iGP1SNEh02`1SNEh00`21ZH40MY5^07JAKP0@07JAKP03086YP@1oWWD0Oiie
01H0Oiie00<0PJV108BTN024Y7P06P24Y7P00`21ZH40Q:Af08BTMP0K08BTMP03086YP@20Wg40P9ma
01X0P9ma00<0PJV107REJ01hUFP05@1hUFP00`21ZH40JX9H06Z2F00A06Z2F003086YP@1JK4T0FVa9
00/0FVa900<0PJV1041;=010Bc@01010Bc@00`21ZH40720H086YP@2:0;3PiP40oooo002:0;3PiP03
01/S7`21ZH40@Ti100D0@Ti100<0PJV106=iGP1SNEh0301SNEh00`21ZH40MY5^07JAKP0@07JAKP03
086YP@1oWWD0Oiie00X0OiieL@21ZH4<07REJ003086YP@1ZPUP0JX9H0100JX9H00<0PJV105Y/B@1J
K4T0301JK4T00`21ZH40@4/d041;=004041;=080PJV1RP2`h>H10?ooo`00R@2`h>H00`21ZH406b<O
086YP@06049>@@03086YP@1SNEh0HgUN00`0HgUN00<0PJV107JAKP1fTFh0301fTFhA086YP@`0Rjn2
00<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm
00<0PJV108>UM023YG@02P23YG@A086YP@h0JX9H00<0PJV105Y/B@1JK4T0301JK4T00`21ZH40@4/d
041;=004041;=003086YP@0L81P0PJV108T0/>3V0@3oool008T0/>3V0P0K8al00`21ZH40@Ti1049>
@@04049>@@03086YP@1SNEh0HgUN00/0HgUN00<0PJV107JAKP1fTFh00`1fTFh:086YP@@0PZAl00<0
PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80S[>201/0S[>200<0
PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV0080MiAV2P21
ZH4506Z2F003086YP@1JK4T0FVa900/0FVa900<0PJV1041;=010Bc@01010Bc@00`21ZH40720H086Y
P@290;3PiP40oooo00280;3PiP03086YP@0K8al0PJV100H0@Ti100<0PJV106=iGP1SNEh01@1SNEh=
086YP@h0PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80
S[>201/0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0
MiAV00`0MiAV3@21ZH4705Y/B@03086YP@10Bc@0@4/d00@0@4/d00<0PJV101`P6021ZH40R02`h>H1
0?ooo`00R02`h>H201/S7`03086YP@12CT40@Ti100<0@Ti12@21ZH47076>KP03086YP@22Y7`0PZAl
0140PZAl00<0PJV108^_PP2;[h805P2;[h800`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h80S[>2
01/0S[>200<0PJV108^_O@2;[gd06P2;[gd00`21ZH40PjEd08>UM00F08>UM003086YP@1gU6H0MiAV
0140MiAV00<0PJV1069jD@1RNU401@1RNU49086YP@D0@4/d00<0PJV101`P6021ZH40R02`h>H10?oo
o`00Q`2`h>H00`21ZH406b<O086YP@02049>@@@0PJV100<0DFEC086YP@1aSVh03@1aSVh00`21ZH40
PZAl08:TO00@08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40
S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40
MiAV07NDIP0@07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?021ZH400`21ZH42041;=003
086YP@0L81P0PJV108L0/>3V0@3oool008L0/>3V0P0K8al3086YP@D0DFEC00<0PJV1076>KP1aSVh0
2`1aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@0
6`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@0
5P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`0
0`19FC`3086YP@0301`P6021ZH40/>3V08H0/>3V0@3oool008H0/>3V1021ZH46055UD`03086YP@1a
SVh0LHi^00`0LHi^00<0PJV108:TO022Y7`04@22Y7`00`21ZH40Rjn208^_PP0F08^_PP03086YP@2>
/h@0S[>401/0S[>400<0PJV108jcPP2>/h806`2>/h800`21ZH40Rjmm08^_O@0K08^_O@03086YP@23
YG@0PjEd01H0PjEd00<0PJV107NDIP1gU6H04@1gU6H00`21ZH40HWYA069jD@0<069jD@03086YP@19
FC`0BETl00@0BETl1021ZH660;3PiP40oooo00260;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1
076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV1
08jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV1
08>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV1
04UI?019FC`01019FC`01021ZH408RLM028W7@21ZH660;3PiP40oooo00260;3PiP03086YP@0U;R/0
PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80
Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K08jcPP03086YP@2;[gd0
Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1RNU40
HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM028W7@260;3PiP40oooo00250;3P
iP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:TO00B
08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0K
08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0B
07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM028W7@21
ZH650;3PiP40oooo00250;3PiP04086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1aSVh0301a
SVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06P2>
/h@00`21ZH40S[>208jcPP0L08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23
YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019
FC`01021ZH408RLM028W7@21ZH650;3PiP40oooo00250;3PiP03086YP@0U;R/0PJV100L0DFEC00<0
PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;[h80Rjn201L0Rjn200<0
PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0
PJV108>UM023YG@05P23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0
PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH650;3PiP40oooo00250;3PiP03086YP@0U
;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00A08:TO003086YP@2;
[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;
[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0A07NDIP03086YP@1R
NU40HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM086YP@250;3PiP40oooo0024
0;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl08:T
O00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jc
PP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07ND
IP0B07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM028W
7@21ZH640;3PiP40oooo00240;3PiP04086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1aSVh0
301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@0
6P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@0
5`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`0
1019FC`01021ZH408RLM028W7@21ZH640;3PiP40oooo00240;3PiP03086YP@0U;R/0PJV100L0DFEC
00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0Rjn2
00<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01X0Rjmm
00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0HWYA
00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH640;3PiP40oooo00240;3PiP03086Y
P@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086Y
P@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>208jcPP0M08jcPP03086Y
P@2;[gd0Rjmm01X0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086Y
P@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM086YP@240;3PiP40oooo
00230;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40PZAl
08:TO00C08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>2
08jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05P23YG@00`21ZH40MiAV
07NDIP0C07NDIP03086YP@1RNU40HWYA00/0HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM
028W7@21ZH630;3PiP40oooo00230;3PiP04086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1a
SVh0301aSVh00`21ZH40PZAl08:TO00C08:TO003086YP@2;[h80Rjn201H0Rjn200<0PJV108jcQ02>
/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023
YG@05P23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019
FC`01019FC`01021ZH408RLM028W7@21ZH630;3PiP40oooo00230;3PiP03086YP@0U;R/0PJV100L0
DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003086YP@2;[h80Rjn201L0
Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03086YP@2;[gd0Rjmm01/0
Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03086YP@1RNU40HWYA00`0
HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH630;3PiP40oooo00230;3PiP03
086YP@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00B08:TO003
086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>208jcPP0M08jcPP03
086YP@2;[gd0Rjmm01/0Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0B07NDIP03
086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01@19FC`00`21ZH408RLM086YP@230;3PiP40
oooo00220;3PiP04086YP@0U;R/09Bh[086YP@L0DFEC00<0PJV1076>KP1aSVh02`1aSVh00`21ZH40
PZAl08:TO00C08:TO003086YP@2;[h80Rjn201L0Rjn200<0PJV108jcQ02>/h@03@2>/h@m086YP@l0
Rjmm00<0PJV108>UM023YG@05`23YG@00`21ZH40MiAV07NDIP0C07NDIP03086YP@1RNU40HWYA00/0
HWYA00<0PJV104UI?019FC`01@19FC`01021ZH408RLM028W7@21ZH620;3PiP40oooo00220;3PiP04
086YP@0U;R/09Bh[086YP@H0DFEC00<0PJV1076>KP1aSVh0301aSVh00`21ZH40PZAl08:TO00908:T
O3@0PJV13P2F`8h00`21ZH40U[n<09JoS00M09JoS003086YP@2C^hL0Tk^700`0Tk^7=021ZH4;07ND
IP03086YP@1RNU40HWYA00`0HWYA00<0PJV104UI?019FC`01019FC`01021ZH408RLM028W7@21ZH62
0;3PiP40oooo00220;3PiP03086YP@0U;R/0PJV100L0DFEC00<0PJV1076>KP1aSVh01@1aSVhC086Y
P@X0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<
01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b
00P0PJ=b4`21ZH47069jD@03086YP@19FC`0BETl00@0BETl00@0PJV1028W7@0R9ad0PJV1PP2`h>H1
0?ooo`00PP2`h>H202D^:`03086YP@1AIE<0DFEC0080DFEC2`21ZH4707fON`03086YP@2</hP0S;>8
01<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<
01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b
01<0PJ=b00<0PJV106b9G01/RE`01@1/RE`;086YP@@0BETl00<0PJV1028W7@21ZH40PP2`h>H10?oo
o`00P@2`h>H00`21ZH409Bh[086YP@05086YP@<0GWUR00<0PJV107fON`1mWg/0301mWg/00`21ZH40
S;>808bcR00C08bcR003086YP@2D_Hd0U;f=01L0U;f=00<0PJV109K0SP2F`8h06`2F`8h00`21ZH40
U[n<09JoS00M09JoS003086YP@2C^hL0Tk^701/0Tk^700<0PJV108bcO`2</gl05`2</gl00`21ZH40
PJ=b086SLP0C086SLP03086YP@1/RE`0K8UL00`0K8UL00@0PJV1051U@`1@ID<0D6E31P21ZH400`0R
9ad0PJV10;3PiP200;3PiP40oooo00210;3PiP80PJV100<0;CXf086YP@1NNF801P1NNF800`21ZH40
OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40
U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40
S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40
D6E3051U@`05051U@`04086YP@0X<b<0PJV1086YPH40/>3V0@3oool00840/>3V00@0PJV102dj=P0]
>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109Bm
S@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>k
Q`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9
G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool0
0840/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0
:3<S086YPH40/>3V0@3oool00840/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fO
N`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0
SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bc
O`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U
@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201N
NF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D
_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C
^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/
RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH40/>3V0@3oool00840/>3V00<0
PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0
PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0
PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0
PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10840/>3V0@3o
ool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0
PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fO
N`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0K09K0
SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL06`2C^hL00`21ZH40S;=o08bcO`0G08bc
O`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U
@`03086YP@0X<b<0PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40
OImk07fON`0;07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40
U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40
S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b0180PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40
D6E3051U@`06051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00840/>3V00<0PJV102dj=P21ZH40
1`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd0
5`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0
702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0
301/RE`00`21ZH40D6E3051U@`05051U@`03086YP@0X<b<0PJV10840/>3V0@3oool00800/>3V00@0
PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00
/>3V0@3oool00800/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03
086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03
086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03
086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04
086YP@0X<b<0:3<S086YPH00/>3V0@3oool00800/>3V00@0PJV102dj=P0]>SH0PJV11`1NNF800`21
ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21
ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21
ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21
ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3oool00800/>3V00@0PJV102dj
=P0]>SH0PJV11`1NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV1
09BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV1
09>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV1
06b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0:3<S086YPH00/>3V0@3o
ool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0
S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0
U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80
PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`05051U@`04086YP@0X<b<0
:3<S086YPH00/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<
07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L
09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G
08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06
051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj=P21ZH40201NNF800`21
ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D_Hd05`2D_Hd00`21
ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C^hL0702C^hL00`21
ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/RE`0301/RE`00`21
ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V00<0PJV102dj=P21
ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>800<0PJV109BmS@2D
_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<00<0PJV109>kQ`2C
^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b00<0PJV106b9G01/
RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V0@3oool00800/>3V
00<0PJV102dj=P21ZH40201NNF800`21ZH40OImk07fON`0<07fON`03086YP@2</hP0S;>801<0S;>8
00<0PJV109BmS@2D_Hd05`2D_Hd00`21ZH40U/2>09K0SP0L09K0SP03086YP@2F_h`0U[n<01d0U[n<
00<0PJV109>kQ`2C^hL0702C^hL00`21ZH40S;=o08bcO`0G08bcO`03086YP@21Xg80PJ=b01<0PJ=b
00<0PJV106b9G01/RE`0301/RE`00`21ZH40D6E3051U@`06051U@`03086YP@0X<b<0PJV10800/>3V
0@3oool00800/>3Vl`21ZH600;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV1
08F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV1
09g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV1
09>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV1
05A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV1
00P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF
01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?
01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW
00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40oooo00200;3PiP03
086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03
086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03
086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03
086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@200;3PiP40
oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA
09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC
09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k
08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X
086YP@200;3PiP40oooo00200;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025
[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702M
biH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C
_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1D
KDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^
00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF
00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?
00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW
00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086Y
P@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03
086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03
086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03
086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3P
iP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21
ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21
ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21
ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021
ZH40;C/X02dk:021ZH600;3PiP40oooo00200;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV1
08F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV1
09g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV1
09>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV1
05A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH600;3PiP40oooo00210;3PiP03086YP@0hBT<0
PJV100L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0
VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0
V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0
M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3P
iP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH02`25[HH00`21ZH40U;nA09BoT@0C09Bo
T@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0702MbiH00`21ZH40W<ZC09c:T`0M09c:
T`03086YP@2JaXl0V/J?01`0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0B08R`
N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@210;3P
iP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40
U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40
W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40
R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01P1DKDL00`21ZH40
;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0PJV108F]QP25[HH0
3025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0
6`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL0
5`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL0
1P1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0PJV100P0J8Q^00<0
PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0
PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0
PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0
PJV105A]A`1DKDL01P1DKDL00`21ZH40;C/X086YP@210;3PiP40oooo00210;3PiP03086YP@0hBT<0
PJV100P0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0
VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0
V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0
M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo0021
0;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09Bo
T@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:
T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`
N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk
:021ZH610;3PiP40oooo00210;3PiP04086YP@0hBT<0>4Y3086YP@L0J8Q^00<0PJV108F]QP25[HH0
3025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH0
6`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL0
5`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0M9IW00<0PJV105A]A`1DKDL0
1@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP04086YP@0hBT<0>4Y3086YP@L0
J8Q^00<0PJV108F]QP25[HH03025[HH00`21ZH40U;nA09BoT@0C09BoT@03086YP@2Kb9H0VlRF01L0
VlRF00<0PJV109g;UP2MbiH06`2MbiH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0
V/J?00<0PJV109>nQ`2C_XL05`2C_XL00`21ZH40R;1k08R`N`0C08R`N`03086YP@1dUVL0M9IW00`0
M9IW00<0PJV105A]A`1DKDL01@1DKDL01021ZH40;C/X02dk:021ZH610;3PiP40oooo00210;3PiP80
PJV100<0>4Y3086YP@1XR6h01P1XR6h00`21ZH40QJf608F]QP0<08F]QP03086YP@2D_i40U;nA01<0
U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0
W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj709>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0
R;1k00<0PJV107BFI`1dUVL0301dUVL00`21ZH40E6e705A]A`0505A]A`04086YP@0]>bP0PJV1086Y
PH40/>3V0@3oool00840/>3V00<0PJV103mGC@21ZH401021ZH4406R8KP03086YP@25[HH0QJf600`0
QJf600<0PJV109BoT@2D_i404`2D_i400`21ZH40VlRF09_8UP0G09_8UP03086YP@2MbiH0WL^F01/0
WL^F00<0PJV109c:T`2LbY<07@2LbY<00`21ZH40V/J?09[6S`0K09[6S`03086YP@2C_XL0Tkj701L0
Tkj700<0PJV108R`N`28/7/04`28/7/00`21ZH40M9IW07BFI`0<07BFI`03086YP@1DKDL0E6e70080
E6e71@21ZH400`0`@R/0PJV10;3PiP200;3PiP40oooo00220;3PiP03086YP@0oEdd0PJV100<0Ki=g
3021ZH4708F]QP03086YP@2D_i40U;nA01<0U;nA00<0PJV109_8UP2Kb9H05`2Kb9H00`21ZH40WL^F
09g;UP0K09g;UP03086YP@2LbY<0W<ZC01d0W<ZC00<0PJV109[6S`2JaXl06`2JaXl00`21ZH40Tkj7
09>nQ`0G09>nQ`03086YP@28/7/0R;1k01<0R;1k00<0PJV107BFI`1dUVL01@1dUVL<086YP@<0FGI>
00<0PJV10312:`0`@R/0PP2`h>H10?ooo`00PP2`h>H00`21ZH40?eM=086YP@0706nCM`03086YP@2<
]hl0S;N?00D0S;N?4P21ZH4;09BoT@03086YP@2Kb9H0VlRF01L0VlRF00<0PJV109g;UP2MbiH06`2M
biH00`21ZH40W<ZC09c:T`0M09c:T`03086YP@2JaXl0V/J?01/0V/J?00<0PJV109>nQ`2C_XL05`2C
_XL00`21ZH40R;1k08R`N`0908R`Na80PJV11`1kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`
@R/0<48[086YPH80/>3V0@3oool00880/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?
08bgS`0<08bgS`03086YP@2JbIT0V/VI00P0V/VI=021ZH4?09g;UP03086YP@2LbY<0W<ZC01d0W<ZC
00<0PJV109[6S`2JaXl03@2JaXld086YP@X0S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>
05UfCP0405UfCP04086YP@0`@R/0<48[086YPH80/>3V0@3oool00880/>3V00@0PJV103mGC@0oEdd0
PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bgS`03086YP@2JbIT0V/VI01<0V/VI00<0PJV10:3AW@2P
dId05`2PdId00`21ZH40X]>M0:;CW@0<0:;CWCl0PJV13P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03
086YP@2>^H<0S[V301<0S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505UfCP04
086YP@0`@R/0<48[086YPH80/>3V0@3oool008<0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21ZH40
S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40
X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40
VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40
FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108<0/>3V0@3oool008<0/>3V00<0PJV103mGC@21ZH40
1`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId0
5`2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH0
6`2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0
301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH<0/>3V0@3oool008<0/>3V
00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI01<0
V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01d0
X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V301<0
S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086Y
PH<0/>3V0@3oool008<0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;08bg
S`03086YP@2JbIT0V/VI01<0V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;C
W@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7
S`03086YP@2>^H<0S[V301<0S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP0505Uf
CP04086YP@0`@R/0<48[086YPH<0/>3V0@3oool008@0/>3V00<0PJV103mGC@21ZH401`1_TgL00`21
ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21
ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21
ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21
ZH40FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108@0/>3V0@3oool008@0/>3V00<0PJV103mGC@21
ZH401`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2P
dId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2O
cYH06P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1k
XFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPH@0/>3V0@3oool008@0
/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI
0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J
01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V3
0180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[
086YPH@0/>3V0@3oool008@0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bgS`0;
08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J
0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0G
09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05UfCP05
05UfCP04086YP@0`@R/0<48[086YPH@0/>3V0@3oool008D0/>3V00<0PJV103mGC@21ZH401`1_TgL0
0`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05`2PdId0
0`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>UP2OcYH06P2OcYH0
0`21ZH40VLN?09W7S`0G09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl0301kXFl0
0`21ZH40FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108D0/>3V0@3oool008D0/>3V00<0PJV103mG
C@21ZH401`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3A
W@2PdId05`2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0X]:J01d0X]:J00<0PJV109o>
UP2OcYH06P2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^Q
K`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0<48[086YPHD0/>3V0@3oool0
08D0/>3V00@0PJV103mGC@0oEdd0PJV11P1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0
V/VI0180V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2RdYX0
X]:J01`0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0
S[V30180S[V300<0PJV107^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP04086YP@0`@R/0
<48[086YPHD0/>3V0@3oool008D0/>3V00@0PJV103mGC@0oEdd0PJV11`1_TgL00`21ZH40S;N?08bg
S`0;08bgS`03086YP@2JbIT0V/VI0180V/VI00<0PJV10:3AW@2PdId05P2PdId00`21ZH40X]>M0:;C
W@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7
S`0F09W7S`03086YP@2>^H<0S[V30180S[V300<0PJV107^QK`1kXFl02`1kXFl00`21ZH40FGI>05Uf
CP0505UfCP04086YP@0`@R/0<48[086YPHD0/>3V0@3oool008H0/>3V00<0PJV103mGC@21ZH401`1_
TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV10:3AW@2PdId05P2P
dId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV109o>UP2OcYH06`2O
cYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV107^QK`1kXFl0301k
XFl00`21ZH40FGI>05UfCP0505UfCP03086YP@0`@R/0PJV108H0/>3V0@3oool008H0/>3V00<0PJV1
03mGC@21ZH401`1_TgL00`21ZH40S;N?08bgS`0<08bgS`03086YP@2JbIT0V/VI0140V/VI00<0PJV1
0:3AW@2PdId05P2PdId00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2RdYX0X]:J01/0X]:J00<0PJV1
09o>UP2OcYH06`2OcYH00`21ZH40VLN?09W7S`0F09W7S`03086YP@2>^H<0S[V30140S[V300<0PJV1
07^QK`1kXFl0301kXFl00`21ZH40FGI>05UfCP0405UfCP03086YP@0`@R/0000000800000Q@2`h>H1
0?ooo`00QP2`h>H4086YP@H0Ki=g00<0PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0A09[9
V@03086YP@2PdId0X=6M01H0X=6M00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]:J0:;BVP0K0:;B
VP03086YP@2OcYH0WljF01/0WljF00<0PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0A08ji
P`03086YP@1kXFl0Nj5_00`0Nj5_00<0PJV105UfCP1IMTh0101IMTh2086YP@@00000Q02`h>H10?oo
o`00Q`2`h>H01021ZH40AF5D086YP@21ZH4606nCM`03086YP@2<]hl0S;N?00/0S;N?00<0PJV109[9
V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0X]>M01/0X]>M00<0PJV10:;B
VP2RdYX06`2RdYX00`21ZH40WljF09o>UP0K09o>UP03086YP@2Iahl0VLN?01H0VLN?00<0PJV108ji
P`2>^H<04@2>^H<00`21ZH40Nj5_07^QK`0;07^QK`07086YP@000000FGI>0000001IMTh0000005Uf
CP02086YP@@00000Q@2`h>H10?ooo`00Q`2`h>H01021ZH40AF5D086YP@1bVgd4086YP@80Ki=g00<0
PJV108bgS`2<]hl0302<]hl00`21ZH40V/VI09[9V@0@09[9V@03086YP@2PdId0X=6M01L0X=6M00<0
PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0
PJV109W7S`2Iahl05`2Iahl00`21ZH40S[V308jiP`0@08jiP`03086YP@1kXFl0Nj5_00`0Nj5_1`00
00000`1NOeH0000000000003000008D0/>3V0@3oool008P0/>3V00<0PJV104EQE021ZH40101bVgd:
086YP@L0S;N?00<0PJV109[9V@2JbIT04@2JbIT00`21ZH40X=6M0:3AW@0F0:3AW@03086YP@2Rdid0
X]>M01X0X]>M00<0PJV10:;BVP2RdYX06`2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0
VLN?01H0VLN?00<0PJV108jiP`2>^H<04@2>^H<01P21ZH40Nj5_07^QK`000000Nj5_00000080Nj5_
1`21ZH460000000305ioEP000000000000@00000Q@2`h>H10?ooo`00R02`h>H00`21ZH40AF5D086Y
P@0607:KO@03086YP@2?_Y@0SkjD00D0SkjD3021ZH4?09[9V@03086YP@2PdId0X=6M01H0X=6M00<0
PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0
PJV109W7S`2Iahl05P2Iahl00`21ZH40S[V308jiP`0708jiP`030000002>^H<0S[V300<0S[V31021
ZH48000000H0OjQf0`0000000`1NOeH000000000000400000003086YP@000000000008H0/>3V0@3o
ool008T0/>3V00<0PJV104EQE021ZH401P1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0
WM2O0080WM2O2P21ZH4509[9V@03086YP@2PdId0000001H0X=6M00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]:J0:;BVP0K0:;BVP03086YP@2OcYH0WljF01X0WljF00<0PJV109W7S`2Iahl05P2Iahl0
0`21ZH40S[V308jiP`0308jiP`<0PJV10`000004086YP@<0T/292P00000407nXMP<000000P1NOeH2
0000000405ioEP0000000000086YP@800000Q`2`h>H10?ooo`00R@2`h>H00`21ZH40AF5D086YP@06
07:KO@03086YP@2?_Y@0SkjD00`0SkjD00<0PJV109g@W`2Md9l02`2Md9l7086YP@0300000021ZH40
PJV100P0PJV1302PdId00`21ZH40X]>M0:;CW@0J0:;CW@04086YP@2RdYX0X]:J000000@0X]:J00<0
00000:;BVP2RdYX04`2RdYX00`21ZH40WljF09o>UP0J09o>UP03086YP@2Iahl0VLN?00@0VLN?0P00
000409W7S`T0PJV10P000007086YP@<0T/290P00000809;0R@8000001P1oZ7H2000000<0OjQf0`00
000305ioEP80000000@0GWmF000000000000PJV10P0000270;3PiP40oooo002:0;3PiP80PJV11P1b
Vgd00`21ZH40SkjD08nnU00<08nnU003086YP@2Md9l0WM2O0100WM2O00@0PJV10:CHXP0000000000
2@2Tf:89086YP@8000001021ZH42000001P0PJV12P00000@086YP@8000003P21ZH42000000/0PJV1
0P000009086YP@8000001021ZH4809g>U@8000000P2McYD00`21ZH40T/2909;0R@0609;0R@800000
1`2B`8T2000000P0OjQf00@0000007nXMP1oZ7H0OjQf0P0000000`21ZH40GWmF05ioEP0300000004
05ioEP00000000000;3PiP800000Q`2`h>H10?ooo`00RP2`h>H00`21ZH40AF5D086YP@0607:KO@03
086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP0200000140
Y=RR0P0000000`2Tf:80PJV10:KJXP020:KJXP8000005P2VfZ8=000000d0YMVP0P0000030:GIX003
086YP@2SeI`0XmFL00T0XmFL0P00000:0:?EW08000000`2SeI`00`21ZH40WLjE09g>U@0409g>U@80
0000302McYD20000000309g>U@21ZH40T/2900P0T/290P00000709;0R@0300000021ZH40OjQf00L0
OjQf00H0000007nXMP1oZ7H0OjQf00000021ZH4305ioEP80000000<0GWmF0000000000000`000028
0;3PiP40oooo002:0;3PiP03086YP@15HE@0PJV100H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@00`21
ZH40WM2O09g@W`0A09g@W`04086YP@2Tf:80Y=RR00000140Y=RR0P0000000`2Tf:80PJV10:KJXP02
0:KJXP8000005@2VfZ83000000P0YMVP1000000<0:GIX08000000`2UfJ000`21ZH40XmFL0:?EW009
0:?EW08000002P2SeI`2000000<0XmFL00<0PJV109g>U@2McYD0102McYD2000000`0WLjE0P000000
0`2McYD0PJV109;0R@0709;0R@<000001P2B`8T2000000`0OjQf0P0000000`21ZH40GWmF05ioEP03
0000000305ioEP000000000000<00000R02`h>H10?ooo`00R`2`h>H2086YP@L0LY]m00<0PJV108nn
U02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR00800000402Tf:820000
0080Y=RR00<0PJV10:KJXP2VfZ800P00000D0:KJXP<0000000<0PJV10:GIX02UfJ00202UfJ040000
00X0YMVP0P0000030:GIX003086YP@2SeI`0XmFL00T0XmFL0P00000:0:?EW08000000P2SeI`00`21
ZH40WLjE09g>U@0509g>U@800000302McYD20000000309g>U@21ZH40T/2900L0T/290P00000709;0
R@0300000021ZH40OjQf00/0OjQf00<00000086YP@1NOeH00P1NOeH20000000305ioEP0000000000
00@00000R02`h>H10?ooo`00R`2`h>H00`21ZH40AF5D086YP@0607:KO@03086YP@2?_Y@0SkjD00/0
SkjD00<0PJV109g@W`2Md9l0402Md9l01@21ZH40Y=RR0:CHXP2Tf:8000000100Y=RR0P0000020:CH
XP03086YP@2VfZ80Y]ZR008000004`2VfZ83000000030:KJXP21ZH40YMVP00X0YMVP100000090:GI
X08000000`2UfJ000`21ZH40XmFL0:?EW0090:?EW08000002P2SeI`200000080XmFL00<0PJV109g>
U@2McYD0102McYD2000000d0WLjE0P0000000`2McYD0PJV109;0R@0709;0R@8000001P2B`8T20000
0003086YP@1oZ7H0OjQf00T0OjQf0P0000001021ZH40GWmF05ioEP1NOeH20000000405ioEP000000
0000086YP@800000R@2`h>H10?ooo`00S02`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02`2?_Y@0
0`21ZH40WM2O09g@W`0@09g@W`04086YP@2Tf:80Y=RR0:CHXP8000003P2Tf:8300000080Y=RR00<0
PJV10:KJXP2VfZ800P00000C0:KJXP8000000P2VfZ800`21ZH40YMVP0:GIX00;0:GIX0030000002U
fJ00YMVP00P0YMVP0P0000030:GIX003086YP@2SeI`0XmFL00T0XmFL0P00000:0:?EW08000000P2S
eI`00`21ZH40WLjE09g>U@0409g>U@800000302McYD20000000309g>U@21ZH40T/2900P0T/290P00
000609;0R@030000002B`8T0PJV100L0OjQf00<0000007nXMP1oZ7H00P000000101oZ7H0PJV105io
EP1NOeH30000000305ioEP000000000000<00000R@2`h>H10?ooo`00S02`h>H00`21ZH40AF5D086Y
P@0607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l0402Md9l01021ZH40Y=RR0:CH
XP2Tf:82000000d0Y=RR0P0000030:CHXP03086YP@2VfZ80Y]ZR008000004`2VfZ8200000080Y]ZR
00<0PJV10:GIX02UfJ005P2UfJ02000000<0YMVP00<0PJV10:?EW02SeI`02@2SeI`2000000T0XmFL
0P0000030:?EW003086YP@2McYD0WLjE00@0WLjE0P00000<09g>U@80000000<0WLjE086YP@2B`8T0
1`2B`8T3000000D0T/293000000207nXMP80000000@0PJV105ioEP1NOeH0GWmF0P0000000`1NOeH0
000000000003000008X0/>3V0@3oool008d0/>3V0P21ZH4607:KO@03086YP@2?_Y@0SkjD00/0SkjD
00<0PJV109g@W`2Md9l0402Md9l01021ZH40Y=RR0:CHXP2Tf:8A000000<0Y=RR00@0PJV10:KJXP2V
fZ80Y]ZR0P00000B0:KJXP8000000P2VfZ800`21ZH40YMVP0:GIX00F0:GIX08000000`2UfJ000`21
ZH40XmFL0:?EW0090:?EW08000002@2SeI`2000000<0XmFL00<0PJV109g>U@2McYD0102McYD20000
00`0WLjE0P0000000`2McYD0PJV109;0R@0709;0R@8000001@2B`8T=00000080OjQf0P0000001021
ZH40GWmF05ioEP1NOeH8000008X0/>3V0@3oool008d0/>3V0P21ZH4607:KO@03086YP@2?_Y@0SkjD
00/0SkjD00<0PJV109g@W`2Md9l0402Md9l00`21ZH40Y=RR0:CHXP020:CHXQ000000102Tf:800`21
ZH40Y]ZR0:KJXP0200000140Y]ZR0`0000020:KJXP03086YP@2UfJ00YMVP01H0YMVP0P0000030:GI
X003086YP@2SeI`0XmFL00T0XmFL0P0000090:?EW08000000P2SeI`00`21ZH40WLjE09g>U@0509g>
U@800000302McYD20000000309g>U@21ZH40T/2900L0T/290P00000509;0R@80000000<0T/29086Y
P@1oZ7H01@1oZ7H300000080OjQf0P0000000`21ZH40GWmF05ioEP08000008/0/>3V0@3oool008h0
/>3V0P21ZH4607:KO@03086YP@2?_Y@0SkjD00/0SkjD00<0PJV109g@W`2Md9l03`2Md9l00`21ZH40
Y=RR0:CHXP030:CHXP8000002`2Tf:82000000@0Y=RR00<0PJV10:KJXP2VfZ800P00000A0:KJXP80
00000`2VfZ800`21ZH40YMVP0:GIX00F0:GIX08000000`2UfJ000`21ZH40XmFL0:?EW0090:?EW080
00002@2SeI`200000080XmFL00<0PJV109g>U@2McYD0102McYD2000000d0WLjE0P0000000`21ZH40
T/2909;0R@0709;0R@8000001@2B`8T200000003086YP@1oZ7H0OjQf00@0OjQf0`00000307nXMP80
00000P1NOeH30000000305ioEP000000000000800000S02`h>H10?ooo`00SP2`h>H2086YP@H0LY]m
00<0PJV108nnU02?_Y@02`2?_Y@00`21ZH40WM2O09g@W`0@09g@W`04086YP@2Tf:80Y=RR0:CHXP@0
00002P2Tf:82000000@0Y=RR00<0PJV10:KJXP2VfZ800P00000A0:KJXP8000000`2VfZ800`21ZH40
YMVP0:GIX00E0:GIX0800000102UfJ000`21ZH40XmFL0:?EW0090:?EW08000002@2SeI`200000080
XmFL00<0PJV109g>U@2McYD0102McYD2000000d0WLjE0P0000000`21ZH40T/2909;0R@0609;0R@<0
00001@2B`8T200000003086YP@1oZ7H0OjQf00<0OjQf0`00000407nXMPL0000000<0GWmF086YP@21
ZH40SP2`h>H10?ooo`00S`2`h>H2086YP@H0LY]m00<0PJV108nnU02?_Y@02P2?_Y@00`21ZH40WM2O
09g@W`0@09g@W`04086YP@2Tf:80Y=RR0:CHXPD00000202Tf:82000000D0Y=RR00<0PJV10:KJXP2V
fZ800`00000@0:KJXP<000000`2VfZ800`21ZH40YMVP0:GIX00D0:GIX08000000`2UfJ000`21ZH40
XmFL0:?EW00:0:?EW08000002@2SeI`200000080XmFL00<0PJV109g>U@2McYD00`2McYD3000000`0
WLjE0P0000000`2McYD0PJV109;0R@0709;0R@8000001P2B`8T3000000<0OjQf1000000507nXMPH0
000000<0GWmF086YP@21ZH40S`2`h>H10?ooo`00S`2`h>H3086YP@D0LY]m00<0PJV108nnU02?_Y@0
2P2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR00@0Y=RR0P0000070:CHXP<00000
1@2Tf:800`21ZH40Y]ZR0:KJXP0400000140Y]ZR0P0000020:KJXP03086YP@2UfJ00YMVP00X0YMVP
00<000000:GIX02UfJ001`2UfJ0300000080YMVP00<0PJV10:?EW02SeI`02P2SeI`2000000P0XmFL
0P0000030:?EW003086YP@2McYD0WLjE00@0WLjE1000000:09g>U@<0000000<0PJV109;0R@2B`8T0
1@2B`8T2000000P0T/292000000607nXMP04086YP@1NOeH0000005ioEP8000000`21ZH6?0;3PiP40
oooo002@0;3PiP@0PJV10`1bVgd00`21ZH40SkjD08nnU00;08nnU003086YP@2Md9l0WM2O00l0WM2O
00<0PJV10:CHXP2Tf:801@2Tf:82000000H0Y=RR0P0000070:CHXP03086YP@2VfZ80Y]ZR00@00000
402VfZ83000000030:KJXP21ZH40YMVP00X0YMVP0`0000080:GIX0@0000000<0YMVP086YP@2SeI`0
2P2SeI`2000000T0XmFL0P0000020:?EW003086YP@2McYD0WLjE00@0WLjE1P00000809g>U@800000
00<0WLjE0000000000001@2B`8T4000000P0T/2900<0PJV10000000000000`00000807nXMP03086Y
P@1NOeH0GWmF00<0000000<0Gh=J086YP@2`h>H0S`2`h>H10?ooo`00T02`h>H2086YP@80LYeo0`21
ZH400`1bVgd0PJV108nnU00;08nnU003086YP@2Md9l0WM2O0100WM2O00<0PJV10:CHXP2Tf:801@2T
f:800`000000Y=RR0:CHXP040:CHXP8000001`2Tf:800`21ZH40Y]ZR0:KJXP06000000l0Y]ZR0`00
00000`21ZH40YMVP0:GIX0080:GIX0<000002@2UfJ0500000003086YP@2SeI`0XmFL00P0XmFL0P00
000:0:?EW08000000P2SeI`00`21ZH40WLjE09g>U@0409g>U@8000000P2McYD4000000<0WLjE1@00
00000`2McYD0000000000008000000T0T/2900@0PJV107nXMP1oZ7H000002@1oZ7H01021ZH40GWmF
086YP@21ZH420000000305n3FP21ZH40/>3V0900/>3V0@3oool00940/>3V0P21ZH4407:MO`D0PJV1
2@2?_Y@00`21ZH40WM2O09g@W`0@09g@W`03086YP@2Tf:80Y=RR00D0Y=RR0P0000040:CHXP<00000
1`2Tf:800`21ZH40Y]ZR0:KJXP02000000030:KJXP000000000000@000003@2VfZ83000000T0YMVP
0`00000:0:GIX080000000@0YMVP00000000000000001`2SeI`5000000X0XmFL0P0000020:?EW003
086YP@2McYD0WLjE00@0WLjE0P00000309g>U@X000000P2McYD8000000/0T/2900<0PJV107nXMP1o
Z7H01`1oZ7H5086YP@80Gh=J0P000002086YPI40/>3V0@3oool00980/>3V0P21ZH4507:MO`03086Y
P@2?`IL0Sl6G00L0PJV10`2?_Y@00`21ZH40WM2O09g@W`0?09g@W`03086YP@2Tf:80Y=RR00H0Y=RR
00<000000:CHXP2Tf:800P2Tf:82000000P0Y=RR00<0PJV10:KJXP2VfZ800`0000020:KJXPP00000
2P2VfZ85000000<0YMVP1@00000;0:GIX08000000P2UfJ0=000000/0XmFL0P0000020:?EW003086Y
P@2McYD0WLjE00@0WLjE0P00000409g>U@H000001@2McYD00`21ZH40T/2909;0R@0?09;0R@04086Y
P@1oZ7H0OjQf07nXMPL0PJV10P1o[7X01021ZH40Gh=J05n3FP1OPeX300000003086YP@2`h>H0/>3V
0900/>3V0@3oool00980/>3V0P21ZH4507:MO`03086YP@2?`IL0Sl6G00L0Sl6G2021ZH4=09g@W`03
086YP@2Tf:80Y=RR00H0Y=RR0P0000030:CHXP800000202Tf:801@21ZH40Y]ZR0:KJXP2VfZ800000
00D0Y]ZR1P00000;0:KJXP/00000302UfJ02000000<0YMVP2@00000>0:?EW08000000P2SeI`00`21
ZH40WLjE09g>U@0409g>U@8000003P2McYD00`21ZH40T/2909;0R@0<09;0R@P0PJV12@1o[7X00`21
ZH40Gh=J05n3FP0205n3FP0300000021ZH40PJV10980/>3V0@3oool009<0/>3V0P21ZH4507:MO`03
086YP@2?`IL0Sl6G00X0Sl6G00@0PJV109kCXP2Ndj80W]>R2P21ZH4409g@W`03086YP@2Tf:80Y=RR
00H0Y=RR0P0000020:CHXP8000002@2Tf:800`21ZH40Y]ZR0:KJXP0G0:KJXP03086YP@2UfJ000000
00D000003`2UfJ02000000<0YMVP00@0PJV10:?EW000000000005P2SeI`00`21ZH40WLjE09g>U@0E
09g>U@03086YP@2B`8T0T/290080T/292P21ZH4309?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV1
05n3FP1OPeX00`1OPeX2086YPI<0/>3V0@3oool009@0/>3V0P21ZH4407:MO`03086YP@2?`IL0Sl6G
00X0Sl6G00<0PJV109kCXP2Ndj802`2Ndj8>086YP@0300000021ZH400000008000002@2Tf:800`21
ZH40Y]ZR0:KJXP0G0:KJXP03086YP@2UfJ00YMVP01@0YMVP0P0000030:GIX003086YP@2SeI`0XmFL
01L0XmFL00<0PJV109g>U@2McYD02P2McYD@086YP@d0TlB=00<0PJV107n/NP1o[7X02P1o[7X00`21
ZH40Gh=J05n3FP0205n3FP80PJV1U02`h>H10?ooo`00U02`h>H2086YP@D0LYeo00<0PJV108o1U`2?
`IL02P2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV00L0YMbV1000000G086YP@d0
Y]ZR00<0PJV10:GIX02UfJ00502UfJ02000000<0YMVP00<0PJV10:?EW02SeI`02`2SeI`I086YP@/0
W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0:07n/NP03086YP@1OPeX0Gh=J00<0
Gh=J0P21ZH6D0;3PiP40oooo002E0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0908o1U`03086Y
P@2Ndj80W]>R00l0W]>R00<0PJV10:GLYP2Ug:H01`2Ug:H3000000X0YMbV00<0PJV10:SOYP2XgjH0
2P2XgjHT086YP@8000004@21ZH490:GJX0040000002UfZ00YMZP086YPAH0W]:I00<0PJV109?4S@2C
a8d03`2Ca8d00`21ZH40Ojaj07n/NP0907n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6E0;3PiP40
oooo002E0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R
00<0PJV10:GLYP2Ug:H01`2Ug:H3000000X0YMbV00<0PJV10:SOYP2XgjH05`2XgjH00`21ZH40YmjT
0:ONY00D0:ONY08000000`2WgZ@00`21ZH40YMZP0:GJX00B0:GJX0@0000000<0YMZP086YP@2NdYT0
5@2NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00X0Ojaj00<0PJV105n3FP1OPeX0
0`1OPeX00`21ZH40/>3V0;3PiP2D0;3PiP40oooo002F0;3PiP80PJV11@1bWGl00`21ZH40Sl6G08o1
U`0908o1U`03086YP@2Ndj80W]>R00l0W]>R00<0PJV10:GLYP2Ug:H01`2Ug:H00`000000YMbV0:GL
YP0:0:GLYP03086YP@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@0502WgZ@2000000<0YmjT00<0
PJV10:GJX02UfZ004@2UfZ06000001H0W]:I00<0PJV109?4S@2Ca8d03`2Ca8d00`21ZH40Ojaj07n/
NP0907n/NP03086YP@1OPeX0Gh=J00<0Gh=J0P21ZH6F0;3PiP40oooo002G0;3PiP80PJV1101bWGl0
0`21ZH40Sl6G08o1U`0:08o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H0
0`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01@0YmjT0P0000030:ONY003086YP@2UfZ00
YMZP0180YMZP100000000`21ZH40W]:I09kBV@0D09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV1
07n/NP1o[7X02P1o[7X00`21ZH40Gh=J05n3FP0205n3FP80PJV1U`2`h>H10?ooo`00U`2`h>H2086Y
P@D0LYeo00<0PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV
01@0YMbV00<0PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00I0:ONY003086YP@2UfZ00YMZP
01<0YMZP00@000000:GJX02UfZ00PJV15P2NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0
Ojaj00T0Ojaj00<0PJV105n3FP1OPeX00`1OPeX2086YPIL0/>3V0@3oool009P0/>3V0P21ZH4407:M
O`03086YP@2?`IL0Sl6G00X0Sl6G00<0PJV109kCXP2Ndj803P2Ndj800`21ZH40YMbV0:GLYP0C0:GL
YP03086YP@2XgjH0Z=nV01L0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00G0:GJ
X003086YP@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0:07n/
NP03086YP@1OPeX0Gh=J0080Gh=J0P21ZH6H0;3PiP40oooo002I0;3PiP80PJV1101bWGl00`21ZH40
Sl6G08o1U`0908o1U`03086YP@2Ndj80W]>R00h0W]>R00<0PJV10:GLYP2Ug:H0502Ug:H00`21ZH40
Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40
W]:I09kBV@0D09kBV@03086YP@2Ca8d0TlB=00h0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40
Gh=J05n3FP0205n3FP80PJV1V@2`h>H10?ooo`00VP2`h>H00`21ZH40LYeo07:MO`0307:MO`03086Y
P@2?`IL0Sl6G00T0Sl6G00<0PJV109kCXP2Ndj803@2Ndj800`21ZH40YMbV0:GLYP0D0:GLYP03086Y
P@2XgjH0Z=nV01H0Z=nV00<0PJV10:ONY02WgZ@05`2WgZ@00`21ZH40YMZP0:GJX00F0:GJX003086Y
P@2NdYT0W]:I01<0W]:I00<0PJV109?4S@2Ca8d03P2Ca8d00`21ZH40Ojaj07n/NP0907n/NP03086Y
P@1OPeX0Gh=J00<0Gh=J00<0PJV10;3PiP2`h>H0V02`h>H10?ooo`00V`2`h>H2086YP@<0LYeo00<0
PJV108o1U`2?`IL02@2?`IL00`21ZH40W]>R09kCXP0>09kCXP03086YP@2Ug:H0YMbV01<0YMbV00<0
PJV10:SOYP2XgjH05P2XgjH00`21ZH40YmjT0:ONY00G0:ONY003086YP@2UfZ00YMZP01H0YMZP00<0
PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0>09?4S@03086YP@1o[7X0Ojaj00T0Ojaj00@0
PJV105n3FP1OPeX0Gh=J0P21ZH6K0;3PiP40oooo002L0;3PiP<0PJV10P1bWGl00`21ZH40Sl6G08o1
U`0908o1U`03086YP@2Ndj80W]>R00d0W]>R00<0PJV10:GLYP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SO
YP0F0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kB
V@0C09kBV@03086YP@2Ca8d0TlB=00d0TlB=00<0PJV107n/NP1o[7X02@1o[7X00`21ZH40Gh=J05n3
FP03086YPI`0/>3V0@3oool009d0/>3V00<0PJV106jJO@21ZH400P21ZH4;08o1U`03086YP@2Ndj80
W]>R00h0W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2WgZ@0
YmjT01L0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0B09kBV@03086YP@2Ca8d0
TlB=00h0TlB=00<0PJV107n/NP1o[7X02@1o[7X3086YP@0305b3F`21ZH40/>3V09`0/>3V0@3oool0
09h0/>3V00<0PJV106jJO@1^VWd01@21ZH4808o1U`03086YP@2Ndj80W]>R00d0W]>R00<0PJV10:GL
YP2Ug:H04`2Ug:H00`21ZH40Z=nV0:SOYP0E0:SOYP03086YP@2WgZ@0YmjT01L0YmjT00<0PJV10:GJ
X02UfZ005@2UfZ000`21ZH40W]:I09kBV@0C09kBV@03086YP@2Ca8d0TlB=00d0TlB=00<0PJV107n/
NP1o[7X01P1o[7X5086YP@80G8=K00<0PJV10;3PiP2`h>H0W02`h>H10?ooo`00WP2`h>H00`21ZH40
KYYm06jJO@0206jJO@03086YP@2;_YD0RkjE00H0PJV10P2?`IL00`21ZH40W]>R09kCXP0=09kCXP03
086YP@2Ug:H0YMbV01<0YMbV00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT0:ONY00G0:ONY003
086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT04`2NdYT00`21ZH40TlB=09?4S@0=09?4S@03
086YP@1o[7X0Ojaj00H0PJV10P1lZgX00`21ZH40G8=K05b3F`0205b3F`03086YP@2`h>H0/>3V09`0
/>3V0@3oool009l0/>3V00<0PJV106jJO@1^VWd00P1^VWd00`21ZH40RkjE08^nU@0508^nU@H0PJV1
3@2Ndj800`21ZH40YMbV0:GLYP0B0:GLYP03086YP@2XgjH0Z=nV01D0Z=nV00<0PJV10:ONY02WgZ@0
5`2WgZ@00`21ZH40YMZP0:GJX00E0:GJX003086YP@2NdYT0W]:I0180W]:I00<0PJV109?4S@2Ca8d0
2`2Ca8d6086YP@L0O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21ZH40/>3V0;3PiP2M0;3PiP40oooo
002P0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;_YD0202;_YD00`21ZH40Vm:R086Y
P@05086YP@L0W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV0:SOYP0F0:SOYP03086YP@2W
gZ@0YmjT01D0YmjT00<0PJV10:GJX02UfZ005P2UfZ000`21ZH40W]:I09kBV@0B09kBV@03086YP@2C
a8d0TlB=00D0TlB=1P21ZH400`2Aa8h0PJV107b[NP0907b[NP03086YP@1LPe/0G8=K0080G8=K00<0
PJV10;3PiP2`h>H0WP2`h>H10?ooo`00X@2`h>H01@21ZH40KYYm06jJO@1^VWd0PJV100X0RkjE00<0
PJV109_BXP2KdZ801@2KdZ86086YP@80W]>R00<0PJV10:GLYP2Ug:H04P2Ug:H00`21ZH40Z=nV0:SO
YP0E0:SOYP03086YP@2WgZ@0YmjT01D0YmjT00<0PJV10:GJX02UfZ005@2UfZ000`21ZH40W]:I09kB
V@0B09kBV@03086YP@2Ca8d0TlB=00H0PJV11`2Aa8h00`21ZH40O:]j07b[NP0807b[NP05086YP@1L
Pe/0G8=K05b3F`21ZH40X@2`h>H10?ooo`00XP2`h>H01@21ZH40KYYm06jJO@1^VWd0PJV100X0RkjE
00<0PJV109_BXP2KdZ802P2KdZ8=086YP@X0YMbV00<0PJV10:SOYP2XgjH05@2XgjH00`21ZH40YmjT
0:ONY00E0:ONY003086YP@2UfZ00YMZP01D0YMZP00<0PJV109kBV@2NdYT0202NdYT=086YP@`0TLB>
00<0PJV107b[NP1lZgX0201lZgX01@21ZH40G8=K05b3F`1LPe/0PJV10:80/>3V0@3oool00:<0/>3V
00D0PJV106jJO@1^VWd0KYYm086YP@0:08^nU@03086YP@2KdZ80Vm:R00`0Vm:R00<0PJV10:CLY`2T
g:L01`2Tg:LF086YP@`0Z=nV00<0PJV10:ONY02WgZ@05@2WgZ@00`21ZH40YMZP0:GJX00:0:GJX1H0
PJV12@2MdiX00`21ZH40TLB>0974SP0<0974SP03086YP@1lZgX0O:]j00P0O:]j00D0PJV105b3F`1L
Pe/0G8=K086YP@2S0;3PiP40oooo002T0;3PiP05086YP@1^VWd0KYYm06jJO@21ZH402P2;_YD00`21
ZH40Vm:R09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0140Y=bW00<0PJV10:OPZ02Wh:P02@2Wh:Pa086Y
P@/0Y=^R00<0PJV109gCVP2MdiX04@2MdiX00`21ZH40TLB>0974SP0;0974SP03086YP@1lZgX0O:]j
00P0O:]j00D0PJV105b3F`1LPe/0G8=K086YP@2T0;3PiP40oooo002T0;3PiP03086YP@1^VWd0KYYm
0080KYYm00<0PJV108^nU@2;_YD01`2;_YD00`21ZH40Vm:R09_BXP0<09_BXP03086YP@2Tg:L0Y=bW
0140Y=bW00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40YmnV0:OOYP0E0:OOYP03086YP@2Tfj80Y=^R
01@0Y=^R00<0PJV109gCVP2MdiX04@2MdiX00`21ZH40TLB>0974SP0<0974SP03086YP@1lZgX0O:]j
00L0O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21ZH40/>3V0;3PiP2R0;3PiP40oooo002U0;3PiP03
086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;_YD01`2;_YD00`21ZH40Vm:R09_BXP0<09_BXP03
086YP@2Tg:L0Y=bW0100Y=bW00<0PJV10:OPZ02Wh:P0502Wh:P00`21ZH40YmnV0:OOYP0E0:OOYP03
086YP@2Tfj80Y=^R01@0Y=^R00<0PJV109gCVP2MdiX0402MdiX00`21ZH40TLB>0974SP0<0974SP03
086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21ZH40/>3V0;3PiP2S0;3PiP40
oooo002V0;3PiP03086YP@1^VWd0KYYm0080KYYm00<0PJV108^nU@2;_YD01`2;_YD00`21ZH40Vm:R
09_BXP0;09_BXP03086YP@2Tg:L0Y=bW0140Y=bW00<0PJV10:OPZ02Wh:P04`2Wh:P00`21ZH40YmnV
0:OOYP0E0:OOYP03086YP@2Tfj80Y=^R01<0Y=^R00<0PJV109gCVP2MdiX04@2MdiX00`21ZH40TLB>
0974SP0;0974SP03086YP@1lZgX0O:]j00L0O:]j00<0PJV105b3F`1LPe/00P1LPe/00`21ZH40/>3V
0;3PiP2T0;3PiP40oooo002W0;3PiP80PJV10P1^VWd00`21ZH40RkjE08^nU@0808^nU@03086YP@2K
dZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2W
gjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj80502Tfj800`21ZH40WM>J09gCVP0@09gCVP03086YP@2A
a8h0TLB>00/0TLB>00<0PJV107b[NP1lZgX0201lZgX00`21ZH40G8=K05b3F`02086YPJL0/>3V0@3o
ool00:P0/>3V0`21ZH400`1^VWd0PJV108^nU@0808^nU@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV1
0:CLY`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00D0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV1
0:CKXP2Tfj80502Tfj800`21ZH40WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00`0TLB>00<0PJV1
07b[NP1lZgX01`1lZgX00`21ZH40G8=K086YP@02086YPJP0/>3V0@3oool00:T0/>3V1@21ZH4908^n
U@03086YP@2KdZ80Vm:R00/0Vm:R00<0PJV10:CLY`2Tg:L0402Tg:L00`21ZH40Yn2X0:OPZ00C0:OP
Z003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj804`2Tfj800`21ZH40WM>J09gCVP0@09gC
VP03086YP@2Aa8h0TLB>00/0TLB>00<0PJV107b[NP1lZgX01`1lZgX3086YP@0305IlF@21ZH40/>3V
0:P0/>3V0@3oool00:/0/>3V00<0PJV106FAMP21ZH400P21ZH4808^nU@03086YP@2KdZ80Vm:R00/0
Vm:R00<0PJV10:CLY`2Tg:L03`2Tg:L00`21ZH40Yn2X0:OPZ00C0:OPZ003086YP@2WgjH0YmnV01<0
YmnV00<0PJV10:CKXP2Tfj804`2Tfj800`21ZH40WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00/0
TLB>00<0PJV107b[NP1lZgX01P1lZgX3086YP@0305IlF@21ZH40/>3V0:X0/>3V0@3oool00:`0/>3V
00<0PJV106FAMP1UTGH01@21ZH4508^nU@03086YP@2KdZ80Vm:R00X0Vm:R00<0PJV10:CLY`2Tg:L0
402Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2WgjH0YmnV01<0YmnV00<0PJV10:CKXP2Tfj80
4P2Tfj800`21ZH40WM>J09gCVP0@09gCVP03086YP@2Aa8h0TLB>00X0TLB>00<0PJV107b[NP1lZgX0
0`1lZgX5086YP@80EWaI00<0PJV10;3PiP2`h>H0ZP2`h>H10?ooo`00[@2`h>H01021ZH40II5f06FA
MP21ZH43086dSP@0PJV100<0RkjE086YP@2KdZ80302KdZ800`21ZH40Y=bW0:CLY`0?0:CLY`03086Y
P@2Wh:P0Yn2X0180Yn2X00<0PJV10:OOYP2WgjH04`2WgjH00`21ZH40Y=^R0:CKXP0B0:CKXP03086Y
P@2MdiX0WM>J00l0WM>J00<0PJV10974SP2Aa8h02`2Aa8h00`21ZH40O:]j086YP@03086YP@<0M:=f
00@0PJV105IlF@1FO5T0PJV1[@2`h>H10?ooo`00[P2`h>H2086YP@0306FAMP21ZH40PJV100D0PKB>
1P21ZH4:09_BXP03086YP@2Tg:L0Y=bW00h0Y=bW00<0PJV10:OPZ02Wh:P04P2Wh:P00`21ZH40YmnV
0:OOYP0C0:OOYP03086YP@2Tfj80Y=^R0180Y=^R00<0PJV109gCVP2MdiX03P2MdiX00`21ZH40TLB>
0974SP080974SPH0PJV11@1dXgH2086YP@0305IlF@21ZH40PJV10:h0/>3V0@3oool00;00/>3V00@0
PJV106FAMP1UTGH0PJV11`21]8h00`21ZH40T/ZL09;:W008086YP@80Vm:R00<0PJV10:CLY`2Tg:L0
3`2Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003086YP@2WgjH0YmnV0140YmnV00<0PJV10:CKXP2Tfj80
4P2Tfj800`21ZH40WM>J09gCVP0?09gCVP03086YP@2Aa8h0TLB>00P0PJV10P29_HX00`21ZH40M:=f
07BSMP0507BSMP04086YP@1FO5T0EWaI086YPK00/>3V0@3oool00;40/>3V00@0PJV106FAMP1UTGH0
PJV11`21]8h00`21ZH40T/ZL09;:W00709;:W0P0PJV1302Tg:L00`21ZH40Yn2X0:OPZ00B0:OPZ003
086YP@2WgjH0YmnV0140YmnV00<0PJV10:CKXP2Tfj804P2Tfj800`21ZH40WM>J09gCVP0:09gCVPP0
PJV12@29_HX00`21ZH40M:=f07BSMP0507BSMP04086YP@1FO5T0EWaI086YPK40/>3V0@3oool00;80
/>3V00@0PJV106FAMP1UTGH0PJV11`21]8h00`21ZH40T/ZL09;:W00:09;:W004086YP@2LeZ<0W=JS
09cFX`T0PJV1102Tg:L00`21ZH40Yn2X0:OPZ00A0:OPZ003086YP@2WgjH0YmnV0140YmnV00<0PJV1
0:CKXP2Tfj804@2Tfj800`21ZH40WM>J09gCVP0209gCVPT0PJV10`2FcIL00`21ZH40RKf:08VmRP0:
08VmRP03086YP@1dXgH0M:=f00D0M:=f00@0PJV105IlF@1FO5T0PJV1/P2`h>H10?ooo`00/`2`h>H2
086YP@0306FAMP21ZH40PKB>00H0PKB>00<0PJV109;:W02BbY`02P2BbY`00`21ZH40W=JS09cFX`09
09cFXdD0PJV12`2FcIL00`21ZH40RKf:08VmRP0:08VmRP03086YP@1dXgH0M:=f00D0M:=f00@0PJV1
05IlF@21ZH40PJV1/`2`h>H10?ooo`00]@2`h>H00`21ZH40II5f086YP@07086dSP03086YP@2BbY`0
T/ZL00T0T/ZL00<0PJV109cFX`2LeZ<03@2LeZ<00`21ZH40XM^U0:7KY@0A0:7KY@03086YP@2Qfj@0
XM^T0140XM^T00<0PJV109kGW`2Neil0402Neil00`21ZH40U/fG09K=U`0>09K=U`03086YP@29_HX0
RKf:00T0RKf:00<0PJV107BSMP1dXgH01@1dXgH00`21ZH40EWaI086YP@2e0;3PiP40oooo002f0;3P
iP04086YP@1UTGH0PJV1086YP@H0PKB>00<0PJV109;:W02BbY`02@2BbY`00`21ZH40W=JS09cFX`0=
09cFX`03086YP@2QfjD0XM^U0100XM^U00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40W]NO09kGW`0@
09kGW`03086YP@2FcIL0U/fG00d0U/fG00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f07BSMP04
07BSMP80PJV100<0EWaI086YP@2`h>H0]@2`h>H10?ooo`00]`2`h>H2086YP@0306FAMP21ZH40PKB>
00D0PKB>00<0PJV109;:W02BbY`02@2BbY`00`21ZH40W=JS09cFX`0<09cFX`03086YP@2QfjD0XM^U
0140XM^U00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40W]NO09kGW`0@09kGW`03086YP@2FcIL0U/fG
00d0U/fG00<0PJV108VmRP29_HX02@29_HX00`21ZH40M:=f07BSMP0407BSMP04086YP@1FO5T0PJV1
086YPKL0/>3V0@3oool00;T0/>3V0`21ZH46086dSP03086YP@2BbY`0T/ZL00T0T/ZL00<0PJV109cF
X`2LeZ<0302LeZ<00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109kG
W`2Neil0402Neil00`21ZH40U/fG09K=U`0<09K=U`03086YP@29_HX0RKf:00T0RKf:00<0PJV107BS
MP1dXgH0101dXgH3086YPKT0/>3V0@3oool00;/0/>3V1021ZH44086dSP03086YP@2BbY`0T/ZL00T0
T/ZL00<0PJV109cFX`2LeZ<02`2LeZ<00`21ZH40XM^U0:7KY@0@0:7KY@03086YP@2Qfj@0XM^T00l0
XM^T00<0PJV109kGW`2Neil03`2Neil00`21ZH40U/fG09K=U`0<09K=U`03086YP@29_HX0RKf:00T0
RKf:00<0PJV107BSMP1dXgH00P1dXgH4086YPK/0/>3V0@3oool00;d0/>3V1P21ZH400`21]8h0PJV1
09;:W00:09;:W003086YP@2LeZ<0W=JS00/0W=JS00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XM^T
0:7KY00?0:7KY003086YP@2Neil0W]NO00l0W]NO00<0PJV109K=U`2FcIL02`2FcIL00`21ZH40RKf:
08VmRP0908VmRP03086YP@1dXgH0PJV100D0PJV1_@2`h>H10?ooo`00_P2`h>H3086YP@80L:1o1P21
ZH4709;:W003086YP@2LeZ<0W=JS00/0W=JS00<0PJV10:7KY@2QfjD03`2QfjD00`21ZH40XM^T0:7K
Y00?0:7KY003086YP@2Neil0W]NO00h0W]NO00<0PJV109K=U`2FcIL0302FcIL00`21ZH40RKf:08Vm
RP0508VmRPH0PJV10P1UTV`3086YPKh0/>3V0@3oool00<00/>3V0`21ZH43072PO`80PJV100<0P[N>
086YP@21ZH401021ZH4209;:W003086YP@2LeZ<0W=JS00/0W=JS00<0PJV10:7KY@2QfjD03P2QfjD0
0`21ZH40XM^T0:7KY00?0:7KY003086YP@2Neil0W]NO00h0W]NO00<0PJV109K=U`2FcIL02`2FcIL0
0`21ZH40RKf:08VmRP06086YP@0307V/O`21ZH40PJV100<0II9/0`21ZH700;3PiP40oooo00320;3P
iP<0PJV10`1`X7l2086YP@D0P[N>2P21ZH4609cFX`03086YP@2QfjD0XM^U00l0XM^U00<0PJV10:7K
Y02Qfj@03@2Qfj@00`21ZH40W]NO09kGW`0>09kGW`03086YP@2FcIL0U/fG00D0U/fG2P21ZH4507V/
O`80PJV10`1UTV`3086YPL80/>3V0@3oool00<@0/>3V0`21ZH43072PO`03086YP@22]hh0P[N>00H0
P[N>0P21ZH4408g4Ua00PJV1202QfjD00`21ZH40XM^T0:7KY00=0:7KY003086YP@2Neil0W]NO00H0
W]NO4021ZH4408NmS@80PJV1201i[7l01021ZH40II9/06FBK01UTV`3086YPL@0/>3V0@3oool00<H0
/>3V0`21ZH42072PO`80PJV12022]hh00`21ZH40SLBG08g4U`0908g4U`03086YP@2BbiX0T/^J00D0
T/^J8@21ZH4708o7U@03086YP@27_Hd0Qkf=00T0Qkf=00<0PJV107V/O`1i[7l01P1i[7l2086YP@80
II9/0`21ZH760;3PiP40oooo00380;3PiP<0PJV10P1`X7l00`21ZH40P[N>08:gSP0608:gSP03086Y
P@2=a9L0SLBG00T0SLBG00<0PJV109;;VP2BbiX0302BbiX00`21ZH40TlbJ09?<VP0=09?<VP03086Y
P@2?aiD0SlNE00`0SlNE00<0PJV108NmS@27_Hd02@27_Hd00`21ZH40NJao07V/O`0607V/O`03086Y
P@1UTV`0II9/00<0PJV1b02`h>H10?ooo`00bP2`h>H3086YP@03072PO`21ZH40PJV100L0P[N>0P21
ZH4:08g4U`03086YP@2BbiX0T/^J00`0T/^J00<0PJV109?<VP2Cc9X02`2Cc9X00`21ZH40SlNE08o7
U@0<08o7U@03086YP@27_Hd0Qkf=00P0Qkf=0P21ZH4707V/O`80PJV100@0II9/086YP@21ZH40PJV1
bP2`h>H10?ooo`00c@2`h>H5086YP@L0P[N>00<0PJV108g4U`2=a9L01`2=a9L00`21ZH40T/^J09;;
VP0<09;;VP03086YP@2Cc9X0TlbJ00/0TlbJ00<0PJV108o7U@2?aiD02`2?aiD00`21ZH40Qkf=08Nm
S@0808NmS@03086YP@1i[7l0NJao00D0NJao1@21ZH7=0;3PiP40oooo003@0;3PiPL0PJV10`22]hh2
086YP@P0SLBG00<0PJV109;;VP2BbiX02`2BbiX00`21ZH40TlbJ09?<VP0;09?<VP03086YP@2?aiD0
SlNE00/0SlNE00<0PJV108NmS@27_Hd01P27_Hd2086YP@<0NJao1`21ZH7@0;3PiP40oooo003C0;3P
iP`0PJV11P2=a9L00`21ZH40T/^J09;;VP0:09;;VP03086YP@2Cc9X0TlbJ00/0TlbJ00<0PJV108o7
U@2?aiD02P2?aiD00`21ZH40Qkf=08NmS@0408NmS@P0PJV100@0HHi[086YP@21ZH40PJV1d`2`h>H1
0?ooo`00eP2`h>H5086YP@80IiMg2021ZH400`2=a9L0PJV109;;VP0;09;;VP03086YP@2Cc9X0TlbJ
00T0TlbJ00<0PJV108o7U@2?aiD02P2?aiD00`21ZH40Qkf=086YP@07086YP@@0HHi[0`21ZH7F0;3P
iP40oooo003I0;3PiPD0PJV100<0IiMg086YP@21ZH40101aY7lY086YP@@0KIig0P21ZH42066>J`@0
PJV1f@2`h>H10?ooo`00g@2`h>H6086YP@D0LJAo0P21ZH4907N[P`03086YP@1h[8<0N:b300P0N:b3
00<0PJV107FXO`1eZ7l0201eZ7l2086YP@D0KIig0P21ZH40101QSV/0PJV1086YP@21ZH7M0;3PiP40
oooo003Q0;3PiP@0PJV11@1aY7l2086YP@P0Mj^300<0PJV107R/P`1h[8<01`1h[8<00`21ZH40MJQo
07FXO`0607FXO`80PJV11@1]WWL4086YPN40/>3V0@3oool00>D0/>3V3021ZH4307N[P`03086YP@1h
[8<0N:b300H0N:b300<0PJV107FXO`1eZ7l00P1eZ7l<086YPND0/>3V0@3oool00?00/>3V4`21ZH7`
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
%%ImageSize: 500 500 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Background color
.69 .878 .902 r
MFill
% Scaling calculations
0 1 0 1 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 Mabswid
[ ] 0 setdash
.605 .777 .566 r
.4503 .46959 m .4498 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.605 .777 .566 r
.48991 .5 m .49001 .46977 L .4503 .46959 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.49001 .53023 m .48991 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.49001 .46977 m .48991 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.48991 .5 m .49001 .53023 L .52992 .53029 L p F P
.505 .664 .505 r
s
.594 .759 .555 r
.52992 .53029 m .53022 .5 L .48991 .5 L p F P
.505 .664 .505 r
s
.61 .784 .575 r
.53022 .5 m .52992 .46971 L .49001 .46977 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.52992 .46971 m .53022 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.53022 .5 m .52992 .53029 L .56922 .53059 L p F P
.505 .664 .505 r
s
.595 .76 .56 r
.56922 .53059 m .56993 .5 L .53022 .5 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.45183 .43953 m .4503 .46959 L .49001 .46977 L p F P
.505 .664 .505 r
s
.619 .8 .584 r
.49001 .46977 m .49032 .43988 L .45183 .43953 L p F P
.505 .664 .505 r
s
.589 .752 .546 r
.4498 .5 m .4503 .53041 L .49001 .53023 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.49032 .56012 m .49001 .53023 L .4503 .53041 L p F P
.505 .664 .505 r
s
.624 .807 .593 r
.49032 .43988 m .49001 .46977 L .52992 .46971 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.49001 .53023 m .49032 .56012 L .529 .56024 L p F P
.505 .664 .505 r
s
.575 .73 .533 r
.529 .56024 m .52992 .53029 L .49001 .53023 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.50634 .45195 m
.50823 .45195 L
s
.5 Mabswid
.624 .807 .593 r
.52992 .46971 m .529 .43976 L .49032 .43988 L p F P
.505 .664 .505 r
s
.626 .809 .599 r
.529 .43976 m .52992 .46971 L .56922 .46941 L p F P
.505 .664 .505 r
s
.612 .786 .58 r
.56993 .5 m .56922 .46941 L .52992 .46971 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.52992 .53029 m .529 .56024 L .56709 .56082 L p F P
.505 .664 .505 r
s
.576 .731 .537 r
.56709 .56082 m .56922 .53059 L .52992 .53029 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.41161 .46916 m .41069 .5 L .4498 .5 L p F P
.505 .664 .505 r
s
.595 .765 .553 r
.4498 .5 m .4503 .46959 L .41161 .46916 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.4503 .53041 m .4498 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.49584 .43986 m
.49735 .43541 L
s
.51416 .43538 m
.51574 .4398 L
s
.5 Mabswid
.61 .788 .572 r
.41436 .43871 m .41161 .46916 L .4503 .46959 L p F P
.505 .664 .505 r
s
.61 .788 .572 r
.4503 .46959 m .45183 .43953 L .41436 .43871 L p F P
.505 .664 .505 r
s
.579 .738 .532 r
.41069 .5 m .41161 .53084 L .4503 .53041 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.45183 .56047 m .4503 .53041 L .41161 .53084 L p F P
.505 .664 .505 r
s
.57 .723 .523 r
.4503 .53041 m .45183 .56047 L .49032 .56012 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54274 .44989 m
.54529 .44726 L
s
.5 Mabswid
.631 .82 .6 r
.45437 .41018 m .45183 .43953 L .49032 .43988 L p F P
.505 .664 .505 r
s
.631 .82 .6 r
.49032 .43988 m .49082 .41067 L .45437 .41018 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.49082 .41067 m .49032 .43988 L .529 .43976 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.52702 .43825 m
.52788 .43528 L
s
.5 Mabswid
.548 .69 .498 r
.49082 .58933 m .49032 .56012 L .45183 .56047 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.49032 .56012 m .49082 .58933 L .52748 .58949 L p F P
.505 .664 .505 r
s
.554 .698 .507 r
.52748 .58949 m .529 .56024 L .49032 .56012 L p F P
.505 .664 .505 r
s
.636 .827 .609 r
.529 .43976 m .52748 .41051 L .49082 .41067 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.52748 .41051 m .529 .43976 L .56709 .43918 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.54332 .41923 m
.54352 .42212 L
s
.5 Mabswid
.626 .809 .599 r
.56922 .46941 m .56709 .43918 L .529 .43976 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.529 .56024 m .52748 .58949 L .56352 .59032 L p F P
.505 .664 .505 r
s
.554 .698 .511 r
.56352 .59032 m .56709 .56082 L .529 .56024 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.56922 .46941 m .56993 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.56993 .5 m .56922 .53059 L .60709 .53114 L p F P
.505 .664 .505 r
s
.592 .756 .561 r
.60709 .53114 m .60821 .5 L .56993 .5 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.56709 .43918 m .56922 .46941 L .60709 .46886 L p F P
.505 .664 .505 r
s
.609 .783 .583 r
.60821 .5 m .60709 .46886 L .56922 .46941 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.56922 .53059 m .56709 .56082 L .60373 .56188 L p F P
.505 .664 .505 r
s
.572 .725 .537 r
.60373 .56188 m .60709 .53114 L .56922 .53059 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.56926 .44079 m
.57056 .44076 L
s
.5 Mabswid
.623 .81 .589 r
.41894 .40902 m .41436 .43871 L .45183 .43953 L p F P
.505 .664 .505 r
s
.623 .81 .589 r
.45183 .43953 m .45437 .41018 L .41894 .40902 L p F P
.505 .664 .505 r
s
.559 .709 .509 r
.41161 .53084 m .41436 .56129 L .45183 .56047 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.45437 .58982 m .45183 .56047 L .41436 .56129 L p F P
.505 .664 .505 r
s
.548 .69 .498 r
.45183 .56047 m .45437 .58982 L .49082 .58933 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.37481 .46849 m .37348 .5 L .41069 .5 L p F P
.505 .664 .505 r
s
.58 .745 .534 r
.41069 .5 m .41161 .46916 L .37481 .46849 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.41161 .53084 m .41069 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.45794 .38193 m .45437 .41018 L .49082 .41067 L p F P
.505 .664 .505 r
s
.641 .839 .616 r
.49082 .41067 m .49154 .38253 L .45794 .38193 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.49154 .38253 m .49082 .41067 L .52748 .41051 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.49154 .61747 m .49082 .58933 L .45437 .58982 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.49082 .58933 m .49154 .61747 L .52534 .61767 L p F P
.505 .664 .505 r
s
.528 .66 .478 r
.52534 .61767 m .52748 .58949 L .49082 .58933 L p F P
.505 .664 .505 r
s
.638 .83 .615 r
.56709 .43918 m .56352 .40968 L .52748 .41051 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.56352 .40968 m .56709 .43918 L .60373 .43812 L p F P
.505 .664 .505 r
s
.624 .807 .602 r
.60709 .46886 m .60373 .43812 L .56709 .43918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.56709 .56082 m .56352 .59032 L .59813 .5918 L p F P
.505 .664 .505 r
s
.548 .69 .51 r
.59813 .5918 m .60373 .56188 L .56709 .56082 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.37878 .43741 m .37481 .46849 L .41161 .46916 L p F P
.505 .664 .505 r
s
.596 .771 .555 r
.41161 .46916 m .41436 .43871 L .37878 .43741 L p F P
.505 .664 .505 r
s
.562 .717 .512 r
.37348 .5 m .37481 .53151 L .41161 .53084 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.41436 .56129 m .41161 .53084 L .37481 .53151 L p F P
.505 .664 .505 r
s
.646 .845 .624 r
.52748 .41051 m .52534 .38233 L .49154 .38253 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.52534 .38233 m .52748 .41051 L .56352 .40968 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.52748 .58949 m .52534 .61767 L .55853 .61867 L p F P
.505 .664 .505 r
s
.528 .659 .481 r
.55853 .61867 m .56352 .59032 L .52748 .58949 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.42535 .38053 m .41894 .40902 L .45437 .41018 L p F P
.505 .664 .505 r
s
.633 .829 .605 r
.45437 .41018 m .45794 .38193 L .42535 .38053 L p F P
.505 .664 .505 r
s
.537 .675 .483 r
.41436 .56129 m .41894 .59098 L .45437 .58982 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.45794 .61807 m .45437 .58982 L .41894 .59098 L p F P
.505 .664 .505 r
s
.522 .652 .468 r
.45437 .58982 m .45794 .61807 L .49154 .61747 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.38539 .40721 m .37878 .43741 L .41436 .43871 L p F P
.505 .664 .505 r
s
.61 .793 .573 r
.41436 .43871 m .41894 .40902 L .38539 .40721 L p F P
.505 .664 .505 r
s
.542 .686 .488 r
.37481 .53151 m .37878 .56259 L .41436 .56129 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.41894 .59098 m .41436 .56129 L .37878 .56259 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.60709 .46886 m .60821 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.60821 .5 m .60709 .53114 L .64258 .53194 L p F P
.505 .664 .505 r
s
.582 .744 .557 r
.64258 .53194 m .64411 .5 L .60821 .5 L p F P
.505 .664 .505 r
s
.648 .848 .63 r
.56352 .40968 m .55853 .38133 L .52534 .38233 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.55853 .38133 m .56352 .40968 L .59813 .4082 L p F P
.505 .664 .505 r
s
.636 .829 .619 r
.60373 .43812 m .59813 .4082 L .56352 .40968 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.56352 .59032 m .55853 .61867 L .59031 .62047 L p F P
.505 .664 .505 r
s
.52 .649 .478 r
.59031 .62047 m .59813 .5918 L .56352 .59032 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.60373 .43812 m .60709 .46886 L .64258 .46806 L p F P
.505 .664 .505 r
s
.601 .773 .58 r
.64411 .5 m .64258 .46806 L .60709 .46886 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.60709 .53114 m .60373 .56188 L .63799 .56341 L p F P
.505 .664 .505 r
s
.56 .711 .531 r
.63799 .56341 m .64258 .53194 L .60709 .53114 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.46253 .35521 m .45794 .38193 L .49154 .38253 L p F P
.505 .664 .505 r
s
.649 .854 .629 r
.49154 .38253 m .49246 .35586 L .46253 .35521 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.49246 .64414 m .49154 .61747 L .45794 .61807 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.49246 .35586 m .49154 .38253 L .52534 .38233 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.49154 .61747 m .49246 .64414 L .52258 .64436 L p F P
.505 .664 .505 r
s
.497 .614 .443 r
.52258 .64436 m .52534 .61767 L .49154 .61747 L p F P
.505 .664 .505 r
s
.654 .86 .637 r
.52534 .38233 m .52258 .35564 L .49246 .35586 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.52258 .35564 m .52534 .38233 L .55853 .38133 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.52534 .61767 m .52258 .64436 L .55212 .64545 L p F P
.505 .664 .505 r
s
.495 .612 .445 r
.55212 .64545 m .55853 .61867 L .52534 .61767 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.59813 .4082 m .60373 .43812 L .63799 .43659 L p F P
.505 .664 .505 r
s
.617 .799 .601 r
.64258 .46806 m .63799 .43659 L .60373 .43812 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.60373 .56188 m .59813 .5918 L .63037 .59394 L p F P
.505 .664 .505 r
s
.535 .672 .501 r
.63037 .59394 m .63799 .56341 L .60373 .56188 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.39462 .37834 m .38539 .40721 L .41894 .40902 L p F P
.505 .664 .505 r
s
.621 .814 .59 r
.41894 .40902 m .42535 .38053 L .39462 .37834 L p F P
.505 .664 .505 r
s
.518 .65 .46 r
.37878 .56259 m .38539 .59279 L .41894 .59098 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.42535 .61947 m .41894 .59098 L .38539 .59279 L p F P
.505 .664 .505 r
s
.51 .636 .453 r
.41894 .59098 m .42535 .61947 L .45794 .61807 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.43357 .35368 m .42535 .38053 L .45794 .38193 L p F P
.505 .664 .505 r
s
.641 .845 .618 r
.45794 .38193 m .46253 .35521 L .43357 .35368 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.46253 .64479 m .45794 .61807 L .42535 .61947 L p F P
.505 .664 .505 r
s
.491 .606 .433 r
.45794 .61807 m .46253 .64479 L .49246 .64414 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.3409 .46758 m .33917 .5 L .37348 .5 L p F P
.505 .664 .505 r
s
.558 .716 .508 r
.37348 .5 m .37481 .46849 L .3409 .46758 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.37481 .53151 m .37348 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.3461 .43565 m .3409 .46758 L .37481 .46849 L p F P
.505 .664 .505 r
s
.575 .744 .53 r
.37481 .46849 m .37878 .43741 L .3461 .43565 L p F P
.505 .664 .505 r
s
.538 .685 .484 r
.33917 .5 m .3409 .53242 L .37481 .53151 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.37878 .56259 m .37481 .53151 L .3409 .53242 L p F P
.505 .664 .505 r
s
.655 .863 .643 r
.55853 .38133 m .55212 .35455 L .52258 .35564 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.55212 .35455 m .55853 .38133 L .59031 .37953 L p F P
.505 .664 .505 r
s
.647 .847 .634 r
.59813 .4082 m .59031 .37953 L .55853 .38133 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.55853 .61867 m .55212 .64545 L .58028 .6474 L p F P
.505 .664 .505 r
s
.487 .6 .44 r
.58028 .6474 m .59031 .62047 L .55853 .61867 L p F P
.505 .664 .505 r
s
1 .5 0 r
2 Mabswid
.37794 .43433 m
.37984 .43256 L
s
.5 Mabswid
.641 .842 .634 r
.59031 .37953 m .59813 .4082 L .63037 .40606 L p F P
.505 .664 .505 r
s
.63 .822 .619 r
.63799 .43659 m .63037 .40606 L .59813 .4082 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.59813 .5918 m .59031 .62047 L .61975 .62304 L p F P
.505 .664 .505 r
s
.505 .628 .466 r
.61975 .62304 m .63037 .59394 L .59813 .5918 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.35472 .40475 m .3461 .43565 L .37878 .43741 L p F P
.505 .664 .505 r
s
.59 .769 .551 r
.37878 .43741 m .38539 .40721 L .35472 .40475 L p F P
.505 .664 .505 r
s
.515 .65 .457 r
.3409 .53242 m .3461 .56435 L .37878 .56259 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.38539 .59279 m .37878 .56259 L .3461 .56435 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.40642 .3513 m .39462 .37834 L .42535 .38053 L p F P
.505 .664 .505 r
s
.629 .831 .605 r
.42535 .38053 m .43357 .35368 L .40642 .3513 L p F P
.505 .664 .505 r
s
.49 .609 .429 r
.38539 .59279 m .39462 .62166 L .42535 .61947 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.43357 .64632 m .42535 .61947 L .39462 .62166 L p F P
.505 .664 .505 r
s
.478 .589 .417 r
.42535 .61947 m .43357 .64632 L .46253 .64479 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.64258 .46806 m .64411 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.64411 .5 m .64258 .53194 L .6746 .53297 L p F P
.505 .664 .505 r
s
.563 .719 .544 r
.6746 .53297 m .67654 .5 L .64411 .5 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.46813 .3305 m .46253 .35521 L .49246 .35586 L p F P
.505 .664 .505 r
s
.653 .866 .639 r
.49246 .35586 m .49358 .33115 L .46813 .3305 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.49358 .33115 m .49246 .35586 L .52258 .35564 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.49358 .66885 m .49246 .64414 L .46253 .64479 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.49246 .64414 m .49358 .66885 L .51922 .66907 L p F P
.505 .664 .505 r
s
.457 .557 .399 r
.51922 .66907 m .52258 .64436 L .49246 .64414 L p F P
.505 .664 .505 r
s
.657 .871 .647 r
.52258 .35564 m .51922 .33093 L .49358 .33115 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.51922 .33093 m .52258 .35564 L .55212 .35455 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.63799 .43659 m .64258 .46806 L .6746 .46703 L p F P
.505 .664 .505 r
s
.584 .752 .57 r
.67654 .5 m .6746 .46703 L .64258 .46806 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.64258 .53194 m .63799 .56341 L .66881 .5654 L p F P
.505 .664 .505 r
s
.538 .682 .515 r
.66881 .5654 m .6746 .53297 L .64258 .53194 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.52258 .64436 m .51922 .66907 L .5443 .67015 L p F P
.505 .664 .505 r
s
.455 .555 .401 r
.5443 .67015 m .55212 .64545 L .52258 .64436 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.3667 .37538 m .35472 .40475 L .38539 .40721 L p F P
.505 .664 .505 r
s
.602 .791 .57 r
.38539 .40721 m .39462 .37834 L .3667 .37538 L p F P
.505 .664 .505 r
s
.489 .612 .427 r
.3461 .56435 m .35472 .59525 L .38539 .59279 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.39462 .62166 m .38539 .59279 L .35472 .59525 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.44359 .32898 m .43357 .35368 L .46253 .35521 L p F P
.505 .664 .505 r
s
.646 .857 .63 r
.46253 .35521 m .46813 .3305 L .44359 .32898 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.46813 .6695 m .46253 .64479 L .43357 .64632 L p F P
.505 .664 .505 r
s
.452 .55 .391 r
.46253 .64479 m .46813 .6695 L .49358 .66885 L p F P
.505 .664 .505 r
s
.654 .863 .646 r
.59031 .37953 m .58028 .3526 L .55212 .35455 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.58028 .3526 m .59031 .37953 L .61975 .37696 L p F P
.505 .664 .505 r
s
.641 .842 .634 r
.63037 .40606 m .61975 .37696 L .59031 .37953 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.59031 .62047 m .58028 .6474 L .60621 .6502 L p F P
.505 .664 .505 r
s
.469 .576 .426 r
.60621 .6502 m .61975 .62304 L .59031 .62047 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.63037 .40606 m .63799 .43659 L .66881 .4346 L p F P
.505 .664 .505 r
s
.602 .781 .593 r
.6746 .46703 m .66881 .4346 L .63799 .43659 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.63799 .56341 m .63037 .59394 L .65921 .59672 L p F P
.505 .664 .505 r
s
.51 .64 .482 r
.65921 .59672 m .66881 .5654 L .63799 .56341 L p F P
.505 .664 .505 r
s
.659 .874 .652 r
.55212 .35455 m .5443 .32985 L .51922 .33093 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.5443 .32985 m .55212 .35455 L .58028 .3526 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.55212 .64545 m .5443 .67015 L .5681 .67209 L p F P
.505 .664 .505 r
s
.445 .541 .394 r
.5681 .67209 m .58028 .6474 L .55212 .64545 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.42073 .32662 m .40642 .3513 L .43357 .35368 L p F P
.505 .664 .505 r
s
.634 .843 .617 r
.43357 .35368 m .44359 .32898 L .42073 .32662 L p F P
.505 .664 .505 r
s
.457 .56 .392 r
.39462 .62166 m .40642 .6487 L .43357 .64632 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.44359 .67102 m .43357 .64632 L .40642 .6487 L p F P
.505 .664 .505 r
s
.439 .532 .374 r
.43357 .64632 m .44359 .67102 L .46813 .6695 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.61975 .37696 m .63037 .40606 L .65921 .40328 L p F P
.505 .664 .505 r
s
.616 .807 .613 r
.66881 .4346 m .65921 .40328 L .63037 .40606 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.63037 .59394 m .61975 .62304 L .64589 .62639 L p F P
.505 .664 .505 r
s
.477 .592 .444 r
.64589 .62639 m .65921 .59672 L .63037 .59394 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.31108 .46642 m .30894 .5 L .33917 .5 L p F P
.505 .664 .505 r
s
.522 .67 .469 r
.33917 .5 m .3409 .46758 L .31108 .46642 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.3409 .53242 m .33917 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.38195 .34809 m .3667 .37538 L .39462 .37834 L p F P
.505 .664 .505 r
s
.612 .809 .586 r
.39462 .37834 m .40642 .3513 L .38195 .34809 L p F P
.505 .664 .505 r
s
.46 .567 .393 r
.35472 .59525 m .3667 .62462 L .39462 .62166 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.40642 .6487 m .39462 .62166 L .3667 .62462 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.31746 .43343 m .31108 .46642 L .3409 .46758 L p F P
.505 .664 .505 r
s
.541 .702 .495 r
.3409 .46758 m .3461 .43565 L .31746 .43343 L p F P
.505 .664 .505 r
s
.499 .635 .441 r
.30894 .5 m .31108 .53358 L .3409 .53242 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.3461 .56435 m .3409 .53242 L .31108 .53358 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.32801 .40165 m .31746 .43343 L .3461 .43565 L p F P
.505 .664 .505 r
s
.559 .731 .518 r
.3461 .43565 m .35472 .40475 L .32801 .40165 L p F P
.505 .664 .505 r
s
.474 .596 .411 r
.31108 .53358 m .31746 .56657 L .3461 .56435 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.35472 .59525 m .3461 .56435 L .31746 .56657 L p F P
.505 .664 .505 r
s
.657 .873 .655 r
.58028 .3526 m .5681 .32791 L .5443 .32985 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.5681 .32791 m .58028 .3526 L .60621 .3498 L p F P
.505 .664 .505 r
s
.648 .857 .647 r
.61975 .37696 m .60621 .3498 L .58028 .3526 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58028 .6474 m .5681 .67209 L .58983 .67486 L p F P
.505 .664 .505 r
s
.426 .514 .377 r
.58983 .67486 m .60621 .6502 L .58028 .6474 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.47472 .30833 m .46813 .3305 L .49358 .33115 L p F P
.505 .664 .505 r
s
.651 .871 .646 r
.49358 .33115 m .4949 .30892 L .47472 .30833 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.4949 .30892 m .49358 .33115 L .51922 .33093 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.4949 .69108 m .49358 .66885 L .46813 .6695 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.49358 .66885 m .4949 .69108 L .51525 .69128 L p F P
.505 .664 .505 r
s
.407 .486 .345 r
.51525 .69128 m .51922 .66907 L .49358 .66885 L p F P
.505 .664 .505 r
s
.655 .876 .652 r
.51922 .33093 m .51525 .30872 L .4949 .30892 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.51525 .30872 m .51922 .33093 L .5443 .32985 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.51922 .66907 m .51525 .69128 L .5351 .69225 L p F P
.505 .664 .505 r
s
.404 .482 .345 r
.5351 .69225 m .5443 .67015 L .51922 .66907 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.60621 .3498 m .61975 .37696 L .64589 .37361 L p F P
.505 .664 .505 r
s
.628 .828 .63 r
.65921 .40328 m .64589 .37361 L .61975 .37696 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.61975 .62304 m .60621 .6502 L .62899 .65381 L p F P
.505 .664 .505 r
s
.439 .536 .4 r
.62899 .65381 m .64589 .62639 L .61975 .62304 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.45535 .30698 m .44359 .32898 L .46813 .3305 L p F P
.505 .664 .505 r
s
.644 .862 .637 r
.46813 .3305 m .47472 .30833 L .45535 .30698 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.47472 .69167 m .46813 .6695 L .44359 .67102 L p F P
.505 .664 .505 r
s
.401 .479 .337 r
.46813 .6695 m .47472 .69167 L .4949 .69108 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.34262 .37167 m .32801 .40165 L .35472 .40475 L p F P
.505 .664 .505 r
s
.573 .756 .54 r
.35472 .40475 m .3667 .37538 L .34262 .37167 L p F P
.505 .664 .505 r
s
.445 .553 .378 r
.31746 .56657 m .32801 .59835 L .35472 .59525 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.3667 .62462 m .35472 .59525 L .32801 .59835 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40032 .32347 m .38195 .34809 L .40642 .3513 L p F P
.505 .664 .505 r
s
.617 .823 .599 r
.40642 .3513 m .42073 .32662 L .40032 .32347 L p F P
.505 .664 .505 r
s
.425 .516 .355 r
.3667 .62462 m .38195 .65191 L .40642 .6487 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.42073 .67338 m .40642 .6487 L .38195 .65191 L p F P
.505 .664 .505 r
s
.416 .502 .348 r
.40642 .6487 m .42073 .67338 L .44359 .67102 L p F P
.505 .664 .505 r
s
.656 .878 .657 r
.5443 .32985 m .5351 .30775 L .51525 .30872 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5351 .30775 m .5443 .32985 L .5681 .32791 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.5443 .67015 m .5351 .69225 L .55383 .69398 L p F P
.505 .664 .505 r
s
.393 .467 .336 r
.55383 .69398 m .5681 .67209 L .5443 .67015 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.6746 .46703 m .67654 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.67654 .5 m .6746 .53297 L .70188 .53425 L p F P
.505 .664 .505 r
s
.527 .674 .518 r
.70188 .53425 m .70421 .5 L .67654 .5 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.66881 .4346 m .6746 .46703 L .70188 .46575 L p F P
.505 .664 .505 r
s
.552 .712 .547 r
.70421 .5 m .70188 .46575 L .6746 .46703 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.6746 .53297 m .66881 .5654 L .69493 .56784 L p F P
.505 .664 .505 r
s
.5 .632 .484 r
.69493 .56784 m .70188 .53425 L .6746 .53297 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.43743 .30488 m .42073 .32662 L .44359 .32898 L p F P
.505 .664 .505 r
s
.633 .849 .625 r
.44359 .32898 m .45535 .30698 L .43743 .30488 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.45535 .69302 m .44359 .67102 L .42073 .67338 L p F P
.505 .664 .505 r
s
.388 .46 .32 r
.44359 .67102 m .45535 .69302 L .47472 .69167 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.65921 .40328 m .66881 .4346 L .69493 .43216 L p F P
.505 .664 .505 r
s
.572 .746 .574 r
.70188 .46575 m .69493 .43216 L .66881 .4346 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.66881 .5654 m .65921 .59672 L .68346 .60013 L p F P
.505 .664 .505 r
s
.468 .584 .446 r
.68346 .60013 m .69493 .56784 L .66881 .5654 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3611 .34411 m .34262 .37167 L .3667 .37538 L p F P
.505 .664 .505 r
s
.584 .777 .559 r
.3667 .37538 m .38195 .34809 L .3611 .34411 L p F P
.505 .664 .505 r
s
.413 .505 .342 r
.32801 .59835 m .34262 .62833 L .3667 .62462 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.38195 .65191 m .3667 .62462 L .34262 .62833 L p F P
.505 .664 .505 r
s
.651 .867 .655 r
.60621 .3498 m .58983 .32514 L .5681 .32791 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.58983 .32514 m .60621 .3498 L .62899 .34619 L p F P
.505 .664 .505 r
s
.635 .844 .642 r
.64589 .37361 m .62899 .34619 L .60621 .3498 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.60621 .6502 m .58983 .67486 L .6087 .6784 L p F P
.505 .664 .505 r
s
.393 .471 .348 r
.6087 .6784 m .62899 .65381 L .60621 .6502 L p F P
.505 .664 .505 r
s
.654 .876 .659 r
.5681 .32791 m .55383 .30602 L .5351 .30775 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.55383 .30602 m .5681 .32791 L .58983 .32514 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.5681 .67209 m .55383 .69398 L .57077 .69644 L p F P
.505 .664 .505 r
s
.372 .438 .318 r
.57077 .69644 m .58983 .67486 L .5681 .67209 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.64589 .37361 m .65921 .40328 L .68346 .39987 L p F P
.505 .664 .505 r
s
.59 .775 .596 r
.69493 .43216 m .68346 .39987 L .65921 .40328 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.65921 .59672 m .64589 .62639 L .66762 .63045 L p F P
.505 .664 .505 r
s
.432 .531 .404 r
.66762 .63045 m .68346 .60013 L .65921 .59672 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42163 .30208 m .40032 .32347 L .42073 .32662 L p F P
.505 .664 .505 r
s
.616 .829 .608 r
.42073 .32662 m .43743 .30488 L .42163 .30208 L p F P
.505 .664 .505 r
s
.383 .456 .311 r
.38195 .65191 m .40032 .67653 L .42073 .67338 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.43743 .69512 m .42073 .67338 L .40032 .67653 L p F P
.505 .664 .505 r
s
.367 .431 .296 r
.42073 .67338 m .43743 .69512 L .45535 .69302 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.28671 .46503 m .2842 .5 L .30894 .5 L p F P
.505 .664 .505 r
s
.463 .595 .408 r
.30894 .5 m .31108 .46642 L .28671 .46503 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.31108 .53358 m .30894 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.48228 .28932 m .47472 .30833 L .4949 .30892 L p F P
.505 .664 .505 r
s
.64 .864 .644 r
.4949 .30892 m .49643 .28977 L .48228 .28932 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.49643 .28977 m .4949 .30892 L .51525 .30872 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.49643 .71023 m .4949 .69108 L .47472 .69167 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.4949 .69108 m .49643 .71023 L .51069 .71038 L p F P
.505 .664 .505 r
s
.34 .392 .274 r
.51069 .71038 m .51525 .69128 L .4949 .69108 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.2942 .43077 m .28671 .46503 L .31108 .46642 L p F P
.505 .664 .505 r
s
.487 .633 .439 r
.31108 .46642 m .31746 .43343 L .2942 .43077 L p F P
.505 .664 .505 r
s
.437 .554 .375 r
.2842 .5 m .28671 .53497 L .31108 .53358 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.31746 .56657 m .31108 .53358 L .28671 .53497 L p F P
.505 .664 .505 r
s
.644 .869 .65 r
.51525 .30872 m .51069 .28962 L .49643 .28977 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.51069 .28962 m .51525 .30872 L .5351 .30775 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.51525 .69128 m .51069 .71038 L .52458 .71113 L p F P
.505 .664 .505 r
s
.336 .387 .273 r
.52458 .71113 m .5351 .69225 L .51525 .69128 L p F P
.505 .664 .505 r
s
.383 .46 .312 r
.34262 .62833 m .3611 .65589 L .38195 .65191 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.40032 .67653 m .38195 .65191 L .3611 .65589 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.3832 .31957 m .3611 .34411 L .38195 .34809 L p F P
.505 .664 .505 r
s
.591 .792 .574 r
.38195 .34809 m .40032 .32347 L .3832 .31957 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.62899 .34619 m .64589 .37361 L .66762 .36955 L p F P
.505 .664 .505 r
s
.603 .799 .615 r
.68346 .39987 m .66762 .36955 L .64589 .37361 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64589 .62639 m .62899 .65381 L .64765 .65816 L p F P
.505 .664 .505 r
s
.391 .471 .356 r
.64765 .65816 m .66762 .63045 L .64589 .62639 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.46877 .28827 m .45535 .30698 L .47472 .30833 L p F P
.505 .664 .505 r
s
.633 .856 .636 r
.47472 .30833 m .48228 .28932 L .46877 .28827 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.48228 .71068 m .47472 .69167 L .45535 .69302 L p F P
.505 .664 .505 r
s
.338 .39 .271 r
.47472 .69167 m .48228 .71068 L .49643 .71023 L p F P
.505 .664 .505 r
s
.408 .509 .341 r
.28671 .53497 m .2942 .56923 L .31746 .56657 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.32801 .59835 m .31746 .56657 L .2942 .56923 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.30655 .39796 m .2942 .43077 L .31746 .43343 L p F P
.505 .664 .505 r
s
.508 .668 .467 r
.31746 .43343 m .32801 .40165 L .30655 .39796 L p F P
.505 .664 .505 r
s
.644 .87 .653 r
.5351 .30775 m .52458 .28887 L .51069 .28962 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.52458 .28887 m .5351 .30775 L .55383 .30602 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5351 .69225 m .52458 .71113 L .5376 .71246 L p F P
.505 .664 .505 r
s
.325 .372 .264 r
.5376 .71246 m .55383 .69398 L .5351 .69225 L p F P
.505 .664 .505 r
s
.647 .869 .658 r
.58983 .32514 m .57077 .30356 L .55383 .30602 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.57077 .30356 m .58983 .32514 L .6087 .3216 L p F P
.505 .664 .505 r
s
.638 .854 .65 r
.62899 .34619 m .6087 .3216 L .58983 .32514 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58983 .67486 m .57077 .69644 L .58528 .69956 L p F P
.505 .664 .505 r
s
.339 .394 .288 r
.58528 .69956 m .6087 .6784 L .58983 .67486 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32354 .36727 m .30655 .39796 L .32801 .40165 L p F P
.505 .664 .505 r
s
.526 .699 .494 r
.32801 .40165 m .34262 .37167 L .32354 .36727 L p F P
.505 .664 .505 r
s
.384 .472 .316 r
.2942 .56923 m .30655 .60204 L .32801 .59835 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.34262 .62833 m .32801 .59835 L .30655 .60204 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45638 .28667 m .43743 .30488 L .45535 .30698 L p F P
.505 .664 .505 r
s
.622 .843 .625 r
.45535 .30698 m .46877 .28827 L .45638 .28667 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.46877 .71173 m .45535 .69302 L .43743 .69512 L p F P
.505 .664 .505 r
s
.333 .382 .267 r
.45535 .69302 m .46877 .71173 L .48228 .71068 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.6087 .3216 m .62899 .34619 L .64765 .34184 L p F P
.505 .664 .505 r
s
.611 .817 .629 r
.66762 .36955 m .64765 .34184 L .62899 .34619 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62899 .65381 m .6087 .6784 L .62388 .68263 L p F P
.505 .664 .505 r
s
.344 .404 .303 r
.62388 .68263 m .64765 .65816 L .62899 .65381 L p F P
.505 .664 .505 r
s
.64 .866 .653 r
.55383 .30602 m .5376 .28754 L .52458 .28887 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.5376 .28754 m .55383 .30602 L .57077 .30356 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.55383 .69398 m .5376 .71246 L .54924 .71433 L p F P
.505 .664 .505 r
s
.304 .344 .245 r
.54924 .71433 m .57077 .69644 L .55383 .69398 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40859 .29866 m .3832 .31957 L .40032 .32347 L p F P
.505 .664 .505 r
s
.591 .801 .585 r
.40032 .32347 m .42163 .30208 L .40859 .29866 L p F P
.505 .664 .505 r
s
.354 .417 .287 r
.3611 .65589 m .3832 .68043 L .40032 .67653 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.42163 .69792 m .40032 .67653 L .3832 .68043 L p F P
.505 .664 .505 r
s
.348 .406 .28 r
.40032 .67653 m .42163 .69792 L .43743 .69512 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34488 .33941 m .32354 .36727 L .34262 .37167 L p F P
.505 .664 .505 r
s
.54 .725 .517 r
.34262 .37167 m .3611 .34411 L .34488 .33941 L p F P
.505 .664 .505 r
s
.363 .438 .297 r
.30655 .60204 m .32354 .63273 L .34262 .62833 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.3611 .65589 m .34262 .62833 L .32354 .63273 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.70188 .46575 m .70421 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.70421 .5 m .70188 .53425 L .72294 .53575 L p F P
.505 .664 .505 r
s
.463 .592 .465 r
.72294 .53575 m .72562 .5 L .70421 .5 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.69493 .43216 m .70188 .46575 L .72294 .46425 L p F P
.505 .664 .505 r
s
.492 .637 .5 r
.72562 .5 m .72294 .46425 L .70188 .46575 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.70188 .53425 m .69493 .56784 L .71494 .57071 L p F P
.505 .664 .505 r
s
.431 .543 .425 r
.71494 .57071 m .72294 .53575 L .70188 .53425 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.4456 .28455 m .42163 .30208 L .43743 .30488 L p F P
.505 .664 .505 r
s
.606 .825 .61 r
.43743 .30488 m .45638 .28667 L .4456 .28455 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.45638 .71333 m .43743 .69512 L .42163 .69792 L p F P
.505 .664 .505 r
s
.322 .367 .257 r
.43743 .69512 m .45638 .71333 L .46877 .71173 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.68346 .39987 m .69493 .43216 L .71494 .42929 L p F P
.505 .664 .505 r
s
.517 .678 .532 r
.72294 .46425 m .71494 .42929 L .69493 .43216 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.69493 .56784 m .68346 .60013 L .70178 .6041 L p F P
.505 .664 .505 r
s
.396 .489 .382 r
.70178 .6041 m .71494 .57071 L .69493 .56784 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.37018 .31502 m .34488 .33941 L .3611 .34411 L p F P
.505 .664 .505 r
s
.551 .745 .537 r
.3611 .34411 m .3832 .31957 L .37018 .31502 L p F P
.505 .664 .505 r
s
.339 .4 .275 r
.32354 .63273 m .34488 .66059 L .3611 .65589 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.3832 .68043 m .3611 .65589 L .34488 .66059 L p F P
.505 .664 .505 r
s
.632 .858 .65 r
.57077 .30356 m .54924 .28567 L .5376 .28754 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.54924 .28567 m .57077 .30356 L .58528 .30044 L p F P
.505 .664 .505 r
s
.633 .855 .651 r
.6087 .3216 m .58528 .30044 L .57077 .30356 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.57077 .69644 m .54924 .71433 L .55905 .71669 L p F P
.505 .664 .505 r
s
.275 .304 .218 r
.55905 .71669 m .58528 .69956 L .57077 .69644 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.58528 .30044 m .6087 .3216 L .62388 .31737 L p F P
.505 .664 .505 r
s
.614 .828 .637 r
.64765 .34184 m .62388 .31737 L .6087 .3216 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.6087 .6784 m .58528 .69956 L .59668 .70325 L p F P
.505 .664 .505 r
s
.291 .329 .243 r
.59668 .70325 m .62388 .68263 L .6087 .6784 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.66762 .36955 m .68346 .39987 L .70178 .3959 L p F P
.505 .664 .505 r
s
.538 .713 .559 r
.71494 .42929 m .70178 .3959 L .68346 .39987 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68346 .60013 m .66762 .63045 L .68373 .63515 L p F P
.505 .664 .505 r
s
.357 .432 .336 r
.68373 .63515 m .70178 .6041 L .68346 .60013 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49074 .27412 m .48228 .28932 L .49643 .28977 L p F P
.505 .664 .505 r
s
.612 .837 .628 r
.49643 .28977 m .49813 .27437 L .49074 .27412 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.49813 .27437 m .49643 .28977 L .51069 .28962 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49813 .72563 m .49643 .71023 L .48228 .71068 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.49643 .71023 m .49813 .72563 L .50559 .72571 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.50559 .72571 m .51069 .71038 L .49643 .71023 L p F P
.505 .664 .505 r
s
.615 .841 .632 r
.51069 .28962 m .50559 .27429 L .49813 .27437 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.50559 .27429 m .51069 .28962 L .52458 .28887 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51069 .71038 m .50559 .72571 L .51284 .72613 L p F P
.505 .664 .505 r
s
.271 .295 .214 r
.51284 .72613 m .52458 .71113 L .51069 .71038 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48372 .27353 m .46877 .28827 L .48228 .28932 L p F P
.505 .664 .505 r
s
.606 .83 .621 r
.48228 .28932 m .49074 .27412 L .48372 .27353 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.49074 .72588 m .48228 .71068 L .46877 .71173 L p F P
.505 .664 .505 r
s
.276 .302 .218 r
.48228 .71068 m .49074 .72588 L .49813 .72563 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.64765 .34184 m .66762 .36955 L .68373 .36485 L p F P
.505 .664 .505 r
s
.555 .743 .581 r
.70178 .3959 m .68373 .36485 L .66762 .36955 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66762 .63045 m .64765 .65816 L .66116 .66317 L p F P
.505 .664 .505 r
s
.315 .37 .286 r
.66116 .66317 m .68373 .63515 L .66762 .63045 L p F P
.505 .664 .505 r
s
.614 .84 .634 r
.52458 .28887 m .51284 .27387 L .50559 .27429 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.51284 .27387 m .52458 .28887 L .5376 .28754 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.52458 .71113 m .51284 .72613 L .51957 .72688 L p F P
.505 .664 .505 r
s
.261 .282 .206 r
.51957 .72688 m .5376 .71246 L .52458 .71113 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.43688 .28198 m .40859 .29866 L .42163 .30208 L p F P
.505 .664 .505 r
s
.584 .799 .589 r
.42163 .30208 m .4456 .28455 L .43688 .28198 L p F P
.505 .664 .505 r
s
.32 .366 .256 r
.3832 .68043 m .40859 .70134 L .42163 .69792 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.4456 .71545 m .42163 .69792 L .40859 .70134 L p F P
.505 .664 .505 r
s
.304 .342 .242 r
.42163 .69792 m .4456 .71545 L .45638 .71333 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.47734 .27264 m .45638 .28667 L .46877 .28827 L p F P
.505 .664 .505 r
s
.597 .819 .612 r
.46877 .28827 m .48372 .27353 L .47734 .27264 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.48372 .72647 m .46877 .71173 L .45638 .71333 L p F P
.505 .664 .505 r
s
.271 .296 .214 r
.46877 .71173 m .48372 .72647 L .49074 .72588 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.39896 .29471 m .37018 .31502 L .3832 .31957 L p F P
.505 .664 .505 r
s
.555 .759 .553 r
.3832 .31957 m .40859 .29866 L .39896 .29471 L p F P
.505 .664 .505 r
s
.311 .358 .25 r
.34488 .66059 m .37018 .68498 L .3832 .68043 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.40859 .70134 m .3832 .68043 L .37018 .68498 L p F P
.505 .664 .505 r
s
.61 .836 .632 r
.5376 .28754 m .51957 .27312 L .51284 .27387 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.51957 .27312 m .5376 .28754 L .54924 .28567 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.5376 .71246 m .51957 .72688 L .52552 .72791 L p F P
.505 .664 .505 r
s
.246 .262 .193 r
.52552 .72791 m .54924 .71433 L .5376 .71246 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.26939 .46342 m .26655 .5 L .2842 .5 L p F P
.505 .664 .505 r
s
.365 .47 .309 r
.2842 .5 m .28671 .46503 L .26939 .46342 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.28671 .53497 m .2842 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.27785 .42772 m .26939 .46342 L .28671 .46503 L p F P
.505 .664 .505 r
s
.395 .518 .348 r
.28671 .46503 m .2942 .43077 L .27785 .42772 L p F P
.505 .664 .505 r
s
.348 .439 .291 r
.26655 .5 m .26939 .53658 L .28671 .53497 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.2942 .56923 m .28671 .53497 L .26939 .53658 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.62388 .31737 m .64765 .34184 L .66116 .33683 L p F P
.505 .664 .505 r
s
.567 .766 .598 r
.68373 .36485 m .66116 .33683 L .64765 .34184 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.64765 .65816 m .62388 .68263 L .63452 .68746 L p F P
.505 .664 .505 r
s
.271 .306 .234 r
.63452 .68746 m .66116 .66317 L .64765 .65816 L p F P
.505 .664 .505 r
s
.619 .843 .643 r
.58528 .30044 m .55905 .28331 L .54924 .28567 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.55905 .28331 m .58528 .30044 L .59668 .29675 L p F P
.505 .664 .505 r
s
.61 .83 .637 r
.62388 .31737 m .59668 .29675 L .58528 .30044 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.58528 .69956 m .55905 .71669 L .56657 .71945 L p F P
.505 .664 .505 r
s
.241 .258 .19 r
.56657 .71945 m .59668 .70325 L .58528 .69956 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.29173 .39373 m .27785 .42772 L .2942 .43077 L p F P
.505 .664 .505 r
s
.423 .562 .385 r
.2942 .43077 m .30655 .39796 L .29173 .39373 L p F P
.505 .664 .505 r
s
.331 .41 .275 r
.26939 .53658 m .27785 .57228 L .2942 .56923 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.30655 .60204 m .2942 .56923 L .27785 .57228 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.47187 .27147 m .4456 .28455 L .45638 .28667 L p F P
.505 .664 .505 r
s
.583 .803 .599 r
.45638 .28667 m .47734 .27264 L .47187 .27147 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.47734 .72736 m .45638 .71333 L .4456 .71545 L p F P
.505 .664 .505 r
s
.262 .283 .206 r
.45638 .71333 m .47734 .72736 L .48372 .72647 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.31071 .36228 m .29173 .39373 L .30655 .39796 L p F P
.505 .664 .505 r
s
.448 .603 .42 r
.30655 .39796 m .32354 .36727 L .31071 .36228 L p F P
.505 .664 .505 r
s
.313 .378 .257 r
.27785 .57228 m .29173 .60627 L .30655 .60204 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.32354 .63273 m .30655 .60204 L .29173 .60627 L p F P
.505 .664 .505 r
s
.602 .828 .628 r
.54924 .28567 m .52552 .27209 L .51957 .27312 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.52552 .27209 m .54924 .28567 L .55905 .28331 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.54924 .71433 m .52552 .72791 L .53045 .7292 L p F P
.505 .664 .505 r
s
.226 .236 .177 r
.53045 .7292 m .55905 .71669 L .54924 .71433 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.59668 .29675 m .62388 .31737 L .63452 .31254 L p F P
.505 .664 .505 r
s
.574 .781 .608 r
.66116 .33683 m .63452 .31254 L .62388 .31737 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.62388 .68263 m .59668 .70325 L .60439 .70742 L p F P
.505 .664 .505 r
s
.224 .239 .179 r
.60439 .70742 m .63452 .68746 L .62388 .68263 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.33435 .33413 m .31071 .36228 L .32354 .36727 L p F P
.505 .664 .505 r
s
.471 .64 .452 r
.32354 .36727 m .34488 .33941 L .33435 .33413 L p F P
.505 .664 .505 r
s
.292 .344 .238 r
.29173 .60627 m .31071 .63772 L .32354 .63273 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.34488 .66059 m .32354 .63273 L .31071 .63772 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.43065 .27904 m .39896 .29471 L .40859 .29866 L p F P
.505 .664 .505 r
s
.554 .763 .562 r
.40859 .29866 m .43688 .28198 L .43065 .27904 L p F P
.505 .664 .505 r
s
.279 .31 .222 r
.37018 .68498 m .39896 .70529 L .40859 .70134 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.43688 .71802 m .40859 .70134 L .39896 .70529 L p F P
.505 .664 .505 r
s
.278 .306 .22 r
.40859 .70134 m .43688 .71802 L .4456 .71545 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.46755 .27007 m .43688 .28198 L .4456 .28455 L p F P
.505 .664 .505 r
s
.566 .783 .584 r
.4456 .28455 m .47187 .27147 L .46755 .27007 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.47187 .72853 m .4456 .71545 L .43688 .71802 L p F P
.505 .664 .505 r
s
.247 .263 .194 r
.4456 .71545 m .47187 .72853 L .47734 .72736 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.36211 .30995 m .33435 .33413 L .34488 .33941 L p F P
.505 .664 .505 r
s
.489 .672 .482 r
.34488 .33941 m .37018 .31502 L .36211 .30995 L p F P
.505 .664 .505 r
s
.27 .308 .217 r
.31071 .63772 m .33435 .66587 L .34488 .66059 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.37018 .68498 m .34488 .66059 L .33435 .66587 L p F P
.505 .664 .505 r
s
.59 .814 .62 r
.55905 .28331 m .53045 .2708 L .52552 .27209 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.53045 .2708 m .55905 .28331 L .56657 .28055 L p F P
.505 .664 .505 r
s
.597 .82 .629 r
.59668 .29675 m .56657 .28055 L .55905 .28331 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.55905 .71669 m .53045 .7292 L .53411 .7307 L p F P
.505 .664 .505 r
s
.207 .213 .162 r
.53411 .7307 m .56657 .71945 L .55905 .71669 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.56657 .28055 m .59668 .29675 L .60439 .29258 L p F P
.505 .664 .505 r
s
.574 .787 .611 r
.63452 .31254 m .60439 .29258 L .59668 .29675 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.59668 .70325 m .56657 .71945 L .57141 .72253 L p F P
.505 .664 .505 r
s
.202 .208 .158 r
.57141 .72253 m .60439 .70742 L .59668 .70325 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.72294 .46425 m .72562 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.72562 .5 m .72294 .53575 L .73609 .53744 L p F P
.505 .664 .505 r
s
.348 .445 .365 r
.73609 .53744 m .73907 .5 L .72562 .5 L p F P
.505 .664 .505 r
s
.555 .774 .585 r
.49813 .27437 m .5 .26345 L .49074 .27412 L closepath p F P
.505 .664 .505 r
s
.556 .775 .587 r
.50559 .27429 m .5 .26345 L .49813 .27437 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .49813 .72563 L .49074 .72588 L closepath p F P
.505 .664 .505 r
s
.202 .208 .158 r
.5 .73655 m .50559 .72571 L .49813 .72563 L closepath p F P
.505 .664 .505 r
s
.555 .774 .587 r
.51284 .27387 m .5 .26345 L .50559 .27429 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .51284 .72613 L .50559 .72571 L closepath p F P
.505 .664 .505 r
s
.415 .55 .447 r
.71494 .42929 m .72294 .46425 L .73609 .46256 L p F P
.505 .664 .505 r
s
.382 .499 .408 r
.73907 .5 m .73609 .46256 L .72294 .46425 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72294 .53575 m .71494 .57071 L .72724 .57394 L p F P
.505 .664 .505 r
s
.312 .389 .32 r
.72724 .57394 m .73609 .53744 L .72294 .53575 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.39333 .29036 m .36211 .30995 L .37018 .31502 L p F P
.505 .664 .505 r
s
.504 .697 .507 r
.37018 .31502 m .39896 .29471 L .39333 .29036 L p F P
.505 .664 .505 r
s
.246 .271 .196 r
.33435 .66587 m .36211 .69005 L .37018 .68498 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.39896 .70529 m .37018 .68498 L .36211 .69005 L p F P
.505 .664 .505 r
s
.552 .77 .582 r
.49074 .27412 m .5 .26345 L .48372 .27353 L closepath p F P
.505 .664 .505 r
s
.201 .207 .157 r
.5 .73655 m .49074 .72588 L .48372 .72647 L closepath p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71494 .57071 m .70178 .6041 L .71274 .60854 L p F P
.505 .664 .505 r
s
.275 .332 .274 r
.71274 .60854 m .72724 .57394 L .71494 .57071 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.70178 .3959 m .71494 .42929 L .72724 .42606 L p F P
.505 .664 .505 r
s
.415 .55 .447 r
.73609 .46256 m .72724 .42606 L .71494 .42929 L p F P
.505 .664 .505 r
s
.553 .772 .586 r
.51957 .27312 m .5 .26345 L .51284 .27387 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .51957 .72688 L .51284 .72613 L closepath p F P
.505 .664 .505 r
s
.544 .757 .564 r
.46458 .26849 m .43065 .27904 L .43688 .28198 L p F P
.505 .664 .505 r
s
.544 .757 .564 r
.43688 .28198 m .46755 .27007 L .46458 .26849 L p F P
.505 .664 .505 r
s
.242 .258 .19 r
.39896 .70529 m .43065 .72096 L .43688 .71802 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.46755 .72993 m .43688 .71802 L .43065 .72096 L p F P
.505 .664 .505 r
s
.227 .236 .177 r
.43688 .71802 m .46755 .72993 L .47187 .72853 L p F P
.505 .664 .505 r
s
.547 .764 .578 r
.48372 .27353 m .5 .26345 L .47734 .27264 L closepath p F P
.505 .664 .505 r
s
.198 .205 .156 r
.5 .73655 m .48372 .72647 L .47734 .72736 L closepath p F P
.505 .664 .505 r
s
.469 .638 .513 r
.68373 .36485 m .70178 .3959 L .71274 .39146 L p F P
.505 .664 .505 r
s
.444 .597 .482 r
.72724 .42606 m .71274 .39146 L .70178 .3959 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.70178 .6041 m .68373 .63515 L .69297 .64039 L p F P
.505 .664 .505 r
s
.238 .276 .227 r
.69297 .64039 m .71274 .60854 L .70178 .6041 L p F P
.505 .664 .505 r
s
.549 .767 .583 r
.52552 .27209 m .5 .26345 L .51957 .27312 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .52552 .72791 L .51957 .72688 L closepath p F P
.505 .664 .505 r
s
.491 .673 .537 r
.66116 .33683 m .68373 .36485 L .69297 .35961 L p F P
.505 .664 .505 r
s
.469 .638 .513 r
.71274 .39146 m .69297 .35961 L .68373 .36485 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.68373 .63515 m .66116 .66317 L .66846 .66869 L p F P
.505 .664 .505 r
s
.202 .221 .181 r
.66846 .66869 m .69297 .64039 L .68373 .63515 L p F P
.505 .664 .505 r
s
.541 .757 .572 r
.47734 .27264 m .5 .26345 L .47187 .27147 L closepath p F P
.505 .664 .505 r
s
.195 .201 .153 r
.5 .73655 m .47734 .72736 L .47187 .72853 L closepath p F P
.505 .664 .505 r
s
.513 .715 .527 r
.42727 .27585 m .39333 .29036 L .39896 .29471 L p F P
.505 .664 .505 r
s
.513 .715 .527 r
.39896 .29471 m .43065 .27904 L .42727 .27585 L p F P
.505 .664 .505 r
s
.222 .234 .174 r
.36211 .69005 m .39333 .70964 L .39896 .70529 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.43065 .72096 m .39896 .70529 L .39333 .70964 L p F P
.505 .664 .505 r
s
.573 .795 .608 r
.56657 .28055 m .53411 .2693 L .53045 .2708 L p F P
.505 .664 .505 r
s
.551 .768 .591 r
.53411 .2693 m .56657 .28055 L .57141 .27747 L p F P
.505 .664 .505 r
s
.566 .784 .606 r
.60439 .29258 m .57141 .27747 L .56657 .28055 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.56657 .71945 m .53411 .7307 L .53635 .73235 L p F P
.505 .664 .505 r
s
.191 .198 .15 r
.53635 .73235 m .57141 .72253 L .56657 .71945 L p F P
.505 .664 .505 r
s
.543 .76 .579 r
.53045 .2708 m .5 .26345 L .52552 .27209 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .53045 .7292 L .52552 .72791 L closepath p F P
.505 .664 .505 r
s
.507 .701 .556 r
.63452 .31254 m .66116 .33683 L .66846 .33131 L p F P
.505 .664 .505 r
s
.491 .673 .537 r
.69297 .35961 m .66846 .33131 L .66116 .33683 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.66116 .66317 m .63452 .68746 L .63983 .69272 L p F P
.505 .664 .505 r
s
.178 .189 .147 r
.63983 .69272 m .66846 .66869 L .66116 .66317 L p F P
.505 .664 .505 r
s
.533 .748 .565 r
.47187 .27147 m .5 .26345 L .46755 .27007 L closepath p F P
.505 .664 .505 r
s
.19 .197 .15 r
.5 .73655 m .47187 .72853 L .46755 .72993 L closepath p F P
.505 .664 .505 r
s
.518 .721 .567 r
.60439 .29258 m .63452 .31254 L .63983 .30728 L p F P
.505 .664 .505 r
s
.507 .701 .556 r
.66846 .33131 m .63983 .30728 L .63452 .31254 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.63452 .68746 m .60439 .70742 L .60783 .71191 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60783 .71191 m .63983 .69272 L .63452 .68746 L p F P
.505 .664 .505 r
s
.535 .751 .573 r
.53411 .2693 m .5 .26345 L .53045 .2708 L closepath p F P
.505 .664 .505 r
s
.184 .192 .146 r
.5 .73655 m .53411 .7307 L .53045 .7292 L closepath p F P
.505 .664 .505 r
s
.517 .725 .541 r
.46311 .26679 m .42727 .27585 L .43065 .27904 L p F P
.505 .664 .505 r
s
.517 .725 .541 r
.43065 .27904 m .46458 .26849 L .46311 .26679 L p F P
.505 .664 .505 r
s
.203 .209 .159 r
.39333 .70964 m .42727 .72415 L .43065 .72096 L p F P
.505 .664 .505 r
s
.191 .198 .151 r
.46458 .73151 m .43065 .72096 L .42727 .72415 L p F P
.505 .664 .505 r
s
.208 .214 .163 r
.43065 .72096 m .46458 .73151 L .46755 .72993 L p F P
.505 .664 .505 r
s
.524 .737 .557 r
.46755 .27007 m .5 .26345 L .46458 .26849 L closepath p F P
.505 .664 .505 r
s
.185 .192 .146 r
.5 .73655 m .46755 .72993 L .46458 .73151 L closepath p F P
.505 .664 .505 r
s
.524 .733 .572 r
.57141 .27747 m .60439 .29258 L .60783 .28809 L p F P
.505 .664 .505 r
s
.518 .721 .567 r
.63983 .30728 m .60783 .28809 L .60439 .29258 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.60439 .70742 m .57141 .72253 L .57327 .72581 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57327 .72581 m .60783 .71191 L .60439 .70742 L p F P
.505 .664 .505 r
s
.526 .74 .566 r
.53635 .26765 m .5 .26345 L .53411 .2693 L closepath p F P
.505 .664 .505 r
s
.551 .768 .591 r
.57141 .27747 m .53635 .26765 L .53411 .2693 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .53635 .73235 L .53411 .7307 L closepath p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26084 .46165 m .25775 .5 L .26655 .5 L p F P
.505 .664 .505 r
s
.244 .318 .21 r
.26655 .5 m .26939 .46342 L .26084 .46165 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.26939 .53658 m .26655 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.27002 .42434 m .26084 .46165 L .26939 .46342 L p F P
.505 .664 .505 r
s
.261 .349 .227 r
.26939 .46342 m .27785 .42772 L .27002 .42434 L p F P
.505 .664 .505 r
s
.228 .286 .193 r
.25775 .5 m .26084 .53835 L .26939 .53658 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.27785 .57228 m .26939 .53658 L .26084 .53835 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.28501 .38909 m .27002 .42434 L .27785 .42772 L p F P
.505 .664 .505 r
s
.285 .389 .254 r
.27785 .42772 m .29173 .39373 L .28501 .38909 L p F P
.505 .664 .505 r
s
.211 .255 .177 r
.26084 .53835 m .27002 .57566 L .27785 .57228 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.29173 .60627 m .27785 .57228 L .27002 .57566 L p F P
.505 .664 .505 r
s
.523 .735 .568 r
.53635 .26765 m .57141 .27747 L .57327 .27419 L p F P
.505 .664 .505 r
s
.524 .733 .572 r
.60783 .28809 m .57327 .27419 L .57141 .27747 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.57141 .72253 m .53635 .73235 L .53702 .73408 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.53702 .73408 m .57327 .72581 L .57141 .72253 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.30538 .35684 m .28501 .38909 L .29173 .39373 L p F P
.505 .664 .505 r
s
.325 .45 .304 r
.29173 .39373 m .31071 .36228 L .30538 .35684 L p F P
.505 .664 .505 r
s
.196 .226 .161 r
.27002 .57566 m .28501 .61091 L .29173 .60627 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.31071 .63772 m .29173 .60627 L .28501 .61091 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.33053 .32842 m .30538 .35684 L .31071 .36228 L p F P
.505 .664 .505 r
s
.363 .508 .353 r
.31071 .36228 m .33435 .33413 L .33053 .32842 L p F P
.505 .664 .505 r
s
.181 .198 .147 r
.28501 .61091 m .30538 .64316 L .31071 .63772 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.33435 .66587 m .31071 .63772 L .30538 .64316 L p F P
.505 .664 .505 r
s
.514 .725 .548 r
.46458 .26849 m .5 .26345 L .46311 .26679 L closepath p F P
.505 .664 .505 r
s
.191 .198 .151 r
.42727 .72415 m .46311 .73321 L .46458 .73151 L p F P
.505 .664 .505 r
s
.178 .186 .142 r
.5 .73655 m .46458 .73151 L .46311 .73321 L closepath p F P
.505 .664 .505 r
s
.399 .562 .4 r
.35974 .30454 m .33053 .32842 L .33435 .33413 L p F P
.505 .664 .505 r
s
.399 .562 .4 r
.33435 .33413 m .36211 .30995 L .35974 .30454 L p F P
.505 .664 .505 r
s
.171 .179 .137 r
.30538 .64316 m .33053 .67158 L .33435 .66587 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.36211 .69005 m .33435 .66587 L .33053 .67158 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.33053 .67158 m .35974 .69546 L .36211 .69005 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39333 .70964 m .36211 .69005 L .35974 .69546 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.39219 .28577 m .35974 .30454 L .36211 .30995 L p F P
.505 .664 .505 r
s
.432 .611 .443 r
.36211 .30995 m .39333 .29036 L .39219 .28577 L p F P
.505 .664 .505 r
s
.516 .728 .557 r
.53702 .26592 m .5 .26345 L .53635 .26765 L closepath p F P
.505 .664 .505 r
s
.523 .735 .568 r
.57327 .27419 m .53702 .26592 L .53635 .26765 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .53702 .73408 L .53635 .73235 L closepath p F P
.505 .664 .505 r
s
.461 .653 .481 r
.427 .27253 m .39219 .28577 L .39333 .29036 L p F P
.505 .664 .505 r
s
.461 .653 .481 r
.39333 .29036 m .42727 .27585 L .427 .27253 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.35974 .69546 m .39219 .71423 L .39333 .70964 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.42727 .72415 m .39333 .70964 L .39219 .71423 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.46325 .26505 m .427 .27253 L .42727 .27585 L p F P
.505 .664 .505 r
s
.485 .687 .513 r
.42727 .27585 m .46311 .26679 L .46325 .26505 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.39219 .71423 m .427 .72747 L .42727 .72415 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.46311 .73321 m .42727 .72415 L .427 .72747 L p F P
.505 .664 .505 r
s
.504 .712 .539 r
.46311 .26679 m .5 .26345 L .46325 .26505 L closepath p F P
.505 .664 .505 r
s
.171 .18 .137 r
.427 .72747 m .46325 .73495 L .46311 .73321 L p F P
.505 .664 .505 r
s
.171 .18 .137 r
.5 .73655 m .46311 .73321 L .46325 .73495 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .50201 .74224 L .50992 .74195 L closepath p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5 .73655 m .494 .74214 L .50201 .74224 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .48628 .74166 L .494 .74214 L closepath p F P
.505 .664 .505 r
s
.14 .151 .115 r
.5 .73655 m .47923 .74082 L .48628 .74166 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .47316 .73967 L .47923 .74082 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .46835 .73825 L .47316 .73967 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .46501 .73666 L .46835 .73825 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .46325 .73495 L .46501 .73666 L closepath p F P
.505 .664 .505 r
s
.164 .173 .132 r
.5 .73655 m .53608 .73581 L .53702 .73408 L closepath p F P
.505 .664 .505 r
s
.157 .167 .127 r
.5 .73655 m .53351 .73747 L .53608 .73581 L closepath p F P
.505 .664 .505 r
s
.151 .161 .122 r
.5 .73655 m .52942 .73899 L .53351 .73747 L closepath p F P
.505 .664 .505 r
s
.145 .156 .118 r
.5 .73655 m .52395 .74028 L .52942 .73899 L closepath p F P
.505 .664 .505 r
s
.141 .151 .115 r
.5 .73655 m .51735 .74128 L .52395 .74028 L closepath p F P
.505 .664 .505 r
s
.137 .148 .113 r
.5 .73655 m .50992 .74195 L .51735 .74128 L closepath p F P
.505 .664 .505 r
s
.506 .715 .548 r
.53608 .26419 m .5 .26345 L .53702 .26592 L closepath p F P
.505 .664 .505 r
s
.494 .702 .539 r
.53351 .26253 m .5 .26345 L .53608 .26419 L closepath p F P
.505 .664 .505 r
s
.493 .699 .53 r
.46325 .26505 m .5 .26345 L .46501 .26334 L closepath p F P
.505 .664 .505 r
s
.483 .689 .529 r
.52942 .26101 m .5 .26345 L .53351 .26253 L closepath p F P
.505 .664 .505 r
s
.482 .686 .521 r
.46501 .26334 m .5 .26345 L .46835 .26175 L closepath p F P
.505 .664 .505 r
s
.473 .676 .52 r
.52395 .25972 m .5 .26345 L .52942 .26101 L closepath p F P
.505 .664 .505 r
s
.472 .674 .513 r
.46835 .26175 m .5 .26345 L .47316 .26033 L closepath p F P
.505 .664 .505 r
s
.465 .666 .512 r
.51735 .25872 m .5 .26345 L .52395 .25972 L closepath p F P
.505 .664 .505 r
s
.464 .664 .506 r
.47316 .26033 m .5 .26345 L .47923 .25918 L closepath p F P
.505 .664 .505 r
s
.458 .658 .505 r
.50992 .25805 m .5 .26345 L .51735 .25872 L closepath p F P
.505 .664 .505 r
s
.458 .657 .502 r
.47923 .25918 m .5 .26345 L .48628 .25834 L closepath p F P
.505 .664 .505 r
s
.454 .652 .501 r
.50201 .25776 m .5 .26345 L .50992 .25805 L closepath p F P
.505 .664 .505 r
s
.454 .652 .499 r
.48628 .25834 m .5 .26345 L .494 .25786 L closepath p F P
.505 .664 .505 r
s
.453 .651 .499 r
.494 .25786 m .5 .26345 L .50201 .25776 L closepath p F P
.505 .664 .505 r
s
.15 .16 .122 r
.57327 .72581 m .53702 .73408 L .53608 .73581 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.53702 .26592 m .57327 .27419 L .57192 .27086 L p F P
.505 .664 .505 r
s
.49 .695 .54 r
.57192 .27086 m .53608 .26419 L .53702 .26592 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.57327 .27419 m .60783 .28809 L .60658 .28345 L p F P
.505 .664 .505 r
s
.468 .666 .525 r
.60658 .28345 m .57192 .27086 L .57327 .27419 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.60783 .71191 m .57327 .72581 L .57192 .72914 L p F P
.505 .664 .505 r
s
.15 .16 .122 r
.53608 .73581 m .57192 .72914 L .57327 .72581 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.60783 .28809 m .63983 .30728 L .63911 .30177 L p F P
.505 .664 .505 r
s
.44 .626 .501 r
.63911 .30177 m .60658 .28345 L .60783 .28809 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.63983 .69272 m .60783 .71191 L .60658 .71655 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.57192 .72914 m .60658 .71655 L .60783 .71191 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.42999 .73078 m .46501 .73666 L .46325 .73495 L p F P
.505 .664 .505 r
s
.149 .16 .121 r
.46325 .73495 m .427 .72747 L .42999 .73078 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.427 .27253 m .46325 .26505 L .46501 .26334 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.63983 .30728 m .66846 .33131 L .66858 .32547 L p F P
.505 .664 .505 r
s
.407 .578 .47 r
.66858 .32547 m .63911 .30177 L .63983 .30728 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.66846 .66869 m .63983 .69272 L .63911 .69823 L p F P
.505 .664 .505 r
s
.122 .134 .102 r
.60658 .71655 m .63911 .69823 L .63983 .69272 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.66846 .33131 m .69297 .35961 L .69409 .35401 L p F P
.505 .664 .505 r
s
.369 .523 .433 r
.69409 .35401 m .66858 .32547 L .66846 .33131 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.69297 .64039 m .66846 .66869 L .66858 .67453 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.63911 .69823 m .66858 .67453 L .66846 .66869 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.57192 .72914 m .53608 .73581 L .53351 .73747 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.53608 .26419 m .57192 .27086 L .56728 .26762 L p F P
.505 .664 .505 r
s
.453 .65 .508 r
.56728 .26762 m .53351 .26253 L .53608 .26419 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.69297 .35961 m .71274 .39146 L .71485 .38667 L p F P
.505 .664 .505 r
s
.328 .462 .39 r
.71485 .38667 m .69409 .35401 L .69297 .35961 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.71274 .60854 m .69297 .64039 L .69409 .64599 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.66858 .67453 m .69409 .64599 L .69297 .64039 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.72724 .57394 m .71274 .60854 L .71485 .61333 L p F P
.505 .664 .505 r
s
.109 .131 .11 r
.69409 .64599 m .71485 .61333 L .71274 .60854 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.71274 .39146 m .72724 .42606 L .73019 .42257 L p F P
.505 .664 .505 r
s
.286 .399 .344 r
.73019 .42257 m .71485 .38667 L .71274 .39146 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.39589 .71886 m .42999 .73078 L .427 .72747 L p F P
.505 .664 .505 r
s
.134 .145 .111 r
.427 .72747 m .39219 .71423 L .39589 .71886 L p F P
.505 .664 .505 r
s
.45 .644 .483 r
.46501 .26334 m .42999 .26922 L .427 .27253 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.39219 .28577 m .427 .27253 L .42999 .26922 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73609 .53744 m .72724 .57394 L .73019 .57743 L p F P
.505 .664 .505 r
s
.125 .155 .137 r
.71485 .61333 m .73019 .57743 L .72724 .57394 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.72724 .42606 m .73609 .46256 L .7396 .46071 L p F P
.505 .664 .505 r
s
.243 .334 .296 r
.7396 .46071 m .73019 .42257 L .72724 .42606 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.73609 .46256 m .73907 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.202 .269 .246 r
.74277 .5 m .7396 .46071 L .73609 .46256 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.73907 .5 m .73609 .53744 L .7396 .53929 L p F P
.505 .664 .505 r
s
.143 .181 .167 r
.73019 .57743 m .7396 .53929 L .73609 .53744 L p F P
.505 .664 .505 r
s
.163 .208 .198 r
.7396 .53929 m .74277 .5 L .73907 .5 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.43626 .73392 m .46835 .73825 L .46501 .73666 L p F P
.505 .664 .505 r
s
.127 .139 .105 r
.46501 .73666 m .42999 .73078 L .43626 .73392 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.42999 .26922 m .46501 .26334 L .46835 .26175 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.36367 .701 m .39589 .71886 L .39219 .71423 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.39219 .71423 m .35974 .69546 L .36367 .701 L p F P
.505 .664 .505 r
s
.399 .576 .427 r
.42999 .26922 m .39589 .28114 L .39219 .28577 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.35974 .30454 m .39219 .28577 L .39589 .28114 L p F P
.505 .664 .505 r
s
.128 .14 .106 r
.53351 .73747 m .56728 .73238 L .57192 .72914 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.56728 .73238 m .53351 .73747 L .52942 .73899 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.53351 .26253 m .56728 .26762 L .55944 .26462 L p F P
.505 .664 .505 r
s
.415 .603 .473 r
.55944 .26462 m .52942 .26101 L .53351 .26253 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.60658 .71655 m .57192 .72914 L .56728 .73238 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.57192 .27086 m .60658 .28345 L .60039 .27887 L p F P
.505 .664 .505 r
s
.402 .584 .466 r
.60039 .27887 m .56728 .26762 L .57192 .27086 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.44561 .73673 m .47316 .73967 L .46835 .73825 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.46835 .73825 m .43626 .73392 L .44561 .73673 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.43626 .26608 m .46835 .26175 L .47316 .26033 L p F P
.505 .664 .505 r
s
.413 .599 .451 r
.46835 .26175 m .43626 .26608 L .42999 .26922 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.3343 .67749 m .36367 .701 L .35974 .69546 L p F P
.505 .664 .505 r
s
.104 .118 .09 r
.35974 .69546 m .33053 .67158 L .3343 .67749 L p F P
.505 .664 .505 r
s
.342 .499 .362 r
.39589 .28114 m .36367 .299 L .35974 .30454 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.33053 .32842 m .35974 .30454 L .36367 .299 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.52942 .73899 m .55944 .73538 L .56728 .73238 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.55944 .73538 m .52942 .73899 L .52395 .74028 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.52942 .26101 m .55944 .26462 L .54866 .26204 L p F P
.505 .664 .505 r
s
.378 .557 .439 r
.54866 .26204 m .52395 .25972 L .52942 .26101 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.30873 .64885 m .3343 .67749 L .33053 .67158 L p F P
.505 .664 .505 r
s
.091 .106 .08 r
.33053 .67158 m .30538 .64316 L .30873 .64885 L p F P
.505 .664 .505 r
s
.28 .413 .292 r
.36367 .299 m .3343 .32251 L .33053 .32842 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.30538 .35684 m .33053 .32842 L .3343 .32251 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.4577 .73906 m .47923 .74082 L .47316 .73967 L p F P
.505 .664 .505 r
s
.085 .1 .076 r
.47316 .73967 m .44561 .73673 L .4577 .73906 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.44561 .26327 m .47316 .26033 L .47923 .25918 L p F P
.505 .664 .505 r
s
.377 .555 .421 r
.47316 .26033 m .44561 .26327 L .43626 .26608 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.40457 .72332 m .43626 .73392 L .42999 .73078 L p F P
.505 .664 .505 r
s
.094 .108 .082 r
.42999 .73078 m .39589 .71886 L .40457 .72332 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.39589 .28114 m .42999 .26922 L .43626 .26608 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.63911 .69823 m .60658 .71655 L .60039 .72113 L p F P
.505 .664 .505 r
s
.097 .111 .084 r
.56728 .73238 m .60039 .72113 L .60658 .71655 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.60658 .28345 m .63911 .30177 L .63189 .29627 L p F P
.505 .664 .505 r
s
.342 .504 .413 r
.63189 .29627 m .60039 .27887 L .60658 .28345 L p F P
.505 .664 .505 r
s
.086 .101 .077 r
.52395 .74028 m .54866 .73796 L .55944 .73538 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.54866 .73796 m .52395 .74028 L .51735 .74128 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.52395 .25972 m .54866 .26204 L .5354 .26001 L p F P
.505 .664 .505 r
s
.345 .516 .408 r
.5354 .26001 m .51735 .25872 L .52395 .25972 L p F P
.505 .664 .505 r
s
.216 .323 .219 r
.3343 .32251 m .30873 .35115 L .30538 .35684 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.28501 .38909 m .30538 .35684 L .30873 .35115 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.28783 .6158 m .30873 .64885 L .30538 .64316 L p F P
.505 .664 .505 r
s
.079 .095 .072 r
.30538 .64316 m .28501 .61091 L .28783 .6158 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47197 .74076 m .48628 .74166 L .47923 .74082 L p F P
.505 .664 .505 r
s
.069 .085 .065 r
.47923 .74082 m .4577 .73906 L .47197 .74076 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.4577 .26094 m .47923 .25918 L .48628 .25834 L p F P
.505 .664 .505 r
s
.345 .515 .394 r
.47923 .25918 m .4577 .26094 L .44561 .26327 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.27233 .57924 m .28783 .6158 L .28501 .61091 L p F P
.505 .664 .505 r
s
.232 .325 .291 r
.28501 .61091 m .27002 .57566 L .27233 .57924 L p F P
.505 .664 .505 r
s
.153 .234 .146 r
.30873 .35115 m .28783 .3842 L .28501 .38909 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.27002 .42434 m .28501 .38909 L .28783 .3842 L p F P
.505 .664 .505 r
s
.07 .086 .066 r
.51735 .74128 m .5354 .73999 L .54866 .73796 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.5354 .73999 m .51735 .74128 L .50992 .74195 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.51735 .25872 m .5354 .26001 L .5203 .25865 L p F P
.505 .664 .505 r
s
.32 .484 .383 r
.5203 .25865 m .50992 .25805 L .51735 .25872 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.60039 .72113 m .56728 .73238 L .55944 .73538 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.56728 .26762 m .60039 .27887 L .58926 .27459 L p F P
.505 .664 .505 r
s
.33 .493 .399 r
.58926 .27459 m .55944 .26462 L .56728 .26762 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48771 .74174 m .494 .74214 L .48628 .74166 L p F P
.505 .664 .505 r
s
.312 .474 .374 r
.48628 .74166 m .47197 .74076 L .48771 .74174 L p F P
.505 .664 .505 r
s
.32 .484 .373 r
.48628 .25834 m .47197 .25924 L .4577 .26094 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.47197 .25924 m .48628 .25834 L .494 .25786 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.2628 .54024 m .27233 .57924 L .27002 .57566 L p F P
.505 .664 .505 r
s
.204 .281 .258 r
.27002 .57566 m .26084 .53835 L .2628 .54024 L p F P
.505 .664 .505 r
s
.087 .114 .1 r
.28783 .3842 m .27233 .42076 L .27002 .42434 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.26084 .46165 m .27002 .42434 L .27233 .42076 L p F P
.505 .664 .505 r
s
.058 .076 .058 r
.50992 .74195 m .5203 .74135 L .5354 .73999 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.5203 .74135 m .50992 .74195 L .50201 .74224 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50992 .25805 m .5203 .25865 L .50411 .25806 L p F P
.505 .664 .505 r
s
.06 .077 .059 r
.50411 .25806 m .50201 .25776 L .50992 .25805 L p F P
.505 .664 .505 r
s
.066 .083 .063 r
.60039 .72113 m .63189 .70373 L .63911 .69823 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.66858 .67453 m .63911 .69823 L .63189 .70373 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.63911 .30177 m .66858 .32547 L .66077 .31957 L p F P
.505 .664 .505 r
s
.076 .092 .07 r
.66077 .31957 m .63189 .29627 L .63911 .30177 L p F P
.505 .664 .505 r
s
.115 .151 .14 r
.27233 .42076 m .2628 .45976 L .26084 .46165 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.25775 .5 m .26084 .46165 L .2628 .45976 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.25958 .5 m .2628 .54024 L .26084 .53835 L p F P
.505 .664 .505 r
s
.169 .226 .215 r
.26084 .53835 m .25775 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.50411 .74194 m .50201 .74224 L .494 .74214 L p F P
.505 .664 .505 r
s
.318 .481 .377 r
.494 .74214 m .48771 .74174 L .50411 .74194 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.48771 .25826 m .494 .25786 L .50201 .25776 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.494 .25786 m .48771 .25826 L .47197 .25924 L p F P
.505 .664 .505 r
s
.312 .474 .369 r
.50201 .74224 m .50411 .74194 L .5203 .74135 L p F P
.505 .664 .505 r
s
.06 .078 .059 r
.50201 .25776 m .50411 .25806 L .48771 .25826 L p F P
.505 .664 .505 r
s
.141 .185 .177 r
.2628 .45976 m .25958 .5 L .25775 .5 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.37424 .70639 m .40457 .72332 L .39589 .71886 L p F P
.505 .664 .505 r
s
.32 .475 .391 r
.39589 .71886 m .36367 .701 L .37424 .70639 L p F P
.505 .664 .505 r
s
.331 .492 .366 r
.43626 .26608 m .40457 .27668 L .39589 .28114 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.36367 .299 m .39589 .28114 L .40457 .27668 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.41809 .72736 m .44561 .73673 L .43626 .73392 L p F P
.505 .664 .505 r
s
.329 .493 .398 r
.43626 .73392 m .40457 .72332 L .41809 .72736 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.40457 .27668 m .43626 .26608 L .44561 .26327 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.66858 .32547 m .69409 .35401 L .68605 .34829 L p F P
.505 .664 .505 r
s
.101 .115 .088 r
.68605 .34829 m .66077 .31957 L .66858 .32547 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.69409 .64599 m .66858 .67453 L .66077 .68043 L p F P
.505 .664 .505 r
s
.229 .35 .247 r
.63189 .70373 m .66077 .68043 L .66858 .67453 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.55944 .73538 m .58926 .72541 L .60039 .72113 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.58926 .72541 m .55944 .73538 L .54866 .73796 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.55944 .26462 m .58926 .27459 L .57348 .27086 L p F P
.505 .664 .505 r
s
.089 .104 .079 r
.57348 .27086 m .54866 .26204 L .55944 .26462 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.63189 .70373 m .60039 .72113 L .58926 .72541 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.60039 .27887 m .63189 .29627 L .61797 .29106 L p F P
.505 .664 .505 r
s
.102 .116 .088 r
.61797 .29106 m .58926 .27459 L .60039 .27887 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.69409 .35401 m .71485 .38667 L .70681 .38173 L p F P
.505 .664 .505 r
s
.123 .135 .103 r
.70681 .38173 m .68605 .34829 L .69409 .35401 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.71485 .61333 m .69409 .64599 L .68605 .65171 L p F P
.505 .664 .505 r
s
.241 .356 .243 r
.66077 .68043 m .68605 .65171 L .69409 .64599 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.34626 .68331 m .37424 .70639 L .36367 .701 L p F P
.505 .664 .505 r
s
.364 .526 .432 r
.36367 .701 m .3343 .67749 L .34626 .68331 L p F P
.505 .664 .505 r
s
.056 .074 .056 r
.40457 .27668 m .37424 .29361 L .36367 .299 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.3343 .32251 m .36367 .299 L .37424 .29361 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.43597 .73074 m .4577 .73906 L .44561 .73673 L p F P
.505 .664 .505 r
s
.392 .574 .454 r
.44561 .73673 m .41809 .72736 L .43597 .73074 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.41809 .27264 m .44561 .26327 L .4577 .26094 L p F P
.505 .664 .505 r
s
.058 .075 .057 r
.44561 .26327 m .41809 .27264 L .40457 .27668 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.73019 .57743 m .71485 .61333 L .70681 .61827 L p F P
.505 .664 .505 r
s
.241 .346 .229 r
.68605 .65171 m .70681 .61827 L .71485 .61333 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.71485 .38667 m .73019 .42257 L .72227 .41895 L p F P
.505 .664 .505 r
s
.142 .155 .117 r
.72227 .41895 m .70681 .38173 L .71485 .38667 L p F P
.505 .664 .505 r
s
.334 .498 .374 r
.54866 .73796 m .57348 .72914 L .58926 .72541 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.57348 .72914 m .54866 .73796 L .5354 .73999 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.54866 .26204 m .57348 .27086 L .55369 .26789 L p F P
.505 .664 .505 r
s
.117 .13 .099 r
.55369 .26789 m .5354 .26001 L .54866 .26204 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.7396 .53929 m .73019 .57743 L .72227 .58105 L p F P
.505 .664 .505 r
s
.231 .323 .206 r
.70681 .61827 m .72227 .58105 L .73019 .57743 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.73019 .42257 m .7396 .46071 L .7318 .4588 L p F P
.505 .664 .505 r
s
.176 .21 .148 r
.7318 .4588 m .72227 .41895 L .73019 .42257 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.39143 .71134 m .41809 .72736 L .40457 .72332 L p F P
.505 .664 .505 r
s
.417 .601 .48 r
.40457 .72332 m .37424 .70639 L .39143 .71134 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.37424 .29361 m .40457 .27668 L .41809 .27264 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.32164 .65452 m .34626 .68331 L .3343 .67749 L p F P
.505 .664 .505 r
s
.396 .559 .458 r
.3343 .67749 m .30873 .64885 L .32164 .65452 L p F P
.505 .664 .505 r
s
.082 .097 .074 r
.37424 .29361 m .34626 .31669 L .3343 .32251 L p F P
.505 .664 .505 r
s
.108 .122 .093 r
.30873 .35115 m .3343 .32251 L .34626 .31669 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.7396 .46071 m .74277 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
.203 .255 .173 r
.73502 .5 m .7318 .4588 L .7396 .46071 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.74277 .5 m .7396 .53929 L .7318 .5412 L p F P
.505 .664 .505 r
s
.231 .312 .203 r
.72227 .58105 m .7318 .5412 L .7396 .53929 L p F P
.505 .664 .505 r
s
.221 .289 .192 r
.7318 .5412 m .73502 .5 L .74277 .5 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.45741 .73324 m .47197 .74076 L .4577 .73906 L p F P
.505 .664 .505 r
s
.437 .63 .492 r
.4577 .73906 m .43597 .73074 L .45741 .73324 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.43597 .26926 m .4577 .26094 L .47197 .25924 L p F P
.505 .664 .505 r
s
.092 .107 .081 r
.4577 .26094 m .43597 .26926 L .41809 .27264 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.66077 .68043 m .63189 .70373 L .61797 .70894 L p F P
.505 .664 .505 r
s
.322 .477 .349 r
.58926 .72541 m .61797 .70894 L .63189 .70373 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.63189 .29627 m .66077 .31957 L .64462 .31391 L p F P
.505 .664 .505 r
s
.144 .155 .118 r
.64462 .31391 m .61797 .29106 L .63189 .29627 L p F P
.505 .664 .505 r
s
.394 .575 .434 r
.5354 .73999 m .55369 .73211 L .57348 .72914 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.55369 .73211 m .5354 .73999 L .5203 .74135 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.5354 .26001 m .55369 .26789 L .53087 .2659 L p F P
.505 .664 .505 r
s
.136 .147 .112 r
.53087 .2659 m .5203 .25865 L .5354 .26001 L p F P
.505 .664 .505 r
s
.42 .601 .443 r
.61797 .70894 m .58926 .72541 L .57348 .72914 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.58926 .27459 m .61797 .29106 L .59764 .28646 L p F P
.505 .664 .505 r
s
.149 .159 .121 r
.59764 .28646 m .57348 .27086 L .58926 .27459 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.48129 .73469 m .48771 .74174 L .47197 .74076 L p F P
.505 .664 .505 r
s
.463 .664 .513 r
.47197 .74076 m .45741 .73324 L .48129 .73469 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.45741 .26676 m .47197 .25924 L .48771 .25826 L p F P
.505 .664 .505 r
s
.119 .131 .1 r
.47197 .25924 m .45741 .26676 L .43597 .26926 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71409 .61857 m
.72616 .59308 L
s
.5 Mabswid
.108 .122 .093 r
.34626 .31669 m .32164 .34548 L .30873 .35115 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.28783 .3842 m .30873 .35115 L .32164 .34548 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30132 .62071 m .32164 .65452 L .30873 .64885 L p F P
.505 .664 .505 r
s
.411 .569 .465 r
.30873 .64885 m .28783 .6158 L .30132 .62071 L p F P
.505 .664 .505 r
s
.438 .63 .477 r
.5203 .74135 m .53087 .7341 L .55369 .73211 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.53087 .7341 m .5203 .74135 L .50411 .74194 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.5203 .25865 m .53087 .2659 L .50627 .26502 L p F P
.505 .664 .505 r
s
.145 .156 .119 r
.50627 .26502 m .50411 .25806 L .5203 .25865 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73018 .58241 m
.73125 .57997 L
s
.73125 .57997 m
.73172 .57789 L
s
.5 Mabswid
.472 .674 .517 r
.50627 .73498 m .50411 .74194 L .48771 .74174 L p F P
.505 .664 .505 r
s
.472 .674 .517 r
.48771 .74174 m .48129 .73469 L .50627 .73498 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.48129 .26531 m .48771 .25826 L .50411 .25806 L p F P
.505 .664 .505 r
s
.137 .148 .113 r
.48771 .25826 m .48129 .26531 L .45741 .26676 L p F P
.505 .664 .505 r
s
.463 .663 .505 r
.50411 .74194 m .50627 .73498 L .53087 .7341 L p F P
.505 .664 .505 r
s
.146 .156 .119 r
.50411 .25806 m .50627 .26502 L .48129 .26531 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.73018 .58241 m
.73064 .58037 L
s
.73064 .58037 m
.73172 .57789 L
s
.5 Mabswid
.41 .558 .456 r
.28614 .58285 m .30132 .62071 L .28783 .6158 L p F P
.505 .664 .505 r
s
.41 .558 .456 r
.28783 .6158 m .27233 .57924 L .28614 .58285 L p F P
.505 .664 .505 r
s
.16 .182 .152 r
.32164 .34548 m .30132 .37929 L .28783 .3842 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.27233 .42076 m .28783 .3842 L .30132 .37929 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.36656 .68871 m .39143 .71134 L .37424 .70639 L p F P
.505 .664 .505 r
s
.481 .675 .536 r
.37424 .70639 m .34626 .68331 L .36656 .68871 L p F P
.505 .664 .505 r
s
.106 .12 .091 r
.41809 .27264 m .39143 .28866 L .37424 .29361 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.34626 .31669 m .37424 .29361 L .39143 .28866 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41472 .71552 m .43597 .73074 L .41809 .72736 L p F P
.505 .664 .505 r
s
.493 .697 .546 r
.41809 .72736 m .39143 .71134 L .41472 .71552 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.39143 .28866 m .41809 .27264 L .43597 .26926 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66077 .31957 m .68605 .34829 L .66819 .34276 L p F P
.505 .664 .505 r
s
.179 .187 .142 r
.66819 .34276 m .64462 .31391 L .66077 .31957 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.68605 .65171 m .66077 .68043 L .64462 .68609 L p F P
.505 .664 .505 r
s
.37 .529 .38 r
.61797 .70894 m .64462 .68609 L .66077 .68043 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27676 .54216 m .28614 .58285 L .27233 .57924 L p F P
.505 .664 .505 r
s
.396 .528 .433 r
.27233 .57924 m .2628 .54024 L .27676 .54216 L p F P
.505 .664 .505 r
s
.216 .253 .216 r
.30132 .37929 m .28614 .41715 L .27233 .42076 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.2628 .45976 m .27233 .42076 L .28614 .41715 L p F P
.505 .664 .505 r
s
.42 .601 .443 r
.57348 .72914 m .59764 .71354 L .61797 .70894 L p F P
.505 .664 .505 r
s
.492 .692 .513 r
.59764 .71354 m .57348 .72914 L .55369 .73211 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57348 .27086 m .59764 .28646 L .57165 .28277 L p F P
.505 .664 .505 r
s
.183 .191 .145 r
.57165 .28277 m .55369 .26789 L .57348 .27086 L p F P
.505 .664 .505 r
s
.278 .344 .287 r
.28614 .41715 m .27676 .45784 L .2628 .45976 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.25958 .5 m .2628 .45976 L .27676 .45784 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.27358 .5 m .27676 .54216 L .2628 .54024 L p F P
.505 .664 .505 r
s
.368 .482 .396 r
.2628 .54024 m .25958 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.329 .42 .348 r
.27676 .45784 m .27358 .5 L .25958 .5 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68605 .34829 m .70681 .38173 L .68772 .37692 L p F P
.505 .664 .505 r
s
.234 .263 .189 r
.68772 .37692 m .66819 .34276 L .68605 .34829 L p F P
.505 .664 .505 r
s
.41 .561 .39 r
.70681 .61827 m .68605 .65171 L .66819 .65724 L p F P
.505 .664 .505 r
s
.398 .557 .393 r
.64462 .68609 m .66819 .65724 L .68605 .65171 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.61797 .29106 m .64462 .31391 L .62029 .30886 L p F P
.505 .664 .505 r
s
.198 .204 .155 r
.62029 .30886 m .59764 .28646 L .61797 .29106 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.64462 .68609 m .61797 .70894 L .59764 .71354 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71699 .60696 m
.71929 .6029 L
s
.5 Mabswid
.542 .758 .585 r
.44307 .71864 m .45741 .73324 L .43597 .73074 L p F P
.505 .664 .505 r
s
.542 .758 .585 r
.43597 .73074 m .41472 .71552 L .44307 .71864 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.41472 .28448 m .43597 .26926 L .45741 .26676 L p F P
.505 .664 .505 r
s
.151 .161 .123 r
.43597 .26926 m .41472 .28448 L .39143 .28866 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34445 .65982 m .36656 .68871 L .34626 .68331 L p F P
.505 .664 .505 r
s
.52 .715 .565 r
.34626 .68331 m .32164 .65452 L .34445 .65982 L p F P
.505 .664 .505 r
s
.148 .158 .12 r
.39143 .28866 m .36656 .31129 L .34626 .31669 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.32164 .34548 m .34626 .31669 L .36656 .31129 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72511 .58847 m
.72591 .58627 L
s
.72291 .59299 m
.72511 .58847 L
s
.72591 .58627 m
.7269 .58194 L
s
.72573 .58018 m
.7269 .58194 L
s
.5 Mabswid
.492 .692 .513 r
.55369 .73211 m .57165 .71723 L .59764 .71354 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.57165 .71723 m .55369 .73211 L .53087 .7341 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.72227 .58105 m .70681 .61827 L .68772 .62308 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72082 .59554 m
.72291 .59299 L
s
.7142 .60956 m
.71699 .60696 L
s
.5 Mabswid
.41 .561 .39 r
.66819 .65724 m .68772 .62308 L .70681 .61827 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.55369 .26789 m .57165 .28277 L .54132 .28027 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.54132 .28027 m .53087 .2659 L .55369 .26789 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70681 .38173 m .72227 .41895 L .70237 .41539 L p F P
.505 .664 .505 r
s
.281 .333 .23 r
.70237 .41539 m .68772 .37692 L .70681 .38173 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39471 .69332 m .41472 .71552 L .39143 .71134 L p F P
.505 .664 .505 r
s
.559 .772 .601 r
.39143 .71134 m .36656 .68871 L .39471 .69332 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.36656 .31129 m .39143 .28866 L .41472 .28448 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.47494 .72046 m .48129 .73469 L .45741 .73324 L p F P
.505 .664 .505 r
s
.569 .79 .603 r
.45741 .73324 m .44307 .71864 L .47494 .72046 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.44307 .28136 m .45741 .26676 L .48129 .26531 L p F P
.505 .664 .505 r
s
.184 .192 .146 r
.45741 .26676 m .44307 .28136 L .41472 .28448 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.7318 .5412 m .72227 .58105 L .70237 .58461 L p F P
.505 .664 .505 r
s
.406 .546 .373 r
.68772 .62308 m .70237 .58461 L .72227 .58105 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71628 .59874 m
.72082 .59554 L
s
.712 .61031 m
.7142 .60956 L
s
.5 Mabswid
.317 .389 .262 r
.72227 .41895 m .7318 .4588 L .71144 .45691 L p F P
.505 .664 .505 r
s
.317 .389 .262 r
.71144 .45691 m .70237 .41539 L .72227 .41895 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71036 .60915 m
.712 .61031 L
s
.5 Mabswid
.567 .786 .59 r
.54132 .71973 m .53087 .7341 L .50627 .73498 L p F P
.505 .664 .505 r
s
.539 .752 .561 r
.53087 .7341 m .54132 .71973 L .57165 .71723 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.53087 .2659 m .54132 .28027 L .5084 .27916 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.5084 .27916 m .50627 .26502 L .53087 .2659 L p F P
.505 .664 .505 r
s
.198 .211 .168 r
.36656 .31129 m .34445 .34018 L .32164 .34548 L p F P
.505 .664 .505 r
s
.287 .335 .264 r
.30132 .37929 m .32164 .34548 L .34445 .34018 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32606 .62534 m .34445 .65982 L .32164 .65452 L p F P
.505 .664 .505 r
s
.537 .727 .573 r
.32164 .65452 m .30132 .62071 L .32606 .62534 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.66819 .65724 m .64462 .68609 L .62029 .69114 L p F P
.505 .664 .505 r
s
.478 .667 .484 r
.59764 .71354 m .62029 .69114 L .64462 .68609 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64462 .31391 m .66819 .34276 L .64051 .33778 L p F P
.505 .664 .505 r
s
.268 .3 .214 r
.64051 .33778 m .62029 .30886 L .64462 .31391 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.5084 .72084 m .50627 .73498 L .48129 .73469 L p F P
.505 .664 .505 r
s
.576 .798 .604 r
.48129 .73469 m .47494 .72046 L .5084 .72084 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.47494 .27954 m .48129 .26531 L .50627 .26502 L p F P
.505 .664 .505 r
s
.205 .211 .16 r
.48129 .26531 m .47494 .27954 L .44307 .28136 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.7318 .4588 m .73502 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
.343 .433 .287 r
.71452 .5 m .71144 .45691 L .7318 .4588 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.73502 .5 m .7318 .5412 L .71144 .54309 L p F P
.505 .664 .505 r
s
.39 .514 .346 r
.70237 .58461 m .71144 .54309 L .7318 .5412 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72348 .58076 m
.72573 .58018 L
s
.5 Mabswid
.567 .786 .59 r
.50627 .73498 m .5084 .72084 L .54132 .71973 L p F P
.505 .664 .505 r
s
.215 .22 .168 r
.50627 .26502 m .5084 .27916 L .47494 .27954 L p F P
.505 .664 .505 r
s
.363 .469 .309 r
.71144 .54309 m .71452 .5 L .73502 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.71374 .60125 m
.71628 .59874 L
s
.5 Mabswid
.552 .758 .556 r
.62029 .69114 m .59764 .71354 L .57165 .71723 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.59764 .28646 m .62029 .30886 L .58863 .30478 L p F P
.505 .664 .505 r
s
.254 .275 .201 r
.58863 .30478 m .57165 .28277 L .59764 .28646 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.72017 .5837 m
.72348 .58076 L
s
.71036 .60915 m
.71115 .60551 L
s
.71115 .60551 m
.71374 .60125 L
s
.7177 .58852 m
.72017 .5837 L
s
.5 Mabswid
.287 .335 .264 r
.34445 .34018 m .32606 .37466 L .30132 .37929 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.28614 .41715 m .30132 .37929 L .32606 .37466 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.31222 .58629 m .32606 .62534 L .30132 .62071 L p F P
.505 .664 .505 r
s
.538 .718 .564 r
.30132 .62071 m .28614 .58285 L .31222 .58629 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.39471 .30668 m .41472 .28448 L .44307 .28136 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.42948 .69679 m .44307 .71864 L .41472 .71552 L p F P
.505 .664 .505 r
s
.605 .828 .634 r
.41472 .71552 m .39471 .69332 L .42948 .69679 L p F P
.505 .664 .505 r
s
.199 .205 .156 r
.41472 .28448 m .39471 .30668 L .36656 .31129 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.37677 .66439 m .39471 .69332 L .36656 .68871 L p F P
.505 .664 .505 r
s
.595 .808 .625 r
.36656 .68871 m .34445 .65982 L .37677 .66439 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.34445 .34018 m .36656 .31129 L .39471 .30668 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.66819 .34276 m .68772 .37692 L .65741 .37255 L p F P
.505 .664 .505 r
s
.326 .383 .264 r
.65741 .37255 m .64051 .33778 L .66819 .34276 L p F P
.505 .664 .505 r
s
.523 .703 .5 r
.68772 .62308 m .66819 .65724 L .64051 .66222 L p F P
.505 .664 .505 r
s
.511 .698 .501 r
.62029 .69114 m .64051 .66222 L .66819 .65724 L p F P
.505 .664 .505 r
s
.36 .439 .345 r
.32606 .37466 m .31222 .41371 L .28614 .41715 L p F P
.505 .664 .505 r
s
.419 .525 .411 r
.27676 .45784 m .28614 .41715 L .31222 .41371 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.30362 .54399 m .31222 .58629 L .28614 .58285 L p F P
.505 .664 .505 r
s
.525 .691 .542 r
.28614 .58285 m .27676 .54216 L .30362 .54399 L p F P
.505 .664 .505 r
s
.552 .758 .556 r
.57165 .71723 m .58863 .69522 L .62029 .69114 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.57165 .28277 m .58863 .30478 L .55125 .302 L p F P
.505 .664 .505 r
s
.291 .324 .231 r
.55125 .302 m .54132 .28027 L .57165 .28277 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.58863 .69522 m .57165 .71723 L .54132 .71973 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70309 .60913 m
.70588 .60489 L
s
.70588 .60489 m
.70752 .60075 L
s
.7011 .61131 m
.70309 .60913 L
s
.5 Mabswid
.419 .525 .411 r
.31222 .41371 m .30362 .45601 L .27676 .45784 L p F P
.505 .664 .505 r
s
.465 .594 .465 r
.27358 .5 m .27676 .45784 L .30362 .45601 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.3007 .5 m .30362 .54399 L .27676 .54216 L p F P
.505 .664 .505 r
s
.501 .649 .509 r
.27676 .54216 m .27358 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69786 .61371 m
.7011 .61131 L
s
.71068 .58543 m
.7115 .58974 L
s
.5 Mabswid
.465 .594 .465 r
.30362 .45601 m .3007 .5 L .27358 .5 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.4689 .69883 m .47494 .72046 L .44307 .71864 L p F P
.505 .664 .505 r
s
.627 .854 .647 r
.44307 .71864 m .42948 .69679 L .4689 .69883 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.42948 .30321 m .44307 .28136 L .47494 .27954 L p F P
.505 .664 .505 r
s
.254 .277 .201 r
.44307 .28136 m .42948 .30321 L .39471 .30668 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.64051 .66222 m .62029 .69114 L .58863 .69522 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.62029 .30886 m .64051 .33778 L .60391 .33372 L p F P
.505 .664 .505 r
s
.327 .377 .263 r
.60391 .33372 m .58863 .30478 L .62029 .30886 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.68772 .37692 m .70237 .41539 L .67017 .41214 L p F P
.505 .664 .505 r
s
.369 .448 .302 r
.67017 .41214 m .65741 .37255 L .68772 .37692 L p F P
.505 .664 .505 r
s
.52 .688 .485 r
.70237 .58461 m .68772 .62308 L .65741 .62745 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.694 .61442 m
.69786 .61371 L
s
.5 Mabswid
.523 .703 .5 r
.64051 .66222 m .65741 .62745 L .68772 .62308 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70893 .58339 m
.71068 .58543 L
s
.5 Mabswid
.622 .846 .63 r
.55125 .698 m .54132 .71973 L .5084 .72084 L p F P
.505 .664 .505 r
s
.597 .815 .602 r
.54132 .71973 m .55125 .698 L .58863 .69522 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.54132 .28027 m .55125 .302 L .51043 .30076 L p F P
.505 .664 .505 r
s
.307 .346 .245 r
.51043 .30076 m .5084 .27916 L .54132 .28027 L p F P
.505 .664 .505 r
s
.296 .338 .255 r
.39471 .30668 m .37677 .33561 L .34445 .34018 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.32606 .37466 m .34445 .34018 L .37677 .33561 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.36172 .62936 m .37677 .66439 L .34445 .65982 L p F P
.505 .664 .505 r
s
.608 .814 .627 r
.34445 .65982 m .32606 .62534 L .36172 .62936 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69207 .61295 m
.694 .61442 L
s
.5 Mabswid
.632 .858 .644 r
.51043 .69924 m .5084 .72084 L .47494 .72046 L p F P
.505 .664 .505 r
s
.632 .858 .644 r
.47494 .72046 m .4689 .69883 L .51043 .69924 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.4689 .30117 m .47494 .27954 L .5084 .27916 L p F P
.505 .664 .505 r
s
.29 .323 .23 r
.47494 .27954 m .4689 .30117 L .42948 .30321 L p F P
.505 .664 .505 r
s
.622 .846 .63 r
.5084 .72084 m .51043 .69924 L .55125 .698 L p F P
.505 .664 .505 r
s
.307 .346 .244 r
.5084 .27916 m .51043 .30076 L .4689 .30117 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.41721 .66786 m .42948 .69679 L .39471 .69332 L p F P
.505 .664 .505 r
s
.635 .855 .652 r
.39471 .69332 m .37677 .66439 L .41721 .66786 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.37677 .33561 m .39471 .30668 L .42948 .30321 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.70237 .41539 m .71144 .45691 L .67811 .45518 L p F P
.505 .664 .505 r
s
.405 .504 .337 r
.67811 .45518 m .67017 .41214 L .70237 .41539 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.71144 .54309 m .70237 .58461 L .67017 .58786 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.70492 .58394 m
.70893 .58339 L
s
.5 Mabswid
.52 .688 .485 r
.65741 .62745 m .67017 .58786 L .70237 .58461 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69079 .6094 m
.69207 .61295 L
s
.69163 .60334 m
.70752 .60075 L
s
.70136 .58675 m
.70492 .58394 L
s
.69079 .6094 m
.69163 .60334 L
s
.5 Mabswid
.448 .568 .386 r
.71144 .45691 m .71452 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.448 .568 .386 r
.6808 .5 m .67811 .45518 L .71144 .45691 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.71452 .5 m .71144 .54309 L .67811 .54482 L p F P
.505 .664 .505 r
s
.505 .66 .46 r
.67017 .58786 m .67811 .54482 L .71144 .54309 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69693 .5919 m
.70136 .58675 L
s
.5 Mabswid
.38 .454 .309 r
.64051 .33778 m .65741 .37255 L .61675 .36896 L p F P
.505 .664 .505 r
s
.38 .454 .309 r
.61675 .36896 m .60391 .33372 L .64051 .33778 L p F P
.505 .664 .505 r
s
.59 .786 .567 r
.65741 .62745 m .64051 .66222 L .60391 .66628 L p F P
.505 .664 .505 r
s
.581 .785 .571 r
.58863 .69522 m .60391 .66628 L .64051 .66222 L p F P
.505 .664 .505 r
s
.481 .619 .427 r
.67811 .54482 m .6808 .5 L .71452 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69163 .60334 m
.69316 .59896 L
s
.5 Mabswid
.606 .801 .615 r
.35034 .58928 m .36172 .62936 L .32606 .62534 L p F P
.505 .664 .505 r
s
.606 .801 .615 r
.32606 .62534 m .31222 .58629 L .35034 .58928 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.60391 .66628 m .58863 .69522 L .55125 .698 L p F P
.505 .664 .505 r
s
.381 .457 .346 r
.37677 .33561 m .36172 .37064 L .32606 .37466 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.31222 .41371 m .32606 .37466 L .36172 .37064 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.58863 .30478 m .60391 .33372 L .56023 .33093 L p F P
.505 .664 .505 r
s
.359 .421 .29 r
.56023 .33093 m .55125 .302 L .58863 .30478 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.69316 .59896 m
.69693 .5919 L
s
.6703 .62995 m
.67831 .60726 L
s
.67831 .60726 m
.6858 .58605 L
s
.5 Mabswid
.652 .874 .659 r
.46342 .6699 m .4689 .69883 L .42948 .69679 L p F P
.505 .664 .505 r
s
.652 .874 .659 r
.42948 .69679 m .41721 .66786 L .46342 .6699 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.41721 .33214 m .42948 .30321 L .4689 .30117 L p F P
.505 .664 .505 r
s
.355 .416 .306 r
.42948 .30321 m .41721 .33214 L .37677 .33561 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.34324 .54559 m .35034 .58928 L .31222 .58629 L p F P
.505 .664 .505 r
s
.592 .774 .593 r
.31222 .58629 m .30362 .54399 L .34324 .54559 L p F P
.505 .664 .505 r
s
.447 .551 .419 r
.36172 .37064 m .35034 .41072 L .31222 .41371 L p F P
.505 .664 .505 r
s
.498 .627 .477 r
.30362 .45601 m .31222 .41371 L .35034 .41072 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6729 .6156 m
.67792 .61112 L
s
.5 Mabswid
.433 .526 .39 r
.36172 .37064 m .37677 .33561 L .41721 .33214 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.40686 .63243 m .41721 .66786 L .37677 .66439 L p F P
.505 .664 .505 r
s
.643 .855 .649 r
.37677 .66439 m .36172 .62936 L .40686 .63243 L p F P
.505 .664 .505 r
s
.622 .836 .613 r
.55125 .698 m .56023 .66907 L .60391 .66628 L p F P
.505 .664 .505 r
s
.645 .864 .639 r
.56023 .66907 m .55125 .698 L .51043 .69924 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.55125 .302 m .56023 .33093 L .51227 .32969 L p F P
.505 .664 .505 r
s
.382 .452 .315 r
.51227 .32969 m .51043 .30076 L .55125 .302 L p F P
.505 .664 .505 r
s
.585 .769 .551 r
.67017 .58786 m .65741 .62745 L .61675 .63104 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66853 .61799 m
.6729 .6156 L
s
.5 Mabswid
.59 .786 .567 r
.60391 .66628 m .61675 .63104 L .65741 .62745 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.65741 .37255 m .67017 .41214 L .6265 .40946 L p F P
.505 .664 .505 r
s
.433 .532 .364 r
.6265 .40946 m .61675 .36896 L .65741 .37255 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.68146 .58888 m
.68374 .59339 L
s
.66286 .61861 m
.66853 .61799 L
s
.3289 .6096 m
.34331 .63167 L
s
.31349 .58598 m
.3274 .6073 L
s
.3274 .6073 m
.3289 .6096 L
s
.5 Mabswid
.498 .627 .477 r
.35034 .41072 m .34324 .45441 L .30362 .45601 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.3007 .5 m .30362 .45601 L .34324 .45441 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.34082 .5 m .34324 .54559 L .30362 .54399 L p F P
.505 .664 .505 r
s
.569 .736 .562 r
.30362 .54399 m .3007 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.51227 .67031 m .51043 .69924 L .4689 .69883 L p F P
.505 .664 .505 r
s
.654 .876 .654 r
.4689 .69883 m .46342 .6699 L .51227 .67031 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.46342 .3301 m .4689 .30117 L .51043 .30076 L p F P
.505 .664 .505 r
s
.385 .456 .329 r
.4689 .30117 m .46342 .3301 L .41721 .33214 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.34331 .63167 m
.34466 .61188 L
s
.34466 .61188 m
.34494 .6078 L
s
.32381 .60308 m
.34385 .60491 L
s
.5 Mabswid
.645 .864 .639 r
.51043 .69924 m .51227 .67031 L .56023 .66907 L p F P
.505 .664 .505 r
s
.394 .467 .332 r
.51043 .30076 m .51227 .32969 L .46342 .3301 L p F P
.505 .664 .505 r
s
.538 .687 .524 r
.34324 .45441 m .34082 .5 L .3007 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67833 .58671 m
.68146 .58888 L
s
.65962 .61703 m
.66286 .61861 L
s
.5 Mabswid
.425 .514 .356 r
.60391 .33372 m .61675 .36896 L .56782 .36649 L p F P
.505 .664 .505 r
s
.425 .514 .356 r
.56782 .36649 m .56023 .33093 L .60391 .33372 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.61675 .63104 m .60391 .66628 L .56023 .66907 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.67017 .41214 m .67811 .45518 L .63259 .45374 L p F P
.505 .664 .505 r
s
.481 .602 .418 r
.63259 .45374 m .6265 .40946 L .67017 .41214 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.67811 .54482 m .67017 .58786 L .6265 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.67238 .5872 m
.67833 .58671 L
s
.5 Mabswid
.585 .769 .551 r
.61675 .63104 m .6265 .59054 L .67017 .58786 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.65691 .61331 m
.65962 .61703 L
s
.65679 .60704 m
.65691 .61331 L
s
.5 Mabswid
.638 .839 .635 r
.39899 .59158 m .40686 .63243 L .36172 .62936 L p F P
.505 .664 .505 r
s
.638 .839 .635 r
.36172 .62936 m .35034 .58928 L .39899 .59158 L p F P
.505 .664 .505 r
s
.433 .526 .39 r
.41721 .33214 m .40686 .36757 L .36172 .37064 L p F P
.505 .664 .505 r
s
.492 .611 .455 r
.35034 .41072 m .36172 .37064 L .40686 .36757 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66763 .59004 m
.67238 .5872 L
s
.5 Mabswid
.459 .56 .408 r
.40686 .36757 m .41721 .33214 L .46342 .3301 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.45878 .63424 m .46342 .6699 L .41721 .66786 L p F P
.505 .664 .505 r
s
.657 .871 .653 r
.41721 .66786 m .40686 .63243 L .45878 .63424 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.66214 .59529 m
.66763 .59004 L
s
.65679 .60704 m
.65809 .60253 L
s
.65809 .60253 m
.66214 .59529 L
s
.5 Mabswid
.518 .658 .461 r
.67811 .45518 m .6808 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
.518 .658 .461 r
.63466 .5 m .63259 .45374 L .67811 .45518 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.6808 .5 m .67811 .54482 L .63259 .54626 L p F P
.505 .664 .505 r
s
.57 .742 .528 r
.6265 .59054 m .63259 .54626 L .67811 .54482 L p F P
.505 .664 .505 r
s
.548 .705 .498 r
.63259 .54626 m .63466 .5 L .6808 .5 L p F P
.505 .664 .505 r
s
.628 .833 .607 r
.56023 .66907 m .56782 .63351 L .61675 .63104 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.56023 .33093 m .56782 .36649 L .51383 .36538 L p F P
.505 .664 .505 r
s
.454 .553 .391 r
.51383 .36538 m .51227 .32969 L .56023 .33093 L p F P
.505 .664 .505 r
s
.648 .859 .632 r
.56782 .63351 m .56023 .66907 L .51227 .67031 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.63583 .61906 m
.63874 .61683 L
s
.63874 .61683 m
.64226 .61244 L
s
.64226 .61244 m
.64347 .60807 L
s
.63056 .62142 m
.63583 .61906 L
s
.5 Mabswid
.621 .815 .591 r
.6265 .59054 m .61675 .63104 L .56782 .63351 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.61675 .36896 m .6265 .40946 L .57359 .40761 L p F P
.505 .664 .505 r
s
.481 .595 .418 r
.57359 .40761 m .56782 .36649 L .61675 .36896 L p F P
.505 .664 .505 r
s
.623 .812 .612 r
.39407 .54682 m .39899 .59158 L .35034 .58928 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.36196 .61359 m
.36385 .62101 L
s
.5 Mabswid
.623 .812 .612 r
.35034 .58928 m .34324 .54559 L .39407 .54682 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.35572 .58906 m
.36196 .61359 L
s
.34559 .59834 m
.34627 .5885 L
s
.34494 .6078 m
.34559 .59834 L
s
.5 Mabswid
.492 .611 .455 r
.40686 .36757 m .39899 .40842 L .35034 .41072 L p F P
.505 .664 .505 r
s
.538 .678 .507 r
.34324 .45441 m .35034 .41072 L .39899 .40842 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.62337 .62191 m
.63056 .62142 L
s
.5 Mabswid
.465 .568 .408 r
.45878 .36576 m .46342 .3301 L .51227 .32969 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.51383 .63462 m .51227 .67031 L .46342 .6699 L p F P
.505 .664 .505 r
s
.658 .871 .647 r
.46342 .6699 m .45878 .63424 L .51383 .63462 L p F P
.505 .664 .505 r
s
.459 .56 .408 r
.46342 .3301 m .45878 .36576 L .40686 .36757 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.36438 .61501 m
.37028 .61949 L
s
.36025 .60832 m
.36438 .61501 L
s
.37028 .61949 m
.37565 .62184 L
s
.5 Mabswid
.648 .859 .632 r
.51227 .67031 m .51383 .63462 L .56782 .63351 L p F P
.505 .664 .505 r
s
.465 .568 .408 r
.51227 .32969 m .51383 .36538 L .45878 .36576 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.64277 .59168 m
.64642 .59638 L
s
.37565 .62184 m
.38304 .62231 L
s
.61899 .62019 m
.62337 .62191 L
s
.63839 .58938 m
.64277 .59168 L
s
.61497 .6163 m
.61899 .62019 L
s
.5 Mabswid
.538 .678 .507 r
.39899 .40842 m .39407 .45318 L .34324 .45441 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.34082 .5 m .34324 .45441 L .39407 .45318 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.3924 .5 m .39407 .54682 L .34324 .54559 L p F P
.505 .664 .505 r
s
.602 .776 .584 r
.34324 .54559 m .34082 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.45525 .59294 m .45878 .63424 L .40686 .63243 L p F P
.505 .664 .505 r
s
.65 .852 .637 r
.40686 .63243 m .39899 .59158 L .45525 .59294 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.39899 .40842 m .40686 .36757 L .45878 .36576 L p F P
.505 .664 .505 r
s
.574 .732 .549 r
.39407 .45318 m .3924 .5 L .34082 .5 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.6265 .40946 m .63259 .45374 L .57721 .45275 L p F P
.505 .664 .505 r
s
.524 .659 .467 r
.57721 .45275 m .57359 .40761 L .6265 .40946 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.63259 .54626 m .6265 .59054 L .57359 .59239 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.6308 .58976 m
.63839 .58938 L
s
.5 Mabswid
.621 .815 .591 r
.56782 .63351 m .57359 .59239 L .6265 .59054 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.61387 .60985 m
.61497 .6163 L
s
.61387 .60985 m
.64347 .60807 L
s
.62513 .5926 m
.6308 .58976 L
s
.61387 .60985 m
.61484 .60524 L
s
.39301 .61018 m
.39705 .61691 L
s
.39705 .61691 m
.4033 .62137 L
s
.61484 .60524 m
.61891 .59788 L
s
.61891 .59788 m
.62513 .5926 L
s
.4033 .62137 m
.40912 .62366 L
s
.5 Mabswid
.641 .84 .615 r
.57359 .59239 m .56782 .63351 L .51383 .63462 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.56782 .36649 m .57359 .40761 L .51502 .40678 L p F P
.505 .664 .505 r
s
.507 .63 .45 r
.51502 .40678 m .51383 .36538 L .56782 .36649 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.3921 .60557 m
.39301 .61018 L
s
.40912 .62366 m
.41733 .624 L
s
.59021 .62166 m
.59418 .61516 L
s
.58433 .62394 m
.59021 .62166 L
s
.3921 .60557 m
.39351 .59842 L
s
.57599 .62425 m
.58433 .62394 L
s
.41733 .624 m
.42254 .62216 L
s
.44816 .61766 m
.45033 .63837 L
s
.5 Mabswid
.65 .852 .63 r
.51502 .59322 m .51383 .63462 L .45878 .63424 L p F P
.505 .664 .505 r
s
.65 .852 .63 r
.45878 .63424 m .45525 .59294 L .51502 .59322 L p F P
.505 .664 .505 r
s
.517 .644 .466 r
.45525 .40706 m .45878 .36576 L .51383 .36538 L p F P
.505 .664 .505 r
s
.513 .639 .469 r
.45878 .36576 m .45525 .40706 L .39899 .40842 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.63259 .45374 m .63466 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.558 .71 .507 r
.57845 .5 m .57721 .45275 L .63259 .45374 L p F P
.505 .664 .505 r
s
.585 .753 .54 r
.63466 .5 m .63259 .54626 L .57721 .54725 L p F P
.505 .664 .505 r
s
.606 .787 .568 r
.57359 .59239 m .57721 .54725 L .63259 .54626 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.59418 .61516 m
.59816 .59108 L
s
.57067 .62239 m
.57599 .62425 L
s
.39351 .59842 m
.39825 .59356 L
s
.42254 .62216 m
.42754 .61812 L
s
.5 Mabswid
.555 .7 .516 r
.39407 .45318 m .39899 .40842 L .45525 .40706 L p F P
.505 .664 .505 r
s
.635 .825 .615 r
.45304 .54755 m .45525 .59294 L .39899 .59158 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.44549 .59216 m
.44765 .61273 L
s
.44765 .61273 m
.44816 .61766 L
s
.5 Mabswid
.635 .825 .615 r
.39899 .59158 m .39407 .54682 L .45304 .54755 L p F P
.505 .664 .505 r
s
.641 .84 .615 r
.51383 .63462 m .51502 .59322 L .57359 .59239 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.5629 .61622 m
.57067 .62239 L
s
.5 Mabswid
.517 .644 .466 r
.51383 .36538 m .51502 .40678 L .45525 .40706 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50523 .64076 m
.50233 .63899 L
s
.50817 .63898 m
.50523 .64076 L
s
.5 Mabswid
.585 .753 .54 r
.57721 .54725 m .57845 .5 L .63466 .5 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50528 .63718 m
.50817 .63898 L
s
.50233 .63899 m
.50528 .63718 L
s
.39825 .59356 m
.40356 .59113 L
s
.55916 .62272 m
.5629 .61622 L
s
.55309 .62493 m
.55916 .62272 L
s
.54429 .62513 m
.55309 .62493 L
s
.53856 .62317 m
.54429 .62513 L
s
.40356 .59113 m
.41226 .5914 L
s
.46339 .62527 m
.47233 .62539 L
s
.45728 .62309 m
.46339 .62527 L
s
.44773 .61647 m
.45728 .62309 L
s
.53 .61685 m
.53856 .62317 L
s
.47233 .62539 m
.47822 .62339 L
s
.41226 .5914 m
.41847 .59419 L
s
.47822 .62339 m
.48098 .61696 L
s
.5 Mabswid
.626 .813 .593 r
.57721 .54725 m .57359 .59239 L .51502 .59322 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.52946 .62537 m
.52976 .61991 L
s
.5629 .61622 m
.56559 .59195 L
s
.5 Mabswid
.548 .69 .496 r
.57359 .40761 m .57721 .45275 L .51576 .4523 L p F P
.505 .664 .505 r
s
.548 .69 .496 r
.51576 .4523 m .51502 .40678 L .57359 .40761 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.41847 .59419 m
.42502 .59947 L
s
.5 Mabswid
.555 .7 .516 r
.45525 .40706 m .45304 .45245 L .39407 .45318 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.3924 .5 m .39407 .45318 L .45304 .45245 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.45228 .5 m .45304 .54755 L .39407 .54682 L p F P
.505 .664 .505 r
s
.614 .791 .588 r
.39407 .54682 m .3924 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
.588 .75 .555 r
.45304 .45245 m .45228 .5 L .3924 .5 L p F P
.505 .664 .505 r
s
.558 .703 .512 r
.45304 .45245 m .45525 .40706 L .51502 .40678 L p F P
.505 .664 .505 r
s
.635 .825 .608 r
.51576 .5477 m .51502 .59322 L .45525 .59294 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50543 .62556 m
.50551 .61764 L
s
.5 Mabswid
.635 .825 .608 r
.45525 .59294 m .45304 .54755 L .51576 .5477 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.50551 .61764 m
.50577 .59262 L
s
.48016 .59256 m
.48098 .61696 L
s
.5 Mabswid
.626 .813 .593 r
.51502 .59322 m .51576 .5477 L .57721 .54725 L p F P
.505 .664 .505 r
s
0 0 0 r
2 Mabswid
.52976 .61991 m
.53129 .59247 L
s
.5 Mabswid
.558 .703 .512 r
.51502 .40678 m .51576 .4523 L .45304 .45245 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.57721 .45275 m .57845 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.58 .739 .534 r
.51602 .5 m .51576 .4523 L .57721 .45275 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.57845 .5 m .57721 .54725 L .51576 .5477 L p F P
.505 .664 .505 r
s
.606 .779 .566 r
.51576 .5477 m .51602 .5 L .57845 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.45228 .5 m .45304 .45245 L .51576 .4523 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.51602 .5 m .51576 .5477 L .45304 .54755 L p F P
.505 .664 .505 r
s
.615 .791 .581 r
.45304 .54755 m .45228 .5 L .51602 .5 L p F P
.505 .664 .505 r
s
.589 .751 .55 r
.51576 .4523 m .51602 .5 L .45228 .5 L p F P
.505 .664 .505 r
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{500, 500},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007d0001m2000`400?l00000o`00003oo`3ooooe
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00>l0/>3V4P21ZH7b0;3PiP40oooo003X0;3PiPP0PJV10P0S9A`0
0`21ZH409BLN02DW7P0602DW7P04086YP@0U9ah09BLN02DW7Pl0PJV1i@2`h>H10?ooo`00hP2`h>H6
086YP@0301hQ6@21ZH40PJV100H08bDL00<0PJV102DW7P0U9ah01`0U9ah00`21ZH409BLN02DW7P06
02DW7P80PJV11`0R9A`6086YPN00/>3V0@3oool00=`0/>3V1`21ZH4401hQ6@80PJV1200S9A`00`21
ZH409BLN02DW7P0802DW7P03086YP@0U9ah09BLN00L09BLN0P21ZH47028U7080PJV10P0M8AT3086Y
PMd0/>3V0@3oool00=P0/>3V1@21ZH400`0G6a@0PJV1086YP@0501hQ6@80PJV1100S9A`S086YP@<0
8RDL0P21ZH4201dQ6@@0PJV1fP2`h>H10?ooo`00eP2`h>H4086YP@0301LK5021ZH40PJV100807R4I
3021ZH4403@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02P0g>2/00`21ZH40=3HX
03@f:00203@f:0T0PJV100<07B4I086YP@21ZH400`21ZH7F0;3PiP40oooo003C0;3PiP`0PJV1100_
<BD00`21ZH40=3HX03@f:00903@f:003086YP@0g>2/0=cP[00X0=cP[00<0PJV103Lh:`0g>2/02`0g
>2/00`21ZH40=3HX03@f:00803@f:003086YP@0^<2D0PJV100L0PJV1e02`h>H10?ooo`00d02`h>H9
086YP@T0;c4U00<0PJV103@f:00d=RP02@0d=RP00`21ZH40=cP[03Lh:`0;03Lh:`03086YP@0g>2/0
=cP[00`0=cP[00<0PJV103@f:00d=RP0200d=RP00`21ZH40;S0U02h`9@0302h`9@H0PJV1d@2`h>H1
0?ooo`00cP2`h>H5086YP@<09RTO00<0PJV102la9@0_<BD0200_<BD00`21ZH40=3HX03@f:00:03@f
:003086YP@0g>2/0=cP[00`0=cP[00<0PJV103Lh:`0g>2/02`0g>2/00`21ZH40=3HX03@f:00903@f
:003086YP@0^<2D0;S0U00D0;S0U1P21ZH7>0;3PiP40oooo003;0;3PiPD0PJV1100V:Al2086YP@X0
;c4U00<0PJV103@f:00d=RP02P0d=RP00`21ZH40=cP[03Lh:`0=03Lh:`03086YP@0g>2/0=cP[00`0
=cP[00<0PJV103@f:00d=RP02@0d=RP2086YP@L0;S0U0P21ZH400`0V:1h0PJV1086YP@02086YPL/0
/>3V0@3oool00<T0/>3V0P21ZH400`0K7QL0PJV1086YP@0402HY7`80PJV12`0_<BD00`21ZH40=3HX
03@f:00;03@f:003086YP@0g>2/0=cP[00d0=cP[00<0PJV103Lh:`0g>2/03@0g>2/00`21ZH40=3HX
03@f:00:03@f:003086YP@0^<2D0;S0U00H0;S0U00@0PJV102HX7P0V:1h09RPN0`21ZH790;3PiP40
oooo00370;3PiP80PJV10P0K7QL00`21ZH409RTO02HY7`0302HY7`03086YP@0_<BD0;c4U00X0;c4U
00<0PJV103@f:00d=RP0100d=RP]086YP@T0=3HX00<0PJV102h`9@0^<2D01P0^<2D2086YP@<09RPN
0`21ZH770;3PiP40oooo00350;3PiP80PJV10P0K7QL2086YP@@09RTO0P21ZH4502la9@l0PJV11`1:
DSX00`21ZH40CUPn04iH?P0>04iH?P03086YP@1>F3h0CUPn00h0CUPn00@0PJV104YB>`1:DS/0BU8k
2021ZH4203@f:003086YP@0^<2D0;S0U00L0;S0U0P21ZH4302HX7P<0PJV1a@2`h>H10?ooo`00``2`
h>H2086YP@<06ahG00<0PJV102HY7`0V:Al00P0V:Al9086YP@H0@DHc00<0PJV104YB>P1:DSX0301:
DSX00`21ZH40CUPn04iH?P0?04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0201:
DS/:086YP@@0;S0U0P21ZH4302HX7P<0PJV1``2`h>H10?ooo`00`@2`h>H2086YP@<06ahG0P21ZH40
0`0V:Al0PJV1086YP@03086YP@h0@DHc00<0PJV104YB>P1:DSX0301:DSX00`21ZH40CUPn04iH?P0?
04iH?P03086YP@1>F3h0CUPn00l0CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`03
0456<`P0PJV10P0V:1h4086YPL40/>3V0@3oool00;l0/>3V0P21ZH4301/N5`D0PJV10`0b=2L00`21
ZH40@DHc0456<`0<0456<`03086YP@1:DSX0BU8j00d0BU8j00<0PJV104iH?P1>F3h03`1>F3h00`21
ZH40CUPn04iH?P0@04iH?P03086YP@1:DS/0BU8k00/0BU8k00<0PJV10456<`11AS<02P11AS<4086Y
P@0302HX7P21ZH40PJV10080PJV1_`2`h>H10?ooo`00_@2`h>H2086YP@806ahG1021ZH46038d9`03
086YP@11AS<0@DHc00`0@DHc00<0PJV104YB>P1:DSX03P1:DSX00`21ZH40CUPn04iH?P0?04iH?P03
086YP@1>F3h0CUPn0100CUPn00<0PJV104YB>`1:DS/0301:DS/00`21ZH40@DHc0456<`0:0456<`03
086YP@0b=2L0<S@W00L0PJV1_@2`h>H10?ooo`00^`2`h>H6086YP@0302DX7P21ZH40<S@W00L0<S@W
00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0=04YB>P03086YP@1>F3h0CUPn0140CUPn
00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0<04YB>`03086YP@11AS<0@DHc00X0@DHc
00<0PJV1038d9`0b=2L00`0b=2L5086YPK/0/>3V0@3oool00;X0/>3V0`21ZH4402DX7P03086YP@0b
=2L0<S@W00H0<S@W00<0PJV10456<`11AS<03011AS<00`21ZH40BU8j04YB>P0>04YB>P03086YP@1>
F3h0CUPn0140CUPn00<0PJV104iH?P1>F3h0401>F3h00`21ZH40BU8k04YB>`0=04YB>`03086YP@11
AS<0@DHc00X0@DHc00<0PJV1038d9`0b=2L0100b=2L5086YPKT0/>3V0@3oool00;P0/>3V0P21ZH45
02DX7P80PJV1200b=2L00`21ZH40@DHc0456<`0=0456<`03086YP@1:DSX0BU8j00h0BU8j00<0PJV1
04iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A04iH?P03086YP@1:DS/0BU8k00`0BU8k00<0PJV1
0456<`11AS<02`11AS<00`21ZH40<S@W038d9`04038d9`04086YP@0T9ah092LN02@W7P80PJV1]`2`
h>H10?ooo`00]P2`h>H3086YP@D09BPN00<0PJV1038d9`0b=2L01`0b=2L00`21ZH40@DHc0456<`0=
0456<`03086YP@1:DSX0BU8j00l0BU8j00<0PJV104iH?P1>F3h04@1>F3h00`21ZH40CUPn04iH?P0A
04iH?P03086YP@1:DS/0BU8k00d0BU8k00<0PJV10456<`11AS<02P11AS<00`21ZH40<S@W038d9`05
038d9`80PJV10`0T9ah00`21ZH40/>3V0;3PiP2d0;3PiP40oooo002e0;3PiP<0PJV11@0U:1h00`21
ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc00d0@DHc00<0PJV104YB>P1:DSX03`1:DSX00`21
ZH40CUPn04iH?P0B04iH?P03086YP@1>F3h0CUPn0180CUPn00<0PJV104YB>`1:DS/03@1:DS/00`21
ZH40@DHc0456<`0:0456<`03086YP@0b=2L0<S@W00H0<S@W00D0PJV102@W7P0T9ah092LN086YP@2e
0;3PiP40oooo002c0;3PiP<0PJV11P0U:1h00`21ZH40<S@W038d9`07038d9`03086YP@11AS<0@DHc
00h0@DHc00<0PJV104YB>P1:DSX01P1:DSXh086YP@`0BU8k00<0PJV10456<`11AS<02P11AS<00`21
ZH40<S@W038d9`06038d9`04086YP@0T9ah092LN02@W7P80PJV1/`2`h>H10?ooo`00/P2`h>H00`21
ZH4051PB086YP@0602DX7P03086YP@0b=2L0<S@W00P0<S@W00<0PJV10456<`11AS<02@11AS<>086Y
P@T0HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00B065cD003086YP@1KJdX0Ff]:
0080Ff]:2@21ZH4304YB>`03086YP@11AS<0@DHc00/0@DHc00<0PJV1038d9`0b=2L01P0b=2L00`21
ZH4092LN02@W7P0202@W7P03086YP@2`h>H0/>3V0;00/>3V0@3oool00;40/>3V00<0PJV101@H4P21
ZH401@0U:1h2086YP@X0<S@W00@0PJV10456<`11AS<0@DHc2@21ZH4405YZCP03086YP@1RM5@0HWAD
0100HWAD00<0PJV106AgE01TMe@04P1TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:
00X0Ff]:2021ZH4:0456<`03086YP@0b=2L0<S@W00H0<S@W00<0PJV102@W7P0T9ah00P0T9ah00`21
ZH40/>3V0;3PiP2_0;3PiP40oooo002_0;3PiP04086YP@0D618051PB086YP@D09BPN00<0PJV1038d
9`0b=2L01P0b=2L8086YP@`0FVY>00<0PJV1069dE01RM5@04@1RM5@00`21ZH40I7MD06AgE00B06Ag
E003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX03`1KJdX00`21ZH40Df1305=P@`08086Y
P@<0@DHc00<0PJV1038d9`0b=2L01P0b=2L2086YP@<092LN00<0PJV10;3PiP2`h>H0[P2`h>H10?oo
o`00[P2`h>H01021ZH4051PB01@H4P21ZH4502DX7P03086YP@0b=2L0<S@W00L0PJV10P1;ET400`21
ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0100HWAD00<0PJV106AgE01TMe@04`1TMe@00`21
ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:00l0Ff]:00<0PJV105=P@`1CH4<0201CH4<7086Y
P@L0<S@W00D0PJV102@W7P0T9ah092LN086YP@2_0;3PiP40oooo002]0;3PiP04086YP@0D6180PJV1
086YP@@09BPN1@21ZH4904]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1069dE01RM5@04@1RM5@0
0`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01<0HG=@00<0PJV105][BP1KJdX0401KJdX0
0`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0PJV100D0PJV10P0b=2L01@21ZH4092LN02@W7P0T
9ah0PJV10:h0/>3V0@3oool00:/0/>3V00@0PJV101@H4P0D6180PJV10`0U:1h4086YP@`0BeI100<0
PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD069dE00A069dE003086YP@1TMe@0I7MD01<0I7MD00<0
PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0?05][BP03086YP@1CH4<0Df1300`0Df1300<0
PJV104A<=P14C3H01@14C3H5086YP@8092LN0P21ZH6/0;3PiP40oooo002Z0;3PiP03086YP@0D6180
51PB00D0PJV10P0b=R/00`21ZH40BeI104]F@@0;04]F@@03086YP@1JJTh0FVY>00h0FVY>00<0PJV1
069dE01RM5@04P1RM5@00`21ZH40I7MD06AgE00C06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV1
05][BP1KJdX0401KJdX00`21ZH40Df1305=P@`0<05=P@`03086YP@14C3H0A4`f00P0A4`f0`21ZH42
02@W7P03086YP@2`h>H0/>3V0:T0/>3V0@3oool00:T0/>3V0P0D6183086YP@H0<SH[00<0PJV104]F
@@1;ET402P1;ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD0180HWAD00<0PJV106Ag
E01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003086YP@1KJdX0Ff]:0100Ff]:00<0PJV105=P
@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0PJV100<0PJV1ZP2`h>H10?oo
o`00Y`2`h>H5086YP@L0<SH[00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0?05YZCP03
086YP@1RM5@0HWAD0180HWAD00<0PJV106AgE01TMe@0501TMe@00`21ZH40HG=@065cD00C065cD003
086YP@1KJdX0Ff]:0140Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0704A<=P03
086YP@0];b@0;BlT0080;BlT0P21ZH6Y0;3PiP40oooo002V0;3PiP80PJV10P0K7aL00`21ZH40<SH[
038f:`05038f:`03086YP@1;ET40BeI100/0BeI100<0PJV105YZCP1JJTh03`1JJTh00`21ZH40HWAD
069dE00C069dE003086YP@1TMe@0I7MD01@0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:
05][BP0A05][BP03086YP@1CH4<0Df1300`0Df1300<0PJV104A<=P14C3H02014C3H00`21ZH40;BlT
02d_900302d_9080PJV1Y`2`h>H10?ooo`00Y@2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[
00<0PJV104]F@@1;ET402`1;ET400`21ZH40FVY>05YZCP0@05YZCP03086YP@1RM5@0HWAD0180HWAD
00<0PJV106AgE01TMe@05@1TMe@00`21ZH40HG=@065cD00D065cD003086YP@1KJdX0Ff]:0140Ff]:
00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00<0;BlT
0P21ZH6V0;3PiP40oooo002T0;3PiP03086YP@0K7aL06alG00806alG00<0PJV1038f:`0b=R/0100b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00l0FVY>00<0PJV1069dE01RM5@04`1R
M5@00`21ZH40I7MD06AgE00E06AgE003086YP@1QLe00HG=@01@0HG=@00<0PJV105][BP1KJdX04P1K
JdX00`21ZH40Df1305=P@`0=05=P@`03086YP@14C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0]
;b@2086YPJD0/>3V0@3oool00:@0/>3V00D0PJV101/O5`0K7aL06alG086YP@07038f:`03086YP@1;
ET40BeI100/0BeI100<0PJV105YZCP1JJTh0401JJTh00`21ZH40HWAD069dE00C069dE003086YP@1T
Me@0I7MD01D0I7MD00<0PJV1065cD01QLe00501QLe000`21ZH40Ff]:05][BP0B05][BP03086YP@1C
H4<0Df1300d0Df1300<0PJV104A<=P14C3H02@14C3H00`21ZH40;BlT02d_900302d_9080PJV1Y02`
h>H10?ooo`00X`2`h>H01@21ZH406alG01/O5`0K7aL0PJV100L0<SH[00<0PJV104]F@@1;ET40301;
ET400`21ZH40FVY>05YZCP0?05YZCP03086YP@1RM5@0HWAD00T0HWAD;`21ZH4<065cD003086YP@1K
JdX0Ff]:0180Ff]:00<0PJV105=P@`1CH4<03@1CH4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0]
;b@0;BlT00@0;BlT0P21ZH6S0;3PiP40oooo002R0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b
=R/00`21ZH40BeI104]F@@0<04]F@@03086YP@1JJTh0FVY>00`0FVY>4021ZH4;07F?J003086YP@1g
TFP0Mi5X01D0Mi5X00<0PJV107B=I01dSF@02@1dSF@G086YP@X0Ff]:00<0PJV105=P@`1CH4<03P1C
H4<00`21ZH40A4`f04A<=P0804A<=P03086YP@0];b@0;BlT00@0;BlT0P21ZH6R0;3PiP40oooo002Q
0;3PiP05086YP@0K7aL06alG01/O5`21ZH401`0b=R/00`21ZH40BeI104]F@@0=04]F@@03086YP@1J
JTh0FVY>0080FVY>2P21ZH4406j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05@1g
TFP00`21ZH40M8eT07B=I00E07B=I003086YP@1/Pe/0K8=K00P0K8=K4021ZH4<05=P@`03086YP@14
C3H0A4`f00P0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2Q0;3PiP40oooo002P
0;3PiP05086YP@0K7aL06alG01/O5`21ZH40200b=R/00`21ZH40BeI104]F@@0804]F@@X0PJV13@1^
QV<00`21ZH40MHmX07F?J00D07F?J003086YP@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05@1d
SF@00`21ZH40K8=K06b3F`0C06b3F`03086YP@1QM4l0HGA?0080HGA?2@21ZH4305=P@`03086YP@14
C3H0A4`f00T0A4`f00<0PJV102d_900];b@00`0];b@00`21ZH406AdF086YP@2P0;3PiP40oooo002P
0;3PiP04086YP@0K7aL06alG086YP@P0<SH[00@0PJV104]F@@1;ET40BeI12021ZH44065dF003086Y
P@1^QV<0KXIS0100KXIS00<0PJV107F?J01eSfP0501eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01H0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0:065dC`L0PJV1
2@14C3H00`21ZH40;BlT02d_900302d_9003086YP@0I7AH0PJV109l0/>3V0@3oool009l0/>3V00D0
PJV101/O5`0K7aL06alG086YP@06038f:`H0PJV12`1QM5P00`21ZH40KXIS06j6H`0A06j6H`03086Y
P@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086Y
P@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df93086YP@03086YP@D0A4`f
00<0PJV102d_900];b@0100];b@2086YPIl0/>3V0@3oool009h0/>3V00D0PJV101/O5`0K7aL06alG
086YP@03038f:`D0PJV1401QM5P00`21ZH40KXIS06j6H`0A06j6H`03086YP@1eSfP0MHmX01@0MHmX
00<0PJV107NAJ01gTFP05P1gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0K8=K01<0K8=K
00<0PJV1065dC`1QM4l03`1QM4l00`21ZH40Df9305=R@`0305=R@`D0PJV100<0A4`f086YP@0];b@0
1@0];b@2086YPIh0/>3V0@3oool009d0/>3V00@0PJV101/O5`0K7aL06alG1@21ZH4404UE@`03086Y
P@1QM5P0HGAH00d0HGAH00<0PJV106j6H`1^QV<04@1^QV<00`21ZH40MHmX07F?J00E07F?J003086Y
P@1gTFP0Mi5X01H0Mi5X00<0PJV107B=I01dSF@05P1dSF@00`21ZH40K8=K06b3F`0D06b3F`03086Y
P@1QM4l0HGA?00l0HGA?00<0PJV105=R@`1CHT<01`1CHT<5086YP@@0;BlT0P21ZH6M0;3PiP40oooo
002L0;3PiP04086YP@0K7aL06alG01/O5`80PJV11`19ED<00`21ZH40HGAH065dF00>065dF003086Y
P@1^QV<0KXIS0140KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00F07NAJ003086Y
P@1dSF@0M8eT01L0M8eT00<0PJV106b3F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0?065dC`03086Y
P@1CHT<0Df9300X0Df9300<0PJV103]3<021ZH400`21ZH400`0];b@0PJV1086YP@2L0;3PiP40oooo
002L0;3PiP04086YP@0K7aL0PJV1086YP@T0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS
06j6H`0B06j6H`03086YP@1eSfP0MHmX01@0MHmX00<0PJV107NAJ01gTFP05`1gTFP00`21ZH40M8eT
07B=I00G07B=I003086YP@1/Pe/0K8=K01<0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df93
05=R@`0905=R@`03086YP@0k@c00>d<`00<0>d<`1021ZH6K0;3PiP40oooo002K0;3PiP<0PJV100<0
:2hV086YP@19ED<01`19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0140KXIS00<0
PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01H0M8eT00<0
PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0?065dC`03086YP@1CHT<0Df9300X0Df9300<0
PJV103]3<00k@c001@0k@c02086YPIX0/>3V0@3oool009X0/>3V0P21ZH4202P^9P03086YP@19ED<0
BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0B06j6H`03086YP@1eSfP0
MHmX01D0MHmX00<0PJV107NAJ01gTFP0601gTFP00`21ZH40M8eT07B=I00F07B=I003086YP@1/Pe/0
K8=K01@0K8=K00<0PJV1065dC`1QM4l0401QM4l00`21ZH40Df9305=R@`0905=R@`03086YP@0k@c00
>d<`00D0>d<`0`21ZH6I0;3PiP40oooo002I0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE
@`19ED<01P19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/04`1/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c001@0k@c000`21ZH407b8J086YP@2H0;3PiP40oooo002I0;3PiP05086YP@0X;RH0:2hV02P^
9P21ZH402@19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?
J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV106b3
F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV103]3
<00k@c00100k@c001021ZH407b8J01lR6P21ZH6G0;3PiP40oooo002H0;3PiP05086YP@0X;RH0:2hV
02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS0180KXIS00<0PJV1
07F?J01eSfP05P1eSfP00`21ZH40Mi5X07NAJ00H07NAJ003086YP@1dSF@0M8eT01L0M8eT00<0PJV1
06b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df9300X0Df9300<0PJV1
03]3<00k@c001@0k@c000`21ZH407b8J086YP@2G0;3PiP40oooo002G0;3PiP03086YP@0X;RH0:2hV
0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01L0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002G0;3PiP05
086YP@0X;RH0:2hV02P^9P21ZH402@19ED<00`21ZH40HGAH065dF00>065dF003086YP@1^QV<0KXIS
01<0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003086YP@1dSF@0M8eT
01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0@065dC`03086YP@1CHT<0Df93
00X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2F0;3PiP40oooo002F0;3PiP03
086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH065dF00=065dF003
086YP@1^QV<0KXIS01@0KXIS00<0PJV107F?J01eSfP05@1eSfP00`21ZH40Mi5X07NAJ00I07NAJ003
086YP@1dSF@0M8eT01P0M8eT00<0PJV106b3F`1/Pe/0501/Pe/00`21ZH40HGA?065dC`0A065dC`03
086YP@1CHT<0Df9300X0Df9300<0PJV103]3<00k@c001@0k@c000`21ZH407b8J086YP@2E0;3PiP40
oooo002E0;3PiP03086YP@0X;RH0:2hV0080:2hV00<0PJV104UE@`19ED<01`19ED<00`21ZH40HGAH
065dF00>065dF003086YP@1^QV<0KXIS01<0KXIS00<0PJV107F?J01eSfP02P1eSfQ9086YPA40K8=K
00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086YP@0k@c00>d<`00D0>d<`
00@0PJV101lR6P0O8QX0PJV1U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^9P0302P^9P03086Y
P@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P03@1QM5P00`21ZH40KXIS06j6H`0906j6HaP0PJV1
3023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0PJV107^HJ`1kV6/0
0`1kV6/<086YP@H0K8=K00<0PJV1065dC`1QM4l04@1QM4l00`21ZH40Df9305=R@`0:05=R@`03086Y
P@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40U02`h>H10?ooo`00U02`h>H00`21ZH40:2hV02P^
9P0202P^9P03086YP@19ED<0BEE300L0BEE300<0PJV1065dF01QM5P02P1QM5P@086YP@/0OIad00<0
PJV108>SN023XgP05P23XgP00`21ZH40Q:Ag08BTM`0I08BTM`03086YP@21XG<0PJ5c01P0PJ5c00<0
PJV107^HJ`1kV6/03`1kV6/A086YP@T0HGA?00<0PJV105=R@`1CHT<02`1CHT<00`21ZH40>d<`03]3
<00403]3<004086YP@0O8QX07b8J086YPI<0/>3V0@3oool009<0/>3V00<0PJV102P^9P0X;RH00P0X
;RH00`21ZH40BEE304UE@`0804UE@`04086YP@1QM5P0HGAH065dF0T0PJV1101bSF/00`21ZH40OIad
07fLM00D07fLM003086YP@23XgP0Pj=h01H0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c
086QL`0H086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d0201^R5d=086YP@X0Df93
00<0PJV103]3<00k@c001@0k@c001021ZH407b8J01lR6P21ZH6B0;3PiP40oooo002B0;3PiP03086Y
P@0X;RH0:2hV00<0:2hV00<0PJV104UE@`19ED<01P19ED<6086YP@`0LXe[00<0PJV107fLM01mW7@0
501mW7@00`21ZH40Pj=h08>SN00G08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<0
6@21XG<00`21ZH40NiQ[07^HJ`0D07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd0
1@21ZH4605=R@`03086YP@0k@c00>d<`00D0>d<`00<0PJV101lR6P21ZH40TP2`h>H10?ooo`00TP2`
h>H00`21ZH40:2hV02P^9P0202P^9P03086YP@19ED<0BEE300<0BEE31021ZH400`1LL5P0PJV107:=
J`0?07:=J`03086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BT
M`0I08BTM`03086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40KXQM06j8
G@0B06j8G@03086YP@1NLTd0GW9=00@0GW9=1@21ZH400`1CHT<0PJV103]3<00603]3<004086YP@0O
8QX07b8J086YPI40/>3V0@3oool00940/>3V00<0PJV102P^9P0X;RH00`0X;RH00`21ZH40BEE3086Y
P@03086YP@@0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00D07fLM003086YP@23
XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I086QL`03086YP@1k
V6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0905ibC@D0PJV11@0k
@c000`21ZH407b8J086YP@2A0;3PiP40oooo002@0;3PiP03086YP@0X;RH0:2hV0080:2hV1021ZH48
05a`F003086YP@1bSF/0LXe[00h0LXe[00<0PJV107fLM01mW7@05@1mW7@00`21ZH40Pj=h08>SN00G
08>SN003086YP@24Y7L0Q:Ag01T0Q:Ag00<0PJV1086QL`21XG<06@21XG<00`21ZH40NiQ[07^HJ`0E
07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1NLTd02`1NLTd00`21ZH40AeDj04ME>P04
086YP@0503]3<021ZH407b8J01lR6P21ZH40T02`h>H10?ooo`00T02`h>H00`0X;RH0PJV1086YP@02
086YP@0303M0=`21ZH40G71H00T0G71H00<0PJV107:=J`1bSF/03P1bSF/00`21ZH40OIad07fLM00E
07fLM003086YP@23XgP0Pj=h01L0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21ZH40PJ5c086QL`0I
086QL`03086YP@1kV6/0NiQ[01D0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21ZH40GW9=05ibC@0<
05ibC@03086YP@17ECX0AeDj00<0AeDj0`21ZH4201lR6P03086YP@2`h>H0/>3V08d0/>3V0@3oool0
08l0/>3V0P21ZH4403M0=`03086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/03`1bSF/00`21
ZH40OIad07fLM00D07fLM003086YP@23XgP0Pj=h01P0Pj=h00<0PJV108BTM`24Y7L06@24Y7L00`21
ZH40PJ5c086QL`0I086QL`03086YP@1kV6/0NiQ[01H0NiQ[00<0PJV106j8G@1^R5d04P1^R5d00`21
ZH40GW9=05ibC@0;05ibC@03086YP@17ECX0AeDj00D0AeDj1021ZH6?0;3PiP40oooo002?0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01@0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0I08BTM`03
086YP@21XG<0PJ5c01T0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM086YP@21ZH6>0;3P
iP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40
LXe[07:=J`0>07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05@1kV6/00`21ZH40
KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH40
92LM02@W7@0T9af>0;3PiP40oooo002>0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05@1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03086YP@0g@3L0=d0g00<0
=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0
OIad00<0PJV108>SN023XgP05`23XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0
PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03086YP@1NLTd0GW9=00`0
GW9=00<0PJV104ME>P17ECX01@17ECX01021ZH4092LM02@W7@21ZH6=0;3PiP40oooo002=0;3PiP03
086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40LXe[07:=J`0?07:=J`03
086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BTM`03
086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40KXQM06j8G@0B06j8G@03
086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH4092LM02@W7@21ZH6<0;3P
iP40oooo002<0;3PiP03086YP@0g@3L0=d0g00@0=d0g00<0PJV105a`F01LL5P0201LL5P00`21ZH40
LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023XgP06023XgP00`21ZH40
Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1kV6/05P1kV6/00`21ZH40
KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00/0GW9=00<0PJV104ME>P17ECX01P17ECX01021ZH40
92LM02@W7@21ZH6<0;3PiP40oooo002<0;3PiP03086YP@0g@3L0=d0g00<0=d0g00<0PJV105a`F01L
L5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad01D0OIad00<0PJV108>SN023
XgP06023XgP00`21ZH40Q:Ag08BTM`0J08BTM`03086YP@21XG<0PJ5c01X0PJ5c00<0PJV107^HJ`1k
V6/05P1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17
ECX01@17ECX01@21ZH4092LM02@W7@0T9ad0PJV108/0/>3V0@3oool008/0/>3V00<0PJV103M0=`0g
@3L0100g@3L00`21ZH40G71H05a`F00805a`F003086YP@1bSF/0LXe[00l0LXe[00<0PJV107fLM01m
W7@05P1mW7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0Q:Ag00<0PJV1086QL`21
XG<06P21XG<00`21ZH40NiQ[07^HJ`0G07^HJ`03086YP@1^R5d0KXQM0180KXQM00<0PJV105ibC@1N
LTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPH/0/>3V0@3oool008/0
/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003086YP@1bSF/0LXe[00l0
LXe[00<0PJV107fLM01mW7@05P1mW7@00`21ZH40Pj=h08>SN00H08>SN003086YP@24Y7L0Q:Ag01X0
Q:Ag00<0PJV1086QL`21XG<06`21XG<00`21ZH40NiQ[07^HJ`0F07^HJ`03086YP@1^R5d0KXQM0180
KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P05086YP@0T9ad092LM02@W
7@21ZH40RP2`h>H10?ooo`00R`2`h>H00`21ZH40=d0g03M0=`0303M0=`03086YP@1LL5P0G71H00T0
G71H00<0PJV107:=J`1bSF/03`1bSF/00`21ZH40OIad07fLM00E07fLM003086YP@23XgP0Pj=h01T0
Pj=h00<0PJV108BTM`24Y7L06P24Y7L00`21ZH40PJ5c086QL`0K086QL`03086YP@1kV6/0NiQ[01H0
NiQ[00<0PJV106j8G@1^R5d04`1^R5d00`21ZH40GW9=05ibC@0<05ibC@03086YP@17ECX0AeDj00H0
AeDj00@0PJV102@W7@0T9ad0PJV1RP2`h>H10?ooo`00RP2`h>H00`21ZH40=d0g03M0=`0403M0=`03
086YP@1LL5P0G71H00P0G71H00<0PJV107:=J`1bSF/0401bSF/00`21ZH40OIad07fLM00E07fLM003
086YP@23XgP0Pj=h01T0Pj=h00<0PJV108BTM`24Y7L03024Y7LM086YP@l0PJ5c00<0PJV107^HJ`1k
V6/05P1kV6/00`21ZH40KXQM06j8G@0C06j8G@03086YP@1NLTd0GW9=00`0GW9=00<0PJV104ME>P17
ECX01P17ECX01021ZH4092LM02@W7@21ZH6:0;3PiP40oooo002:0;3PiP03086YP@0g@3L0=d0g00<0
=d0g00<0PJV105a`F01LL5P02@1LL5P00`21ZH40LXe[07:=J`0?07:=J`03086YP@1mW7@0OIad00X0
OIad=`21ZH4>08jcP`03086YP@2</7h0S;1n00`0S;1n7021ZH4=07^HJ`03086YP@1^R5d0KXQM0180
KXQM00<0PJV105ibC@1NLTd03@1NLTd00`21ZH40AeDj04ME>P0504ME>P05086YP@0T9ad092LM02@W
7@21ZH40R@2`h>H10?ooo`00R@2`h>H00`21ZH40=d0g03M0=`0403M0=`03086YP@1LL5P0G71H00T0
G71H00<0PJV107:=J`1bSF/02`1bSF/A086YP@`0RJf100<0PJV108jcQ02>/h@06@2>/h@00`21ZH40
S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26Z7L02P26Z7LH086YP@/0
KXQM00<0PJV105ibC@1NLTd0301NLTd00`21ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086Y
PHT0/>3V0@3oool008T0/>3V00<0PJV103M0=`0g@3L00`0g@3L00`21ZH40G71H05a`F00905a`F003
086YP@1bSF/0LXe[0080LXe[2P21ZH4407nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>
/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26
Z7L05`26Z7L00`21ZH40NiY[07^JJ`0807^JJ`l0PJV12`1NLTd00`21ZH40AeDj04ME>P0604ME>P05
086YP@0T9ad092LM02@W7@21ZH40R02`h>H10?ooo`00R02`h>H00`21ZH40=d0g03M0=`0403M0=`03
086YP@1LL5P0G71H00H0G71H2021ZH4>07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>
/h@06@2>/h@00`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26
Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^JJ`04086YP@1WPEH0Ih5F06N1EPP0PJV1101NLTd00`21
ZH40AeDj04ME>P0604ME>P04086YP@0T9ad092LM086YPHP0/>3V0@3oool008P0/>3V00<0PJV103M0
=`0g@3L00`0g@3L01021ZH40G71H05a`F01LL5P6086YP@<0JhIY00<0PJV107nPNP1oX7X0401oX7X0
0`21ZH40RJf108V]P@0E08V]P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jcP`2>/h<06P2>/h<0
0`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/0
0`21ZH40Ih5F06N1EP0906N1EPL0PJV11P17ECX01@21ZH4092LM02@W7@0T9ad0PJV108L0/>3V0@3o
ool008L0/>3V00@0PJV103M0=`0g@3L0=d0g1`21ZH4906^6J@03086YP@1oX7X0Oj1j00l0Oj1j00<0
PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301X0S[>300<0
PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[01<0NiY[00<0
PJV106N1EP1WPEH0301WPEH00`21ZH40DF=3055S@`05086YP@80AeDj00@0PJV102@W7@0T9ad0PJV1
Q`2`h>H10?ooo`00Q`2`h>H4086YP@<0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21ZH40Oj1j07nP
NP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jc
P`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^J
J`0C07^JJ`03086YP@1WPEH0Ih5F00`0Ih5F00<0PJV1055S@`1AHd<01@1AHd<4086YP@8092LM00<0
PJV10;3PiP2`h>H0Q02`h>H10?ooo`00QP2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02@1[QVT0
0`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@0
0`21ZH40S[>308jcP`0J08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L0
0`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01P1AHd<0
0`21ZH40;CDU086YP@02086YPHH0/>3V0@3oool008H0/>3V0P21ZH4504MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`OP0L08b`OP03086YP@26Z7L0QZQg
01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300@0PJV102de9@0]=BD0;CDUQP2`h>H10?ooo`00QP2`h>H00`21ZH40AeQ904MHB@0404MH
B@03086YP@1[QVT0JhIY00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]
P@03086YP@2>/h@0S[>401X0S[>400<0PJV108jcP`2>/h<06P2>/h<00`21ZH40S;1n08b`OP0L08b`
OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1
EP03086YP@1AHd<0DF=300L0DF=300D0PJV102de9@0]=BD0;CDU086YP@250;3PiP40oooo00260;3P
iP03086YP@17F4T0AeQ900@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0J08jc
P`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0
PJV108D0/>3V0@3oool008D0/>3V0P21ZH4604MHB@03086YP@1[QVT0JhIY00T0JhIY00<0PJV107nP
NP1oX7X04@1oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>401T0S[>400<0PJV108jc
P`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg01L0QZQg00<0PJV107^J
J`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=300H0DF=300D0PJV102de
9@0]=BD0;CDU086YP@250;3PiP40oooo00250;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6
J@03086YP@1oX7X0Oj1j0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jc
Q003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0G08JX
M`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S
@`04086YP@0]=BD0;CDU086YPHD0/>3V0@3oool008D0/>3V0P21ZH4504MHB@03086YP@1[QVT0JhIY
00X0JhIY00<0PJV107nPNP1oX7X0401oX7X00`21ZH40RJf108V]P@0F08V]P@03086YP@2>/h@0S[>4
01X0S[>400<0PJV108jcP`2>/h<0702>/h<00`21ZH40S;1n08b`OP0K08b`OP03086YP@26Z7L0QZQg
01P0QZQg00<0PJV107^JJ`1kVV/04`1kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@240;3PiP40oooo00250;3PiP03086YP@17F4T0AeQ9
00@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf1
01H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n
01/0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^JJ`03086YP@1WPEH0Ih5F
00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108@0/>3V0@3oool0
08D0/>3V00<0PJV104MHB@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j
0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>3
01`0S[>300<0PJV108b`OP2</7h06`2</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[
01<0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU
02de9@21ZH40Q02`h>H10?ooo`00Q02`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21
ZH40Oj1j07nPNP0@07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06P2>/h@00`21
ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01/0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21
ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021
ZH40;CDU02de9@21ZH640;3PiP40oooo00240;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0906^6
J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00J08jc
Q003086YP@2>/h<0S[>301`0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JX
M`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1EP1WPEH03@1WPEH00`21ZH40DF=3055S@`07055S
@`05086YP@0]=BD0;CDU02de9@21ZH40P`2`h>H10?ooo`00Q02`h>H2086YP@D0AeQ900<0PJV106^6
J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0A07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jc
Q02>/h@06P2>/h@00`21ZH40S[>308jcP`0L08jcP`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JX
M`26Z7L05`26Z7L00`21ZH40NiY[07^JJ`0D07^JJ`03086YP@1WPEH0Ih5F00d0Ih5F00<0PJV1055S
@`1AHd<01`1AHd<01@21ZH40;CDU02de9@0]=BD0PJV108<0/>3V0@3oool008@0/>3V00<0PJV104MH
B@17F4T01017F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j0140Oj1j00<0PJV108V]
P@29[H405P29[H400`21ZH40S[>408jcQ00J08jcQ003086YP@2>/h<0S[>301`0S[>300<0PJV108b`
OP2</7h0702</7h00`21ZH40QZQg08JXM`0G08JXM`03086YP@1kVV/0NiY[01@0NiY[00<0PJV106N1
EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU02de9@21ZH40P`2`h>H1
0?ooo`00P`2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0@07nP
NP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@06`2>/h@00`21ZH40S[>308jcP`0L08jc
P`03086YP@2</7h0S;1n01`0S;1n00<0PJV108JXM`26Z7L06026Z7L00`21ZH40NiY[07^JJ`0C07^J
J`03086YP@1WPEH0Ih5F00h0Ih5F00<0PJV1055S@`1AHd<01`1AHd<01021ZH40;CDU02de9@21ZH63
0;3PiP40oooo00230;3PiP80PJV11P17F4T00`21ZH40JhIY06^6J@0:06^6J@03086YP@1oX7X0Oj1j
0100Oj1j00<0PJV108V]P@29[H405P29[H400`21ZH40S[>408jcQ00K08jcQ003086YP@2>/h<0S[>3
01`0S[>300<0PJV108b`OP2</7h0702</7h00`21ZH40QZQg08JXM`0H08JXM`03086YP@1kVV/0NiY[
01<0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`07055S@`05086YP@0]=BD0;CDU
02de9@21ZH40PP2`h>H10?ooo`00P`2`h>H2086YP@H0AeQ900<0PJV106^6J@1[QVT02@1[QVT00`21
ZH40Oj1j07nPNP0A07nPNP03086YP@29[H40RJf101H0RJf100<0PJV108jcQ02>/h@03@2>/hAJ086Y
P@d0QZQg00<0PJV107^JJ`1kVV/0501kVV/00`21ZH40Ih5F06N1EP0=06N1EP03086YP@1AHd<0DF=3
00L0DF=300D0PJV102de9@0]=BD0;CDU086YP@220;3PiP40oooo00230;3PiP0301dV8`21ZH40AeQ9
00@0AeQ900<0PJV106^6J@1[QVT02P1[QVT00`21ZH40Oj1j07nPNP0807nPNS80PJV13P2F_hh00`21
ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H402`2>]H4I086Y
P@/0NiY[00<0PJV106N1EP1WPEH03P1WPEH00`21ZH40DF=3055S@`06055S@`05086YP@0]=BD0;CDU
02de9@21ZH40PP2`h>H10?ooo`00P`2`h>H00`21ZH40AeQ904MHB@0404MHB@03086YP@1[QVT0JhIY
00@0JhIY4@21ZH4908V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21
ZH40U/2<09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21
ZH40Q:Qf08BXMP0908BXMR40PJV11@1AHd<01021ZH40;CDU02de9@21ZH620;3PiP40oooo00220;3P
iP80PJV10`17F4T:086YP@H0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:k
S003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09Bm
R003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:A
HP03086YP@1GKTT0Efi90080Efi91`21ZH4202de9@03086YP@2`h>H0/>3V07l0/>3V0@3oool00880
/>3V1@21ZH4305A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40
T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40
U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40
LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900<0PJV103=1;021ZH400P21ZH610;3PiP40
oooo00220;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn6
00<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<
00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf
00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021
ZH40P@2`h>H10?ooo`00PP2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10840/>3V0@3oool00880/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg
00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>
00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F1
00<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi9
00D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00220;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00PP2`h>H00`21ZH40E6]I
05A[F@0405A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<
09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0702F`8`00`21ZH40U;f8
09BmR00L09BmR003086YP@2>]H40S[F101P0S[F100<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R
07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40
oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn6
00<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01`0U/2<
00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0H08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf
00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021
ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn6
08V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<
09K0S00L09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40602>]H400`21ZH40Q:Qf
08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/
03=1;00c@B`0PJV10840/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg
00<0PJV108V_QP29[hH04@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01X0U[n>
00<0PJV109K0S02F`8`07@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101P0S[F1
00<0PJV108BXMP24Z7H05024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi9
00D0PJV103=1;00c@B`0<d4/086YP@210;3PiP40oooo00210;3PiP80PJV11P1DJeT00`21ZH40MiQg
07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>
09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F1
08jeP@0I08jeP@03086YP@24Z7H0Q:Qf01<0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi9
05M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P@2`h>H10?ooo`00P@2`h>H2086YP@H0E6]I
00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<
00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f8
00<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R
00<0PJV105M^B@1GKTT01`1GKTT01021ZH40<d4/03=1;021ZH610;3PiP40oooo00210;3PiP80PJV1
1P1DJeT00`21ZH40MiQg07NHM`0:07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00
P@2`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800
/>3V0@3oool00840/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00X0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0
7@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0
<d4/086YP@200;3PiP40oooo00210;3PiP0302@_;@21ZH40E6]I00D0E6]I00<0PJV107NHM`1gV7L0
2P1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
6@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00840/>3V00<0PJV105A[F@1DJeT0
101DJeT00`21ZH40MiQg07NHM`0;07NHM`03086YP@29[hH0RJn60140RJn600<0PJV109:kS02B^h`0
5P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086YP@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0
702D_HP00`21ZH40S[F108jeP@0I08jeP@03086YP@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF80
3P1bTF800`21ZH40Efi905M^B@0705M^B@05086YP@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00
P02`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L02`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086Y
P@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh06`2F_hh00`21ZH40U/2<09K0S00M09K0S003086Y
P@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H406@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086Y
P@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT01`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800
/>3V0@3oool00800/>3V0P21ZH4605A[F@03086YP@1gV7L0MiQg00/0MiQg00<0PJV108V_QP29[hH0
4@29[hH00`21ZH40T[^<09:kS00F09:kS003086YP@2F_hh0U[n>01/0U[n>00<0PJV109K0S02F`8`0
7@2F`8`00`21ZH40U;f809BmR00L09BmR003086YP@2>]H40S[F101T0S[F100<0PJV108BXMP24Z7H0
5024Z7H00`21ZH40LY5R07:AHP0>07:AHP03086YP@1GKTT0Efi900L0Efi900D0PJV103=1;00c@B`0
<d4/086YP@200;3PiP40oooo00200;3PiP80PJV11P1DJeT00`21ZH40MiQg07NHM`0;07NHM`03086Y
P@29[hH0RJn60140RJn600<0PJV109:kS02B^h`05P2B^h`00`21ZH40U[n>09JoSP0K09JoSP03086Y
P@2F`8`0U/2<01d0U/2<00<0PJV109BmR02D_HP0702D_HP00`21ZH40S[F108jeP@0I08jeP@03086Y
P@24Z7H0Q:Qf01@0Q:Qf00<0PJV107:AHP1bTF803P1bTF800`21ZH40Efi905M^B@0705M^B@05086Y
P@0c@B`0<d4/03=1;021ZH40P02`h>H10?ooo`00P02`h>H2086YP@H0E6]I00<0PJV107NHM`1gV7L0
2`1gV7L00`21ZH40RJn608V_QP0A08V_QP03086YP@2B^h`0T[^<01H0T[^<00<0PJV109JoSP2F_hh0
6`2F_hh00`21ZH40U/2<09K0S00M09K0S003086YP@2D_HP0U;f801`0U;f800<0PJV108jeP@2>]H40
6@2>]H400`21ZH40Q:Qf08BXMP0D08BXMP03086YP@1bTF80LY5R00h0LY5R00<0PJV105M^B@1GKTT0
1`1GKTT01@21ZH40<d4/03=1;00c@B`0PJV10800/>3V0@3oool00800/>3Vl`21ZH600;3PiP40oooo
00200;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P02`h>H10?ooo`00P02`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bd
O`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9
<@0hBC40PJV10800/>3V0@3oool00800/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0
PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00200;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0;082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H00`21ZH40GW]U05ik
I@0405ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6
U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7
T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^N
K@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo
00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0
PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0
PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0
PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40
P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096l
S`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:
U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bd
O`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9
<@0hBC40PJV10800/>3V0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0
PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0
PJV109g:U02MbY@07@2MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01T0UL2:00<0
PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0
PJV103Q9<@0hBC40>4Ta086YP@200;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082V
PP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:
UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0
RP0I09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ah
C`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P02`h>H10?ooo`00P@2`h>H2086YP@H0GW]U00<0
PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0
PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2Kai00VlN@01`0VlN@00<0
PJV109G0RP2E`8X06@2E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0
PJV105ahC`1LN4l01`1LN4l01021ZH40>4Ta03Q9<@21ZH610;3PiP40oooo00210;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01d0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0I09G0RP03086YP@2<]7l0S;Ao01<0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00P@2`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802`20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06P2MbYH00`21ZH40WLZD09g:U00M09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V
0@3oool00840/>3V0P21ZH4605ikI@03086YP@20YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta
086YP@210;3PiP40oooo00210;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0;082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H00`21ZH40GW]U05ikI@0405ikI@03086YP@20
YX80P:J200/0P:J200<0PJV1096lS`2A_8l04@2A_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2M
bYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702MbY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E
`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1L
N4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta086YP@210;3PiP40oooo00220;3PiP80PJV11P1N
NfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2J
aYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702K
ai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1k
WVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0hBC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`
h>H2086YP@H0GW]U00<0PJV1082VPP20YX802P20YX800`21ZH40TKb?096lS`0A096lS`03086YP@2J
aYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2K
ai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1k
WVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1LN4l01@21ZH40>4Ta03Q9<@0hBC40PJV10840/>3V
0@3oool00880/>3V0P21ZH4605ikI@03086YP@20YX80P:J200X0P:J200<0PJV1096lS`2A_8l04@2A
_8l00`21ZH40V/JE09[6U@0F09[6U@03086YP@2MbYH0WLZF01/0WLZF00<0PJV109g:U02MbY@0702M
bY@00`21ZH40VlN@09_7T00L09_7T003086YP@2E`8X0UL2:01P0UL2:00<0PJV108bdO`2<]7l0502<
]7l00`21ZH40Nii]07^NK@0>07^NK@03086YP@1LN4l0G7Q?00L0G7Q?00D0PJV103Q9<@0hBC40>4Ta
086YP@210;3PiP40oooo00220;3PiP80PJV11P1NNfD00`21ZH40P:J2082VPP0:082VPP03086YP@2A
_8l0TKb?0140TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2M
bY@0WLZD01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<
]7l0S;Ao01@0S;Ao00<0PJV107^NK@1kWVd03P1kWVd00`21ZH40G7Q?05ahC`0705ahC`05086YP@0h
BC40>4Ta03Q9<@21ZH40P@2`h>H10?ooo`00PP2`h>H5086YP@<0GW]U00<0PJV1082VPP20YX802P20
YX800`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2M
bYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E
`8X00`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00h0Nii]00<0PJV105ahC`1LN4l01`1L
N4l00`21ZH40>4Ta03Q9<@02086YPH40/>3V0@3oool00880/>3V0P21ZH4306F7KPX0PJV11P20YX80
0`21ZH40TKb?096lS`0A096lS`03086YP@2JaYD0V/JE01H0V/JE00<0PJV109g:UP2MbYH06`2MbYH0
0`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0RP2E`8X0602E`8X0
0`21ZH40S;Ao08bdO`0D08bdO`03086YP@1kWVd0Nii]00H0Nii]5@21ZH400`0kCc<0PJV10;3PiP20
0;3PiP40oooo00230;3PiP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X01026/8X@086Y
P@X0TKb?00<0PJV109[6U@2JaYD05P2JaYD00`21ZH40WLZF09g:UP0K09g:UP03086YP@2MbY@0WLZD
01`0WLZD00<0PJV109_7T02Kai00702Kai000`21ZH40UL2:09G0RP0H09G0RP03086YP@2<]7l0S;Ao
00T0S;Ao5021ZH48086XM@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?<`0kCc<0>dlcPP2`h>H1
0?ooo`00P`2`h>H2086YP@D0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0709O6
Uc80PJV13`2MbYH00`21ZH40WLZD09g:U00L09g:U003086YP@2Kai00VlN@01`0VlN@00<0PJV109G0
RP2E`8X02`2E`8XI086YP@/0TKf700<0PJV1086XM@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00606>3
F005086YP@0kCc<0>dlc03]?<`21ZH40PP2`h>H10?ooo`00P`2`h>H2086YP@H0IHM^00<0PJV108J`
RP26/8X02@26/8X00`21ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid0302RdieK086YP@d0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086X
M@03086YP@1SPeP0Hh=H00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@220;3PiP40oooo00230;3P
iP80PJV11P1UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?
W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0K0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@
U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086X
M@21Z7D03P21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40PP2`h>H1
0?ooo`00P`2`h>H2086YP@H0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06`2Rdid00`21ZH40X]>K0:;CV`0L0:;C
V`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH63
0;3PiP40oooo00240;3PiP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21
ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21
ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21
ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21
ZH40>dlc03]?<`0kCc<0PJV108<0/>3V0@3oool008@0/>3V0P21ZH4506F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL04@2GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA
01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@230;3PiP40oooo00240;3PiP80PJV11P1UQfh00`21
ZH40Q[2:08J`RP0908J`RP03086YP@2GaYL0UlJG0140UlJG00<0PJV109o?W02Oci`05P2Oci`00`21
ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21
ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701@0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21
ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc03]?<`21ZH40P`2`h>H10?ooo`00Q02`h>H2086Y
P@H0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe
00d0PJQe00<0PJV106>3F01SPeP01`1SPeP01021ZH40>dlc03]?<`21ZH640;3PiP40oooo00250;3P
iP03086YP@1UQfh0IHM^00@0IHM^00<0PJV108J`RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6
U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;C
V`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096m
Q`03086YP@21Z7D0PJQe00h0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0
PJV108@0/>3V0@3oool008D0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`
RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;C
W@03086YP@2Rdi/0X]>K01`0X]>K00<0PJV10:3@U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9
T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3
F005086YP@0kCc<0>dlc03]?<`21ZH40Q02`h>H10?ooo`00Q@2`h>H2086YP@D0IHM^00<0PJV108J`
RP26/8X02P26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL01H0WlnL00<0PJV10:;C
W@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9
T@2KbI40602KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe00d0PJQe00<0PJV106>3
F01SPeP01`1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108@0/>3V0@3oool008D0/>3V0P21ZH4606F7
KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?
W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/0702Rdi/00`21ZH40X=2G0:3@U`0K0:3@
U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL0502A_HL00`21ZH40PJQe086XM@0=086X
M@03086YP@1SPeP0Hh=H00L0Hh=H00@0PJV103]?<`0kCc<0PJV1Q@2`h>H10?ooo`00Q@2`h>H2086Y
P@H0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0A09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06@2Rdid00`21ZH40X]>K0:;CV`0L0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0D096mQ`03086YP@21Z7D0PJQe
00d0PJQe00<0PJV106>3F01SPeP01P1SPeP01@21ZH40>dlc03]?<`0kCc<0PJV108D0/>3V0@3oool0
08H0/>3V00<0PJV106F7KP1UQfh0101UQfh00`21ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG
0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K
01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf7
01<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc
03]?<`21ZH40Q@2`h>H10?ooo`00QP2`h>H00`21ZH40IHM^06F7KP0406F7KP03086YP@26/8X0Q[2:
00X0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M
01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA
01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21ZH40PJQe086XM@0=086XM@03086YP@1SPeP0Hh=H
00L0Hh=H00D0PJV103]?<`0kCc<0>dlc086YP@250;3PiP40oooo00260;3PiP80PJV11@1UQfh00`21
ZH40Q[2:08J`RP0:08J`RP03086YP@2GaYL0UlJG0100UlJG00<0PJV109o?W02Oci`05P2Oci`00`21
ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@U`2Pd9L0702Pd9L00`21
ZH40VlVA09_9T@0G09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086XM@21Z7D03@21Z7D00`21
ZH40Hh=H06>3F00706>3F005086YP@0kCc<0>dlc086YP@000000Q@2`h>H10?ooo`00QP2`h>H2086Y
P@H0IHM^00<0PJV108J`RP26/8X02@26/8X00`21ZH40UlJG09O6U`0@09O6U`03086YP@2Oci`0WlnL
01H0WlnL00<0PJV10:;CW@2Rdid06P2Rdid00`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G
01`0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0C096mQ`03086YP@21Z7D0PJQe
00d0PJQe00<0PJV106>3F01SPeP01P1SPeP01021ZH40000003]?<`21ZH43000008@0/>3V0@3oool0
08L0/>3V1021ZH4306F7KP03086YP@26/8X0Q[2:00T0Q[2:00<0PJV109O6U`2GaYL0402GaYL00`21
ZH40WlnL09o?W00F09o?W003086YP@2Rdid0X]>M01X0X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21
ZH40X=2G0:3@U`0L0:3@U`03086YP@2KbI40VlVA01L0VlVA00<0PJV1096mQ`2A_HL04`2A_HL00`21
ZH40PJQe086XM@0<086XM@03086YP@1SPeP0Hh=H00D0Hh=H0P21ZH46000008D0/>3V0@3oool008L0
/>3V00@0PJV106R>M01XSW@0J8id1`21ZH4908J`RP03086YP@2GaYL0UlJG00l0UlJG00<0PJV109o?
W02Oci`05P2Oci`00`21ZH40X]>M0:;CW@0J0:;CW@03086YP@2Rdi/0X]>K01X0X]>K00<0PJV10:3@
U`2Pd9L06`2Pd9L00`21ZH40VlVA09_9T@0H09_9T@03086YP@2A_HL0TKf701<0TKf700<0PJV1086X
M@21Z7D03021Z7D01021ZH40000006>3F0000004086YP@0306N;G`000000000000@00000QP2`h>H1
0?ooo`00R02`h>H00`21ZH40J8id06R>M00306R>M004086YP@29]i00RKN@08VgT0H0PJV10`26/8X0
0`21ZH40000009O6U`0@09O6U`03086YP@2Oci`0WlnL01D0WlnL00<0PJV10:;CW@2Rdid06P2Rdid0
0`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI405`2KbI40
0`21ZH40TKf7096mQ`0C096mQ`05086YP@21Z7D0PJQe086XM@0000000`21Z7D00`000000PJQe086X
M@02086XM@80PJV11P00000306N;G`L00000QP2`h>H10?ooo`00R02`h>H00`21ZH40J8id06R>M004
06R>M003086YP@29]i00RKN@00H0RKN@1021ZH4010000000PJV1086YP@21ZH4>09O6U`04086YP@2O
ci`0WlnL000001D0WlnL00<0PJV10:;CW@2Rdid06@2Rdid00`21ZH40X]>K0:;CV`0J0:;CV`03086Y
P@2Pd9L0X=2G01/0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf7096mQ`0C096mQ`03086Y
P@000000000000L000000`21ZH400`25/7`000000000000600000080Ih]O0P000000100kDS@00000
0000000000270;3PiP40oooo00290;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i00
2@29]i000`21ZH4000000000000209_=W@X0PJV100H0UlJG000000000000UlJG086YP@2Oci`30000
01@0WlnL00<0PJV10000000000006@2Rdid00`21ZH40X]>K0:;CV`0J0:;CV`03086YP@2Pd9L0X=2G
01/0X=2G00<0PJV109_9T@2KbI405`2KbI400`21ZH40TKf700000003096mQ`030000002A_HL0TKf7
00<0TKf72@21ZH4:000000D0QK1l0P00000406N;G`8000000P1WRel00`000000>e8d000000020000
08P0/>3V0@3oool008T0/>3V00<0PJV106R>M01XSW@0101XSW@00`21ZH40RKN@08VgT00908VgT003
086YP@000000000000/0VlfM00<0PJV10000000000001021ZH42000000P0PJV1302Oci`7000001D0
X]>M00<0PJV10:;CV`2Rdi/06P2Rdi/00`21ZH40X=2G0:3@U`0K0:3@U`03086YP@2KbI40VlVA00T0
VlVA0P00000;086YP@X000000`21ZH4809G4S@@000001025/7`3000000@0QK1l0P0000000`21ZH40
Ih]O06N;G`0306N;G`050000001WRel0Ih]O0000000kDS@00`0000280;3PiP40oooo002:0;3PiP03
086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i002@29]i000`21ZH40VlfM0000000<09_=W@80
000000@0VlfM086YP@2SeZ80XmJR0P0000080:?FXP/0PJV12`00000<086YP@8000004021ZH420000
0003086YP@2Rdi/0X]>K00L0X]>K0P0000030:;CV`03086YP@2Pd9L0X=2G00D0X=2G0P0000060:3@
U`X0PJV10P00000=086YP@80000000<0PJV109k@U`2Nd9L0202Nd9L<000000T0ULB=0`00000608F`
O0<000001025/7`00`000000QK1l086YP@0506N;G`030000001WRel0PJV10080>e8d00<00000086Y
P@000000R02`h>H10?ooo`00RP2`h>H00`21ZH40J8id06R>M00406R>M003086YP@29]i00RKN@00P0
RKN@00@0PJV109_=W@00000000002`2KcId200000080VlfM00@0PJV10:?FXP00000000004P2SeZ83
000000D0Y]ZS1@00000<0:KJX`8000000`2VfZ<00`21ZH40Y]ZQ0:KJX@090:KJX@80000000<0Y]ZQ
086YP@21ZH401`21ZH42000000/0PJV10P000006086YP@T0Y=NM0P0000030:CGW@03086YP@2Nd9L0
W]2G00P0W]2G0P00000:09k@U`<00000202Ea8d3000000L0ULB=0`0000000`21ZH40QK1l08F`O004
08F`O0<000000`25/7`200000003086YP@1WRel0Ih]O00H0Ih]O00<0PJV103]B=00000000`000028
0;3PiP40oooo002;0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i002@29]i000`21
ZH40VlfM0000000;09_=W@8000000P2KcId00`21ZH40XmJR0000000200000100XmJR0`0000000`21
ZH40Y]ZS0:KJX`060:KJX`@000002P2VfZ<2000000<0Y]ZS00<0PJV10:KJX@2VfZ402@2VfZ420000
00X0Y]ZQ0P0000030:KJX@03086YP@2Teid0Y=NM00D0Y=NM0P00000?0:CGW@8000000`2Teid00`21
ZH40W]2G09k@U`0809k@U`8000002@2Nd9L300000003086YP@2Ea8d0ULB=00L0ULB=0`00000509G4
S@<0000000<0ULB=086YP@25/7`01025/7`3000000<0QK1l0P0000000`25/7`0PJV106N;G`0706N;
G`D00000R@2`h>H10?ooo`00R`2`h>H00`21ZH40J8id06R>M00306R>M003086YP@29]i00RKN@00T0
RKN@00@0PJV109_=W@00000000002P2KcId200000080VlfM00<0PJV10:?FXP2SeZ800P00000?0:?F
XP<000000P2SeZ800`21ZH40Y]ZS0:KJX`060:KJX`@000002@2VfZ<2000000<0Y]ZS00<0PJV10:KJ
X@2VfZ402@2VfZ42000000X0Y]ZQ0P0000030:KJX@03086YP@2Teid0Y=NM00D0Y=NM0P00000?0:CG
W@8000000`2Teid00`21ZH40W]2G09k@U`0809k@U`800000202Nd9L30000000309k@U`21ZH40ULB=
00T0ULB=00<0000009G4S@2Ea8d0102Ea8d20000000309G4S@21ZH40QK1l00D0QK1l0P00000308F`
O080000000<0QK1l086YP@1WRel0101WRel00`000000Ih]O06N;G`06000008T0/>3V0@3oool008/0
/>3V00<0PJV106R>M01XSW@0101XSW@00`21ZH40RKN@08VgT00808VgT003086YP@2KcId0VlfM0080
00002@2KcId200000080VlfM00<0PJV10:?FXP2SeZ800P00000?0:?FXP8000000`2SeZ800`21ZH40
Y]ZS0:KJX`080:KJX`<00000202VfZ<2000000<0Y]ZS00<0PJV10:KJX@2VfZ402@2VfZ42000000X0
Y]ZQ0P0000030:KJX@03086YP@2Teid0Y=NM00D0Y=NM0P00000?0:CGW@8000000P2Teid00`21ZH40
W]2G09k@U`0909k@U`800000202Nd9L200000080W]2G00<0PJV109G4S@2Ea8d03P2Ea8d200000080
ULB=00<0PJV108F`O025/7`01025/7`2000000<0QK1l0P0000000`25/7`0PJV106N;G`0500000080
Ih]O0`0000000`21ZH4000000;3PiP290;3PiP40oooo002<0;3PiP03086YP@1XSW@0J8id00<0J8id
00<0PJV108VgT029]i002@29]i000`21ZH40VlfM0000000<000000<0VlfM00@0PJV10:?FXP000000
00003`2SeZ82000000<0XmJR00<0PJV10:KJX`2VfZ<02@2VfZ<00`000000Y]ZS0:KJX`070:KJX`80
00000`2VfZ<00`21ZH40Y]ZQ0:KJX@090:KJX@8000002P2VfZ42000000<0Y]ZQ00<0PJV10:CGW@2T
eid01@2Teid2000000l0Y=NM0P0000020:CGW@03086YP@2Nd9L0W]2G00P0W]2G0P00000909k@U`04
0000002Nd9L0W]2G086YPA40ULB=00D0000009G4S@2Ea8d0ULB=086YP@0508F`O0<000000`25/7`:
0000000306N;G`000000000000@00000RP2`h>H10?ooo`00S02`h>H00`21ZH40J8id06R>M00406R>
M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId03000000309_=W@04086YP@2SeZ800000
000000l0XmJR0P0000030:?FXP03086YP@2VfZ<0Y]ZS01<0Y]ZS0P0000030:KJX`03086YP@2VfZ40
Y]ZQ00T0Y]ZQ0P00000:0:KJX@8000000`2VfZ400`21ZH40Y=NM0:CGW@050:CGW@8000003P2Teid2
000000<0Y=NM00<0PJV109k@U`2Nd9L0202Nd9L2000000P0W]2G0P00000209k@U`03086YP@2Ea8d0
ULB=00h0ULB=0P00000309G4S@03086YP@25/7`0QK1l00<0QK1l0P00000408F`O0D000000P1WRel9
000008/0/>3V0@3oool008d0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08VgT00808Vg
T004086YP@2KcId0VlfM09_=W@8000001`2KcId2000000<0VlfM00<0PJV10:?FXP0000000P00000=
0:?FXP<000000`2SeZ800`21ZH40Y]ZS0:KJX`0C0:KJX`8000000`2VfZ<00`21ZH40Y]ZQ0:KJX@09
0:KJX@8000002P2VfZ42000000<0Y]ZQ00<0PJV10:CGW@2Teid01@2Teid2000000h0Y=NM0P000003
0:CGW@03086YP@2Nd9L0W]2G00P0W]2G0P00000709k@U`8000000`2Nd9L00`21ZH40ULB=09G4S@08
09G4S@030000002Ea8d0ULB=0080ULB=0P00000309G4S@03086YP@25/7`0QK1l00@0QK1l0P000004
08F`O080000000@0PJV106N;G`1WRel0Ih]O1P000000100kDS@00000086YP@00002;0;3PiP40oooo
002=0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i002@29]i000`21ZH40VlfM09_=
W@03000000H0VlfM0P00000409_=W@04086YP@2SeZ800000000000h0XmJR0P0000040:?FXP03086Y
P@2VfZ<0Y]ZS0180Y]ZS0P0000030:KJX`03086YP@2VfZ40Y]ZQ00T0Y]ZQ0P00000:0:KJX@800000
0`2VfZ400`21ZH40Y=NM0:CGW@050:CGW@8000003P2Teid2000000<0Y=NM00<0PJV109k@U`2Nd9L0
202Nd9L2000000L0W]2G4@00000409G4S@8000000`2Ea8d00`21ZH40QK1l08F`O00308F`O0<00000
1025/7`200000003086YP@1WRel0Ih]O00<0000000<0Ih]O0000000000001@00002;0;3PiP40oooo
002>0;3PiP03086YP@1XSW@0J8id00<0J8id00<0PJV108VgT029]i002029]i001021ZH40VlfM09_=
W@2KcId3000000D0VlfM0P00000409_=W@04086YP@2SeZ800000000000l0XmJR00<000000:?FXP2S
eZ800P2SeZ800`21ZH40Y]ZS0:KJX`0B0:KJX`8000000`2VfZ<00`21ZH40Y]ZQ0:KJX@090:KJX@80
00002P2VfZ42000000<0Y]ZQ00<0PJV10:CGW@2Teid01@2Teid2000000h0Y=NM0P0000030:CGW@03
086YP@2Nd9L0W]2G00P0W]2G0P00000709k@Ua400000102Ea8d2000000<0ULB=00<0PJV108F`O025
/7`00`25/7`3000000<0QK1l0`00000306N;G`8000000P1WRel400000003086YP@000000/>3V08/0
/>3V0@3oool008h0/>3V00<0PJV106R>M01XSW@00`1XSW@00`21ZH40RKN@08VgT00908VgT004086Y
P@2KcId0VlfM09_=W@800000102KcId2000000D0VlfM00<0PJV10:?FXP0000000P00000>0:?FXP80
00000`2SeZ800`21ZH40Y]ZS0:KJX`0B0:KJX`<000000P2VfZ<00`21ZH40Y]ZQ0:KJX@090:KJX@80
00002P2VfZ42000000<0Y]ZQ00<0PJV10:CGW@2Teid01@2Teid2000000h0Y=NM0P0000030:CGW@03
086YP@2Nd9L0W]2G00P0W]2G0P00000709k@U`8000000P2Nd9L00`21ZH40ULB=09G4S@0709G4S@<0
0000102Ea8d200000080ULB=00<0PJV108F`O025/7`00`25/7`3000000D0QK1l0`000000101WRel0
000000000000000206N;G`03086YP@000000000000<00000S02`h>H10?ooo`00S`2`h>H00`21ZH40
J8id06R>M00306R>M003086YP@29]i00RKN@00P0RKN@00<0PJV109_=W@2KcId00P2KcId2000000<0
VlfM0P00000609_=W@03086YP@0000000000008000003P2SeZ8200000080XmJR00<0PJV10:KJX`2V
fZ<04P2VfZ<3000000<0Y]ZS00<0PJV10:KJX@2VfZ40202VfZ42000000X0Y]ZQ0P0000030:KJX@03
086YP@2Teid0Y=NM00D0Y=NM0P00000>0:CGW@8000000P2Teid00`21ZH40W]2G09k@U`0809k@U`80
0000202Nd9L200000080W]2G00<0PJV109G4S@2Ea8d01P2Ea8d3000000D0ULB=100000000`21ZH40
QK1l08F`O00208F`O0@000001@25/7`00`21ZH40000000000003000000<0Ih]O00D0PJV103]B=00k
DS@0PJV10000002=0;3PiP40oooo002?0;3PiP80PJV1101XSW@00`21ZH40RKN@08VgT00808VgT003
086YP@2KcId0VlfM00<0VlfM00@0000009_=W@2KcId0VlfM0P00000609_=W@03086YP@2SeZ800000
00<000003@2SeZ83000000030:?FXP21ZH40Y]ZS00X0Y]ZS00<000000:KJX`2VfZ<01P2VfZ<40000
0080Y]ZS00<0PJV10:KJX@2VfZ40202VfZ42000000X0Y]ZQ0P0000030:KJX@03086YP@2Teid0Y=NM
00@0Y=NM0`00000=0:CGW@<000000P2Teid00`21ZH40W]2G09k@U`0809k@U`800000202Nd9L30000
000309k@U`21ZH40ULB=00H0ULB=0`00000609G4S@D000000P25/7`5000000H0QK1l00<0PJV10000
000000000P00000306N;G`04086YP@0kDS@0PJV1086YP@800000S@2`h>H10?ooo`00T02`h>H5086Y
P@0306R>M021ZH40RKN@00T0RKN@00<0PJV109_=W@2KcId00P2KcId200000080VlfM0P00000609_=
W@03086YP@2SeZ80000000@000003@2SeZ83000000030:?FXP21ZH40Y]ZS00L0Y]ZS100000070:KJ
X`D0000000<0Y]ZS086YP@2VfZ402@2VfZ43000000T0Y]ZQ0P0000030:KJX@03086YP@2Teid0Y=NM
00D0Y=NM1000000;0:CGW@D0000000<0PJV109k@U`2Nd9L0202Nd9L00`000000W]2G09k@U`0709k@
U`@000001P2Ea8d4000000X0ULB=2@00000608F`O003086YP@1WRel0Ih]O00<0Ih]O1021ZH400`0m
F3X0PJV10000002>0;3PiP40oooo002@0;3PiP03086YP@1YTGL0JI5g0080JI5g0`21ZH4908VgT003
086YP@2KcId0VlfM00<0VlfM00<0000009_=W@2KcId00P00000609_=W@03086YP@2SeZ80000000L0
00002`2SeZ8300000003086YP@2VfZ<0Y]ZS00D0Y]ZS100000080:KJX`L000002P2VfZ400`000000
Y]ZQ0:KJX@090:KJX@8000000`2VfZ400`21ZH40Y=NM0:CGW@040:CGW@H000002P2Teid6000000T0
W]2G0P00000;09k@U`D000000P2Ea8d4000000/0ULB=1@0000000`25/7`000000000000608F`O003
086YP@1WRel0Ih]O00@0PJV100L0J8mS086YP@0mF3X0?EPj086YP@2`h>H0000008h0/>3V0@3oool0
0940/>3V00<0PJV106VAM`1YTGL00`1YTGL5086YP@D0RKN@00<0PJV109_=W@2KcId00`2KcId20000
000309_=W@000000000000L0VlfM00<0PJV10:?FXP0000000P2SeZ88000000P0XmJR1@0000030:KJ
X`@000002`2VfZ<2000000030:KJX`000000000000800000202VfZ42000000/0Y]ZQ0P0000030:KJ
X@03086YP@2Teid0Y=NM00@0Y=NM0P0000020:CGW@D000000`2Teid600000080Y=NM1@00000309k@
U`D00000302Nd9L8000000d0ULB=00<0PJV108F`O025/7`00`25/7`2000000@0QK1l1@21ZH4506R?
H`03086YP@0mF3X0?EPj0940/>3V0@3oool00980/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40
RKZB08VjTP0208VjTP@0PJV10P29]i000`21ZH40VlfM09_=W@0309_=W@@000001`2KcId00`21ZH40
XmJR0:?FXP040:?FXPH000002@2SeZ8:000000`0Y]ZS0P0000030:KJX`@000000`2VfZ45000000/0
Y]ZQ0P0000030:KJX@03086YP@2Teid0Y=NM00@0Y=NM0P0000030:CGW@`00000102Teid;000000d0
W]2G00<0PJV109G4S@0000001000000>09G4S@03086YP@25/7`0QK1l0080QK1l0`000004086YP@03
08FcO`21ZH40J8mS00H0J8mS00@0PJV103eH>P0mF3X0PJV1T@2`h>H10?ooo`00TP2`h>H00`21ZH40
JI5g06VAM`0306VAM`03086YP@29^Y80RKZB00D0RKZB1`21ZH4209_=W@<000001`2KcId00`21ZH40
XmJR0:?FXP0D0:?FXP03086YP@000000000000@000003P2VfZ<2000000<0Y]ZS00<0PJV100000000
00002000000<0:KJX@8000000`2VfZ400`21ZH40Y=NM0:CGW@040:CGW@8000001@2Teid6000000P0
Y=NM00<0PJV109k@U`0000001@00000?09k@U`03086YP@2Ea8d0ULB=0180ULB=00<0PJV108F`O025
/7`00`21ZH42000000H0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21ZH40?EPj086YP@2B0;3PiP40
oooo002C0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y802029^Y801021ZH40Vm2P
09_@X02Kd:02086YP@<000001021ZH4409_=W@03086YP@2SeZ80XmJR01@0XmJR00<0PJV10:KJX`2V
fZ<04@2VfZ<2000000<0Y]ZS00<0PJV10:KJX@0000001@00000?0:KJX@8000000`2VfZ400`21ZH40
Y=NM0:CGW@040:CGW@8000004P2Teid00`21ZH40W]2G09k@U`0E09k@U`03086YP@2Ea8d0ULB=00P0
ULB=3@21ZH4308FcO`8000001@25/gl00`21ZH40J8mS06R?H`0506R?H`04086YP@0mF3X0?EPj086Y
PI80/>3V0@3oool009@0/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08VjTP0708VjTP03
086YP@2Kd:00Vm2P00@0Vm2P0P00000409_@X100PJV12`2SeZ800`21ZH40Y]ZS0:KJX`0A0:KJX`80
00000`2VfZ<00`21ZH40Y]ZQ0:KJX@0I0:KJX@03086YP@2Teid0Y=NM01P0Y=NM00<0PJV109k@U`2N
d9L0402Nd9L@086YP@T0UlVA00<0PJV108FcO`25/gl00`25/gl3000000D0QK=o00<0PJV106R?H`1X
Sf<0101XSf<01021ZH40?EPj03eH>P21ZH6C0;3PiP40oooo002D0;3PiP03086YP@1YTGL0JI5g00<0
JI5g00<0PJV108VjTP29^Y801`29^Y800`21ZH40Vm2P09_@X00309_@X0800000202Kd:000`21ZH40
Y=ZV0:CJYP090:CJYQP0PJV11`2VfZ<2000000<0Y]ZS00<0PJV10:KJX@2VfZ406@2VfZ400`21ZH40
Y=NM0:CGW@0H0:CGW@03086YP@2Nd9L0W]2G00@0W]2G3021ZH450:3EV`03086YP@2GbI40UlVA0140
UlVA00<0PJV108FcO`25/gl01025/gl00`000000QK=o08FcO`0308FcO`03086YP@1XSf<0J8mS00D0
J8mS00<0PJV103eH>P21ZH40U02`h>H10?ooo`00U@2`h>H00`21ZH40JI5g06VAM`0206VAM`03086Y
P@29^Y80RKZB00L0RKZB00<0PJV109_@X02Kd:000`2Kd:02000000T0Vm2P00<0PJV10:CJYP2TfZH0
4`2TfZH00`21ZH40Z=jW0:SNY`0:0:SNY`L0PJV10P00000K086YP@0300000021ZH40PJV102<0PJV1
402PeI/00`21ZH40UlVA09O9T@0A09O9T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<0
1@1XSf<01021ZH40?EPj03eH>P21ZH6D0;3PiP40oooo002F0;3PiP03086YP@1YTGL0JI5g0080JI5g
00<0PJV108VjTP29^Y801`29^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV01@0Y=ZV
00<0PJV10:SNY`2XgZL0402XgZL2000000<0Z=jW00<0PJV10:SNY@2XgZD04`2XgZD400000080Z=jU
00<0PJV10:GKX@2Ufj40602Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2GbI40UlVA0140UlVA
00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086YP@0mF3X0PJV109D0/>3V
0@3oool009L0/>3V00D0PJV106VAM`1YTGL0JI5g086YP@0908VjTP03086YP@2Kd:00Vm2P00h0Vm2P
00<0PJV10:CJYP2TfZH04`2TfZH00`21ZH40Z=jW0:SNY`0A0:SNY`8000000P2XgZL00`21ZH40Z=jU
0:SNY@0B0:SNY@H0000000<0Z=jU086YP@2Ufj406@2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086Y
P@2GbI40UlVA0100UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`03086Y
P@0mF3X0PJV109H0/>3V0@3oool009L0/>3V00<0PJV106VAM`1YTGL00P1YTGL00`21ZH40RKZB08Vj
TP0708VjTP03086YP@2Kd:00Vm2P00d0Vm2P00<0PJV10:CJYP2TfZH04`2TfZH00`21ZH40Z=jW0:SN
Y`0A0:SNY`8000000P2XgZL00`21ZH40Z=jU0:SNY@0C0:SNY@@000000P2XgZD00`21ZH40YM^Q0:GK
X@0G0:GKX@03086YP@2PeI/0X=FK01@0X=FK00<0PJV109O9T@2GbI404@2GbI400`21ZH40QK=o08Fc
O`0:08FcO`03086YP@1XSf<0J8mS00D0J8mS00<0PJV103eH>P21ZH40UP2`h>H10?ooo`00V02`h>H0
1@21ZH40JI5g06VAM`1YTGL0PJV100T0RKZB00<0PJV109_@X02Kd:003P2Kd:000`21ZH40Y=ZV0:CJ
YP0B0:CJYP03086YP@2XgZL0Z=jW01H0Z=jW00<0PJV10:SNY@2XgZD0502XgZD01@000000Z=jU0:SN
Y@2XgZD0PJV101T0YM^Q00<0PJV10:3EV`2PeI/0502PeI/00`21ZH40UlVA09O9T@0@09O9T@03086Y
P@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21ZH40?EPj086YP@2G0;3PiP40oooo
002I0;3PiP05086YP@1YTGL0JI5g06VAM`21ZH402@29^Y800`21ZH40Vm2P09_@X00=09_@X003086Y
P@2TfZH0Y=ZV01<0Y=ZV00<0PJV10:SNY`2XgZL05@2XgZL00`21ZH40Z=jU0:SNY@0H0:SNY@03086Y
P@2Ufj40YM^Q01L0YM^Q00<0PJV10:3EV`2PeI/0502PeI/00`21ZH40UlVA09O9T@0@09O9T@03086Y
P@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<0101XSf<01021ZH40?EPj03eH>P21ZH6G0;3PiP40
oooo002I0;3PiP03086YP@1YTGL0JI5g0080JI5g00<0PJV108VjTP29^Y801P29^Y800`21ZH40Vm2P
09_@X00>09_@X003086YP@2TfZH0Y=ZV0180Y=ZV00<0PJV10:SNY`2XgZL05@2XgZL00`21ZH40Z=jU
0:SNY@0H0:SNY@03086YP@2Ufj40YM^Q01L0YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA
09O9T@0@09O9T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21ZH40?EPj
086YP@2H0;3PiP40oooo002J0;3PiP05086YP@1YTGL0JI5g06VAM`21ZH402@29^Y800`21ZH40Vm2P
09_@X00=09_@X003086YP@2TfZH0Y=ZV0180Y=ZV00<0PJV10:SNY`2XgZL05@2XgZL00`21ZH40Z=jU
0:SNY@0H0:SNY@03086YP@2Ufj40YM^Q01H0YM^Q00<0PJV10:3EV`2PeI/0502PeI/00`21ZH40UlVA
09O9T@0@09O9T@03086YP@25/gl0QK=o00T0QK=o00<0PJV106R?H`1XSf<01@1XSf<00`21ZH40?EPj
086YP@2I0;3PiP40oooo002K0;3PiP80PJV10P1YTGL00`21ZH40RKZB08VjTP0608VjTP03086YP@2K
d:00Vm2P00h0Vm2P00<0PJV10:CJYP2TfZH04@2TfZH00`21ZH40Z=jW0:SNY`0E0:SNY`03086YP@2X
gZD0Z=jU01P0Z=jU00<0PJV10:GKX@2Ufj405P2Ufj400`21ZH40X=FK0:3EV`0D0:3EV`03086YP@2G
bI40UlVA00l0UlVA00<0PJV108FcO`25/gl02P25/gl00`21ZH40J8mS06R?H`0506R?H`80PJV1VP2`
h>H10?ooo`00W02`h>H4086YP@T0RKZB00<0PJV109_@X02Kd:003@2Kd:000`21ZH40Y=ZV0:CJYP0B
0:CJYP03086YP@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05`2XgZD00`21ZH40YM^Q0:GKX@0G
0:GKX@03086YP@2PeI/0X=FK01<0X=FK00<0PJV109O9T@2GbI40402GbI400`21ZH40QK=o08FcO`09
08FcO`03086YP@1XSf<0J8mS00<0J8mS1021ZH6K0;3PiP40oooo002L0;3PiP03086YP@1USgD0IHme
00<0PJV11`29^Y800`21ZH40Vm2P09_@X00>09_@X003086YP@2TfZH0Y=ZV0140Y=ZV00<0PJV10:SN
Y`2XgZL05@2XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q01L0YM^Q00<0PJV10:3E
V`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0?09O9T@03086YP@25/gl0QK=o00X0QK=o00<0PJV106R?
H`21ZH400`21ZH400`1USV@0PJV1086YP@2L0;3PiP40oooo002M0;3PiP04086YP@1USgD0IHme06F?
M@D0PJV11029^Y800`21ZH40Vm2P09_@X00=09_@X003086YP@2TfZH0Y=ZV0140Y=ZV00<0PJV10:SN
Y`2XgZL05@2XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q01H0YM^Q00<0PJV10:3E
V`2PeI/0502PeI/00`21ZH40UlVA09O9T@0?09O9T@03086YP@25/gl0QK=o00L0QK=o1@21ZH4406F>
I080PJV1W@2`h>H10?ooo`00WP2`h>H01@21ZH40IHme06F?M@1USgD0PJV100<0QKN@1@21ZH4@09_@
X003086YP@2TfZH0Y=ZV0140Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0F0:SN
Y@03086YP@2Ufj40YM^Q01H0YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0?09O9
T@03086YP@25/gl0QK=o00@0QK=o1021ZH400`22/X00PJV106F>I00506F>I080PJV1WP2`h>H10?oo
o`00W`2`h>H01@21ZH40IHme06F?M@1USgD0PJV100H0QKN@1P21ZH4;09_@X003086YP@2TfZH0Y=ZV
0140Y=ZV00<0PJV10:SNY`2XgZL0502XgZL00`21ZH40Z=jU0:SNY@0F0:SNY@03086YP@2Ufj40YM^Q
01H0YM^Q00<0PJV10:3EV`2PeI/04`2PeI/00`21ZH40UlVA09O9T@0?09O9T@03086YP@25/gl0PJV1
00@0PJV11022/X000`21ZH40IHiT06F>I00406F>I080PJV1W`2`h>H10?ooo`00X02`h>H01021ZH40
IHme06F?M@21ZH4808FgT004086YP@2HcYl0V<jO09S>W`P0PJV1102Kd:000`21ZH40Y=ZV0:CJYP0@
0:CJYP03086YP@2XgZL0Z=jW01@0Z=jW00<0PJV10:SNY@2XgZD05P2XgZD00`21ZH40YM^Q0:GKX@0F
0:GKX@03086YP@2PeI/0X=FK01<0X=FK00<0PJV109O9T@2GbI402P2GbI47086YP@T0P[:000<0PJV1
06F>I01USV@00`1USV@00`21ZH40?E/n086YP@2O0;3PiP40oooo002P0;3PiP05086YP@1USgD0IHme
06F?M@21ZH402025]i000`21ZH40V<jO09S>W`0809S>W`T0PJV13P2TfZH00`21ZH40Z=jW0:SNY`0D
0:SNY`03086YP@2XgZD0Z=jU01H0Z=jU00<0PJV10:GKX@2Ufj405@2Ufj400`21ZH40X=FK0:3EV`0C
0:3EV`03086YP@2GbI40UlVA0080UlVA2@21ZH4309C8TP03086YP@22/X00P[:000T0P[:000<0PJV1
06F>I01USV@00`1USV@00`21ZH40?E/n086YP@2P0;3PiP40oooo002Q0;3PiP05086YP@1USgD0IHme
06F?M@21ZH401`25]i000`21ZH40V<jO09S>W`0=09S>W`04086YP@2RfZH0X]ZV0:;JYPX0PJV11@2T
fZH00`21ZH40Z=jW0:SNY`0D0:SNY`03086YP@2XgZD0Z=jU01D0Z=jU00<0PJV10:GKX@2Ufj405@2U
fj400`21ZH40X=FK0:3EV`090:3EV`l0PJV1302Db9800`21ZH40P[:008:bP00808:bP003086YP@1U
SV@0IHiT00<0IHiT00<0PJV103eK?P21ZH40X@2`h>H10?ooo`00XP2`h>H01@21ZH40IHme06F?M@1U
SgD0PJV100L0QKN@00<0PJV109S>W`2HcYl0302HcYl00`21ZH40X]ZV0:;JYP0;0:;JYQ40PJV12`2X
gZL00`21ZH40Z=jU0:SNY@0E0:SNY@03086YP@2Ufj40YM^Q00X0YM^Q5`21ZH4909oFW003086YP@2D
b980U<RB00h0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I00406F>I080PJV1XP2`
h>H10?ooo`00X`2`h>H01@21ZH40IHme06F?M@1USgD0PJV100L0QKN@00<0PJV109S>W`2HcYl0302H
cYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX00T0Y]nX<021ZH4;0:GMX`03086YP@2O
eY`0WmJL0180WmJL00<0PJV109C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1U
SV@0IHiT00@0IHiT0P21ZH6S0;3PiP40oooo002T0;3PiP05086YP@1USgD0IHme06F?M@21ZH401`25
]i000`21ZH40V<jO09S>W`0;09S>W`03086YP@2RfZH0X]ZV0100X]ZV00<0PJV10:KOZ02VgjP04`2V
gjP00`21ZH40Yn2W0:OPY`0E0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`04P2O
eY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000T0P[:000<0PJV106F>I01USV@00`1U
SV@2086YPJ@0/>3V0@3oool00:@0/>3V00<0PJV106F?M@1USgD00P1USgD00`21ZH40QKN@08FgT004
08FgT003086YP@2HcYl0V<jO00`0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ00C
0:KOZ003086YP@2Wh:L0Yn2W01D0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00B
09oFW003086YP@2Db980U<RB00d0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I003
06F>I080PJV1Y@2`h>H10?ooo`00Y@2`h>H01@21ZH40IHme06F?M@1USgD0PJV100L0QKN@00<0PJV1
09S>W`2HcYl02`2HcYl00`21ZH40X]ZV0:;JYP0@0:;JYP03086YP@2VgjP0Y]nX0180Y]nX00<0PJV1
0:OPY`2Wh:L05@2Wh:L00`21ZH40YMfS0:GMX`0D0:GMX`03086YP@2OeY`0WmJL0140WmJL00<0PJV1
09C8TP2Db9803@2Db9800`21ZH40P[:008:bP00808:bP003086YP@1USV@0IHiT00<0IHiT0P21ZH6V
0;3PiP40oooo002V0;3PiP80PJV10P1USgD00`21ZH40QKN@08FgT00508FgT003086YP@2HcYl0V<jO
00/0V<jO00<0PJV10:;JYP2RfZH03`2RfZH00`21ZH40Y]nX0:KOZ00C0:KOZ003086YP@2Wh:L0Yn2W
01@0Yn2W00<0PJV10:GMX`2UgJ<0502UgJ<00`21ZH40WmJL09oFW00A09oFW003086YP@2Db980U<RB
00`0U<RB00<0PJV108:bP022/X002022/X000`21ZH40IHiT06F>I00306F>I080PJV1Y`2`h>H10?oo
o`00Y`2`h>H5086YP@L0QKN@00<0PJV109S>W`2HcYl02`2HcYl00`21ZH40X]ZV0:;JYP0?0:;JYP03
086YP@2VgjP0Y]nX0180Y]nX00<0PJV10:OPY`2Wh:L0502Wh:L00`21ZH40YMfS0:GMX`0C0:GMX`03
086YP@2OeY`0WmJL0140WmJL00<0PJV109C8TP2Db9803@2Db9800`21ZH40P[:008:bP00708:bP003
086YP@1USV@0IHiT0080IHiT0P21ZH6Y0;3PiP40oooo002Y0;3PiP03086YP@1MQVh0PJV10080PJV1
1P25]i000`21ZH40V<jO09S>W`0:09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0PJV10:KOZ02VgjP0
4P2VgjP00`21ZH40Yn2W0:OPY`0D0:OPY`03086YP@2UgJ<0YMfS01<0YMfS00<0PJV109oFW02OeY`0
402OeY`00`21ZH40U<RB09C8TP0=09C8TP03086YP@22/X00P[:000P0P[:000<0PJV106F>I01USV@0
0`21ZH6Z0;3PiP40oooo002Z0;3PiP03086YP@1MQVh0GHI^00@0PJV10`25]i000`21ZH40V<jO09S>
W`0;09S>W`03086YP@2RfZH0X]ZV00h0X]ZV00<0PJV10:KOZ02VgjP04P2VgjP00`21ZH40Yn2W0:OP
Y`0C0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0PJV109oFW02OeY`0402OeY`00`21ZH40U<RB09C8
TP0<09C8TP03086YP@22/X00P[:000P0P[:01021ZH400`1NQf40PJV10;3PiP2Z0;3PiP40oooo002[
0;3PiP80PJV100@0GHI^086YP@1k[8T0Njb91@21ZH4<09S>W`03086YP@2RfZH0X]ZV00l0X]ZV00<0
PJV10:KOZ02VgjP04@2VgjP00`21ZH40Yn2W0:OPY`0C0:OPY`03086YP@2UgJ<0YMfS01@0YMfS00<0
PJV109oFW02OeY`03`2OeY`00`21ZH40U<RB09C8TP0<09C8TP03086YP@22/X00P[:000H0P[:01021
ZH4205j7H@80PJV1[02`h>H10?ooo`00[@2`h>H01021ZH40GHI^086YP@21ZH4407^/R@D0PJV12@2H
cYl00`21ZH40X]ZV0:;JYP0>0:;JYP03086YP@2VgjP0Y]nX0140Y]nX00<0PJV10:OPY`2Wh:L04`2W
h:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL0100WmJL00<0PJV109C8TP2Db980302D
b9800`21ZH40P[:008:bP006086YP@0307ZZN`21ZH40GXMQ0080GXMQ00<0PJV10;3PiP2`h>H0[02`
h>H10?ooo`00[P2`h>H01021ZH40GHI^05f6KP21ZH4507^/R@03086YP@2?aIT0SlFI00L0PJV10P2H
cYl00`21ZH40X]ZV0:;JYP0?0:;JYP03086YP@2VgjP0Y]nX0100Y]nX00<0PJV10:OPY`2Wh:L04`2W
h:L00`21ZH40YMfS0:GMX`0C0:GMX`03086YP@2OeY`0WmJL00l0WmJL00<0PJV109C8TP2Db9802@2D
b987086YP@H0NZYk00D0PJV105j7H@1NQf40GXMQ086YP@2_0;3PiP40oooo002_0;3PiP80PJV100<0
GHI^086YP@1k[8T0101k[8T00`21ZH40SlFI08o5V@0608o5V@P0PJV1302RfZH00`21ZH40Y]nX0:KO
Z00A0:KOZ003086YP@2Wh:L0Yn2W0180Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oF
W00?09oFW004086YP@2Db980U<RB09C8TPP0PJV10P2=`Xh00`21ZH40NZYk07ZZN`0607ZZN`80PJV1
0`1NQf400`21ZH40/>3V0;3PiP2^0;3PiP40oooo002a0;3PiP03086YP@1MQVh0PJV100D0Njb90P21
ZH4:08o5V@04086YP@2Jdj80V]>R09[CXPT0PJV1102RfZH00`21ZH40Y]nX0:KOZ00@0:KOZ003086Y
P@2Wh:L0Yn2W0180Yn2W00<0PJV10:GMX`2UgJ<04`2UgJ<00`21ZH40WmJL09oFW00:09oFW0T0PJV1
2@2=`Xh00`21ZH40NZYk07ZZN`0607ZZN`03086YP@1NQf40GXMQ0080GXMQ00<0PJV10;3PiP2`h>H0
[`2`h>H10?ooo`00/P2`h>H00`21ZH40GHI^086YP@0607^/R@03086YP@2?aIT0SlFI00P0SlFI00<0
PJV109[CXP2Jdj802@2Jdj8>086YP@T0Y]nX00<0PJV10:OPY`2Wh:L04P2Wh:L00`21ZH40YMfS0:GM
X`0B0:GMX`03086YP@2OeY`0WmJL0080WmJL2@21ZH4309S@VP03086YP@2=`Xh0SL:>00/0SL:>00<0
PJV107ZZN`1jZW/01P1jZW/00`21ZH40GXMQ05j7H@0205j7H@03086YP@2`h>H0/>3V0;00/>3V0@3o
ool00;<0/>3V0`21ZH4607^/R@03086YP@2?aIT0SlFI00L0SlFI00<0PJV109[CXP2Jdj803P2Jdj80
0`21ZH40X=ZU0:3JY@060:3JYCP0PJV1302Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0
NZYk00H0NZYk00@0PJV105j7H@1NQf40GXMQ0P21ZH6c0;3PiP40oooo002e0;3PiP<0PJV11@1k[8T0
0`21ZH40SlFI08o5V@0708o5V@03086YP@2Jdj80V]>R00d0V]>R00<0PJV10:3JY@2PfZD03`2PfZD0
0`21ZH40XM^T0:7KY00B0:7KY003086YP@2Of:40WmRQ0180WmRQ00<0PJV109S@VP2Hd9X03@2Hd9X0
0`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0NZYk00H0NZYk00D0PJV105j7H@1NQf40GXMQ086Y
P@2e0;3PiP40oooo002f0;3PiP<0PJV11@1k[8T00`21ZH40SlFI08o5V@0708o5V@03086YP@2Jdj80
V]>R00d0V]>R00<0PJV10:3JY@2PfZD03`2PfZD00`21ZH40XM^T0:7KY00A0:7KY003086YP@2Of:40
WmRQ0140WmRQ00<0PJV109S@VP2Hd9X03@2Hd9X00`21ZH40SL:>08g2SP0:08g2SP03086YP@1jZW/0
NZYk00D0NZYk0P21ZH4305j7H@03086YP@2`h>H0/>3V0;@0/>3V0@3oool00;P0/>3V0P21ZH4507^/
R@80PJV1202?aIT00`21ZH40V]>R09[CXP0=09[CXP03086YP@2PfZD0X=ZU00h0X=ZU00<0PJV10:7K
Y02Qfj@04@2Qfj@00`21ZH40WmRQ09oHX@0A09oHX@03086YP@2Hd9X0V=2J00`0V=2J00<0PJV108g2
SP2=`Xh02`2=`Xh00`21ZH40NZYk07ZZN`0407ZZN`04086YP@1NQf40GXMQ05j7H@80PJV1]`2`h>H1
0?ooo`00^P2`h>H3086YP@@0Njb900<0PJV108o5V@2?aIT01P2?aIT00`21ZH40V]>R09[CXP0<09[C
XP03086YP@2PfZD0X=ZU00h0X=ZU00<0PJV10:7KY02Qfj@04@2Qfj@00`21ZH40WmRQ09oHX@0@09oH
X@03086YP@2Hd9X0V=2J00d0V=2J00<0PJV108g2SP2=`Xh02P2=`Xh00`21ZH40NZYk07ZZN`0407ZZ
N`H0PJV1^02`h>H10?ooo`00^`2`h>H6086YP@0307^/R@21ZH40SlFI00L0SlFI00<0PJV109[CXP2J
dj80302Jdj800`21ZH40X=ZU0:3JY@0=0:3JY@03086YP@2Qfj@0XM^T0140XM^T00<0PJV109oHX@2O
f:40402Of:400`21ZH40V=2J09S@VP0<09S@VP03086YP@2=`Xh0SL:>00X0SL:>00<0PJV107ZZN`1j
ZW/00`1jZW/3086YP@03059jF@21ZH40PJV10;X0/>3V0@3oool00;d0/>3V0P21ZH4206ZINP@0PJV1
1P2?aIT00`21ZH40V]>R09[CXP0<09[CXP03086YP@2PfZD0X=ZU00h0X=ZU00<0PJV10:7KY02Qfj@0
3`2Qfj@00`21ZH40WmRQ09oHX@0@09oHX@03086YP@2Hd9X0V=2J00`0V=2J00<0PJV108g2SP2=`Xh0
2P2=`Xh01021ZH40NZYk07ZZN`1jZW/4086YP@03059jF@21ZH40PJV10;`0/>3V0@3oool00;l0/>3V
0P21ZH4306ZINPD0PJV10`2?aIT00`21ZH40V]>R09[CXP0<09[CXP03086YP@2PfZD0X=ZU00d0X=ZU
00<0PJV10:7KY02Qfj@03`2Qfj@00`21ZH40WmRQ09oHX@0@09oHX@03086YP@2Hd9X0V=2J00/0V=2J
00<0PJV108g2SP2=`Xh02P2=`Xh7086YP@03059jF@21ZH40PJV10;h0/>3V0@3oool00<40/>3V0P21
ZH4306ZINP80PJV100<0O[:;086YP@21ZH400`21ZH4>09[CXP03086YP@2PfZD0X=ZU00`0X=ZU00<0
PJV10:7KY02Qfj@03`2Qfj@00`21ZH40WmRQ09oHX@0?09oHX@03086YP@2Hd9X0V=2J00`0V=2J00<0
PJV108g2SP2=`Xh00`2=`Xh8086YP@80JiUa0P21ZH400`1BNUT0PJV1086YP@300;3PiP40oooo0033
0;3PiP80PJV10`1ZVGX00`21ZH40O[:;07jbR`0207jbR`T0PJV11P2Jdj800`21ZH40X=ZU0:3JY@0<
0:3JY@03086YP@2Qfj@0XM^T00l0XM^T00<0PJV109oHX@2Of:403`2Of:400`21ZH40V=2J09S@VP08
09S@VPX0PJV1101m/H<2086YP@<0JiUa00@0PJV1059jF@21ZH40PJV1`P2`h>H10?ooo`00a@2`h>H2
086YP@80JYUj0P21ZH4407jbR`80PJV11@2:`YD?086YP@L0X=ZU00<0PJV10:7KY02Qfj@03P2Qfj@0
0`21ZH40WmRQ09oHX@0>09oHX@04086YP@2Hd9X0V=2J09S@VPP0PJV10P29`8l00`21ZH40OK6307fa
P`0707faP`80PJV10`1[VG44086YPL@0/>3V0@3oool00<H0/>3V0`21ZH4206ZINP03086YP@1n/X/0
O[:;00<0O[:;00<0PJV108[2U@2:`YD02P2:`YD00`21ZH40TLZJ097:VP04097:VRd0PJV12@29`8l0
0`21ZH40OK6307faP`0707faP`04086YP@1[VG40JiUa06^IL@@0PJV1aP2`h>H10?ooo`00b02`h>H3
086YP@0306ZINP21ZH40PJV100@0O[:;0P21ZH4;08[2U@03086YP@2AbYX0TLZJ00/0TLZJ00<0PJV1
09?<VP2Cc9X03@2Cc9X00`21ZH40TLVG0979U`0=0979U`03086YP@29`8l0RL2?00X0RL2?00<0PJV1
07faP`1m/H<01P1m/H<2086YP@80JiUa0`21ZH790;3PiP40oooo003;0;3PiPD0PJV1101n/X/2086Y
P@X0R/:E00<0PJV1097:VP2AbYX02P2AbYX00`21ZH40TlbJ09?<VP0=09?<VP03086YP@2AbIL0TLVG
00`0TLVG00<0PJV108W0S`29`8l02@29`8l2086YP@L0OK630P21ZH4206^IL@<0PJV1b`2`h>H10?oo
o`00c@2`h>H6086YP@<0O[:;00<0PJV108[2U@2:`YD0202:`YD00`21ZH40TLZJ097:VP0:097:VP03
086YP@2Cc9X0TlbJ00`0TlbJ00<0PJV10979U`2AbIL02`2AbIL00`21ZH40RL2?08W0S`0908W0S`03
086YP@1m/H<0OK6300D0OK631P21ZH7>0;3PiP40oooo003@0;3PiPT0PJV12@2:`YD00`21ZH40TLZJ
097:VP09097:VP03086YP@2Cc9X0TlbJ00/0TlbJ00<0PJV10979U`2AbIL0302AbIL00`21ZH40RL2?
08W0S`0808W0S`03086YP@1m/H<0OK6300<0OK631P21ZH7A0;3PiP40oooo003C0;3PiP`0PJV1102:
`YD00`21ZH40TLZJ097:VP09097:VP03086YP@2Cc9X0TlbJ00X0TlbJ00<0PJV10979U`2AbIL02`2A
bIL00`21ZH40RL2?08W0S`0808W0S`03086YP@1m/H<0PJV100P0PJV1d`2`h>H10?ooo`00e@2`h>H5
086YP@0506BBM021ZH40PJV1086YP@1_XGd02`21ZH45097:VP03086YP@2Cc9X0TlbJ00X0TlbJ00<0
PJV10979U`2AbIL02P2AbIL00`21ZH40RL2?08W0S`0308W0S`P0PJV100<0I9=_086YP@21ZH400`21
ZH7F0;3PiP40oooo003H0;3PiPD0PJV100<0I99d086YP@21ZH401@1_XGd2086YP@<0MZV39@21ZH42
072QNP80PJV10P1TTfl5086YPMT0/>3V0@3oool00=`0/>3V1`21ZH4406nQO@80PJV1201fZH<00`21
ZH40N:b407R/Q00807R/Q003086YP@1fZH40MZV100L0MZV10P21ZH47072QNP80PJV10P1TTfl3086Y
PMd0/>3V0@3oool00>40/>3V1`21ZH400`1_XGd0PJV1086YP@0607JYP`03086YP@1h[8@0N:b400L0
N:b400<0PJV107JYP@1fZH401P1fZH42086YP@L0L:5j1P21ZH7P0;3PiP40oooo003X0;3PiPL0PJV1
0`1fZH<00`21ZH40N:b407R/Q00607R/Q003086YP@1fZH40MZV10080MZV13`21ZH7T0;3PiP40oooo
003_0;3PiQ80PJV1lP2`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`
h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40
oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3P
i_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3o
ool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3V
m02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?oo
o`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd
0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo
003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0
/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool0
0?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`
h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00
o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3P
iP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o
0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V
0@3oool00?l0/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0
/>3Vm02`h>H10?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00?l0/>3Vm02`h>H1
0?ooo`00o`2`h>Kd0;3PiP40oooo003o0;3Pi_@0/>3V0@3oool00001\
\>"],
  ImageRangeCache->{{{0, 499}, {499, 0}} -> {-5.00005*^-06, -5.00005*^-06, \
0.00200403, 0.00200403}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 677}},
WindowToolbars->"EditBar",
WindowSize->{1015, 639},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
StyleDefinitions -> "Classroom.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 29, 0, 67, "Title"],

Cell[CellGroupData[{
Cell[1808, 55, 33, 0, 62, "Section"],
Cell[1844, 57, 73, 1, 50, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1954, 63, 31, 0, 62, "Section"],
Cell[1988, 65, 614, 13, 67, "Text"],
Cell[2605, 80, 458, 7, 67, "Text"],
Cell[3066, 89, 705, 12, 86, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3808, 106, 28, 0, 62, "Section"],
Cell[3839, 108, 95, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[3959, 114, 616, 11, 210, "Input"],
Cell[4578, 127, 360, 5, 25, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4975, 137, 34, 0, 52, "Subsection"],
Cell[5012, 139, 117, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[5154, 145, 60, 1, 50, "Input"],
Cell[5217, 148, 51907, 954, 462, 7018, 396, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57161, 1107, 85, 1, 50, "Input"],
Cell[57249, 1110, 37431, 1243, 215, 12766, 934, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94717, 2358, 85, 1, 50, "Input"],
Cell[94805, 2361, 36708, 1300, 221, 13629, 1012, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131550, 3666, 85, 1, 50, "Input"],
Cell[131638, 3669, 38212, 1588, 220, 17117, 1324, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169887, 5262, 74, 1, 50, "Input"],
Cell[169964, 5265, 33532, 1067, 248, 11323, 789, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203533, 6337, 87, 1, 50, "Input"],
Cell[203623, 6340, 41237, 1769, 220, 19199, 1494, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[244875, 8112, 87, 1, 50, "Input"],

Cell[CellGroupData[{
Cell[244987, 8117, 168, 2, 50, "Input"],
Cell[245158, 8121, 37496, 1532, 220, 16513, 1270, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[282669, 9656, 74, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[282768, 9660, 402, 7, 150, "Input"],

Cell[CellGroupData[{
Cell[283195, 9671, 33142, 1190, 215, 12766, 934, "GraphicsData", \
"PostScript", "Graphics"],
Cell[316340, 10863, 33318, 1258, 221, 13629, 1012, "GraphicsData", \
"PostScript", "Graphics"],
Cell[349661, 12123, 39160, 1744, 220, 19199, 1494, "GraphicsData", \
"PostScript", "Graphics"],
Cell[388824, 13869, 33782, 1221, 215, 13236, 964, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[422667, 15097, 33, 0, 52, "Subsection"],
Cell[422703, 15099, 116, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[422844, 15105, 60, 1, 50, "Input"],
Cell[422907, 15108, 61173, 1114, 424, 7640, 450, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[484117, 16227, 85, 1, 50, "Input"],
Cell[484205, 16230, 42883, 1883, 216, 20205, 1600, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[527125, 18118, 85, 1, 50, "Input"],
Cell[527213, 18121, 41220, 1953, 218, 21393, 1705, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[568470, 20079, 85, 1, 50, "Input"],
Cell[568558, 20082, 43438, 2184, 219, 24071, 1942, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[612033, 22271, 74, 1, 50, "Input"],
Cell[612110, 22274, 34420, 1111, 248, 11754, 828, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[646567, 23390, 87, 1, 50, "Input"],
Cell[646657, 23393, 43125, 2059, 220, 22683, 1803, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[689819, 25457, 87, 1, 50, "Input"],
Cell[689909, 25460, 42573, 1818, 215, 19392, 1528, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[732519, 27283, 163, 2, 50, "Input"],
Cell[732685, 27287, 42044, 2072, 219, 22764, 1831, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[774766, 29364, 402, 7, 150, "Input"],

Cell[CellGroupData[{
Cell[775193, 29375, 41984, 1872, 216, 20205, 1600, "GraphicsData", \
"PostScript", "Graphics"],
Cell[817180, 31249, 40892, 1949, 218, 21393, 1705, "GraphicsData", \
"PostScript", "Graphics"],
Cell[858075, 33200, 41987, 2045, 220, 22683, 1803, "GraphicsData", \
"PostScript", "Graphics"],
Cell[900065, 35247, 40720, 1796, 215, 19392, 1528, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[940858, 37051, 47, 0, 62, "Section"],
Cell[940908, 37053, 741, 15, 184, "Text"],
Cell[941652, 37070, 666, 17, 67, "Text"],
Cell[942321, 37089, 103, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[942449, 37096, 75, 2, 52, "Subsection"],
Cell[942527, 37100, 374, 6, 48, "Text"],
Cell[942904, 37108, 605, 9, 190, "Input"],
Cell[943512, 37119, 137, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[943674, 37128, 381, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[944080, 37138, 66359, 1709, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1010442, 38849, 66464, 1709, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1076909, 40560, 66335, 1707, 443, 16183, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1143247, 42269, 66238, 1706, 443, 16187, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1209488, 43977, 66281, 1706, 443, 16214, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1275772, 45685, 66192, 1705, 443, 16218, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1341967, 47392, 65932, 1702, 443, 16213, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1407902, 49096, 65791, 1701, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1473696, 50799, 65663, 1699, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1539362, 52500, 65416, 1696, 443, 16223, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1604781, 54198, 65271, 1694, 443, 16204, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1670055, 55894, 65570, 1698, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1735628, 57594, 65622, 1699, 443, 16186, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1801253, 59295, 65711, 1700, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1866967, 60997, 65818, 1701, 443, 16184, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1932788, 62700, 65999, 1703, 443, 16171, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1998790, 64405, 66337, 1707, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2065130, 66114, 66344, 1707, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2131477, 67823, 66186, 1705, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2197666, 69530, 66357, 1707, 443, 16213, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2264026, 71239, 66093, 1704, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2330122, 72945, 65906, 1702, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2396031, 74649, 65705, 1700, 443, 16164, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2461739, 76351, 65476, 1697, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2527218, 78050, 65514, 1697, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2592735, 79749, 65318, 1695, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2658056, 81446, 65395, 1696, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2723454, 83144, 65594, 1698, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2789051, 84844, 65667, 1699, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2854721, 86545, 65949, 1703, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[2920697, 88252, 222, 6, 29, "Text"],

Cell[CellGroupData[{
Cell[2920944, 88262, 387, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[2921356, 88272, 67096, 1718, 447, 16172, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2988455, 89992, 67120, 1717, 443, 16186, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3055578, 91711, 67116, 1717, 443, 16178, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3122697, 93430, 66973, 1715, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3189673, 95147, 66684, 1712, 443, 16187, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3256360, 96861, 66800, 1713, 443, 16198, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3323163, 98576, 66725, 1712, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3389891, 100290, 67036, 1716, 443, 16175, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3456930, 102008, 67144, 1717, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3524077, 103727, 67268, 1719, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3591348, 105448, 67078, 1717, 443, 16192, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3658429, 107167, 66680, 1712, 443, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3725112, 108881, 66251, 1706, 443, 16192, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3791366, 110589, 66334, 1707, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3857703, 112298, 66740, 1712, 443, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3924446, 114012, 66961, 1715, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3991410, 115729, 67028, 1716, 443, 16211, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4058441, 117447, 67072, 1716, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4125516, 119165, 66877, 1714, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4192396, 120881, 66720, 1712, 443, 16179, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4259119, 122595, 66633, 1711, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4325755, 124308, 66695, 1712, 443, 16186, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4392453, 126022, 66800, 1713, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4459256, 127737, 67066, 1716, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4526325, 129455, 67258, 1719, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4593586, 131176, 67063, 1716, 443, 16198, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4660652, 132894, 66758, 1712, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4727413, 134608, 66228, 1706, 443, 16213, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4793644, 136316, 66427, 1708, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4860074, 138026, 66848, 1713, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[4926949, 139743, 351, 11, 29, "Text"],
Cell[4927303, 139756, 398, 6, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4927738, 139767, 72, 2, 52, "Subsection"],
Cell[4927813, 139771, 98, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[4927936, 139777, 605, 9, 190, "Input"],
Cell[4928544, 139788, 370, 5, 25, "Message"]
}, Open  ]],
Cell[4928929, 139796, 319, 14, 29, "Text"],

Cell[CellGroupData[{
Cell[4929273, 139814, 381, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[4929679, 139824, 66292, 1707, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4995974, 141533, 66593, 1711, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5062570, 143246, 67157, 1717, 443, 16207, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5129730, 144965, 67349, 1720, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5197082, 146687, 67564, 1722, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5264649, 148411, 67956, 1727, 443, 16220, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5332608, 150140, 67815, 1725, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5400426, 151867, 67417, 1721, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5467846, 153590, 66640, 1711, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5534489, 155303, 65488, 1697, 443, 16206, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5599980, 157002, 64845, 1689, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5664828, 158693, 64445, 1684, 443, 16188, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5729276, 160379, 65478, 1696, 443, 16217, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5794757, 162077, 65679, 1699, 443, 16187, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5860439, 163778, 65883, 1702, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5926325, 165482, 66217, 1706, 443, 16214, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5992545, 167190, 66430, 1708, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6058978, 168900, 67089, 1717, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6126070, 170619, 67256, 1719, 443, 16188, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6193329, 172340, 67543, 1722, 443, 16204, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6260875, 174064, 68083, 1729, 443, 16209, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6328961, 175795, 68024, 1728, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6396988, 177525, 67422, 1721, 443, 16184, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6464413, 179248, 66665, 1711, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6531081, 180961, 65641, 1699, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6596725, 182662, 64775, 1688, 443, 16190, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6661503, 184352, 64530, 1685, 443, 16200, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6726036, 186039, 65542, 1697, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6791581, 187738, 65571, 1698, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6857155, 189438, 65995, 1703, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[6923177, 191145, 112, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[6923314, 191152, 387, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[6923726, 191162, 65704, 1701, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6989433, 192865, 66300, 1707, 443, 16200, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7055736, 194574, 67100, 1717, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7122839, 196293, 67951, 1727, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7190793, 198022, 68055, 1728, 443, 16214, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7258851, 199752, 68095, 1729, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7326949, 201483, 67872, 1726, 443, 16213, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7394824, 203211, 67351, 1720, 443, 16174, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7462178, 204933, 66678, 1711, 443, 16214, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7528859, 206646, 65409, 1696, 443, 16188, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7594271, 208344, 64665, 1687, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7658939, 210033, 64621, 1686, 443, 16190, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7723563, 211721, 65107, 1693, 443, 16184, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7788673, 213416, 65016, 1691, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7853692, 215109, 65121, 1692, 443, 16192, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7918816, 216803, 65695, 1699, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7984514, 218504, 66204, 1706, 443, 16189, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8050721, 220212, 67148, 1717, 443, 16206, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8117872, 221931, 68076, 1729, 443, 16198, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8185951, 223662, 68274, 1731, 443, 16198, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8254228, 225395, 68217, 1730, 443, 16214, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8322448, 227127, 67994, 1728, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8390445, 228857, 67465, 1721, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8457913, 230580, 66656, 1711, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8524572, 232293, 65636, 1699, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8590211, 233994, 64709, 1687, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8654923, 235683, 64524, 1685, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8719450, 237370, 65057, 1692, 443, 16180, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8784510, 239064, 65082, 1692, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8849595, 240758, 65202, 1693, 443, 16204, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[8914824, 242455, 106, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[8914955, 242462, 398, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[8915378, 242472, 66317, 1708, 444, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8981698, 244182, 67050, 1716, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9048751, 245900, 67789, 1725, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9116543, 247627, 68227, 1731, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9184773, 249360, 68471, 1734, 443, 16204, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9253247, 251096, 68498, 1734, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9321748, 252832, 68314, 1732, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9390065, 254566, 67803, 1725, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9457871, 256293, 67020, 1716, 443, 16207, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9524894, 258011, 66208, 1706, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9591105, 259719, 65181, 1693, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9656289, 261414, 64169, 1681, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9720461, 263097, 63319, 1670, 443, 16216, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9783783, 264769, 64313, 1683, 443, 16181, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9848099, 266454, 65305, 1695, 443, 16185, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9913407, 268151, 66282, 1707, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9979692, 269860, 67258, 1719, 443, 16190, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10046953, 271581, 67849, 1726, 443, 16198, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10114805, 273309, 68386, 1733, 443, 16200, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10183194, 275044, 68715, 1737, 443, 16181, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10251912, 276783, 68737, 1737, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10320652, 278522, 68381, 1733, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10389036, 280257, 67801, 1725, 443, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10456840, 281984, 67179, 1718, 443, 16204, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10524022, 283704, 66308, 1707, 443, 16200, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10590333, 285413, 65337, 1695, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10655673, 287110, 64189, 1681, 443, 16187, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10719865, 288793, 63311, 1670, 443, 16184, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10783179, 290465, 64285, 1682, 443, 16186, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10847467, 292149, 65264, 1694, 443, 16205, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10912792, 293850, 73, 2, 52, "Subsection"],
Cell[10912868, 293854, 102, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[10912995, 293861, 607, 9, 190, "Input"],
Cell[10913605, 293872, 378, 5, 25, "Message"]
}, Open  ]],
Cell[10913998, 293880, 212, 11, 29, "Text"],

Cell[CellGroupData[{
Cell[10914235, 293895, 387, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[10914647, 293905, 66292, 1707, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10980942, 295614, 66464, 1709, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11047409, 297325, 66335, 1707, 443, 16183, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11113747, 299034, 66238, 1706, 443, 16187, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11179988, 300742, 66281, 1706, 443, 16214, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11246272, 302450, 66192, 1705, 443, 16218, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11312467, 304157, 65932, 1702, 443, 16213, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11378402, 305861, 65791, 1701, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11444196, 307564, 65663, 1699, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11509862, 309265, 65416, 1696, 443, 16223, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11575281, 310963, 65271, 1694, 443, 16204, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11640555, 312659, 65570, 1698, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11706128, 314359, 65622, 1699, 443, 16186, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11771753, 316060, 65778, 1702, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11837534, 317764, 65818, 1701, 443, 16184, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11903355, 319467, 65999, 1703, 443, 16171, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11969357, 321172, 66337, 1707, 443, 16197, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12035697, 322881, 66344, 1707, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12102044, 324590, 66186, 1705, 443, 16212, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12168233, 326297, 66357, 1707, 443, 16213, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12234593, 328006, 66093, 1704, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12300689, 329712, 65906, 1702, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12366598, 331416, 65705, 1700, 443, 16164, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12432306, 333118, 65476, 1697, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12497785, 334817, 65514, 1697, 443, 16196, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12563302, 336516, 65318, 1695, 443, 16194, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12628623, 338213, 65395, 1696, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12694021, 339911, 65594, 1698, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12759618, 341611, 65667, 1699, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12825288, 343312, 65949, 1703, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[12891264, 345019, 123, 3, 29, "Text"],
Cell[12891390, 345024, 399, 6, 130, "Input"],
Cell[12891792, 345032, 144, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[12891961, 345041, 399, 6, 130, "Input"],

Cell[CellGroupData[{
Cell[12892385, 345051, 68073, 1729, 443, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12960461, 346782, 67715, 1724, 443, 16218, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13028179, 348508, 67234, 1718, 443, 16215, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13095416, 350228, 66494, 1709, 443, 16208, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13161913, 351939, 65639, 1699, 443, 16187, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13227555, 353640, 64645, 1686, 443, 16206, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13292203, 355328, 63992, 1678, 443, 16209, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13356198, 357008, 63810, 1676, 443, 16193, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13420011, 358686, 64077, 1679, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13484091, 360367, 63980, 1678, 443, 16209, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13548074, 362047, 63990, 1679, 443, 16201, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13612067, 363728, 63950, 1678, 443, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13676020, 365408, 63860, 1677, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13739883, 367087, 63832, 1676, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13803718, 368765, 64096, 1680, 443, 16203, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13867817, 370447, 64938, 1690, 443, 16211, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13932758, 372139, 65872, 1701, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13998633, 373842, 66663, 1711, 443, 16191, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14065299, 375555, 67425, 1721, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14132727, 377278, 67958, 1727, 443, 16198, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14200688, 379007, 68217, 1730, 443, 16202, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14268908, 380739, 68170, 1730, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14337081, 382471, 68605, 1735, 443, 16185, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14405689, 384208, 68448, 1734, 443, 16181, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14474140, 385944, 68636, 1736, 443, 16199, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14542779, 387682, 68369, 1733, 443, 16183, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14611151, 389417, 68588, 1735, 443, 16192, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14679742, 391154, 68379, 1732, 443, 16210, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14748124, 392888, 68453, 1733, 443, 16195, 1085, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14816580, 394623, 68534, 1734, 443, 16211, 1085, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14885175, 396364, 59, 0, 52, "Subsection"],

Cell[CellGroupData[{
Cell[14885259, 396368, 54, 0, 43, "Subsubsection"],
Cell[14885316, 396370, 122, 3, 33, "Text"],
Cell[14885441, 396375, 1065, 17, 270, "Input"],
Cell[14886509, 396394, 376, 6, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14886922, 396405, 51, 0, 29, "Subsubsection"],
Cell[14886976, 396407, 120, 3, 33, "Text"],
Cell[14887099, 396412, 1069, 17, 270, "Input"],
Cell[14888171, 396431, 209, 4, 52, "Text"],
Cell[14888383, 396437, 409, 7, 110, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14888829, 396449, 50, 0, 29, "Subsubsection"],
Cell[14888882, 396451, 118, 3, 33, "Text"],
Cell[14889003, 396456, 1061, 17, 270, "Input"],
Cell[14890067, 396475, 184, 6, 33, "Text"],
Cell[14890254, 396483, 382, 6, 110, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14890697, 396496, 52, 0, 62, "Section"],
Cell[14890752, 396498, 262, 5, 48, "Text"],

Cell[CellGroupData[{
Cell[14891039, 396507, 40, 0, 52, "Subsection"],
Cell[14891082, 396509, 279, 5, 48, "Text"],
Cell[14891364, 396516, 1836, 32, 370, "Input"],

Cell[CellGroupData[{
Cell[14893225, 396552, 376, 7, 130, "Input"],

Cell[CellGroupData[{
Cell[14893626, 396563, 153457, 5796, 238, 67335, 4728, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15047086, 402361, 153295, 5862, 238, 68297, 4809, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15200384, 408225, 152870, 5826, 238, 67974, 4775, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15353257, 414053, 153560, 5901, 238, 68878, 4852, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15506820, 419956, 152555, 5815, 238, 67800, 4765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15659378, 425773, 154356, 5795, 238, 67341, 4717, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15813737, 431570, 153824, 5806, 238, 67445, 4736, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15967564, 437378, 151627, 5586, 238, 64888, 4512, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16119194, 442966, 152817, 5489, 238, 63514, 4383, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16272014, 448457, 152271, 5484, 238, 63438, 4384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16424288, 453943, 152593, 5520, 238, 63942, 4422, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16576884, 459465, 153623, 5637, 238, 65235, 4542, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16730510, 465104, 153230, 5733, 238, 66596, 4660, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16883743, 470839, 154928, 5801, 238, 67286, 4716, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17038674, 476642, 154961, 5840, 238, 67890, 4762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17193638, 482484, 154057, 5802, 238, 67472, 4730, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17347698, 488288, 154844, 5842, 238, 67850, 4765, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17502545, 494132, 153915, 5771, 238, 67038, 4695, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17656463, 499905, 157187, 5918, 238, 68338, 4818, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17813653, 505825, 155854, 5864, 238, 67811, 4774, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17969510, 511691, 154799, 5735, 238, 66343, 4640, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18124312, 517428, 153053, 5602, 238, 64900, 4510, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18277368, 523032, 153415, 5631, 238, 65153, 4538, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18430786, 528665, 154525, 5703, 238, 66004, 4607, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18585314, 534370, 154322, 5765, 238, 66765, 4681, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18739639, 540137, 151759, 5692, 238, 66312, 4634, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18891401, 545831, 151358, 5727, 238, 66858, 4680, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19042762, 551560, 154062, 5791, 238, 67254, 4716, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19196827, 557353, 152646, 5776, 238, 67308, 4719, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19349476, 563131, 154131, 5807, 238, 67538, 4735, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19503610, 568940, 155073, 5874, 238, 68095, 4797, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19658686, 574816, 154003, 5770, 238, 66980, 4692, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19812692, 580588, 156653, 5840, 238, 67391, 4735, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19969348, 586430, 154582, 5685, 238, 65721, 4585, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20123933, 592117, 153619, 5629, 238, 65122, 4533, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20277555, 597748, 154857, 5693, 238, 65757, 4590, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20432415, 603443, 155200, 5802, 238, 67096, 4711, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20587618, 609247, 156741, 5953, 238, 68880, 4865, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20744362, 615202, 154920, 5842, 238, 67671, 4762, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20899285, 621046, 154835, 5836, 238, 67756, 4758, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21054123, 626884, 152785, 5707, 238, 66378, 4637, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21206911, 632593, 153583, 5772, 238, 67160, 4702, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21360497, 638367, 155906, 5821, 238, 67320, 4724, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21516406, 644190, 153808, 5790, 238, 67275, 4718, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21670217, 649982, 153601, 5722, 238, 66295, 4641, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21823821, 655706, 152497, 5629, 238, 65252, 4549, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21976321, 661337, 153057, 5544, 238, 64107, 4443, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22129381, 666883, 153928, 5618, 238, 64872, 4515, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22283312, 672503, 151938, 5645, 238, 65588, 4576, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22435253, 678150, 153171, 5773, 238, 67185, 4708, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22588473, 683929, 236, 5, 90, "Input"],
Cell[22588712, 683936, 17404, 334, 296, 6018, 189, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22606119, 684272, 132, 3, 49, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22606300, 684281, 79, 0, 52, "Subsection"],
Cell[22606382, 684283, 524, 8, 67, "Text"],
Cell[22606909, 684293, 319, 5, 48, "Text"],
Cell[22607231, 684300, 341, 6, 132, "Input"],
Cell[22607575, 684308, 189, 4, 29, "Text"],

Cell[CellGroupData[{
Cell[22607789, 684316, 2087, 34, 470, "Input"],
Cell[22609879, 684352, 101566, 3128, 160, 78278, 2836, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[22711460, 687483, 108, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[22711593, 687490, 357, 6, 110, "Input"],

Cell[CellGroupData[{
Cell[22711975, 687500, 191237, 6167, 509, 106842, 5121, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22903215, 693669, 190961, 6199, 508, 108010, 5172, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23094179, 699870, 189477, 6143, 508, 107668, 5130, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23283659, 706015, 189378, 6170, 508, 107820, 5160, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23473040, 712187, 188840, 6103, 508, 106383, 5082, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23661883, 718292, 188837, 6184, 508, 108097, 5184, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23850723, 724478, 187610, 6151, 508, 107980, 5165, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24038336, 730631, 188200, 6186, 508, 108193, 5195, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24226539, 736819, 189841, 6211, 508, 107525, 5191, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24416383, 743032, 190243, 6230, 508, 108478, 5217, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24606629, 749264, 188488, 6055, 508, 106748, 5043, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24795120, 755321, 188903, 6054, 508, 106539, 5034, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24984026, 761377, 189385, 6022, 508, 105381, 4982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25173414, 767401, 189187, 6048, 508, 106479, 5024, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25362604, 773451, 187553, 6028, 508, 106562, 5025, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25550160, 779481, 188699, 6130, 508, 107481, 5124, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25738862, 785613, 188317, 6138, 508, 106868, 5129, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25927182, 791753, 187494, 6106, 508, 107331, 5112, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26114679, 797861, 185977, 6015, 508, 106529, 5031, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26300659, 803878, 187935, 6114, 508, 107284, 5115, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26488597, 809994, 189166, 6112, 508, 106348, 5086, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26677766, 816108, 189482, 6159, 508, 107636, 5145, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26867251, 822269, 189330, 6150, 508, 107711, 5139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[27056584, 828421, 190519, 6189, 508, 107908, 5166, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

